# coding: utf8
from __future__ import unicode_literals


# Stop words

STOP_WORDS = set("""
අතර
එච්චර
එපමණ
එලෙස
එවිට
ඒ
කට
කදී
කින්
ක්
ට
තුර
ත්
ද
නමුත්
නොහොත්
පමණ
පමණි
ම
මෙච්චර
මෙපමණ
මෙලෙස
මෙවිට
මේ
ය
යි
ලදී
ලෙස
වගේ
වන
විට
විටෙක
විතර
විය
වුව
වුවත්
වුවද
වූ
සමඟ
සහ
හා
හෙවත්
හෝ  
""".split())
