# coding: utf8
from __future__ import unicode_literals

# Original pairs downloaded from http://www.lexiconista.com/datasets/lemmatization/
# Replaced characters using cedillas with the correct ones (ș and ț)

LOOKUP = {
    "abale": "aba",
    "abalei": "aba",
    "abalele": "aba",
    "abalelor": "aba",
    "abaua": "aba",
    "abace": "abac",
    "abacele": "abac",
    "abacelor": "abac",
    "abacul": "abac",
    "abacului": "abac",
    "abaca": "abacă",
    "abace": "abacă",
    "abacei": "abacă",
    "abacele": "abacă",
    "abacelor": "abacă",
    "abagița": "abagiță",
    "abagițe": "abagiță",
    "abagiței": "abagiță",
    "abagițele": "abagiță",
    "abagițelor": "abagiță",
    "abagii": "abagiu",
    "abagiii": "abagiu",
    "abagiilor": "abagiu",
    "abagiul": "abagiu",
    "abagiului": "abagiu",
    "abajurul": "abajur",
    "abajurului": "abajur",
    "abajururi": "abajur",
    "abajururile": "abajur",
    "abajururilor": "abajur",
    "abandonul": "abandon",
    "abandonului": "abandon",
    "abandonuri": "abandon",
    "abandonurile": "abandon",
    "abandonurilor": "abandon",
    "abandonă": "abandona",
    "abandonai": "abandona",
    "abandonam": "abandona",
    "abandonăm": "abandona",
    "abandonând": "abandona",
    "abandonându": "abandona",
    "abandonară": "abandona",
    "abandonarăm": "abandona",
    "abandonarăți": "abandona",
    "abandonase": "abandona",
    "abandonasem": "abandona",
    "abandonaseră": "abandona",
    "abandonaserăm": "abandona",
    "abandonaserăți": "abandona",
    "abandonaseși": "abandona",
    "abandonași": "abandona",
    "abandonat": "abandona",
    "abandonați": "abandona",
    "abandonatu": "abandona",
    "abandonau": "abandona",
    "abandonează": "abandona",
    "abandonez": "abandona",
    "abandoneze": "abandona",
    "abandonezi": "abandona",
    "neabandonând": "abandona",
    "neabandonându": "abandona",
    "nemaiabandonând": "abandona",
    "nemaiabandonându": "abandona",
    "abandonarea": "abandonare",
    "abandonări": "abandonare",
    "abandonării": "abandonare",
    "abandonările": "abandonare",
    "abandonata": "abandonat",
    "abandonată": "abandonat",
    "abandonate": "abandonat",
    "abandonatei": "abandonat",
    "abandonatele": "abandonat",
    "abandonatelor": "abandonat",
    "abandonați": "abandonat",
    "abandonații": "abandonat",
    "abandonaților": "abandonat",
    "abandonatul": "abandonat",
    "abandonatului": "abandonat",
    "abanoși": "abanos",
    "abanoșii": "abanos",
    "abanoșilor": "abanos",
    "abanosul": "abanos",
    "abanosului": "abanos",
    "abataje": "abataj",
    "abatajele": "abataj",
    "abatajelor": "abataj",
    "abatajul": "abataj",
    "abatajului": "abataj",
    "abat": "abate",
    "abată": "abate",
    "abătând": "abate",
    "abătându": "abate",
    "abătea": "abate",
    "abăteai": "abate",
    "abăteam": "abate",
    "abăteați": "abate",
    "abăteau": "abate",
    "abatele": "abate",
    "abatelui": "abate",
    "abatem": "abate",
    "abateți": "abate",
    "abați": "abate",
    "abații": "abate",
    "abaților": "abate",
    "abătu": "abate",
    "abătui": "abate",
    "abătură": "abate",
    "abăturăm": "abate",
    "abăturăți": "abate",
    "abătuse": "abate",
    "abătusem": "abate",
    "abătuseră": "abate",
    "abătuserăm": "abate",
    "abătuserăți": "abate",
    "abătuseși": "abate",
    "abătuși": "abate",
    "abătut": "abate",
    "abătutu": "abate",
    "neabătând": "abate",
    "neabătându": "abate",
    "nemaiabătând": "abate",
    "nemaiabătându": "abate",
    "abaterea": "abatere",
    "abateri": "abatere",
    "abaterii": "abatere",
    "abaterile": "abatere",
    "abația": "abație",
    "abației": "abație",
    "abații": "abație",
    "abațiile": "abație",
    "abațiilor": "abație",
    "abatiza": "abatiză",
    "abatize": "abatiză",
    "abatizei": "abatiză",
    "abatizele": "abatiză",
    "abatizelor": "abatiză",
    "abatoare": "abator",
    "abatoarele": "abator",
    "abatoarelor": "abator",
    "abatorul": "abator",
    "abatorului": "abator",
    "abătuta": "abătut",
    "abătută": "abătut",
    "abătute": "abătut",
    "abătutei": "abătut",
    "abătutele": "abătut",
    "abătutelor": "abătut",
    "abătuți": "abătut",
    "abătuții": "abătut",
    "abătuților": "abătut",
    "abătutul": "abătut",
    "abătutului": "abătut",
    "abcese": "abces",
    "abcesele": "abces",
    "abceselor": "abces",
    "abcesul": "abces",
    "abcesului": "abces",
    "abdic": "abdica",
    "abdică": "abdica",
    "abdicai": "abdica",
    "abdicam": "abdica",
    "abdicăm": "abdica",
    "abdicând": "abdica",
    "abdicându": "abdica",
    "abdicară": "abdica",
    "abdicarăm": "abdica",
    "abdicarăți": "abdica",
    "abdicase": "abdica",
    "abdicasem": "abdica",
    "abdicaseră": "abdica",
    "abdicaserăm": "abdica",
    "abdicaserăți": "abdica",
    "abdicaseși": "abdica",
    "abdicași": "abdica",
    "abdicat": "abdica",
    "abdicați": "abdica",
    "abdicatu": "abdica",
    "abdicau": "abdica",
    "abdice": "abdica",
    "abdici": "abdica",
    "neabdicând": "abdica",
    "neabdicându": "abdica",
    "nemaiabdicând": "abdica",
    "nemaiabdicându": "abdica",
    "abdicarea": "abdicare",
    "abdicări": "abdicare",
    "abdicării": "abdicare",
    "abdicările": "abdicare",
    "abdicata": "abdicat",
    "abdicată": "abdicat",
    "abdicate": "abdicat",
    "abdicatei": "abdicat",
    "abdicatele": "abdicat",
    "abdicatelor": "abdicat",
    "abdicați": "abdicat",
    "abdicații": "abdicat",
    "abdicaților": "abdicat",
    "abdicatul": "abdicat",
    "abdicatului": "abdicat",
    "abdomene": "abdomen",
    "abdomenele": "abdomen",
    "abdomenelor": "abdomen",
    "abdomenul": "abdomen",
    "abdomenului": "abdomen",
    "abdominală": "abdominal",
    "abdominale": "abdominal",
    "abdominalei": "abdominal",
    "abdominalele": "abdominal",
    "abdominalelor": "abdominal",
    "abdominali": "abdominal",
    "abdominalii": "abdominal",
    "abdominalilor": "abdominal",
    "abdominalul": "abdominal",
    "abdominalului": "abdominal",
    "abductori": "abductor",
    "abductorii": "abductor",
    "abductorilor": "abductor",
    "abductorul": "abductor",
    "abductorului": "abductor",
    "abeceu": "abece",
    "abeceu'": "abece",
    "abecedare": "abecedar",
    "abecedarele": "abecedar",
    "abecedarelor": "abecedar",
    "abecedarul": "abecedar",
    "abecedarului": "abecedar",
    "aberanta": "aberant",
    "aberantă": "aberant",
    "aberante": "aberant",
    "aberantei": "aberant",
    "aberantele": "aberant",
    "aberantelor": "aberant",
    "aberanți": "aberant",
    "aberanții": "aberant",
    "aberanților": "aberant",
    "aberantul": "aberant",
    "aberantului": "aberant",
    "aberația": "aberație",
    "aberației": "aberație",
    "aberații": "aberație",
    "aberațiile": "aberație",
    "aberațiilor": "aberație",
    "abila": "abil",
    "abilă": "abil",
    "abile": "abil",
    "abilei": "abil",
    "abilele": "abil",
    "abilelor": "abil",
    "abili": "abil",
    "abilii": "abil",
    "abililor": "abil",
    "abilul": "abil",
    "abilului": "abil",
    "abilită": "abilita",
    "abilitai": "abilita",
    "abilitam": "abilita",
    "abilităm": "abilita",
    "abilitând": "abilita",
    "abilitându": "abilita",
    "abilitară": "abilita",
    "abilitarăm": "abilita",
    "abilitarăți": "abilita",
    "abilitase": "abilita",
    "abilitasem": "abilita",
    "abilitaseră": "abilita",
    "abilitaserăm": "abilita",
    "abilitaserăți": "abilita",
    "abilitaseși": "abilita",
    "abilitași": "abilita",
    "abilitat": "abilita",
    "abilitați": "abilita",
    "abilitatu": "abilita",
    "abilitau": "abilita",
    "abilitează": "abilita",
    "abilitez": "abilita",
    "abiliteze": "abilita",
    "abilitezi": "abilita",
    "neabilitând": "abilita",
    "neabilitându": "abilita",
    "nemaiabilitând": "abilita",
    "nemaiabilitându": "abilita",
    "abilitarea": "abilitare",
    "abilitări": "abilitare",
    "abilitării": "abilitare",
    "abilitările": "abilitare",
    "abilitata": "abilitat",
    "abilitată": "abilitat",
    "abilitate": "abilitat",
    "abilitatei": "abilitat",
    "abilitatele": "abilitat",
    "abilitatelor": "abilitat",
    "abilitați": "abilitat",
    "abilitații": "abilitat",
    "abilitaților": "abilitat",
    "abilitatul": "abilitat",
    "abilitatului": "abilitat",
    "abilitatea": "abilitate",
    "abilități": "abilitate",
    "abilității": "abilitate",
    "abilitățile": "abilitate",
    "abilităților": "abilitate",
    "abiotica": "abiotic",
    "abiotică": "abiotic",
    "abiotice": "abiotic",
    "abioticei": "abiotic",
    "abioticele": "abiotic",
    "abioticelor": "abiotic",
    "abiotici": "abiotic",
    "abioticii": "abiotic",
    "abioticilor": "abiotic",
    "abioticul": "abiotic",
    "abioticului": "abiotic",
    "abisul": "abis",
    "abisului": "abis",
    "abisuri": "abis",
    "abisurile": "abis",
    "abisurilor": "abis",
    "abisala": "abisal",
    "abisală": "abisal",
    "abisale": "abisal",
    "abisalei": "abisal",
    "abisalele": "abisal",
    "abisalelor": "abisal",
    "abisali": "abisal",
    "abisalii": "abisal",
    "abisalilor": "abisal",
    "abisalul": "abisal",
    "abisalului": "abisal",
    "abjecta": "abject",
    "abjectă": "abject",
    "abjecte": "abject",
    "abjectei": "abject",
    "abjectele": "abject",
    "abjectelor": "abject",
    "abjecți": "abject",
    "abjecții": "abject",
    "abjecților": "abject",
    "abjectul": "abject",
    "abjectului": "abject",
    "abjecția": "abjecție",
    "abjecției": "abjecție",
    "abjecții": "abjecție",
    "abjecțiile": "abjecție",
    "abjecțiilor": "abjecție",
    "abjur": "abjura",
    "abjură": "abjura",
    "abjurai": "abjura",
    "abjuram": "abjura",
    "abjurăm": "abjura",
    "abjurând": "abjura",
    "abjurându": "abjura",
    "abjurară": "abjura",
    "abjurarăm": "abjura",
    "abjurarăți": "abjura",
    "abjurase": "abjura",
    "abjurasem": "abjura",
    "abjuraseră": "abjura",
    "abjuraserăm": "abjura",
    "abjuraserăți": "abjura",
    "abjuraseși": "abjura",
    "abjurași": "abjura",
    "abjurat": "abjura",
    "abjurați": "abjura",
    "abjuratu": "abjura",
    "abjurau": "abjura",
    "abjure": "abjura",
    "abjuri": "abjura",
    "abjurarea": "abjurare",
    "abjurări": "abjurare",
    "abjurării": "abjurare",
    "abjurările": "abjurare",
    "abjurărilor": "abjurare",
    "abjurată": "abjurat",
    "abjurate": "abjurat",
    "abjurați": "abjurat",
    "abnegația": "abnegație",
    "abnegației": "abnegație",
    "abnegații": "abnegație",
    "abnegațiile": "abnegație",
    "abnegațiilor": "abnegație",
    "abolea": "aboli",
    "aboleai": "aboli",
    "aboleam": "aboli",
    "abolească": "aboli",
    "aboleați": "aboli",
    "aboleau": "aboli",
    "abolesc": "aboli",
    "abolește": "aboli",
    "abolești": "aboli",
    "abolii": "aboli",
    "abolim": "aboli",
    "abolind": "aboli",
    "abolindu": "aboli",
    "aboliră": "aboli",
    "abolirăm": "aboli",
    "abolirăți": "aboli",
    "abolise": "aboli",
    "abolisem": "aboli",
    "aboliseră": "aboli",
    "aboliserăm": "aboli",
    "aboliserăți": "aboli",
    "aboliseși": "aboli",
    "aboliși": "aboli",
    "abolit": "aboli",
    "aboliți": "aboli",
    "abolitu": "aboli",
    "neabolind": "aboli",
    "neabolindu": "aboli",
    "nemaiabolind": "aboli",
    "nemaiabolindu": "aboli",
    "abolirea": "abolire",
    "aboliri": "abolire",
    "abolirii": "abolire",
    "abolirile": "abolire",
    "abolita": "abolit",
    "abolită": "abolit",
    "abolite": "abolit",
    "abolitei": "abolit",
    "abolitele": "abolit",
    "abolitelor": "abolit",
    "aboliți": "abolit",
    "aboliții": "abolit",
    "aboliților": "abolit",
    "abolitul": "abolit",
    "abolitului": "abolit",
    "aboliționista": "aboliționist",
    "aboliționistă": "aboliționist",
    "aboliționiste": "aboliționist",
    "aboliționistei": "aboliționist",
    "aboliționistele": "aboliționist",
    "aboliționistelor": "aboliționist",
    "aboliționiști": "aboliționist",
    "aboliționiștii": "aboliționist",
    "aboliționiștilor": "aboliționist",
    "aboliționistul": "aboliționist",
    "aboliționistului": "aboliționist",
    "abominabila": "abominabil",
    "abominabilă": "abominabil",
    "abominabile": "abominabil",
    "abominabilei": "abominabil",
    "abominabilele": "abominabil",
    "abominabilelor": "abominabil",
    "abominabili": "abominabil",
    "abominabilii": "abominabil",
    "abominabililor": "abominabil",
    "abominabilul": "abominabil",
    "abominabilului": "abominabil",
    "abonă": "abona",
    "abonai": "abona",
    "abonam": "abona",
    "abonăm": "abona",
    "abonând": "abona",
    "abonându": "abona",
    "abonară": "abona",
    "abonarăm": "abona",
    "abonarăți": "abona",
    "abonase": "abona",
    "abonasem": "abona",
    "abonaseră": "abona",
    "abonaserăm": "abona",
    "abonaserăți": "abona",
    "abonaseși": "abona",
    "abonași": "abona",
    "abonat": "abona",
    "abonați": "abona",
    "abonatu": "abona",
    "abonau": "abona",
    "abonează": "abona",
    "abonez": "abona",
    "aboneze": "abona",
    "abonezi": "abona",
    "neabonând": "abona",
    "neabonându": "abona",
    "nemaiabonând": "abona",
    "nemaiabonându": "abona",
    "abonamente": "abonament",
    "abonamentele": "abonament",
    "abonamentelor": "abonament",
    "abonamentul": "abonament",
    "abonamentului": "abonament",
    "abonarea": "abonare",
    "abonări": "abonare",
    "abonării": "abonare",
    "abonările": "abonare",
    "abonata": "abonat",
    "abonată": "abonat",
    "abonate": "abonat",
    "abonatei": "abonat",
    "abonatele": "abonat",
    "abonatelor": "abonat",
    "abonați": "abonat",
    "abonații": "abonat",
    "abonaților": "abonat",
    "abonatul": "abonat",
    "abonatului": "abonat",
    "abonata": "abonată",
    "abonate": "abonată",
    "abonatei": "abonată",
    "abonatele": "abonată",
    "abonatelor": "abonată",
    "abordă": "aborda",
    "abordai": "aborda",
    "abordam": "aborda",
    "abordăm": "aborda",
    "abordând": "aborda",
    "abordându": "aborda",
    "abordară": "aborda",
    "abordarăm": "aborda",
    "abordarăți": "aborda",
    "abordase": "aborda",
    "abordasem": "aborda",
    "abordaseră": "aborda",
    "abordaserăm": "aborda",
    "abordaserăți": "aborda",
    "abordaseși": "aborda",
    "abordași": "aborda",
    "abordat": "aborda",
    "abordați": "aborda",
    "abordatu": "aborda",
    "abordau": "aborda",
    "abordează": "aborda",
    "abordez": "aborda",
    "abordeze": "aborda",
    "abordezi": "aborda",
    "neabordând": "aborda",
    "neabordându": "aborda",
    "nemaiabordând": "aborda",
    "nemaiabordându": "aborda",
    "abordabila": "abordabil",
    "abordabilă": "abordabil",
    "abordabile": "abordabil",
    "abordabilei": "abordabil",
    "abordabilele": "abordabil",
    "abordabilelor": "abordabil",
    "abordabili": "abordabil",
    "abordabilii": "abordabil",
    "abordabililor": "abordabil",
    "abordabilul": "abordabil",
    "abordabilului": "abordabil",
    "abordarea": "abordare",
    "abordări": "abordare",
    "abordării": "abordare",
    "abordările": "abordare",
    "abordata": "abordat",
    "abordată": "abordat",
    "abordate": "abordat",
    "abordatei": "abordat",
    "abordatele": "abordat",
    "abordatelor": "abordat",
    "abordați": "abordat",
    "abordații": "abordat",
    "abordaților": "abordat",
    "abordatul": "abordat",
    "abordatului": "abordat",
    "aborigeni": "aborigen",
    "aborigenii": "aborigen",
    "aborigenilor": "aborigen",
    "aborigenul": "aborigen",
    "aborigenului": "aborigen",
    "abortiva": "abortiv",
    "abortivă": "abortiv",
    "abortive": "abortiv",
    "abortivei": "abortiv",
    "abortivele": "abortiv",
    "abortivelor": "abortiv",
    "abortivi": "abortiv",
    "abortivii": "abortiv",
    "abortivilor": "abortiv",
    "abortivul": "abortiv",
    "abortivului": "abortiv",
    "abrașa": "abraș",
    "abrașă": "abraș",
    "abrașe": "abraș",
    "abrașei": "abraș",
    "abrașele": "abraș",
    "abrașelor": "abraș",
    "abrași": "abraș",
    "abrașii": "abraș",
    "abrașilor": "abraș",
    "abrașul": "abraș",
    "abrașului": "abraș",
    "abraziunea": "abraziune",
    "abraziuni": "abraziune",
    "abraziunii": "abraziune",
    "abraziunile": "abraziune",
    "abraziunilor": "abraziune",
    "abr.": "abraziv",
    "abraziva": "abraziv",
    "abrazivă": "abraziv",
    "abrazive": "abraziv",
    "abrazivei": "abraziv",
    "abrazivele": "abraziv",
    "abrazivelor": "abraziv",
    "abrazivi": "abraziv",
    "abrazivii": "abraziv",
    "abrazivilor": "abraziv",
    "abrazivul": "abraziv",
    "abrazivului": "abraziv",
    "abreviai": "abrevia",
    "abreviam": "abrevia",
    "abreviară": "abrevia",
    "abreviarăm": "abrevia",
    "abreviarăți": "abrevia",
    "abreviase": "abrevia",
    "abreviasem": "abrevia",
    "abreviaseră": "abrevia",
    "abreviaserăm": "abrevia",
    "abreviaserăți": "abrevia",
    "abreviaseși": "abrevia",
    "abreviași": "abrevia",
    "abreviat": "abrevia",
    "abreviați": "abrevia",
    "abreviatu": "abrevia",
    "abreviau": "abrevia",
    "abreviază": "abrevia",
    "abrevie": "abrevia",
    "abreviem": "abrevia",
    "abreviez": "abrevia",
    "abrevieze": "abrevia",
    "abreviezi": "abrevia",
    "abreviind": "abrevia",
    "abreviindu": "abrevia",
    "neabreviind": "abrevia",
    "neabreviindu": "abrevia",
    "nemaiabreviind": "abrevia",
    "nemaiabreviindu": "abrevia",
    "abreviabilă": "abreviabil",
    "abreviabile": "abreviabil",
    "abreviabili": "abreviabil",
    "abreviata": "abreviat",
    "abreviată": "abreviat",
    "abreviate": "abreviat",
    "abreviatei": "abreviat",
    "abreviatele": "abreviat",
    "abreviatelor": "abreviat",
    "abreviați": "abreviat",
    "abreviații": "abreviat",
    "abreviaților": "abreviat",
    "abreviatul": "abreviat",
    "abreviatului": "abreviat",
    "abreviativa": "abreviativ",
    "abreviativă": "abreviativ",
    "abreviative": "abreviativ",
    "abreviativei": "abreviativ",
    "abreviativele": "abreviativ",
    "abreviativelor": "abreviativ",
    "abreviativi": "abreviativ",
    "abreviativii": "abreviativ",
    "abreviativilor": "abreviativ",
    "abreviativul": "abreviativ",
    "abreviativului": "abreviativ",
    "abr.": "abreviere",
    "abrevierea": "abreviere",
    "abrevieri": "abreviere",
    "abrevierii": "abreviere",
    "abrevierile": "abreviere",
    "abrog": "abroga",
    "abrogă": "abroga",
    "abrogai": "abroga",
    "abrogam": "abroga",
    "abrogăm": "abroga",
    "abrogând": "abroga",
    "abrogându": "abroga",
    "abrogară": "abroga",
    "abrogarăm": "abroga",
    "abrogarăți": "abroga",
    "abrogase": "abroga",
    "abrogasem": "abroga",
    "abrogaseră": "abroga",
    "abrogaserăm": "abroga",
    "abrogaserăți": "abroga",
    "abrogaseși": "abroga",
    "abrogași": "abroga",
    "abrogat": "abroga",
    "abrogați": "abroga",
    "abrogatu": "abroga",
    "abrogau": "abroga",
    "abroge": "abroga",
    "abrogi": "abroga",
    "neabrogând": "abroga",
    "neabrogându": "abroga",
    "nemaiabrogând": "abroga",
    "nemaiabrogându": "abroga",
    "abrogarea": "abrogare",
    "abrogări": "abrogare",
    "abrogării": "abrogare",
    "abrogările": "abrogare",
    "abrogata": "abrogat",
    "abrogată": "abrogat",
    "abrogate": "abrogat",
    "abrogatei": "abrogat",
    "abrogatele": "abrogat",
    "abrogatelor": "abrogat",
    "abrogați": "abrogat",
    "abrogații": "abrogat",
    "abrogaților": "abrogat",
    "abrogatul": "abrogat",
    "abrogatului": "abrogat",
    "abruc": "abruca",
    "abrucă": "abruca",
    "abrucai": "abruca",
    "abrucam": "abruca",
    "abrucăm": "abruca",
    "abrucând": "abruca",
    "abrucându": "abruca",
    "abrucară": "abruca",
    "abrucarăm": "abruca",
    "abrucarăți": "abruca",
    "abrucase": "abruca",
    "abrucasem": "abruca",
    "abrucaseră": "abruca",
    "abrucaserăm": "abruca",
    "abrucaserăți": "abruca",
    "abrucaseși": "abruca",
    "abrucași": "abruca",
    "abrucat": "abruca",
    "abrucați": "abruca",
    "abrucatu": "abruca",
    "abrucau": "abruca",
    "abruce": "abruca",
    "abruci": "abruca",
    "abrucată": "abrucat",
    "abrucate": "abrucat",
    "abrucați": "abrucat",
    "abrupta": "abrupt",
    "abruptă": "abrupt",
    "abrupte": "abrupt",
    "abruptei": "abrupt",
    "abruptele": "abrupt",
    "abruptelor": "abrupt",
    "abrupți": "abrupt",
    "abrupții": "abrupt",
    "abrupților": "abrupt",
    "abrupto": "abrupt",
    "abruptul": "abrupt",
    "abruptului": "abrupt",
    "abrutiză": "abrutiza",
    "abrutizai": "abrutiza",
    "abrutizam": "abrutiza",
    "abrutizăm": "abrutiza",
    "abrutizând": "abrutiza",
    "abrutizându": "abrutiza",
    "abrutizară": "abrutiza",
    "abrutizarăm": "abrutiza",
    "abrutizarăți": "abrutiza",
    "abrutizase": "abrutiza",
    "abrutizasem": "abrutiza",
    "abrutizaseră": "abrutiza",
    "abrutizaserăm": "abrutiza",
    "abrutizaserăți": "abrutiza",
    "abrutizaseși": "abrutiza",
    "abrutizași": "abrutiza",
    "abrutizat": "abrutiza",
    "abrutizați": "abrutiza",
    "abrutizatu": "abrutiza",
    "abrutizau": "abrutiza",
    "abrutizează": "abrutiza",
    "abrutizez": "abrutiza",
    "abrutizeze": "abrutiza",
    "abrutizezi": "abrutiza",
    "neabrutizând": "abrutiza",
    "neabrutizându": "abrutiza",
    "nemaiabrutizând": "abrutiza",
    "nemaiabrutizându": "abrutiza",
    "abrutizanta": "abrutizant",
    "abrutizantă": "abrutizant",
    "abrutizante": "abrutizant",
    "abrutizantei": "abrutizant",
    "abrutizantele": "abrutizant",
    "abrutizantelor": "abrutizant",
    "abrutizanți": "abrutizant",
    "abrutizanții": "abrutizant",
    "abrutizanților": "abrutizant",
    "abrutizantul": "abrutizant",
    "abrutizantului": "abrutizant",
    "abrutizarea": "abrutizare",
    "abrutizări": "abrutizare",
    "abrutizării": "abrutizare",
    "abrutizările": "abrutizare",
    "abrutizata": "abrutizat",
    "abrutizată": "abrutizat",
    "abrutizate": "abrutizat",
    "abrutizatei": "abrutizat",
    "abrutizatele": "abrutizat",
    "abrutizatelor": "abrutizat",
    "abrutizați": "abrutizat",
    "abrutizații": "abrutizat",
    "abrutizaților": "abrutizat",
    "abrutizatul": "abrutizat",
    "abrutizatului": "abrutizat",
    "abrutizata": "abrutizată",
    "abrutizate": "abrutizată",
    "abrutizatei": "abrutizată",
    "abrutizatele": "abrutizată",
    "abrutizatelor": "abrutizată",
    "absconsa": "abscons",
    "absconsă": "abscons",
    "absconse": "abscons",
    "absconsei": "abscons",
    "absconsele": "abscons",
    "absconselor": "abscons",
    "absconși": "abscons",
    "absconșii": "abscons",
    "absconșilor": "abscons",
    "absconsul": "abscons",
    "absconsului": "abscons",
    "absenta": "absent",
    "absentă": "absent",
    "absente": "absent",
    "absentei": "absent",
    "absentele": "absent",
    "absentelor": "absent",
    "absenți": "absent",
    "absenții": "absent",
    "absenților": "absent",
    "absentul": "absent",
    "absentului": "absent",
    "absentă": "absenta",
    "absentai": "absenta",
    "absentam": "absenta",
    "absentăm": "absenta",
    "absentând": "absenta",
    "absentându": "absenta",
    "absentară": "absenta",
    "absentarăm": "absenta",
    "absentarăți": "absenta",
    "absentase": "absenta",
    "absentasem": "absenta",
    "absentaseră": "absenta",
    "absentaserăm": "absenta",
    "absentaserăți": "absenta",
    "absentaseși": "absenta",
    "absentași": "absenta",
    "absentat": "absenta",
    "absentați": "absenta",
    "absentatu": "absenta",
    "absentau": "absenta",
    "absentează": "absenta",
    "absentez": "absenta",
    "absenteze": "absenta",
    "absentezi": "absenta",
    "absența": "absență",
    "absențe": "absență",
    "absenței": "absență",
    "absențele": "absență",
    "absențelor": "absență",
    "absentarea": "absentare",
    "absentări": "absentare",
    "absentării": "absentare",
    "absentările": "absentare",
    "absentărilor": "absentare",
    "absentata": "absentat",
    "absentată": "absentat",
    "absentate": "absentat",
    "absentatei": "absentat",
    "absentatele": "absentat",
    "absentatelor": "absentat",
    "absentați": "absentat",
    "absentații": "absentat",
    "absentaților": "absentat",
    "absentatul": "absentat",
    "absentatului": "absentat",
    "absidiala": "absidial",
    "absidială": "absidial",
    "absidiale": "absidial",
    "absidialele": "absidial",
    "absidialelor": "absidial",
    "absidiali": "absidial",
    "absidialii": "absidial",
    "absidialilor": "absidial",
    "absidialul": "absidial",
    "absidialului": "absidial",
    "absoluta": "absolut",
    "absolută": "absolut",
    "absolute": "absolut",
    "absolutei": "absolut",
    "absolutele": "absolut",
    "absolutelor": "absolut",
    "absoluți": "absolut",
    "absoluții": "absolut",
    "absoluților": "absolut",
    "absolutul": "absolut",
    "absolutului": "absolut",
    "absolutisme": "absolutism",
    "absolutismele": "absolutism",
    "absolutismelor": "absolutism",
    "absolutismul": "absolutism",
    "absolutismului": "absolutism",
    "absolutista": "absolutist",
    "absolutistă": "absolutist",
    "absolutiste": "absolutist",
    "absolutistei": "absolutist",
    "absolutistele": "absolutist",
    "absolutistelor": "absolutist",
    "absolutiști": "absolutist",
    "absolutiștii": "absolutist",
    "absolutiștilor": "absolutist",
    "absolutistul": "absolutist",
    "absolutistului": "absolutist",
    "absolutiză": "absolutiza",
    "absolutizai": "absolutiza",
    "absolutizam": "absolutiza",
    "absolutizăm": "absolutiza",
    "absolutizând": "absolutiza",
    "absolutizându": "absolutiza",
    "absolutizară": "absolutiza",
    "absolutizarăm": "absolutiza",
    "absolutizarăți": "absolutiza",
    "absolutizase": "absolutiza",
    "absolutizasem": "absolutiza",
    "absolutizaseră": "absolutiza",
    "absolutizaserăm": "absolutiza",
    "absolutizaserăți": "absolutiza",
    "absolutizaseși": "absolutiza",
    "absolutizași": "absolutiza",
    "absolutizat": "absolutiza",
    "absolutizați": "absolutiza",
    "absolutizatu": "absolutiza",
    "absolutizau": "absolutiza",
    "absolutizează": "absolutiza",
    "absolutizez": "absolutiza",
    "absolutizeze": "absolutiza",
    "absolutizezi": "absolutiza",
    "neabsolutizând": "absolutiza",
    "neabsolutizându": "absolutiza",
    "nemaiabsolutizând": "absolutiza",
    "nemaiabsolutizându": "absolutiza",
    "absolutizarea": "absolutizare",
    "absolutizări": "absolutizare",
    "absolutizării": "absolutizare",
    "absolutizările": "absolutizare",
    "absolutizata": "absolutizat",
    "absolutizată": "absolutizat",
    "absolutizate": "absolutizat",
    "absolutizatei": "absolutizat",
    "absolutizatele": "absolutizat",
    "absolutizatelor": "absolutizat",
    "absolutizați": "absolutizat",
    "absolutizații": "absolutizat",
    "absolutizaților": "absolutizat",
    "absolutizatul": "absolutizat",
    "absolutizatului": "absolutizat",
    "absolvenți": "absolvent",
    "absolvenții": "absolvent",
    "absolvenților": "absolvent",
    "absolventul": "absolvent",
    "absolventului": "absolvent",
    "absolventa": "absolventă",
    "absolvente": "absolventă",
    "absolventei": "absolventă",
    "absolventele": "absolventă",
    "absolventelor": "absolventă",
    "absolv": "absolvi",
    "absolvă": "absolvi",
    "absolve": "absolvi",
    "absolvea": "absolvi",
    "absolveai": "absolvi",
    "absolveam": "absolvi",
    "absolveați": "absolvi",
    "absolveau": "absolvi",
    "absolvii": "absolvi",
    "absolvim": "absolvi",
    "absolvind": "absolvi",
    "absolvindu": "absolvi",
    "absolviră": "absolvi",
    "absolvirăm": "absolvi",
    "absolvirăți": "absolvi",
    "absolvise": "absolvi",
    "absolvisem": "absolvi",
    "absolviseră": "absolvi",
    "absolviserăm": "absolvi",
    "absolviserăți": "absolvi",
    "absolviseși": "absolvi",
    "absolviși": "absolvi",
    "absolvit": "absolvi",
    "absolviți": "absolvi",
    "absolvitu": "absolvi",
    "neabsolvind": "absolvi",
    "neabsolvindu": "absolvi",
    "nemaiabsolvind": "absolvi",
    "nemaiabsolvindu": "absolvi",
    "absolvirea": "absolvire",
    "absolviri": "absolvire",
    "absolvirii": "absolvire",
    "absolvirile": "absolvire",
    "absolvita": "absolvit",
    "absolvită": "absolvit",
    "absolvite": "absolvit",
    "absolvitei": "absolvit",
    "absolvitele": "absolvit",
    "absolvitelor": "absolvit",
    "absolviți": "absolvit",
    "absolviții": "absolvit",
    "absolviților": "absolvit",
    "absolvitul": "absolvit",
    "absolvitului": "absolvit",
    "absorbanta": "absorbant",
    "absorbantă": "absorbant",
    "absorbante": "absorbant",
    "absorbantei": "absorbant",
    "absorbantele": "absorbant",
    "absorbantelor": "absorbant",
    "absorbanți": "absorbant",
    "absorbanții": "absorbant",
    "absorbanților": "absorbant",
    "absorbantul": "absorbant",
    "absorbantului": "absorbant",
    "absoarbă": "absorbi",
    "absoarbe": "absorbi",
    "absorb": "absorbi",
    "absorbea": "absorbi",
    "absorbeai": "absorbi",
    "absorbeam": "absorbi",
    "absorbeați": "absorbi",
    "absorbeau": "absorbi",
    "absorbii": "absorbi",
    "absorbim": "absorbi",
    "absorbind": "absorbi",
    "absorbindu": "absorbi",
    "absorbiră": "absorbi",
    "absorbirăm": "absorbi",
    "absorbirăți": "absorbi",
    "absorbise": "absorbi",
    "absorbisem": "absorbi",
    "absorbiseră": "absorbi",
    "absorbiserăm": "absorbi",
    "absorbiserăți": "absorbi",
    "absorbiseși": "absorbi",
    "absorbiși": "absorbi",
    "absorbit": "absorbi",
    "absorbiți": "absorbi",
    "absorbitu": "absorbi",
    "neabsorbind": "absorbi",
    "neabsorbindu": "absorbi",
    "nemaiabsorbind": "absorbi",
    "nemaiabsorbindu": "absorbi",
    "absorbirea": "absorbire",
    "absorbiri": "absorbire",
    "absorbirii": "absorbire",
    "absorbirile": "absorbire",
    "absorbita": "absorbit",
    "absorbită": "absorbit",
    "absorbite": "absorbit",
    "absorbitei": "absorbit",
    "absorbitele": "absorbit",
    "absorbitelor": "absorbit",
    "absorbiți": "absorbit",
    "absorbiții": "absorbit",
    "absorbiților": "absorbit",
    "absorbitul": "absorbit",
    "absorbitului": "absorbit",
    "absorbitoare": "absorbitor",
    "absorbitoarea": "absorbitor",
    "absorbitoarei": "absorbitor",
    "absorbitoarele": "absorbitor",
    "absorbitoarelor": "absorbitor",
    "absorbitori": "absorbitor",
    "absorbitorii": "absorbitor",
    "absorbitorilor": "absorbitor",
    "absorbitorul": "absorbitor",
    "absorbitorului": "absorbitor",
    "absorbția": "absorbție",
    "absorbției": "absorbție",
    "absorbții": "absorbție",
    "absorbțiile": "absorbție",
    "absorbțiilor": "absorbție",
    "abstinenta": "abstinent",
    "abstinentă": "abstinent",
    "abstinente": "abstinent",
    "abstinentei": "abstinent",
    "abstinentele": "abstinent",
    "abstinentelor": "abstinent",
    "abstinenți": "abstinent",
    "abstinenții": "abstinent",
    "abstinenților": "abstinent",
    "abstinentul": "abstinent",
    "abstinentului": "abstinent",
    "abstinenta": "abstinentă",
    "abstinente": "abstinentă",
    "abstinentei": "abstinentă",
    "abstinentele": "abstinentă",
    "abstinentelor": "abstinentă",
    "abstinența": "abstinență",
    "abstinențe": "abstinență",
    "abstinenței": "abstinență",
    "abstinențele": "abstinență",
    "abstinențelor": "abstinență",
    "abstracta": "abstract",
    "abstractă": "abstract",
    "abstracte": "abstract",
    "abstractei": "abstract",
    "abstractele": "abstract",
    "abstractelor": "abstract",
    "abstracți": "abstract",
    "abstracții": "abstract",
    "abstracților": "abstract",
    "abstractul": "abstract",
    "abstractului": "abstract",
    "abstracția": "abstracție",
    "abstracției": "abstracție",
    "abstracții": "abstracție",
    "abstracțiile": "abstracție",
    "abstracțiilor": "abstracție",
    "abstracționista": "abstracționist",
    "abstracționistă": "abstracționist",
    "abstracționiste": "abstracționist",
    "abstracționistei": "abstracționist",
    "abstracționistele": "abstracționist",
    "abstracționistelor": "abstracționist",
    "abstracționiști": "abstracționist",
    "abstracționiștii": "abstracționist",
    "abstracționiștilor": "abstracționist",
    "abstracționistul": "abstracționist",
    "abstracționistului": "abstracționist",
    "abstracționista": "abstracționistă",
    "abstracționiste": "abstracționistă",
    "abstracționistei": "abstracționistă",
    "abstracționistele": "abstracționistă",
    "abstracționistelor": "abstracționistă",
    "abstractiză": "abstractiza",
    "abstractizai": "abstractiza",
    "abstractizam": "abstractiza",
    "abstractizăm": "abstractiza",
    "abstractizând": "abstractiza",
    "abstractizându": "abstractiza",
    "abstractizară": "abstractiza",
    "abstractizarăm": "abstractiza",
    "abstractizarăți": "abstractiza",
    "abstractizase": "abstractiza",
    "abstractizasem": "abstractiza",
    "abstractizaseră": "abstractiza",
    "abstractizaserăm": "abstractiza",
    "abstractizaserăți": "abstractiza",
    "abstractizaseși": "abstractiza",
    "abstractizași": "abstractiza",
    "abstractizat": "abstractiza",
    "abstractizați": "abstractiza",
    "abstractizatu": "abstractiza",
    "abstractizau": "abstractiza",
    "abstractizează": "abstractiza",
    "abstractizez": "abstractiza",
    "abstractizeze": "abstractiza",
    "abstractizezi": "abstractiza",
    "neabstractizând": "abstractiza",
    "neabstractizându": "abstractiza",
    "nemaiabstractizând": "abstractiza",
    "nemaiabstractizându": "abstractiza",
    "abstractizarea": "abstractizare",
    "abstractizări": "abstractizare",
    "abstractizării": "abstractizare",
    "abstractizările": "abstractizare",
    "abstractizata": "abstractizat",
    "abstractizată": "abstractizat",
    "abstractizate": "abstractizat",
    "abstractizatei": "abstractizat",
    "abstractizatele": "abstractizat",
    "abstractizatelor": "abstractizat",
    "abstractizați": "abstractizat",
    "abstractizații": "abstractizat",
    "abstractizaților": "abstractizat",
    "abstractizatul": "abstractizat",
    "abstractizatului": "abstractizat",
    "abstrag": "abstrage",
    "abstragă": "abstrage",
    "abstrăgând": "abstrage",
    "abstrăgându": "abstrage",
    "abstrăgea": "abstrage",
    "abstrăgeai": "abstrage",
    "abstrăgeam": "abstrage",
    "abstrăgeați": "abstrage",
    "abstrăgeau": "abstrage",
    "abstragem": "abstrage",
    "abstrageți": "abstrage",
    "abstragi": "abstrage",
    "abstras": "abstrage",
    "abstrase": "abstrage",
    "abstrăsei": "abstrage",
    "abstraseră": "abstrage",
    "abstraserăm": "abstrage",
    "abstraserăți": "abstrage",
    "abstrăsese": "abstrage",
    "abstrăsesem": "abstrage",
    "abstrăseseră": "abstrage",
    "abstrăseserăm": "abstrage",
    "abstrăseserăți": "abstrage",
    "abstrăseseși": "abstrage",
    "abstrăseși": "abstrage",
    "abstrasu": "abstrage",
    "neabstrăgând": "abstrage",
    "neabstrăgându": "abstrage",
    "nemaiabstrăgând": "abstrage",
    "nemaiabstrăgându": "abstrage",
    "abstragerea": "abstragere",
    "abstrageri": "abstragere",
    "abstragerii": "abstragere",
    "abstragerile": "abstragere",
    "abstrasa": "abstras",
    "abstrasă": "abstras",
    "abstrase": "abstras",
    "abstrasei": "abstras",
    "abstrasele": "abstras",
    "abstraselor": "abstras",
    "abstrași": "abstras",
    "abstrașii": "abstras",
    "abstrașilor": "abstras",
    "abstrasul": "abstras",
    "abstrasului": "abstras",
    "absurda": "absurd",
    "absurdă": "absurd",
    "absurde": "absurd",
    "absurdei": "absurd",
    "absurdele": "absurd",
    "absurdelor": "absurd",
    "absurdul": "absurd",
    "absurdului": "absurd",
    "absurzi": "absurd",
    "absurzii": "absurd",
    "absurzilor": "absurd",
    "absurditatea": "absurditate",
    "absurdități": "absurditate",
    "absurdității": "absurditate",
    "absurditățile": "absurditate",
    "absurdităților": "absurditate",
    "abții": "abține",
    "abțin": "abține",
    "abțină": "abține",
    "abținând": "abține",
    "abținându": "abține",
    "abținea": "abține",
    "abțineai": "abține",
    "abțineam": "abține",
    "abțineați": "abține",
    "abțineau": "abține",
    "abținem": "abține",
    "abțineți": "abține",
    "abținu": "abține",
    "abținui": "abține",
    "abținură": "abține",
    "abținurăm": "abține",
    "abținurăți": "abține",
    "abținuse": "abține",
    "abținusem": "abține",
    "abținuseră": "abține",
    "abținuserăm": "abține",
    "abținuserăți": "abține",
    "abținuseși": "abține",
    "abținuși": "abține",
    "abținut": "abține",
    "abținutu": "abține",
    "neabținând": "abține",
    "neabținându": "abține",
    "nemaiabținând": "abține",
    "nemaiabținându": "abține",
    "abținerea": "abținere",
    "abțineri": "abținere",
    "abținerii": "abținere",
    "abținerile": "abținere",
    "abținuta": "abținut",
    "abținută": "abținut",
    "abținute": "abținut",
    "abținutei": "abținut",
    "abținutele": "abținut",
    "abținutelor": "abținut",
    "abținuți": "abținut",
    "abținuții": "abținut",
    "abținuților": "abținut",
    "abținutul": "abținut",
    "abținutului": "abținut",
    "abulica": "abulic",
    "abulică": "abulic",
    "abulice": "abulic",
    "abulicei": "abulic",
    "abulicele": "abulic",
    "abulicelor": "abulic",
    "abulici": "abulic",
    "abulicii": "abulic",
    "abulicilor": "abulic",
    "abulicul": "abulic",
    "abulicului": "abulic",
    "abund": "abunda",
    "abundă": "abunda",
    "abundai": "abunda",
    "abundam": "abunda",
    "abundăm": "abunda",
    "abundând": "abunda",
    "abundându": "abunda",
    "abundară": "abunda",
    "abundarăm": "abunda",
    "abundarăți": "abunda",
    "abundase": "abunda",
    "abundasem": "abunda",
    "abundaseră": "abunda",
    "abundaserăm": "abunda",
    "abundaserăți": "abunda",
    "abundaseși": "abunda",
    "abundași": "abunda",
    "abundat": "abunda",
    "abundați": "abunda",
    "abundatu": "abunda",
    "abundau": "abunda",
    "abunde": "abunda",
    "abunzi": "abunda",
    "neabundând": "abunda",
    "neabundându": "abunda",
    "nemaiabundând": "abunda",
    "nemaiabundându": "abunda",
    "abundată": "abundat",
    "abundate": "abundat",
    "abundați": "abundat",
    "abundenta": "abundent",
    "abundentă": "abundent",
    "abundente": "abundent",
    "abundentei": "abundent",
    "abundentele": "abundent",
    "abundentelor": "abundent",
    "abundenți": "abundent",
    "abundenții": "abundent",
    "abundenților": "abundent",
    "abundentul": "abundent",
    "abundentului": "abundent",
    "abundența": "abundență",
    "abundențe": "abundență",
    "abundenței": "abundență",
    "abundențele": "abundență",
    "aburi": "abur",
    "aburii": "abur",
    "aburilor": "abur",
    "aburul": "abur",
    "aburului": "abur",
    "aburcata": "aburcat",
    "aburcată": "aburcat",
    "aburcate": "aburcat",
    "aburcatei": "aburcat",
    "aburcatele": "aburcat",
    "aburcatelor": "aburcat",
    "aburcați": "aburcat",
    "aburcații": "aburcat",
    "aburcaților": "aburcat",
    "aburcatul": "aburcat",
    "aburcatului": "aburcat",
    "aburea": "aburi",
    "abureai": "aburi",
    "abuream": "aburi",
    "aburească": "aburi",
    "abureați": "aburi",
    "abureau": "aburi",
    "aburesc": "aburi",
    "aburește": "aburi",
    "aburești": "aburi",
    "aburii": "aburi",
    "aburim": "aburi",
    "aburind": "aburi",
    "aburindu": "aburi",
    "aburiră": "aburi",
    "aburirăm": "aburi",
    "aburirăți": "aburi",
    "aburise": "aburi",
    "aburisem": "aburi",
    "aburiseră": "aburi",
    "aburiserăm": "aburi",
    "aburiserăți": "aburi",
    "aburiseși": "aburi",
    "aburiși": "aburi",
    "aburit": "aburi",
    "aburiți": "aburi",
    "aburitu": "aburi",
    "aburinda": "aburind",
    "aburindă": "aburind",
    "aburinde": "aburind",
    "aburindei": "aburind",
    "aburindele": "aburind",
    "aburindelor": "aburind",
    "aburindul": "aburind",
    "aburindului": "aburind",
    "aburinzi": "aburind",
    "aburinzii": "aburind",
    "aburinzilor": "aburind",
    "aburită": "aburit",
    "aburite": "aburit",
    "aburiți": "aburit",
    "abuzul": "abuz",
    "abuzului": "abuz",
    "abuzuri": "abuz",
    "abuzurile": "abuz",
    "abuzurilor": "abuz",
    "abuză": "abuza",
    "abuzai": "abuza",
    "abuzam": "abuza",
    "abuzăm": "abuza",
    "abuzând": "abuza",
    "abuzându": "abuza",
    "abuzară": "abuza",
    "abuzarăm": "abuza",
    "abuzarăți": "abuza",
    "abuzase": "abuza",
    "abuzasem": "abuza",
    "abuzaseră": "abuza",
    "abuzaserăm": "abuza",
    "abuzaserăți": "abuza",
    "abuzaseși": "abuza",
    "abuzași": "abuza",
    "abuzat": "abuza",
    "abuzați": "abuza",
    "abuzatu": "abuza",
    "abuzau": "abuza",
    "abuzează": "abuza",
    "abuzez": "abuza",
    "abuzeze": "abuza",
    "abuzezi": "abuza",
    "neabuzând": "abuza",
    "neabuzându": "abuza",
    "nemaiabuzând": "abuza",
    "nemaiabuzându": "abuza",
    "abuzarea": "abuzare",
    "abuzări": "abuzare",
    "abuzării": "abuzare",
    "abuzările": "abuzare",
    "abuzată": "abuzat",
    "abuzate": "abuzat",
    "abuzați": "abuzat",
    "abuziva": "abuziv",
    "abuzivă": "abuziv",
    "abuzive": "abuziv",
    "abuzivei": "abuziv",
    "abuzivele": "abuziv",
    "abuzivelor": "abuziv",
    "abuzivi": "abuziv",
    "abuzivii": "abuziv",
    "abuzivilor": "abuziv",
    "abuzivul": "abuziv",
    "abuzivului": "abuziv",
    "ace": "ac",
    "acele": "ac",
    "acelor": "ac",
    "acul": "ac",
    "acului": "ac",
    "acadeaua": "acadea",
    "acadele": "acadea",
    "acadelei": "acadea",
    "acadelele": "acadea",
    "acadelelor": "acadea",
    "Academiei_Române": "Academia_Română",
    "academica": "academic",
    "academică": "academic",
    "academice": "academic",
    "academicei": "academic",
    "academicele": "academic",
    "academicelor": "academic",
    "academici": "academic",
    "academicii": "academic",
    "academicilor": "academic",
    "academicul": "academic",
    "academicului": "academic",
    "acad.": "academician",
    "academicianul": "academician",
    "academicianului": "academician",
    "academicieni": "academician",
    "academicienii": "academician",
    "academicienilor": "academician",
    "academiciana": "academiciană",
    "academiciene": "academiciană",
    "academicienei": "academiciană",
    "academicienele": "academiciană",
    "academicienelor": "academiciană",
    "academia": "academie",
    "academiei": "academie",
    "academii": "academie",
    "academiile": "academie",
    "academiilor": "academie",
    "acalmia": "acalmie",
    "acalmiei": "acalmie",
    "acalmii": "acalmie",
    "acalmiile": "acalmie",
    "acalmiilor": "acalmie",
    "acapară": "acapara",
    "acaparai": "acapara",
    "acaparam": "acapara",
    "acaparăm": "acapara",
    "acaparând": "acapara",
    "acaparându": "acapara",
    "acaparară": "acapara",
    "acapararăm": "acapara",
    "acapararăți": "acapara",
    "acaparase": "acapara",
    "acaparasem": "acapara",
    "acaparaseră": "acapara",
    "acaparaserăm": "acapara",
    "acaparaserăți": "acapara",
    "acaparaseși": "acapara",
    "acaparași": "acapara",
    "acaparat": "acapara",
    "acaparați": "acapara",
    "acaparatu": "acapara",
    "acaparau": "acapara",
    "acaparează": "acapara",
    "acaparez": "acapara",
    "acapareze": "acapara",
    "acaparezi": "acapara",
    "neacaparând": "acapara",
    "neacaparându": "acapara",
    "nemaiacaparând": "acapara",
    "nemaiacaparându": "acapara",
    "acapararea": "acaparare",
    "acaparări": "acaparare",
    "acaparării": "acaparare",
    "acaparările": "acaparare",
    "acaparata": "acaparat",
    "acaparată": "acaparat",
    "acaparate": "acaparat",
    "acaparatei": "acaparat",
    "acaparatele": "acaparat",
    "acaparatelor": "acaparat",
    "acaparați": "acaparat",
    "acaparații": "acaparat",
    "acaparaților": "acaparat",
    "acaparatul": "acaparat",
    "acaparatului": "acaparat",
    "acaparatoarea": "acaparatoare",
    "acaparatoarei": "acaparatoare",
    "acaparatoarele": "acaparatoare",
    "acaparatoarelor": "acaparatoare",
    "acaparatoare": "acaparator",
    "acaparatoarea": "acaparator",
    "acaparatoarei": "acaparator",
    "acaparatoarele": "acaparator",
    "acaparatoarelor": "acaparator",
    "acaparatori": "acaparator",
    "acaparatorii": "acaparator",
    "acaparatorilor": "acaparator",
    "acaparatorul": "acaparator",
    "acaparatorului": "acaparator",
    "acari": "acar",
    "acarii": "acar",
    "acarilor": "acar",
    "acarul": "acar",
    "acarului": "acar",
    "acaretul": "acaret",
    "acaretului": "acaret",
    "acareturi": "acaret",
    "acareturile": "acaret",
    "acareturilor": "acaret",
    "acas'": "acasă",
    "acatiste": "acatist",
    "acatistele": "acatist",
    "acatistelor": "acatist",
    "acatistul": "acatist",
    "acatistului": "acatist",
    "neaccedând": "acceda",
    "neaccedându": "acceda",
    "nemaiaccedând": "acceda",
    "nemaiaccedându": "acceda",
    "accedată": "accedat",
    "accedate": "accedat",
    "accedați": "accedat",
    "acceadă": "accede",
    "acced": "accede",
    "accedă": "accede",
    "accedai": "accede",
    "accedând": "accede",
    "accedându": "accede",
    "accedară": "accede",
    "accedarăm": "accede",
    "accedarăți": "accede",
    "accedase": "accede",
    "accedasem": "accede",
    "accedaseră": "accede",
    "accedaserăm": "accede",
    "accedaserăți": "accede",
    "accedaseși": "accede",
    "accedași": "accede",
    "accedat": "accede",
    "accedatu": "accede",
    "accedea": "accede",
    "accedeai": "accede",
    "accedeam": "accede",
    "accedeați": "accede",
    "accedeau": "accede",
    "accedem": "accede",
    "accedeți": "accede",
    "accezi": "accede",
    "acceleră": "accelera",
    "accelerai": "accelera",
    "acceleram": "accelera",
    "accelerăm": "accelera",
    "accelerând": "accelera",
    "accelerându": "accelera",
    "accelerară": "accelera",
    "accelerarăm": "accelera",
    "accelerarăți": "accelera",
    "accelerase": "accelera",
    "accelerasem": "accelera",
    "acceleraseră": "accelera",
    "acceleraserăm": "accelera",
    "acceleraserăți": "accelera",
    "acceleraseși": "accelera",
    "accelerași": "accelera",
    "accelerat": "accelera",
    "accelerați": "accelera",
    "acceleratu": "accelera",
    "accelerau": "accelera",
    "accelerează": "accelera",
    "accelerez": "accelera",
    "accelereze": "accelera",
    "accelerezi": "accelera",
    "neaccelerând": "accelera",
    "neaccelerându": "accelera",
    "nemaiaccelerând": "accelera",
    "nemaiaccelerându": "accelera",
    "accelerarea": "accelerare",
    "accelerări": "accelerare",
    "accelerării": "accelerare",
    "accelerările": "accelerare",
    "accelerata": "accelerat",
    "accelerată": "accelerat",
    "accelerate": "accelerat",
    "acceleratei": "accelerat",
    "acceleratele": "accelerat",
    "acceleratelor": "accelerat",
    "accelerați": "accelerat",
    "accelerații": "accelerat",
    "acceleraților": "accelerat",
    "acceleratul": "accelerat",
    "acceleratului": "accelerat",
    "acceleratoare": "accelerator",
    "acceleratoarea": "accelerator",
    "acceleratoarei": "accelerator",
    "acceleratoarele": "accelerator",
    "acceleratoarelor": "accelerator",
    "acceleratori": "accelerator",
    "acceleratorii": "accelerator",
    "acceleratorilor": "accelerator",
    "acceleratorul": "accelerator",
    "acceleratorului": "accelerator",
    "accente": "accent",
    "accentele": "accent",
    "accentelor": "accent",
    "accentul": "accent",
    "accentului": "accent",
    "accentuă": "accentua",
    "accentuai": "accentua",
    "accentuam": "accentua",
    "accentuăm": "accentua",
    "accentuând": "accentua",
    "accentuându": "accentua",
    "accentuară": "accentua",
    "accentuarăm": "accentua",
    "accentuarăți": "accentua",
    "accentuase": "accentua",
    "accentuasem": "accentua",
    "accentuaseră": "accentua",
    "accentuaserăm": "accentua",
    "accentuaserăți": "accentua",
    "accentuaseși": "accentua",
    "accentuași": "accentua",
    "accentuat": "accentua",
    "accentuați": "accentua",
    "accentuatu": "accentua",
    "accentuau": "accentua",
    "accentuează": "accentua",
    "accentuez": "accentua",
    "accentueze": "accentua",
    "accentuezi": "accentua",
    "neaccentuând": "accentua",
    "neaccentuându": "accentua",
    "nemaiaccentuând": "accentua",
    "nemaiaccentuându": "accentua",
    "accentuarea": "accentuare",
    "accentuări": "accentuare",
    "accentuării": "accentuare",
    "accentuările": "accentuare",
    "acc.": "accentuat",
    "accentuata": "accentuat",
    "accentuată": "accentuat",
    "accentuate": "accentuat",
    "accentuatei": "accentuat",
    "accentuatele": "accentuat",
    "accentuatelor": "accentuat",
    "accentuați": "accentuat",
    "accentuații": "accentuat",
    "accentuaților": "accentuat",
    "accentuatul": "accentuat",
    "accentuatului": "accentuat",
    "accept": "accepta",
    "acceptă": "accepta",
    "acceptai": "accepta",
    "acceptam": "accepta",
    "acceptăm": "accepta",
    "acceptând": "accepta",
    "acceptându": "accepta",
    "acceptară": "accepta",
    "acceptarăm": "accepta",
    "acceptarăți": "accepta",
    "acceptase": "accepta",
    "acceptasem": "accepta",
    "acceptaseră": "accepta",
    "acceptaserăm": "accepta",
    "acceptaserăți": "accepta",
    "acceptaseși": "accepta",
    "acceptași": "accepta",
    "acceptat": "accepta",
    "acceptați": "accepta",
    "acceptatu": "accepta",
    "acceptau": "accepta",
    "accepte": "accepta",
    "accepți": "accepta",
    "neacceptând": "accepta",
    "neacceptându": "accepta",
    "nemaiacceptând": "accepta",
    "nemaiacceptându": "accepta",
    "acceptabilă": "acceptabil",
    "acceptabile": "acceptabil",
    "acceptabili": "acceptabil",
    "acceptarea": "acceptare",
    "acceptări": "acceptare",
    "acceptării": "acceptare",
    "acceptările": "acceptare",
    "acceptata": "acceptat",
    "acceptată": "acceptat",
    "acceptate": "acceptat",
    "acceptatei": "acceptat",
    "acceptatele": "acceptat",
    "acceptatelor": "acceptat",
    "acceptați": "acceptat",
    "acceptații": "acceptat",
    "acceptaților": "acceptat",
    "acceptatul": "acceptat",
    "acceptatului": "acceptat",
    "accepția": "accepție",
    "accepției": "accepție",
    "accepții": "accepție",
    "accepțiile": "accepție",
    "accepțiilor": "accepție",
    "accepțiunea": "accepțiune",
    "accepțiuni": "accepțiune",
    "accepțiunii": "accepțiune",
    "accepțiunile": "accepțiune",
    "accepțiunilor": "accepțiune",
    "accese": "acces",
    "accesele": "acces",
    "acceselor": "acces",
    "accesul": "acces",
    "accesului": "acces",
    "accesibila": "accesibil",
    "accesibilă": "accesibil",
    "accesibile": "accesibil",
    "accesibilei": "accesibil",
    "accesibilele": "accesibil",
    "accesibilelor": "accesibil",
    "accesibili": "accesibil",
    "accesibilii": "accesibil",
    "accesibililor": "accesibil",
    "accesibilul": "accesibil",
    "accesibilului": "accesibil",
    "accesorii": "accesoriu",
    "accesoriile": "accesoriu",
    "accesoriilor": "accesoriu",
    "accesoriul": "accesoriu",
    "accesoriului": "accesoriu",
    "accidente": "accident",
    "accidentele": "accident",
    "accidentelor": "accident",
    "accidentul": "accident",
    "accidentului": "accident",
    "accidentă": "accidenta",
    "accidentai": "accidenta",
    "accidentam": "accidenta",
    "accidentăm": "accidenta",
    "accidentând": "accidenta",
    "accidentându": "accidenta",
    "accidentară": "accidenta",
    "accidentarăm": "accidenta",
    "accidentarăți": "accidenta",
    "accidentase": "accidenta",
    "accidentasem": "accidenta",
    "accidentaseră": "accidenta",
    "accidentaserăm": "accidenta",
    "accidentaserăți": "accidenta",
    "accidentaseși": "accidenta",
    "accidentași": "accidenta",
    "accidentat": "accidenta",
    "accidentați": "accidenta",
    "accidentatu": "accidenta",
    "accidentau": "accidenta",
    "accidentează": "accidenta",
    "accidentez": "accidenta",
    "accidenteze": "accidenta",
    "accidentezi": "accidenta",
    "neaccidentând": "accidenta",
    "neaccidentându": "accidenta",
    "nemaiaccidentând": "accidenta",
    "nemaiaccidentându": "accidenta",
    "accidentala": "accidental",
    "accidentală": "accidental",
    "accidentale": "accidental",
    "accidentalei": "accidental",
    "accidentalele": "accidental",
    "accidentalelor": "accidental",
    "accidentali": "accidental",
    "accidentalii": "accidental",
    "accidentalilor": "accidental",
    "accidentalul": "accidental",
    "accidentalului": "accidental",
    "accidentarea": "accidentare",
    "accidentări": "accidentare",
    "accidentării": "accidentare",
    "accidentările": "accidentare",
    "accidentata": "accidentat",
    "accidentată": "accidentat",
    "accidentate": "accidentat",
    "accidentatei": "accidentat",
    "accidentatele": "accidentat",
    "accidentatelor": "accidentat",
    "accidentați": "accidentat",
    "accidentații": "accidentat",
    "accidentaților": "accidentat",
    "accidentatul": "accidentat",
    "accidentatului": "accidentat",
    "accidentata": "accidentată",
    "accidentate": "accidentată",
    "accidentatei": "accidentată",
    "accidentatele": "accidentată",
    "accidentatelor": "accidentată",
    "acciza": "acciză",
    "accize": "acciză",
    "accizei": "acciză",
    "accizele": "acciză",
    "accizelor": "acciză",
    "ace-de-mare": "ac-de-mare",
    "acele-de-mare": "ac-de-mare",
    "acelor-de-mare": "ac-de-mare",
    "acul-de-mare": "ac-de-mare",
    "acului-de-mare": "ac-de-mare",
    "acefala": "acefal",
    "acefală": "acefal",
    "acefale": "acefal",
    "acefalei": "acefal",
    "acefalele": "acefal",
    "acefalelor": "acefal",
    "acefali": "acefal",
    "acefalii": "acefal",
    "acefalilor": "acefal",
    "acefalul": "acefal",
    "acefalului": "acefal",
    "acea": "acel",
    "acei": "acel",
    "acele": "acel",
    "acelei": "acel",
    "acelor": "acel",
    "acelui": "acel",
    "aceea": "acela",
    "aceia": "acela",
    "acelea": "acela",
    "aceleia": "acela",
    "acelora": "acela",
    "aceluia": "acela",
    "aceeași": "același",
    "aceiași": "același",
    "aceleași": "același",
    "aceleiași": "același",
    "acelorași": "același",
    "aceluiași": "același",
    "acerba": "acerb",
    "acerbă": "acerb",
    "acerbe": "acerb",
    "acerbei": "acerb",
    "acerbele": "acerb",
    "acerbelor": "acerb",
    "acerbi": "acerb",
    "acerbii": "acerb",
    "acerbilor": "acerb",
    "acerbul": "acerb",
    "acerbului": "acerb",
    "această": "acest",
    "aceste": "acest",
    "acestei": "acest",
    "acești": "acest",
    "acestor": "acest",
    "acestui": "acest",
    "aceasta": "acesta",
    "acestea": "acesta",
    "acesteia": "acesta",
    "aceștia": "acesta",
    "acestora": "acesta",
    "acestuia": "acesta",
    "acetica": "acetic",
    "acetică": "acetic",
    "acetice": "acetic",
    "aceticei": "acetic",
    "aceticele": "acetic",
    "aceticelor": "acetic",
    "acetici": "acetic",
    "aceticii": "acetic",
    "aceticilor": "acetic",
    "aceticul": "acetic",
    "aceticului": "acetic",
    "achit": "achita",
    "achită": "achita",
    "achitai": "achita",
    "achitam": "achita",
    "achităm": "achita",
    "achitând": "achita",
    "achitându": "achita",
    "achitară": "achita",
    "achitarăm": "achita",
    "achitarăți": "achita",
    "achitase": "achita",
    "achitasem": "achita",
    "achitaseră": "achita",
    "achitaserăm": "achita",
    "achitaserăți": "achita",
    "achitaseși": "achita",
    "achitași": "achita",
    "achitat": "achita",
    "achitați": "achita",
    "achitatu": "achita",
    "achitau": "achita",
    "achite": "achita",
    "achiți": "achita",
    "neachitând": "achita",
    "neachitându": "achita",
    "nemaiachitând": "achita",
    "nemaiachitându": "achita",
    "achitabilă": "achitabil",
    "achitabile": "achitabil",
    "achitabili": "achitabil",
    "achitarea": "achitare",
    "achitări": "achitare",
    "achitării": "achitare",
    "achitările": "achitare",
    "achitata": "achitat",
    "achitată": "achitat",
    "achitate": "achitat",
    "achitatei": "achitat",
    "achitatele": "achitat",
    "achitatelor": "achitat",
    "achitați": "achitat",
    "achitații": "achitat",
    "achitaților": "achitat",
    "achitatul": "achitat",
    "achitatului": "achitat",
    "achiziția": "achiziție",
    "achiziției": "achiziție",
    "achiziții": "achiziție",
    "achizițiile": "achiziție",
    "achizițiilor": "achiziție",
    "achiziționă": "achiziționa",
    "achiziționai": "achiziționa",
    "achiziționam": "achiziționa",
    "achiziționăm": "achiziționa",
    "achiziționând": "achiziționa",
    "achiziționându": "achiziționa",
    "achiziționară": "achiziționa",
    "achiziționarăm": "achiziționa",
    "achiziționarăți": "achiziționa",
    "achiziționase": "achiziționa",
    "achiziționasem": "achiziționa",
    "achiziționaseră": "achiziționa",
    "achiziționaserăm": "achiziționa",
    "achiziționaserăți": "achiziționa",
    "achiziționaseși": "achiziționa",
    "achiziționași": "achiziționa",
    "achiziționat": "achiziționa",
    "achiziționați": "achiziționa",
    "achiziționatu": "achiziționa",
    "achiziționau": "achiziționa",
    "achiziționează": "achiziționa",
    "achiziționez": "achiziționa",
    "achiziționeze": "achiziționa",
    "achiziționezi": "achiziționa",
    "neachiziționând": "achiziționa",
    "neachiziționându": "achiziționa",
    "nemaiachiziționând": "achiziționa",
    "nemaiachiziționându": "achiziționa",
    "achiziționarea": "achiziționare",
    "achiziționări": "achiziționare",
    "achiziționării": "achiziționare",
    "achiziționările": "achiziționare",
    "achiziționata": "achiziționat",
    "achiziționată": "achiziționat",
    "achiziționate": "achiziționat",
    "achiziționatei": "achiziționat",
    "achiziționatele": "achiziționat",
    "achiziționatelor": "achiziționat",
    "achiziționați": "achiziționat",
    "achiziționații": "achiziționat",
    "achiziționaților": "achiziționat",
    "achiziționatul": "achiziționat",
    "achiziționatului": "achiziționat",
    "achizitoarea": "achizitoare",
    "achizitoarei": "achizitoare",
    "achizitoarele": "achizitoare",
    "achizitoarelor": "achizitoare",
    "achizitori": "achizitor",
    "achizitorii": "achizitor",
    "achizitorilor": "achizitor",
    "achizitorul": "achizitor",
    "achizitorului": "achizitor",
    "aciclica": "aciclic",
    "aciclică": "aciclic",
    "aciclice": "aciclic",
    "aciclicei": "aciclic",
    "aciclicele": "aciclic",
    "aciclicelor": "aciclic",
    "aciclici": "aciclic",
    "aciclicii": "aciclic",
    "aciclicilor": "aciclic",
    "aciclicul": "aciclic",
    "aciclicului": "aciclic",
    "aciculara": "acicular",
    "aciculară": "acicular",
    "aciculare": "acicular",
    "acicularei": "acicular",
    "acicularele": "acicular",
    "acicularelor": "acicular",
    "aciculari": "acicular",
    "acicularii": "acicular",
    "acicularilor": "acicular",
    "acicularul": "acicular",
    "acicularului": "acicular",
    "acida": "acid",
    "acidă": "acid",
    "acide": "acid",
    "acidei": "acid",
    "acidele": "acid",
    "acidelor": "acid",
    "acidul": "acid",
    "acidului": "acid",
    "acizi": "acid",
    "acizii": "acid",
    "acizilor": "acid",
    "acidulă": "acidula",
    "acidulai": "acidula",
    "acidulam": "acidula",
    "acidulăm": "acidula",
    "acidulând": "acidula",
    "acidulându": "acidula",
    "acidulară": "acidula",
    "acidularăm": "acidula",
    "acidularăți": "acidula",
    "acidulase": "acidula",
    "acidulasem": "acidula",
    "acidulaseră": "acidula",
    "acidulaserăm": "acidula",
    "acidulaserăți": "acidula",
    "acidulaseși": "acidula",
    "acidulași": "acidula",
    "acidulat": "acidula",
    "acidulați": "acidula",
    "acidulatu": "acidula",
    "acidulau": "acidula",
    "acidulează": "acidula",
    "acidulez": "acidula",
    "aciduleze": "acidula",
    "acidulezi": "acidula",
    "neacidulând": "acidula",
    "neacidulându": "acidula",
    "nemaiacidulând": "acidula",
    "nemaiacidulându": "acidula",
    "acidularea": "acidulare",
    "acidulări": "acidulare",
    "acidulării": "acidulare",
    "acidulările": "acidulare",
    "acidulata": "acidulat",
    "acidulată": "acidulat",
    "acidulate": "acidulat",
    "acidulatei": "acidulat",
    "acidulatele": "acidulat",
    "acidulatelor": "acidulat",
    "acidulați": "acidulat",
    "acidulații": "acidulat",
    "acidulaților": "acidulat",
    "acidulatul": "acidulat",
    "acidulatului": "acidulat",
    "aciuă": "aciua",
    "aciuai": "aciua",
    "aciuam": "aciua",
    "aciuăm": "aciua",
    "aciuând": "aciua",
    "aciuându": "aciua",
    "aciuară": "aciua",
    "aciuarăm": "aciua",
    "aciuarăți": "aciua",
    "aciuase": "aciua",
    "aciuasem": "aciua",
    "aciuaseră": "aciua",
    "aciuaserăm": "aciua",
    "aciuaserăți": "aciua",
    "aciuaseși": "aciua",
    "aciuași": "aciua",
    "aciuat": "aciua",
    "aciuați": "aciua",
    "aciuatu": "aciua",
    "aciuau": "aciua",
    "aciuează": "aciua",
    "aciuez": "aciua",
    "aciueze": "aciua",
    "aciuezi": "aciua",
    "neaciuând": "aciua",
    "neaciuându": "aciua",
    "nemaiaciuând": "aciua",
    "nemaiaciuându": "aciua",
    "aciuarea": "aciuare",
    "aciuări": "aciuare",
    "aciuării": "aciuare",
    "aciuările": "aciuare",
    "aciuata": "aciuat",
    "aciuată": "aciuat",
    "aciuate": "aciuat",
    "aciuatei": "aciuat",
    "aciuatele": "aciuat",
    "aciuatelor": "aciuat",
    "aciuați": "aciuat",
    "aciuații": "aciuat",
    "aciuaților": "aciuat",
    "aciuatul": "aciuat",
    "aciuatului": "aciuat",
    "aciuea": "aciui",
    "aciueai": "aciui",
    "aciueam": "aciui",
    "aciueați": "aciui",
    "aciueau": "aciui",
    "aciuează": "aciui",
    "aciuez": "aciui",
    "aciueze": "aciui",
    "aciuezi": "aciui",
    "aciuii": "aciui",
    "aciuim": "aciui",
    "aciuind": "aciui",
    "aciuindu": "aciui",
    "aciuiră": "aciui",
    "aciuirăm": "aciui",
    "aciuirăți": "aciui",
    "aciuise": "aciui",
    "aciuisem": "aciui",
    "aciuiseră": "aciui",
    "aciuiserăm": "aciui",
    "aciuiserăți": "aciui",
    "aciuiseși": "aciui",
    "aciuiși": "aciui",
    "aciuit": "aciui",
    "aciuiți": "aciui",
    "aciuitu": "aciui",
    "aciuirea": "aciuire",
    "aciuiri": "aciuire",
    "aciuirii": "aciuire",
    "aciuirile": "aciuire",
    "aciuita": "aciuit",
    "aciuită": "aciuit",
    "aciuite": "aciuit",
    "aciuitei": "aciuit",
    "aciuitele": "aciuit",
    "aciuitelor": "aciuit",
    "aciuiți": "aciuit",
    "aciuiții": "aciuit",
    "aciuiților": "aciuit",
    "aciuitul": "aciuit",
    "aciuitului": "aciuit",
    "aclamă": "aclama",
    "aclamai": "aclama",
    "aclamam": "aclama",
    "aclamăm": "aclama",
    "aclamând": "aclama",
    "aclamându": "aclama",
    "aclamară": "aclama",
    "aclamarăm": "aclama",
    "aclamarăți": "aclama",
    "aclamase": "aclama",
    "aclamasem": "aclama",
    "aclamaseră": "aclama",
    "aclamaserăm": "aclama",
    "aclamaserăți": "aclama",
    "aclamaseși": "aclama",
    "aclamași": "aclama",
    "aclamat": "aclama",
    "aclamați": "aclama",
    "aclamatu": "aclama",
    "aclamau": "aclama",
    "aclamează": "aclama",
    "aclamez": "aclama",
    "aclameze": "aclama",
    "aclamezi": "aclama",
    "neaclamând": "aclama",
    "neaclamându": "aclama",
    "nemaiaclamând": "aclama",
    "nemaiaclamându": "aclama",
    "aclamarea": "aclamare",
    "aclamări": "aclamare",
    "aclamării": "aclamare",
    "aclamările": "aclamare",
    "aclamata": "aclamat",
    "aclamată": "aclamat",
    "aclamate": "aclamat",
    "aclamatei": "aclamat",
    "aclamatele": "aclamat",
    "aclamatelor": "aclamat",
    "aclamați": "aclamat",
    "aclamații": "aclamat",
    "aclamaților": "aclamat",
    "aclamatul": "aclamat",
    "aclamatului": "aclamat",
    "aclimatiză": "aclimatiza",
    "aclimatizai": "aclimatiza",
    "aclimatizam": "aclimatiza",
    "aclimatizăm": "aclimatiza",
    "aclimatizând": "aclimatiza",
    "aclimatizându": "aclimatiza",
    "aclimatizară": "aclimatiza",
    "aclimatizarăm": "aclimatiza",
    "aclimatizarăți": "aclimatiza",
    "aclimatizase": "aclimatiza",
    "aclimatizasem": "aclimatiza",
    "aclimatizaseră": "aclimatiza",
    "aclimatizaserăm": "aclimatiza",
    "aclimatizaserăți": "aclimatiza",
    "aclimatizaseși": "aclimatiza",
    "aclimatizași": "aclimatiza",
    "aclimatizat": "aclimatiza",
    "aclimatizați": "aclimatiza",
    "aclimatizatu": "aclimatiza",
    "aclimatizau": "aclimatiza",
    "aclimatizează": "aclimatiza",
    "aclimatizez": "aclimatiza",
    "aclimatizeze": "aclimatiza",
    "aclimatizezi": "aclimatiza",
    "neaclimatizând": "aclimatiza",
    "neaclimatizându": "aclimatiza",
    "nemaiaclimatizând": "aclimatiza",
    "nemaiaclimatizându": "aclimatiza",
    "aclimatizarea": "aclimatizare",
    "aclimatizări": "aclimatizare",
    "aclimatizării": "aclimatizare",
    "aclimatizările": "aclimatizare",
    "aclimatizata": "aclimatizat",
    "aclimatizată": "aclimatizat",
    "aclimatizate": "aclimatizat",
    "aclimatizatei": "aclimatizat",
    "aclimatizatele": "aclimatizat",
    "aclimatizatelor": "aclimatizat",
    "aclimatizați": "aclimatizat",
    "aclimatizații": "aclimatizat",
    "aclimatizaților": "aclimatizat",
    "aclimatizatul": "aclimatizat",
    "aclimatizatului": "aclimatizat",
    "acneea": "acnee",
    "acneei": "acnee",
    "acneele": "acnee",
    "acneelor": "acnee",
    "acolada": "acoladă",
    "acolade": "acoladă",
    "acoladei": "acoladă",
    "acoladele": "acoladă",
    "acoladelor": "acoladă",
    "acoliți": "acolit",
    "acoliții": "acolit",
    "acoliților": "acolit",
    "acolitul": "acolit",
    "acolitului": "acolit",
    "acomodai": "acomoda",
    "acomodam": "acomoda",
    "acomodând": "acomoda",
    "acomodară": "acomoda",
    "acomodarăm": "acomoda",
    "acomodarăți": "acomoda",
    "acomodase": "acomoda",
    "acomodasem": "acomoda",
    "acomodaseră": "acomoda",
    "acomodaserăm": "acomoda",
    "acomodaserăți": "acomoda",
    "acomodaseși": "acomoda",
    "acomodași": "acomoda",
    "acomodat": "acomoda",
    "acomodați": "acomoda",
    "acomodatu": "acomoda",
    "acomodau": "acomoda",
    "acomodează": "acomoda",
    "acomodez": "acomoda",
    "acomodeze": "acomoda",
    "acomodezi": "acomoda",
    "neacomodând": "acomoda",
    "nemaiacomodând": "acomoda",
    "acomodabila": "acomodabil",
    "acomodabile": "acomodabil",
    "acomodabilei": "acomodabil",
    "acomodabilele": "acomodabil",
    "acomodabilelor": "acomodabil",
    "acomodabili": "acomodabil",
    "acomodabilii": "acomodabil",
    "acomodabililor": "acomodabil",
    "acomodabilul": "acomodabil",
    "acomodabilului": "acomodabil",
    "acomodarea": "acomodare",
    "acomodări": "acomodare",
    "acomodării": "acomodare",
    "acomodările": "acomodare",
    "acomodata": "acomodat",
    "acomodată": "acomodat",
    "acomodate": "acomodat",
    "acomodatei": "acomodat",
    "acomodatele": "acomodat",
    "acomodatelor": "acomodat",
    "acomodați": "acomodat",
    "acomodații": "acomodat",
    "acomodaților": "acomodat",
    "acomodatul": "acomodat",
    "acomodatului": "acomodat",
    "acompaniai": "acompania",
    "acompaniam": "acompania",
    "acompaniară": "acompania",
    "acompaniarăm": "acompania",
    "acompaniarăți": "acompania",
    "acompaniase": "acompania",
    "acompaniasem": "acompania",
    "acompaniaseră": "acompania",
    "acompaniaserăm": "acompania",
    "acompaniaserăți": "acompania",
    "acompaniaseși": "acompania",
    "acompaniași": "acompania",
    "acompaniat": "acompania",
    "acompaniați": "acompania",
    "acompaniatu": "acompania",
    "acompaniau": "acompania",
    "acompaniază": "acompania",
    "acompanie": "acompania",
    "acompaniem": "acompania",
    "acompaniez": "acompania",
    "acompanieze": "acompania",
    "acompaniezi": "acompania",
    "acompaniind": "acompania",
    "acompaniindu": "acompania",
    "neacompaniind": "acompania",
    "neacompaniindu": "acompania",
    "nemaiacompaniind": "acompania",
    "nemaiacompaniindu": "acompania",
    "acompaniamente": "acompaniament",
    "acompaniamentele": "acompaniament",
    "acompaniamentelor": "acompaniament",
    "acompaniamentul": "acompaniament",
    "acompaniamentului": "acompaniament",
    "acompaniata": "acompaniat",
    "acompaniată": "acompaniat",
    "acompaniate": "acompaniat",
    "acompaniatei": "acompaniat",
    "acompaniatele": "acompaniat",
    "acompaniatelor": "acompaniat",
    "acompaniați": "acompaniat",
    "acompaniații": "acompaniat",
    "acompaniaților": "acompaniat",
    "acompaniatul": "acompaniat",
    "acompaniatului": "acompaniat",
    "acompanierea": "acompaniere",
    "acompanieri": "acompaniere",
    "acompanierii": "acompaniere",
    "acompanierile": "acompaniere",
    "acontul": "acont",
    "acontului": "acont",
    "aconturi": "acont",
    "aconturile": "acont",
    "aconturilor": "acont",
    "acopăr": "acoperi",
    "acoperă": "acoperi",
    "acopere": "acoperi",
    "acoperea": "acoperi",
    "acopereai": "acoperi",
    "acopeream": "acoperi",
    "acopereați": "acoperi",
    "acopereau": "acoperi",
    "acoperii": "acoperi",
    "acoperim": "acoperi",
    "acoperind": "acoperi",
    "acoperindu": "acoperi",
    "acoperirăm": "acoperi",
    "acoperirăți": "acoperi",
    "acoperise": "acoperi",
    "acoperisem": "acoperi",
    "acoperiseră": "acoperi",
    "acoperiserăți": "acoperi",
    "acoperiseși": "acoperi",
    "acoperiși": "acoperi",
    "acoperit": "acoperi",
    "acoperiți": "acoperi",
    "acoperitu": "acoperi",
    "neacoperind": "acoperi",
    "neacoperindu": "acoperi",
    "nemaiacoperind": "acoperi",
    "nemaiacoperindu": "acoperi",
    "acoperirea": "acoperire",
    "acoperiri": "acoperire",
    "acoperirii": "acoperire",
    "acoperirile": "acoperire",
    "acoperișul": "acoperiș",
    "acoperișului": "acoperiș",
    "acoperișuri": "acoperiș",
    "acoperișurile": "acoperiș",
    "acoperișurilor": "acoperiș",
    "acoperita": "acoperit",
    "acoperită": "acoperit",
    "acoperite": "acoperit",
    "acoperitei": "acoperit",
    "acoperitele": "acoperit",
    "acoperitelor": "acoperit",
    "acoperiți": "acoperit",
    "acoperiții": "acoperit",
    "acoperiților": "acoperit",
    "acoperitul": "acoperit",
    "acoperitului": "acoperit",
    "acoperitoarea": "acoperitoare",
    "acoperitoarei": "acoperitoare",
    "acoperitoarele": "acoperitoare",
    "acoperitoarelor": "acoperitoare",
    "acoperitori": "acoperitor",
    "acoperitorii": "acoperitor",
    "acoperitorilor": "acoperitor",
    "acoperitorul": "acoperitor",
    "acoperitorului": "acoperitor",
    "acor'": "acord",
    "acordul": "acord",
    "acordului": "acord",
    "acorduri": "acord",
    "acordurile": "acord",
    "acordurilor": "acord",
    "acord": "acorda",
    "acordă": "acorda",
    "acordai": "acorda",
    "acordam": "acorda",
    "acordăm": "acorda",
    "acordând": "acorda",
    "acordându": "acorda",
    "acordară": "acorda",
    "acordarăm": "acorda",
    "acordarăți": "acorda",
    "acordase": "acorda",
    "acordasem": "acorda",
    "acordaseră": "acorda",
    "acordaserăm": "acorda",
    "acordaserăți": "acorda",
    "acordaseși": "acorda",
    "acordași": "acorda",
    "acordat": "acorda",
    "acordați": "acorda",
    "acordatu": "acorda",
    "acordau": "acorda",
    "acorde": "acorda",
    "acordează": "acorda",
    "acordez": "acorda",
    "acordeze": "acorda",
    "acordezi": "acorda",
    "acorzi": "acorda",
    "neacordând": "acorda",
    "neacordându": "acorda",
    "nemaiacordând": "acorda",
    "nemaiacordându": "acorda",
    "acordaje": "acordaj",
    "acordajele": "acordaj",
    "acordajelor": "acordaj",
    "acordajul": "acordaj",
    "acordajului": "acordaj",
    "acordarea": "acordare",
    "acordări": "acordare",
    "acordării": "acordare",
    "acordările": "acordare",
    "acordata": "acordat",
    "acordată": "acordat",
    "acordate": "acordat",
    "acordatei": "acordat",
    "acordatele": "acordat",
    "acordatelor": "acordat",
    "acordați": "acordat",
    "acordații": "acordat",
    "acordaților": "acordat",
    "acordatul": "acordat",
    "acordatului": "acordat",
    "acostă": "acosta",
    "acostai": "acosta",
    "acostam": "acosta",
    "acostăm": "acosta",
    "acostând": "acosta",
    "acostându": "acosta",
    "acostară": "acosta",
    "acostarăm": "acosta",
    "acostarăți": "acosta",
    "acostase": "acosta",
    "acostasem": "acosta",
    "acostaseră": "acosta",
    "acostaserăm": "acosta",
    "acostaserăți": "acosta",
    "acostaseși": "acosta",
    "acostași": "acosta",
    "acostat": "acosta",
    "acostați": "acosta",
    "acostatu": "acosta",
    "acostau": "acosta",
    "acostează": "acosta",
    "acostez": "acosta",
    "acosteze": "acosta",
    "acostezi": "acosta",
    "neacostând": "acosta",
    "neacostându": "acosta",
    "nemaiacostând": "acosta",
    "nemaiacostându": "acosta",
    "acostamente": "acostament",
    "acostamentele": "acostament",
    "acostamentelor": "acostament",
    "acostamentul": "acostament",
    "acostamentului": "acostament",
    "acostarea": "acostare",
    "acostări": "acostare",
    "acostării": "acostare",
    "acostările": "acostare",
    "acostata": "acostat",
    "acostată": "acostat",
    "acostate": "acostat",
    "acostatei": "acostat",
    "acostatele": "acostat",
    "acostatelor": "acostat",
    "acostați": "acostat",
    "acostații": "acostat",
    "acostaților": "acostat",
    "acostatul": "acostat",
    "acostatului": "acostat",
    "acotiledoane": "acotiledon",
    "acotiledoanei": "acotiledon",
    "acotiledoanele": "acotiledon",
    "acotiledoanelor": "acotiledon",
    "acotiledona": "acotiledon",
    "acotiledonă": "acotiledon",
    "acotiledoni": "acotiledon",
    "acotiledonii": "acotiledon",
    "acotiledonilor": "acotiledon",
    "acotiledonul": "acotiledon",
    "acotiledonului": "acotiledon",
    "acotiledonata": "acotiledonat",
    "acotiledonată": "acotiledonat",
    "acotiledonate": "acotiledonat",
    "acotiledonatei": "acotiledonat",
    "acotiledonatele": "acotiledonat",
    "acotiledonatelor": "acotiledonat",
    "acotiledonați": "acotiledonat",
    "acotiledonații": "acotiledonat",
    "acotiledonaților": "acotiledonat",
    "acotiledonatul": "acotiledonat",
    "acotiledonatului": "acotiledonat",
    "acreala": "acreală",
    "acreli": "acreală",
    "acrelii": "acreală",
    "acrelile": "acreală",
    "acrelilor": "acreală",
    "acredită": "acredita",
    "acreditai": "acredita",
    "acreditam": "acredita",
    "acredităm": "acredita",
    "acreditând": "acredita",
    "acreditându": "acredita",
    "acreditară": "acredita",
    "acreditarăm": "acredita",
    "acreditarăți": "acredita",
    "acreditase": "acredita",
    "acreditasem": "acredita",
    "acreditaseră": "acredita",
    "acreditaserăm": "acredita",
    "acreditaserăți": "acredita",
    "acreditaseși": "acredita",
    "acreditași": "acredita",
    "acreditat": "acredita",
    "acreditați": "acredita",
    "acreditatu": "acredita",
    "acreditau": "acredita",
    "acreditează": "acredita",
    "acrediteze": "acredita",
    "acreditezi": "acredita",
    "neacreditând": "acredita",
    "neacreditându": "acredita",
    "nemaiacreditând": "acredita",
    "nemaiacreditându": "acredita",
    "acreditarea": "acreditare",
    "acreditări": "acreditare",
    "acreditării": "acreditare",
    "acreditările": "acreditare",
    "acreditata": "acreditat",
    "acreditată": "acreditat",
    "acreditate": "acreditat",
    "acreditatei": "acreditat",
    "acreditatele": "acreditat",
    "acreditatelor": "acreditat",
    "acreditați": "acreditat",
    "acreditații": "acreditat",
    "acreditaților": "acreditat",
    "acreditatul": "acreditat",
    "acreditatului": "acreditat",
    "acreditata": "acreditată",
    "acreditate": "acreditată",
    "acreditatei": "acreditată",
    "acreditatele": "acreditată",
    "acreditatelor": "acreditată",
    "acreditive": "acreditiv",
    "acreditivele": "acreditiv",
    "acreditivelor": "acreditiv",
    "acreditivul": "acreditiv",
    "acreditivului": "acreditiv",
    "acrea": "acri",
    "acreai": "acri",
    "acream": "acri",
    "acrească": "acri",
    "acreați": "acri",
    "acreau": "acri",
    "acresc": "acri",
    "acrește": "acri",
    "acrești": "acri",
    "acrii": "acri",
    "acrim": "acri",
    "acrind": "acri",
    "acrindu": "acri",
    "acriră": "acri",
    "acrirăm": "acri",
    "acrirăți": "acri",
    "acrise": "acri",
    "acrisem": "acri",
    "acriseră": "acri",
    "acriserăți": "acri",
    "acriseși": "acri",
    "acriși": "acri",
    "acrit": "acri",
    "acriți": "acri",
    "acritu": "acri",
    "neacrind": "acri",
    "neacrindu": "acri",
    "nemaiacrind": "acri",
    "nemaiacrindu": "acri",
    "acrirea": "acrire",
    "acriri": "acrire",
    "acririi": "acrire",
    "acririle": "acrire",
    "acririlor": "acrire",
    "acrita": "acrit",
    "acrită": "acrit",
    "acrite": "acrit",
    "acritei": "acrit",
    "acritele": "acrit",
    "acritelor": "acrit",
    "acriți": "acrit",
    "acriții": "acrit",
    "acriților": "acrit",
    "acritul": "acrit",
    "acritului": "acrit",
    "acritura": "acritură",
    "acrituri": "acritură",
    "acriturii": "acritură",
    "acriturile": "acritură",
    "acriturilor": "acritură",
    "acrobați": "acrobat",
    "acrobații": "acrobat",
    "acrobaților": "acrobat",
    "acrobatul": "acrobat",
    "acrobatului": "acrobat",
    "acrobata": "acrobată",
    "acrobate": "acrobată",
    "acrobatei": "acrobată",
    "acrobatele": "acrobată",
    "acrobatelor": "acrobată",
    "acrobatica": "acrobatic",
    "acrobatică": "acrobatic",
    "acrobatice": "acrobatic",
    "acrobaticei": "acrobatic",
    "acrobaticele": "acrobatic",
    "acrobaticelor": "acrobatic",
    "acrobatici": "acrobatic",
    "acrobaticii": "acrobatic",
    "acrobaticilor": "acrobatic",
    "acrobaticul": "acrobatic",
    "acrobaticului": "acrobatic",
    "acrobația": "acrobație",
    "acrobației": "acrobație",
    "acrobații": "acrobație",
    "acrobațiile": "acrobație",
    "acrobațiilor": "acrobație",
    "acrobaticilor": "acromatic",
    "acromatica": "acromatic",
    "acromatică": "acromatic",
    "acromatice": "acromatic",
    "acromaticei": "acromatic",
    "acromaticele": "acromatic",
    "acromaticelor": "acromatic",
    "acromatici": "acromatic",
    "acromaticii": "acromatic",
    "acromaticul": "acromatic",
    "acromaticului": "acromatic",
    "acrostihul": "acrostih",
    "acrostihului": "acrostih",
    "acrostihuri": "acrostih",
    "acrostihurile": "acrostih",
    "acrostihurilor": "acrostih",
    "acra": "acru",
    "acră": "acru",
    "acre": "acru",
    "acrei": "acru",
    "acrele": "acru",
    "acrelor": "acru",
    "acri": "acru",
    "acrii": "acru",
    "acrilor": "acru",
    "acrul": "acru",
    "acrului": "acru",
    "acte": "act",
    "actele": "act",
    "actelor": "act",
    "actul": "act",
    "actului": "act",
    "acționă": "acționa",
    "acționai": "acționa",
    "acționam": "acționa",
    "acționăm": "acționa",
    "acționând": "acționa",
    "acționându": "acționa",
    "acționară": "acționa",
    "acționarăm": "acționa",
    "acționarăți": "acționa",
    "acționase": "acționa",
    "acționasem": "acționa",
    "acționaseră": "acționa",
    "acționaserăm": "acționa",
    "acționaserăți": "acționa",
    "acționaseși": "acționa",
    "acționași": "acționa",
    "acționat": "acționa",
    "acționați": "acționa",
    "acționatu": "acționa",
    "acționau": "acționa",
    "acționează": "acționa",
    "acționez": "acționa",
    "acționeze": "acționa",
    "acționezi": "acționa",
    "neacționând": "acționa",
    "neacționându": "acționa",
    "nemaiacționând": "acționa",
    "nemaiacționându": "acționa",
    "acționari": "acționar",
    "acționarii": "acționar",
    "acționarilor": "acționar",
    "acționarul": "acționar",
    "acționarului": "acționar",
    "acționara": "acționară",
    "acționare": "acționară",
    "acționarei": "acționară",
    "acționarele": "acționară",
    "acționarelor": "acționară",
    "acționarea": "acționare",
    "acționări": "acționare",
    "acționării": "acționare",
    "acționările": "acționare",
    "acționata": "acționat",
    "acționată": "acționat",
    "acționate": "acționat",
    "acționatei": "acționat",
    "acționatele": "acționat",
    "acționatelor": "acționat",
    "acționați": "acționat",
    "acționații": "acționat",
    "acționaților": "acționat",
    "acționatul": "acționat",
    "acționatului": "acționat",
    "acțiunea": "acțiune",
    "acțiuni": "acțiune",
    "acțiunii": "acțiune",
    "acțiunile": "acțiune",
    "acțiunilor": "acțiune",
    "activa": "activ",
    "activă": "activ",
    "active": "activ",
    "activei": "activ",
    "activele": "activ",
    "activelor": "activ",
    "activi": "activ",
    "activii": "activ",
    "activilor": "activ",
    "activul": "activ",
    "activului": "activ",
    "activă": "activa",
    "activai": "activa",
    "activam": "activa",
    "activăm": "activa",
    "activând": "activa",
    "activându": "activa",
    "activară": "activa",
    "activarăm": "activa",
    "activarăți": "activa",
    "activase": "activa",
    "activasem": "activa",
    "activaseră": "activa",
    "activaserăm": "activa",
    "activaserăți": "activa",
    "activaseși": "activa",
    "activași": "activa",
    "activat": "activa",
    "activați": "activa",
    "activatu": "activa",
    "activau": "activa",
    "activează": "activa",
    "activez": "activa",
    "activeze": "activa",
    "activezi": "activa",
    "neactivând": "activa",
    "neactivându": "activa",
    "nemaiactivând": "activa",
    "nemaiactivându": "activa",
    "activarea": "activare",
    "activări": "activare",
    "activării": "activare",
    "activările": "activare",
    "activata": "activat",
    "activată": "activat",
    "activate": "activat",
    "activatei": "activat",
    "activatele": "activat",
    "activatelor": "activat",
    "activați": "activat",
    "activații": "activat",
    "activaților": "activat",
    "activatul": "activat",
    "activatului": "activat",
    "activiști": "activist",
    "activiștii": "activist",
    "activiștilor": "activist",
    "activistul": "activist",
    "activistului": "activist",
    "activista": "activistă",
    "activiste": "activistă",
    "activistei": "activistă",
    "activistele": "activistă",
    "activistelor": "activistă",
    "activitatea": "activitate",
    "activități": "activitate",
    "activității": "activitate",
    "activitățile": "activitate",
    "activităților": "activitate",
    "activiză": "activiza",
    "activizai": "activiza",
    "activizam": "activiza",
    "activizăm": "activiza",
    "activizând": "activiza",
    "activizându": "activiza",
    "activizară": "activiza",
    "activizarăm": "activiza",
    "activizarăți": "activiza",
    "activizase": "activiza",
    "activizasem": "activiza",
    "activizaseră": "activiza",
    "activizaserăm": "activiza",
    "activizaserăți": "activiza",
    "activizaseși": "activiza",
    "activizași": "activiza",
    "activizat": "activiza",
    "activizați": "activiza",
    "activizatu": "activiza",
    "activizau": "activiza",
    "activizează": "activiza",
    "activizez": "activiza",
    "activizeze": "activiza",
    "activizezi": "activiza",
    "neactivizând": "activiza",
    "neactivizându": "activiza",
    "nemaiactivizând": "activiza",
    "nemaiactivizându": "activiza",
    "activizarea": "activizare",
    "activizări": "activizare",
    "activizării": "activizare",
    "activizările": "activizare",
    "activizata": "activizat",
    "activizată": "activizat",
    "activizate": "activizat",
    "activizatei": "activizat",
    "activizatele": "activizat",
    "activizatelor": "activizat",
    "activizați": "activizat",
    "activizații": "activizat",
    "activizaților": "activizat",
    "activizatul": "activizat",
    "activizatului": "activizat",
    "actori": "actor",
    "actorii": "actor",
    "actorilor": "actor",
    "actorul": "actor",
    "actorului": "actor",
    "actoriceasca": "actoricesc",
    "actoricească": "actoricesc",
    "actoricescul": "actoricesc",
    "actoricescului": "actoricesc",
    "actoricești": "actoricesc",
    "actoriceștii": "actoricesc",
    "actoriceștile": "actoricesc",
    "actoriceștilor": "actoricesc",
    "actoria": "actorie",
    "actoriei": "actorie",
    "actorii": "actorie",
    "actoriile": "actorie",
    "actoriilor": "actorie",
    "actrița": "actriță",
    "actrițe": "actriță",
    "actriței": "actriță",
    "actrițele": "actriță",
    "actrițelor": "actriță",
    "actuala": "actual",
    "actuală": "actual",
    "actuale": "actual",
    "actualei": "actual",
    "actualele": "actual",
    "actualelor": "actual",
    "actuali": "actual",
    "actualii": "actual",
    "actualilor": "actual",
    "actualul": "actual",
    "actualului": "actual",
    "actualitatea": "actualitate",
    "actualități": "actualitate",
    "actualității": "actualitate",
    "actualitățile": "actualitate",
    "actualităților": "actualitate",
    "actualiză": "actualiza",
    "actualizai": "actualiza",
    "actualizam": "actualiza",
    "actualizăm": "actualiza",
    "actualizând": "actualiza",
    "actualizându": "actualiza",
    "actualizară": "actualiza",
    "actualizarăm": "actualiza",
    "actualizarăți": "actualiza",
    "actualizase": "actualiza",
    "actualizasem": "actualiza",
    "actualizaseră": "actualiza",
    "actualizaserăm": "actualiza",
    "actualizaserăți": "actualiza",
    "actualizaseși": "actualiza",
    "actualizași": "actualiza",
    "actualizat": "actualiza",
    "actualizați": "actualiza",
    "actualizatu": "actualiza",
    "actualizau": "actualiza",
    "actualizează": "actualiza",
    "actualizez": "actualiza",
    "actualizeze": "actualiza",
    "actualizezi": "actualiza",
    "neactualizând": "actualiza",
    "neactualizându": "actualiza",
    "nemaiactualizând": "actualiza",
    "nemaiactualizându": "actualiza",
    "actualizarea": "actualizare",
    "actualizări": "actualizare",
    "actualizării": "actualizare",
    "actualizările": "actualizare",
    "actualizata": "actualizat",
    "actualizată": "actualizat",
    "actualizate": "actualizat",
    "actualizatei": "actualizat",
    "actualizatele": "actualizat",
    "actualizatelor": "actualizat",
    "actualizați": "actualizat",
    "actualizații": "actualizat",
    "actualizaților": "actualizat",
    "actualizatul": "actualizat",
    "actualizatului": "actualizat",
    "acuarela": "acuarelă",
    "acuarele": "acuarelă",
    "acuarelei": "acuarelă",
    "acuarelele": "acuarelă",
    "acuarelelor": "acuarelă",
    "acuitatea": "acuitate",
    "acuități": "acuitate",
    "acuității": "acuitate",
    "acuitățile": "acuitate",
    "acuităților": "acuitate",
    "acu'": "acum",
    "acuminata": "acuminat",
    "acuminată": "acuminat",
    "acuminate": "acuminat",
    "acuminatei": "acuminat",
    "acuminatele": "acuminat",
    "acuminatelor": "acuminat",
    "acuminați": "acuminat",
    "acuminații": "acuminat",
    "acuminaților": "acuminat",
    "acuminatul": "acuminat",
    "acuminatului": "acuminat",
    "acumulă": "acumula",
    "acumulai": "acumula",
    "acumulam": "acumula",
    "acumulăm": "acumula",
    "acumulând": "acumula",
    "acumulându": "acumula",
    "acumulară": "acumula",
    "acumularăm": "acumula",
    "acumularăți": "acumula",
    "acumulase": "acumula",
    "acumulasem": "acumula",
    "acumulaseră": "acumula",
    "acumulaserăm": "acumula",
    "acumulaserăți": "acumula",
    "acumulaseși": "acumula",
    "acumulași": "acumula",
    "acumulat": "acumula",
    "acumulați": "acumula",
    "acumulatu": "acumula",
    "acumulau": "acumula",
    "acumulează": "acumula",
    "acumulez": "acumula",
    "acumuleze": "acumula",
    "acumulezi": "acumula",
    "neacumulând": "acumula",
    "neacumulându": "acumula",
    "nemaiacumulând": "acumula",
    "nemaiacumulându": "acumula",
    "acumularea": "acumulare",
    "acumulări": "acumulare",
    "acumulării": "acumulare",
    "acumulările": "acumulare",
    "acumulata": "acumulat",
    "acumulată": "acumulat",
    "acumulate": "acumulat",
    "acumulatei": "acumulat",
    "acumulatele": "acumulat",
    "acumulatelor": "acumulat",
    "acumulați": "acumulat",
    "acumulații": "acumulat",
    "acumulaților": "acumulat",
    "acumulatul": "acumulat",
    "acumulatului": "acumulat",
    "acumulatoare": "acumulator",
    "acumulatoarele": "acumulator",
    "acumulatoarelor": "acumulator",
    "acumulatorul": "acumulator",
    "acumulatorului": "acumulator",
    "acuplă": "acupla",
    "acuplai": "acupla",
    "acuplam": "acupla",
    "acuplăm": "acupla",
    "acuplând": "acupla",
    "acuplându": "acupla",
    "acuplară": "acupla",
    "acuplarăm": "acupla",
    "acuplarăți": "acupla",
    "acuplase": "acupla",
    "acuplasem": "acupla",
    "acuplaseră": "acupla",
    "acuplaserăm": "acupla",
    "acuplaserăți": "acupla",
    "acuplaseși": "acupla",
    "acuplași": "acupla",
    "acuplat": "acupla",
    "acuplați": "acupla",
    "acuplatu": "acupla",
    "acuplau": "acupla",
    "acuplează": "acupla",
    "acuplez": "acupla",
    "acupleze": "acupla",
    "acuplezi": "acupla",
    "acuplată": "acuplat",
    "acuplate": "acuplat",
    "acuplați": "acuplat",
    "acuratețea": "acuratețe",
    "acurateți": "acuratețe",
    "acurateții": "acuratețe",
    "acuratețile": "acuratețe",
    "acurateților": "acuratețe",
    "acustica": "acustic",
    "acustică": "acustic",
    "acustice": "acustic",
    "acusticei": "acustic",
    "acusticele": "acustic",
    "acusticelor": "acustic",
    "acustici": "acustic",
    "acusticii": "acustic",
    "acusticilor": "acustic",
    "acusticul": "acustic",
    "acusticului": "acustic",
    "acuta": "acut",
    "acută": "acut",
    "acute": "acut",
    "acutei": "acut",
    "acutele": "acut",
    "acutelor": "acut",
    "acuți": "acut",
    "acuții": "acut",
    "acuților": "acut",
    "acutul": "acut",
    "acutului": "acut",
    "acutizarea": "acutizare",
    "acuz": "acuza",
    "acuză": "acuza",
    "acuzai": "acuza",
    "acuzam": "acuza",
    "acuzăm": "acuza",
    "acuzând": "acuza",
    "acuzându": "acuza",
    "acuzară": "acuza",
    "acuzarăm": "acuza",
    "acuzarăți": "acuza",
    "acuzase": "acuza",
    "acuzasem": "acuza",
    "acuzaseră": "acuza",
    "acuzaserăm": "acuza",
    "acuzaserăți": "acuza",
    "acuzaseși": "acuza",
    "acuzași": "acuza",
    "acuzat": "acuza",
    "acuzați": "acuza",
    "acuzatu": "acuza",
    "acuzau": "acuza",
    "acuze": "acuza",
    "acuzi": "acuza",
    "neacuzând": "acuza",
    "neacuzându": "acuza",
    "nemaiacuzând": "acuza",
    "nemaiacuzându": "acuza",
    "acuza": "acuză",
    "acuze": "acuză",
    "acuzei": "acuză",
    "acuzele": "acuză",
    "acuzelor": "acuză",
    "acuzarea": "acuzare",
    "acuzări": "acuzare",
    "acuzării": "acuzare",
    "acuzările": "acuzare",
    "acuzata": "acuzat",
    "acuzată": "acuzat",
    "acuzate": "acuzat",
    "acuzatei": "acuzat",
    "acuzatele": "acuzat",
    "acuzatelor": "acuzat",
    "acuzați": "acuzat",
    "acuzații": "acuzat",
    "acuzaților": "acuzat",
    "acuzatul": "acuzat",
    "acuzatului": "acuzat",
    "acuzata": "acuzată",
    "acuzate": "acuzată",
    "acuzatei": "acuzată",
    "acuzatele": "acuzată",
    "acuzatelor": "acuzată",
    "acuzația": "acuzație",
    "acuzației": "acuzație",
    "acuzații": "acuzație",
    "acuzațiile": "acuzație",
    "acuzațiilor": "acuzație",
    "acuzatoarea": "acuzatoare",
    "acuzatoarei": "acuzatoare",
    "acuzatoarele": "acuzatoare",
    "acuzatoarelor": "acuzatoare",
    "acuzatoare": "acuzator",
    "acuzatoarea": "acuzator",
    "acuzatoarei": "acuzator",
    "acuzatoarele": "acuzator",
    "acuzatoarelor": "acuzator",
    "acuzatori": "acuzator",
    "acuzatorii": "acuzator",
    "acuzatorilor": "acuzator",
    "acuzatorul": "acuzator",
    "acuzatorului": "acuzator",
    "acvarii": "acvariu",
    "acvariile": "acvariu",
    "acvariilor": "acvariu",
    "acvariul": "acvariu",
    "acvariului": "acvariu",
    "acvatica": "acvatic",
    "acvatică": "acvatic",
    "acvatice": "acvatic",
    "acvaticei": "acvatic",
    "acvaticele": "acvatic",
    "acvaticelor": "acvatic",
    "acvatici": "acvatic",
    "acvaticii": "acvatic",
    "acvaticilor": "acvatic",
    "acvaticul": "acvatic",
    "acvaticului": "acvatic",
    "acvifera": "acvifer",
    "acviferă": "acvifer",
    "acvifere": "acvifer",
    "acviferei": "acvifer",
    "acviferele": "acvifer",
    "acviferelor": "acvifer",
    "acviferi": "acvifer",
    "acviferii": "acvifer",
    "acviferilor": "acvifer",
    "acviferul": "acvifer",
    "acviferului": "acvifer",
    "acvila": "acvilă",
    "acvile": "acvilă",
    "acvilei": "acvilă",
    "acvilele": "acvilă",
    "acvilelor": "acvilă",
    "acvilina": "acvilin",
    "acvilină": "acvilin",
    "acviline": "acvilin",
    "acvilinei": "acvilin",
    "acvilinele": "acvilin",
    "acvilinelor": "acvilin",
    "acvilini": "acvilin",
    "acvilinii": "acvilin",
    "acvilinilor": "acvilin",
    "acvilinul": "acvilin",
    "acvilinului": "acvilin",
    "a.h.l.": "ad_hunc_locum",
    "a.i.": "ad_interim",
    "ad_us.": "ad_usum",
    "Adei": "Ada",
    "adagii": "adagiu",
    "adagiile": "adagiu",
    "adagiilor": "adagiu",
    "adagiul": "adagiu",
    "adagiului": "adagiu",
    "adamantina": "adamantin",
    "adamantină": "adamantin",
    "adamantine": "adamantin",
    "adamantinei": "adamantin",
    "adamantinele": "adamantin",
    "adamantinelor": "adamantin",
    "adamantini": "adamantin",
    "adamantinii": "adamantin",
    "adamantinilor": "adamantin",
    "adamantinul": "adamantin",
    "adamantinului": "adamantin",
    "adânca": "adânc",
    "adâncă": "adânc",
    "adânci": "adânc",
    "adâncii": "adânc",
    "adâncile": "adânc",
    "adâncilor": "adânc",
    "adâncul": "adânc",
    "adâncului": "adânc",
    "adâncuri": "adânc",
    "adâncurile": "adânc",
    "adâncurilor": "adânc",
    "adâncea": "adânci",
    "adânceai": "adânci",
    "adânceam": "adânci",
    "adâncească": "adânci",
    "adânceați": "adânci",
    "adânceau": "adânci",
    "adâncesc": "adânci",
    "adâncește": "adânci",
    "adâncești": "adânci",
    "adâncii": "adânci",
    "adâncim": "adânci",
    "adâncind": "adânci",
    "adâncindu": "adânci",
    "adânciră": "adânci",
    "adâncirăm": "adânci",
    "adâncirăți": "adânci",
    "adâncise": "adânci",
    "adâncisem": "adânci",
    "adânciseră": "adânci",
    "adânciserăm": "adânci",
    "adânciserăți": "adânci",
    "adânciseși": "adânci",
    "adânciși": "adânci",
    "adâncit": "adânci",
    "adânciți": "adânci",
    "adâncitu": "adânci",
    "neadâncind": "adânci",
    "neadâncindu": "adânci",
    "nemaiadâncind": "adânci",
    "nemaiadâncindu": "adânci",
    "adâncimea": "adâncime",
    "adâncimi": "adâncime",
    "adâncimii": "adâncime",
    "adâncimile": "adâncime",
    "adâncimilor": "adâncime",
    "adâncirea": "adâncire",
    "adânciri": "adâncire",
    "adâncirii": "adâncire",
    "adâncirile": "adâncire",
    "adâncita": "adâncit",
    "adâncită": "adâncit",
    "adâncite": "adâncit",
    "adâncitei": "adâncit",
    "adâncitele": "adâncit",
    "adâncitelor": "adâncit",
    "adânciți": "adâncit",
    "adânciții": "adâncit",
    "adânciților": "adâncit",
    "adâncitul": "adâncit",
    "adâncitului": "adâncit",
    "adâncitura": "adâncitură",
    "adâncituri": "adâncitură",
    "adânciturii": "adâncitură",
    "adânciturile": "adâncitură",
    "adânciturilor": "adâncitură",
    "adaosul": "adaos",
    "adaosului": "adaos",
    "adaosuri": "adaos",
    "adaosurile": "adaos",
    "adaosurilor": "adaos",
    "adăp": "adăpa",
    "adapă": "adăpa",
    "adăpă": "adăpa",
    "adăpai": "adăpa",
    "adăpam": "adăpa",
    "adăpăm": "adăpa",
    "adăpând": "adăpa",
    "adăpându": "adăpa",
    "adăpară": "adăpa",
    "adăparăm": "adăpa",
    "adăparăți": "adăpa",
    "adăpase": "adăpa",
    "adăpasem": "adăpa",
    "adăpaseră": "adăpa",
    "adăpaserăm": "adăpa",
    "adăpaserăți": "adăpa",
    "adăpaseși": "adăpa",
    "adăpași": "adăpa",
    "adăpat": "adăpa",
    "adăpați": "adăpa",
    "adăpatu": "adăpa",
    "adăpau": "adăpa",
    "adape": "adăpa",
    "adăpi": "adăpa",
    "neadăpând": "adăpa",
    "neadăpându": "adăpa",
    "nemaiadăpând": "adăpa",
    "nemaiadăpându": "adăpa",
    "adăparea": "adăpare",
    "adăpări": "adăpare",
    "adăpării": "adăpare",
    "adăpările": "adăpare",
    "adăpata": "adăpat",
    "adăpată": "adăpat",
    "adăpate": "adăpat",
    "adăpatei": "adăpat",
    "adăpatele": "adăpat",
    "adăpatelor": "adăpat",
    "adăpați": "adăpat",
    "adăpații": "adăpat",
    "adăpaților": "adăpat",
    "adăpatul": "adăpat",
    "adăpatului": "adăpat",
    "adăpostul": "adăpost",
    "adăpostului": "adăpost",
    "adăposturi": "adăpost",
    "adăposturile": "adăpost",
    "adăposturilor": "adăpost",
    "adăpostea": "adăposti",
    "adăposteai": "adăposti",
    "adăposteam": "adăposti",
    "adăpostească": "adăposti",
    "adăposteați": "adăposti",
    "adăposteau": "adăposti",
    "adăpostesc": "adăposti",
    "adăpostește": "adăposti",
    "adăpostești": "adăposti",
    "adăpostii": "adăposti",
    "adăpostim": "adăposti",
    "adăpostind": "adăposti",
    "adăpostindu": "adăposti",
    "adăpostiră": "adăposti",
    "adăpostirăm": "adăposti",
    "adăpostirăți": "adăposti",
    "adăpostise": "adăposti",
    "adăpostisem": "adăposti",
    "adăpostiseră": "adăposti",
    "adăpostiserăm": "adăposti",
    "adăpostiserăți": "adăposti",
    "adăpostiseși": "adăposti",
    "adăpostiși": "adăposti",
    "adăpostit": "adăposti",
    "adăpostiți": "adăposti",
    "adăpostitu": "adăposti",
    "neadăpostind": "adăposti",
    "neadăpostindu": "adăposti",
    "nemaiadăpostind": "adăposti",
    "nemaiadăpostindu": "adăposti",
    "adăpostirea": "adăpostire",
    "adăpostiri": "adăpostire",
    "adăpostirii": "adăpostire",
    "adăpostirile": "adăpostire",
    "adăpostita": "adăpostit",
    "adăpostită": "adăpostit",
    "adăpostite": "adăpostit",
    "adăpostitei": "adăpostit",
    "adăpostitele": "adăpostit",
    "adăpostitelor": "adăpostit",
    "adăpostiți": "adăpostit",
    "adăpostiții": "adăpostit",
    "adăpostiților": "adăpostit",
    "adăpostitul": "adăpostit",
    "adăpostitului": "adăpostit",
    "adaptă": "adapta",
    "adaptai": "adapta",
    "adaptam": "adapta",
    "adaptăm": "adapta",
    "adaptând": "adapta",
    "adaptându": "adapta",
    "adaptară": "adapta",
    "adaptarăm": "adapta",
    "adaptarăți": "adapta",
    "adaptase": "adapta",
    "adaptasem": "adapta",
    "adaptaseră": "adapta",
    "adaptaserăm": "adapta",
    "adaptaserăți": "adapta",
    "adaptaseși": "adapta",
    "adaptași": "adapta",
    "adaptat": "adapta",
    "adaptați": "adapta",
    "adaptatu": "adapta",
    "adaptau": "adapta",
    "adaptează": "adapta",
    "adaptez": "adapta",
    "adapteze": "adapta",
    "adaptezi": "adapta",
    "neadaptând": "adapta",
    "neadaptându": "adapta",
    "nemaiadaptând": "adapta",
    "nemaiadaptându": "adapta",
    "adaptabila": "adaptabil",
    "adaptabilă": "adaptabil",
    "adaptabile": "adaptabil",
    "adaptabilei": "adaptabil",
    "adaptabilele": "adaptabil",
    "adaptabilelor": "adaptabil",
    "adaptabili": "adaptabil",
    "adaptabilii": "adaptabil",
    "adaptabililor": "adaptabil",
    "adaptabilul": "adaptabil",
    "adaptabilului": "adaptabil",
    "adaptarea": "adaptare",
    "adaptări": "adaptare",
    "adaptării": "adaptare",
    "adaptările": "adaptare",
    "adaptata": "adaptat",
    "adaptată": "adaptat",
    "adaptate": "adaptat",
    "adaptatei": "adaptat",
    "adaptatele": "adaptat",
    "adaptatelor": "adaptat",
    "adaptați": "adaptat",
    "adaptații": "adaptat",
    "adaptaților": "adaptat",
    "adaptatul": "adaptat",
    "adaptatului": "adaptat",
    "adast": "adăsta",
    "adastă": "adăsta",
    "adăstă": "adăsta",
    "adăstai": "adăsta",
    "adăstam": "adăsta",
    "adăstăm": "adăsta",
    "adăstând": "adăsta",
    "adăstându": "adăsta",
    "adăstară": "adăsta",
    "adăstarăm": "adăsta",
    "adăstarăți": "adăsta",
    "adăstase": "adăsta",
    "adăstasem": "adăsta",
    "adăstaseră": "adăsta",
    "adăstaserăm": "adăsta",
    "adăstaserăți": "adăsta",
    "adăstaseși": "adăsta",
    "adăstași": "adăsta",
    "adăstat": "adăsta",
    "adăstați": "adăsta",
    "adăstatu": "adăsta",
    "adăstau": "adăsta",
    "adaste": "adăsta",
    "adăști": "adăsta",
    "adăstată": "adăstat",
    "adăstate": "adăstat",
    "adăstați": "adăstat",
    "ad.": "adaugă",
    "adaug": "adăuga",
    "adaugă": "adăuga",
    "adăugă": "adăuga",
    "adăugai": "adăuga",
    "adăugam": "adăuga",
    "adăugăm": "adăuga",
    "adăugând": "adăuga",
    "adăugându": "adăuga",
    "adăugară": "adăuga",
    "adăugarăm": "adăuga",
    "adăugarăți": "adăuga",
    "adăugase": "adăuga",
    "adăugasem": "adăuga",
    "adăugaseră": "adăuga",
    "adăugaserăm": "adăuga",
    "adăugaserăți": "adăuga",
    "adăugaseși": "adăuga",
    "adăugași": "adăuga",
    "adăugat": "adăuga",
    "adăugați": "adăuga",
    "adăugatu": "adăuga",
    "adăugau": "adăuga",
    "adauge": "adăuga",
    "adaugi": "adăuga",
    "neadăugând": "adăuga",
    "neadăugându": "adăuga",
    "nemaiadăugând": "adăuga",
    "nemaiadăugându": "adăuga",
    "adăugabilă": "adăugabil",
    "adăugabile": "adăugabil",
    "adăugabili": "adăugabil",
    "adăugarea": "adăugare",
    "adăugări": "adăugare",
    "adăugării": "adăugare",
    "adăugările": "adăugare",
    "adăugata": "adăugat",
    "adăugată": "adăugat",
    "adăugate": "adăugat",
    "adăugatei": "adăugat",
    "adăugatele": "adăugat",
    "adăugatelor": "adăugat",
    "adăugați": "adăugat",
    "adăugații": "adăugat",
    "adăugaților": "adăugat",
    "adăugatul": "adăugat",
    "adăugatului": "adăugat",
    "adăugirea": "adăugire",
    "adăugiri": "adăugire",
    "adăugirii": "adăugire",
    "adăugirile": "adăugire",
    "adăugirilor": "adăugire",
    "adăugită": "adăugit",
    "adăugite": "adăugit",
    "adăugiți": "adăugit",
    "ad.": "addenda",
    "adecuata": "adecuat",
    "adecuată": "adecuat",
    "adecuate": "adecuat",
    "adecuatei": "adecuat",
    "adecuatele": "adecuat",
    "adecuatelor": "adecuat",
    "adecuați": "adecuat",
    "adecuații": "adecuat",
    "adecuaților": "adecuat",
    "adecuatul": "adecuat",
    "adecuatului": "adecuat",
    "adecvata": "adecvat",
    "adecvată": "adecvat",
    "adecvate": "adecvat",
    "adecvatei": "adecvat",
    "adecvatele": "adecvat",
    "adecvatelor": "adecvat",
    "adecvați": "adecvat",
    "adecvații": "adecvat",
    "adecvaților": "adecvat",
    "adecvatul": "adecvat",
    "adecvatului": "adecvat",
    "ademenea": "ademeni",
    "ademeneai": "ademeni",
    "ademeneam": "ademeni",
    "ademenească": "ademeni",
    "ademeneați": "ademeni",
    "ademeneau": "ademeni",
    "ademenesc": "ademeni",
    "ademenește": "ademeni",
    "ademenești": "ademeni",
    "ademenii": "ademeni",
    "ademenim": "ademeni",
    "ademenind": "ademeni",
    "ademenindu": "ademeni",
    "ademeniră": "ademeni",
    "ademenirăm": "ademeni",
    "ademenirăți": "ademeni",
    "ademenise": "ademeni",
    "ademenisem": "ademeni",
    "ademeniseră": "ademeni",
    "ademeniserăm": "ademeni",
    "ademeniserăți": "ademeni",
    "ademeniseși": "ademeni",
    "ademeniși": "ademeni",
    "ademenit": "ademeni",
    "ademeniți": "ademeni",
    "ademenitu": "ademeni",
    "neademenind": "ademeni",
    "neademenindu": "ademeni",
    "nemaiademenind": "ademeni",
    "nemaiademenindu": "ademeni",
    "ademenirea": "ademenire",
    "ademeniri": "ademenire",
    "ademenirii": "ademenire",
    "ademenirile": "ademenire",
    "ademenita": "ademenit",
    "ademenită": "ademenit",
    "ademenite": "ademenit",
    "ademenitei": "ademenit",
    "ademenitele": "ademenit",
    "ademenitelor": "ademenit",
    "ademeniți": "ademenit",
    "ademeniții": "ademenit",
    "ademeniților": "ademenit",
    "ademenitul": "ademenit",
    "ademenitului": "ademenit",
    "ademenitoarea": "ademenitoare",
    "ademenitoarei": "ademenitoare",
    "ademenitoarele": "ademenitoare",
    "ademenitoarelor": "ademenitoare",
    "ademenitoare": "ademenitor",
    "ademenitoarea": "ademenitor",
    "ademenitoarei": "ademenitor",
    "ademenitoarele": "ademenitor",
    "ademenitoarelor": "ademenitor",
    "ademenitori": "ademenitor",
    "ademenitorii": "ademenitor",
    "ademenitorilor": "ademenitor",
    "ademenitorul": "ademenitor",
    "ademenitorului": "ademenitor",
    "adepți": "adept",
    "adepții": "adept",
    "adepților": "adept",
    "adeptul": "adept",
    "adeptului": "adept",
    "adepta": "adeptă",
    "adepte": "adeptă",
    "adeptei": "adeptă",
    "adeptele": "adeptă",
    "adeptelor": "adeptă",
    "ader": "adera",
    "aderă": "adera",
    "aderai": "adera",
    "aderam": "adera",
    "aderăm": "adera",
    "aderând": "adera",
    "aderându": "adera",
    "aderară": "adera",
    "aderarăm": "adera",
    "aderarăți": "adera",
    "aderase": "adera",
    "aderasem": "adera",
    "aderaseră": "adera",
    "aderaserăm": "adera",
    "aderaserăți": "adera",
    "aderaseși": "adera",
    "aderași": "adera",
    "aderat": "adera",
    "aderați": "adera",
    "aderatu": "adera",
    "aderau": "adera",
    "adere": "adera",
    "aderi": "adera",
    "neaderând": "adera",
    "neaderându": "adera",
    "nemaiaderând": "adera",
    "nemaiaderându": "adera",
    "aderarea": "aderare",
    "aderări": "aderare",
    "aderării": "aderare",
    "aderările": "aderare",
    "aderata": "aderat",
    "aderată": "aderat",
    "aderate": "aderat",
    "aderatei": "aderat",
    "aderatele": "aderat",
    "aderatelor": "aderat",
    "aderați": "aderat",
    "aderații": "aderat",
    "aderaților": "aderat",
    "aderatul": "aderat",
    "aderatului": "aderat",
    "aderenta": "aderent",
    "aderentă": "aderent",
    "aderente": "aderent",
    "aderentei": "aderent",
    "aderentele": "aderent",
    "aderentelor": "aderent",
    "aderenți": "aderent",
    "aderenții": "aderent",
    "aderenților": "aderent",
    "aderentul": "aderent",
    "aderentului": "aderent",
    "aderența": "aderență",
    "aderențe": "aderență",
    "aderenței": "aderență",
    "aderențele": "aderență",
    "aderențelor": "aderență",
    "adevărul": "adevăr",
    "adevărului": "adevăr",
    "adevăruri": "adevăr",
    "adevărurile": "adevăr",
    "adevărurilor": "adevăr",
    "adevărata": "adevărat",
    "adevărată": "adevărat",
    "adevărate": "adevărat",
    "adevăratei": "adevărat",
    "adevăratele": "adevărat",
    "adevăratelor": "adevărat",
    "adevărați": "adevărat",
    "adevărații": "adevărat",
    "adevăraților": "adevărat",
    "adevăratul": "adevărat",
    "adevăratului": "adevărat",
    "adeverea": "adeveri",
    "adevereai": "adeveri",
    "adeveream": "adeveri",
    "adeverească": "adeveri",
    "adevereați": "adeveri",
    "adevereau": "adeveri",
    "adeveresc": "adeveri",
    "adeverește": "adeveri",
    "adeverești": "adeveri",
    "adeverii": "adeveri",
    "adeverim": "adeveri",
    "adeverind": "adeveri",
    "adeverindu": "adeveri",
    "adeveriră": "adeveri",
    "adeverirăm": "adeveri",
    "adeverirăți": "adeveri",
    "adeverise": "adeveri",
    "adeverisem": "adeveri",
    "adeveriseră": "adeveri",
    "adeveriserăm": "adeveri",
    "adeveriserăți": "adeveri",
    "adeveriseși": "adeveri",
    "adeveriși": "adeveri",
    "adeverit": "adeveri",
    "adeveriți": "adeveri",
    "adeveritu": "adeveri",
    "neadeverind": "adeveri",
    "neadeverindu": "adeveri",
    "nemaiadeverind": "adeveri",
    "nemaiadeverindu": "adeveri",
    "adeverința": "adeverință",
    "adeverințe": "adeverință",
    "adeverinței": "adeverință",
    "adeverințele": "adeverință",
    "adeverințelor": "adeverință",
    "adeverirea": "adeverire",
    "adeveriri": "adeverire",
    "adeveririi": "adeverire",
    "adeveririle": "adeverire",
    "adeveririlor": "adeverire",
    "adeverita": "adeverit",
    "adeverită": "adeverit",
    "adeverite": "adeverit",
    "adeveritei": "adeverit",
    "adeveritele": "adeverit",
    "adeveritelor": "adeverit",
    "adeveriți": "adeverit",
    "adeveriții": "adeverit",
    "adeveriților": "adeverit",
    "adeveritul": "adeverit",
    "adeveritului": "adeverit",
    "adeveritoarea": "adeveritoare",
    "adeveritoarei": "adeveritoare",
    "adeveritoarele": "adeveritoare",
    "adeveritoarelor": "adeveritoare",
    "adeveritoare": "adeveritor",
    "adeveritoarea": "adeveritor",
    "adeveritoarei": "adeveritor",
    "adeveritoarele": "adeveritor",
    "adeveritoarelor": "adeveritor",
    "adeveritori": "adeveritor",
    "adeveritorii": "adeveritor",
    "adeveritorilor": "adeveritor",
    "adeveritorul": "adeveritor",
    "adeveritorului": "adeveritor",
    "adeziunea": "adeziune",
    "adeziuni": "adeziune",
    "adeziunii": "adeziune",
    "adeziunile": "adeziune",
    "adeziunilor": "adeziune",
    "adeziva": "adeziv",
    "adezivă": "adeziv",
    "adezive": "adeziv",
    "adezivei": "adeziv",
    "adezivele": "adeziv",
    "adezivelor": "adeziv",
    "adezivi": "adeziv",
    "adezivii": "adeziv",
    "adezivilor": "adeziv",
    "adezivul": "adeziv",
    "adezivului": "adeziv",
    "adiase": "adia",
    "adiat": "adia",
    "adie": "adia",
    "adiind": "adia",
    "neadiind": "adia",
    "nemaiadiind": "adia",
    "adiacenta": "adiacent",
    "adiacentă": "adiacent",
    "adiacente": "adiacent",
    "adiacentei": "adiacent",
    "adiacentele": "adiacent",
    "adiacentelor": "adiacent",
    "adiacenți": "adiacent",
    "adiacenții": "adiacent",
    "adiacenților": "adiacent",
    "adiacentul": "adiacent",
    "adiacentului": "adiacent",
    "adiafora": "adiafor",
    "adiaforă": "adiafor",
    "adiafore": "adiafor",
    "adiaforei": "adiafor",
    "adiaforele": "adiafor",
    "adiaforelor": "adiafor",
    "adiafori": "adiafor",
    "adiaforii": "adiafor",
    "adiaforilor": "adiafor",
    "adiaforul": "adiafor",
    "adiaforului": "adiafor",
    "adiată": "adiat",
    "adiate": "adiat",
    "adiați": "adiat",
    "adierea": "adiere",
    "adieri": "adiere",
    "adierii": "adiere",
    "adierile": "adiere",
    "adipoasa": "adipos",
    "adipoasă": "adipos",
    "adipoase": "adipos",
    "adipoasei": "adipos",
    "adipoasele": "adipos",
    "adipoaselor": "adipos",
    "adipoși": "adipos",
    "adipoșii": "adipos",
    "adipoșilor": "adipos",
    "adiposul": "adipos",
    "adiposului": "adipos",
    "adiționala": "adițional",
    "adițională": "adițional",
    "adiționale": "adițional",
    "adiționalei": "adițional",
    "adiționalele": "adițional",
    "adiționalelor": "adițional",
    "adiționali": "adițional",
    "adiționalii": "adițional",
    "adiționalilor": "adițional",
    "adiționalul": "adițional",
    "adiționalului": "adițional",
    "adj.": "adjectiv",
    "adjective": "adjectiv",
    "adjectivele": "adjectiv",
    "adjectivelor": "adjectiv",
    "adjectivul": "adjectiv",
    "adjectivului": "adjectiv",
    "adjectivala": "adjectival",
    "adjectivală": "adjectival",
    "adjectivale": "adjectival",
    "adjectivalei": "adjectival",
    "adjectivalele": "adjectival",
    "adjectivalelor": "adjectival",
    "adjectivali": "adjectival",
    "adjectivalii": "adjectival",
    "adjectivalilor": "adjectival",
    "adjectivalul": "adjectival",
    "adjectivalului": "adjectival",
    "adjudec": "adjudeca",
    "adjudecă": "adjudeca",
    "adjudecai": "adjudeca",
    "adjudecam": "adjudeca",
    "adjudecăm": "adjudeca",
    "adjudecând": "adjudeca",
    "adjudecându": "adjudeca",
    "adjudecară": "adjudeca",
    "adjudecarăm": "adjudeca",
    "adjudecarăți": "adjudeca",
    "adjudecase": "adjudeca",
    "adjudecasem": "adjudeca",
    "adjudecaseră": "adjudeca",
    "adjudecaserăm": "adjudeca",
    "adjudecaserăți": "adjudeca",
    "adjudecaseși": "adjudeca",
    "adjudecași": "adjudeca",
    "adjudecat": "adjudeca",
    "adjudecați": "adjudeca",
    "adjudecatu": "adjudeca",
    "adjudecau": "adjudeca",
    "adjudece": "adjudeca",
    "adjudeci": "adjudeca",
    "neadjudecând": "adjudeca",
    "neadjudecându": "adjudeca",
    "nemaiadjudecând": "adjudeca",
    "nemaiadjudecându": "adjudeca",
    "adjudecarea": "adjudecare",
    "adjudecări": "adjudecare",
    "adjudecării": "adjudecare",
    "adjudecările": "adjudecare",
    "adjudecata": "adjudecat",
    "adjudecată": "adjudecat",
    "adjudecate": "adjudecat",
    "adjudecatei": "adjudecat",
    "adjudecatele": "adjudecat",
    "adjudecatelor": "adjudecat",
    "adjudecați": "adjudecat",
    "adjudecații": "adjudecat",
    "adjudecaților": "adjudecat",
    "adjudecatul": "adjudecat",
    "adjudecatului": "adjudecat",
    "adjuncta": "adjunct",
    "adjunctă": "adjunct",
    "adjuncte": "adjunct",
    "adjunctei": "adjunct",
    "adjunctele": "adjunct",
    "adjunctelor": "adjunct",
    "adjuncți": "adjunct",
    "adjuncții": "adjunct",
    "adjuncților": "adjunct",
    "adjunctul": "adjunct",
    "adjunctului": "adjunct",
    "adjuncta": "adjunctă",
    "adjuncte": "adjunctă",
    "adjunctei": "adjunctă",
    "adjunctele": "adjunctă",
    "adjunctelor": "adjunctă",
    "administră": "administra",
    "administrai": "administra",
    "administram": "administra",
    "administrăm": "administra",
    "administrând": "administra",
    "administrându": "administra",
    "administrară": "administra",
    "administrarăm": "administra",
    "administrarăți": "administra",
    "administrase": "administra",
    "administrasem": "administra",
    "administraseră": "administra",
    "administraserăm": "administra",
    "administraserăți": "administra",
    "administraseși": "administra",
    "administrași": "administra",
    "administrat": "administra",
    "administrați": "administra",
    "administratu": "administra",
    "administrau": "administra",
    "administrează": "administra",
    "administrez": "administra",
    "administreze": "administra",
    "administrezi": "administra",
    "neadministrând": "administra",
    "neadministrându": "administra",
    "nemaiadministrând": "administra",
    "nemaiadministrându": "administra",
    "administrarea": "administrare",
    "administrări": "administrare",
    "administrării": "administrare",
    "administrările": "administrare",
    "administrata": "administrat",
    "administrată": "administrat",
    "administrate": "administrat",
    "administratei": "administrat",
    "administratele": "administrat",
    "administratelor": "administrat",
    "administrați": "administrat",
    "administrații": "administrat",
    "administraților": "administrat",
    "administratul": "administrat",
    "administratului": "administrat",
    "administrația": "administrație",
    "administrației": "administrație",
    "administrații": "administrație",
    "administrațiile": "administrație",
    "administrațiilor": "administrație",
    "administrativa": "administrativ",
    "administrativă": "administrativ",
    "administrative": "administrativ",
    "administrativei": "administrativ",
    "administrativele": "administrativ",
    "administrativelor": "administrativ",
    "administrativi": "administrativ",
    "administrativii": "administrativ",
    "administrativilor": "administrativ",
    "administrativul": "administrativ",
    "administrativului": "administrativ",
    "adtiv": "administrativ",
    "administratoarea": "administratoare",
    "administratoarei": "administratoare",
    "administratoarele": "administratoare",
    "administratoarelor": "administratoare",
    "administratori": "administrator",
    "administratorii": "administrator",
    "administratorilor": "administrator",
    "administratorul": "administrator",
    "administratorului": "administrator",
    "admir": "admira",
    "admiră": "admira",
    "admirai": "admira",
    "admiram": "admira",
    "admirăm": "admira",
    "admirând": "admira",
    "admirându": "admira",
    "admirară": "admira",
    "admirarăm": "admira",
    "admirarăți": "admira",
    "admirase": "admira",
    "admirasem": "admira",
    "admiraseră": "admira",
    "admiraserăm": "admira",
    "admiraserăți": "admira",
    "admiraseși": "admira",
    "admirași": "admira",
    "admirat": "admira",
    "admirați": "admira",
    "admiratu": "admira",
    "admirau": "admira",
    "admire": "admira",
    "admiri": "admira",
    "neadmirând": "admira",
    "neadmirându": "admira",
    "nemaiadmirând": "admira",
    "nemaiadmirându": "admira",
    "admirabilă": "admirabil",
    "admirabile": "admirabil",
    "admirabili": "admirabil",
    "admirarea": "admirare",
    "admirări": "admirare",
    "admirării": "admirare",
    "admirările": "admirare",
    "admirata": "admirat",
    "admirată": "admirat",
    "admirate": "admirat",
    "admiratei": "admirat",
    "admiratele": "admirat",
    "admiratelor": "admirat",
    "admirați": "admirat",
    "admirații": "admirat",
    "admiraților": "admirat",
    "admiratul": "admirat",
    "admiratului": "admirat",
    "admirația": "admirație",
    "admirației": "admirație",
    "admirații": "admirație",
    "admirațiile": "admirație",
    "admirațiilor": "admirație",
    "admirativa": "admirativ",
    "admirativă": "admirativ",
    "admirative": "admirativ",
    "admirativei": "admirativ",
    "admirativele": "admirativ",
    "admirativelor": "admirativ",
    "admirativi": "admirativ",
    "admirativii": "admirativ",
    "admirativilor": "admirativ",
    "admirativul": "admirativ",
    "admirativului": "admirativ",
    "admiratoarea": "admiratoare",
    "admiratoarei": "admiratoare",
    "admiratoarele": "admiratoare",
    "admiratoarelor": "admiratoare",
    "admiratoare": "admirator",
    "admiratoarea": "admirator",
    "admiratoarei": "admirator",
    "admiratoarele": "admirator",
    "admiratoarelor": "admirator",
    "admiratori": "admirator",
    "admiratorii": "admirator",
    "admiratorilor": "admirator",
    "admiratorul": "admirator",
    "admiratorului": "admirator",
    "admisa": "admis",
    "admisă": "admis",
    "admise": "admis",
    "admisei": "admis",
    "admisele": "admis",
    "admiselor": "admis",
    "admiși": "admis",
    "admișii": "admis",
    "admișilor": "admis",
    "admisul": "admis",
    "admisului": "admis",
    "admisa": "admisă",
    "admise": "admisă",
    "admisei": "admisă",
    "admisele": "admisă",
    "admiselor": "admisă",
    "admisibila": "admisibil",
    "admisibilă": "admisibil",
    "admisibile": "admisibil",
    "admisibilei": "admisibil",
    "admisibilele": "admisibil",
    "admisibilelor": "admisibil",
    "admisibili": "admisibil",
    "admisibilii": "admisibil",
    "admisibililor": "admisibil",
    "admisibilul": "admisibil",
    "admisibilului": "admisibil",
    "admis": "admite",
    "admise": "admite",
    "admisei": "admite",
    "admiseră": "admite",
    "admiserăm": "admite",
    "admiserăți": "admite",
    "admisese": "admite",
    "admisesem": "admite",
    "admiseseră": "admite",
    "admiseserăm": "admite",
    "admiseserăți": "admite",
    "admiseseși": "admite",
    "admiseși": "admite",
    "admisu": "admite",
    "admit": "admite",
    "admită": "admite",
    "admițând": "admite",
    "admițându": "admite",
    "admitea": "admite",
    "admiteai": "admite",
    "admiteam": "admite",
    "admiteați": "admite",
    "admiteau": "admite",
    "admitem": "admite",
    "admiteți": "admite",
    "admiți": "admite",
    "neadmițând": "admite",
    "neadmițându": "admite",
    "nemaiadmițând": "admite",
    "nemaiadmițându": "admite",
    "admiterea": "admitere",
    "admiteri": "admitere",
    "admiterii": "admitere",
    "admiterile": "admitere",
    "admonestă": "admonesta",
    "admonestai": "admonesta",
    "admonestam": "admonesta",
    "admonestăm": "admonesta",
    "admonestând": "admonesta",
    "admonestându": "admonesta",
    "admonestară": "admonesta",
    "admonestarăm": "admonesta",
    "admonestarăți": "admonesta",
    "admonestase": "admonesta",
    "admonestasem": "admonesta",
    "admonestaseră": "admonesta",
    "admonestaserăm": "admonesta",
    "admonestaserăți": "admonesta",
    "admonestaseși": "admonesta",
    "admonestași": "admonesta",
    "admonestat": "admonesta",
    "admonestați": "admonesta",
    "admonestatu": "admonesta",
    "admonestau": "admonesta",
    "admonestează": "admonesta",
    "admonestez": "admonesta",
    "admonesteze": "admonesta",
    "admonestezi": "admonesta",
    "neadmonestând": "admonesta",
    "neadmonestându": "admonesta",
    "nemaiadmonestând": "admonesta",
    "nemaiadmonestându": "admonesta",
    "admonestarea": "admonestare",
    "admonestări": "admonestare",
    "admonestării": "admonestare",
    "admonestările": "admonestare",
    "admonestata": "admonestat",
    "admonestată": "admonestat",
    "admonestate": "admonestat",
    "admonestatei": "admonestat",
    "admonestatele": "admonestat",
    "admonestatelor": "admonestat",
    "admonestați": "admonestat",
    "admonestații": "admonestat",
    "admonestaților": "admonestat",
    "admonestatul": "admonestat",
    "admonestatului": "admonestat",
    "adnotă": "adnota",
    "adnotai": "adnota",
    "adnotam": "adnota",
    "adnotăm": "adnota",
    "adnotând": "adnota",
    "adnotându": "adnota",
    "adnotară": "adnota",
    "adnotarăm": "adnota",
    "adnotarăți": "adnota",
    "adnotase": "adnota",
    "adnotasem": "adnota",
    "adnotaseră": "adnota",
    "adnotaserăm": "adnota",
    "adnotaserăți": "adnota",
    "adnotaseși": "adnota",
    "adnotași": "adnota",
    "adnotat": "adnota",
    "adnotați": "adnota",
    "adnotatu": "adnota",
    "adnotau": "adnota",
    "adnotează": "adnota",
    "adnotez": "adnota",
    "adnoteze": "adnota",
    "adnotezi": "adnota",
    "neadnotând": "adnota",
    "neadnotându": "adnota",
    "nemaiadnotând": "adnota",
    "nemaiadnotându": "adnota",
    "adnotarea": "adnotare",
    "adnotări": "adnotare",
    "adnotării": "adnotare",
    "adnotările": "adnotare",
    "adnotata": "adnotat",
    "adnotată": "adnotat",
    "adnotate": "adnotat",
    "adnotatei": "adnotat",
    "adnotatele": "adnotat",
    "adnotatelor": "adnotat",
    "adnotați": "adnotat",
    "adnotații": "adnotat",
    "adnotaților": "adnotat",
    "adnotatul": "adnotat",
    "adnotatului": "adnotat",
    "adolescenta": "adolescent",
    "adolescentă": "adolescent",
    "adolescente": "adolescent",
    "adolescentei": "adolescent",
    "adolescentele": "adolescent",
    "adolescentelor": "adolescent",
    "adolescenți": "adolescent",
    "adolescenții": "adolescent",
    "adolescenților": "adolescent",
    "adolescentul": "adolescent",
    "adolescentului": "adolescent",
    "adolescenta": "adolescentă",
    "adolescente": "adolescentă",
    "adolescentei": "adolescentă",
    "adolescentele": "adolescentă",
    "adolescentelor": "adolescentă",
    "adolescența": "adolescență",
    "adolescențe": "adolescență",
    "adolescenței": "adolescență",
    "adolescențele": "adolescență",
    "adolescențelor": "adolescență",
    "adonice": "adonic",
    "adonicele": "adonic",
    "adonicelor": "adonic",
    "adonicul": "adonic",
    "adonicului": "adonic",
    "adopt": "adopta",
    "adoptă": "adopta",
    "adoptai": "adopta",
    "adoptam": "adopta",
    "adoptăm": "adopta",
    "adoptând": "adopta",
    "adoptându": "adopta",
    "adoptară": "adopta",
    "adoptarăm": "adopta",
    "adoptarăți": "adopta",
    "adoptase": "adopta",
    "adoptasem": "adopta",
    "adoptaseră": "adopta",
    "adoptaserăm": "adopta",
    "adoptaserăți": "adopta",
    "adoptaseși": "adopta",
    "adoptași": "adopta",
    "adoptat": "adopta",
    "adoptați": "adopta",
    "adoptatu": "adopta",
    "adoptau": "adopta",
    "adopte": "adopta",
    "adopți": "adopta",
    "neadoptând": "adopta",
    "neadoptându": "adopta",
    "nemaiadoptând": "adopta",
    "nemaiadoptându": "adopta",
    "adoptarea": "adoptare",
    "adoptări": "adoptare",
    "adoptării": "adoptare",
    "adoptările": "adoptare",
    "adoptata": "adoptat",
    "adoptată": "adoptat",
    "adoptate": "adoptat",
    "adoptatei": "adoptat",
    "adoptatele": "adoptat",
    "adoptatelor": "adoptat",
    "adoptați": "adoptat",
    "adoptații": "adoptat",
    "adoptaților": "adoptat",
    "adoptatul": "adoptat",
    "adoptatului": "adoptat",
    "adoptata": "adoptată",
    "adoptate": "adoptată",
    "adoptatei": "adoptată",
    "adoptatele": "adoptată",
    "adoptatelor": "adoptată",
    "adopția": "adopție",
    "adopției": "adopție",
    "adopții": "adopție",
    "adopțiile": "adopție",
    "adopțiilor": "adopție",
    "adopțiunea": "adopțiune",
    "adopțiuni": "adopțiune",
    "adopțiunii": "adopțiune",
    "adopțiunile": "adopțiune",
    "adopțiunilor": "adopțiune",
    "adoptiva": "adoptiv",
    "adoptivă": "adoptiv",
    "adoptive": "adoptiv",
    "adoptivei": "adoptiv",
    "adoptivele": "adoptiv",
    "adoptivelor": "adoptiv",
    "adoptivi": "adoptiv",
    "adoptivii": "adoptiv",
    "adoptivilor": "adoptiv",
    "adoptivul": "adoptiv",
    "adoptivului": "adoptiv",
    "ador": "adora",
    "adoră": "adora",
    "adorai": "adora",
    "adoram": "adora",
    "adorăm": "adora",
    "adorând": "adora",
    "adorându": "adora",
    "adorară": "adora",
    "adorarăm": "adora",
    "adorarăți": "adora",
    "adorase": "adora",
    "adorasem": "adora",
    "adoraseră": "adora",
    "adoraserăm": "adora",
    "adoraserăți": "adora",
    "adoraseși": "adora",
    "adorași": "adora",
    "adorat": "adora",
    "adorați": "adora",
    "adoratu": "adora",
    "adorau": "adora",
    "adore": "adora",
    "adori": "adora",
    "neadorând": "adora",
    "neadorându": "adora",
    "nemaiadorând": "adora",
    "nemaiadorându": "adora",
    "adorabilă": "adorabil",
    "adorabile": "adorabil",
    "adorabili": "adorabil",
    "adorarea": "adorare",
    "adorări": "adorare",
    "adorării": "adorare",
    "adorările": "adorare",
    "adorata": "adorat",
    "adorată": "adorat",
    "adorate": "adorat",
    "adoratei": "adorat",
    "adoratele": "adorat",
    "adoratelor": "adorat",
    "adorați": "adorat",
    "adorații": "adorat",
    "adoraților": "adorat",
    "adoratul": "adorat",
    "adoratului": "adorat",
    "adorația": "adorație",
    "adorației": "adorație",
    "adorații": "adorație",
    "adorațiile": "adorație",
    "adorațiilor": "adorație",
    "adoratoarea": "adoratoare",
    "adoratoarei": "adoratoare",
    "adoratoarele": "adoratoare",
    "adoratoarelor": "adoratoare",
    "adoratori": "adorator",
    "adoratorii": "adorator",
    "adoratorilor": "adorator",
    "adoratorul": "adorator",
    "adoratorului": "adorator",
    "adoarmă": "adormi",
    "adoarme": "adormi",
    "adorm": "adormi",
    "adormea": "adormi",
    "adormeai": "adormi",
    "adormeam": "adormi",
    "adormeați": "adormi",
    "adormeau": "adormi",
    "adormii": "adormi",
    "adormim": "adormi",
    "adormind": "adormi",
    "adormindu": "adormi",
    "adormiră": "adormi",
    "adormirăm": "adormi",
    "adormirăți": "adormi",
    "adormise": "adormi",
    "adormisem": "adormi",
    "adormiseră": "adormi",
    "adormiserăm": "adormi",
    "adormiserăți": "adormi",
    "adormiseși": "adormi",
    "adormiși": "adormi",
    "adormit": "adormi",
    "adormiți": "adormi",
    "adormitu": "adormi",
    "neadormind": "adormi",
    "neadormindu": "adormi",
    "nemaiadormind": "adormi",
    "nemaiadormindu": "adormi",
    "adormirea": "adormire",
    "adormiri": "adormire",
    "adormirii": "adormire",
    "adormirile": "adormire",
    "adormita": "adormit",
    "adormită": "adormit",
    "adormite": "adormit",
    "adormitei": "adormit",
    "adormitele": "adormit",
    "adormitelor": "adormit",
    "adormiți": "adormit",
    "adormiții": "adormit",
    "adormiților": "adormit",
    "adormitul": "adormit",
    "adormitului": "adormit",
    "adormita": "adormită",
    "adormite": "adormită",
    "adormitei": "adormită",
    "adormitele": "adormită",
    "adormitelor": "adormită",
    "adormitoarea": "adormitoare",
    "adormitoarei": "adormitoare",
    "adormitoarele": "adormitoare",
    "adormitoarelor": "adormitoare",
    "adormitori": "adormitor",
    "adormitorii": "adormitor",
    "adormitorilor": "adormitor",
    "adormitorul": "adormitor",
    "adormitorului": "adormitor",
    "Adrasteii": "Adrasteia",
    "adr.": "adresa",
    "adresă": "adresa",
    "adresai": "adresa",
    "adresam": "adresa",
    "adresăm": "adresa",
    "adresând": "adresa",
    "adresându": "adresa",
    "adresară": "adresa",
    "adresarăm": "adresa",
    "adresarăți": "adresa",
    "adresase": "adresa",
    "adresasem": "adresa",
    "adresaseră": "adresa",
    "adresaserăm": "adresa",
    "adresaserăți": "adresa",
    "adresaseși": "adresa",
    "adresași": "adresa",
    "adresat": "adresa",
    "adresați": "adresa",
    "adresatu": "adresa",
    "adresau": "adresa",
    "adresează": "adresa",
    "adresez": "adresa",
    "adreseze": "adresa",
    "adresezi": "adresa",
    "neadresând": "adresa",
    "neadresându": "adresa",
    "nemaiadresând": "adresa",
    "nemaiadresându": "adresa",
    "adresa": "adresă",
    "adrese": "adresă",
    "adresei": "adresă",
    "adresele": "adresă",
    "adreselor": "adresă",
    "adresanți": "adresant",
    "adresanții": "adresant",
    "adresanților": "adresant",
    "adresantul": "adresant",
    "adresantului": "adresant",
    "adresanta": "adresantă",
    "adresante": "adresantă",
    "adresantei": "adresantă",
    "adresantele": "adresantă",
    "adresantelor": "adresantă",
    "adresarea": "adresare",
    "adresări": "adresare",
    "adresării": "adresare",
    "adresările": "adresare",
    "adresata": "adresat",
    "adresată": "adresat",
    "adresate": "adresat",
    "adresatei": "adresat",
    "adresatele": "adresat",
    "adresatelor": "adresat",
    "adresați": "adresat",
    "adresații": "adresat",
    "adresaților": "adresat",
    "adresatul": "adresat",
    "adresatului": "adresat",
    "Adriană": "Adriana",
    "Adriane": "Adriana",
    "Adrianei": "Adriana",
    "aducătoare": "aducător",
    "aducătoarea": "aducător",
    "aducătoarei": "aducător",
    "aducătoarele": "aducător",
    "aducătoarelor": "aducător",
    "aducători": "aducător",
    "aducătorii": "aducător",
    "aducătorilor": "aducător",
    "aducătorul": "aducător",
    "aducătorului": "aducător",
    "adu": "aduce",
    "aduc": "aduce",
    "aducă": "aduce",
    "aducând": "aduce",
    "aducându": "aduce",
    "aducea": "aduce",
    "aduceai": "aduce",
    "aduceam": "aduce",
    "aduceați": "aduce",
    "aduceau": "aduce",
    "aducem": "aduce",
    "aduceți": "aduce",
    "aduci": "aduce",
    "adus": "aduce",
    "aduse": "aduce",
    "adusei": "aduce",
    "aduseră": "aduce",
    "aduserăm": "aduce",
    "aduserăți": "aduce",
    "adusese": "aduce",
    "adusesem": "aduce",
    "aduseseră": "aduce",
    "aduseserăm": "aduce",
    "aduseserăți": "aduce",
    "aduseseși": "aduce",
    "aduseși": "aduce",
    "adusu": "aduce",
    "neaducând": "aduce",
    "neaducându": "aduce",
    "nemaiaducând": "aduce",
    "nemaiaducându": "aduce",
    "aducerea": "aducere",
    "aduceri": "aducere",
    "aducerii": "aducere",
    "aducerile": "aducere",
    "adulă": "adula",
    "adulai": "adula",
    "adulam": "adula",
    "adulăm": "adula",
    "adulând": "adula",
    "adulându": "adula",
    "adulară": "adula",
    "adularăm": "adula",
    "adularăți": "adula",
    "adulase": "adula",
    "adulasem": "adula",
    "adulaseră": "adula",
    "adulaserăm": "adula",
    "adulaserăți": "adula",
    "adulaseși": "adula",
    "adulași": "adula",
    "adulat": "adula",
    "adulați": "adula",
    "adulatu": "adula",
    "adulau": "adula",
    "adulează": "adula",
    "adulez": "adula",
    "aduleze": "adula",
    "adulezi": "adula",
    "neadulând": "adula",
    "neadulându": "adula",
    "nemaiadulând": "adula",
    "nemaiadulându": "adula",
    "adularea": "adulare",
    "adulări": "adulare",
    "adulării": "adulare",
    "adulările": "adulare",
    "adulata": "adulat",
    "adulată": "adulat",
    "adulate": "adulat",
    "adulatei": "adulat",
    "adulatele": "adulat",
    "adulatelor": "adulat",
    "adulați": "adulat",
    "adulații": "adulat",
    "adulaților": "adulat",
    "adulatul": "adulat",
    "adulatului": "adulat",
    "adulata": "adulată",
    "adulate": "adulată",
    "adulatei": "adulată",
    "adulatele": "adulată",
    "adulatelor": "adulată",
    "adulatoarea": "adulatoare",
    "adulatoarei": "adulatoare",
    "adulatoarele": "adulatoare",
    "adulatoarelor": "adulatoare",
    "adulatoare": "adulator",
    "adulatoarea": "adulator",
    "adulatoarei": "adulator",
    "adulatoarele": "adulator",
    "adulatoarelor": "adulator",
    "adulatori": "adulator",
    "adulatorii": "adulator",
    "adulatorilor": "adulator",
    "adulatorul": "adulator",
    "adulatorului": "adulator",
    "adulmec": "adulmeca",
    "adulmecă": "adulmeca",
    "adulmecai": "adulmeca",
    "adulmecam": "adulmeca",
    "adulmecăm": "adulmeca",
    "adulmecând": "adulmeca",
    "adulmecându": "adulmeca",
    "adulmecară": "adulmeca",
    "adulmecarăm": "adulmeca",
    "adulmecarăți": "adulmeca",
    "adulmecase": "adulmeca",
    "adulmecasem": "adulmeca",
    "adulmecaseră": "adulmeca",
    "adulmecaserăm": "adulmeca",
    "adulmecaserăți": "adulmeca",
    "adulmecaseși": "adulmeca",
    "adulmecași": "adulmeca",
    "adulmecat": "adulmeca",
    "adulmecați": "adulmeca",
    "adulmecatu": "adulmeca",
    "adulmecau": "adulmeca",
    "adulmece": "adulmeca",
    "adulmeci": "adulmeca",
    "neadulmecând": "adulmeca",
    "neadulmecându": "adulmeca",
    "nemaiadulmecând": "adulmeca",
    "nemaiadulmecându": "adulmeca",
    "adulmecarea": "adulmecare",
    "adulmecări": "adulmecare",
    "adulmecării": "adulmecare",
    "adulmecările": "adulmecare",
    "adulmecata": "adulmecat",
    "adulmecată": "adulmecat",
    "adulmecate": "adulmecat",
    "adulmecatei": "adulmecat",
    "adulmecatele": "adulmecat",
    "adulmecatelor": "adulmecat",
    "adulmecați": "adulmecat",
    "adulmecații": "adulmecat",
    "adulmecaților": "adulmecat",
    "adulmecatul": "adulmecat",
    "adulmecatului": "adulmecat",
    "adulmecătoare": "adulmecător",
    "adulmecătoarea": "adulmecător",
    "adulmecătoarei": "adulmecător",
    "adulmecătoarele": "adulmecător",
    "adulmecătoarelor": "adulmecător",
    "adulmecători": "adulmecător",
    "adulmecătorii": "adulmecător",
    "adulmecătorilor": "adulmecător",
    "adulmecătorul": "adulmecător",
    "adulmecătorului": "adulmecător",
    "adulta": "adult",
    "adultă": "adult",
    "adulte": "adult",
    "adultei": "adult",
    "adultele": "adult",
    "adultelor": "adult",
    "adulți": "adult",
    "adulții": "adult",
    "adulților": "adult",
    "adultul": "adult",
    "adultului": "adult",
    "adulta": "adultă",
    "adulte": "adultă",
    "adultei": "adultă",
    "adultele": "adultă",
    "adultelor": "adultă",
    "adultera": "adulter",
    "adulteră": "adulter",
    "adultere": "adulter",
    "adulterei": "adulter",
    "adulterele": "adulter",
    "adulterelor": "adulter",
    "adulteri": "adulter",
    "adulterii": "adulter",
    "adulterilor": "adulter",
    "adulterul": "adulter",
    "adulterului": "adulter",
    "adulterina": "adulterin",
    "adulterină": "adulterin",
    "adulterine": "adulterin",
    "adulterinei": "adulterin",
    "adulterinele": "adulterin",
    "adulterinelor": "adulterin",
    "adulterini": "adulterin",
    "adulterinii": "adulterin",
    "adulterinilor": "adulterin",
    "adulterinul": "adulterin",
    "adulterinului": "adulterin",
    "adumbrea": "adumbri",
    "adumbreai": "adumbri",
    "adumbream": "adumbri",
    "adumbrească": "adumbri",
    "adumbreați": "adumbri",
    "adumbreau": "adumbri",
    "adumbresc": "adumbri",
    "adumbrește": "adumbri",
    "adumbrești": "adumbri",
    "adumbrii": "adumbri",
    "adumbrim": "adumbri",
    "adumbrind": "adumbri",
    "adumbrindu": "adumbri",
    "adumbriră": "adumbri",
    "adumbrirăm": "adumbri",
    "adumbrirăți": "adumbri",
    "adumbrise": "adumbri",
    "adumbrisem": "adumbri",
    "adumbriseră": "adumbri",
    "adumbriserăm": "adumbri",
    "adumbriserăți": "adumbri",
    "adumbriseși": "adumbri",
    "adumbriși": "adumbri",
    "adumbrit": "adumbri",
    "adumbriți": "adumbri",
    "adumbritu": "adumbri",
    "neadumbrind": "adumbri",
    "neadumbrindu": "adumbri",
    "nemaiadumbrind": "adumbri",
    "nemaiadumbrindu": "adumbri",
    "adumbrirea": "adumbrire",
    "adumbriri": "adumbrire",
    "adumbririi": "adumbrire",
    "adumbririle": "adumbrire",
    "adumbrita": "adumbrit",
    "adumbrită": "adumbrit",
    "adumbrite": "adumbrit",
    "adumbritei": "adumbrit",
    "adumbritele": "adumbrit",
    "adumbritelor": "adumbrit",
    "adumbriți": "adumbrit",
    "adumbriții": "adumbrit",
    "adumbriților": "adumbrit",
    "adumbritul": "adumbrit",
    "adumbritului": "adumbrit",
    "adun": "aduna",
    "adună": "aduna",
    "adunai": "aduna",
    "adunam": "aduna",
    "adunăm": "aduna",
    "adunând": "aduna",
    "adunându": "aduna",
    "adunară": "aduna",
    "adunarăm": "aduna",
    "adunarăți": "aduna",
    "adunase": "aduna",
    "adunasem": "aduna",
    "adunaseră": "aduna",
    "adunaserăm": "aduna",
    "adunaserăți": "aduna",
    "adunaseși": "aduna",
    "adunași": "aduna",
    "adunat": "aduna",
    "adunați": "aduna",
    "adunatu": "aduna",
    "adunau": "aduna",
    "adune": "aduna",
    "aduni": "aduna",
    "neadunând": "aduna",
    "neadunându": "aduna",
    "nemaiadunând": "aduna",
    "nemaiadunându": "aduna",
    "adunarea": "adunare",
    "adunări": "adunare",
    "adunării": "adunare",
    "adunările": "adunare",
    "adunărilor": "adunare",
    "adunata": "adunat",
    "adunată": "adunat",
    "adunate": "adunat",
    "adunatei": "adunat",
    "adunatele": "adunat",
    "adunatelor": "adunat",
    "adunați": "adunat",
    "adunații": "adunat",
    "adunaților": "adunat",
    "adunatul": "adunat",
    "adunatului": "adunat",
    "adunătoarea": "adunătoare",
    "adunătoarei": "adunătoare",
    "adunătoarele": "adunătoare",
    "adunătoarelor": "adunătoare",
    "adunătoare": "adunător",
    "adunătoarea": "adunător",
    "adunătoarei": "adunător",
    "adunătoarele": "adunător",
    "adunătoarelor": "adunător",
    "adunători": "adunător",
    "adunătorii": "adunător",
    "adunătorilor": "adunător",
    "adunătorul": "adunător",
    "adunătorului": "adunător",
    "adunătura": "adunătură",
    "adunături": "adunătură",
    "adunăturii": "adunătură",
    "adunăturile": "adunătură",
    "adunăturilor": "adunătură",
    "adusa": "adus",
    "adusă": "adus",
    "aduse": "adus",
    "adusei": "adus",
    "adusele": "adus",
    "aduselor": "adus",
    "aduși": "adus",
    "adușii": "adus",
    "adușilor": "adus",
    "adusul": "adus",
    "adusului": "adus",
    "adventista": "adventist",
    "adventistă": "adventist",
    "adventiste": "adventist",
    "adventistei": "adventist",
    "adventistele": "adventist",
    "adventistelor": "adventist",
    "adventiști": "adventist",
    "adventiștii": "adventist",
    "adventiștilor": "adventist",
    "adventistul": "adventist",
    "adventistului": "adventist",
    "adventiva": "adventiv",
    "adventivă": "adventiv",
    "adventive": "adventiv",
    "adventivei": "adventiv",
    "adventivele": "adventiv",
    "adventivelor": "adventiv",
    "adventivi": "adventiv",
    "adventivii": "adventiv",
    "adventivilor": "adventiv",
    "adventivul": "adventiv",
    "adventivului": "adventiv",
    "adv.": "adverb",
    "adverbe": "adverb",
    "adverbele": "adverb",
    "adverbelor": "adverb",
    "adverbul": "adverb",
    "adverbului": "adverb",
    "adverbiala": "adverbial",
    "adverbială": "adverbial",
    "adverbiale": "adverbial",
    "adverbialei": "adverbial",
    "adverbialele": "adverbial",
    "adverbialelor": "adverbial",
    "adverbiali": "adverbial",
    "adverbialii": "adverbial",
    "adverbialilor": "adverbial",
    "adverbialul": "adverbial",
    "adverbialului": "adverbial",
    "adversă": "advers",
    "adverse": "advers",
    "adverși": "advers",
    "adversari": "adversar",
    "adversarii": "adversar",
    "adversarilor": "adversar",
    "adversarul": "adversar",
    "adversarului": "adversar",
    "adversara": "adversară",
    "adversare": "adversară",
    "adversarei": "adversară",
    "adversarele": "adversară",
    "adversarelor": "adversară",
    "adversativa": "adversativ",
    "adversativă": "adversativ",
    "adversative": "adversativ",
    "adversativei": "adversativ",
    "adversativele": "adversativ",
    "adversativelor": "adversativ",
    "adversativi": "adversativ",
    "adversativii": "adversativ",
    "adversativilor": "adversativ",
    "adversativul": "adversativ",
    "adversativului": "adversativ",
    "aedul": "aed",
    "aedului": "aed",
    "aezi": "aed",
    "aezii": "aed",
    "aezilor": "aed",
    "aere": "aer",
    "aerele": "aer",
    "aerelor": "aer",
    "aerul": "aer",
    "aerului": "aer",
    "aerata": "aerat",
    "aerată": "aerat",
    "aerate": "aerat",
    "aeratei": "aerat",
    "aeratele": "aerat",
    "aeratelor": "aerat",
    "aerați": "aerat",
    "aerații": "aerat",
    "aeraților": "aerat",
    "aeratul": "aerat",
    "aeratului": "aerat",
    "aeriana": "aerian",
    "aeriană": "aerian",
    "aerianul": "aerian",
    "aerianului": "aerian",
    "aeriene": "aerian",
    "aerienei": "aerian",
    "aerienele": "aerian",
    "aerienelor": "aerian",
    "aerieni": "aerian",
    "aerienii": "aerian",
    "aerienilor": "aerian",
    "aeriforma": "aeriform",
    "aeriformă": "aeriform",
    "aeriforme": "aeriform",
    "aeriformei": "aeriform",
    "aeriformele": "aeriform",
    "aeriformelor": "aeriform",
    "aeriformi": "aeriform",
    "aeriformii": "aeriform",
    "aeriformilor": "aeriform",
    "aeriformul": "aeriform",
    "aeriformului": "aeriform",
    "aerisirea": "aerisire",
    "aerisiri": "aerisire",
    "aerisirii": "aerisire",
    "aerisirile": "aerisire",
    "aerisirilor": "aerisire",
    "aeroba": "aerob",
    "aerobă": "aerob",
    "aerobe": "aerob",
    "aerobei": "aerob",
    "aerobele": "aerob",
    "aerobelor": "aerob",
    "aerobi": "aerob",
    "aerobii": "aerob",
    "aerobilor": "aerob",
    "aerobul": "aerob",
    "aerobului": "aerob",
    "aerobaza": "aerobază",
    "aerobaze": "aerobază",
    "aerobazei": "aerobază",
    "aerobazele": "aerobază",
    "aerobazelor": "aerobază",
    "aerobiotica": "aerobiotic",
    "aerobiotică": "aerobiotic",
    "aerobiotice": "aerobiotic",
    "aerobioticei": "aerobiotic",
    "aerobioticele": "aerobiotic",
    "aerobioticelor": "aerobiotic",
    "aerobiotici": "aerobiotic",
    "aerobioticii": "aerobiotic",
    "aerobioticilor": "aerobiotic",
    "aerobioticul": "aerobiotic",
    "aerobioticului": "aerobiotic",
    "aerodina": "aerodină",
    "aerodine": "aerodină",
    "aerodinei": "aerodină",
    "aerodinele": "aerodină",
    "aerodinelor": "aerodină",
    "aerodinamica": "aerodinamic",
    "aerodinamică": "aerodinamic",
    "aerodinamice": "aerodinamic",
    "aerodinamicei": "aerodinamic",
    "aerodinamicele": "aerodinamic",
    "aerodinamicelor": "aerodinamic",
    "aerodinamici": "aerodinamic",
    "aerodinamicii": "aerodinamic",
    "aerodinamicilor": "aerodinamic",
    "aerodinamicul": "aerodinamic",
    "aerodinamicului": "aerodinamic",
    "aerodinamica": "aerodinamică",
    "aerodinamici": "aerodinamică",
    "aerodinamicii": "aerodinamică",
    "aerodinamicile": "aerodinamică",
    "aerodinamicilor": "aerodinamică",
    "aerodromul": "aerodrom",
    "aerodromului": "aerodrom",
    "aerodromuri": "aerodrom",
    "aerodromurile": "aerodrom",
    "aerodromurilor": "aerodrom",
    "aeroliți": "aerolit",
    "aeroliții": "aerolit",
    "aeroliților": "aerolit",
    "aerolitul": "aerolit",
    "aerolitului": "aerolit",
    "aeromodele": "aeromodel",
    "aeromodelele": "aeromodel",
    "aeromodelelor": "aeromodel",
    "aeromodelul": "aeromodel",
    "aeromodelului": "aeromodel",
    "aeromodelismul": "aeromodelism",
    "aeromodelismului": "aeromodelism",
    "aeronauți": "aeronaut",
    "aeronauții": "aeronaut",
    "aeronauților": "aeronaut",
    "aeronautul": "aeronaut",
    "aeronautului": "aeronaut",
    "aeronautica": "aeronautic",
    "aeronautică": "aeronautic",
    "aeronautice": "aeronautic",
    "aeronauticei": "aeronautic",
    "aeronauticele": "aeronautic",
    "aeronauticelor": "aeronautic",
    "aeronautici": "aeronautic",
    "aeronauticii": "aeronautic",
    "aeronauticilor": "aeronautic",
    "aeronauticul": "aeronautic",
    "aeronauticului": "aeronautic",
    "aeronautica": "aeronautică",
    "aeronauticele": "aeronautică",
    "aeronautici": "aeronautică",
    "aeronauticii": "aeronautică",
    "aeronauticilor": "aeronautică",
    "aeroplane": "aeroplan",
    "aeroplanele": "aeroplan",
    "aeroplanelor": "aeroplan",
    "aeroplanul": "aeroplan",
    "aeroplanului": "aeroplan",
    "aeroportul": "aeroport",
    "aeroportului": "aeroport",
    "aeroporturi": "aeroport",
    "aeroporturile": "aeroport",
    "aeroporturilor": "aeroport",
    "aeropurtata": "aeropurtat",
    "aeropurtată": "aeropurtat",
    "aeropurtate": "aeropurtat",
    "aeropurtatei": "aeropurtat",
    "aeropurtatele": "aeropurtat",
    "aeropurtatelor": "aeropurtat",
    "aeropurtați": "aeropurtat",
    "aeropurtații": "aeropurtat",
    "aeropurtaților": "aeropurtat",
    "aeropurtatul": "aeropurtat",
    "aeropurtatului": "aeropurtat",
    "aeroasa": "aeros",
    "aeroasă": "aeros",
    "aeroase": "aeros",
    "aeroasei": "aeros",
    "aeroasele": "aeros",
    "aeroaselor": "aeros",
    "aeroși": "aeros",
    "aeroșii": "aeros",
    "aeroșilor": "aeros",
    "aerosul": "aeros",
    "aerosului": "aeros",
    "aerosoli": "aerosol",
    "aerosolii": "aerosol",
    "aerosolilor": "aerosol",
    "aerosolul": "aerosol",
    "aerosolului": "aerosol",
    "aerostate": "aerostat",
    "aerostatele": "aerostat",
    "aerostatelor": "aerostat",
    "aerostatul": "aerostat",
    "aerostatului": "aerostat",
    "aerostatica": "aerostatic",
    "aerostatică": "aerostatic",
    "aerostatice": "aerostatic",
    "aerostaticei": "aerostatic",
    "aerostaticele": "aerostatic",
    "aerostaticelor": "aerostatic",
    "aerostatici": "aerostatic",
    "aerostaticii": "aerostatic",
    "aerostaticilor": "aerostatic",
    "aerostaticul": "aerostatic",
    "aerostaticului": "aerostatic",
    "aerostatica": "aerostatică",
    "aerostaticele": "aerostatică",
    "aerostatici": "aerostatică",
    "aerostaticii": "aerostatică",
    "aerostaticilor": "aerostatică",
    "afabila": "afabil",
    "afabilă": "afabil",
    "afabile": "afabil",
    "afabilei": "afabil",
    "afabilele": "afabil",
    "afabilelor": "afabil",
    "afabili": "afabil",
    "afabilii": "afabil",
    "afabililor": "afabil",
    "afabilul": "afabil",
    "afabilului": "afabil",
    "afacerea": "afacere",
    "afaceri": "afacere",
    "afacerii": "afacere",
    "afacerile": "afacere",
    "afacerilor": "afacere",
    "afaceriști": "afacerist",
    "afaceriștii": "afacerist",
    "afaceriștilor": "afacerist",
    "afaceristul": "afacerist",
    "afaceristului": "afacerist",
    "afacerista": "afaceristă",
    "afaceriste": "afaceristă",
    "afaceristei": "afaceristă",
    "afaceristele": "afaceristă",
    "afaceristelor": "afaceristă",
    "afână": "afâna",
    "afânai": "afâna",
    "afânam": "afâna",
    "afânăm": "afâna",
    "afânând": "afâna",
    "afânându": "afâna",
    "afânară": "afâna",
    "afânarăm": "afâna",
    "afânarăți": "afâna",
    "afânase": "afâna",
    "afânasem": "afâna",
    "afânaseră": "afâna",
    "afânaserăm": "afâna",
    "afânaserăți": "afâna",
    "afânaseși": "afâna",
    "afânași": "afâna",
    "afânat": "afâna",
    "afânați": "afâna",
    "afânatu": "afâna",
    "afânau": "afâna",
    "afânează": "afâna",
    "afânez": "afâna",
    "afâneze": "afâna",
    "afânezi": "afâna",
    "neafânând": "afâna",
    "neafânându": "afâna",
    "nemaiafânând": "afâna",
    "nemaiafânându": "afâna",
    "afânarea": "afânare",
    "afânări": "afânare",
    "afânării": "afânare",
    "afânările": "afânare",
    "afânata": "afânat",
    "afânată": "afânat",
    "afânate": "afânat",
    "afânatei": "afânat",
    "afânatele": "afânat",
    "afânatelor": "afânat",
    "afânați": "afânat",
    "afânații": "afânat",
    "afânaților": "afânat",
    "afânatul": "afânat",
    "afânatului": "afânat",
    "afânătoare": "afânător",
    "afânătoarele": "afânător",
    "afânătoarelor": "afânător",
    "afânători": "afânător",
    "afânătorii": "afânător",
    "afânătorilor": "afânător",
    "afânătorul": "afânător",
    "afânătorului": "afânător",
    "afazica": "afazic",
    "afazică": "afazic",
    "afazice": "afazic",
    "afazicei": "afazic",
    "afazicele": "afazic",
    "afazicelor": "afazic",
    "afazici": "afazic",
    "afazicii": "afazic",
    "afazicilor": "afazic",
    "afazicul": "afazic",
    "afazicului": "afazic",
    "afazia": "afazie",
    "afaziei": "afazie",
    "afazii": "afazie",
    "afaziile": "afazie",
    "afaziilor": "afazie",
    "afecte": "afect",
    "afectele": "afect",
    "afectelor": "afect",
    "afectul": "afect",
    "afectului": "afect",
    "afectă": "afecta",
    "afectai": "afecta",
    "afectam": "afecta",
    "afectăm": "afecta",
    "afectând": "afecta",
    "afectându": "afecta",
    "afectară": "afecta",
    "afectarăm": "afecta",
    "afectarăți": "afecta",
    "afectase": "afecta",
    "afectasem": "afecta",
    "afectaseră": "afecta",
    "afectaserăm": "afecta",
    "afectaserăți": "afecta",
    "afectaseși": "afecta",
    "afectași": "afecta",
    "afectat": "afecta",
    "afectați": "afecta",
    "afectatu": "afecta",
    "afectau": "afecta",
    "afectează": "afecta",
    "afectez": "afecta",
    "afecteze": "afecta",
    "afectezi": "afecta",
    "neafectând": "afecta",
    "neafectându": "afecta",
    "nemaiafectând": "afecta",
    "nemaiafectându": "afecta",
    "afectarea": "afectare",
    "afectări": "afectare",
    "afectării": "afectare",
    "afectările": "afectare",
    "afectata": "afectat",
    "afectată": "afectat",
    "afectate": "afectat",
    "afectatei": "afectat",
    "afectatele": "afectat",
    "afectatelor": "afectat",
    "afectați": "afectat",
    "afectații": "afectat",
    "afectaților": "afectat",
    "afectatul": "afectat",
    "afectatului": "afectat",
    "afecțiunea": "afecțiune",
    "afecțiuni": "afecțiune",
    "afecțiunii": "afecțiune",
    "afecțiunile": "afecțiune",
    "afecțiunilor": "afecțiune",
    "afectiva": "afectiv",
    "afectivă": "afectiv",
    "afective": "afectiv",
    "afectivei": "afectiv",
    "afectivele": "afectiv",
    "afectivelor": "afectiv",
    "afectivi": "afectiv",
    "afectivii": "afectiv",
    "afectivilor": "afectiv",
    "afectivul": "afectiv",
    "afectivului": "afectiv",
    "afectivitatea": "afectivitate",
    "afectivități": "afectivitate",
    "afectivității": "afectivitate",
    "afectivitățile": "afectivitate",
    "afectivităților": "afectivitate",
    "afectuoasa": "afectuos",
    "afectuoasă": "afectuos",
    "afectuoase": "afectuos",
    "afectuoasei": "afectuos",
    "afectuoasele": "afectuos",
    "afectuoaselor": "afectuos",
    "afectuoși": "afectuos",
    "afectuoșii": "afectuos",
    "afectuoșilor": "afectuos",
    "afectuosul": "afectuos",
    "afectuosului": "afectuos",
    "afemeiați": "afemeiat",
    "afemeiații": "afemeiat",
    "afemeiaților": "afemeiat",
    "afemeiatul": "afemeiat",
    "afemeiatului": "afemeiat",
    "aferata": "aferat",
    "aferată": "aferat",
    "aferate": "aferat",
    "aferatei": "aferat",
    "aferatele": "aferat",
    "aferatelor": "aferat",
    "aferați": "aferat",
    "aferații": "aferat",
    "aferaților": "aferat",
    "aferatul": "aferat",
    "aferatului": "aferat",
    "aferenta": "aferent",
    "aferentă": "aferent",
    "aferente": "aferent",
    "aferentei": "aferent",
    "aferentele": "aferent",
    "aferentelor": "aferent",
    "aferenți": "aferent",
    "aferenții": "aferent",
    "aferenților": "aferent",
    "aferentul": "aferent",
    "aferentului": "aferent",
    "afereza": "afereză",
    "afereze": "afereză",
    "aferezei": "afereză",
    "aferezele": "afereză",
    "aferezelor": "afereză",
    "afetul": "afet",
    "afetului": "afet",
    "afeturi": "afet",
    "afeturile": "afet",
    "afeturilor": "afet",
    "afiliai": "afilia",
    "afiliam": "afilia",
    "afiliară": "afilia",
    "afiliarăm": "afilia",
    "afiliarăți": "afilia",
    "afiliase": "afilia",
    "afiliasem": "afilia",
    "afiliaseră": "afilia",
    "afiliaserăm": "afilia",
    "afiliaserăți": "afilia",
    "afiliaseși": "afilia",
    "afiliași": "afilia",
    "afiliat": "afilia",
    "afiliați": "afilia",
    "afiliatu": "afilia",
    "afiliau": "afilia",
    "afiliază": "afilia",
    "afilie": "afilia",
    "afiliem": "afilia",
    "afiliez": "afilia",
    "afilieze": "afilia",
    "afiliezi": "afilia",
    "afiliind": "afilia",
    "afiliindu": "afilia",
    "neafiliind": "afilia",
    "neafiliindu": "afilia",
    "nemaiafiliind": "afilia",
    "nemaiafiliindu": "afilia",
    "afiliata": "afiliat",
    "afiliată": "afiliat",
    "afiliate": "afiliat",
    "afiliatei": "afiliat",
    "afiliatele": "afiliat",
    "afiliatelor": "afiliat",
    "afiliați": "afiliat",
    "afiliații": "afiliat",
    "afiliaților": "afiliat",
    "afiliatul": "afiliat",
    "afiliatului": "afiliat",
    "afiliata": "afiliată",
    "afiliate": "afiliată",
    "afiliatei": "afiliată",
    "afiliatele": "afiliată",
    "afiliatelor": "afiliată",
    "afilierea": "afiliere",
    "afilieri": "afiliere",
    "afilierii": "afiliere",
    "afilierile": "afiliere",
    "afina": "afină",
    "afine": "afină",
    "afinei": "afină",
    "afinele": "afină",
    "afinelor": "afină",
    "afinitatea": "afinitate",
    "afinități": "afinitate",
    "afinității": "afinitate",
    "afinitățile": "afinitate",
    "afinităților": "afinitate",
    "afirm": "afirma",
    "afirmă": "afirma",
    "afirmai": "afirma",
    "afirmam": "afirma",
    "afirmăm": "afirma",
    "afirmând": "afirma",
    "afirmându": "afirma",
    "afirmară": "afirma",
    "afirmarăm": "afirma",
    "afirmarăți": "afirma",
    "afirmase": "afirma",
    "afirmasem": "afirma",
    "afirmaseră": "afirma",
    "afirmaserăm": "afirma",
    "afirmaserăți": "afirma",
    "afirmaseși": "afirma",
    "afirmași": "afirma",
    "afirmat": "afirma",
    "afirmați": "afirma",
    "afirmatu": "afirma",
    "afirmau": "afirma",
    "afirme": "afirma",
    "afirmi": "afirma",
    "neafirmând": "afirma",
    "neafirmându": "afirma",
    "nemaiafirmând": "afirma",
    "nemaiafirmându": "afirma",
    "afirmarea": "afirmare",
    "afirmări": "afirmare",
    "afirmării": "afirmare",
    "afirmările": "afirmare",
    "afirmata": "afirmat",
    "afirmată": "afirmat",
    "afirmate": "afirmat",
    "afirmatei": "afirmat",
    "afirmatele": "afirmat",
    "afirmatelor": "afirmat",
    "afirmați": "afirmat",
    "afirmații": "afirmat",
    "afirmaților": "afirmat",
    "afirmatul": "afirmat",
    "afirmatului": "afirmat",
    "afirmația": "afirmație",
    "afirmației": "afirmație",
    "afirmații": "afirmație",
    "afirmațiile": "afirmație",
    "afirmațiilor": "afirmație",
    "afirmativa": "afirmativ",
    "afirmativă": "afirmativ",
    "afirmative": "afirmativ",
    "afirmativei": "afirmativ",
    "afirmativele": "afirmativ",
    "afirmativelor": "afirmativ",
    "afirmativi": "afirmativ",
    "afirmativii": "afirmativ",
    "afirmativilor": "afirmativ",
    "afirmativul": "afirmativ",
    "afirmativului": "afirmativ",
    "afișe": "afiș",
    "afișele": "afiș",
    "afișelor": "afiș",
    "afișul": "afiș",
    "afișului": "afiș",
    "afișă": "afișa",
    "afișai": "afișa",
    "afișam": "afișa",
    "afișăm": "afișa",
    "afișând": "afișa",
    "afișându": "afișa",
    "afișară": "afișa",
    "afișarăm": "afișa",
    "afișarăți": "afișa",
    "afișase": "afișa",
    "afișasem": "afișa",
    "afișaseră": "afișa",
    "afișaserăm": "afișa",
    "afișaserăți": "afișa",
    "afișaseși": "afișa",
    "afișași": "afișa",
    "afișat": "afișa",
    "afișați": "afișa",
    "afișatu": "afișa",
    "afișau": "afișa",
    "afișează": "afișa",
    "afișez": "afișa",
    "afișeze": "afișa",
    "afișezi": "afișa",
    "neafișând": "afișa",
    "neafișându": "afișa",
    "nemaiafișând": "afișa",
    "nemaiafișându": "afișa",
    "afișaje": "afișaj",
    "afișajele": "afișaj",
    "afișajelor": "afișaj",
    "afișajul": "afișaj",
    "afișajului": "afișaj",
    "afișarea": "afișare",
    "afișări": "afișare",
    "afișării": "afișare",
    "afișările": "afișare",
    "afișata": "afișat",
    "afișată": "afișat",
    "afișate": "afișat",
    "afișatei": "afișat",
    "afișatele": "afișat",
    "afișatelor": "afișat",
    "afișați": "afișat",
    "afișații": "afișat",
    "afișaților": "afișat",
    "afișatul": "afișat",
    "afișatului": "afișat",
    "afișiere": "afișier",
    "afișierele": "afișier",
    "afișierelor": "afișier",
    "afișierul": "afișier",
    "afișierului": "afișier",
    "afixe": "afix",
    "afixele": "afix",
    "afixelor": "afix",
    "afixul": "afix",
    "afixului": "afix",
    "află": "afla",
    "aflai": "afla",
    "aflam": "afla",
    "aflăm": "afla",
    "aflând": "afla",
    "aflându": "afla",
    "aflară": "afla",
    "aflarăm": "afla",
    "aflarăți": "afla",
    "aflase": "afla",
    "aflasem": "afla",
    "aflaseră": "afla",
    "aflaserăm": "afla",
    "aflaserăți": "afla",
    "aflaseși": "afla",
    "aflași": "afla",
    "aflat": "afla",
    "aflați": "afla",
    "aflatu": "afla",
    "aflau": "afla",
    "afle": "afla",
    "afli": "afla",
    "aflu": "afla",
    "neaflând": "afla",
    "neaflându": "afla",
    "nemaiaflând": "afla",
    "nemaiaflându": "afla",
    "aflarea": "aflare",
    "aflări": "aflare",
    "aflării": "aflare",
    "aflările": "aflare",
    "aflata": "aflat",
    "aflată": "aflat",
    "aflate": "aflat",
    "aflatei": "aflat",
    "aflatele": "aflat",
    "aflatelor": "aflat",
    "aflați": "aflat",
    "aflații": "aflat",
    "aflaților": "aflat",
    "aflatul": "aflat",
    "aflatului": "aflat",
    "aflătoare": "aflător",
    "aflătoarea": "aflător",
    "aflătoarei": "aflător",
    "aflătoarele": "aflător",
    "aflătoarelor": "aflător",
    "aflători": "aflător",
    "aflătorii": "aflător",
    "aflătorilor": "aflător",
    "aflătorul": "aflător",
    "aflătorului": "aflător",
    "afluenți": "afluent",
    "afluenții": "afluent",
    "afluenților": "afluent",
    "afluentul": "afluent",
    "afluentului": "afluent",
    "afluența": "afluență",
    "afluențe": "afluență",
    "afluenței": "afluență",
    "afluențele": "afluență",
    "afluențelor": "afluență",
    "afluxul": "aflux",
    "afluxului": "aflux",
    "afluxuri": "aflux",
    "afluxurile": "aflux",
    "afluxurilor": "aflux",
    "afocale": "afocal",
    "afocalele": "afocal",
    "afocalelor": "afocal",
    "afocalul": "afocal",
    "afocalului": "afocal",
    "afona": "afon",
    "afonă": "afon",
    "afone": "afon",
    "afonei": "afon",
    "afonele": "afon",
    "afonelor": "afon",
    "afoni": "afon",
    "afonii": "afon",
    "afonilor": "afon",
    "afonul": "afon",
    "afonului": "afon",
    "aforisme": "aforism",
    "aforismele": "aforism",
    "aforismelor": "aforism",
    "aforismul": "aforism",
    "aforismului": "aforism",
    "aforistica": "aforistic",
    "aforistică": "aforistic",
    "aforistice": "aforistic",
    "aforisticei": "aforistic",
    "aforisticele": "aforistic",
    "aforisticelor": "aforistic",
    "aforistici": "aforistic",
    "aforisticii": "aforistic",
    "aforisticilor": "aforistic",
    "aforisticul": "aforistic",
    "aforisticului": "aforistic",
    "Africă": "Africa",
    "Africi": "Africa",
    "Africii": "Africa",
    "africana": "african",
    "africană": "african",
    "africane": "african",
    "africanei": "african",
    "africanele": "african",
    "africanelor": "african",
    "africani": "african",
    "africanii": "african",
    "africanilor": "african",
    "africanul": "african",
    "africanului": "african",
    "Afrodită": "Afrodita",
    "Afrodite": "Afrodita",
    "Afroditei": "Afrodita",
    "afrodiziaca": "afrodiziac",
    "afrodiziacă": "afrodiziac",
    "afrodiziace": "afrodiziac",
    "afrodiziacei": "afrodiziac",
    "afrodiziacele": "afrodiziac",
    "afrodiziacelor": "afrodiziac",
    "afrodiziaci": "afrodiziac",
    "afrodiziacii": "afrodiziac",
    "afrodiziacilor": "afrodiziac",
    "afrodiziacul": "afrodiziac",
    "afrodiziacului": "afrodiziac",
    "afrontul": "afront",
    "afrontului": "afront",
    "afronturi": "afront",
    "afronturile": "afront",
    "afronturilor": "afront",
    "afta": "aftă",
    "afte": "aftă",
    "aftei": "aftă",
    "aftele": "aftă",
    "aftelor": "aftă",
    "afum": "afuma",
    "afumă": "afuma",
    "afumai": "afuma",
    "afumam": "afuma",
    "afumăm": "afuma",
    "afumând": "afuma",
    "afumându": "afuma",
    "afumară": "afuma",
    "afumarăm": "afuma",
    "afumarăți": "afuma",
    "afumase": "afuma",
    "afumasem": "afuma",
    "afumaseră": "afuma",
    "afumaserăm": "afuma",
    "afumaserăți": "afuma",
    "afumaseși": "afuma",
    "afumași": "afuma",
    "afumat": "afuma",
    "afumați": "afuma",
    "afumatu": "afuma",
    "afumau": "afuma",
    "afume": "afuma",
    "afumi": "afuma",
    "afumată": "afumat",
    "afumate": "afumat",
    "afumați": "afumat",
    "afunda": "afund",
    "afundă": "afund",
    "afunde": "afund",
    "afundei": "afund",
    "afundele": "afund",
    "afundelor": "afund",
    "afundul": "afund",
    "afundului": "afund",
    "afunzi": "afund",
    "afunzii": "afund",
    "afunzilor": "afund",
    "afund": "afunda",
    "afundă": "afunda",
    "afundai": "afunda",
    "afundam": "afunda",
    "afundăm": "afunda",
    "afundând": "afunda",
    "afundându": "afunda",
    "afundară": "afunda",
    "afundarăm": "afunda",
    "afundarăți": "afunda",
    "afundase": "afunda",
    "afundasem": "afunda",
    "afundaseră": "afunda",
    "afundaserăm": "afunda",
    "afundaserăți": "afunda",
    "afundaseși": "afunda",
    "afundași": "afunda",
    "afundat": "afunda",
    "afundați": "afunda",
    "afundatu": "afunda",
    "afundau": "afunda",
    "afunde": "afunda",
    "afunzi": "afunda",
    "neafundând": "afunda",
    "neafundându": "afunda",
    "nemaiafundând": "afunda",
    "nemaiafundându": "afunda",
    "afundarea": "afundare",
    "afundări": "afundare",
    "afundării": "afundare",
    "afundările": "afundare",
    "afundata": "afundat",
    "afundată": "afundat",
    "afundate": "afundat",
    "afundatei": "afundat",
    "afundatele": "afundat",
    "afundatelor": "afundat",
    "afundați": "afundat",
    "afundații": "afundat",
    "afundaților": "afundat",
    "afundatul": "afundat",
    "afundatului": "afundat",
    "afundătura": "afundătură",
    "afundături": "afundătură",
    "afundăturii": "afundătură",
    "afundăturile": "afundătură",
    "afundăturilor": "afundătură",
    "afurisiți": "afurisit",
    "aga": "agă",
    "agapelor": "agă",
    "agi": "agă",
    "agii": "agă",
    "agilor": "agă",
    "agapa": "agapă",
    "agape": "agapă",
    "agapei": "agapă",
    "agapele": "agapă",
    "agasă": "agasa",
    "agasai": "agasa",
    "agasam": "agasa",
    "agasăm": "agasa",
    "agasând": "agasa",
    "agasându": "agasa",
    "agasară": "agasa",
    "agasarăm": "agasa",
    "agasarăți": "agasa",
    "agasase": "agasa",
    "agasasem": "agasa",
    "agasaseră": "agasa",
    "agasaserăm": "agasa",
    "agasaserăți": "agasa",
    "agasaseși": "agasa",
    "agasași": "agasa",
    "agasat": "agasa",
    "agasați": "agasa",
    "agasatu": "agasa",
    "agasau": "agasa",
    "agasează": "agasa",
    "agasez": "agasa",
    "agaseze": "agasa",
    "agasezi": "agasa",
    "neagasând": "agasa",
    "neagasându": "agasa",
    "nemaiagasând": "agasa",
    "nemaiagasându": "agasa",
    "agasanta": "agasant",
    "agasantă": "agasant",
    "agasante": "agasant",
    "agasantei": "agasant",
    "agasantele": "agasant",
    "agasantelor": "agasant",
    "agasanți": "agasant",
    "agasanții": "agasant",
    "agasantul": "agasant",
    "agasantului": "agasant",
    "agasarea": "agasare",
    "agasări": "agasare",
    "agasării": "agasare",
    "agasările": "agasare",
    "agasanților": "agasat",
    "agasata": "agasat",
    "agasată": "agasat",
    "agasate": "agasat",
    "agasatei": "agasat",
    "agasatele": "agasat",
    "agasatelor": "agasat",
    "agasați": "agasat",
    "agasații": "agasat",
    "agasaților": "agasat",
    "agasatul": "agasat",
    "agasatului": "agasat",
    "agate": "agat",
    "agatele": "agat",
    "agatelor": "agat",
    "agatul": "agat",
    "agatului": "agat",
    "agăț": "agăța",
    "agață": "agăța",
    "agăță": "agăța",
    "agățai": "agăța",
    "agățam": "agăța",
    "agățăm": "agăța",
    "agățând": "agăța",
    "agățându": "agăța",
    "agățară": "agăța",
    "agățarăm": "agăța",
    "agățarăți": "agăța",
    "agățase": "agăța",
    "agățasem": "agăța",
    "agățaseră": "agăța",
    "agățaserăm": "agăța",
    "agățaserăți": "agăța",
    "agățaseși": "agăța",
    "agățași": "agăța",
    "agățat": "agăța",
    "agățați": "agăța",
    "agățatu": "agăța",
    "agățau": "agăța",
    "agațe": "agăța",
    "agăți": "agăța",
    "neagățând": "agăța",
    "neagățându": "agăța",
    "nemaiagățând": "agăța",
    "nemaiagățându": "agăța",
    "agățarea": "agățare",
    "agățări": "agățare",
    "agățării": "agățare",
    "agățările": "agățare",
    "agățata": "agățat",
    "agățată": "agățat",
    "agățate": "agățat",
    "agățatei": "agățat",
    "agățatele": "agățat",
    "agățatelor": "agățat",
    "agățați": "agățat",
    "agățații": "agățat",
    "agățaților": "agățat",
    "agățatul": "agățat",
    "agățatului": "agățat",
    "agățătoarea": "agățătoare",
    "agățătoarei": "agățătoare",
    "agățătoarele": "agățătoare",
    "agățătoarelor": "agățătoare",
    "agățătoare": "agățător",
    "agățătoarea": "agățător",
    "agățătoarei": "agățător",
    "agățătoarele": "agățător",
    "agățătoarelor": "agățător",
    "agățători": "agățător",
    "agățătorii": "agățător",
    "agățătorilor": "agățător",
    "agățătorul": "agățător",
    "agățătorului": "agățător",
    "ageamia": "ageamie",
    "ageamiei": "ageamie",
    "ageamii": "ageamie",
    "ageamiile": "ageamie",
    "ageamiilor": "ageamie",
    "ageamie": "ageamiu",
    "ageamiei": "ageamiu",
    "ageamii": "ageamiu",
    "ageamiii": "ageamiu",
    "ageamiile": "ageamiu",
    "ageamiilor": "ageamiu",
    "ageamiul": "ageamiu",
    "ageamiului": "ageamiu",
    "agenda": "agendă",
    "agende": "agendă",
    "agendei": "agendă",
    "agendele": "agendă",
    "agendelor": "agendă",
    "agenți": "agent",
    "agenții": "agent",
    "agenților": "agent",
    "agentul": "agent",
    "agentului": "agent",
    "agenta": "agentă",
    "agente": "agentă",
    "agentei": "agentă",
    "agentele": "agentă",
    "agentelor": "agentă",
    "C.I.A.": "Agenția_Centrală_de_Informații",
    "agenția": "agenție",
    "agenției": "agenție",
    "agenții": "agenție",
    "agențiile": "agenție",
    "agențiilor": "agenție",
    "agentura": "agentură",
    "agenturi": "agentură",
    "agenturii": "agentură",
    "agenturile": "agentură",
    "agenturilor": "agentură",
    "agera": "ager",
    "ageră": "ager",
    "agere": "ager",
    "agerei": "ager",
    "agerele": "ager",
    "agerelor": "ager",
    "ageri": "ager",
    "agerii": "ager",
    "agerilor": "ager",
    "agerul": "ager",
    "agerului": "ager",
    "agerimea": "agerime",
    "agerimi": "agerime",
    "agerimii": "agerime",
    "agerimile": "agerime",
    "agerimilor": "agerime",
    "agia": "agie",
    "agiei": "agie",
    "agii": "agie",
    "agiile": "agie",
    "agiilor": "agie",
    "agila": "agil",
    "agilă": "agil",
    "agile": "agil",
    "agilei": "agil",
    "agilele": "agil",
    "agilelor": "agil",
    "agili": "agil",
    "agilii": "agil",
    "agililor": "agil",
    "agilul": "agil",
    "agilului": "agil",
    "agit": "agita",
    "agită": "agita",
    "agitai": "agita",
    "agitam": "agita",
    "agităm": "agita",
    "agitând": "agita",
    "agitându": "agita",
    "agitară": "agita",
    "agitarăm": "agita",
    "agitarăți": "agita",
    "agitase": "agita",
    "agitasem": "agita",
    "agitaseră": "agita",
    "agitaserăm": "agita",
    "agitaserăți": "agita",
    "agitaseși": "agita",
    "agitași": "agita",
    "agitat": "agita",
    "agitați": "agita",
    "agitatu": "agita",
    "agitau": "agita",
    "agite": "agita",
    "agiți": "agita",
    "neagitând": "agita",
    "neagitându": "agita",
    "nemaiagitând": "agita",
    "nemaiagitându": "agita",
    "agitarea": "agitare",
    "agitări": "agitare",
    "agitării": "agitare",
    "agitările": "agitare",
    "agitata": "agitat",
    "agitată": "agitat",
    "agitate": "agitat",
    "agitatei": "agitat",
    "agitatele": "agitat",
    "agitatelor": "agitat",
    "agitați": "agitat",
    "agitații": "agitat",
    "agitaților": "agitat",
    "agitatul": "agitat",
    "agitatului": "agitat",
    "agitata": "agitată",
    "agitate": "agitată",
    "agitatei": "agitată",
    "agitatele": "agitată",
    "agitatelor": "agitată",
    "agitația": "agitație",
    "agitației": "agitație",
    "agitații": "agitație",
    "agitațiile": "agitație",
    "agitațiilor": "agitație",
    "agitatoarea": "agitatoare",
    "agitatoarei": "agitatoare",
    "agitatoarele": "agitatoare",
    "agitatoarelor": "agitatoare",
    "agitatori": "agitator",
    "agitatorii": "agitator",
    "agitatorilor": "agitator",
    "agitatorul": "agitator",
    "agitatorului": "agitator",
    "agitatorica": "agitatoric",
    "agitatorică": "agitatoric",
    "agitatorice": "agitatoric",
    "agitatoricei": "agitatoric",
    "agitatoricele": "agitatoric",
    "agitatoricelor": "agitatoric",
    "agitatorici": "agitatoric",
    "agitatoricii": "agitatoric",
    "agitatoricilor": "agitatoric",
    "agitatoricul": "agitatoric",
    "agitatoricului": "agitatoric",
    "aglomeră": "aglomera",
    "aglomerai": "aglomera",
    "aglomeram": "aglomera",
    "aglomerăm": "aglomera",
    "aglomerând": "aglomera",
    "aglomerându": "aglomera",
    "aglomerară": "aglomera",
    "aglomerarăm": "aglomera",
    "aglomerarăți": "aglomera",
    "aglomerase": "aglomera",
    "aglomerasem": "aglomera",
    "aglomeraseră": "aglomera",
    "aglomeraserăm": "aglomera",
    "aglomeraserăți": "aglomera",
    "aglomeraseși": "aglomera",
    "aglomerași": "aglomera",
    "aglomerat": "aglomera",
    "aglomerați": "aglomera",
    "aglomeratu": "aglomera",
    "aglomerau": "aglomera",
    "aglomerează": "aglomera",
    "aglomerez": "aglomera",
    "aglomereze": "aglomera",
    "aglomerezi": "aglomera",
    "neaglomerând": "aglomera",
    "neaglomerându": "aglomera",
    "nemaiaglomerând": "aglomera",
    "nemaiaglomerându": "aglomera",
    "aglomerarea": "aglomerare",
    "aglomerări": "aglomerare",
    "aglomerării": "aglomerare",
    "aglomerările": "aglomerare",
    "aglomerata": "aglomerat",
    "aglomerată": "aglomerat",
    "aglomerate": "aglomerat",
    "aglomeratei": "aglomerat",
    "aglomeratele": "aglomerat",
    "aglomeratelor": "aglomerat",
    "aglomerați": "aglomerat",
    "aglomerații": "aglomerat",
    "aglomeraților": "aglomerat",
    "aglomeratul": "aglomerat",
    "aglomeratului": "aglomerat",
    "aglomerația": "aglomerație",
    "aglomerației": "aglomerație",
    "aglomerații": "aglomerație",
    "aglomerațiile": "aglomerație",
    "aglomerațiilor": "aglomerație",
    "aglutină": "aglutina",
    "aglutinai": "aglutina",
    "aglutinam": "aglutina",
    "aglutinăm": "aglutina",
    "aglutinând": "aglutina",
    "aglutinându": "aglutina",
    "aglutinară": "aglutina",
    "aglutinarăm": "aglutina",
    "aglutinarăți": "aglutina",
    "aglutinase": "aglutina",
    "aglutinasem": "aglutina",
    "aglutinaserăm": "aglutina",
    "aglutinaserăți": "aglutina",
    "aglutinaseși": "aglutina",
    "aglutinași": "aglutina",
    "aglutinat": "aglutina",
    "aglutinați": "aglutina",
    "aglutinatu": "aglutina",
    "aglutinau": "aglutina",
    "aglutinează": "aglutina",
    "aglutinez": "aglutina",
    "aglutineze": "aglutina",
    "aglutinezi": "aglutina",
    "neaglutinând": "aglutina",
    "neaglutinându": "aglutina",
    "nemaiaglutinând": "aglutina",
    "nemaiaglutinându": "aglutina",
    "aglutinanta": "aglutinant",
    "aglutinantă": "aglutinant",
    "aglutinante": "aglutinant",
    "aglutinantei": "aglutinant",
    "aglutinantele": "aglutinant",
    "aglutinantelor": "aglutinant",
    "aglutinanți": "aglutinant",
    "aglutinanții": "aglutinant",
    "aglutinanților": "aglutinant",
    "aglutinantul": "aglutinant",
    "aglutinantului": "aglutinant",
    "aglutinarea": "aglutinare",
    "aglutinări": "aglutinare",
    "aglutinării": "aglutinare",
    "aglutinările": "aglutinare",
    "aglutinata": "aglutinat",
    "aglutinate": "aglutinat",
    "aglutinați": "aglutinat",
    "aglutinații": "aglutinat",
    "aglutinaților": "aglutinat",
    "aglutinatul": "aglutinat",
    "aglutinatului": "aglutinat",
    "agnostica": "agnostic",
    "agnostice": "agnostic",
    "agnosticei": "agnostic",
    "agnosticele": "agnostic",
    "agnosticelor": "agnostic",
    "agnostici": "agnostic",
    "agnosticii": "agnostic",
    "agnosticilor": "agnostic",
    "agnosticul": "agnostic",
    "agnosticului": "agnostic",
    "agnosticisme": "agnosticism",
    "agnosticismele": "agnosticism",
    "agnosticismelor": "agnosticism",
    "agnosticismul": "agnosticism",
    "agnosticismului": "agnosticism",
    "agonica": "agonic",
    "agonică": "agonic",
    "agonice": "agonic",
    "agonicei": "agonic",
    "agonicele": "agonic",
    "agonicelor": "agonic",
    "agonici": "agonic",
    "agonicii": "agonic",
    "agonicilor": "agonic",
    "agonicul": "agonic",
    "agonicului": "agonic",
    "agonia": "agonie",
    "agoniei": "agonie",
    "agonii": "agonie",
    "agoniile": "agonie",
    "agoniilor": "agonie",
    "agoniseala": "agoniseală",
    "agoniseli": "agoniseală",
    "agoniselii": "agoniseală",
    "agoniselile": "agoniseală",
    "agoniselilor": "agoniseală",
    "agonisea": "agonisi",
    "agoniseai": "agonisi",
    "agoniseam": "agonisi",
    "agonisească": "agonisi",
    "agoniseați": "agonisi",
    "agoniseau": "agonisi",
    "agonisesc": "agonisi",
    "agonisește": "agonisi",
    "agonisești": "agonisi",
    "agonisii": "agonisi",
    "agonisim": "agonisi",
    "agonisind": "agonisi",
    "agonisindu": "agonisi",
    "agonisiră": "agonisi",
    "agonisirăm": "agonisi",
    "agonisirăți": "agonisi",
    "agonisise": "agonisi",
    "agonisisem": "agonisi",
    "agonisiseră": "agonisi",
    "agonisiserăm": "agonisi",
    "agonisiserăți": "agonisi",
    "agonisiseși": "agonisi",
    "agonisiși": "agonisi",
    "agonisit": "agonisi",
    "agonisiți": "agonisi",
    "agonisitu": "agonisi",
    "neagonisind": "agonisi",
    "neagonisindu": "agonisi",
    "nemaiagonisind": "agonisi",
    "nemaiagonisindu": "agonisi",
    "agonisirea": "agonisire",
    "agonisiri": "agonisire",
    "agonisirii": "agonisire",
    "agonisirile": "agonisire",
    "agonisita": "agonisit",
    "agonisită": "agonisit",
    "agonisite": "agonisit",
    "agonisitei": "agonisit",
    "agonisitele": "agonisit",
    "agonisitelor": "agonisit",
    "agonisiți": "agonisit",
    "agonisiții": "agonisit",
    "agonisiților": "agonisit",
    "agonisitul": "agonisit",
    "agonisitului": "agonisit",
    "agoniză": "agoniza",
    "agonizai": "agoniza",
    "agonizam": "agoniza",
    "agonizăm": "agoniza",
    "agonizând": "agoniza",
    "agonizându": "agoniza",
    "agonizară": "agoniza",
    "agonizarăm": "agoniza",
    "agonizarăți": "agoniza",
    "agonizase": "agoniza",
    "agonizasem": "agoniza",
    "agonizaseră": "agoniza",
    "agonizaserăm": "agoniza",
    "agonizaserăți": "agoniza",
    "agonizaseși": "agoniza",
    "agonizași": "agoniza",
    "agonizat": "agoniza",
    "agonizați": "agoniza",
    "agonizatu": "agoniza",
    "agonizau": "agoniza",
    "agonizează": "agoniza",
    "agonizez": "agoniza",
    "agonizeze": "agoniza",
    "agonizezi": "agoniza",
    "neagonizând": "agoniza",
    "neagonizându": "agoniza",
    "nemaiagonizând": "agoniza",
    "nemaiagonizându": "agoniza",
    "agonizanta": "agonizant",
    "agonizantă": "agonizant",
    "agonizante": "agonizant",
    "agonizantei": "agonizant",
    "agonizantele": "agonizant",
    "agonizantelor": "agonizant",
    "agonizanți": "agonizant",
    "agonizanții": "agonizant",
    "agonizanților": "agonizant",
    "agonizantul": "agonizant",
    "agonizantului": "agonizant",
    "agonizată": "agonizat",
    "agonizate": "agonizat",
    "agonizați": "agonizat",
    "agramata": "agramat",
    "agramată": "agramat",
    "agramate": "agramat",
    "agramatei": "agramat",
    "agramatele": "agramat",
    "agramatelor": "agramat",
    "agramați": "agramat",
    "agramații": "agramat",
    "agramaților": "agramat",
    "agramatul": "agramat",
    "agramatului": "agramat",
    "agramatisme": "agramatism",
    "agramatismele": "agramatism",
    "agramatismelor": "agramatism",
    "agramatismul": "agramatism",
    "agramatismului": "agramatism",
    "agrara": "agrar",
    "agrară": "agrar",
    "agrare": "agrar",
    "agrarei": "agrar",
    "agrarele": "agrar",
    "agrarelor": "agrar",
    "agrari": "agrar",
    "agrarii": "agrar",
    "agrarilor": "agrar",
    "agrarul": "agrar",
    "agrarului": "agrar",
    "agrariana": "agrarian",
    "agrariană": "agrarian",
    "agrarianul": "agrarian",
    "agrarianului": "agrarian",
    "agrariene": "agrarian",
    "agrarienei": "agrarian",
    "agrarienele": "agrarian",
    "agrarienelor": "agrarian",
    "agrarieni": "agrarian",
    "agrarienii": "agrarian",
    "agrarienilor": "agrarian",
    "agrariana": "agrariană",
    "agrariene": "agrariană",
    "agrarienei": "agrariană",
    "agrarienele": "agrariană",
    "agrarienelor": "agrariană",
    "agravă": "agrava",
    "agravai": "agrava",
    "agravam": "agrava",
    "agravăm": "agrava",
    "agravând": "agrava",
    "agravându": "agrava",
    "agravară": "agrava",
    "agravarăm": "agrava",
    "agravarăți": "agrava",
    "agravase": "agrava",
    "agravasem": "agrava",
    "agravaseră": "agrava",
    "agravaserăm": "agrava",
    "agravaserăți": "agrava",
    "agravaseși": "agrava",
    "agravași": "agrava",
    "agravat": "agrava",
    "agravați": "agrava",
    "agravatu": "agrava",
    "agravau": "agrava",
    "agravează": "agrava",
    "agravez": "agrava",
    "agraveze": "agrava",
    "agravezi": "agrava",
    "neagravând": "agrava",
    "neagravându": "agrava",
    "nemaiagravând": "agrava",
    "nemaiagravându": "agrava",
    "agravanta": "agravant",
    "agravantă": "agravant",
    "agravante": "agravant",
    "agravantei": "agravant",
    "agravantele": "agravant",
    "agravantelor": "agravant",
    "agravanți": "agravant",
    "agravanții": "agravant",
    "agravanților": "agravant",
    "agravantul": "agravant",
    "agravantului": "agravant",
    "agravarea": "agravare",
    "agravări": "agravare",
    "agravării": "agravare",
    "agravările": "agravare",
    "agravata": "agravat",
    "agravată": "agravat",
    "agravate": "agravat",
    "agravatei": "agravat",
    "agravatele": "agravat",
    "agravatelor": "agravat",
    "agravați": "agravat",
    "agravații": "agravat",
    "agravaților": "agravat",
    "agravatul": "agravat",
    "agravatului": "agravat",
    "agreă": "agrea",
    "agreai": "agrea",
    "agream": "agrea",
    "agreăm": "agrea",
    "agreară": "agrea",
    "agrearăm": "agrea",
    "agrearăți": "agrea",
    "agrease": "agrea",
    "agreasem": "agrea",
    "agreaseră": "agrea",
    "agreaserăm": "agrea",
    "agreaserăți": "agrea",
    "agreaseși": "agrea",
    "agreași": "agrea",
    "agreat": "agrea",
    "agreați": "agrea",
    "agreatu": "agrea",
    "agreau": "agrea",
    "agreează": "agrea",
    "agreez": "agrea",
    "agreeze": "agrea",
    "agreezi": "agrea",
    "agreind": "agrea",
    "agreindu": "agrea",
    "neagreând": "agrea",
    "neagreându": "agrea",
    "nemaiagreând": "agrea",
    "nemaiagreându": "agrea",
    "agreabilă": "agreabil",
    "agreabile": "agreabil",
    "agreabili": "agreabil",
    "agreata": "agreat",
    "agreată": "agreat",
    "agreate": "agreat",
    "agreatei": "agreat",
    "agreatele": "agreat",
    "agreatelor": "agreat",
    "agreați": "agreat",
    "agreații": "agreat",
    "agreaților": "agreat",
    "agreatul": "agreat",
    "agreatului": "agreat",
    "agreerea": "agreere",
    "agreeri": "agreere",
    "agreerii": "agreere",
    "agreerile": "agreere",
    "agreg": "agrega",
    "agregă": "agrega",
    "agregai": "agrega",
    "agregam": "agrega",
    "agregăm": "agrega",
    "agregând": "agrega",
    "agregându": "agrega",
    "agregară": "agrega",
    "agregarăm": "agrega",
    "agregarăți": "agrega",
    "agregase": "agrega",
    "agregasem": "agrega",
    "agregaseră": "agrega",
    "agregaserăm": "agrega",
    "agregaserăți": "agrega",
    "agregaseși": "agrega",
    "agregași": "agrega",
    "agregat": "agrega",
    "agregați": "agrega",
    "agregatu": "agrega",
    "agregau": "agrega",
    "agrege": "agrega",
    "agregi": "agrega",
    "neagregând": "agrega",
    "neagregându": "agrega",
    "nemaiagregând": "agrega",
    "nemaiagregându": "agrega",
    "agregarea": "agregare",
    "agregări": "agregare",
    "agregării": "agregare",
    "agregările": "agregare",
    "agregata": "agregat",
    "agregată": "agregat",
    "agregate": "agregat",
    "agregatei": "agregat",
    "agregatele": "agregat",
    "agregatelor": "agregat",
    "agregați": "agregat",
    "agregații": "agregat",
    "agregaților": "agregat",
    "agregatul": "agregat",
    "agregatului": "agregat",
    "agremente": "agrement",
    "agrementele": "agrement",
    "agrementelor": "agrement",
    "agrementul": "agrement",
    "agrementului": "agrement",
    "agresă": "agresa",
    "agresai": "agresa",
    "agresam": "agresa",
    "agresăm": "agresa",
    "agresând": "agresa",
    "agresându": "agresa",
    "agresară": "agresa",
    "agresarăm": "agresa",
    "agresarăți": "agresa",
    "agresase": "agresa",
    "agresasem": "agresa",
    "agresaseră": "agresa",
    "agresaserăm": "agresa",
    "agresaserăți": "agresa",
    "agresaseși": "agresa",
    "agresași": "agresa",
    "agresat": "agresa",
    "agresați": "agresa",
    "agresatu": "agresa",
    "agresau": "agresa",
    "agresează": "agresa",
    "agresez": "agresa",
    "agreseze": "agresa",
    "agresezi": "agresa",
    "agresarea": "agresare",
    "agresări": "agresare",
    "agresării": "agresare",
    "agresările": "agresare",
    "agresata": "agresat",
    "agresată": "agresat",
    "agresate": "agresat",
    "agresatei": "agresat",
    "agresatele": "agresat",
    "agresatelor": "agresat",
    "agresați": "agresat",
    "agresații": "agresat",
    "agresaților": "agresat",
    "agresatul": "agresat",
    "agresatului": "agresat",
    "agresiunea": "agresiune",
    "agresiuni": "agresiune",
    "agresiunii": "agresiune",
    "agresiunile": "agresiune",
    "agresiunilor": "agresiune",
    "agresiva": "agresiv",
    "agresivă": "agresiv",
    "agresive": "agresiv",
    "agresivei": "agresiv",
    "agresivele": "agresiv",
    "agresivelor": "agresiv",
    "agresivi": "agresiv",
    "agresivii": "agresiv",
    "agresivilor": "agresiv",
    "agresivul": "agresiv",
    "agresivului": "agresiv",
    "agresivitatea": "agresivitate",
    "agresivități": "agresivitate",
    "agresivității": "agresivitate",
    "agresivitățile": "agresivitate",
    "agresivităților": "agresivitate",
    "agresoarea": "agresoare",
    "agresoarei": "agresoare",
    "agresoarele": "agresoare",
    "agresoarelor": "agresoare",
    "agresori": "agresor",
    "agresorii": "agresor",
    "agresorilor": "agresor",
    "agresorul": "agresor",
    "agresorului": "agresor",
    "agricola": "agricol",
    "agricolă": "agricol",
    "agricole": "agricol",
    "agricolei": "agricol",
    "agricolele": "agricol",
    "agricolelor": "agricol",
    "agricoli": "agricol",
    "agricolii": "agricol",
    "agricolilor": "agricol",
    "agricolul": "agricol",
    "agricolului": "agricol",
    "agricultoarea": "agricultoare",
    "agricultoarei": "agricultoare",
    "agricultoarele": "agricultoare",
    "agricultoarelor": "agricultoare",
    "agricultori": "agricultor",
    "agricultorii": "agricultor",
    "agricultorilor": "agricultor",
    "agricultorul": "agricultor",
    "agricultorului": "agricultor",
    "agric.": "agricultură",
    "agricultura": "agricultură",
    "agriculturi": "agricultură",
    "agriculturii": "agricultură",
    "agriculturile": "agricultură",
    "agriculturilor": "agricultură",
    "Agripină": "Agripina",
    "Agripinei": "Agripina",
    "agroalimentară": "agroalimentar",
    "agroalimentare": "agroalimentar",
    "agroalimentari": "agroalimentar",
    "agroalimentarea": "agroalimentare",
    "agroalimentări": "agroalimentare",
    "agroalimentării": "agroalimentare",
    "agroalimentările": "agroalimentare",
    "agroalimentărilor": "agroalimentare",
    "agrobiologica": "agrobiologic",
    "agrobiologică": "agrobiologic",
    "agrobiologice": "agrobiologic",
    "agrobiologicei": "agrobiologic",
    "agrobiologicele": "agrobiologic",
    "agrobiologicelor": "agrobiologic",
    "agrobiologici": "agrobiologic",
    "agrobiologicii": "agrobiologic",
    "agrobiologicilor": "agrobiologic",
    "agrobiologicul": "agrobiologic",
    "agrobiologicului": "agrobiologic",
    "agr.": "agronom",
    "agronomi": "agronom",
    "agronomii": "agronom",
    "agronomilor": "agronom",
    "agronomul": "agronom",
    "agronomului": "agronom",
    "agronoma": "agronomă",
    "agronome": "agronomă",
    "agronomei": "agronomă",
    "agronomele": "agronomă",
    "agronomelor": "agronomă",
    "agronomica": "agronomic",
    "agronomică": "agronomic",
    "agronomice": "agronomic",
    "agronomicei": "agronomic",
    "agronomicele": "agronomic",
    "agronomicelor": "agronomic",
    "agronomici": "agronomic",
    "agronomicii": "agronomic",
    "agronomicilor": "agronomic",
    "agronomicul": "agronomic",
    "agronomicului": "agronomic",
    "agron.": "agronomie",
    "agronomia": "agronomie",
    "agronomiei": "agronomie",
    "agronomii": "agronomie",
    "agronomiile": "agronomie",
    "agronomiilor": "agronomie",
    "agrotehnica": "agrotehnic",
    "agrotehnică": "agrotehnic",
    "agrotehnice": "agrotehnic",
    "agrotehnicei": "agrotehnic",
    "agrotehnicele": "agrotehnic",
    "agrotehnicelor": "agrotehnic",
    "agrotehnici": "agrotehnic",
    "agrotehnicii": "agrotehnic",
    "agrotehnicilor": "agrotehnic",
    "agrotehnicul": "agrotehnic",
    "agrotehnicului": "agrotehnic",
    "agrotehnica": "agrotehnică",
    "agrotehnici": "agrotehnică",
    "agrotehnicii": "agrotehnică",
    "agrotehnicile": "agrotehnică",
    "agrotehnicilor": "agrotehnică",
    "agrozootehnica": "agrozootehnic",
    "agrozootehnică": "agrozootehnic",
    "agrozootehnice": "agrozootehnic",
    "agrozootehnicei": "agrozootehnic",
    "agrozootehnicele": "agrozootehnic",
    "agrozootehnicelor": "agrozootehnic",
    "agrozootehnici": "agrozootehnic",
    "agrozootehnicii": "agrozootehnic",
    "agrozootehnicilor": "agrozootehnic",
    "agrozootehnicul": "agrozootehnic",
    "agrozootehnicului": "agrozootehnic",
    "agurida": "aguridă",
    "aguride": "aguridă",
    "aguridei": "aguridă",
    "aguridele": "aguridă",
    "aguridelor": "aguridă",
    "ahei": "aheu",
    "aheii": "aheu",
    "aheilor": "aheu",
    "aheul": "aheu",
    "aheului": "aheu",
    "ahotnica": "ahotnic",
    "ahotnică": "ahotnic",
    "ahotnice": "ahotnic",
    "ahotnicei": "ahotnic",
    "ahotnicele": "ahotnic",
    "ahotnicelor": "ahotnic",
    "ahotnici": "ahotnic",
    "ahotnicii": "ahotnic",
    "ahotnicilor": "ahotnic",
    "ahotnicul": "ahotnic",
    "ahotnicului": "ahotnic",
    "ahtiai": "ahtia",
    "ahtiam": "ahtia",
    "ahtiară": "ahtia",
    "ahtiarăm": "ahtia",
    "ahtiarăți": "ahtia",
    "ahtiase": "ahtia",
    "ahtiasem": "ahtia",
    "ahtiaseră": "ahtia",
    "ahtiaserăm": "ahtia",
    "ahtiaserăți": "ahtia",
    "ahtiaseși": "ahtia",
    "ahtiași": "ahtia",
    "ahtiat": "ahtia",
    "ahtiați": "ahtia",
    "ahtiatu": "ahtia",
    "ahtiau": "ahtia",
    "ahtiază": "ahtia",
    "ahtie": "ahtia",
    "ahtiem": "ahtia",
    "ahtiez": "ahtia",
    "ahtieze": "ahtia",
    "ahtiezi": "ahtia",
    "ahtiind": "ahtia",
    "ahtiindu": "ahtia",
    "neahtiind": "ahtia",
    "neahtiindu": "ahtia",
    "nemaiahtiind": "ahtia",
    "nemaiahtiindu": "ahtia",
    "ahtiata": "ahtiat",
    "ahtiată": "ahtiat",
    "ahtiate": "ahtiat",
    "ahtiatei": "ahtiat",
    "ahtiatele": "ahtiat",
    "ahtiatelor": "ahtiat",
    "ahtiați": "ahtiat",
    "ahtiații": "ahtiat",
    "ahtiaților": "ahtiat",
    "ahtiatul": "ahtiat",
    "ahtiatului": "ahtiat",
    "ahtiata": "ahtiată",
    "ahtiate": "ahtiată",
    "ahtiatei": "ahtiată",
    "ahtiatele": "ahtiată",
    "ahtiatelor": "ahtiată",
    "ahtierea": "ahtiere",
    "ahtieri": "ahtiere",
    "ahtierii": "ahtiere",
    "ahtierile": "ahtiere",
    "aisbergul": "aisberg",
    "aisbergului": "aisberg",
    "aisberguri": "aisberg",
    "aisbergurile": "aisberg",
    "aisbergurilor": "aisberg",
    "Aiudul": "Aiud",
    "Aiudului": "Aiud",
    "aiură": "aiura",
    "aiurai": "aiura",
    "aiuram": "aiura",
    "aiurăm": "aiura",
    "aiurând": "aiura",
    "aiurându": "aiura",
    "aiurară": "aiura",
    "aiurarăm": "aiura",
    "aiurarăți": "aiura",
    "aiurase": "aiura",
    "aiurasem": "aiura",
    "aiuraseră": "aiura",
    "aiuraserăm": "aiura",
    "aiuraserăți": "aiura",
    "aiuraseși": "aiura",
    "aiurași": "aiura",
    "aiurat": "aiura",
    "aiurați": "aiura",
    "aiuratu": "aiura",
    "aiurau": "aiura",
    "aiurează": "aiura",
    "aiurez": "aiura",
    "aiureze": "aiura",
    "aiurezi": "aiura",
    "neaiurând": "aiura",
    "neaiurându": "aiura",
    "nemaiaiurând": "aiura",
    "nemaiaiurându": "aiura",
    "aiurarea": "aiurare",
    "aiurări": "aiurare",
    "aiurării": "aiurare",
    "aiurările": "aiurare",
    "aiurată": "aiurat",
    "aiurate": "aiurat",
    "aiurați": "aiurat",
    "aiurații": "aiurat",
    "aiuraților": "aiurat",
    "aiuratul": "aiurat",
    "aiuratului": "aiurat",
    "aiureala": "aiureală",
    "aiureli": "aiureală",
    "aiurelii": "aiureală",
    "aiurelile": "aiureală",
    "aiurelilor": "aiureală",
    "aiurita": "aiurit",
    "aiurită": "aiurit",
    "aiurite": "aiurit",
    "aiuritei": "aiurit",
    "aiuritele": "aiurit",
    "aiuritelor": "aiurit",
    "aiuriți": "aiurit",
    "aiuriții": "aiurit",
    "aiuriților": "aiurit",
    "aiuritul": "aiurit",
    "aiuritului": "aiurit",
    "aiurita": "aiurită",
    "aiurite": "aiurită",
    "aiuritei": "aiurită",
    "aiuritele": "aiurită",
    "aiuritelor": "aiurită",
    "ajung": "ajunge",
    "ajungă": "ajunge",
    "ajungând": "ajunge",
    "ajungându": "ajunge",
    "ajungea": "ajunge",
    "ajungeai": "ajunge",
    "ajungeam": "ajunge",
    "ajungeați": "ajunge",
    "ajungeau": "ajunge",
    "ajungem": "ajunge",
    "ajungeți": "ajunge",
    "ajungi": "ajunge",
    "ajuns": "ajunge",
    "ajunse": "ajunge",
    "ajunsei": "ajunge",
    "ajunseră": "ajunge",
    "ajunserăm": "ajunge",
    "ajunserăți": "ajunge",
    "ajunsese": "ajunge",
    "ajunsesem": "ajunge",
    "ajunseseră": "ajunge",
    "ajunseserăm": "ajunge",
    "ajunseserăți": "ajunge",
    "ajunseseși": "ajunge",
    "ajunseși": "ajunge",
    "ajunsu": "ajunge",
    "neajungând": "ajunge",
    "neajungându": "ajunge",
    "nemaiajungând": "ajunge",
    "nemaiajungându": "ajunge",
    "ajungerea": "ajungere",
    "ajungeri": "ajungere",
    "ajungerii": "ajungere",
    "ajungerile": "ajungere",
    "ajunsa": "ajuns",
    "ajunsă": "ajuns",
    "ajunse": "ajuns",
    "ajunsei": "ajuns",
    "ajunsele": "ajuns",
    "ajunselor": "ajuns",
    "ajunși": "ajuns",
    "ajunșii": "ajuns",
    "ajunșilor": "ajuns",
    "ajunsul": "ajuns",
    "ajunsului": "ajuns",
    "ajustă": "ajusta",
    "ajustai": "ajusta",
    "ajustam": "ajusta",
    "ajustăm": "ajusta",
    "ajustând": "ajusta",
    "ajustându": "ajusta",
    "ajustară": "ajusta",
    "ajustarăm": "ajusta",
    "ajustarăți": "ajusta",
    "ajustase": "ajusta",
    "ajustasem": "ajusta",
    "ajustaseră": "ajusta",
    "ajustaserăm": "ajusta",
    "ajustaserăți": "ajusta",
    "ajustaseși": "ajusta",
    "ajustași": "ajusta",
    "ajustat": "ajusta",
    "ajustați": "ajusta",
    "ajustatu": "ajusta",
    "ajustau": "ajusta",
    "ajustează": "ajusta",
    "ajustez": "ajusta",
    "ajusteze": "ajusta",
    "ajustezi": "ajusta",
    "neajustând": "ajusta",
    "neajustându": "ajusta",
    "nemaiajustând": "ajusta",
    "nemaiajustându": "ajusta",
    "ajustarea": "ajustare",
    "ajustări": "ajustare",
    "ajustării": "ajustare",
    "ajustările": "ajustare",
    "ajustata": "ajustat",
    "ajustată": "ajustat",
    "ajustate": "ajustat",
    "ajustatei": "ajustat",
    "ajustatele": "ajustat",
    "ajustatelor": "ajustat",
    "ajustați": "ajustat",
    "ajustații": "ajustat",
    "ajustaților": "ajustat",
    "ajustatul": "ajustat",
    "ajustatului": "ajustat",
    "ajut": "ajuta",
    "ajută": "ajuta",
    "ajutai": "ajuta",
    "ajutam": "ajuta",
    "ajutăm": "ajuta",
    "ajutând": "ajuta",
    "ajutându": "ajuta",
    "ajutară": "ajuta",
    "ajutarăm": "ajuta",
    "ajutarăți": "ajuta",
    "ajutase": "ajuta",
    "ajutasem": "ajuta",
    "ajutaseră": "ajuta",
    "ajutaserăm": "ajuta",
    "ajutaserăți": "ajuta",
    "ajutaseși": "ajuta",
    "ajutași": "ajuta",
    "ajutat": "ajuta",
    "ajutați": "ajuta",
    "ajutatu": "ajuta",
    "ajutau": "ajuta",
    "ajute": "ajuta",
    "ajuți": "ajuta",
    "neajutând": "ajuta",
    "neajutându": "ajuta",
    "nemaiajutând": "ajuta",
    "nemaiajutându": "ajuta",
    "ajutarea": "ajutare",
    "ajutări": "ajutare",
    "ajutării": "ajutare",
    "ajutările": "ajutare",
    "ajutași": "ajutat",
    "ajutata": "ajutat",
    "ajutată": "ajutat",
    "ajutate": "ajutat",
    "ajutatei": "ajutat",
    "ajutatele": "ajutat",
    "ajutatelor": "ajutat",
    "ajutați": "ajutat",
    "ajutații": "ajutat",
    "ajutaților": "ajutat",
    "ajutatul": "ajutat",
    "ajutatului": "ajutat",
    "ajutătoare": "ajutător",
    "ajutătoarea": "ajutător",
    "ajutătoarei": "ajutător",
    "ajutătoarele": "ajutător",
    "ajutătoarelor": "ajutător",
    "ajutători": "ajutător",
    "ajutătorii": "ajutător",
    "ajutătorilor": "ajutător",
    "ajutătorul": "ajutător",
    "ajutătorului": "ajutător",
    "ajutoarea": "ajutoare",
    "ajutoarei": "ajutoare",
    "ajutoarele": "ajutoare",
    "ajutoarelor": "ajutoare",
    "ajutoare": "ajutor",
    "ajutoarele": "ajutor",
    "ajutoarelor": "ajutor",
    "ajutori": "ajutor",
    "ajutorii": "ajutor",
    "ajutorilor": "ajutor",
    "ajutorul": "ajutor",
    "ajutorului": "ajutor",
    "ajutorarea": "ajutorare",
    "ajutorări": "ajutorare",
    "ajutorării": "ajutorare",
    "ajutorările": "ajutorare",
    "ajutorărilor": "ajutorare",
    "a": "al",
    "ai": "al",
    "ale": "al",
    "alor": "al",
    "ăi": "ăl",
    "ălei": "ăl",
    "ălor": "ăl",
    "ălui": "ăl",
    "ăi": "ăla",
    "aia": "ăla",
    "ăia": "ăla",
    "alea": "ăla",
    "ăleia": "ăla",
    "ălora": "ăla",
    "ăluia": "ăla",
    "alaiul": "alai",
    "alaiului": "alai",
    "alaiuri": "alai",
    "alaiurile": "alai",
    "alaiurilor": "alai",
    "alama": "alamă",
    "alame": "alamă",
    "alamei": "alamă",
    "alamele": "alamă",
    "alamelor": "alamă",
    "alămuri": "alamă",
    "alămurile": "alamă",
    "alămurilor": "alamă",
    "alambicul": "alambic",
    "alambicului": "alambic",
    "alambicuri": "alambic",
    "alambicurile": "alambic",
    "alambicurilor": "alambic",
    "alambică": "alambica",
    "alambicai": "alambica",
    "alambicam": "alambica",
    "alambicând": "alambica",
    "alambicându": "alambica",
    "alambicară": "alambica",
    "alambicarăm": "alambica",
    "alambicarăți": "alambica",
    "alambicase": "alambica",
    "alambicasem": "alambica",
    "alambicaseră": "alambica",
    "alambicaserăm": "alambica",
    "alambicaserăți": "alambica",
    "alambicaseși": "alambica",
    "alambicași": "alambica",
    "alambicat": "alambica",
    "alambicați": "alambica",
    "alambicatu": "alambica",
    "alambicau": "alambica",
    "alambichează": "alambica",
    "alambichez": "alambica",
    "alambicheze": "alambica",
    "alambichezi": "alambica",
    "nealambicând": "alambica",
    "nealambicându": "alambica",
    "nemaialambicând": "alambica",
    "nemaialambicându": "alambica",
    "alambicarea": "alambicare",
    "alambicări": "alambicare",
    "alambicării": "alambicare",
    "alambicările": "alambicare",
    "alambicata": "alambicat",
    "alambicată": "alambicat",
    "alambicate": "alambicat",
    "alambicatei": "alambicat",
    "alambicatele": "alambicat",
    "alambicatelor": "alambicat",
    "alambicați": "alambicat",
    "alambicații": "alambicat",
    "alambicaților": "alambicat",
    "alambicatul": "alambicat",
    "alambicatului": "alambicat",
    "alăptă": "alăpta",
    "alăptai": "alăpta",
    "alăptam": "alăpta",
    "alăptăm": "alăpta",
    "alăptând": "alăpta",
    "alăptându": "alăpta",
    "alăptară": "alăpta",
    "alăptarăm": "alăpta",
    "alăptarăți": "alăpta",
    "alăptase": "alăpta",
    "alăptasem": "alăpta",
    "alăptaseră": "alăpta",
    "alăptaserăm": "alăpta",
    "alăptaserăți": "alăpta",
    "alăptaseși": "alăpta",
    "alăptași": "alăpta",
    "alăptat": "alăpta",
    "alăptați": "alăpta",
    "alăptatu": "alăpta",
    "alăptau": "alăpta",
    "alăptează": "alăpta",
    "alăptez": "alăpta",
    "alăpteze": "alăpta",
    "alăptezi": "alăpta",
    "alăptarea": "alăptare",
    "alăptări": "alăptare",
    "alăptării": "alăptare",
    "alăptările": "alăptare",
    "alăptărilor": "alăptare",
    "alăptata": "alăptat",
    "alăptată": "alăptat",
    "alăptate": "alăptat",
    "alăptatei": "alăptat",
    "alăptatele": "alăptat",
    "alăptatelor": "alăptat",
    "alăptați": "alăptat",
    "alăptații": "alăptat",
    "alăptaților": "alăptat",
    "alăptatul": "alăptat",
    "alăptatului": "alăptat",
    "alarmă": "alarma",
    "alarmai": "alarma",
    "alarmam": "alarma",
    "alarmăm": "alarma",
    "alarmând": "alarma",
    "alarmându": "alarma",
    "alarmară": "alarma",
    "alarmarăm": "alarma",
    "alarmarăți": "alarma",
    "alarmase": "alarma",
    "alarmasem": "alarma",
    "alarmaseră": "alarma",
    "alarmaserăm": "alarma",
    "alarmaserăți": "alarma",
    "alarmaseși": "alarma",
    "alarmași": "alarma",
    "alarmat": "alarma",
    "alarmați": "alarma",
    "alarmatu": "alarma",
    "alarmau": "alarma",
    "alarmează": "alarma",
    "alarmez": "alarma",
    "alarmeze": "alarma",
    "alarmezi": "alarma",
    "nealarmând": "alarma",
    "nealarmându": "alarma",
    "nemaialarmând": "alarma",
    "nemaialarmându": "alarma",
    "alarma": "alarmă",
    "alarme": "alarmă",
    "alarmei": "alarmă",
    "alarmele": "alarmă",
    "alarmelor": "alarmă",
    "alarmanta": "alarmant",
    "alarmantă": "alarmant",
    "alarmante": "alarmant",
    "alarmantei": "alarmant",
    "alarmantele": "alarmant",
    "alarmantelor": "alarmant",
    "alarmanți": "alarmant",
    "alarmanții": "alarmant",
    "alarmanților": "alarmant",
    "alarmantul": "alarmant",
    "alarmantului": "alarmant",
    "alarmanta": "alarmantă",
    "alarmante": "alarmantă",
    "alarmantei": "alarmantă",
    "alarmantele": "alarmantă",
    "alarmantelor": "alarmantă",
    "alarmarea": "alarmare",
    "alarmări": "alarmare",
    "alarmării": "alarmare",
    "alarmările": "alarmare",
    "alarmata": "alarmat",
    "alarmată": "alarmat",
    "alarmate": "alarmat",
    "alarmatei": "alarmat",
    "alarmatele": "alarmat",
    "alarmatelor": "alarmat",
    "alarmați": "alarmat",
    "alarmații": "alarmat",
    "alarmaților": "alarmat",
    "alarmatul": "alarmat",
    "alarmatului": "alarmat",
    "alarmiști": "alarmist",
    "alarmiștii": "alarmist",
    "alarmiștilor": "alarmist",
    "alarmistul": "alarmist",
    "alarmistului": "alarmist",
    "alarmista": "alarmistă",
    "alarmiste": "alarmistă",
    "alarmistei": "alarmistă",
    "alarmistele": "alarmistă",
    "alarmistelor": "alarmistă",
    "alătur": "alătura",
    "alătură": "alătura",
    "alăturai": "alătura",
    "alăturam": "alătura",
    "alăturăm": "alătura",
    "alăturând": "alătura",
    "alăturându": "alătura",
    "alăturară": "alătura",
    "alăturarăm": "alătura",
    "alăturarăți": "alătura",
    "alăturase": "alătura",
    "alăturasem": "alătura",
    "alăturaseră": "alătura",
    "alăturaserăm": "alătura",
    "alăturaserăți": "alătura",
    "alăturaseși": "alătura",
    "alăturași": "alătura",
    "alăturat": "alătura",
    "alăturați": "alătura",
    "alăturatu": "alătura",
    "alăturau": "alătura",
    "alăture": "alătura",
    "alături": "alătura",
    "nealăturând": "alătura",
    "nealăturându": "alătura",
    "nemaialăturând": "alătura",
    "nemaialăturându": "alătura",
    "alăturarea": "alăturare",
    "alăturări": "alăturare",
    "alăturării": "alăturare",
    "alăturările": "alăturare",
    "alăturata": "alăturat",
    "alăturată": "alăturat",
    "alăturate": "alăturat",
    "alăturatele": "alăturat",
    "alăturatelor": "alăturat",
    "alăturați": "alăturat",
    "alăturații": "alăturat",
    "alăturaților": "alăturat",
    "alăturatul": "alăturat",
    "alăturatului": "alăturat",
    "alăuta": "alăută",
    "alăute": "alăută",
    "alăutei": "alăută",
    "alăutele": "alăută",
    "alăutelor": "alăută",
    "alba": "alb",
    "albă": "alb",
    "albe": "alb",
    "albei": "alb",
    "albele": "alb",
    "albelor": "alb",
    "albi": "alb",
    "albii": "alb",
    "albilor": "alb",
    "albul": "alb",
    "albului": "alb",
    "albaneza": "albanez",
    "albaneză": "albanez",
    "albaneze": "albanez",
    "albanezei": "albanez",
    "albanezele": "albanez",
    "albanezelor": "albanez",
    "albanezi": "albanez",
    "albanezii": "albanez",
    "albanezilor": "albanez",
    "albanezul": "albanez",
    "albanezului": "albanez",
    "alb.": "albaneză",
    "albăstreaua": "albăstrea",
    "albăstrele": "albăstrea",
    "albăstrelei": "albăstrea",
    "albăstrelele": "albăstrea",
    "albăstrelelor": "albăstrea",
    "albăstrea": "albăstrel",
    "albăstreaua": "albăstrel",
    "albăstrei": "albăstrel",
    "albăstreii": "albăstrel",
    "albăstreilor": "albăstrel",
    "albăstrele": "albăstrel",
    "albăstrelei": "albăstrel",
    "albăstrelele": "albăstrel",
    "albăstrelelor": "albăstrel",
    "albăstrelul": "albăstrel",
    "albăstrelului": "albăstrel",
    "albăstrica": "albăstrel",
    "albăstrică": "albăstrel",
    "albăstricei": "albăstrel",
    "albăstricii": "albăstrel",
    "albăstricile": "albăstrel",
    "albăstricilor": "albăstrel",
    "albăstrioara": "albăstrior",
    "albăstrioară": "albăstrior",
    "albăstrioare": "albăstrior",
    "albăstrioarei": "albăstrior",
    "albăstrioarele": "albăstrior",
    "albăstrioarelor": "albăstrior",
    "albăstriori": "albăstrior",
    "albăstriorii": "albăstrior",
    "albăstriorilor": "albăstrior",
    "albăstriorul": "albăstrior",
    "albăstriorului": "albăstrior",
    "albăstrita": "albăstrit",
    "albăstrită": "albăstrit",
    "albăstrite": "albăstrit",
    "albăstritei": "albăstrit",
    "albăstritele": "albăstrit",
    "albăstritelor": "albăstrit",
    "albăstriți": "albăstrit",
    "albăstriții": "albăstrit",
    "albăstriților": "albăstrit",
    "albăstritul": "albăstrit",
    "albăstritului": "albăstrit",
    "albăstria": "albăstriu",
    "albăstrie": "albăstriu",
    "albăstriei": "albăstriu",
    "albăstrii": "albăstriu",
    "albăstriii": "albăstriu",
    "albăstriile": "albăstriu",
    "albăstriilor": "albăstriu",
    "albăstrioarelor": "albăstriu",
    "albăstriul": "albăstriu",
    "albăstriului": "albăstriu",
    "albastra": "albastru",
    "albastră": "albastru",
    "albastre": "albastru",
    "albastrei": "albastru",
    "albastrele": "albastru",
    "albastrelor": "albastru",
    "albaștri": "albastru",
    "albaștrii": "albastru",
    "albaștrilor": "albastru",
    "albastrul": "albastru",
    "albastrului": "albastru",
    "albeața": "albeață",
    "albețele": "albeață",
    "albeți": "albeață",
    "albeții": "albeață",
    "albeților": "albeață",
    "albea": "albi",
    "albeai": "albi",
    "albeam": "albi",
    "albească": "albi",
    "albeați": "albi",
    "albeau": "albi",
    "albesc": "albi",
    "albește": "albi",
    "albești": "albi",
    "albii": "albi",
    "albim": "albi",
    "albind": "albi",
    "albindu": "albi",
    "albiră": "albi",
    "albirăm": "albi",
    "albirăți": "albi",
    "albise": "albi",
    "albisem": "albi",
    "albiseră": "albi",
    "albiserăm": "albi",
    "albiserăți": "albi",
    "albiseși": "albi",
    "albiși": "albi",
    "albit": "albi",
    "albiți": "albi",
    "albitu": "albi",
    "nealbind": "albi",
    "nealbindu": "albi",
    "nemaialbind": "albi",
    "nemaialbindu": "albi",
    "albicioasa": "albicios",
    "albicioasă": "albicios",
    "albicioase": "albicios",
    "albicioasei": "albicios",
    "albicioasele": "albicios",
    "albicioaselor": "albicios",
    "albicioși": "albicios",
    "albicioșii": "albicios",
    "albicioșilor": "albicios",
    "albiciosul": "albicios",
    "albiciosului": "albicios",
    "albia": "albie",
    "albiei": "albie",
    "albii": "albie",
    "albiile": "albie",
    "albiilor": "albie",
    "albina": "albină",
    "albine": "albină",
    "albinei": "albină",
    "albinele": "albină",
    "albinelor": "albină",
    "albirea": "albire",
    "albiri": "albire",
    "albirii": "albire",
    "albirile": "albire",
    "albita": "albit",
    "albită": "albit",
    "albite": "albit",
    "albitei": "albit",
    "albitele": "albit",
    "albitelor": "albit",
    "albiți": "albit",
    "albiții": "albit",
    "albiților": "albit",
    "albitul": "albit",
    "albitului": "albit",
    "albitoarea": "albitoare",
    "albitoarei": "albitoare",
    "albitoarele": "albitoare",
    "albitoarelor": "albitoare",
    "albitori": "albitor",
    "albitorii": "albitor",
    "albitorilor": "albitor",
    "albitorul": "albitor",
    "albitorului": "albitor",
    "albume": "album",
    "albumele": "album",
    "albumelor": "album",
    "albumul": "album",
    "albumului": "album",
    "albumina": "albumină",
    "albumine": "albumină",
    "albuminei": "albumină",
    "albuminele": "albumină",
    "albuminelor": "albumină",
    "albuminoida": "albuminoid",
    "albuminoidă": "albuminoid",
    "albuminoide": "albuminoid",
    "albuminoidei": "albuminoid",
    "albuminoidele": "albuminoid",
    "albuminoidelor": "albuminoid",
    "albuminoidul": "albuminoid",
    "albuminoidului": "albuminoid",
    "albuminoizi": "albuminoid",
    "albuminoizii": "albuminoid",
    "albuminoizilor": "albuminoid",
    "albuminoasa": "albuminos",
    "albuminoasă": "albuminos",
    "albuminoase": "albuminos",
    "albuminoasei": "albuminos",
    "albuminoasele": "albuminos",
    "albuminoaselor": "albuminos",
    "albuminoși": "albuminos",
    "albuminoșii": "albuminos",
    "albuminoșilor": "albuminos",
    "albuminosul": "albuminos",
    "albuminosului": "albuminos",
    "albuminuria": "albuminurie",
    "albuminuriei": "albuminurie",
    "albuminurii": "albuminurie",
    "albuminuriile": "albuminurie",
    "albuminuriilor": "albuminurie",
    "alburia": "alburiu",
    "alburie": "alburiu",
    "alburiei": "alburiu",
    "alburii": "alburiu",
    "alburiii": "alburiu",
    "alburiile": "alburiu",
    "alburiilor": "alburiu",
    "alburiul": "alburiu",
    "alburiului": "alburiu",
    "alc.": "alcalin",
    "alcalina": "alcalin",
    "alcalină": "alcalin",
    "alcaline": "alcalin",
    "alcalinei": "alcalin",
    "alcalinele": "alcalin",
    "alcalinelor": "alcalin",
    "alcalini": "alcalin",
    "alcalinii": "alcalin",
    "alcalinilor": "alcalin",
    "alcalinul": "alcalin",
    "alcalinului": "alcalin",
    "alcătuia": "alcătui",
    "alcătuiai": "alcătui",
    "alcătuiam": "alcătui",
    "alcătuiască": "alcătui",
    "alcătuiați": "alcătui",
    "alcătuiau": "alcătui",
    "alcătuiesc": "alcătui",
    "alcătuiește": "alcătui",
    "alcătuiești": "alcătui",
    "alcătuii": "alcătui",
    "alcătuim": "alcătui",
    "alcătuind": "alcătui",
    "alcătuindu": "alcătui",
    "alcătuiră": "alcătui",
    "alcătuirăm": "alcătui",
    "alcătuirăți": "alcătui",
    "alcătuise": "alcătui",
    "alcătuisem": "alcătui",
    "alcătuiseră": "alcătui",
    "alcătuiserăm": "alcătui",
    "alcătuiserăți": "alcătui",
    "alcătuiseși": "alcătui",
    "alcătuiși": "alcătui",
    "alcătuit": "alcătui",
    "alcătuiți": "alcătui",
    "alcătuitu": "alcătui",
    "nealcătuind": "alcătui",
    "nealcătuindu": "alcătui",
    "nemaialcătuind": "alcătui",
    "nemaialcătuindu": "alcătui",
    "alcătuirea": "alcătuire",
    "alcătuiri": "alcătuire",
    "alcătuirii": "alcătuire",
    "alcătuirile": "alcătuire",
    "alcătuita": "alcătuit",
    "alcătuită": "alcătuit",
    "alcătuite": "alcătuit",
    "alcătuitei": "alcătuit",
    "alcătuitele": "alcătuit",
    "alcătuitelor": "alcătuit",
    "alcătuiți": "alcătuit",
    "alcătuiții": "alcătuit",
    "alcătuiților": "alcătuit",
    "alcătuitul": "alcătuit",
    "alcătuitului": "alcătuit",
    "alcătuitoare": "alcătuitor",
    "alcătuitoarea": "alcătuitor",
    "alcătuitoarei": "alcătuitor",
    "alcătuitoarele": "alcătuitor",
    "alcătuitoarelor": "alcătuitor",
    "alcătuitori": "alcătuitor",
    "alcătuitorii": "alcătuitor",
    "alcătuitorilor": "alcătuitor",
    "alcătuitorul": "alcătuitor",
    "alcătuitorului": "alcătuitor",
    "alchimia": "alchimie",
    "alchimiei": "alchimie",
    "alchimii": "alchimie",
    "alchimiile": "alchimie",
    "alchimiilor": "alchimie",
    "alcooli": "alcool",
    "alcoolii": "alcool",
    "alcoolilor": "alcool",
    "alcoolul": "alcool",
    "alcoolului": "alcool",
    "alcooluri": "alcool",
    "alcoolurile": "alcool",
    "alcoolurilor": "alcool",
    "alcoolica": "alcoolic",
    "alcoolică": "alcoolic",
    "alcoolice": "alcoolic",
    "alcoolicei": "alcoolic",
    "alcoolicele": "alcoolic",
    "alcoolicelor": "alcoolic",
    "alcoolici": "alcoolic",
    "alcoolicii": "alcoolic",
    "alcoolicilor": "alcoolic",
    "alcoolicul": "alcoolic",
    "alcoolicului": "alcoolic",
    "alcoolica": "alcoolică",
    "alcoolice": "alcoolică",
    "alcoolicei": "alcoolică",
    "alcoolicele": "alcoolică",
    "alcoolicelor": "alcoolică",
    "alcoolismul": "alcoolism",
    "alcoolismului": "alcoolism",
    "alcoolizata": "alcoolizat",
    "alcoolizată": "alcoolizat",
    "alcoolizate": "alcoolizat",
    "alcoolizatei": "alcoolizat",
    "alcoolizatele": "alcoolizat",
    "alcoolizatelor": "alcoolizat",
    "alcoolizați": "alcoolizat",
    "alcoolizații": "alcoolizat",
    "alcoolizaților": "alcoolizat",
    "alcoolizatul": "alcoolizat",
    "alcoolizatului": "alcoolizat",
    "alcovul": "alcov",
    "alcovului": "alcov",
    "alcovuri": "alcov",
    "alcovurile": "alcov",
    "alcovurilor": "alcov",
    "aldămașul": "aldămaș",
    "aldămașului": "aldămaș",
    "aldămașuri": "aldămaș",
    "aldămașurile": "aldămaș",
    "aldămașurilor": "aldămaș",
    "aldina": "aldin",
    "aldină": "aldin",
    "aldine": "aldin",
    "aldinei": "aldin",
    "aldinele": "aldin",
    "aldinelor": "aldin",
    "aldinul": "aldin",
    "aldinului": "aldin",
    "aldina": "aldină",
    "aldine": "aldină",
    "aldinei": "aldină",
    "aldinele": "aldină",
    "aldinelor": "aldină",
    "aleanul": "alean",
    "aleanului": "alean",
    "aleanuri": "alean",
    "aleanurile": "alean",
    "aleanurilor": "alean",
    "aleasa": "aleasă",
    "alese": "aleasă",
    "alesei": "aleasă",
    "alesele": "aleasă",
    "aleselor": "aleasă",
    "aleatoria": "aleatoriu",
    "aleatorie": "aleatoriu",
    "aleatoriei": "aleatoriu",
    "aleatorii": "aleatoriu",
    "aleatoriii": "aleatoriu",
    "aleatoriile": "aleatoriu",
    "aleatoriilor": "aleatoriu",
    "aleatoriul": "aleatoriu",
    "aleatoriului": "aleatoriu",
    "aleea": "alee",
    "alei": "alee",
    "aleii": "alee",
    "aleile": "alee",
    "aleilor": "alee",
    "alegătoarea": "alegătoare",
    "alegătoarei": "alegătoare",
    "alegătoarele": "alegătoare",
    "alegătoarelor": "alegătoare",
    "alegători": "alegător",
    "alegătorii": "alegător",
    "alegătorilor": "alegător",
    "alegătorul": "alegător",
    "alegătorului": "alegător",
    "aleagă": "alege",
    "aleg": "alege",
    "alegând": "alege",
    "alegându": "alege",
    "alegea": "alege",
    "alegeai": "alege",
    "alegeam": "alege",
    "alegeați": "alege",
    "alegeau": "alege",
    "alegem": "alege",
    "alegeți": "alege",
    "alegi": "alege",
    "ales": "alege",
    "alese": "alege",
    "alesei": "alege",
    "aleseră": "alege",
    "aleserăm": "alege",
    "aleserăți": "alege",
    "alesese": "alege",
    "alesesem": "alege",
    "aleseseră": "alege",
    "aleseserăm": "alege",
    "aleseserăți": "alege",
    "aleseseși": "alege",
    "aleseși": "alege",
    "alesu": "alege",
    "nealegând": "alege",
    "nealegându": "alege",
    "nemaialegând": "alege",
    "nemaialegându": "alege",
    "alegerea": "alegere",
    "alegeri": "alegere",
    "alegerii": "alegere",
    "alegerile": "alegere",
    "alegerilor": "alegere",
    "alegorica": "alegoric",
    "alegorică": "alegoric",
    "alegorice": "alegoric",
    "alegoricei": "alegoric",
    "alegoricele": "alegoric",
    "alegoricelor": "alegoric",
    "alegorici": "alegoric",
    "alegoricii": "alegoric",
    "alegoricilor": "alegoric",
    "alegoricul": "alegoric",
    "alegoricului": "alegoric",
    "alegoria": "alegorie",
    "alegoriei": "alegorie",
    "alegorii": "alegorie",
    "alegoriile": "alegorie",
    "alegoriilor": "alegorie",
    "alegra": "alegru",
    "alegră": "alegru",
    "alegre": "alegru",
    "alegrei": "alegru",
    "alegrele": "alegru",
    "alegrelor": "alegru",
    "alegri": "alegru",
    "alegrii": "alegru",
    "alegrilor": "alegru",
    "alegrul": "alegru",
    "alegrului": "alegru",
    "alandala": "alene",
    "aleargă": "alerga",
    "alerg": "alerga",
    "alergă": "alerga",
    "alergai": "alerga",
    "alergam": "alerga",
    "alergăm": "alerga",
    "alergând": "alerga",
    "alergându": "alerga",
    "alergase": "alerga",
    "alergasem": "alerga",
    "alergaseră": "alerga",
    "alergaserăm": "alerga",
    "alergaserăți": "alerga",
    "alergaseși": "alerga",
    "alergași": "alerga",
    "alergat": "alerga",
    "alergați": "alerga",
    "alergatu": "alerga",
    "alergau": "alerga",
    "alerge": "alerga",
    "alergi": "alerga",
    "nealergând": "alerga",
    "nealergându": "alerga",
    "nemaialergând": "alerga",
    "nemaialergându": "alerga",
    "alergarea": "alergare",
    "alergări": "alergare",
    "alergării": "alergare",
    "alergările": "alergare",
    "alergata": "alergat",
    "alergată": "alergat",
    "alergate": "alergat",
    "alergatei": "alergat",
    "alergatele": "alergat",
    "alergatelor": "alergat",
    "alergați": "alergat",
    "alergații": "alergat",
    "alergaților": "alergat",
    "alergatul": "alergat",
    "alergatului": "alergat",
    "alergătoarea": "alergătoare",
    "alergătoarei": "alergătoare",
    "alergătoarele": "alergătoare",
    "alergătoarelor": "alergătoare",
    "alergători": "alergător",
    "alergătorii": "alergător",
    "alergătorilor": "alergător",
    "alergătorul": "alergător",
    "alergătorului": "alergător",
    "alergătura": "alergătură",
    "alergături": "alergătură",
    "alergăturii": "alergătură",
    "alergăturile": "alergătură",
    "alergăturilor": "alergătură",
    "alergia": "alergie",
    "alergiei": "alergie",
    "alergii": "alergie",
    "alergiile": "alergie",
    "alergiilor": "alergie",
    "alerta": "alert",
    "alertă": "alert",
    "alerte": "alert",
    "alertei": "alert",
    "alertele": "alert",
    "alertelor": "alert",
    "alerți": "alert",
    "alerții": "alert",
    "alerților": "alert",
    "alertul": "alert",
    "alertului": "alert",
    "alertat": "alerta",
    "alerta": "alertă",
    "alerte": "alertă",
    "alertei": "alertă",
    "alertele": "alertă",
    "alertelor": "alertă",
    "alertată": "alertat",
    "alertate": "alertat",
    "alertați": "alertat",
    "aleasa": "ales",
    "aleasă": "ales",
    "alese": "ales",
    "alesei": "ales",
    "alesele": "ales",
    "aleselor": "ales",
    "aleși": "ales",
    "aleșii": "ales",
    "aleșilor": "ales",
    "alesul": "ales",
    "alesului": "ales",
    "alexandrina": "alexandrin",
    "alexandrină": "alexandrin",
    "alexandrinul": "alexandrin",
    "alexandrinului": "alexandrin",
    "Al.": "Alexandru",
    "aleză": "aleza",
    "alezai": "aleza",
    "alezam": "aleza",
    "alezăm": "aleza",
    "alezând": "aleza",
    "alezându": "aleza",
    "alezară": "aleza",
    "alezarăm": "aleza",
    "alezarăți": "aleza",
    "alezase": "aleza",
    "alezasem": "aleza",
    "alezaseră": "aleza",
    "alezaserăm": "aleza",
    "alezaserăți": "aleza",
    "alezaseși": "aleza",
    "alezași": "aleza",
    "alezat": "aleza",
    "alezați": "aleza",
    "alezatu": "aleza",
    "alezau": "aleza",
    "alezează": "aleza",
    "alezez": "aleza",
    "alezeze": "aleza",
    "alezezi": "aleza",
    "nealezând": "aleza",
    "nealezându": "aleza",
    "nemaialezând": "aleza",
    "nemaialezându": "aleza",
    "alezarea": "alezare",
    "alezări": "alezare",
    "alezării": "alezare",
    "alezările": "alezare",
    "alezata": "alezat",
    "alezată": "alezat",
    "alezate": "alezat",
    "alezatei": "alezat",
    "alezatele": "alezat",
    "alezatelor": "alezat",
    "alezați": "alezat",
    "alezații": "alezat",
    "alezaților": "alezat",
    "alezatul": "alezat",
    "alezatului": "alezat",
    "alfabetul": "alfabet",
    "alfabetului": "alfabet",
    "alfabeturi": "alfabet",
    "alfabeturile": "alfabet",
    "alfabeturilor": "alfabet",
    "alfabetica": "alfabetic",
    "alfabetică": "alfabetic",
    "alfabeticul": "alfabetic",
    "alfabeticului": "alfabetic",
    "alfabetiză": "alfabetiza",
    "alfabetizai": "alfabetiza",
    "alfabetizam": "alfabetiza",
    "alfabetizăm": "alfabetiza",
    "alfabetizând": "alfabetiza",
    "alfabetizându": "alfabetiza",
    "alfabetizară": "alfabetiza",
    "alfabetizarăm": "alfabetiza",
    "alfabetizarăți": "alfabetiza",
    "alfabetizase": "alfabetiza",
    "alfabetizasem": "alfabetiza",
    "alfabetizaseră": "alfabetiza",
    "alfabetizaserăm": "alfabetiza",
    "alfabetizaserăți": "alfabetiza",
    "alfabetizaseși": "alfabetiza",
    "alfabetizași": "alfabetiza",
    "alfabetizat": "alfabetiza",
    "alfabetizați": "alfabetiza",
    "alfabetizatu": "alfabetiza",
    "alfabetizau": "alfabetiza",
    "alfabetizează": "alfabetiza",
    "alfabetizez": "alfabetiza",
    "alfabetizeze": "alfabetiza",
    "alfabetizezi": "alfabetiza",
    "nealfabetizând": "alfabetiza",
    "nealfabetizându": "alfabetiza",
    "nemaialfabetizând": "alfabetiza",
    "nemaialfabetizându": "alfabetiza",
    "alfabetizarea": "alfabetizare",
    "alfabetizări": "alfabetizare",
    "alfabetizării": "alfabetizare",
    "alfabetizările": "alfabetizare",
    "alfabetizata": "alfabetizat",
    "alfabetizată": "alfabetizat",
    "alfabetizate": "alfabetizat",
    "alfabetizatei": "alfabetizat",
    "alfabetizatele": "alfabetizat",
    "alfabetizatelor": "alfabetizat",
    "alfabetizați": "alfabetizat",
    "alfabetizații": "alfabetizat",
    "alfabetizaților": "alfabetizat",
    "alfabetizatul": "alfabetizat",
    "alfabetizatului": "alfabetizat",
    "alga": "algă",
    "alge": "algă",
    "algei": "algă",
    "algele": "algă",
    "algelor": "algă",
    "algebra": "algebră",
    "algebre": "algebră",
    "algebrei": "algebră",
    "algebrele": "algebră",
    "algebrelor": "algebră",
    "algebrica": "algebric",
    "algebrică": "algebric",
    "algebrice": "algebric",
    "algebricei": "algebric",
    "algebricele": "algebric",
    "algebricelor": "algebric",
    "algebrici": "algebric",
    "algebricii": "algebric",
    "algebricilor": "algebric",
    "algebricul": "algebric",
    "algebricului": "algebric",
    "algeriana": "algerian",
    "algeriană": "algerian",
    "algerianul": "algerian",
    "algerianului": "algerian",
    "algeriene": "algerian",
    "algerienei": "algerian",
    "algerienele": "algerian",
    "algerienelor": "algerian",
    "algerieni": "algerian",
    "algerienii": "algerian",
    "algerienilor": "algerian",
    "algoritme": "algoritm",
    "algoritmele": "algoritm",
    "algoritmelor": "algoritm",
    "algoritmi": "algoritm",
    "algoritmii": "algoritm",
    "algoritmilor": "algoritm",
    "algoritmul": "algoritm",
    "algoritmului": "algoritm",
    "aliai": "alia",
    "aliam": "alia",
    "aliară": "alia",
    "aliarăm": "alia",
    "aliarăți": "alia",
    "aliase": "alia",
    "aliasem": "alia",
    "aliaseră": "alia",
    "aliaserăm": "alia",
    "aliaserăți": "alia",
    "aliaseși": "alia",
    "aliași": "alia",
    "aliat": "alia",
    "aliați": "alia",
    "aliatu": "alia",
    "aliau": "alia",
    "aliază": "alia",
    "alie": "alia",
    "aliem": "alia",
    "aliez": "alia",
    "alieze": "alia",
    "aliezi": "alia",
    "aliind": "alia",
    "aliindu": "alia",
    "nealiind": "alia",
    "nealiindu": "alia",
    "nemaialiind": "alia",
    "nemaialiindu": "alia",
    "al.e.": "alia_editio",
    "aliaje": "aliaj",
    "aliajele": "aliaj",
    "aliajelor": "aliaj",
    "aliajul": "aliaj",
    "aliajului": "aliaj",
    "alianța": "alianță",
    "alianțe": "alianță",
    "alianței": "alianță",
    "alianțele": "alianță",
    "alianțelor": "alianță",
    "aliata": "aliat",
    "aliată": "aliat",
    "aliate": "aliat",
    "aliatei": "aliat",
    "aliatele": "aliat",
    "aliatelor": "aliat",
    "aliați": "aliat",
    "aliații": "aliat",
    "aliaților": "aliat",
    "aliatul": "aliat",
    "aliatului": "aliat",
    "aliata": "aliată",
    "aliate": "aliată",
    "aliatei": "aliată",
    "aliatele": "aliată",
    "aliatelor": "aliată",
    "alibiul": "alibi",
    "alibiului": "alibi",
    "alibiuri": "alibi",
    "alibiurile": "alibi",
    "alibiurilor": "alibi",
    "alica": "alică",
    "alice": "alică",
    "alicei": "alică",
    "alicele": "alică",
    "alicelor": "alică",
    "alienă": "aliena",
    "alienai": "aliena",
    "alienam": "aliena",
    "alienăm": "aliena",
    "alienând": "aliena",
    "alienându": "aliena",
    "alienară": "aliena",
    "alienarăm": "aliena",
    "alienarăți": "aliena",
    "alienase": "aliena",
    "alienasem": "aliena",
    "alienaseră": "aliena",
    "alienaserăm": "aliena",
    "alienaserăți": "aliena",
    "alienaseși": "aliena",
    "alienași": "aliena",
    "alienat": "aliena",
    "alienați": "aliena",
    "alienatu": "aliena",
    "alienau": "aliena",
    "alienează": "aliena",
    "alienez": "aliena",
    "alieneze": "aliena",
    "alienezi": "aliena",
    "nealienând": "aliena",
    "nealienându": "aliena",
    "nemaialienând": "aliena",
    "nemaialienându": "aliena",
    "alienabila": "alienabil",
    "alienabilă": "alienabil",
    "alienabile": "alienabil",
    "alienabilei": "alienabil",
    "alienabilele": "alienabil",
    "alienabilelor": "alienabil",
    "alienabili": "alienabil",
    "alienabilii": "alienabil",
    "alienabililor": "alienabil",
    "alienabilul": "alienabil",
    "alienabilului": "alienabil",
    "alienarea": "alienare",
    "alienări": "alienare",
    "alienării": "alienare",
    "alienările": "alienare",
    "alienata": "alienat",
    "alienată": "alienat",
    "alienate": "alienat",
    "alienatei": "alienat",
    "alienatele": "alienat",
    "alienatelor": "alienat",
    "alienați": "alienat",
    "alienații": "alienat",
    "alienaților": "alienat",
    "alienatul": "alienat",
    "alienatului": "alienat",
    "alienata": "alienată",
    "alienate": "alienată",
    "alienatei": "alienată",
    "alienatele": "alienată",
    "alienatelor": "alienată",
    "alienista": "alienist",
    "alienistă": "alienist",
    "alieniste": "alienist",
    "alienistei": "alienist",
    "alienistele": "alienist",
    "alienistelor": "alienist",
    "alieniști": "alienist",
    "alieniștii": "alienist",
    "alieniștilor": "alienist",
    "alienistul": "alienist",
    "alienistului": "alienist",
    "alierea": "aliere",
    "alieri": "aliere",
    "alierii": "aliere",
    "alierile": "aliere",
    "alifia": "alifie",
    "alifiei": "alifie",
    "alifii": "alifie",
    "alifiile": "alifie",
    "alifiilor": "alifie",
    "alilodidactica": "alilodidactic",
    "alilodidactică": "alilodidactic",
    "alilodidactice": "alilodidactic",
    "alilodidacticei": "alilodidactic",
    "alilodidacticele": "alilodidactic",
    "alilodidacticelor": "alilodidactic",
    "alilodidactici": "alilodidactic",
    "alilodidacticii": "alilodidactic",
    "alilodidacticilor": "alilodidactic",
    "alilodidacticul": "alilodidactic",
    "alilodidacticului": "alilodidactic",
    "alimane": "aliman",
    "alimanele": "aliman",
    "alimanelor": "aliman",
    "alimanul": "aliman",
    "alimanului": "aliman",
    "alimente": "aliment",
    "alimentele": "aliment",
    "alimentelor": "aliment",
    "alimentul": "aliment",
    "alimentului": "aliment",
    "alimentă": "alimenta",
    "alimentai": "alimenta",
    "alimentam": "alimenta",
    "alimentăm": "alimenta",
    "alimentând": "alimenta",
    "alimentându": "alimenta",
    "alimentară": "alimenta",
    "alimentarăm": "alimenta",
    "alimentarăți": "alimenta",
    "alimentase": "alimenta",
    "alimentasem": "alimenta",
    "alimentaseră": "alimenta",
    "alimentaserăm": "alimenta",
    "alimentaserăți": "alimenta",
    "alimentaseși": "alimenta",
    "alimentași": "alimenta",
    "alimentat": "alimenta",
    "alimentați": "alimenta",
    "alimentatu": "alimenta",
    "alimentau": "alimenta",
    "alimentează": "alimenta",
    "alimentez": "alimenta",
    "alimenteze": "alimenta",
    "alimentezi": "alimenta",
    "nealimentând": "alimenta",
    "nealimentându": "alimenta",
    "nemaialimentând": "alimenta",
    "nemaialimentându": "alimenta",
    "alimentara": "alimentar",
    "alimentară": "alimentar",
    "alimentare": "alimentar",
    "alimentarul": "alimentar",
    "alimentarului": "alimentar",
    "alim.": "alimentară",
    "alimentara": "alimentară",
    "alimentare": "alimentară",
    "alimentarea": "alimentare",
    "alimentări": "alimentare",
    "alimentării": "alimentare",
    "alimentările": "alimentare",
    "alimentata": "alimentat",
    "alimentată": "alimentat",
    "alimentate": "alimentat",
    "alimentatei": "alimentat",
    "alimentatele": "alimentat",
    "alimentatelor": "alimentat",
    "alimentați": "alimentat",
    "alimentații": "alimentat",
    "alimentaților": "alimentat",
    "alimentatul": "alimentat",
    "alimentatului": "alimentat",
    "alimentația": "alimentație",
    "alimentației": "alimentație",
    "alimentații": "alimentație",
    "alimentațiile": "alimentație",
    "alimentațiilor": "alimentație",
    "alin": "alina",
    "alină": "alina",
    "alinai": "alina",
    "alinam": "alina",
    "alinăm": "alina",
    "alinând": "alina",
    "alinându": "alina",
    "alinară": "alina",
    "alinarăm": "alina",
    "alinarăți": "alina",
    "alinase": "alina",
    "alinasem": "alina",
    "alinaseră": "alina",
    "alinaserăm": "alina",
    "alinaserăți": "alina",
    "alinaseși": "alina",
    "alinași": "alina",
    "alinat": "alina",
    "alinați": "alina",
    "alinatu": "alina",
    "alinau": "alina",
    "aline": "alina",
    "Alinei": "Alina",
    "alini": "alina",
    "nealinând": "alina",
    "nealinându": "alina",
    "nemaialinând": "alina",
    "nemaialinându": "alina",
    "alinarea": "alinare",
    "alinări": "alinare",
    "alinării": "alinare",
    "alinările": "alinare",
    "alinata": "alinat",
    "alinată": "alinat",
    "alinate": "alinat",
    "alinatei": "alinat",
    "alinatele": "alinat",
    "alinatelor": "alinat",
    "alinați": "alinat",
    "alinații": "alinat",
    "alinaților": "alinat",
    "alinatul": "alinat",
    "alinatului": "alinat",
    "alinătoarea": "alinătoare",
    "alinătoarei": "alinătoare",
    "alinătoarele": "alinătoare",
    "alinătoarelor": "alinătoare",
    "alinătoare": "alinător",
    "alinătoarea": "alinător",
    "alinătoarei": "alinător",
    "alinătoarele": "alinător",
    "alinătoarelor": "alinător",
    "alinători": "alinător",
    "alinătorii": "alinător",
    "alinătorilor": "alinător",
    "alinătorul": "alinător",
    "alinătorului": "alinător",
    "alinătura": "alinătură",
    "alinături": "alinătură",
    "alinăturii": "alinătură",
    "alinăturile": "alinătură",
    "alinăturilor": "alinătură",
    "alineate": "alineat",
    "alineatele": "alineat",
    "alineatelor": "alineat",
    "alineatul": "alineat",
    "alineatului": "alineat",
    "aliniai": "alinia",
    "aliniam": "alinia",
    "aliniară": "alinia",
    "aliniarăm": "alinia",
    "aliniarăți": "alinia",
    "aliniase": "alinia",
    "aliniasem": "alinia",
    "aliniaseră": "alinia",
    "aliniaserăm": "alinia",
    "aliniaserăți": "alinia",
    "aliniaseși": "alinia",
    "aliniași": "alinia",
    "aliniat": "alinia",
    "aliniați": "alinia",
    "aliniatu": "alinia",
    "aliniau": "alinia",
    "aliniază": "alinia",
    "alinie": "alinia",
    "aliniem": "alinia",
    "aliniez": "alinia",
    "alinieze": "alinia",
    "aliniezi": "alinia",
    "aliniind": "alinia",
    "aliniindu": "alinia",
    "nealiniind": "alinia",
    "nealiniindu": "alinia",
    "nemaialiniind": "alinia",
    "nemaialiniindu": "alinia",
    "aliniata": "aliniat",
    "aliniată": "aliniat",
    "aliniate": "aliniat",
    "aliniatei": "aliniat",
    "aliniatele": "aliniat",
    "aliniatelor": "aliniat",
    "aliniați": "aliniat",
    "aliniații": "aliniat",
    "aliniaților": "aliniat",
    "aliniatul": "aliniat",
    "aliniatului": "aliniat",
    "alinierea": "aliniere",
    "alinieri": "aliniere",
    "alinierii": "aliniere",
    "alinierile": "aliniere",
    "alintul": "alint",
    "alintului": "alint",
    "alinturi": "alint",
    "alinturile": "alint",
    "alinturilor": "alint",
    "alint": "alinta",
    "alintă": "alinta",
    "alintai": "alinta",
    "alintam": "alinta",
    "alintăm": "alinta",
    "alintând": "alinta",
    "alintându": "alinta",
    "alintară": "alinta",
    "alintarăm": "alinta",
    "alintarăți": "alinta",
    "alintase": "alinta",
    "alintasem": "alinta",
    "alintaseră": "alinta",
    "alintaserăm": "alinta",
    "alintaserăți": "alinta",
    "alintaseși": "alinta",
    "alintași": "alinta",
    "alintat": "alinta",
    "alintați": "alinta",
    "alintatu": "alinta",
    "alintau": "alinta",
    "alinte": "alinta",
    "alinți": "alinta",
    "nealintând": "alinta",
    "nealintându": "alinta",
    "nemaialintând": "alinta",
    "nemaialintându": "alinta",
    "alintarea": "alintare",
    "alintări": "alintare",
    "alintării": "alintare",
    "alintările": "alintare",
    "alintata": "alintat",
    "alintată": "alintat",
    "alintate": "alintat",
    "alintatei": "alintat",
    "alintatele": "alintat",
    "alintatelor": "alintat",
    "alintați": "alintat",
    "alintații": "alintat",
    "alintaților": "alintat",
    "alintatul": "alintat",
    "alintatului": "alintat",
    "alintata": "alintată",
    "alintate": "alintată",
    "alintatei": "alintată",
    "alintatele": "alintată",
    "alintatelor": "alintată",
    "alintătoarea": "alintătoare",
    "alintătoarei": "alintătoare",
    "alintătoarele": "alintătoare",
    "alintătoarelor": "alintătoare",
    "alintătoare": "alintător",
    "alintătoarea": "alintător",
    "alintătoarei": "alintător",
    "alintătoarele": "alintător",
    "alintătoarelor": "alintător",
    "alintători": "alintător",
    "alintătorii": "alintător",
    "alintătorilor": "alintător",
    "alintătorul": "alintător",
    "alintătorului": "alintător",
    "alintătura": "alintătură",
    "alintături": "alintătură",
    "alintăturii": "alintătură",
    "alintăturile": "alintătură",
    "alintăturilor": "alintătură",
    "aliotmani": "aliotman",
    "aliotmanii": "aliotman",
    "aliotmanilor": "aliotman",
    "aliotmanul": "aliotman",
    "aliotmanului": "aliotman",
    "alipea": "alipi",
    "alipeai": "alipi",
    "alipeam": "alipi",
    "alipească": "alipi",
    "alipeați": "alipi",
    "alipeau": "alipi",
    "alipesc": "alipi",
    "alipește": "alipi",
    "alipești": "alipi",
    "alipii": "alipi",
    "alipim": "alipi",
    "alipind": "alipi",
    "alipindu": "alipi",
    "alipiră": "alipi",
    "alipirăm": "alipi",
    "alipirăți": "alipi",
    "alipise": "alipi",
    "alipisem": "alipi",
    "alipiseră": "alipi",
    "alipiserăm": "alipi",
    "alipiserăți": "alipi",
    "alipiseși": "alipi",
    "alipiși": "alipi",
    "alipit": "alipi",
    "alipiți": "alipi",
    "alipitu": "alipi",
    "alipirea": "alipire",
    "alipiri": "alipire",
    "alipirii": "alipire",
    "alipirile": "alipire",
    "alipirilor": "alipire",
    "alipita": "alipit",
    "alipită": "alipit",
    "alipite": "alipit",
    "alipitei": "alipit",
    "alipitele": "alipit",
    "alipitelor": "alipit",
    "alipiți": "alipit",
    "alipiții": "alipit",
    "alipiților": "alipit",
    "alipitul": "alipit",
    "alipitului": "alipit",
    "aliterația": "aliterație",
    "aliterației": "aliterație",
    "aliterații": "aliterație",
    "aliterațiile": "aliterație",
    "aliterațiilor": "aliterație",
    "alizee": "alizeu",
    "alizeele": "alizeu",
    "alizeelor": "alizeu",
    "alizeul": "alizeu",
    "alizeului": "alizeu",
    "almanahul": "almanah",
    "almanahului": "almanah",
    "almanahuri": "almanah",
    "almanahurile": "almanah",
    "almanahurilor": "almanah",
    "aloc": "aloca",
    "alocă": "aloca",
    "alocai": "aloca",
    "alocam": "aloca",
    "alocăm": "aloca",
    "alocând": "aloca",
    "alocându": "aloca",
    "alocară": "aloca",
    "alocarăm": "aloca",
    "alocarăți": "aloca",
    "alocase": "aloca",
    "alocasem": "aloca",
    "alocaseră": "aloca",
    "alocaserăm": "aloca",
    "alocaserăți": "aloca",
    "alocaseși": "aloca",
    "alocași": "aloca",
    "alocat": "aloca",
    "alocați": "aloca",
    "alocatu": "aloca",
    "alocau": "aloca",
    "aloce": "aloca",
    "aloci": "aloca",
    "nealocând": "aloca",
    "nealocându": "aloca",
    "nemaialocând": "aloca",
    "nemaialocându": "aloca",
    "alocarea": "alocare",
    "alocări": "alocare",
    "alocării": "alocare",
    "alocările": "alocare",
    "alocata": "alocat",
    "alocată": "alocat",
    "alocate": "alocat",
    "alocatei": "alocat",
    "alocatele": "alocat",
    "alocatelor": "alocat",
    "alocați": "alocat",
    "alocații": "alocat",
    "alocaților": "alocat",
    "alocatul": "alocat",
    "alocatului": "alocat",
    "alocația": "alocație",
    "alocației": "alocație",
    "alocații": "alocație",
    "alocațiile": "alocație",
    "alocațiilor": "alocație",
    "alocuțiunea": "alocuțiune",
    "alocuțiuni": "alocuțiune",
    "alocuțiunii": "alocuțiune",
    "alocuțiunile": "alocuțiune",
    "alocuțiunilor": "alocuțiune",
    "alogena": "alogen",
    "alogenă": "alogen",
    "alogenul": "alogen",
    "alogenului": "alogen",
    "alotropica": "alotropic",
    "alotropică": "alotropic",
    "alotropice": "alotropic",
    "alotropicei": "alotropic",
    "alotropicele": "alotropic",
    "alotropicelor": "alotropic",
    "alotropici": "alotropic",
    "alotropicii": "alotropic",
    "alotropicilor": "alotropic",
    "alotropicul": "alotropic",
    "alotropicului": "alotropic",
    "alotropia": "alotropie",
    "alotropiei": "alotropie",
    "alotropii": "alotropie",
    "alotropiile": "alotropie",
    "alotropiilor": "alotropie",
    "alpacale": "alpaca",
    "alpacalei": "alpaca",
    "alpacalele": "alpaca",
    "alpacalelor": "alpaca",
    "alpacaua": "alpaca",
    "alpenștocul": "alpenștoc",
    "alpenștocului": "alpenștoc",
    "alpenștocuri": "alpenștoc",
    "alpenștocurile": "alpenștoc",
    "alpenștocurilor": "alpenștoc",
    "alpestra": "alpestru",
    "alpestră": "alpestru",
    "alpestre": "alpestru",
    "alpestrei": "alpestru",
    "alpestrele": "alpestru",
    "alpestrelor": "alpestru",
    "alpeștri": "alpestru",
    "alpeștrii": "alpestru",
    "alpeștrilor": "alpestru",
    "alpestrul": "alpestru",
    "alpestrului": "alpestru",
    "alpina": "alpin",
    "alpină": "alpin",
    "alpine": "alpin",
    "alpinei": "alpin",
    "alpinele": "alpin",
    "alpinelor": "alpin",
    "alpini": "alpin",
    "alpinii": "alpin",
    "alpinilor": "alpin",
    "alpinul": "alpin",
    "alpinului": "alpin",
    "alpinismul": "alpinism",
    "alpinismului": "alpinism",
    "altă": "alt",
    "alte": "alt",
    "altei": "alt",
    "alți": "alt",
    "altor": "alt",
    "altui": "alt",
    "altaica": "altaic",
    "altaică": "altaic",
    "altaice": "altaic",
    "altaicei": "altaic",
    "altaicele": "altaic",
    "altaicelor": "altaic",
    "altaici": "altaic",
    "altaicii": "altaic",
    "altaicilor": "altaic",
    "altaicul": "altaic",
    "altaicului": "altaic",
    "altare": "altar",
    "altarele": "altar",
    "altarelor": "altar",
    "altarul": "altar",
    "altarului": "altar",
    "al'ceva": "altceva",
    "altcuiva": "altcineva",
    "alteră": "altera",
    "alterai": "altera",
    "alteram": "altera",
    "alterăm": "altera",
    "alterând": "altera",
    "alterându": "altera",
    "alterară": "altera",
    "alterarăm": "altera",
    "alterarăți": "altera",
    "alterase": "altera",
    "alterasem": "altera",
    "alteraseră": "altera",
    "alteraserăm": "altera",
    "alteraserăți": "altera",
    "alteraseși": "altera",
    "alterași": "altera",
    "alterat": "altera",
    "alterați": "altera",
    "alteratu": "altera",
    "alterau": "altera",
    "alterează": "altera",
    "alterez": "altera",
    "altereze": "altera",
    "alterezi": "altera",
    "nealterând": "altera",
    "nealterându": "altera",
    "nemaialterând": "altera",
    "nemaialterându": "altera",
    "alterabila": "alterabil",
    "alterabilă": "alterabil",
    "alterabile": "alterabil",
    "alterabilei": "alterabil",
    "alterabilele": "alterabil",
    "alterabilelor": "alterabil",
    "alterabili": "alterabil",
    "alterabilii": "alterabil",
    "alterabililor": "alterabil",
    "alterabilul": "alterabil",
    "alterabilului": "alterabil",
    "alterarea": "alterare",
    "alterări": "alterare",
    "alterării": "alterare",
    "alterările": "alterare",
    "alterata": "alterat",
    "alterată": "alterat",
    "alterate": "alterat",
    "alteratei": "alterat",
    "alteratele": "alterat",
    "alteratelor": "alterat",
    "alterați": "alterat",
    "alterații": "alterat",
    "alteraților": "alterat",
    "alteratul": "alterat",
    "alteratului": "alterat",
    "altercația": "altercație",
    "altercației": "altercație",
    "altercații": "altercație",
    "altercațiile": "altercație",
    "altercațiilor": "altercație",
    "alterna": "altern",
    "alternă": "altern",
    "alterne": "altern",
    "alternei": "altern",
    "alternele": "altern",
    "alternelor": "altern",
    "alterni": "altern",
    "alternii": "altern",
    "alternilor": "altern",
    "alternul": "altern",
    "alternului": "altern",
    "alternă": "alterna",
    "alternai": "alterna",
    "alternam": "alterna",
    "alternăm": "alterna",
    "alternând": "alterna",
    "alternându": "alterna",
    "alternară": "alterna",
    "alternarăm": "alterna",
    "alternarăți": "alterna",
    "alternase": "alterna",
    "alternasem": "alterna",
    "alternaseră": "alterna",
    "alternaserăm": "alterna",
    "alternaserăți": "alterna",
    "alternaseși": "alterna",
    "alternași": "alterna",
    "alternat": "alterna",
    "alternați": "alterna",
    "alternatu": "alterna",
    "alternau": "alterna",
    "alternează": "alterna",
    "alternez": "alterna",
    "alterneze": "alterna",
    "alternezi": "alterna",
    "nealternând": "alterna",
    "nealternându": "alterna",
    "nemaialternând": "alterna",
    "nemaialternându": "alterna",
    "alternanța": "alternanță",
    "alternarea": "alternare",
    "alternări": "alternare",
    "alternării": "alternare",
    "alternările": "alternare",
    "alternata": "alternat",
    "alternată": "alternat",
    "alternate": "alternat",
    "alternatei": "alternat",
    "alternatele": "alternat",
    "alternatelor": "alternat",
    "alternați": "alternat",
    "alternații": "alternat",
    "alternaților": "alternat",
    "alternatul": "alternat",
    "alternatului": "alternat",
    "alternativa": "alternativ",
    "alternativă": "alternativ",
    "alternative": "alternativ",
    "alternativei": "alternativ",
    "alternativele": "alternativ",
    "alternativelor": "alternativ",
    "alternativi": "alternativ",
    "alternativii": "alternativ",
    "alternativilor": "alternativ",
    "alternativul": "alternativ",
    "alternativului": "alternativ",
    "alternativa": "alternativă",
    "alternative": "alternativă",
    "alternativei": "alternativă",
    "alternativele": "alternativă",
    "alternativelor": "alternativă",
    "alteța": "alteță",
    "altețe": "alteță",
    "alteței": "alteță",
    "altețele": "alteță",
    "altețelor": "alteță",
    "altimetre": "altimetru",
    "altimetrele": "altimetru",
    "altimetrelor": "altimetru",
    "altimetrul": "altimetru",
    "altimetrului": "altimetru",
    "altista": "altist",
    "altistă": "altist",
    "altiste": "altist",
    "altistei": "altist",
    "altistele": "altist",
    "altistelor": "altist",
    "altiști": "altist",
    "altiștii": "altist",
    "altiștilor": "altist",
    "altistul": "altist",
    "altistului": "altist",
    "alt.": "altitudine",
    "altitudinea": "altitudine",
    "altitudini": "altitudine",
    "altitudinii": "altitudine",
    "altitudinile": "altitudine",
    "altitudinilor": "altitudine",
    "altruismul": "altruism",
    "altruismului": "altruism",
    "altruista": "altruist",
    "altruistă": "altruist",
    "altruiste": "altruist",
    "altruistei": "altruist",
    "altruistele": "altruist",
    "altruistelor": "altruist",
    "altruiști": "altruist",
    "altruiștii": "altruist",
    "altruiștilor": "altruist",
    "altruistul": "altruist",
    "altruistului": "altruist",
    "alta": "altul",
    "alteia": "altul",
    "altele": "altul",
    "alții": "altul",
    "altora": "altul",
    "altuia": "altul",
    "alumina": "alumină",
    "aluminiul": "aluminiu",
    "aluminiului": "aluminiu",
    "aluni": "alun",
    "alunii": "alun",
    "alunilor": "alun",
    "alunul": "alun",
    "alunului": "alun",
    "aluna": "alună",
    "alune": "alună",
    "alunei": "alună",
    "alunele": "alună",
    "alunelor": "alună",
    "alunec": "aluneca",
    "alunecă": "aluneca",
    "alunecai": "aluneca",
    "alunecam": "aluneca",
    "alunecăm": "aluneca",
    "alunecând": "aluneca",
    "alunecându": "aluneca",
    "alunecară": "aluneca",
    "alunecarăm": "aluneca",
    "alunecarăți": "aluneca",
    "alunecase": "aluneca",
    "alunecasem": "aluneca",
    "alunecaseră": "aluneca",
    "alunecaserăm": "aluneca",
    "alunecaserăți": "aluneca",
    "alunecaseși": "aluneca",
    "alunecași": "aluneca",
    "alunecat": "aluneca",
    "alunecați": "aluneca",
    "alunecatu": "aluneca",
    "alunecau": "aluneca",
    "alunece": "aluneca",
    "aluneci": "aluneca",
    "nealunecând": "aluneca",
    "nealunecându": "aluneca",
    "nemaialunecând": "aluneca",
    "nemaialunecându": "aluneca",
    "alunecarea": "alunecare",
    "alunecări": "alunecare",
    "alunecării": "alunecare",
    "alunecările": "alunecare",
    "alunecata": "alunecat",
    "alunecată": "alunecat",
    "alunecate": "alunecat",
    "alunecatei": "alunecat",
    "alunecatele": "alunecat",
    "alunecatelor": "alunecat",
    "alunecați": "alunecat",
    "alunecații": "alunecat",
    "alunecaților": "alunecat",
    "alunecatul": "alunecat",
    "alunecatului": "alunecat",
    "alunecătoare": "alunecător",
    "alunecătoarea": "alunecător",
    "alunecătoarei": "alunecător",
    "alunecătoarele": "alunecător",
    "alunecătoarelor": "alunecător",
    "alunecători": "alunecător",
    "alunecătorii": "alunecător",
    "alunecătorilor": "alunecător",
    "alunecătorul": "alunecător",
    "alunecătorului": "alunecător",
    "alunecătura": "alunecătură",
    "alunecături": "alunecătură",
    "alunecăturii": "alunecătură",
    "alunecăturile": "alunecătură",
    "alunecăturilor": "alunecătură",
    "alunecoasa": "alunecos",
    "alunecoasă": "alunecos",
    "alunecoase": "alunecos",
    "alunecoasei": "alunecos",
    "alunecoasele": "alunecos",
    "alunecoaselor": "alunecos",
    "alunecoși": "alunecos",
    "alunecoșii": "alunecos",
    "alunecoșilor": "alunecos",
    "alunecosul": "alunecos",
    "alunecosului": "alunecos",
    "alung": "alunga",
    "alungă": "alunga",
    "alungai": "alunga",
    "alungam": "alunga",
    "alungăm": "alunga",
    "alungând": "alunga",
    "alungându": "alunga",
    "alungară": "alunga",
    "alungarăm": "alunga",
    "alungarăți": "alunga",
    "alungase": "alunga",
    "alungasem": "alunga",
    "alungaseră": "alunga",
    "alungaserăm": "alunga",
    "alungaserăți": "alunga",
    "alungaseși": "alunga",
    "alungași": "alunga",
    "alungat": "alunga",
    "alungați": "alunga",
    "alungatu": "alunga",
    "alungau": "alunga",
    "alunge": "alunga",
    "alungi": "alunga",
    "nealungând": "alunga",
    "nealungându": "alunga",
    "nemaialungând": "alunga",
    "nemaialungându": "alunga",
    "alungarea": "alungare",
    "alungări": "alungare",
    "alungării": "alungare",
    "alungările": "alungare",
    "alungata": "alungat",
    "alungată": "alungat",
    "alungate": "alungat",
    "alungatei": "alungat",
    "alungatele": "alungat",
    "alungatelor": "alungat",
    "alungați": "alungat",
    "alungații": "alungat",
    "alungaților": "alungat",
    "alungatul": "alungat",
    "alungatului": "alungat",
    "alungătoarea": "alungătoare",
    "alungătoarei": "alungătoare",
    "alungătoarele": "alungătoare",
    "alungătoarelor": "alungătoare",
    "alungătoare": "alungător",
    "alungătoarea": "alungător",
    "alungătoarei": "alungător",
    "alungătoarele": "alungător",
    "alungătoarelor": "alungător",
    "alungători": "alungător",
    "alungătorii": "alungător",
    "alungătorilor": "alungător",
    "alungătorul": "alungător",
    "alungătorului": "alungător",
    "alungea": "alungi",
    "alungeai": "alungi",
    "alungeam": "alungi",
    "alungească": "alungi",
    "alungeați": "alungi",
    "alungeau": "alungi",
    "alungesc": "alungi",
    "alungește": "alungi",
    "alungești": "alungi",
    "alungii": "alungi",
    "alungim": "alungi",
    "alungind": "alungi",
    "alungindu": "alungi",
    "alungiră": "alungi",
    "alungirăm": "alungi",
    "alungirăți": "alungi",
    "alungise": "alungi",
    "alungisem": "alungi",
    "alungiseră": "alungi",
    "alungiserăm": "alungi",
    "alungiserăți": "alungi",
    "alungiseși": "alungi",
    "alungiși": "alungi",
    "alungit": "alungi",
    "alungiți": "alungi",
    "alungitu": "alungi",
    "alungita": "alungit",
    "alungită": "alungit",
    "alungite": "alungit",
    "alungitei": "alungit",
    "alungitele": "alungit",
    "alungitelor": "alungit",
    "alungiți": "alungit",
    "alungiții": "alungit",
    "alungiților": "alungit",
    "alungitul": "alungit",
    "alungitului": "alungit",
    "alunișul": "aluniș",
    "alunișului": "aluniș",
    "alunișuri": "aluniș",
    "alunișurile": "aluniș",
    "alunișurilor": "aluniș",
    "alunia": "aluniu",
    "alunie": "aluniu",
    "aluniei": "aluniu",
    "alunii": "aluniu",
    "aluniii": "aluniu",
    "aluniile": "aluniu",
    "aluniilor": "aluniu",
    "aluniul": "aluniu",
    "aluniului": "aluniu",
    "aluniză": "aluniza",
    "alunizai": "aluniza",
    "alunizam": "aluniza",
    "alunizăm": "aluniza",
    "alunizând": "aluniza",
    "alunizându": "aluniza",
    "alunizară": "aluniza",
    "alunizarăm": "aluniza",
    "alunizarăți": "aluniza",
    "alunizase": "aluniza",
    "alunizasem": "aluniza",
    "alunizaseră": "aluniza",
    "alunizaserăm": "aluniza",
    "alunizaserăți": "aluniza",
    "alunizaseși": "aluniza",
    "alunizași": "aluniza",
    "alunizat": "aluniza",
    "alunizați": "aluniza",
    "alunizatu": "aluniza",
    "alunizau": "aluniza",
    "alunizează": "aluniza",
    "alunizez": "aluniza",
    "alunizeze": "aluniza",
    "alunizezi": "aluniza",
    "nealunizând": "aluniza",
    "nealunizându": "aluniza",
    "nemaialunizând": "aluniza",
    "nemaialunizându": "aluniza",
    "alunizarea": "alunizare",
    "alunizări": "alunizare",
    "alunizării": "alunizare",
    "alunizările": "alunizare",
    "alunizata": "alunizat",
    "alunizată": "alunizat",
    "alunizate": "alunizat",
    "alunizatei": "alunizat",
    "alunizatele": "alunizat",
    "alunizatelor": "alunizat",
    "alunizați": "alunizat",
    "alunizații": "alunizat",
    "alunizaților": "alunizat",
    "alunizatul": "alunizat",
    "alunizatului": "alunizat",
    "alura": "alură",
    "aluri": "alură",
    "alurii": "alură",
    "alurile": "alură",
    "alurilor": "alură",
    "aluviala": "aluvial",
    "aluvială": "aluvial",
    "aluviale": "aluvial",
    "aluvialei": "aluvial",
    "aluvialele": "aluvial",
    "aluvialelor": "aluvial",
    "aluviali": "aluvial",
    "aluvialii": "aluvial",
    "aluvialilor": "aluvial",
    "aluvialul": "aluvial",
    "aluvialului": "aluvial",
    "aluvionara": "aluvionar",
    "aluvionară": "aluvionar",
    "aluvionare": "aluvionar",
    "aluvionarei": "aluvionar",
    "aluvionarele": "aluvionar",
    "aluvionarelor": "aluvionar",
    "aluvionari": "aluvionar",
    "aluvionarii": "aluvionar",
    "aluvionarilor": "aluvionar",
    "aluvionarul": "aluvionar",
    "aluvionarului": "aluvionar",
    "aluviunea": "aluviune",
    "aluviuni": "aluviune",
    "aluviunii": "aluviune",
    "aluviunile": "aluviune",
    "aluviunilor": "aluviune",
    "aluzia": "aluzie",
    "aluzii": "aluzie",
    "aluziii": "aluzie",
    "aluziile": "aluzie",
    "aluziilor": "aluzie",
    "alveolara": "alveolar",
    "alveolară": "alveolar",
    "alveolare": "alveolar",
    "alveolarei": "alveolar",
    "alveolarele": "alveolar",
    "alveolarelor": "alveolar",
    "alveolari": "alveolar",
    "alveolarii": "alveolar",
    "alveolarilor": "alveolar",
    "alveolarul": "alveolar",
    "alveolarului": "alveolar",
    "amabila": "amabil",
    "amabilă": "amabil",
    "amabile": "amabil",
    "amabilei": "amabil",
    "amabilele": "amabil",
    "amabilelor": "amabil",
    "amabili": "amabil",
    "amabilii": "amabil",
    "amabililor": "amabil",
    "amabilul": "amabil",
    "amabilului": "amabil",
    "amabilitatea": "amabilitate",
    "amabilități": "amabilitate",
    "amabilității": "amabilitate",
    "amabilitățile": "amabilitate",
    "amabilităților": "amabilitate",
    "amăgea": "amăgi",
    "amăgeai": "amăgi",
    "amăgeam": "amăgi",
    "amăgească": "amăgi",
    "amăgeați": "amăgi",
    "amăgeau": "amăgi",
    "amăgesc": "amăgi",
    "amăgește": "amăgi",
    "amăgești": "amăgi",
    "amăgii": "amăgi",
    "amăgim": "amăgi",
    "amăgind": "amăgi",
    "amăgindu": "amăgi",
    "amăgiră": "amăgi",
    "amăgirăm": "amăgi",
    "amăgirăți": "amăgi",
    "amăgise": "amăgi",
    "amăgisem": "amăgi",
    "amăgiseră": "amăgi",
    "amăgiserăm": "amăgi",
    "amăgiserăți": "amăgi",
    "amăgiseși": "amăgi",
    "amăgiși": "amăgi",
    "amăgit": "amăgi",
    "amăgiți": "amăgi",
    "amăgitu": "amăgi",
    "neamăgind": "amăgi",
    "neamăgindu": "amăgi",
    "nemaiamăgind": "amăgi",
    "nemaiamăgindu": "amăgi",
    "amăgirea": "amăgire",
    "amăgiri": "amăgire",
    "amăgirii": "amăgire",
    "amăgirile": "amăgire",
    "amăgita": "amăgit",
    "amăgită": "amăgit",
    "amăgite": "amăgit",
    "amăgitei": "amăgit",
    "amăgitele": "amăgit",
    "amăgitelor": "amăgit",
    "amăgiți": "amăgit",
    "amăgiții": "amăgit",
    "amăgiților": "amăgit",
    "amăgitul": "amăgit",
    "amăgitului": "amăgit",
    "amăgita": "amăgită",
    "amăgite": "amăgită",
    "amăgitei": "amăgită",
    "amăgitele": "amăgită",
    "amăgitelor": "amăgită",
    "amăgitoare": "amăgitor",
    "amăgitoarea": "amăgitor",
    "amăgitoarei": "amăgitor",
    "amăgitoarele": "amăgitor",
    "amăgitoarelor": "amăgitor",
    "amăgitori": "amăgitor",
    "amăgitorii": "amăgitor",
    "amăgitorilor": "amăgitor",
    "amăgitorul": "amăgitor",
    "amăgitorului": "amăgitor",
    "amalgame": "amalgam",
    "amalgamele": "amalgam",
    "amalgamelor": "amalgam",
    "amalgamul": "amalgam",
    "amalgamului": "amalgam",
    "amân": "amâna",
    "amână": "amâna",
    "amânai": "amâna",
    "amânam": "amâna",
    "amânăm": "amâna",
    "amânând": "amâna",
    "amânându": "amâna",
    "amânară": "amâna",
    "amânarăm": "amâna",
    "amânarăți": "amâna",
    "amânase": "amâna",
    "amânasem": "amâna",
    "amânaseră": "amâna",
    "amânaserăm": "amâna",
    "amânaserăți": "amâna",
    "amânaseși": "amâna",
    "amânași": "amâna",
    "amânat": "amâna",
    "amânați": "amâna",
    "amânatu": "amâna",
    "amânau": "amâna",
    "amâne": "amâna",
    "amâni": "amâna",
    "neamânând": "amâna",
    "neamânându": "amâna",
    "nemaiamânând": "amâna",
    "nemaiamânându": "amâna",
    "amânarea": "amânare",
    "amânări": "amânare",
    "amânării": "amânare",
    "amânările": "amânare",
    "amânata": "amânat",
    "amânată": "amânat",
    "amânate": "amânat",
    "amânatei": "amânat",
    "amânatele": "amânat",
    "amânatelor": "amânat",
    "amânați": "amânat",
    "amânații": "amânat",
    "amânaților": "amânat",
    "amânatul": "amânat",
    "amânatului": "amânat",
    "amândouă": "amândoi",
    "amânduror": "amândoi",
    "amândurora": "amândoi",
    "amanete": "amanet",
    "amanetele": "amanet",
    "amanetelor": "amanet",
    "amanetul": "amanet",
    "amanetului": "amanet",
    "amanetă": "amaneta",
    "amanetai": "amaneta",
    "amanetam": "amaneta",
    "amanetăm": "amaneta",
    "amanetând": "amaneta",
    "amanetându": "amaneta",
    "amanetară": "amaneta",
    "amanetarăm": "amaneta",
    "amanetarăți": "amaneta",
    "amanetase": "amaneta",
    "amanetasem": "amaneta",
    "amanetaseră": "amaneta",
    "amanetaserăm": "amaneta",
    "amanetaserăți": "amaneta",
    "amanetaseși": "amaneta",
    "amanetași": "amaneta",
    "amanetat": "amaneta",
    "amanetați": "amaneta",
    "amanetatu": "amaneta",
    "amanetau": "amaneta",
    "amanetează": "amaneta",
    "amanetez": "amaneta",
    "amaneteze": "amaneta",
    "amanetezi": "amaneta",
    "neamanetând": "amaneta",
    "neamanetându": "amaneta",
    "nemaiamanetând": "amaneta",
    "nemaiamanetându": "amaneta",
    "amanetarea": "amanetare",
    "amanetări": "amanetare",
    "amanetării": "amanetare",
    "amanetările": "amanetare",
    "amanetata": "amanetat",
    "amanetată": "amanetat",
    "amanetate": "amanetat",
    "amanetatei": "amanetat",
    "amanetatele": "amanetat",
    "amanetatelor": "amanetat",
    "amanetați": "amanetat",
    "amanetații": "amanetat",
    "amanetaților": "amanetat",
    "amanetatul": "amanetat",
    "amanetatului": "amanetat",
    "amanți": "amant",
    "amanții": "amant",
    "amanților": "amant",
    "amantul": "amant",
    "amantului": "amant",
    "amanta": "amantă",
    "amante": "amantă",
    "amantei": "amantă",
    "amantele": "amantă",
    "amantelor": "amantă",
    "amănunte": "amănunt",
    "amănuntele": "amănunt",
    "amănuntelor": "amănunt",
    "amănuntul": "amănunt",
    "amănuntului": "amănunt",
    "amănunțea": "amănunți",
    "amănunțeai": "amănunți",
    "amănunțeam": "amănunți",
    "amănunțească": "amănunți",
    "amănunțeați": "amănunți",
    "amănunțeau": "amănunți",
    "amănunțesc": "amănunți",
    "amănunțește": "amănunți",
    "amănunțești": "amănunți",
    "amănunții": "amănunți",
    "amănunțim": "amănunți",
    "amănunțind": "amănunți",
    "amănunțindu": "amănunți",
    "amănunțiră": "amănunți",
    "amănunțirăm": "amănunți",
    "amănunțirăți": "amănunți",
    "amănunțise": "amănunți",
    "amănunțisem": "amănunți",
    "amănunțiseră": "amănunți",
    "amănunțiserăm": "amănunți",
    "amănunțiserăți": "amănunți",
    "amănunțiseși": "amănunți",
    "amănunțiși": "amănunți",
    "amănunțit": "amănunți",
    "amănunțiți": "amănunți",
    "amănunțitu": "amănunți",
    "amănunțirea": "amănunțire",
    "amănunțiri": "amănunțire",
    "amănunțirii": "amănunțire",
    "amănunțirile": "amănunțire",
    "amănunțirilor": "amănunțire",
    "amănunțita": "amănunțit",
    "amănunțită": "amănunțit",
    "amănunțite": "amănunțit",
    "amănunțitei": "amănunțit",
    "amănunțitele": "amănunțit",
    "amănunțitelor": "amănunțit",
    "amănunțiți": "amănunțit",
    "amănunțiții": "amănunțit",
    "amănunțiților": "amănunțit",
    "amănunțitul": "amănunțit",
    "amănunțitului": "amănunțit",
    "amara": "amar",
    "amară": "amar",
    "amare": "amar",
    "amarei": "amar",
    "amarele": "amar",
    "amarelor": "amar",
    "amari": "amar",
    "amarii": "amar",
    "amarilor": "amar",
    "amarul": "amar",
    "amarului": "amar",
    "amărăciunea": "amărăciune",
    "amărăciuni": "amărăciune",
    "amărăciunii": "amărăciune",
    "amărăciunile": "amărăciune",
    "amărăciunilor": "amărăciune",
    "amărârea": "amărâre",
    "amărâri": "amărâre",
    "amărârii": "amărâre",
    "amărârile": "amărâre",
    "amărâta": "amărât",
    "amărâtă": "amărât",
    "amărâte": "amărât",
    "amărâtei": "amărât",
    "amărâtele": "amărât",
    "amărâtelor": "amărât",
    "amărâți": "amărât",
    "amărâții": "amărât",
    "amărâților": "amărât",
    "amărâtu": "amărât",
    "amărâtu-": "amărât",
    "amărâtul": "amărât",
    "amărâtului": "amărât",
    "amărâta": "amărâtă",
    "amărâte": "amărâtă",
    "amărâtei": "amărâtă",
    "amărâtele": "amărâtă",
    "amărâtelor": "amărâtă",
    "amăra": "amărî",
    "amărai": "amărî",
    "amărâi": "amărî",
    "amăram": "amărî",
    "amărâm": "amărî",
    "amărând": "amărî",
    "amărându": "amărî",
    "amărâră": "amărî",
    "amărârăm": "amărî",
    "amărârăți": "amărî",
    "amărăsc": "amărî",
    "amărască": "amărî",
    "amărâse": "amărî",
    "amărâsem": "amărî",
    "amărâseră": "amărî",
    "amărâserăm": "amărî",
    "amărâserăți": "amărî",
    "amărâseși": "amărî",
    "amărâși": "amărî",
    "amărăște": "amărî",
    "amărăști": "amărî",
    "amărât": "amărî",
    "amărați": "amărî",
    "amărâți": "amărî",
    "amărâtu": "amărî",
    "amărau": "amărî",
    "neamărând": "amărî",
    "neamărându": "amărî",
    "nemaiamărând": "amărî",
    "nemaiamărându": "amărî",
    "amarnica": "amarnic",
    "amarnică": "amarnic",
    "amarnice": "amarnic",
    "amarnicei": "amarnic",
    "amarnicele": "amarnic",
    "amarnicelor": "amarnic",
    "amarnici": "amarnic",
    "amarnicii": "amarnic",
    "amarnicilor": "amarnic",
    "amarnicul": "amarnic",
    "amarnicului": "amarnic",
    "amăruia": "amărui",
    "amăruie": "amărui",
    "amăruiei": "amărui",
    "amăruiele": "amărui",
    "amăruielor": "amărui",
    "amăruii": "amărui",
    "amăruilor": "amărui",
    "amăruiul": "amărui",
    "amăruiului": "amărui",
    "amatoarea": "amatoare",
    "amatoarei": "amatoare",
    "amatoarele": "amatoare",
    "amatoarelor": "amatoare",
    "amatoare": "amator",
    "amatoarea": "amator",
    "amatoarei": "amator",
    "amatoarele": "amator",
    "amatoarelor": "amator",
    "amatori": "amator",
    "amatorii": "amator",
    "amatorilor": "amator",
    "amatorul": "amator",
    "amatorului": "amator",
    "amazoana": "amazoană",
    "amazoane": "amazoană",
    "amazoanei": "amazoană",
    "amazoanele": "amazoană",
    "amazoanelor": "amazoană",
    "amazoniana": "amazonian",
    "amazoniană": "amazonian",
    "amazoniane": "amazonian",
    "amazonianei": "amazonian",
    "amazonianele": "amazonian",
    "amazonianelor": "amazonian",
    "amazonianul": "amazonian",
    "amazonianului": "amazonian",
    "amazonieni": "amazonian",
    "amazonienii": "amazonian",
    "amazonienilor": "amazonian",
    "amazoniana": "amazoniană",
    "amazoniene": "amazoniană",
    "amazonienei": "amazoniană",
    "amazonienele": "amazoniană",
    "amazonienelor": "amazoniană",
    "ambală": "ambala",
    "ambalai": "ambala",
    "ambalam": "ambala",
    "ambalăm": "ambala",
    "ambalând": "ambala",
    "ambalându": "ambala",
    "ambalară": "ambala",
    "ambalarăm": "ambala",
    "ambalarăți": "ambala",
    "ambalase": "ambala",
    "ambalasem": "ambala",
    "ambalaseră": "ambala",
    "ambalaserăm": "ambala",
    "ambalaserăți": "ambala",
    "ambalaseși": "ambala",
    "ambalași": "ambala",
    "ambalat": "ambala",
    "ambalați": "ambala",
    "ambalatu": "ambala",
    "ambalau": "ambala",
    "ambalează": "ambala",
    "ambalez": "ambala",
    "ambaleze": "ambala",
    "ambalezi": "ambala",
    "neambalând": "ambala",
    "neambalându": "ambala",
    "nemaiambalând": "ambala",
    "nemaiambalându": "ambala",
    "ambalaje": "ambalaj",
    "ambalajelor": "ambalaj",
    "ambalajul": "ambalaj",
    "ambalajului": "ambalaj",
    "ambalarea": "ambalare",
    "ambalări": "ambalare",
    "ambalării": "ambalare",
    "ambalările": "ambalare",
    "ambalata": "ambalat",
    "ambalată": "ambalat",
    "ambalate": "ambalat",
    "ambalatei": "ambalat",
    "ambalatele": "ambalat",
    "ambalatelor": "ambalat",
    "ambalați": "ambalat",
    "ambalații": "ambalat",
    "ambalaților": "ambalat",
    "ambalatul": "ambalat",
    "ambalatului": "ambalat",
    "ambarcadere": "ambarcader",
    "ambarcaderele": "ambarcader",
    "ambarcaderelor": "ambarcader",
    "ambarcaderul": "ambarcader",
    "ambarcaderului": "ambarcader",
    "ambarcația": "ambarcație",
    "ambarcației": "ambarcație",
    "ambarcații": "ambarcație",
    "ambarcațiile": "ambarcație",
    "ambarcațiilor": "ambarcație",
    "ambarcațiunea": "ambarcațiune",
    "ambarcațiuni": "ambarcațiune",
    "ambarcațiunii": "ambarcațiune",
    "ambarcațiunile": "ambarcațiune",
    "ambarcațiunilor": "ambarcațiune",
    "ambasada": "ambasadă",
    "ambasade": "ambasadă",
    "ambasadei": "ambasadă",
    "ambasadele": "ambasadă",
    "ambasadelor": "ambasadă",
    "ambasadoarea": "ambasadoare",
    "ambasadoarei": "ambasadoare",
    "ambasadoarele": "ambasadoare",
    "ambasadoarelor": "ambasadoare",
    "Amb.": "ambasador",
    "ambasadori": "ambasador",
    "ambasadorii": "ambasador",
    "ambasadorilor": "ambasador",
    "ambasadorul": "ambasador",
    "ambasadorului": "ambasador",
    "ambianta": "ambiant",
    "ambiantă": "ambiant",
    "ambiante": "ambiant",
    "ambiantei": "ambiant",
    "ambiantele": "ambiant",
    "ambiantelor": "ambiant",
    "ambianți": "ambiant",
    "ambianții": "ambiant",
    "ambianților": "ambiant",
    "ambiantul": "ambiant",
    "ambiantului": "ambiant",
    "ambianța": "ambianță",
    "ambianțe": "ambianță",
    "ambianței": "ambianță",
    "ambianțele": "ambianță",
    "ambianțelor": "ambianță",
    "ambidextra": "ambidextru",
    "ambidextră": "ambidextru",
    "ambidextre": "ambidextru",
    "ambidextrei": "ambidextru",
    "ambidextrele": "ambidextru",
    "ambidextrelor": "ambidextru",
    "ambidextri": "ambidextru",
    "ambidextrii": "ambidextru",
    "ambidextrilor": "ambidextru",
    "ambidextrul": "ambidextru",
    "ambidextrului": "ambidextru",
    "ambientul": "ambient",
    "ambientului": "ambient",
    "ambigena": "ambigen",
    "ambigenă": "ambigen",
    "ambigene": "ambigen",
    "ambigenei": "ambigen",
    "ambigenele": "ambigen",
    "ambigenelor": "ambigen",
    "ambigeni": "ambigen",
    "ambigenii": "ambigen",
    "ambigenilor": "ambigen",
    "ambigenul": "ambigen",
    "ambigenului": "ambigen",
    "ambiguitatea": "ambiguitate",
    "ambiguități": "ambiguitate",
    "ambiguității": "ambiguitate",
    "ambiguitățile": "ambiguitate",
    "ambiguităților": "ambiguitate",
    "ambigua": "ambiguu",
    "ambiguă": "ambiguu",
    "ambigue": "ambiguu",
    "ambiguei": "ambiguu",
    "ambiguele": "ambiguu",
    "ambiguelor": "ambiguu",
    "ambigui": "ambiguu",
    "ambiguii": "ambiguu",
    "ambiguilor": "ambiguu",
    "ambiguul": "ambiguu",
    "ambiguului": "ambiguu",
    "ambele": "ambii",
    "ambelor": "ambii",
    "ambilor": "ambii",
    "ambiția": "ambiție",
    "ambiției": "ambiție",
    "ambiții": "ambiție",
    "ambițiile": "ambiție",
    "ambițiilor": "ambiție",
    "ambiționă": "ambiționa",
    "ambiționai": "ambiționa",
    "ambiționam": "ambiționa",
    "ambiționăm": "ambiționa",
    "ambiționând": "ambiționa",
    "ambiționându": "ambiționa",
    "ambiționară": "ambiționa",
    "ambiționarăm": "ambiționa",
    "ambiționarăți": "ambiționa",
    "ambiționase": "ambiționa",
    "ambiționasem": "ambiționa",
    "ambiționaseră": "ambiționa",
    "ambiționaserăm": "ambiționa",
    "ambiționaserăți": "ambiționa",
    "ambiționaseși": "ambiționa",
    "ambiționași": "ambiționa",
    "ambiționat": "ambiționa",
    "ambiționați": "ambiționa",
    "ambiționatu": "ambiționa",
    "ambiționau": "ambiționa",
    "ambiționează": "ambiționa",
    "ambiționez": "ambiționa",
    "ambiționeze": "ambiționa",
    "ambiționezi": "ambiționa",
    "neambiționând": "ambiționa",
    "neambiționându": "ambiționa",
    "nemaiambiționând": "ambiționa",
    "nemaiambiționându": "ambiționa",
    "ambiționarea": "ambiționare",
    "ambiționări": "ambiționare",
    "ambiționării": "ambiționare",
    "ambiționările": "ambiționare",
    "ambiționata": "ambiționat",
    "ambiționată": "ambiționat",
    "ambiționate": "ambiționat",
    "ambiționatei": "ambiționat",
    "ambiționatele": "ambiționat",
    "ambiționatelor": "ambiționat",
    "ambiționați": "ambiționat",
    "ambiționații": "ambiționat",
    "ambiționaților": "ambiționat",
    "ambiționatul": "ambiționat",
    "ambiționatului": "ambiționat",
    "ambițioasa": "ambițios",
    "ambițioasă": "ambițios",
    "ambițioase": "ambițios",
    "ambițioasei": "ambițios",
    "ambițioasele": "ambițios",
    "ambițioaselor": "ambițios",
    "ambițioși": "ambițios",
    "ambițioșii": "ambițios",
    "ambițioșilor": "ambițios",
    "ambițiosul": "ambițios",
    "ambițiosului": "ambițios",
    "ambivalenta": "ambivalent",
    "ambivalentă": "ambivalent",
    "ambivalente": "ambivalent",
    "ambivalentei": "ambivalent",
    "ambivalentele": "ambivalent",
    "ambivalentelor": "ambivalent",
    "ambivalenți": "ambivalent",
    "ambivalenții": "ambivalent",
    "ambivalenților": "ambivalent",
    "ambivalentul": "ambivalent",
    "ambivalentului": "ambivalent",
    "ambivalența": "ambivalență",
    "ambivalențe": "ambivalență",
    "ambivalenței": "ambivalență",
    "ambivalențele": "ambivalență",
    "ambivalențelor": "ambivalență",
    "ambra": "ambră",
    "ambre": "ambră",
    "ambrei": "ambră",
    "ambrele": "ambră",
    "ambrelor": "ambră",
    "ambreiaje": "ambreiaj",
    "ambreiajele": "ambreiaj",
    "ambreiajelor": "ambreiaj",
    "ambreiajul": "ambreiaj",
    "ambreiajului": "ambreiaj",
    "ambroziaca": "ambroziac",
    "ambroziacă": "ambroziac",
    "ambroziace": "ambroziac",
    "ambroziacei": "ambroziac",
    "ambroziacele": "ambroziac",
    "ambroziacelor": "ambroziac",
    "ambroziaci": "ambroziac",
    "ambroziacii": "ambroziac",
    "ambroziacilor": "ambroziac",
    "ambroziacul": "ambroziac",
    "ambroziacului": "ambroziac",
    "ambrozia": "ambrozie",
    "ambroziei": "ambrozie",
    "ambulanta": "ambulant",
    "ambulantă": "ambulant",
    "ambulante": "ambulant",
    "ambulantei": "ambulant",
    "ambulantele": "ambulant",
    "ambulantelor": "ambulant",
    "ambulanți": "ambulant",
    "ambulanții": "ambulant",
    "ambulanților": "ambulant",
    "ambulantul": "ambulant",
    "ambulantului": "ambulant",
    "ambulanța": "ambulanță",
    "ambulanțe": "ambulanță",
    "ambulanței": "ambulanță",
    "ambulanțele": "ambulanță",
    "ambulanțelor": "ambulanță",
    "ambulanțieri": "ambulanțier",
    "ambulanțierii": "ambulanțier",
    "ambulanțierilor": "ambulanțier",
    "ambulanțierul": "ambulanțier",
    "ambulanțierului": "ambulanțier",
    "ambulanțiera": "ambulanțieră",
    "ambulanțiere": "ambulanțieră",
    "ambulanțierei": "ambulanțieră",
    "ambulanțierele": "ambulanțieră",
    "ambulanțierelor": "ambulanțieră",
    "ambulatoria": "ambulatoriu",
    "ambulatorie": "ambulatoriu",
    "ambulatoriei": "ambulatoriu",
    "ambulatorii": "ambulatoriu",
    "ambulatoriii": "ambulatoriu",
    "ambulatoriile": "ambulatoriu",
    "ambulatoriilor": "ambulatoriu",
    "ambulatoriul": "ambulatoriu",
    "ambulatoriului": "ambulatoriu",
    "ambuscada": "ambuscadă",
    "ambuscade": "ambuscadă",
    "ambuscadei": "ambuscadă",
    "ambuscadele": "ambuscadă",
    "ambuscadelor": "ambuscadă",
    "amelioră": "ameliora",
    "ameliorai": "ameliora",
    "amelioram": "ameliora",
    "ameliorăm": "ameliora",
    "ameliorând": "ameliora",
    "ameliorându": "ameliora",
    "ameliorară": "ameliora",
    "ameliorarăm": "ameliora",
    "ameliorarăți": "ameliora",
    "ameliorase": "ameliora",
    "ameliorasem": "ameliora",
    "amelioraseră": "ameliora",
    "amelioraserăm": "ameliora",
    "amelioraserăți": "ameliora",
    "amelioraseși": "ameliora",
    "ameliorași": "ameliora",
    "ameliorat": "ameliora",
    "ameliorați": "ameliora",
    "amelioratu": "ameliora",
    "ameliorau": "ameliora",
    "ameliorează": "ameliora",
    "ameliorez": "ameliora",
    "amelioreze": "ameliora",
    "ameliorezi": "ameliora",
    "neameliorând": "ameliora",
    "neameliorându": "ameliora",
    "nemaiameliorând": "ameliora",
    "nemaiameliorându": "ameliora",
    "ameliorarea": "ameliorare",
    "ameliorări": "ameliorare",
    "ameliorării": "ameliorare",
    "ameliorările": "ameliorare",
    "ameliorata": "ameliorat",
    "ameliorată": "ameliorat",
    "ameliorate": "ameliorat",
    "amelioratei": "ameliorat",
    "amelioratele": "ameliorat",
    "amelioratelor": "ameliorat",
    "ameliorați": "ameliorat",
    "ameliorații": "ameliorat",
    "amelioraților": "ameliorat",
    "amelioratul": "ameliorat",
    "amelioratului": "ameliorat",
    "amenajă": "amenaja",
    "amenajai": "amenaja",
    "amenajam": "amenaja",
    "amenajăm": "amenaja",
    "amenajând": "amenaja",
    "amenajându": "amenaja",
    "amenajară": "amenaja",
    "amenajarăm": "amenaja",
    "amenajarăți": "amenaja",
    "amenajase": "amenaja",
    "amenajasem": "amenaja",
    "amenajaseră": "amenaja",
    "amenajaserăm": "amenaja",
    "amenajaserăți": "amenaja",
    "amenajaseși": "amenaja",
    "amenajași": "amenaja",
    "amenajat": "amenaja",
    "amenajați": "amenaja",
    "amenajatu": "amenaja",
    "amenajau": "amenaja",
    "amenajează": "amenaja",
    "amenajez": "amenaja",
    "amenajeze": "amenaja",
    "amenajezi": "amenaja",
    "neamenajând": "amenaja",
    "neamenajându": "amenaja",
    "nemaiamenajând": "amenaja",
    "nemaiamenajându": "amenaja",
    "amenajarea": "amenajare",
    "amenajări": "amenajare",
    "amenajării": "amenajare",
    "amenajările": "amenajare",
    "amenajata": "amenajat",
    "amenajată": "amenajat",
    "amenajate": "amenajat",
    "amenajatei": "amenajat",
    "amenajatele": "amenajat",
    "amenajatelor": "amenajat",
    "amenajați": "amenajat",
    "amenajații": "amenajat",
    "amenajaților": "amenajat",
    "amenajatul": "amenajat",
    "amenajatului": "amenajat",
    "amendă": "amenda",
    "amendai": "amenda",
    "amendam": "amenda",
    "amendăm": "amenda",
    "amendând": "amenda",
    "amendându": "amenda",
    "amendară": "amenda",
    "amendarăm": "amenda",
    "amendarăți": "amenda",
    "amendase": "amenda",
    "amendasem": "amenda",
    "amendaseră": "amenda",
    "amendaserăm": "amenda",
    "amendaserăți": "amenda",
    "amendaseși": "amenda",
    "amendași": "amenda",
    "amendat": "amenda",
    "amendați": "amenda",
    "amendatu": "amenda",
    "amendau": "amenda",
    "amendează": "amenda",
    "amendez": "amenda",
    "amendeze": "amenda",
    "amendezi": "amenda",
    "neamendând": "amenda",
    "neamendându": "amenda",
    "nemaiamendând": "amenda",
    "nemaiamendându": "amenda",
    "amenda": "amendă",
    "amenzi": "amendă",
    "amenzii": "amendă",
    "amenzile": "amendă",
    "amenzilor": "amendă",
    "amendabila": "amendabil",
    "amendabilă": "amendabil",
    "amendabile": "amendabil",
    "amendabilei": "amendabil",
    "amendabilele": "amendabil",
    "amendabilelor": "amendabil",
    "amendabili": "amendabil",
    "amendabilii": "amendabil",
    "amendabililor": "amendabil",
    "amendabilul": "amendabil",
    "amendabilului": "amendabil",
    "amendamente": "amendament",
    "amendamentele": "amendament",
    "amendamentelor": "amendament",
    "amendamentul": "amendament",
    "amendamentului": "amendament",
    "amendarea": "amendare",
    "amendări": "amendare",
    "amendării": "amendare",
    "amendările": "amendare",
    "amendata": "amendat",
    "amendată": "amendat",
    "amendate": "amendat",
    "amendatei": "amendat",
    "amendatele": "amendat",
    "amendatelor": "amendat",
    "amendați": "amendat",
    "amendații": "amendat",
    "amendaților": "amendat",
    "amendatul": "amendat",
    "amendatului": "amendat",
    "amendata": "amendată",
    "amendate": "amendată",
    "amendatei": "amendată",
    "amendatele": "amendată",
    "amendatelor": "amendată",
    "ameninț": "amenința",
    "amenință": "amenința",
    "amenințai": "amenința",
    "amenințam": "amenința",
    "amenințăm": "amenința",
    "amenințând": "amenința",
    "amenințându": "amenința",
    "amenințară": "amenința",
    "amenințarăm": "amenința",
    "amenințarăți": "amenința",
    "amenințase": "amenința",
    "amenințasem": "amenința",
    "amenințaseră": "amenința",
    "amenințaserăm": "amenința",
    "amenințaserăți": "amenința",
    "amenințaseși": "amenința",
    "amenințași": "amenința",
    "amenințat": "amenința",
    "amenințați": "amenința",
    "amenințatu": "amenința",
    "amenințau": "amenința",
    "amenințe": "amenința",
    "ameninți": "amenința",
    "neamenințând": "amenința",
    "neamenințându": "amenința",
    "nemaiamenințând": "amenința",
    "nemaiamenințându": "amenința",
    "amenințarea": "amenințare",
    "amenințări": "amenințare",
    "amenințării": "amenințare",
    "amenințările": "amenințare",
    "amenințărilor": "amenințare",
    "amenințata": "amenințat",
    "amenințată": "amenințat",
    "amenințate": "amenințat",
    "amenințatei": "amenințat",
    "amenințatele": "amenințat",
    "amenințatelor": "amenințat",
    "amenințați": "amenințat",
    "amenințații": "amenințat",
    "amenințaților": "amenințat",
    "amenințatul": "amenințat",
    "amenințatului": "amenințat",
    "amenințata": "amenințată",
    "amenințate": "amenințată",
    "amenințatei": "amenințată",
    "amenințatele": "amenințată",
    "amenințatelor": "amenințată",
    "amenințătoare": "amenințător",
    "amenințătoarea": "amenințător",
    "amenințătoarei": "amenințător",
    "amenințătoarele": "amenințător",
    "amenințătoarelor": "amenințător",
    "amenințători": "amenințător",
    "amenințătorii": "amenințător",
    "amenințătorilor": "amenințător",
    "amenințătorul": "amenințător",
    "amenințătorului": "amenințător",
    "amenorea": "amenoree",
    "Americă": "America",
    "Americi": "America",
    "Americii": "America",
    "americana": "american",
    "americană": "american",
    "americane": "american",
    "americanei": "american",
    "americanele": "american",
    "americanelor": "american",
    "americani": "american",
    "americanii": "american",
    "americanilor": "american",
    "americanul": "american",
    "americanului": "american",
    "americanca": "americancă",
    "americance": "americancă",
    "americancei": "americancă",
    "americancele": "americancă",
    "americancelor": "americancă",
    "amestecul": "amestec",
    "amestecului": "amestec",
    "amestecuri": "amestec",
    "amestecurile": "amestec",
    "amestecurilor": "amestec",
    "amestec": "amesteca",
    "amestecă": "amesteca",
    "amestecai": "amesteca",
    "amestecam": "amesteca",
    "amestecăm": "amesteca",
    "amestecând": "amesteca",
    "amestecându": "amesteca",
    "amestecară": "amesteca",
    "amestecarăm": "amesteca",
    "amestecarăți": "amesteca",
    "amestecase": "amesteca",
    "amestecasem": "amesteca",
    "amestecaseră": "amesteca",
    "amestecaserăm": "amesteca",
    "amestecaserăți": "amesteca",
    "amestecaseși": "amesteca",
    "amestecași": "amesteca",
    "amestecat": "amesteca",
    "amestecați": "amesteca",
    "amestecatu": "amesteca",
    "amestecau": "amesteca",
    "amestece": "amesteca",
    "amesteci": "amesteca",
    "neamestecând": "amesteca",
    "neamestecându": "amesteca",
    "nemaiamestecând": "amesteca",
    "nemaiamestecându": "amesteca",
    "amestecarea": "amestecare",
    "amestecări": "amestecare",
    "amestecării": "amestecare",
    "amestecările": "amestecare",
    "amestecata": "amestecat",
    "amestecată": "amestecat",
    "amestecate": "amestecat",
    "amestecatei": "amestecat",
    "amestecatele": "amestecat",
    "amestecatelor": "amestecat",
    "amestecați": "amestecat",
    "amestecații": "amestecat",
    "amestecaților": "amestecat",
    "amestecatul": "amestecat",
    "amestecatului": "amestecat",
    "amestecătoare": "amestecător",
    "amestecătoarele": "amestecător",
    "amestecătoarelor": "amestecător",
    "amestecători": "amestecător",
    "amestecătorii": "amestecător",
    "amestecătorilor": "amestecător",
    "amestecătorul": "amestecător",
    "amestecătorului": "amestecător",
    "amestecătura": "amestecătură",
    "amestecături": "amestecătură",
    "amestecăturii": "amestecătură",
    "amestecăturile": "amestecătură",
    "amestecăturilor": "amestecătură",
    "amețeala": "amețeală",
    "amețeli": "amețeală",
    "amețelii": "amețeală",
    "amețelile": "amețeală",
    "amețelilor": "amețeală",
    "amețea": "ameți",
    "amețeai": "ameți",
    "amețeam": "ameți",
    "amețească": "ameți",
    "amețeați": "ameți",
    "amețeau": "ameți",
    "amețesc": "ameți",
    "amețește": "ameți",
    "amețești": "ameți",
    "ameții": "ameți",
    "amețim": "ameți",
    "amețind": "ameți",
    "amețindu": "ameți",
    "amețiră": "ameți",
    "amețirăm": "ameți",
    "amețirăți": "ameți",
    "amețise": "ameți",
    "amețisem": "ameți",
    "amețiseră": "ameți",
    "amețiserăm": "ameți",
    "amețiserăți": "ameți",
    "amețiseși": "ameți",
    "amețiși": "ameți",
    "amețit": "ameți",
    "amețiți": "ameți",
    "amețitu": "ameți",
    "neamețind": "ameți",
    "neamețindu": "ameți",
    "nemaiamețind": "ameți",
    "nemaiamețindu": "ameți",
    "amețirea": "amețire",
    "amețiri": "amețire",
    "amețirii": "amețire",
    "amețirile": "amețire",
    "ametiste": "ametist",
    "ametistele": "ametist",
    "ametistelor": "ametist",
    "ametistul": "ametist",
    "ametistului": "ametist",
    "amețita": "amețit",
    "amețită": "amețit",
    "amețite": "amețit",
    "amețitei": "amețit",
    "amețitele": "amețit",
    "amețitelor": "amețit",
    "amețiți": "amețit",
    "amețiții": "amețit",
    "amețiților": "amețit",
    "amețitul": "amețit",
    "amețitului": "amețit",
    "amețita": "amețită",
    "amețite": "amețită",
    "amețitei": "amețită",
    "amețitele": "amețită",
    "amețitelor": "amețită",
    "amețitoare": "amețitor",
    "amețitoarea": "amețitor",
    "amețitoarei": "amețitor",
    "amețitoarele": "amețitor",
    "amețitoarelor": "amețitor",
    "amețitori": "amețitor",
    "amețitorii": "amețitor",
    "amețitorilor": "amețitor",
    "amețitorul": "amețitor",
    "amețitorului": "amețitor",
    "amfibia": "amfibiu",
    "amfibie": "amfibiu",
    "amfibiei": "amfibiu",
    "amfibii": "amfibiu",
    "amfibiii": "amfibiu",
    "amfibiile": "amfibiu",
    "amfibiilor": "amfibiu",
    "amfibiul": "amfibiu",
    "amfibiului": "amfibiu",
    "amfibrahi": "amfibrah",
    "amfibrahii": "amfibrah",
    "amfibrahilor": "amfibrah",
    "amfibrahul": "amfibrah",
    "amfibrahului": "amfibrah",
    "amfiteatre": "amfiteatru",
    "amfiteatrele": "amfiteatru",
    "amfiteatrelor": "amfiteatru",
    "amfiteatrul": "amfiteatru",
    "amfiteatrului": "amfiteatru",
    "amfitrioana": "amfitrioană",
    "amfitrioane": "amfitrioană",
    "amfitrioanei": "amfitrioană",
    "amfitrioanele": "amfitrioană",
    "amfitrioanelor": "amfitrioană",
    "amfitrioni": "amfitrion",
    "amfitrionii": "amfitrion",
    "amfitrionilor": "amfitrion",
    "amfitrionul": "amfitrion",
    "amfitrionului": "amfitrion",
    "amfora": "amforă",
    "amfore": "amforă",
    "amforei": "amforă",
    "amforele": "amforă",
    "amforelor": "amforă",
    "amiabila": "amiabil",
    "amiabilă": "amiabil",
    "amiabile": "amiabil",
    "amiabilei": "amiabil",
    "amiabilele": "amiabil",
    "amiabilelor": "amiabil",
    "amiabili": "amiabil",
    "amiabilii": "amiabil",
    "amiabililor": "amiabil",
    "amiabilul": "amiabil",
    "amiabilului": "amiabil",
    "amiaza": "amiază",
    "amiezele": "amiază",
    "amiezelor": "amiază",
    "amiezi": "amiază",
    "amiezii": "amiază",
    "amici": "amic",
    "amicii": "amic",
    "amicilor": "amic",
    "amicul": "amic",
    "amicului": "amic",
    "amica": "amică",
    "amice": "amică",
    "amicei": "amică",
    "amicele": "amică",
    "amicelor": "amică",
    "amicala": "amical",
    "amicală": "amical",
    "amicale": "amical",
    "amicalei": "amical",
    "amicalele": "amical",
    "amicalelor": "amical",
    "amicali": "amical",
    "amicalii": "amical",
    "amicalilor": "amical",
    "amicalul": "amical",
    "amicalului": "amical",
    "amiciția": "amiciție",
    "amiciției": "amiciție",
    "amiciții": "amiciție",
    "amicițiile": "amiciție",
    "amicițiilor": "amiciție",
    "amid.": "amidon",
    "amidonul": "amidon",
    "amidonului": "amidon",
    "amilacee": "amilaceu",
    "amilaceele": "amilaceu",
    "amilaceelor": "amilaceu",
    "amilaceul": "amilaceu",
    "amilaceului": "amilaceu",
    "aminoacidul": "aminoacid",
    "aminoacidului": "aminoacid",
    "aminoacizi": "aminoacid",
    "aminoacizii": "aminoacid",
    "aminoacizilor": "aminoacid",
    "amintea": "aminti",
    "aminteai": "aminti",
    "aminteam": "aminti",
    "amintească": "aminti",
    "aminteați": "aminti",
    "aminteau": "aminti",
    "amintesc": "aminti",
    "amintește": "aminti",
    "amintești": "aminti",
    "amintii": "aminti",
    "amintim": "aminti",
    "amintind": "aminti",
    "amintindu": "aminti",
    "amintiră": "aminti",
    "amintirăm": "aminti",
    "amintirăți": "aminti",
    "amintise": "aminti",
    "amintisem": "aminti",
    "amintiseră": "aminti",
    "amintiserăm": "aminti",
    "amintiserăți": "aminti",
    "amintiseși": "aminti",
    "amintiși": "aminti",
    "amintit": "aminti",
    "amintiți": "aminti",
    "amintitu": "aminti",
    "neamintind": "aminti",
    "neamintindu": "aminti",
    "nemaiamintind": "aminti",
    "nemaiamintindu": "aminti",
    "amintirea": "amintire",
    "amintiri": "amintire",
    "amintirii": "amintire",
    "amintirile": "amintire",
    "amintirilor": "amintire",
    "amintita": "amintit",
    "amintită": "amintit",
    "amintite": "amintit",
    "amintitei": "amintit",
    "amintitele": "amintit",
    "amintitelor": "amintit",
    "amintiți": "amintit",
    "amintiții": "amintit",
    "amintiților": "amintit",
    "amintitul": "amintit",
    "amintitului": "amintit",
    "amirali": "amiral",
    "amiralii": "amiral",
    "amiralilor": "amiral",
    "amiralul": "amiral",
    "amiralului": "amiral",
    "amiralitatea": "amiralitate",
    "amiralități": "amiralitate",
    "amiralității": "amiralitate",
    "amiralitățile": "amiralitate",
    "amiralităților": "amiralitate",
    "amnare": "amnar",
    "amnarele": "amnar",
    "amnarelor": "amnar",
    "amnarul": "amnar",
    "amnarului": "amnar",
    "amniotica": "amniotic",
    "amniotică": "amniotic",
    "amniotice": "amniotic",
    "amnioticei": "amniotic",
    "amnioticele": "amniotic",
    "amnioticelor": "amniotic",
    "amniotici": "amniotic",
    "amnioticii": "amniotic",
    "amnioticilor": "amniotic",
    "amnioticul": "amniotic",
    "amnioticului": "amniotic",
    "amnistiai": "amnistia",
    "amnistiam": "amnistia",
    "amnistiară": "amnistia",
    "amnistiarăm": "amnistia",
    "amnistiarăți": "amnistia",
    "amnistiase": "amnistia",
    "amnistiasem": "amnistia",
    "amnistiaseră": "amnistia",
    "amnistiaserăm": "amnistia",
    "amnistiaserăți": "amnistia",
    "amnistiaseși": "amnistia",
    "amnistiași": "amnistia",
    "amnistiat": "amnistia",
    "amnistiați": "amnistia",
    "amnistiatu": "amnistia",
    "amnistiau": "amnistia",
    "amnistiază": "amnistia",
    "amnistie": "amnistia",
    "amnistiem": "amnistia",
    "amnistiez": "amnistia",
    "amnistieze": "amnistia",
    "amnistiezi": "amnistia",
    "amnistiind": "amnistia",
    "amnistiindu": "amnistia",
    "neamnistiind": "amnistia",
    "neamnistiindu": "amnistia",
    "nemaiamnistiind": "amnistia",
    "nemaiamnistiindu": "amnistia",
    "amnistiabilă": "amnistiabil",
    "amnistiabile": "amnistiabil",
    "amnistiabili": "amnistiabil",
    "amnistiata": "amnistiat",
    "amnistiată": "amnistiat",
    "amnistiate": "amnistiat",
    "amnistiatei": "amnistiat",
    "amnistiatele": "amnistiat",
    "amnistiatelor": "amnistiat",
    "amnistiați": "amnistiat",
    "amnistiații": "amnistiat",
    "amnistiaților": "amnistiat",
    "amnistiatul": "amnistiat",
    "amnistiatului": "amnistiat",
    "amnistiata": "amnistiată",
    "amnistiate": "amnistiată",
    "amnistiatei": "amnistiată",
    "amnistiatele": "amnistiată",
    "amnistiatelor": "amnistiată",
    "amnistierea": "amnistiere",
    "amnistieri": "amnistiere",
    "amnistierii": "amnistiere",
    "amnistierile": "amnistiere",
    "amoniacul": "amoniac",
    "amoniacului": "amoniac",
    "amoniacala": "amoniacal",
    "amoniacală": "amoniacal",
    "amoniacale": "amoniacal",
    "amoniacalei": "amoniacal",
    "amoniacalele": "amoniacal",
    "amoniacalelor": "amoniacal",
    "amoniacali": "amoniacal",
    "amoniacalii": "amoniacal",
    "amoniacalilor": "amoniacal",
    "amoniacalul": "amoniacal",
    "amoniacalului": "amoniacal",
    "amorul": "amor",
    "amorului": "amor",
    "amoruri": "amor",
    "amorurile": "amor",
    "amorurilor": "amor",
    "amorala": "amoral",
    "amorală": "amoral",
    "amorale": "amoral",
    "amoralei": "amoral",
    "amoralele": "amoral",
    "amoralelor": "amoral",
    "amorali": "amoral",
    "amoralii": "amoral",
    "amoralilor": "amoral",
    "amoralul": "amoral",
    "amoralului": "amoral",
    "amorezata": "amorezat",
    "amorezată": "amorezat",
    "amorezate": "amorezat",
    "amorezatei": "amorezat",
    "amorezatele": "amorezat",
    "amorezatelor": "amorezat",
    "amorezați": "amorezat",
    "amorezații": "amorezat",
    "amorezaților": "amorezat",
    "amorezatul": "amorezat",
    "amorezatului": "amorezat",
    "amorfa": "amorf",
    "amorfă": "amorf",
    "amorfe": "amorf",
    "amorfei": "amorf",
    "amorfele": "amorf",
    "amorfelor": "amorf",
    "amorfi": "amorf",
    "amorfii": "amorf",
    "amorfilor": "amorf",
    "amorful": "amorf",
    "amorfului": "amorf",
    "amoroasa": "amoros",
    "amoroasă": "amoros",
    "amoroase": "amoros",
    "amoroasei": "amoros",
    "amoroasele": "amoros",
    "amoroaselor": "amoros",
    "amoroși": "amoros",
    "amoroșii": "amoros",
    "amoroșilor": "amoros",
    "amorosul": "amoros",
    "amorosului": "amoros",
    "amorul-propriu": "amor-propriu",
    "amorului-propriu": "amor-propriu",
    "amorsa": "amorsă",
    "amorse": "amorsă",
    "amorsei": "amorsă",
    "amorsele": "amorsă",
    "amorselor": "amorsă",
    "amorțeala": "amorțeală",
    "amorțeli": "amorțeală",
    "amorțelii": "amorțeală",
    "amorțelile": "amorțeală",
    "amorțelilor": "amorțeală",
    "amorțea": "amorți",
    "amorțeai": "amorți",
    "amorțeam": "amorți",
    "amorțească": "amorți",
    "amorțeați": "amorți",
    "amorțeau": "amorți",
    "amorțesc": "amorți",
    "amorțește": "amorți",
    "amorțești": "amorți",
    "amorții": "amorți",
    "amorțim": "amorți",
    "amorțind": "amorți",
    "amorțindu": "amorți",
    "amorțiră": "amorți",
    "amorțirăm": "amorți",
    "amorțirăți": "amorți",
    "amorțise": "amorți",
    "amorțisem": "amorți",
    "amorțiseră": "amorți",
    "amorțiserăm": "amorți",
    "amorțiserăți": "amorți",
    "amorțiseși": "amorți",
    "amorțiși": "amorți",
    "amorțit": "amorți",
    "amorțiți": "amorți",
    "amorțitu": "amorți",
    "neamorțind": "amorți",
    "neamorțindu": "amorți",
    "nemaiamorțind": "amorți",
    "nemaiamorțindu": "amorți",
    "amorțirea": "amorțire",
    "amorțiri": "amorțire",
    "amorțirii": "amorțire",
    "amortismente": "amortisment",
    "amortismentele": "amortisment",
    "amortismentelor": "amortisment",
    "amortismentul": "amortisment",
    "amortismentului": "amortisment",
    "amorțita": "amorțit",
    "amorțită": "amorțit",
    "amorțite": "amorțit",
    "amorțitei": "amorțit",
    "amorțitele": "amorțit",
    "amorțitelor": "amorțit",
    "amorțiți": "amorțit",
    "amorțiții": "amorțit",
    "amorțiților": "amorțit",
    "amorțitul": "amorțit",
    "amorțitului": "amorțit",
    "amorțita": "amorțită",
    "amorțite": "amorțită",
    "amorțitei": "amorțită",
    "amorțitele": "amorțită",
    "amorțitelor": "amorțită",
    "amortiză": "amortiza",
    "amortizai": "amortiza",
    "amortizam": "amortiza",
    "amortizăm": "amortiza",
    "amortizând": "amortiza",
    "amortizându": "amortiza",
    "amortizară": "amortiza",
    "amortizarăm": "amortiza",
    "amortizarăți": "amortiza",
    "amortizase": "amortiza",
    "amortizasem": "amortiza",
    "amortizaseră": "amortiza",
    "amortizaserăm": "amortiza",
    "amortizaserăți": "amortiza",
    "amortizaseși": "amortiza",
    "amortizași": "amortiza",
    "amortizat": "amortiza",
    "amortizați": "amortiza",
    "amortizatu": "amortiza",
    "amortizau": "amortiza",
    "amortizează": "amortiza",
    "amortizez": "amortiza",
    "amortizeze": "amortiza",
    "amortizezi": "amortiza",
    "neamortizând": "amortiza",
    "neamortizându": "amortiza",
    "nemaiamortizând": "amortiza",
    "nemaiamortizându": "amortiza",
    "amortizabilă": "amortizabil",
    "amortizabile": "amortizabil",
    "amortizabili": "amortizabil",
    "amortizarea": "amortizare",
    "amortizări": "amortizare",
    "amortizării": "amortizare",
    "amortizările": "amortizare",
    "amortizata": "amortizat",
    "amortizată": "amortizat",
    "amortizate": "amortizat",
    "amortizatei": "amortizat",
    "amortizatele": "amortizat",
    "amortizatelor": "amortizat",
    "amortizați": "amortizat",
    "amortizații": "amortizat",
    "amortizaților": "amortizat",
    "amortizatul": "amortizat",
    "amortizatului": "amortizat",
    "amovibila": "amovibil",
    "amovibilă": "amovibil",
    "amovibile": "amovibil",
    "amovibilei": "amovibil",
    "amovibilele": "amovibil",
    "amovibilelor": "amovibil",
    "amovibili": "amovibil",
    "amovibilii": "amovibil",
    "amovibililor": "amovibil",
    "amovibilul": "amovibil",
    "amovibilului": "amovibil",
    "amperi": "amper",
    "amperii": "amper",
    "amperilor": "amper",
    "amperul": "amper",
    "amperului": "amper",
    "amper-ora": "amper-oră",
    "amper-ore": "amper-oră",
    "amper-orei": "amper-oră",
    "amper-orele": "amper-oră",
    "amper-orelor": "amper-oră",
    "amper-spira": "amper-spiră",
    "amper-spire": "amper-spiră",
    "amper-spirei": "amper-spiră",
    "amper-spirele": "amper-spiră",
    "amper-spirelor": "amper-spiră",
    "amplasă": "amplasa",
    "amplasai": "amplasa",
    "amplasam": "amplasa",
    "amplasăm": "amplasa",
    "amplasând": "amplasa",
    "amplasându": "amplasa",
    "amplasară": "amplasa",
    "amplasarăm": "amplasa",
    "amplasarăți": "amplasa",
    "amplasase": "amplasa",
    "amplasasem": "amplasa",
    "amplasaseră": "amplasa",
    "amplasaserăm": "amplasa",
    "amplasaserăți": "amplasa",
    "amplasaseși": "amplasa",
    "amplasași": "amplasa",
    "amplasat": "amplasa",
    "amplasați": "amplasa",
    "amplasatu": "amplasa",
    "amplasau": "amplasa",
    "amplasează": "amplasa",
    "amplasez": "amplasa",
    "amplaseze": "amplasa",
    "amplasezi": "amplasa",
    "neamplasând": "amplasa",
    "neamplasându": "amplasa",
    "nemaiamplasând": "amplasa",
    "nemaiamplasându": "amplasa",
    "amplasabilă": "amplasabil",
    "amplasabile": "amplasabil",
    "amplasabili": "amplasabil",
    "amplasamente": "amplasament",
    "amplasamentele": "amplasament",
    "amplasamentelor": "amplasament",
    "amplasamentul": "amplasament",
    "amplasamentului": "amplasament",
    "amplasarea": "amplasare",
    "amplasări": "amplasare",
    "amplasării": "amplasare",
    "amplasările": "amplasare",
    "amplasata": "amplasat",
    "amplasată": "amplasat",
    "amplasate": "amplasat",
    "amplasatei": "amplasat",
    "amplasatele": "amplasat",
    "amplasatelor": "amplasat",
    "amplasați": "amplasat",
    "amplasații": "amplasat",
    "amplasaților": "amplasat",
    "amplasatul": "amplasat",
    "amplasatului": "amplasat",
    "amplific": "amplifica",
    "amplifică": "amplifica",
    "amplificai": "amplifica",
    "amplificam": "amplifica",
    "amplificăm": "amplifica",
    "amplificând": "amplifica",
    "amplificându": "amplifica",
    "amplificară": "amplifica",
    "amplificarăm": "amplifica",
    "amplificarăți": "amplifica",
    "amplificase": "amplifica",
    "amplificasem": "amplifica",
    "amplificaseră": "amplifica",
    "amplificaserăm": "amplifica",
    "amplificaserăți": "amplifica",
    "amplificaseși": "amplifica",
    "amplificași": "amplifica",
    "amplificat": "amplifica",
    "amplificați": "amplifica",
    "amplificatu": "amplifica",
    "amplificau": "amplifica",
    "amplifice": "amplifica",
    "amplifici": "amplifica",
    "neamplificând": "amplifica",
    "neamplificându": "amplifica",
    "nemaiamplificând": "amplifica",
    "nemaiamplificându": "amplifica",
    "amplificabilă": "amplificabil",
    "amplificabile": "amplificabil",
    "amplificabili": "amplificabil",
    "amplificarea": "amplificare",
    "amplificări": "amplificare",
    "amplificării": "amplificare",
    "amplificările": "amplificare",
    "amplificata": "amplificat",
    "amplificată": "amplificat",
    "amplificate": "amplificat",
    "amplificatei": "amplificat",
    "amplificatele": "amplificat",
    "amplificatelor": "amplificat",
    "amplificați": "amplificat",
    "amplificații": "amplificat",
    "amplificaților": "amplificat",
    "amplificatul": "amplificat",
    "amplificatului": "amplificat",
    "amplificatoare": "amplificator",
    "amplificatoarea": "amplificator",
    "amplificatoarei": "amplificator",
    "amplificatoarele": "amplificator",
    "amplificatoarelor": "amplificator",
    "amplificatori": "amplificator",
    "amplificatorii": "amplificator",
    "amplificatorilor": "amplificator",
    "amplificatorul": "amplificator",
    "amplificatorului": "amplificator",
    "amplitudinea": "amplitudine",
    "amplitudini": "amplitudine",
    "amplitudinii": "amplitudine",
    "amplitudinile": "amplitudine",
    "amplitudinilor": "amplitudine",
    "amploaiați": "amploaia",
    "amploaiații": "amploaia",
    "amploaiaților": "amploaia",
    "amploaiatul": "amploaia",
    "amploaiatului": "amploaia",
    "amploarea": "amploare",
    "amplori": "amploare",
    "amplorii": "amploare",
    "amplorile": "amploare",
    "amplorilor": "amploare",
    "amploiați": "amploiat",
    "amploiații": "amploiat",
    "amploiaților": "amploiat",
    "amploiata": "amploiată",
    "amploiate": "amploiată",
    "amploiatei": "amploiată",
    "amploiatele": "amploiată",
    "amploiatelor": "amploiată",
    "amploiatul": "amploiată",
    "amploiatului": "amploiată",
    "ampla": "amplu",
    "amplă": "amplu",
    "ample": "amplu",
    "amplei": "amplu",
    "amplele": "amplu",
    "amplelor": "amplu",
    "ampli": "amplu",
    "amplii": "amplu",
    "amplilor": "amplu",
    "amplul": "amplu",
    "amplului": "amplu",
    "amprenta": "amprentă",
    "amprente": "amprentă",
    "amprentei": "amprentă",
    "amprentele": "amprentă",
    "amprentelor": "amprentă",
    "ampută": "amputa",
    "amputai": "amputa",
    "amputam": "amputa",
    "amputăm": "amputa",
    "amputând": "amputa",
    "amputându": "amputa",
    "amputară": "amputa",
    "amputarăm": "amputa",
    "amputarăți": "amputa",
    "amputase": "amputa",
    "amputasem": "amputa",
    "amputaseră": "amputa",
    "amputaserăm": "amputa",
    "amputaserăți": "amputa",
    "amputaseși": "amputa",
    "amputași": "amputa",
    "amputat": "amputa",
    "amputați": "amputa",
    "amputatu": "amputa",
    "amputau": "amputa",
    "amputează": "amputa",
    "amputez": "amputa",
    "amputeze": "amputa",
    "amputezi": "amputa",
    "neamputând": "amputa",
    "neamputându": "amputa",
    "nemaiamputând": "amputa",
    "nemaiamputându": "amputa",
    "amputabilă": "amputabil",
    "amputabile": "amputabil",
    "amputabili": "amputabil",
    "amputarea": "amputare",
    "amputări": "amputare",
    "amputării": "amputare",
    "amputările": "amputare",
    "amputata": "amputat",
    "amputată": "amputat",
    "amputate": "amputat",
    "amputatei": "amputat",
    "amputatele": "amputat",
    "amputatelor": "amputat",
    "amputați": "amputat",
    "amputații": "amputat",
    "amputaților": "amputat",
    "amputatul": "amputat",
    "amputatului": "amputat",
    "amputata": "amputată",
    "amputate": "amputată",
    "amputatei": "amputată",
    "amputatele": "amputată",
    "amputatelor": "amputată",
    "amuleta": "amuletă",
    "amulete": "amuletă",
    "amuletei": "amuletă",
    "amuletele": "amuletă",
    "amuletelor": "amuletă",
    "amurgul": "amurg",
    "amurgului": "amurg",
    "amurguri": "amurg",
    "amurgurile": "amurg",
    "amurgurilor": "amurg",
    "amurgea": "amurgi",
    "amurgească": "amurgi",
    "amurgește": "amurgi",
    "amurgind": "amurgi",
    "amurgise": "amurgi",
    "amurgit": "amurgi",
    "neamurgind": "amurgi",
    "nemaiamurgind": "amurgi",
    "amurgirea": "amurgire",
    "amurgiri": "amurgire",
    "amurgirii": "amurgire",
    "amurgirile": "amurgire",
    "amuțirile": "amurgire",
    "amurgita": "amurgit",
    "amurgită": "amurgit",
    "amurgite": "amurgit",
    "amurgitei": "amurgit",
    "amurgitele": "amurgit",
    "amurgitelor": "amurgit",
    "amurgiți": "amurgit",
    "amurgiții": "amurgit",
    "amurgiților": "amurgit",
    "amurgitul": "amurgit",
    "amurgitului": "amurgit",
    "amuțea": "amuți",
    "amuțeai": "amuți",
    "amuțeam": "amuți",
    "amuțească": "amuți",
    "amuțeați": "amuți",
    "amuțeau": "amuți",
    "amuțesc": "amuți",
    "amuțește": "amuți",
    "amuțești": "amuți",
    "amuții": "amuți",
    "amuțim": "amuți",
    "amuțind": "amuți",
    "amuțindu": "amuți",
    "amuțiră": "amuți",
    "amuțirăm": "amuți",
    "amuțirăți": "amuți",
    "amuțise": "amuți",
    "amuțisem": "amuți",
    "amuțiseră": "amuți",
    "amuțiserăm": "amuți",
    "amuțiserăți": "amuți",
    "amuțiseși": "amuți",
    "amuțiși": "amuți",
    "amuțit": "amuți",
    "amuțiți": "amuți",
    "amuțitu": "amuți",
    "neamuțind": "amuți",
    "neamuțindu": "amuți",
    "nemaiamuțind": "amuți",
    "nemaiamuțindu": "amuți",
    "amuțirea": "amuțire",
    "amuțiri": "amuțire",
    "amuțirii": "amuțire",
    "amuțita": "amuțit",
    "amuțită": "amuțit",
    "amuțite": "amuțit",
    "amuțitei": "amuțit",
    "amuțitele": "amuțit",
    "amuțitelor": "amuțit",
    "amuțiți": "amuțit",
    "amuțiții": "amuțit",
    "amuțiților": "amuțit",
    "amuțitul": "amuțit",
    "amuțitului": "amuțit",
    "amuz": "amuza",
    "amuză": "amuza",
    "amuzai": "amuza",
    "amuzam": "amuza",
    "amuzăm": "amuza",
    "amuzând": "amuza",
    "amuzându": "amuza",
    "amuzară": "amuza",
    "amuzarăm": "amuza",
    "amuzarăți": "amuza",
    "amuzase": "amuza",
    "amuzasem": "amuza",
    "amuzaseră": "amuza",
    "amuzaserăm": "amuza",
    "amuzaserăți": "amuza",
    "amuzaseși": "amuza",
    "amuzași": "amuza",
    "amuzat": "amuza",
    "amuzați": "amuza",
    "amuzatu": "amuza",
    "amuzau": "amuza",
    "amuze": "amuza",
    "amuzi": "amuza",
    "neamuzând": "amuza",
    "neamuzându": "amuza",
    "nemaiamuzând": "amuza",
    "nemaiamuzându": "amuza",
    "amuzamente": "amuzament",
    "amuzamentele": "amuzament",
    "amuzamentelor": "amuzament",
    "amuzamentul": "amuzament",
    "amuzamentului": "amuzament",
    "amuzanta": "amuzant",
    "amuzantă": "amuzant",
    "amuzante": "amuzant",
    "amuzantei": "amuzant",
    "amuzantele": "amuzant",
    "amuzantelor": "amuzant",
    "amuzanți": "amuzant",
    "amuzanții": "amuzant",
    "amuzanților": "amuzant",
    "amuzantul": "amuzant",
    "amuzantului": "amuzant",
    "amuzarea": "amuzare",
    "amuzări": "amuzare",
    "amuzării": "amuzare",
    "amuzările": "amuzare",
    "amuzata": "amuzat",
    "amuzată": "amuzat",
    "amuzate": "amuzat",
    "amuzatei": "amuzat",
    "amuzatele": "amuzat",
    "amuzatelor": "amuzat",
    "amuzați": "amuzat",
    "amuzații": "amuzat",
    "amuzaților": "amuzat",
    "amuzatul": "amuzat",
    "amuzatului": "amuzat",
    "amvoane": "amvon",
    "amvoanele": "amvon",
    "amvoanelor": "amvon",
    "amvonul": "amvon",
    "amvonului": "amvon",
    "ani": "an",
    "anii": "an",
    "anilor": "an",
    "anu": "an",
    "anul": "an",
    "anului": "an",
    "Ană": "Ana",
    "Ane": "Ana",
    "Anei": "Ana",
    "anabaptista": "anabaptist",
    "anabaptistă": "anabaptist",
    "anabaptiste": "anabaptist",
    "anabaptistei": "anabaptist",
    "anabaptistele": "anabaptist",
    "anabaptistelor": "anabaptist",
    "anabaptiști": "anabaptist",
    "anabaptiștii": "anabaptist",
    "anabaptiștilor": "anabaptist",
    "anabaptistul": "anabaptist",
    "anabaptistului": "anabaptist",
    "anabolisme": "anabolism",
    "anabolismele": "anabolism",
    "anabolismelor": "anabolism",
    "anabolismul": "anabolism",
    "anabolismului": "anabolism",
    "anacolute": "anacolut",
    "anacolutele": "anacolut",
    "anacolutelor": "anacolut",
    "anacolutul": "anacolut",
    "anacolutului": "anacolut",
    "anacoluturi": "anacolut",
    "anacoluturile": "anacolut",
    "anacoluturilor": "anacolut",
    "anacreontica": "anacreontic",
    "anacreontică": "anacreontic",
    "anacreontice": "anacreontic",
    "anacreonticei": "anacreontic",
    "anacreonticele": "anacreontic",
    "anacreonticelor": "anacreontic",
    "anacreontici": "anacreontic",
    "anacreonticii": "anacreontic",
    "anacreonticilor": "anacreontic",
    "anacreonticul": "anacreontic",
    "anacreonticului": "anacreontic",
    "anacronica": "anacronic",
    "anacronică": "anacronic",
    "anacronice": "anacronic",
    "anacronicei": "anacronic",
    "anacronicele": "anacronic",
    "anacronicelor": "anacronic",
    "anacronici": "anacronic",
    "anacronicii": "anacronic",
    "anacronicilor": "anacronic",
    "anacronicul": "anacronic",
    "anacronicului": "anacronic",
    "anacronisme": "anacronism",
    "anacronismele": "anacronism",
    "anacronismelor": "anacronism",
    "anacronismul": "anacronism",
    "anacronismului": "anacronism",
    "anacronistica": "anacronistic",
    "anacronistică": "anacronistic",
    "anacronistice": "anacronistic",
    "anacronisticei": "anacronistic",
    "anacronisticele": "anacronistic",
    "anacronisticelor": "anacronistic",
    "anacronistici": "anacronistic",
    "anacronisticii": "anacronistic",
    "anacronisticilor": "anacronistic",
    "anacronisticul": "anacronistic",
    "anacronisticului": "anacronistic",
    "anaeroba": "anaerob",
    "anaerobă": "anaerob",
    "anaerobe": "anaerob",
    "anaerobei": "anaerob",
    "anaerobele": "anaerob",
    "anaerobelor": "anaerob",
    "anaerobi": "anaerob",
    "anaerobii": "anaerob",
    "anaerobilor": "anaerob",
    "anaerobul": "anaerob",
    "anaerobului": "anaerob",
    "anaerobiotica": "anaerobiotic",
    "anaerobiotică": "anaerobiotic",
    "anaerobiotice": "anaerobiotic",
    "anaerobioticei": "anaerobiotic",
    "anaerobioticele": "anaerobiotic",
    "anaerobioticelor": "anaerobiotic",
    "anaerobiotici": "anaerobiotic",
    "anaerobioticii": "anaerobiotic",
    "anaerobioticilor": "anaerobiotic",
    "anaerobioticul": "anaerobiotic",
    "anaerobioticului": "anaerobiotic",
    "anafilactica": "anafilactic",
    "anafilactică": "anafilactic",
    "anafilactice": "anafilactic",
    "anafilacticei": "anafilactic",
    "anafilacticele": "anafilactic",
    "anafilacticelor": "anafilactic",
    "anafilactici": "anafilactic",
    "anafilacticii": "anafilactic",
    "anafilacticilor": "anafilactic",
    "anafilacticul": "anafilactic",
    "anafilacticului": "anafilactic",
    "anafora": "anaforă",
    "anafore": "anaforă",
    "anaforei": "anaforă",
    "anaforele": "anaforă",
    "anaforelor": "anaforă",
    "anagrama": "anagramă",
    "anagrame": "anagramă",
    "anagramei": "anagramă",
    "anagramele": "anagramă",
    "anagramelor": "anagramă",
    "anahoretica": "anahoretic",
    "anahoretică": "anahoretic",
    "anahoretice": "anahoretic",
    "anahoreticei": "anahoretic",
    "anahoreticele": "anahoretic",
    "anahoreticelor": "anahoretic",
    "anahoretici": "anahoretic",
    "anahoreticii": "anahoretic",
    "anahoreticilor": "anahoretic",
    "anahoreticul": "anahoretic",
    "anahoreticului": "anahoretic",
    "anala": "anal",
    "anală": "anal",
    "anale": "anal",
    "analei": "anal",
    "analele": "anal",
    "analelor": "anal",
    "anali": "anal",
    "analii": "anal",
    "analilor": "anal",
    "analul": "anal",
    "analului": "anal",
    "analele": "anale",
    "analelor": "anale",
    "analfabeți": "analfabet",
    "analfabeții": "analfabet",
    "analfabeților": "analfabet",
    "analfabetul": "analfabet",
    "analfabetului": "analfabet",
    "analfabeta": "analfabetă",
    "analfabete": "analfabetă",
    "analfabetei": "analfabetă",
    "analfabetele": "analfabetă",
    "analfabetelor": "analfabetă",
    "analfabetismul": "analfabetism",
    "analfabetismului": "analfabetism",
    "analgezica": "analgezic",
    "analgezică": "analgezic",
    "analgezice": "analgezic",
    "analgezicei": "analgezic",
    "analgezicele": "analgezic",
    "analgezicelor": "analgezic",
    "analgezici": "analgezic",
    "analgezicii": "analgezic",
    "analgezicilor": "analgezic",
    "analgezicul": "analgezic",
    "analgezicului": "analgezic",
    "analiști": "analist",
    "analiștii": "analist",
    "analiștilor": "analist",
    "analistul": "analist",
    "analistului": "analist",
    "analitica": "analitic",
    "analitică": "analitic",
    "analitice": "analitic",
    "analiticei": "analitic",
    "analiticele": "analitic",
    "analiticelor": "analitic",
    "analitici": "analitic",
    "analiticii": "analitic",
    "analiticilor": "analitic",
    "analiticul": "analitic",
    "analiticului": "analitic",
    "analitica": "analitică",
    "analitice": "analitică",
    "analiticele": "analitică",
    "analiticelor": "analitică",
    "analiticii": "analitică",
    "analiză": "analiza",
    "analizai": "analiza",
    "analizam": "analiza",
    "analizăm": "analiza",
    "analizând": "analiza",
    "analizându": "analiza",
    "analizară": "analiza",
    "analizarăm": "analiza",
    "analizarăți": "analiza",
    "analizase": "analiza",
    "analizasem": "analiza",
    "analizaseră": "analiza",
    "analizaserăm": "analiza",
    "analizaserăți": "analiza",
    "analizaseși": "analiza",
    "analizași": "analiza",
    "analizat": "analiza",
    "analizați": "analiza",
    "analizatu": "analiza",
    "analizau": "analiza",
    "analizează": "analiza",
    "analizez": "analiza",
    "analizeze": "analiza",
    "analizezi": "analiza",
    "neanalizând": "analiza",
    "neanalizându": "analiza",
    "nemaianalizând": "analiza",
    "nemaianalizându": "analiza",
    "analiza": "analiză",
    "analize": "analiză",
    "analizei": "analiză",
    "analizele": "analiză",
    "analizelor": "analiză",
    "analizabila": "analizabil",
    "analizabilă": "analizabil",
    "analizabile": "analizabil",
    "analizabilei": "analizabil",
    "analizabilele": "analizabil",
    "analizabilelor": "analizabil",
    "analizabili": "analizabil",
    "analizabilii": "analizabil",
    "analizabililor": "analizabil",
    "analizabilul": "analizabil",
    "analizabilului": "analizabil",
    "analizarea": "analizare",
    "analizări": "analizare",
    "analizării": "analizare",
    "analizările": "analizare",
    "analizata": "analizat",
    "analizată": "analizat",
    "analizate": "analizat",
    "analizatei": "analizat",
    "analizatele": "analizat",
    "analizatelor": "analizat",
    "analizați": "analizat",
    "analizații": "analizat",
    "analizaților": "analizat",
    "analizatul": "analizat",
    "analizatului": "analizat",
    "analizatoare": "analizator",
    "analizatoarele": "analizator",
    "analizatoarelor": "analizator",
    "analizatorul": "analizator",
    "analizatorului": "analizator",
    "analoga": "analog",
    "analogă": "analog",
    "analoge": "analog",
    "analogei": "analog",
    "analogele": "analog",
    "analogelor": "analog",
    "analogi": "analog",
    "analogii": "analog",
    "analogilor": "analog",
    "analogul": "analog",
    "analogului": "analog",
    "analogica": "analogic",
    "analogică": "analogic",
    "analogice": "analogic",
    "analogicele": "analogic",
    "analogicelor": "analogic",
    "analogici": "analogic",
    "analogicii": "analogic",
    "analogicilor": "analogic",
    "analogicul": "analogic",
    "analogicului": "analogic",
    "analogia": "analogie",
    "analogiei": "analogie",
    "analogii": "analogie",
    "analogiile": "analogie",
    "analogiilor": "analogie",
    "ananghia": "ananghie",
    "ananghiei": "ananghie",
    "ananghii": "ananghie",
    "ananghiile": "ananghie",
    "ananghiilor": "ananghie",
    "anapești": "anapest",
    "anapeștii": "anapest",
    "anapeștilor": "anapest",
    "anapestul": "anapest",
    "anapestului": "anapest",
    "anapestica": "anapestic",
    "anapestică": "anapestic",
    "anapestice": "anapestic",
    "anapesticele": "anapestic",
    "anapesticelor": "anapestic",
    "anapestici": "anapestic",
    "anapesticii": "anapestic",
    "anapesticilor": "anapestic",
    "anapesticul": "anapestic",
    "anapesticului": "anapestic",
    "anarhica": "anarhic",
    "anarhică": "anarhic",
    "anarhice": "anarhic",
    "anarhicei": "anarhic",
    "anarhicele": "anarhic",
    "anarhicelor": "anarhic",
    "anarhici": "anarhic",
    "anarhicii": "anarhic",
    "anarhicilor": "anarhic",
    "anarhicul": "anarhic",
    "anarhicului": "anarhic",
    "anarhia": "anarhie",
    "anarhiei": "anarhie",
    "anarhii": "anarhie",
    "anarhiile": "anarhie",
    "anarhiilor": "anarhie",
    "anarhismul": "anarhism",
    "anarhismului": "anarhism",
    "anarhiști": "anarhist",
    "anarhiștii": "anarhist",
    "anarhiștilor": "anarhist",
    "anarhistul": "anarhist",
    "anarhistului": "anarhist",
    "anarhista": "anarhistă",
    "anarhiste": "anarhistă",
    "anarhistei": "anarhistă",
    "anarhistele": "anarhistă",
    "anarhistelor": "anarhistă",
    "anarhizarea": "anarhizare",
    "anarhizări": "anarhizare",
    "anarhizării": "anarhizare",
    "anarhizările": "anarhizare",
    "anarhizărilor": "anarhizare",
    "Anastasie": "Anastasia",
    "Anastasiei": "Anastasia",
    "Anastasii": "Anastasia",
    "anastatica": "anastatic",
    "anastatică": "anastatic",
    "anastatice": "anastatic",
    "anastaticei": "anastatic",
    "anastaticele": "anastatic",
    "anastaticelor": "anastatic",
    "anastatici": "anastatic",
    "anastaticii": "anastatic",
    "anastaticilor": "anastatic",
    "anastaticul": "anastatic",
    "anastaticului": "anastatic",
    "anastrofa": "anastrofă",
    "anastrofe": "anastrofă",
    "anastrofei": "anastrofă",
    "anastrofele": "anastrofă",
    "anastrofelor": "anastrofă",
    "anatema": "anatemă",
    "anateme": "anatemă",
    "anatemei": "anatemă",
    "anatemele": "anatemă",
    "anatemelor": "anatemă",
    "anatomica": "anatomic",
    "anatomică": "anatomic",
    "anatomice": "anatomic",
    "anatomicei": "anatomic",
    "anatomicele": "anatomic",
    "anatomicelor": "anatomic",
    "anatomici": "anatomic",
    "anatomicii": "anatomic",
    "anatomicilor": "anatomic",
    "anatomicul": "anatomic",
    "anatomicului": "anatomic",
    "anatomia": "anatomie",
    "anatomiei": "anatomie",
    "anatomii": "anatomie",
    "anatomiile": "anatomie",
    "anatomiilor": "anatomie",
    "Ancăi": "Anca",
    "ancestrala": "ancestral",
    "ancestrală": "ancestral",
    "ancestrale": "ancestral",
    "ancestralei": "ancestral",
    "ancestralele": "ancestral",
    "ancestralelor": "ancestral",
    "ancestrali": "ancestral",
    "ancestralii": "ancestral",
    "ancestralilor": "ancestral",
    "ancestralul": "ancestral",
    "ancestralului": "ancestral",
    "anchetă": "ancheta",
    "anchetai": "ancheta",
    "anchetam": "ancheta",
    "anchetăm": "ancheta",
    "anchetând": "ancheta",
    "anchetându": "ancheta",
    "anchetară": "ancheta",
    "anchetarăm": "ancheta",
    "anchetarăți": "ancheta",
    "anchetase": "ancheta",
    "anchetasem": "ancheta",
    "anchetaseră": "ancheta",
    "anchetaserăm": "ancheta",
    "anchetaserăți": "ancheta",
    "anchetaseși": "ancheta",
    "anchetași": "ancheta",
    "anchetat": "ancheta",
    "anchetați": "ancheta",
    "anchetatu": "ancheta",
    "anchetau": "ancheta",
    "anchetează": "ancheta",
    "anchetez": "ancheta",
    "ancheteze": "ancheta",
    "anchetezi": "ancheta",
    "neanchetând": "ancheta",
    "neanchetându": "ancheta",
    "nemaianchetând": "ancheta",
    "nemaianchetându": "ancheta",
    "ancheta": "anchetă",
    "anchete": "anchetă",
    "anchetei": "anchetă",
    "anchetele": "anchetă",
    "anchetelor": "anchetă",
    "anchetarea": "anchetare",
    "anchetări": "anchetare",
    "anchetării": "anchetare",
    "anchetările": "anchetare",
    "anchetata": "anchetat",
    "anchetată": "anchetat",
    "anchetate": "anchetat",
    "anchetatei": "anchetat",
    "anchetatele": "anchetat",
    "anchetatelor": "anchetat",
    "anchetați": "anchetat",
    "anchetații": "anchetat",
    "anchetaților": "anchetat",
    "anchetatul": "anchetat",
    "anchetatului": "anchetat",
    "anchetata": "anchetată",
    "anchetate": "anchetată",
    "anchetatei": "anchetată",
    "anchetatele": "anchetată",
    "anchetatelor": "anchetată",
    "anchetatoarea": "anchetatoare",
    "anchetatoarei": "anchetatoare",
    "anchetatoarele": "anchetatoare",
    "anchetatoarelor": "anchetatoare",
    "anchetatori": "anchetator",
    "anchetatorii": "anchetator",
    "anchetatorilor": "anchetator",
    "anchetatorul": "anchetator",
    "anchetatorului": "anchetator",
    "anchiloză": "anchiloza",
    "anchilozai": "anchiloza",
    "anchilozam": "anchiloza",
    "anchilozăm": "anchiloza",
    "anchilozând": "anchiloza",
    "anchilozându": "anchiloza",
    "anchilozară": "anchiloza",
    "anchilozarăm": "anchiloza",
    "anchilozarăți": "anchiloza",
    "anchilozase": "anchiloza",
    "anchilozasem": "anchiloza",
    "anchilozaseră": "anchiloza",
    "anchilozaserăm": "anchiloza",
    "anchilozaserăți": "anchiloza",
    "anchilozaseși": "anchiloza",
    "anchilozași": "anchiloza",
    "anchilozat": "anchiloza",
    "anchilozați": "anchiloza",
    "anchilozatu": "anchiloza",
    "anchilozau": "anchiloza",
    "anchilozează": "anchiloza",
    "anchilozez": "anchiloza",
    "anchilozeze": "anchiloza",
    "anchilozezi": "anchiloza",
    "neanchilozând": "anchiloza",
    "neanchilozându": "anchiloza",
    "nemaianchilozând": "anchiloza",
    "nemaianchilozându": "anchiloza",
    "anchiloza": "anchiloză",
    "anchiloze": "anchiloză",
    "anchilozei": "anchiloză",
    "anchilozele": "anchiloză",
    "anchilozelor": "anchiloză",
    "anchilozarea": "anchilozare",
    "anchilozări": "anchilozare",
    "anchilozării": "anchilozare",
    "anchilozările": "anchilozare",
    "anchilozata": "anchilozat",
    "anchilozată": "anchilozat",
    "anchilozate": "anchilozat",
    "anchilozatei": "anchilozat",
    "anchilozatele": "anchilozat",
    "anchilozatelor": "anchilozat",
    "anchilozați": "anchilozat",
    "anchilozații": "anchilozat",
    "anchilozaților": "anchilozat",
    "anchilozatul": "anchilozat",
    "anchilozatului": "anchilozat",
    "anchilozata": "anchilozată",
    "anchilozate": "anchilozată",
    "anchilozatei": "anchilozată",
    "anchilozatele": "anchilozată",
    "anchilozatelor": "anchilozată",
    "ancoră": "ancora",
    "ancorai": "ancora",
    "ancoram": "ancora",
    "ancorăm": "ancora",
    "ancorând": "ancora",
    "ancorându": "ancora",
    "ancorară": "ancora",
    "ancorarăm": "ancora",
    "ancorarăți": "ancora",
    "ancorase": "ancora",
    "ancorasem": "ancora",
    "ancoraseră": "ancora",
    "ancoraserăm": "ancora",
    "ancoraserăți": "ancora",
    "ancoraseși": "ancora",
    "ancorași": "ancora",
    "ancorat": "ancora",
    "ancorați": "ancora",
    "ancoratu": "ancora",
    "ancorau": "ancora",
    "ancorează": "ancora",
    "ancorez": "ancora",
    "ancoreze": "ancora",
    "ancorezi": "ancora",
    "neancorând": "ancora",
    "neancorându": "ancora",
    "nemaiancorând": "ancora",
    "nemaiancorându": "ancora",
    "ancora": "ancoră",
    "ancore": "ancoră",
    "ancorei": "ancoră",
    "ancorele": "ancoră",
    "ancorelor": "ancoră",
    "ancorarea": "ancorare",
    "ancorări": "ancorare",
    "ancorării": "ancorare",
    "ancorările": "ancorare",
    "ancorata": "ancorat",
    "ancorată": "ancorat",
    "ancorate": "ancorat",
    "ancoratei": "ancorat",
    "ancoratele": "ancorat",
    "ancoratelor": "ancorat",
    "ancorați": "ancorat",
    "ancorații": "ancorat",
    "ancoraților": "ancorat",
    "ancoratul": "ancorat",
    "ancoratului": "ancorat",
    "Andă": "Anda",
    "Ande": "Anda",
    "Andei": "Anda",
    "androgina": "androgin",
    "androgină": "androgin",
    "androgine": "androgin",
    "androginei": "androgin",
    "androginele": "androgin",
    "androginelor": "androgin",
    "androgini": "androgin",
    "androginii": "androgin",
    "androginilor": "androgin",
    "androginul": "androgin",
    "androginului": "androgin",
    "anduranța": "anduranță",
    "anduranțe": "anduranță",
    "anduranței": "anduranță",
    "anduranțele": "anduranță",
    "anduranțelor": "anduranță",
    "anecdota": "anecdotă",
    "anecdote": "anecdotă",
    "anecdotei": "anecdotă",
    "anecdotele": "anecdotă",
    "anecdotelor": "anecdotă",
    "anecdotica": "anecdotic",
    "anecdotică": "anecdotic",
    "anecdotice": "anecdotic",
    "anecdoticei": "anecdotic",
    "anecdoticele": "anecdotic",
    "anecdoticelor": "anecdotic",
    "anecdotici": "anecdotic",
    "anecdoticii": "anecdotic",
    "anecdoticilor": "anecdotic",
    "anecdoticul": "anecdotic",
    "anecdoticului": "anecdotic",
    "anemiai": "anemia",
    "anemiam": "anemia",
    "anemiară": "anemia",
    "anemiarăm": "anemia",
    "anemiarăți": "anemia",
    "anemiase": "anemia",
    "anemiasem": "anemia",
    "anemiaseră": "anemia",
    "anemiaserăm": "anemia",
    "anemiaserăți": "anemia",
    "anemiaseși": "anemia",
    "anemiași": "anemia",
    "anemiat": "anemia",
    "anemiați": "anemia",
    "anemiatu": "anemia",
    "anemiau": "anemia",
    "anemiază": "anemia",
    "anemie": "anemia",
    "anemiem": "anemia",
    "anemiez": "anemia",
    "anemieze": "anemia",
    "anemiezi": "anemia",
    "anemiind": "anemia",
    "anemiindu": "anemia",
    "neanemiind": "anemia",
    "neanemiindu": "anemia",
    "nemaianemiind": "anemia",
    "nemaianemiindu": "anemia",
    "anemiata": "anemiat",
    "anemiată": "anemiat",
    "anemiate": "anemiat",
    "anemiatei": "anemiat",
    "anemiatele": "anemiat",
    "anemiatelor": "anemiat",
    "anemiați": "anemiat",
    "anemiații": "anemiat",
    "anemiaților": "anemiat",
    "anemiatul": "anemiat",
    "anemiatului": "anemiat",
    "anemiata": "anemiată",
    "anemiate": "anemiată",
    "anemiatei": "anemiată",
    "anemiatele": "anemiată",
    "anemiatelor": "anemiată",
    "anemica": "anemic",
    "anemică": "anemic",
    "anemice": "anemic",
    "anemicei": "anemic",
    "anemicele": "anemic",
    "anemicelor": "anemic",
    "anemici": "anemic",
    "anemicii": "anemic",
    "anemicilor": "anemic",
    "anemicul": "anemic",
    "anemicului": "anemic",
    "anemia": "anemie",
    "anemiei": "anemie",
    "anemii": "anemie",
    "anemiile": "anemie",
    "anemiilor": "anemie",
    "anemierea": "anemiere",
    "anemieri": "anemiere",
    "anemierii": "anemiere",
    "anemierile": "anemiere",
    "anemometre": "anemometru",
    "anemometrele": "anemometru",
    "anemometrelor": "anemometru",
    "anemometrul": "anemometru",
    "anemometrului": "anemometru",
    "anemona": "anemonă",
    "anemone": "anemonă",
    "anemonei": "anemonă",
    "anemonele": "anemonă",
    "anemonelor": "anemonă",
    "anemoscoape": "anemoscop",
    "anemoscoapele": "anemoscop",
    "anemoscoapelor": "anemoscop",
    "anemoscopul": "anemoscop",
    "anemoscopului": "anemoscop",
    "anemostate": "anemostat",
    "anemostatele": "anemostat",
    "anemostatelor": "anemostat",
    "anemostatul": "anemostat",
    "anemostatului": "anemostat",
    "aneroide": "aneroid",
    "aneroidele": "aneroid",
    "aneroidelor": "aneroid",
    "aneroidul": "aneroid",
    "aneroidului": "aneroid",
    "anestezica": "anestezic",
    "anestezică": "anestezic",
    "anestezice": "anestezic",
    "anestezicei": "anestezic",
    "anestezicele": "anestezic",
    "anestezicelor": "anestezic",
    "anestezici": "anestezic",
    "anestezicii": "anestezic",
    "anestezicilor": "anestezic",
    "anestezicul": "anestezic",
    "anestezicului": "anestezic",
    "anestezia": "anestezie",
    "anesteziei": "anestezie",
    "anestezii": "anestezie",
    "anesteziile": "anestezie",
    "anesteziilor": "anestezie",
    "anevoioasa": "anevoios",
    "anevoioasă": "anevoios",
    "anevoioase": "anevoios",
    "anevoioasei": "anevoios",
    "anevoioasele": "anevoios",
    "anevoioaselor": "anevoios",
    "anevoioși": "anevoios",
    "anevoioșii": "anevoios",
    "anevoioșilor": "anevoios",
    "anevoiosul": "anevoios",
    "anevoiosului": "anevoios",
    "anexă": "anexa",
    "anexai": "anexa",
    "anexam": "anexa",
    "anexăm": "anexa",
    "anexând": "anexa",
    "anexându": "anexa",
    "anexară": "anexa",
    "anexarăm": "anexa",
    "anexarăți": "anexa",
    "anexase": "anexa",
    "anexasem": "anexa",
    "anexaseră": "anexa",
    "anexaserăm": "anexa",
    "anexaserăți": "anexa",
    "anexaseși": "anexa",
    "anexași": "anexa",
    "anexat": "anexa",
    "anexați": "anexa",
    "anexatu": "anexa",
    "anexau": "anexa",
    "anexează": "anexa",
    "anexez": "anexa",
    "anexeze": "anexa",
    "anexezi": "anexa",
    "neanexând": "anexa",
    "neanexându": "anexa",
    "nemaianexând": "anexa",
    "nemaianexându": "anexa",
    "anexa": "anexă",
    "anexe": "anexă",
    "anexei": "anexă",
    "anexele": "anexă",
    "anexelor": "anexă",
    "anexarea": "anexare",
    "anexări": "anexare",
    "anexării": "anexare",
    "anexările": "anexare",
    "anexata": "anexat",
    "anexată": "anexat",
    "anexate": "anexat",
    "anexatei": "anexat",
    "anexatele": "anexat",
    "anexatelor": "anexat",
    "anexați": "anexat",
    "anexații": "anexat",
    "anexaților": "anexat",
    "anexatul": "anexat",
    "anexatului": "anexat",
    "anexionista": "anexionist",
    "anexionistă": "anexionist",
    "anexioniste": "anexionist",
    "anexionistei": "anexionist",
    "anexionistele": "anexionist",
    "anexionistelor": "anexionist",
    "anexioniști": "anexionist",
    "anexioniștii": "anexionist",
    "anexioniștilor": "anexionist",
    "anexionistul": "anexionist",
    "anexionistului": "anexionist",
    "anexiunea": "anexiune",
    "anexiuni": "anexiune",
    "anexiunii": "anexiune",
    "anexiunile": "anexiune",
    "anexiunilor": "anexiune",
    "angajă": "angaja",
    "angajai": "angaja",
    "angajam": "angaja",
    "angajăm": "angaja",
    "angajând": "angaja",
    "angajându": "angaja",
    "angajară": "angaja",
    "angajarăm": "angaja",
    "angajarăți": "angaja",
    "angajase": "angaja",
    "angajasem": "angaja",
    "angajaseră": "angaja",
    "angajaserăm": "angaja",
    "angajaserăți": "angaja",
    "angajaseși": "angaja",
    "angajași": "angaja",
    "angajat": "angaja",
    "angajați": "angaja",
    "angajatu": "angaja",
    "angajau": "angaja",
    "angajează": "angaja",
    "angajez": "angaja",
    "angajeze": "angaja",
    "angajezi": "angaja",
    "neangajând": "angaja",
    "neangajându": "angaja",
    "nemaiangajând": "angaja",
    "nemaiangajându": "angaja",
    "angajamente": "angajament",
    "angajamentele": "angajament",
    "angajamentelor": "angajament",
    "angajamentul": "angajament",
    "angajamentului": "angajament",
    "angajarea": "angajare",
    "angajări": "angajare",
    "angajării": "angajare",
    "angajările": "angajare",
    "angajărilor": "angajare",
    "angajata": "angajat",
    "angajată": "angajat",
    "angajate": "angajat",
    "angajatei": "angajat",
    "angajatele": "angajat",
    "angajatelor": "angajat",
    "angajați": "angajat",
    "angajații": "angajat",
    "angajaților": "angajat",
    "angajatul": "angajat",
    "angajatului": "angajat",
    "angajata": "angajată",
    "angajate": "angajată",
    "angajatei": "angajată",
    "angajatele": "angajată",
    "angajatelor": "angajată",
    "angarale": "angara",
    "angaralei": "angara",
    "angaralele": "angara",
    "angaralelor": "angara",
    "angaraua": "angara",
    "Angelă": "Angela",
    "Angele": "Angela",
    "Angelei": "Angela",
    "angelica": "angelic",
    "angelică": "angelic",
    "angelice": "angelic",
    "angelicei": "angelic",
    "angelicele": "angelic",
    "angelicelor": "angelic",
    "angelici": "angelic",
    "angelicii": "angelic",
    "angelicilor": "angelic",
    "angelicul": "angelic",
    "angelicului": "angelic",
    "anghina": "anghină",
    "anghine": "anghină",
    "anghinei": "anghină",
    "anghinele": "anghină",
    "anghinelor": "anghină",
    "angiosperma": "angiosperm",
    "angiospermă": "angiosperm",
    "angiosperme": "angiosperm",
    "angiospermei": "angiosperm",
    "angiospermele": "angiosperm",
    "angiospermelor": "angiosperm",
    "angiospermi": "angiosperm",
    "angiospermii": "angiosperm",
    "angiospermilor": "angiosperm",
    "angiospermul": "angiosperm",
    "angiospermului": "angiosperm",
    "Anglie": "Anglia",
    "Angliei": "Anglia",
    "Anglii": "Anglia",
    "anglicana": "anglican",
    "anglicană": "anglican",
    "anglicane": "anglican",
    "anglicanei": "anglican",
    "anglicanele": "anglican",
    "anglicanelor": "anglican",
    "anglicani": "anglican",
    "anglicanii": "anglican",
    "anglicanilor": "anglican",
    "anglicanul": "anglican",
    "anglicanului": "anglican",
    "anglista": "anglist",
    "anglistă": "anglist",
    "angliste": "anglist",
    "anglistei": "anglist",
    "anglistele": "anglist",
    "anglistelor": "anglist",
    "angliști": "anglist",
    "angliștii": "anglist",
    "angliștilor": "anglist",
    "anglistul": "anglist",
    "anglistului": "anglist",
    "anglista": "anglistă",
    "angliste": "anglistă",
    "anglistei": "anglistă",
    "anglistele": "anglistă",
    "anglistelor": "anglistă",
    "anglistul": "anglistă",
    "anglistului": "anglistă",
    "angoasa": "angoasă",
    "angoase": "angoasă",
    "angoasei": "angoasă",
    "angoasele": "angoasă",
    "angoaselor": "angoasă",
    "angrenă": "angrena",
    "angrenai": "angrena",
    "angrenam": "angrena",
    "angrenăm": "angrena",
    "angrenând": "angrena",
    "angrenându": "angrena",
    "angrenară": "angrena",
    "angrenarăm": "angrena",
    "angrenarăți": "angrena",
    "angrenase": "angrena",
    "angrenasem": "angrena",
    "angrenaseră": "angrena",
    "angrenaserăm": "angrena",
    "angrenaserăți": "angrena",
    "angrenaseși": "angrena",
    "angrenași": "angrena",
    "angrenat": "angrena",
    "angrenați": "angrena",
    "angrenatu": "angrena",
    "angrenau": "angrena",
    "angrenează": "angrena",
    "angrenez": "angrena",
    "angreneze": "angrena",
    "angrenezi": "angrena",
    "neangrenând": "angrena",
    "neangrenându": "angrena",
    "nemaiangrenând": "angrena",
    "nemaiangrenându": "angrena",
    "angrenaje": "angrenaj",
    "angrenajele": "angrenaj",
    "angrenajelor": "angrenaj",
    "angrenajul": "angrenaj",
    "angrenajului": "angrenaj",
    "angrenarea": "angrenare",
    "angrenări": "angrenare",
    "angrenării": "angrenare",
    "angrenările": "angrenare",
    "angrenata": "angrenat",
    "angrenată": "angrenat",
    "angrenate": "angrenat",
    "angrenatei": "angrenat",
    "angrenatele": "angrenat",
    "angrenatelor": "angrenat",
    "angrenați": "angrenat",
    "angrenații": "angrenat",
    "angrenaților": "angrenat",
    "angrenatul": "angrenat",
    "angrenatului": "angrenat",
    "angrosiști": "angrosist",
    "angrosiștii": "angrosist",
    "angrosiștilor": "angrosist",
    "angrosistul": "angrosist",
    "angrosistului": "angrosist",
    "angroul": "angrou",
    "angroului": "angrou",
    "angrouri": "angrou",
    "angrourile": "angrou",
    "angrourilor": "angrou",
    "angstromi": "angstrom",
    "angstromii": "angstrom",
    "angstromilor": "angstrom",
    "angstromul": "angstrom",
    "angstromului": "angstrom",
    "angulara": "angular",
    "angulară": "angular",
    "angulare": "angular",
    "angularei": "angular",
    "angularele": "angular",
    "angularelor": "angular",
    "angulari": "angular",
    "angularii": "angular",
    "angularilor": "angular",
    "angularul": "angular",
    "angularului": "angular",
    "anguloasa": "angulos",
    "anguloasă": "angulos",
    "anguloase": "angulos",
    "anguloasei": "angulos",
    "anguloasele": "angulos",
    "anguloaselor": "angulos",
    "anguloși": "angulos",
    "anguloșii": "angulos",
    "anguloșilor": "angulos",
    "angulosul": "angulos",
    "angulosului": "angulos",
    "anhidra": "anhidru",
    "anhidră": "anhidru",
    "anhidre": "anhidru",
    "anhidrei": "anhidru",
    "anhidrele": "anhidru",
    "anhidrelor": "anhidru",
    "anhidri": "anhidru",
    "anhidrii": "anhidru",
    "anhidrilor": "anhidru",
    "anhidrul": "anhidru",
    "anhidrului": "anhidru",
    "anihilă": "anihila",
    "anihilai": "anihila",
    "anihilam": "anihila",
    "anihilăm": "anihila",
    "anihilând": "anihila",
    "anihilându": "anihila",
    "anihilară": "anihila",
    "anihilarăm": "anihila",
    "anihilarăți": "anihila",
    "anihilase": "anihila",
    "anihilasem": "anihila",
    "anihilaseră": "anihila",
    "anihilaserăm": "anihila",
    "anihilaserăți": "anihila",
    "anihilaseși": "anihila",
    "anihilași": "anihila",
    "anihilat": "anihila",
    "anihilați": "anihila",
    "anihilatu": "anihila",
    "anihilau": "anihila",
    "anihilează": "anihila",
    "anihilez": "anihila",
    "anihileze": "anihila",
    "anihilezi": "anihila",
    "neanihilând": "anihila",
    "neanihilându": "anihila",
    "nemaianihilând": "anihila",
    "nemaianihilându": "anihila",
    "anihilanta": "anihilant",
    "anihilantă": "anihilant",
    "anihilante": "anihilant",
    "anihilantei": "anihilant",
    "anihilantele": "anihilant",
    "anihilantelor": "anihilant",
    "anihilanți": "anihilant",
    "anihilanții": "anihilant",
    "anihilanților": "anihilant",
    "anihilantul": "anihilant",
    "anihilantului": "anihilant",
    "anihilarea": "anihilare",
    "anihilări": "anihilare",
    "anihilării": "anihilare",
    "anihilările": "anihilare",
    "anihilata": "anihilat",
    "anihilată": "anihilat",
    "anihilate": "anihilat",
    "anihilatei": "anihilat",
    "anihilatele": "anihilat",
    "anihilatelor": "anihilat",
    "anihilați": "anihilat",
    "anihilații": "anihilat",
    "anihilaților": "anihilat",
    "anihilatul": "anihilat",
    "anihilatului": "anihilat",
    "anihilatoare": "anihilator",
    "anihilatoarea": "anihilator",
    "anihilatoarei": "anihilator",
    "anihilatoarele": "anihilator",
    "anihilatoarelor": "anihilator",
    "anihilatori": "anihilator",
    "anihilatorii": "anihilator",
    "anihilatorilor": "anihilator",
    "anihilatorul": "anihilator",
    "anihilatorului": "anihilator",
    "animă": "anima",
    "animai": "anima",
    "animam": "anima",
    "animăm": "anima",
    "animând": "anima",
    "animându": "anima",
    "animară": "anima",
    "animarăm": "anima",
    "animarăți": "anima",
    "animase": "anima",
    "animasem": "anima",
    "animaseră": "anima",
    "animaserăm": "anima",
    "animaserăți": "anima",
    "animaseși": "anima",
    "animași": "anima",
    "animat": "anima",
    "animați": "anima",
    "animatu": "anima",
    "animau": "anima",
    "animează": "anima",
    "animeze": "anima",
    "animezi": "anima",
    "neanimând": "anima",
    "neanimându": "anima",
    "nemaianimând": "anima",
    "nemaianimându": "anima",
    "animale": "animal",
    "animalele": "animal",
    "animalelor": "animal",
    "animalul": "animal",
    "animalului": "animal",
    "animalica": "animalic",
    "animalică": "animalic",
    "animalice": "animalic",
    "animalicei": "animalic",
    "animalicele": "animalic",
    "animalicelor": "animalic",
    "animalici": "animalic",
    "animalicii": "animalic",
    "animalicilor": "animalic",
    "animalicul": "animalic",
    "animalicului": "animalic",
    "animaliera": "animalier",
    "animalieră": "animalier",
    "animaliere": "animalier",
    "animalierei": "animalier",
    "animalierele": "animalier",
    "animalierelor": "animalier",
    "animalieri": "animalier",
    "animalierii": "animalier",
    "animalierilor": "animalier",
    "animalierul": "animalier",
    "animalierului": "animalier",
    "animalitatea": "animalitate",
    "animalități": "animalitate",
    "animalității": "animalitate",
    "animalitățile": "animalitate",
    "animalităților": "animalitate",
    "animalizata": "animalizat",
    "animalizată": "animalizat",
    "animalizate": "animalizat",
    "animalizatei": "animalizat",
    "animalizatele": "animalizat",
    "animalizatelor": "animalizat",
    "animalizați": "animalizat",
    "animalizații": "animalizat",
    "animalizaților": "animalizat",
    "animalizatul": "animalizat",
    "animalizatului": "animalizat",
    "animarea": "animare",
    "animări": "animare",
    "animării": "animare",
    "animările": "animare",
    "animata": "animat",
    "animată": "animat",
    "animate": "animat",
    "animatei": "animat",
    "animatele": "animat",
    "animatelor": "animat",
    "animați": "animat",
    "animații": "animat",
    "animaților": "animat",
    "animatul": "animat",
    "animatului": "animat",
    "animația": "animație",
    "animației": "animație",
    "animații": "animație",
    "animațiile": "animație",
    "animațiilor": "animație",
    "animatoarea": "animatoare",
    "animatoarei": "animatoare",
    "animatoarele": "animatoare",
    "animatoarelor": "animatoare",
    "animatoare": "animator",
    "animatoarea": "animator",
    "animatoarei": "animator",
    "animatoarele": "animator",
    "animatoarelor": "animator",
    "animatori": "animator",
    "animatorii": "animator",
    "animatorilor": "animator",
    "animatorul": "animator",
    "animatorului": "animator",
    "animisme": "animism",
    "animismele": "animism",
    "animismelor": "animism",
    "animismul": "animism",
    "animismului": "animism",
    "animista": "animist",
    "animistă": "animist",
    "animiste": "animist",
    "animistei": "animist",
    "animistele": "animist",
    "animistelor": "animist",
    "animiști": "animist",
    "animiștii": "animist",
    "animiștilor": "animist",
    "animistul": "animist",
    "animistului": "animist",
    "animozitatea": "animozitate",
    "animozități": "animozitate",
    "animozității": "animozitate",
    "animozitățile": "animozitate",
    "animozităților": "animozitate",
    "anin": "anina",
    "anină": "anina",
    "aninai": "anina",
    "aninam": "anina",
    "aninăm": "anina",
    "aninând": "anina",
    "aninându": "anina",
    "aninară": "anina",
    "aninarăm": "anina",
    "aninarăți": "anina",
    "aninase": "anina",
    "aninasem": "anina",
    "aninaseră": "anina",
    "aninaserăm": "anina",
    "aninaserăți": "anina",
    "aninaseși": "anina",
    "aninași": "anina",
    "aninat": "anina",
    "aninați": "anina",
    "aninatu": "anina",
    "aninau": "anina",
    "anine": "anina",
    "anini": "anina",
    "aninată": "aninat",
    "aninate": "aninat",
    "aninați": "aninat",
    "aniversă": "aniversa",
    "aniversai": "aniversa",
    "aniversam": "aniversa",
    "aniversăm": "aniversa",
    "aniversând": "aniversa",
    "aniversându": "aniversa",
    "aniversară": "aniversa",
    "aniversarăm": "aniversa",
    "aniversarăți": "aniversa",
    "aniversase": "aniversa",
    "aniversasem": "aniversa",
    "aniversaseră": "aniversa",
    "aniversaserăm": "aniversa",
    "aniversaserăți": "aniversa",
    "aniversaseși": "aniversa",
    "aniversași": "aniversa",
    "aniversat": "aniversa",
    "aniversați": "aniversa",
    "aniversatu": "aniversa",
    "aniversau": "aniversa",
    "aniversează": "aniversa",
    "aniversez": "aniversa",
    "aniverseze": "aniversa",
    "aniversezi": "aniversa",
    "neaniversând": "aniversa",
    "neaniversându": "aniversa",
    "nemaianiversând": "aniversa",
    "nemaianiversându": "aniversa",
    "aniversara": "aniversar",
    "aniversară": "aniversar",
    "aniversare": "aniversar",
    "aniversarei": "aniversar",
    "aniversarele": "aniversar",
    "aniversarelor": "aniversar",
    "aniversari": "aniversar",
    "aniversarii": "aniversar",
    "aniversarilor": "aniversar",
    "aniversarul": "aniversar",
    "aniversarului": "aniversar",
    "aniversarea": "aniversare",
    "aniversări": "aniversare",
    "aniversării": "aniversare",
    "aniversările": "aniversare",
    "aniversata": "aniversat",
    "aniversată": "aniversat",
    "aniversate": "aniversat",
    "aniversatei": "aniversat",
    "aniversatele": "aniversat",
    "aniversatelor": "aniversat",
    "aniversați": "aniversat",
    "aniversații": "aniversat",
    "aniversaților": "aniversat",
    "aniversatul": "aniversat",
    "aniversatului": "aniversat",
    "aniversata": "aniversată",
    "aniversate": "aniversată",
    "aniversatei": "aniversată",
    "aniversatele": "aniversată",
    "aniversatelor": "aniversată",
    "Ankară": "Ankara",
    "Ankare": "Ankara",
    "Ankarei": "Ankara",
    "anii-lumină": "an-lumină",
    "anilor-lumină": "an-lumină",
    "ani-lumină": "an-lumină",
    "anul-lumină": "an-lumină",
    "anului-lumină": "an-lumină",
    "a.p.": "anni_praeteriti",
    "a.D.": "anno_Domini",
    "anodica": "anodic",
    "anodică": "anodic",
    "anodice": "anodic",
    "anodicei": "anodic",
    "anodicele": "anodic",
    "anodicelor": "anodic",
    "anodici": "anodic",
    "anodicii": "anodic",
    "anodicilor": "anodic",
    "anodicul": "anodic",
    "anodicului": "anodic",
    "anodina": "anodin",
    "anodină": "anodin",
    "anodine": "anodin",
    "anodinei": "anodin",
    "anodinele": "anodin",
    "anodinelor": "anodin",
    "anodini": "anodin",
    "anodinii": "anodin",
    "anodinilor": "anodin",
    "anodinul": "anodin",
    "anodinului": "anodin",
    "anofeli": "anofel",
    "anofelii": "anofel",
    "anofelilor": "anofel",
    "anofelul": "anofel",
    "anofelului": "anofel",
    "anofelogena": "anofelogen",
    "anofelogenă": "anofelogen",
    "anofelogene": "anofelogen",
    "anofelogenei": "anofelogen",
    "anofelogenele": "anofelogen",
    "anofelogenelor": "anofelogen",
    "anofelogeni": "anofelogen",
    "anofelogenii": "anofelogen",
    "anofelogenilor": "anofelogen",
    "anofelogenul": "anofelogen",
    "anofelogenului": "anofelogen",
    "anomalia": "anomalie",
    "anomaliei": "anomalie",
    "anomalii": "anomalie",
    "anomaliile": "anomalie",
    "anomaliilor": "anomalie",
    "anonima": "anonim",
    "anonimă": "anonim",
    "anonime": "anonim",
    "anonimei": "anonim",
    "anonimele": "anonim",
    "anonimelor": "anonim",
    "anonimi": "anonim",
    "anonimii": "anonim",
    "anonimilor": "anonim",
    "anonimul": "anonim",
    "anonimului": "anonim",
    "anonima": "anonimă",
    "anonime": "anonimă",
    "anonimei": "anonimă",
    "anonimele": "anonimă",
    "anonimelor": "anonimă",
    "anonimate": "anonimat",
    "anonimatele": "anonimat",
    "anonimatelor": "anonimat",
    "anonimatul": "anonimat",
    "anonimatului": "anonimat",
    "anorganica": "anorganic",
    "anorganică": "anorganic",
    "anorganice": "anorganic",
    "anorganicei": "anorganic",
    "anorganicele": "anorganic",
    "anorganicelor": "anorganic",
    "anorganici": "anorganic",
    "anorganicii": "anorganic",
    "anorganicilor": "anorganic",
    "anorganicul": "anorganic",
    "anorganicului": "anorganic",
    "anormala": "anormal",
    "anormală": "anormal",
    "anormale": "anormal",
    "anormalei": "anormal",
    "anormalele": "anormal",
    "anormalelor": "anormal",
    "anormali": "anormal",
    "anormalii": "anormal",
    "anormalilor": "anormal",
    "anormalul": "anormal",
    "anormalului": "anormal",
    "anosta": "anost",
    "anostă": "anost",
    "anoste": "anost",
    "anostei": "anost",
    "anostele": "anost",
    "anostelor": "anost",
    "anoști": "anost",
    "anoștii": "anost",
    "anoștilor": "anost",
    "anostul": "anost",
    "anostului": "anost",
    "anotimpul": "anotimp",
    "anotimpului": "anotimp",
    "anotimpuri": "anotimp",
    "anotimpurile": "anotimp",
    "anotimpurilor": "anotimp",
    "ansamblul": "ansamblu",
    "ansamblului": "ansamblu",
    "ansambluri": "ansamblu",
    "ansamblurile": "ansamblu",
    "ansamblurilor": "ansamblu",
    "antagonica": "antagonic",
    "antagonică": "antagonic",
    "antagonice": "antagonic",
    "antagonicei": "antagonic",
    "antagonicele": "antagonic",
    "antagonicelor": "antagonic",
    "antagonici": "antagonic",
    "antagonicii": "antagonic",
    "antagonicilor": "antagonic",
    "antagonicul": "antagonic",
    "antagonicului": "antagonic",
    "antagonisme": "antagonism",
    "antagonismele": "antagonism",
    "antagonismelor": "antagonism",
    "antagonismul": "antagonism",
    "antagonismului": "antagonism",
    "antagonista": "antagonist",
    "antagonistă": "antagonist",
    "antagoniste": "antagonist",
    "antagonistei": "antagonist",
    "antagonistele": "antagonist",
    "antagonistelor": "antagonist",
    "antagoniști": "antagonist",
    "antagoniștii": "antagonist",
    "antagoniștilor": "antagonist",
    "antagonistul": "antagonist",
    "antagonistului": "antagonist",
    "antale": "antal",
    "antalele": "antal",
    "antalelor": "antal",
    "antalul": "antal",
    "antalului": "antal",
    "anii-tampon": "an-tampon",
    "anilor-tampon": "an-tampon",
    "ani-tampon": "an-tampon",
    "anul-tampon": "an-tampon",
    "anului-tampon": "an-tampon",
    "antarctică": "antarctic",
    "antarctice": "antarctic",
    "antarctici": "antarctic",
    "Antarctică": "Antarctica",
    "Antarctici": "Antarctica",
    "Antarcticii": "Antarctica",
    "a.d.": "ante_diem",
    "a.m.": "ante_meridiem",
    "antebelica": "antebelic",
    "antebelică": "antebelic",
    "antebelice": "antebelic",
    "antebelicei": "antebelic",
    "antebelicele": "antebelic",
    "antebelicelor": "antebelic",
    "antebelici": "antebelic",
    "antebelicii": "antebelic",
    "antebelicilor": "antebelic",
    "antebelicul": "antebelic",
    "antebelicului": "antebelic",
    "antebrațe": "antebraț",
    "antebrațele": "antebraț",
    "antebrațelor": "antebraț",
    "antebrațul": "antebraț",
    "antebrațului": "antebraț",
    "antecedente": "antecedent",
    "antecedentele": "antecedent",
    "antecedentelor": "antecedent",
    "antecedentul": "antecedent",
    "antecedentului": "antecedent",
    "antecesoarea": "antecesoare",
    "antecesoarei": "antecesoare",
    "antecesoarele": "antecesoare",
    "antecesoarelor": "antecesoare",
    "antecesorul": "antecesor",
    "antecesorului": "antecesor",
    "anteclasați": "anteclasat",
    "anteclasații": "anteclasat",
    "anteclasaților": "anteclasat",
    "anteclasatul": "anteclasat",
    "anteclasatului": "anteclasat",
    "anteclasata": "anteclasată",
    "anteclasate": "anteclasată",
    "anteclasatei": "anteclasată",
    "anteclasatele": "anteclasată",
    "anteclasatelor": "anteclasată",
    "antedată": "antedata",
    "antedatai": "antedata",
    "antedatam": "antedata",
    "antedatăm": "antedata",
    "antedatând": "antedata",
    "antedatându": "antedata",
    "antedatară": "antedata",
    "antedatarăm": "antedata",
    "antedatarăți": "antedata",
    "antedatase": "antedata",
    "antedatasem": "antedata",
    "antedataseră": "antedata",
    "antedataserăm": "antedata",
    "antedataserăți": "antedata",
    "antedataseși": "antedata",
    "antedatași": "antedata",
    "antedatat": "antedata",
    "antedatați": "antedata",
    "antedatatu": "antedata",
    "antedatau": "antedata",
    "antedatează": "antedata",
    "antedatez": "antedata",
    "antedateze": "antedata",
    "antedatezi": "antedata",
    "antedatarea": "antedatare",
    "antedatări": "antedatare",
    "antedatării": "antedatare",
    "antedatările": "antedatare",
    "antedatărilor": "antedatare",
    "antedatata": "antedatat",
    "antedatată": "antedatat",
    "antedatate": "antedatat",
    "antedatatei": "antedatat",
    "antedatatele": "antedatat",
    "antedatatelor": "antedatat",
    "antedatați": "antedatat",
    "antedatații": "antedatat",
    "antedataților": "antedatat",
    "antedatato": "antedatat",
    "antedatatul": "antedatat",
    "antedatatule": "antedatat",
    "antedatatului": "antedatat",
    "antediluviana": "antediluvian",
    "antediluviană": "antediluvian",
    "antediluvianul": "antediluvian",
    "antediluvianului": "antediluvian",
    "antediluviene": "antediluvian",
    "antediluvienei": "antediluvian",
    "antediluvienele": "antediluvian",
    "antediluvienelor": "antediluvian",
    "antediluvieni": "antediluvian",
    "antediluvienii": "antediluvian",
    "antediluvienilor": "antediluvian",
    "antemergători": "antemergător",
    "antemergătorii": "antemergător",
    "antemergătorilor": "antemergător",
    "antemergătorul": "antemergător",
    "antemergătorului": "antemergător",
    "antemeridiana": "antemeridian",
    "antemeridiană": "antemeridian",
    "antemeridiane": "antemeridian",
    "antemeridianei": "antemeridian",
    "antemeridianele": "antemeridian",
    "antemeridianelor": "antemeridian",
    "antemeridiani": "antemeridian",
    "antemeridianii": "antemeridian",
    "antemeridianilor": "antemeridian",
    "antemeridianul": "antemeridian",
    "antemeridianului": "antemeridian",
    "antena": "antenă",
    "antene": "antenă",
    "antenei": "antenă",
    "antenele": "antenă",
    "antenelor": "antenă",
    "antepenultima": "antepenultim",
    "antepenultimă": "antepenultim",
    "antepenultime": "antepenultim",
    "antepenultimei": "antepenultim",
    "antepenultimele": "antepenultim",
    "antepenultimelor": "antepenultim",
    "antepenultimi": "antepenultim",
    "antepenultimii": "antepenultim",
    "antepenultimilor": "antepenultim",
    "antepenultimul": "antepenultim",
    "antepenultimului": "antepenultim",
    "anteprimirea": "anteprimire",
    "anteprimiri": "anteprimire",
    "anteprimirii": "anteprimire",
    "anteprimirile": "anteprimire",
    "anteprimirilor": "anteprimire",
    "anterioara": "anterior",
    "anterioară": "anterior",
    "anterioare": "anterior",
    "anterioarei": "anterior",
    "anterioarele": "anterior",
    "anterioarelor": "anterior",
    "anteriori": "anterior",
    "anteriorii": "anterior",
    "anteriorilor": "anterior",
    "anteriorul": "anterior",
    "anteriorului": "anterior",
    "anterie": "anteriu",
    "anteriele": "anteriu",
    "anterielor": "anteriu",
    "anteriul": "anteriu",
    "anteriului": "anteriu",
    "antete": "antet",
    "antetele": "antet",
    "antetelor": "antet",
    "antetul": "antet",
    "antetului": "antet",
    "antiaeriana": "antiaerian",
    "antiaeriană": "antiaerian",
    "antiaerianul": "antiaerian",
    "antiaerianului": "antiaerian",
    "antiaeriene": "antiaerian",
    "antiaerienei": "antiaerian",
    "antiaerienele": "antiaerian",
    "antiaerienelor": "antiaerian",
    "antiaerieni": "antiaerian",
    "antiaerienii": "antiaerian",
    "antiaerienilor": "antiaerian",
    "antialcoolica": "antialcoolic",
    "antialcoolică": "antialcoolic",
    "antialcoolice": "antialcoolic",
    "antialcoolicei": "antialcoolic",
    "antialcoolicele": "antialcoolic",
    "antialcoolicelor": "antialcoolic",
    "antialcoolici": "antialcoolic",
    "antialcoolicii": "antialcoolic",
    "antialcoolicilor": "antialcoolic",
    "antialcoolicul": "antialcoolic",
    "antialcoolicului": "antialcoolic",
    "antibacteriana": "antibacterian",
    "antibacteriană": "antibacterian",
    "antibacterianul": "antibacterian",
    "antibacterianului": "antibacterian",
    "antibacteriene": "antibacterian",
    "antibacterienei": "antibacterian",
    "antibacterienele": "antibacterian",
    "antibacterienelor": "antibacterian",
    "antibacterieni": "antibacterian",
    "antibacterienii": "antibacterian",
    "antibacterienilor": "antibacterian",
    "antibiotica": "antibiotic",
    "antibiotică": "antibiotic",
    "antibiotice": "antibiotic",
    "antibioticei": "antibiotic",
    "antibioticele": "antibiotic",
    "antibioticelor": "antibiotic",
    "antibiotici": "antibiotic",
    "antibioticii": "antibiotic",
    "antibioticilor": "antibiotic",
    "antibioticul": "antibiotic",
    "antibioticului": "antibiotic",
    "antibolșevica": "antibolșevic",
    "antibolșevică": "antibolșevic",
    "antibolșevice": "antibolșevic",
    "antibolșevicei": "antibolșevic",
    "antibolșevicele": "antibolșevic",
    "antibolșevicelor": "antibolșevic",
    "antibolșevici": "antibolșevic",
    "antibolșevicii": "antibolșevic",
    "antibolșevicilor": "antibolșevic",
    "antibolșevicul": "antibolșevic",
    "antibolșevicului": "antibolșevic",
    "antibolșevica": "antibolșevică",
    "antibolșevice": "antibolșevică",
    "antibolșevicei": "antibolșevică",
    "antibolșevicele": "antibolșevică",
    "antibolșevicelor": "antibolșevică",
    "antica": "antic",
    "antică": "antic",
    "antice": "antic",
    "anticei": "antic",
    "anticele": "antic",
    "anticelor": "antic",
    "antici": "antic",
    "anticii": "antic",
    "anticilor": "antic",
    "anticul": "antic",
    "anticului": "antic",
    "anticamera": "anticameră",
    "anticamere": "anticameră",
    "anticamerei": "anticameră",
    "anticamerele": "anticameră",
    "anticamerelor": "anticameră",
    "anticari": "anticar",
    "anticarii": "anticar",
    "anticarilor": "anticar",
    "anticarul": "anticar",
    "anticarului": "anticar",
    "anticariate": "anticariat",
    "anticariatele": "anticariat",
    "anticariatelor": "anticariat",
    "anticariatul": "anticariat",
    "anticariatului": "anticariat",
    "antic.": "antichitate",
    "antichitatea": "antichitate",
    "antichități": "antichitate",
    "antichității": "antichitate",
    "antichitățile": "antichitate",
    "antichităților": "antichitate",
    "anticipă": "anticipa",
    "anticipai": "anticipa",
    "anticipam": "anticipa",
    "anticipăm": "anticipa",
    "anticipând": "anticipa",
    "anticipându": "anticipa",
    "anticipară": "anticipa",
    "anticiparăm": "anticipa",
    "anticiparăți": "anticipa",
    "anticipase": "anticipa",
    "anticipasem": "anticipa",
    "anticipaseră": "anticipa",
    "anticipaserăm": "anticipa",
    "anticipaserăți": "anticipa",
    "anticipaseși": "anticipa",
    "anticipași": "anticipa",
    "anticipat": "anticipa",
    "anticipați": "anticipa",
    "anticipatu": "anticipa",
    "anticipau": "anticipa",
    "anticipează": "anticipa",
    "anticipez": "anticipa",
    "anticipeze": "anticipa",
    "anticipezi": "anticipa",
    "neanticipând": "anticipa",
    "neanticipându": "anticipa",
    "nemaianticipând": "anticipa",
    "nemaianticipându": "anticipa",
    "anticiparea": "anticipare",
    "anticipări": "anticipare",
    "anticipării": "anticipare",
    "anticipările": "anticipare",
    "anticipata": "anticipat",
    "anticipată": "anticipat",
    "anticipate": "anticipat",
    "anticipatei": "anticipat",
    "anticipatele": "anticipat",
    "anticipatelor": "anticipat",
    "anticipați": "anticipat",
    "anticipații": "anticipat",
    "anticipaților": "anticipat",
    "anticipatul": "anticipat",
    "anticipatului": "anticipat",
    "anticipata": "anticipată",
    "anticipate": "anticipată",
    "anticipatei": "anticipată",
    "anticipatele": "anticipată",
    "anticipatelor": "anticipată",
    "anticipația": "anticipație",
    "anticipației": "anticipație",
    "anticipații": "anticipație",
    "anticipațiile": "anticipație",
    "anticipațiilor": "anticipație",
    "anticlericala": "anticlerical",
    "anticlericală": "anticlerical",
    "anticlericale": "anticlerical",
    "anticlericalei": "anticlerical",
    "anticlericalele": "anticlerical",
    "anticlericalelor": "anticlerical",
    "anticlericali": "anticlerical",
    "anticlericalii": "anticlerical",
    "anticlericalilor": "anticlerical",
    "anticlericalul": "anticlerical",
    "anticlericalului": "anticlerical",
    "anticomunista": "anticomunist",
    "anticomunistă": "anticomunist",
    "anticomuniste": "anticomunist",
    "anticomunistei": "anticomunist",
    "anticomunistele": "anticomunist",
    "anticomunistelor": "anticomunist",
    "anticomuniști": "anticomunist",
    "anticomuniștii": "anticomunist",
    "anticomuniștilor": "anticomunist",
    "anticomunistul": "anticomunist",
    "anticomunistului": "anticomunist",
    "anticomunista": "anticomunistă",
    "anticomuniste": "anticomunistă",
    "anticomunistei": "anticomunistă",
    "anticomunistele": "anticomunistă",
    "anticomunistelor": "anticomunistă",
    "anticonstituționala": "anticonstituțional",
    "anticonstituțională": "anticonstituțional",
    "anticonstituționale": "anticonstituțional",
    "anticonstituționalei": "anticonstituțional",
    "anticonstituționalele": "anticonstituțional",
    "anticonstituționalelor": "anticonstituțional",
    "anticonstituționali": "anticonstituțional",
    "anticonstituționalii": "anticonstituțional",
    "anticonstituționalilor": "anticonstituțional",
    "anticonstituționalul": "anticonstituțional",
    "anticonstituționalului": "anticonstituțional",
    "anticorpi": "anticorp",
    "anticorpii": "anticorp",
    "anticorpilor": "anticorp",
    "anticorpul": "anticorp",
    "anticorpului": "anticorp",
    "anticreștina": "anticreștin",
    "anticreștină": "anticreștin",
    "anticreștine": "anticreștin",
    "anticreștinei": "anticreștin",
    "anticreștinele": "anticreștin",
    "anticreștinelor": "anticreștin",
    "anticreștini": "anticreștin",
    "anticreștinii": "anticreștin",
    "anticreștinilor": "anticreștin",
    "anticreștinul": "anticreștin",
    "anticreștinului": "anticreștin",
    "anticreștina": "anticreștină",
    "anticreștine": "anticreștină",
    "anticreștinei": "anticreștină",
    "anticreștinele": "anticreștină",
    "anticreștinelor": "anticreștină",
    "anticrista": "anticrist",
    "anticristă": "anticrist",
    "anticriste": "anticrist",
    "anticristei": "anticrist",
    "anticristele": "anticrist",
    "anticristelor": "anticrist",
    "anticriști": "anticrist",
    "anticriștii": "anticrist",
    "anticriștilor": "anticrist",
    "anticristul": "anticrist",
    "anticristului": "anticrist",
    "anticrista": "anticristă",
    "anticriste": "anticristă",
    "anticristei": "anticristă",
    "anticristele": "anticristă",
    "anticristelor": "anticristă",
    "antiderapanta": "antiderapant",
    "antiderapantă": "antiderapant",
    "antiderapante": "antiderapant",
    "antiderapantei": "antiderapant",
    "antiderapantele": "antiderapant",
    "antiderapantelor": "antiderapant",
    "antiderapanți": "antiderapant",
    "antiderapanții": "antiderapant",
    "antiderapanților": "antiderapant",
    "antiderapantul": "antiderapant",
    "antiderapantului": "antiderapant",
    "antidiareica": "antidiareic",
    "antidiareică": "antidiareic",
    "antidiareice": "antidiareic",
    "antidiareicei": "antidiareic",
    "antidiareicele": "antidiareic",
    "antidiareicelor": "antidiareic",
    "antidiareici": "antidiareic",
    "antidiareicii": "antidiareic",
    "antidiareicilor": "antidiareic",
    "antidiareicul": "antidiareic",
    "antidiareicului": "antidiareic",
    "antidinastica": "antidinastic",
    "antidinastică": "antidinastic",
    "antidinastice": "antidinastic",
    "antidinasticei": "antidinastic",
    "antidinasticele": "antidinastic",
    "antidinasticelor": "antidinastic",
    "antidinastici": "antidinastic",
    "antidinasticii": "antidinastic",
    "antidinasticilor": "antidinastic",
    "antidinasticul": "antidinastic",
    "antidinasticului": "antidinastic",
    "antidotul": "antidot",
    "antidotului": "antidot",
    "antidoturi": "antidot",
    "antidoturile": "antidot",
    "antidoturilor": "antidot",
    "antieducativa": "antieducativ",
    "antieducativă": "antieducativ",
    "antieducative": "antieducativ",
    "antieducativei": "antieducativ",
    "antieducativele": "antieducativ",
    "antieducativelor": "antieducativ",
    "antieducativi": "antieducativ",
    "antieducativii": "antieducativ",
    "antieducativilor": "antieducativ",
    "antieducativul": "antieducativ",
    "antieducativului": "antieducativ",
    "antiepidemica": "antiepidemic",
    "antiepidemică": "antiepidemic",
    "antiepidemice": "antiepidemic",
    "antiepidemicei": "antiepidemic",
    "antiepidemicele": "antiepidemic",
    "antiepidemicelor": "antiepidemic",
    "antiepidemici": "antiepidemic",
    "antiepidemicii": "antiepidemic",
    "antiepidemicilor": "antiepidemic",
    "antiepidemicul": "antiepidemic",
    "antiepidemicului": "antiepidemic",
    "antiestetica": "antiestetic",
    "antiestetică": "antiestetic",
    "antiestetice": "antiestetic",
    "antiesteticei": "antiestetic",
    "antiesteticele": "antiestetic",
    "antiesteticelor": "antiestetic",
    "antiestetici": "antiestetic",
    "antiesteticii": "antiestetic",
    "antiesteticilor": "antiestetic",
    "antiesteticul": "antiestetic",
    "antiesteticului": "antiestetic",
    "antifascista": "antifascist",
    "antifascistă": "antifascist",
    "antifasciste": "antifascist",
    "antifascistei": "antifascist",
    "antifascistele": "antifascist",
    "antifascistelor": "antifascist",
    "antifasciști": "antifascist",
    "antifasciștii": "antifascist",
    "antifasciștilor": "antifascist",
    "antifascistul": "antifascist",
    "antifascistului": "antifascist",
    "antifraza": "antifrază",
    "antifraze": "antifrază",
    "antifrazei": "antifrază",
    "antifrazele": "antifrază",
    "antifrazelor": "antifrază",
    "antigenul": "antigen",
    "antigenului": "antigen",
    "antiguvernamentala": "antiguvernamental",
    "antiguvernamentală": "antiguvernamental",
    "antiguvernamentale": "antiguvernamental",
    "antiguvernamentalei": "antiguvernamental",
    "antiguvernamentalele": "antiguvernamental",
    "antiguvernamentalelor": "antiguvernamental",
    "antiguvernamentali": "antiguvernamental",
    "antiguvernamentalii": "antiguvernamental",
    "antiguvernamentalilor": "antiguvernamental",
    "antiguvernamentalul": "antiguvernamental",
    "antiguvernamentalului": "antiguvernamental",
    "antiinflamatoare": "antiinflamator",
    "antiinflamatoarea": "antiinflamator",
    "antiinflamatoarei": "antiinflamator",
    "antiinflamatoarele": "antiinflamator",
    "antiinflamatoarelor": "antiinflamator",
    "antiinflamatori": "antiinflamator",
    "antiinflamatorii": "antiinflamator",
    "antiinflamatorilor": "antiinflamator",
    "antiinflamatorul": "antiinflamator",
    "antiinflamatorului": "antiinflamator",
    "antiintelectuala": "antiintelectual",
    "antiintelectuală": "antiintelectual",
    "antiintelectuale": "antiintelectual",
    "antiintelectualei": "antiintelectual",
    "antiintelectualele": "antiintelectual",
    "antiintelectualelor": "antiintelectual",
    "antiintelectuali": "antiintelectual",
    "antiintelectualii": "antiintelectual",
    "antiintelectualilor": "antiintelectual",
    "antiintelectualul": "antiintelectual",
    "antiintelectualului": "antiintelectual",
    "antiintelectuala": "antiintelectuală",
    "antiintelectuale": "antiintelectuală",
    "antiintelectualei": "antiintelectuală",
    "antiintelectualele": "antiintelectuală",
    "antiintelectualelor": "antiintelectuală",
    "antiiperialista": "antiiperialist",
    "antiiperialistă": "antiiperialist",
    "antiiperialiste": "antiiperialist",
    "antiiperialistei": "antiiperialist",
    "antiiperialistele": "antiiperialist",
    "antiiperialistelor": "antiiperialist",
    "antiiperialiști": "antiiperialist",
    "antiiperialiștii": "antiiperialist",
    "antiiperialiștilor": "antiiperialist",
    "antiiperialistul": "antiiperialist",
    "antiiperialistului": "antiiperialist",
    "antilogia": "antilogie",
    "antilogiei": "antilogie",
    "antilogii": "antilogie",
    "antilogiile": "antilogie",
    "antilogiilor": "antilogie",
    "antimaghiară": "antimaghiar",
    "antimaghiare": "antimaghiar",
    "antimaghiari": "antimaghiar",
    "antimarxista": "antimarxist",
    "antimarxistă": "antimarxist",
    "antimarxiste": "antimarxist",
    "antimarxistei": "antimarxist",
    "antimarxistele": "antimarxist",
    "antimarxistelor": "antimarxist",
    "antimarxiști": "antimarxist",
    "antimarxiștii": "antimarxist",
    "antimarxiștilor": "antimarxist",
    "antimarxistul": "antimarxist",
    "antimarxistului": "antimarxist",
    "antimonarhica": "antimonarhic",
    "antimonarhică": "antimonarhic",
    "antimonarhice": "antimonarhic",
    "antimonarhicei": "antimonarhic",
    "antimonarhicele": "antimonarhic",
    "antimonarhicelor": "antimonarhic",
    "antimonarhici": "antimonarhic",
    "antimonarhicii": "antimonarhic",
    "antimonarhicilor": "antimonarhic",
    "antimonarhicul": "antimonarhic",
    "antimonarhicului": "antimonarhic",
    "antimonica": "antimonic",
    "antimonică": "antimonic",
    "antimonice": "antimonic",
    "antimonicei": "antimonic",
    "antimonicele": "antimonic",
    "antimonicelor": "antimonic",
    "antimonici": "antimonic",
    "antimonicii": "antimonic",
    "antimonicilor": "antimonic",
    "antimonicul": "antimonic",
    "antimonicului": "antimonic",
    "antimuncitoreasca": "antimuncitoresc",
    "antimuncitorească": "antimuncitoresc",
    "antimuncitorescul": "antimuncitoresc",
    "antimuncitorescului": "antimuncitoresc",
    "antimuncitorești": "antimuncitoresc",
    "antimuncitoreștii": "antimuncitoresc",
    "antimuncitoreștile": "antimuncitoresc",
    "antimuncitoreștilor": "antimuncitoresc",
    "antinaționala": "antinațional",
    "antinațională": "antinațional",
    "antinaționale": "antinațional",
    "antinaționalei": "antinațional",
    "antinaționalele": "antinațional",
    "antinaționalelor": "antinațional",
    "antinaționali": "antinațional",
    "antinaționalii": "antinațional",
    "antinaționalilor": "antinațional",
    "antinaționalul": "antinațional",
    "antinaționalului": "antinațional",
    "antinaționala": "antinațională",
    "antinaționale": "antinațională",
    "antinaționalei": "antinațională",
    "antinaționalele": "antinațională",
    "antinaționalelor": "antinațională",
    "antinevralgica": "antinevralgic",
    "antinevralgică": "antinevralgic",
    "antinevralgice": "antinevralgic",
    "antinevralgicei": "antinevralgic",
    "antinevralgicele": "antinevralgic",
    "antinevralgicelor": "antinevralgic",
    "antinevralgici": "antinevralgic",
    "antinevralgicii": "antinevralgic",
    "antinevralgicilor": "antinevralgic",
    "antinevralgicul": "antinevralgic",
    "antinevralgicului": "antinevralgic",
    "antinomica": "antinomic",
    "antinomică": "antinomic",
    "antinomice": "antinomic",
    "antinomicei": "antinomic",
    "antinomicele": "antinomic",
    "antinomicelor": "antinomic",
    "antinomici": "antinomic",
    "antinomicii": "antinomic",
    "antinomicilor": "antinomic",
    "antinomicul": "antinomic",
    "antinomicului": "antinomic",
    "antinomia": "antinomie",
    "antinomiei": "antinomie",
    "antinomii": "antinomie",
    "antinomiile": "antinomie",
    "antinomiilor": "antinomie",
    "antioccidentală": "antioccidental",
    "antioccidentale": "antioccidental",
    "antioccidentali": "antioccidental",
    "antiparalela": "antiparalel",
    "antiparalelă": "antiparalel",
    "antiparalele": "antiparalel",
    "antiparalelei": "antiparalel",
    "antiparalelele": "antiparalel",
    "antiparalelelor": "antiparalel",
    "antiparaleli": "antiparalel",
    "antiparalelii": "antiparalel",
    "antiparalelilor": "antiparalel",
    "antiparalelul": "antiparalel",
    "antiparalelului": "antiparalel",
    "antipartinica": "antipartinic",
    "antipartinică": "antipartinic",
    "antipartinice": "antipartinic",
    "antipartinicei": "antipartinic",
    "antipartinicele": "antipartinic",
    "antipartinicelor": "antipartinic",
    "antipartinici": "antipartinic",
    "antipartinicii": "antipartinic",
    "antipartinicilor": "antipartinic",
    "antipartinicul": "antipartinic",
    "antipartinicului": "antipartinic",
    "antipatica": "antipatic",
    "antipatică": "antipatic",
    "antipatice": "antipatic",
    "antipaticei": "antipatic",
    "antipaticele": "antipatic",
    "antipaticelor": "antipatic",
    "antipatici": "antipatic",
    "antipaticii": "antipatic",
    "antipaticilor": "antipatic",
    "antipaticul": "antipatic",
    "antipaticului": "antipatic",
    "antipatia": "antipatie",
    "antipatiei": "antipatie",
    "antipatii": "antipatie",
    "antipatiile": "antipatie",
    "antipatiilor": "antipatie",
    "antipedagogia": "antipedagogie",
    "antipedagogiei": "antipedagogie",
    "antipedagogii": "antipedagogie",
    "antipedagogiile": "antipedagogie",
    "antipedagogiilor": "antipedagogie",
    "antipiretica": "antipiretic",
    "antipiretică": "antipiretic",
    "antipiretice": "antipiretic",
    "antipireticei": "antipiretic",
    "antipireticele": "antipiretic",
    "antipireticelor": "antipiretic",
    "antipiretici": "antipiretic",
    "antipireticii": "antipiretic",
    "antipireticilor": "antipiretic",
    "antipireticul": "antipiretic",
    "antipireticului": "antipiretic",
    "antipodul": "antipod",
    "antipodului": "antipod",
    "antipozi": "antipod",
    "antipozii": "antipod",
    "antipozilor": "antipod",
    "antipopulara": "antipopular",
    "antipopulară": "antipopular",
    "antipopulare": "antipopular",
    "antipopularei": "antipopular",
    "antipopularele": "antipopular",
    "antipopularelor": "antipopular",
    "antipopulari": "antipopular",
    "antipopularii": "antipopular",
    "antipopularilor": "antipopular",
    "antipopularul": "antipopular",
    "antipopularului": "antipopular",
    "antiprezidențiala": "antiprezidențial",
    "antiprezidențială": "antiprezidențial",
    "antiprezidențiale": "antiprezidențial",
    "antiprezidențialei": "antiprezidențial",
    "antiprezidențialele": "antiprezidențial",
    "antiprezidențialelor": "antiprezidențial",
    "antiprezidențiali": "antiprezidențial",
    "antiprezidențialii": "antiprezidențial",
    "antiprezidențialilor": "antiprezidențial",
    "antiprezidențialul": "antiprezidențial",
    "antiprezidențialului": "antiprezidențial",
    "antirabica": "antirabic",
    "antirabică": "antirabic",
    "antirabice": "antirabic",
    "antirabicei": "antirabic",
    "antirabicele": "antirabic",
    "antirabicelor": "antirabic",
    "antirabici": "antirabic",
    "antirabicii": "antirabic",
    "antirabicilor": "antirabic",
    "antirabicul": "antirabic",
    "antirabicului": "antirabic",
    "antirealista": "antirealist",
    "antirealistă": "antirealist",
    "antirealiste": "antirealist",
    "antirealistei": "antirealist",
    "antirealistele": "antirealist",
    "antirealistelor": "antirealist",
    "antirealiști": "antirealist",
    "antirealiștii": "antirealist",
    "antirealiștilor": "antirealist",
    "antirealistul": "antirealist",
    "antirealistului": "antirealist",
    "antiregalista": "antiregalist",
    "antiregalistă": "antiregalist",
    "antiregaliste": "antiregalist",
    "antiregalistei": "antiregalist",
    "antiregalistele": "antiregalist",
    "antiregalistelor": "antiregalist",
    "antiregaliști": "antiregalist",
    "antiregaliștii": "antiregalist",
    "antiregaliștilor": "antiregalist",
    "antiregalistul": "antiregalist",
    "antiregalistului": "antiregalist",
    "antireligioasa": "antireligios",
    "antireligioasă": "antireligios",
    "antireligioase": "antireligios",
    "antireligioasei": "antireligios",
    "antireligioasele": "antireligios",
    "antireligioaselor": "antireligios",
    "antireligioși": "antireligios",
    "antireligioșii": "antireligios",
    "antireligioșilor": "antireligios",
    "antireligiosul": "antireligios",
    "antireligiosului": "antireligios",
    "anti-româneasca": "anti-românesc",
    "anti-românească": "anti-românesc",
    "anti-românescul": "anti-românesc",
    "anti-românescului": "anti-românesc",
    "anti-românești": "anti-românesc",
    "anti-româneștii": "anti-românesc",
    "anti-româneștile": "anti-românesc",
    "anti-româneștilor": "anti-românesc",
    "antisemita": "antisemit",
    "antisemită": "antisemit",
    "antisemite": "antisemit",
    "antisemitei": "antisemit",
    "antisemitele": "antisemit",
    "antisemitelor": "antisemit",
    "antisemiți": "antisemit",
    "antisemiții": "antisemit",
    "antisemiților": "antisemit",
    "antisemitul": "antisemit",
    "antisemitului": "antisemit",
    "antisemitisme": "antisemitism",
    "antisemitismele": "antisemitism",
    "antisemitismelor": "antisemitism",
    "antisemitismul": "antisemitism",
    "antisemitismului": "antisemitism",
    "antiseptica": "antiseptic",
    "antiseptică": "antiseptic",
    "antiseptice": "antiseptic",
    "antisepticei": "antiseptic",
    "antisepticele": "antiseptic",
    "antisepticelor": "antiseptic",
    "antiseptici": "antiseptic",
    "antisepticii": "antiseptic",
    "antisepticilor": "antiseptic",
    "antisepticul": "antiseptic",
    "antisepticului": "antiseptic",
    "Anti-Sexul": "Anti-Sex",
    "Anti-Sexului": "Anti-Sex",
    "antisimți": "antisimț",
    "antisimții": "antisimț",
    "antisimților": "antisimț",
    "antisimțul": "antisimț",
    "antisimțului": "antisimț",
    "antisociala": "antisocial",
    "antisocială": "antisocial",
    "antisociale": "antisocial",
    "antisocialei": "antisocial",
    "antisocialele": "antisocial",
    "antisocialelor": "antisocial",
    "antisociali": "antisocial",
    "antisocialii": "antisocial",
    "antisocialilor": "antisocial",
    "antisocialul": "antisocial",
    "antisocialului": "antisocial",
    "antispasmodica": "antispasmodic",
    "antispasmodică": "antispasmodic",
    "antispasmodice": "antispasmodic",
    "antispasmodicei": "antispasmodic",
    "antispasmodicele": "antispasmodic",
    "antispasmodicelor": "antispasmodic",
    "antispasmodici": "antispasmodic",
    "antispasmodicii": "antispasmodic",
    "antispasmodicilor": "antispasmodic",
    "antispasmodicul": "antispasmodic",
    "antispasmodicului": "antispasmodic",
    "antistatala": "antistatal",
    "antistatală": "antistatal",
    "antistatale": "antistatal",
    "antistatalei": "antistatal",
    "antistatalele": "antistatal",
    "antistatalelor": "antistatal",
    "antistatali": "antistatal",
    "antistatalii": "antistatal",
    "antistatalilor": "antistatal",
    "antistatalul": "antistatal",
    "antistatalului": "antistatal",
    "antiștiițifica": "antiștiițific",
    "antiștiițifică": "antiștiițific",
    "antiștiițifice": "antiștiițific",
    "antiștiițificei": "antiștiițific",
    "antiștiițificele": "antiștiițific",
    "antiștiițificelor": "antiștiițific",
    "antiștiițifici": "antiștiițific",
    "antiștiițificii": "antiștiițific",
    "antiștiițificilor": "antiștiițific",
    "antiștiițificul": "antiștiițific",
    "antiștiițificului": "antiștiițific",
    "antistrofa": "antistrofă",
    "antistrofe": "antistrofă",
    "antistrofei": "antistrofă",
    "antistrofele": "antistrofă",
    "antistrofelor": "antistrofă",
    "antiterorista": "antiterorist",
    "antiteroristă": "antiterorist",
    "antiteroriste": "antiterorist",
    "antiteroristei": "antiterorist",
    "antiteroristele": "antiterorist",
    "antiteroristelor": "antiterorist",
    "antiteroriști": "antiterorist",
    "antiteroriștii": "antiterorist",
    "antiteroriștilor": "antiterorist",
    "antiteroristul": "antiterorist",
    "antiteroristului": "antiterorist",
    "antiterorista": "antiteroristă",
    "antiteroriste": "antiteroristă",
    "antiteroristei": "antiteroristă",
    "antiteroristele": "antiteroristă",
    "antiteroristelor": "antiteroristă",
    "antitetica": "antitetic",
    "antitetică": "antitetic",
    "antitetice": "antitetic",
    "antiteticei": "antitetic",
    "antiteticele": "antitetic",
    "antiteticelor": "antitetic",
    "antitetici": "antitetic",
    "antiteticii": "antitetic",
    "antiteticilor": "antitetic",
    "antiteticul": "antitetic",
    "antiteticului": "antitetic",
    "antiteza": "antiteză",
    "antiteze": "antiteză",
    "antitezei": "antiteză",
    "antitezele": "antiteză",
    "antitezelor": "antiteză",
    "antitrinitara": "antitrinitar",
    "antitrinitară": "antitrinitar",
    "antitrinitare": "antitrinitar",
    "antitrinitarei": "antitrinitar",
    "antitrinitarele": "antitrinitar",
    "antitrinitarelor": "antitrinitar",
    "antitrinitari": "antitrinitar",
    "antitrinitarii": "antitrinitar",
    "antitrinitarilor": "antitrinitar",
    "antitrinitarul": "antitrinitar",
    "antitrinitarului": "antitrinitar",
    "antiumana": "antiuman",
    "antiumană": "antiuman",
    "antiumane": "antiuman",
    "antiumanei": "antiuman",
    "antiumanele": "antiuman",
    "antiumanelor": "antiuman",
    "antiumani": "antiuman",
    "antiumanii": "antiuman",
    "antiumanilor": "antiuman",
    "antiumanul": "antiuman",
    "antiumanului": "antiuman",
    "antivirala": "antiviral",
    "antivirală": "antiviral",
    "antivirale": "antiviral",
    "antiviralei": "antiviral",
    "antiviralele": "antiviral",
    "antiviralelor": "antiviral",
    "antivirali": "antiviral",
    "antiviralii": "antiviral",
    "antiviralilor": "antiviral",
    "antiviralul": "antiviral",
    "antiviralului": "antiviral",
    "antologica": "antologic",
    "antologică": "antologic",
    "antologice": "antologic",
    "antologicei": "antologic",
    "antologicele": "antologic",
    "antologicelor": "antologic",
    "antologici": "antologic",
    "antologicii": "antologic",
    "antologicilor": "antologic",
    "antologicul": "antologic",
    "antologicului": "antologic",
    "antologia": "antologie",
    "antologiei": "antologie",
    "antologii": "antologie",
    "antologiile": "antologie",
    "antologiilor": "antologie",
    "antonime": "antonim",
    "antonimele": "antonim",
    "antonimelor": "antonim",
    "antonimul": "antonim",
    "antonimului": "antonim",
    "antonimica": "antonimic",
    "antonimică": "antonimic",
    "antonimice": "antonimic",
    "antonimicei": "antonimic",
    "antonimicele": "antonimic",
    "antonimicelor": "antonimic",
    "antonimici": "antonimic",
    "antonimicii": "antonimic",
    "antonimicilor": "antonimic",
    "antonimicul": "antonimic",
    "antonimicului": "antonimic",
    "antonomaza": "antonomază",
    "antonomaze": "antonomază",
    "antonomazei": "antonomază",
    "antonomazele": "antonomază",
    "antonomazelor": "antonomază",
    "antracitul": "antracit",
    "antracitului": "antracit",
    "antracte": "antract",
    "antractele": "antract",
    "antractelor": "antract",
    "antractul": "antract",
    "antractului": "antract",
    "antraxe": "antrax",
    "antraxele": "antrax",
    "antraxelor": "antrax",
    "antraxul": "antrax",
    "antraxului": "antrax",
    "antraxuri": "antrax",
    "antraxurile": "antrax",
    "antraxurilor": "antrax",
    "antrenul": "antren",
    "antrenului": "antren",
    "antrenuri": "antren",
    "antrenurile": "antren",
    "antrenurilor": "antren",
    "antrenă": "antrena",
    "antrenai": "antrena",
    "antrenam": "antrena",
    "antrenăm": "antrena",
    "antrenând": "antrena",
    "antrenându": "antrena",
    "antrenară": "antrena",
    "antrenarăm": "antrena",
    "antrenarăți": "antrena",
    "antrenase": "antrena",
    "antrenasem": "antrena",
    "antrenaseră": "antrena",
    "antrenaserăm": "antrena",
    "antrenaserăți": "antrena",
    "antrenaseși": "antrena",
    "antrenași": "antrena",
    "antrenat": "antrena",
    "antrenați": "antrena",
    "antrenatu": "antrena",
    "antrenau": "antrena",
    "antrenează": "antrena",
    "antrenez": "antrena",
    "antreneze": "antrena",
    "antrenezi": "antrena",
    "neantrenând": "antrena",
    "neantrenându": "antrena",
    "nemaiantrenând": "antrena",
    "nemaiantrenându": "antrena",
    "antrenamente": "antrenament",
    "antrenamentele": "antrenament",
    "antrenamentelor": "antrenament",
    "antrenamentul": "antrenament",
    "antrenamentului": "antrenament",
    "antrenanta": "antrenant",
    "antrenantă": "antrenant",
    "antrenante": "antrenant",
    "antrenantei": "antrenant",
    "antrenantele": "antrenant",
    "antrenantelor": "antrenant",
    "antrenanți": "antrenant",
    "antrenanții": "antrenant",
    "antrenanților": "antrenant",
    "antrenantul": "antrenant",
    "antrenantului": "antrenant",
    "antrenarea": "antrenare",
    "antrenări": "antrenare",
    "antrenării": "antrenare",
    "antrenările": "antrenare",
    "antrenata": "antrenat",
    "antrenată": "antrenat",
    "antrenate": "antrenat",
    "antrenatei": "antrenat",
    "antrenatele": "antrenat",
    "antrenatelor": "antrenat",
    "antrenați": "antrenat",
    "antrenații": "antrenat",
    "antrenaților": "antrenat",
    "antrenatul": "antrenat",
    "antrenatului": "antrenat",
    "antrenoarea": "antrenoare",
    "antrenoarei": "antrenoare",
    "antrenoarele": "antrenoare",
    "antrenoarelor": "antrenoare",
    "antrenori": "antrenor",
    "antrenorii": "antrenor",
    "antrenorilor": "antrenor",
    "antrenorul": "antrenor",
    "antrenorului": "antrenor",
    "antrepozite": "antrepozit",
    "antrepozitele": "antrepozit",
    "antrepozitelor": "antrepozit",
    "antrepozitul": "antrepozit",
    "antrepozitului": "antrepozit",
    "antreprenori": "antreprenor",
    "antreprenorii": "antreprenor",
    "antreprenorilor": "antreprenor",
    "antreprenorul": "antreprenor",
    "antreprenorului": "antreprenor",
    "antrepriza": "antrepriză",
    "antreprize": "antrepriză",
    "antreprizei": "antrepriză",
    "antreprizele": "antrepriză",
    "antreprizelor": "antrepriză",
    "antretul": "antret",
    "antretului": "antret",
    "antreturi": "antret",
    "antreturile": "antret",
    "antreturilor": "antret",
    "antreul": "antreu",
    "antreului": "antreu",
    "antreuri": "antreu",
    "antreurile": "antreu",
    "antreurilor": "antreu",
    "antricoate": "antricot",
    "antricoatele": "antricot",
    "antricoatelor": "antricot",
    "antricotul": "antricot",
    "antricotului": "antricot",
    "antropocentrica": "antropocentric",
    "antropocentrică": "antropocentric",
    "antropocentrice": "antropocentric",
    "antropocentricei": "antropocentric",
    "antropocentricele": "antropocentric",
    "antropocentricelor": "antropocentric",
    "antropocentrici": "antropocentric",
    "antropocentricii": "antropocentric",
    "antropocentricilor": "antropocentric",
    "antropocentricul": "antropocentric",
    "antropocentricului": "antropocentric",
    "antropofaga": "antropofag",
    "antropofagă": "antropofag",
    "antropofage": "antropofag",
    "antropofagei": "antropofag",
    "antropofagele": "antropofag",
    "antropofagelor": "antropofag",
    "antropofagi": "antropofag",
    "antropofagii": "antropofag",
    "antropofagilor": "antropofag",
    "antropofagul": "antropofag",
    "antropofagului": "antropofag",
    "antropogeneza": "antropogeneză",
    "antropogeneze": "antropogeneză",
    "antropogenezei": "antropogeneză",
    "antropogenezele": "antropogeneză",
    "antropogenezelor": "antropogeneză",
    "antropoida": "antropoid",
    "antropoidă": "antropoid",
    "antropoide": "antropoid",
    "antropoidei": "antropoid",
    "antropoidele": "antropoid",
    "antropoidelor": "antropoid",
    "antropoidul": "antropoid",
    "antropoidului": "antropoid",
    "antropoizi": "antropoid",
    "antropoizii": "antropoid",
    "antropoizilor": "antropoid",
    "antropologica": "antropologic",
    "antropologică": "antropologic",
    "antropologice": "antropologic",
    "antropologicei": "antropologic",
    "antropologicele": "antropologic",
    "antropologicelor": "antropologic",
    "antropologici": "antropologic",
    "antropologicii": "antropologic",
    "antropologicilor": "antropologic",
    "antropologicul": "antropologic",
    "antropologicului": "antropologic",
    "antropologia": "antropologie",
    "antropologiei": "antropologie",
    "antropologii": "antropologie",
    "antropologiile": "antropologie",
    "antropologiilor": "antropologie",
    "antropometrica": "antropometric",
    "antropometrică": "antropometric",
    "antropometrice": "antropometric",
    "antropometricei": "antropometric",
    "antropometricele": "antropometric",
    "antropometricelor": "antropometric",
    "antropometrici": "antropometric",
    "antropometricii": "antropometric",
    "antropometricilor": "antropometric",
    "antropometricul": "antropometric",
    "antropometricului": "antropometric",
    "antropomorfa": "antropomorf",
    "antropomorfă": "antropomorf",
    "antropomorfe": "antropomorf",
    "antropomorfei": "antropomorf",
    "antropomorfele": "antropomorf",
    "antropomorfelor": "antropomorf",
    "antropomorfi": "antropomorf",
    "antropomorfii": "antropomorf",
    "antropomorfilor": "antropomorf",
    "antropomorful": "antropomorf",
    "antropomorfului": "antropomorf",
    "antropozofica": "antropozofic",
    "antropozofică": "antropozofic",
    "antropozofice": "antropozofic",
    "antropozoficei": "antropozofic",
    "antropozoficele": "antropozofic",
    "antropozoficelor": "antropozofic",
    "antropozofici": "antropozofic",
    "antropozoficii": "antropozofic",
    "antropozoficilor": "antropozofic",
    "antropozoficul": "antropozofic",
    "antropozoficului": "antropozofic",
    "antropozofia": "antropozofie",
    "antropozofiei": "antropozofie",
    "antropozofii": "antropozofie",
    "antropozofiile": "antropozofie",
    "antropozofiilor": "antropozofie",
    "antuma": "antum",
    "antumă": "antum",
    "antume": "antum",
    "antumei": "antum",
    "antumele": "antum",
    "antumelor": "antum",
    "antumi": "antum",
    "antumii": "antum",
    "antumilor": "antum",
    "antumul": "antum",
    "antumului": "antum",
    "anturaje": "anturaj",
    "anturajele": "anturaj",
    "anturajelor": "anturaj",
    "anturajul": "anturaj",
    "anturajului": "anturaj",
    "anuala": "anual",
    "anuală": "anual",
    "anuale": "anual",
    "anualei": "anual",
    "anualele": "anual",
    "anualelor": "anual",
    "anuali": "anual",
    "anualii": "anual",
    "anualilor": "anual",
    "anualul": "anual",
    "anualului": "anual",
    "anualizată": "anualizat",
    "anualizate": "anualizat",
    "anualizați": "anualizat",
    "anuare": "anuar",
    "anuarele": "anuar",
    "anuarelor": "anuar",
    "anuarul": "anuar",
    "anuarului": "anuar",
    "anu'": "anul",
    "a.c.": "anul_curent",
    "anulă": "anula",
    "anulai": "anula",
    "anulam": "anula",
    "anulăm": "anula",
    "anulând": "anula",
    "anulându": "anula",
    "anulară": "anula",
    "anularăm": "anula",
    "anularăți": "anula",
    "anulase": "anula",
    "anulasem": "anula",
    "anulaseră": "anula",
    "anulaserăm": "anula",
    "anulaserăți": "anula",
    "anulaseși": "anula",
    "anulași": "anula",
    "anulat": "anula",
    "anulați": "anula",
    "anulatu": "anula",
    "anulau": "anula",
    "anulează": "anula",
    "anulez": "anula",
    "anuleze": "anula",
    "anulezi": "anula",
    "neanulând": "anula",
    "neanulându": "anula",
    "nemaianulând": "anula",
    "nemaianulându": "anula",
    "anularea": "anulare",
    "anulări": "anulare",
    "anulării": "anulare",
    "anulările": "anulare",
    "anulata": "anulat",
    "anulată": "anulat",
    "anulate": "anulat",
    "anulatei": "anulat",
    "anulatele": "anulat",
    "anulatelor": "anulat",
    "anulați": "anulat",
    "anulații": "anulat",
    "anulaților": "anulat",
    "anulatul": "anulat",
    "anulatului": "anulat",
    "anumită": "anumit",
    "anumite": "anumit",
    "anumiți": "anumit",
    "anumitor": "anumit",
    "anunțul": "anunț",
    "anunțului": "anunț",
    "anunțuri": "anunț",
    "anunțurile": "anunț",
    "anunțurilor": "anunț",
    "anunț": "anunța",
    "anunță": "anunța",
    "anunțai": "anunța",
    "anunțam": "anunța",
    "anunțăm": "anunța",
    "anunțând": "anunța",
    "anunțându": "anunța",
    "anunțară": "anunța",
    "anunțarăm": "anunța",
    "anunțarăți": "anunța",
    "anunțase": "anunța",
    "anunțasem": "anunța",
    "anunțaseră": "anunța",
    "anunțaserăm": "anunța",
    "anunțaserăți": "anunța",
    "anunțaseși": "anunța",
    "anunțași": "anunța",
    "anunțat": "anunța",
    "anunțați": "anunța",
    "anunțau": "anunța",
    "anunțe": "anunța",
    "anunți": "anunța",
    "neanunțând": "anunța",
    "neanunțându": "anunța",
    "nemaianunțând": "anunța",
    "nemaianunțându": "anunța",
    "anunțarea": "anunțare",
    "anunțări": "anunțare",
    "anunțării": "anunțare",
    "anunțările": "anunțare",
    "anunțata": "anunțat",
    "anunțată": "anunțat",
    "anunțate": "anunțat",
    "anunțatei": "anunțat",
    "anunțatele": "anunțat",
    "anunțatelor": "anunțat",
    "anunțați": "anunțat",
    "anunțații": "anunțat",
    "anunțaților": "anunțat",
    "anunțatul": "anunțat",
    "anunțatului": "anunțat",
    "anunțători": "anunțător",
    "anunțătorii": "anunțător",
    "anunțătorilor": "anunțător",
    "anunțătorul": "anunțător",
    "anunțătorului": "anunțător",
    "anuria": "anurie",
    "anuriei": "anurie",
    "anurii": "anurie",
    "anuriile": "anurie",
    "anuriilor": "anurie",
    "anusul": "anus",
    "anusului": "anus",
    "anusuri": "anus",
    "anusurile": "anus",
    "anusurilor": "anus",
    "anvelopa": "anvelopă",
    "anvelope": "anvelopă",
    "anvelopei": "anvelopă",
    "anvelopele": "anvelopă",
    "anvelopelor": "anvelopă",
    "anvergura": "anvergură",
    "anverguri": "anvergură",
    "anvergurii": "anvergură",
    "anvergurile": "anvergură",
    "anvergurilor": "anvergură",
    "anxietatea": "anxietate",
    "anxietăți": "anxietate",
    "anxietății": "anxietate",
    "anxietățile": "anxietate",
    "anxietăților": "anxietate",
    "aor.": "aorist",
    "aoristul": "aorist",
    "aoristului": "aorist",
    "aorta": "aortă",
    "aorte": "aortă",
    "aortei": "aortă",
    "aortele": "aortă",
    "aortelor": "aortă",
    "apa": "apă",
    "ape": "apă",
    "apei": "apă",
    "apele": "apă",
    "apelor": "apă",
    "apanaje": "apanaj",
    "apanajele": "apanaj",
    "apanajelor": "apanaj",
    "apanajul": "apanaj",
    "apanajului": "apanaj",
    "apăr": "apăra",
    "apără": "apăra",
    "apărai": "apăra",
    "apăram": "apăra",
    "apărăm": "apăra",
    "apărând": "apăra",
    "apărându": "apăra",
    "apărară": "apăra",
    "apărarăm": "apăra",
    "apărarăți": "apăra",
    "apărase": "apăra",
    "apărasem": "apăra",
    "apăraseră": "apăra",
    "apăraserăm": "apăra",
    "apăraserăți": "apăra",
    "apăraseși": "apăra",
    "apărași": "apăra",
    "apărat": "apăra",
    "apărați": "apăra",
    "apăratu": "apăra",
    "apărau": "apăra",
    "apere": "apăra",
    "aperi": "apăra",
    "neapărând": "apăra",
    "neapărându": "apăra",
    "nemaiapărând": "apăra",
    "nemaiapărându": "apăra",
    "apărabilă": "apărabil",
    "apărabile": "apărabil",
    "apărabili": "apărabil",
    "apărarea": "apărare",
    "apărări": "apărare",
    "apărării": "apărare",
    "apărările": "apărare",
    "aparate": "aparat",
    "aparatele": "aparat",
    "aparatelor": "aparat",
    "aparatul": "aparat",
    "aparatului": "aparat",
    "apărata": "apărat",
    "apărată": "apărat",
    "apărate": "apărat",
    "apăratei": "apărat",
    "apăratele": "apărat",
    "apăratelor": "apărat",
    "apărați": "apărat",
    "apărații": "apărat",
    "apăraților": "apărat",
    "apăratul": "apărat",
    "apăratului": "apărat",
    "aparataje": "aparataj",
    "aparatajele": "aparataj",
    "aparatajelor": "aparataj",
    "aparatajul": "aparataj",
    "aparatajului": "aparataj",
    "apărătoarea": "apărătoare",
    "apărătoarei": "apărătoare",
    "apărătoarele": "apărătoare",
    "apărătoarelor": "apărătoare",
    "apărătoare": "apărător",
    "apărătoarea": "apărător",
    "apărătoarei": "apărător",
    "apărătoarele": "apărător",
    "apărătoarelor": "apărător",
    "apărători": "apărător",
    "apărătorii": "apărător",
    "apărătorilor": "apărător",
    "apărătorul": "apărător",
    "apărătorului": "apărător",
    "aparatura": "aparatură",
    "aparaturi": "aparatură",
    "aparaturii": "aparatură",
    "aparaturile": "aparatură",
    "aparaturilor": "aparatură",
    "apar": "apărea",
    "apară": "apărea",
    "apărând": "apărea",
    "apărându": "apărea",
    "apare": "apărea",
    "apăreai": "apărea",
    "apăream": "apărea",
    "apăreați": "apărea",
    "apăreau": "apărea",
    "apărem": "apărea",
    "apăreți": "apărea",
    "apari": "apărea",
    "apăru": "apărea",
    "apărui": "apărea",
    "apărură": "apărea",
    "apărurăm": "apărea",
    "apărurăți": "apărea",
    "apăruse": "apărea",
    "apărusem": "apărea",
    "apăruseră": "apărea",
    "apăruserăm": "apărea",
    "apăruserăți": "apărea",
    "apăruseși": "apărea",
    "apăruși": "apărea",
    "apărut": "apărea",
    "apărutu": "apărea",
    "neapărând": "apărea",
    "neapărându": "apărea",
    "nemaiapărând": "apărea",
    "nemaiapărându": "apărea",
    "aparenta": "aparent",
    "aparentă": "aparent",
    "aparente": "aparent",
    "aparentei": "aparent",
    "aparentele": "aparent",
    "aparentelor": "aparent",
    "aparenți": "aparent",
    "aparenții": "aparent",
    "aparenților": "aparent",
    "aparentul": "aparent",
    "aparentului": "aparent",
    "aparența": "aparență",
    "aparențe": "aparență",
    "aparenței": "aparență",
    "aparențele": "aparență",
    "aparențelor": "aparență",
    "apariția": "apariție",
    "apariției": "apariție",
    "apariții": "apariție",
    "aparițiile": "apariție",
    "aparițiilor": "apariție",
    "ap.": "apartament",
    "apartamente": "apartament",
    "apartamentele": "apartament",
    "apartamentelor": "apartament",
    "apartamentul": "apartament",
    "apartamentului": "apartament",
    "apartenența": "apartenență",
    "apartenențe": "apartenență",
    "apartenenței": "apartenență",
    "apartenențele": "apartenență",
    "apartenențelor": "apartenență",
    "apartheidul": "apartheid",
    "apartheidului": "apartheid",
    "aparții": "aparține",
    "aparțin": "aparține",
    "aparțină": "aparține",
    "aparținând": "aparține",
    "aparținându": "aparține",
    "aparținea": "aparține",
    "aparțineai": "aparține",
    "aparțineam": "aparține",
    "aparțineați": "aparține",
    "aparțineau": "aparține",
    "aparținem": "aparține",
    "aparțineți": "aparține",
    "aparținu": "aparține",
    "aparținui": "aparține",
    "aparținură": "aparține",
    "aparținurăm": "aparține",
    "aparținurăți": "aparține",
    "aparținuse": "aparține",
    "aparținusem": "aparține",
    "aparținuseră": "aparține",
    "aparținuserăm": "aparține",
    "aparținuserăți": "aparține",
    "aparținuseși": "aparține",
    "aparținuși": "aparține",
    "aparținut": "aparține",
    "aparținutu": "aparține",
    "neaparținând": "aparține",
    "neaparținându": "aparține",
    "nemaiaparținând": "aparține",
    "nemaiaparținându": "aparține",
    "aparținuta": "aparținut",
    "aparținută": "aparținut",
    "aparținute": "aparținut",
    "aparținutei": "aparținut",
    "aparținutele": "aparținut",
    "aparținutelor": "aparținut",
    "aparținuți": "aparținut",
    "aparținuții": "aparținut",
    "aparținuților": "aparținut",
    "aparținutul": "aparținut",
    "aparținutului": "aparținut",
    "apăruta": "apărut",
    "apărută": "apărut",
    "apărute": "apărut",
    "apărutei": "apărut",
    "apărutele": "apărut",
    "apărutelor": "apărut",
    "apăruți": "apărut",
    "apăruții": "apărut",
    "apăruților": "apărut",
    "apărutul": "apărut",
    "apărutului": "apărut",
    "apași": "apaș",
    "apașii": "apaș",
    "apașilor": "apaș",
    "apașul": "apaș",
    "apașului": "apaș",
    "apăs": "apăsa",
    "apasă": "apăsa",
    "apăsă": "apăsa",
    "apăsai": "apăsa",
    "apăsam": "apăsa",
    "apăsăm": "apăsa",
    "apăsând": "apăsa",
    "apăsându": "apăsa",
    "apăsară": "apăsa",
    "apăsarăm": "apăsa",
    "apăsarăți": "apăsa",
    "apăsase": "apăsa",
    "apăsasem": "apăsa",
    "apăsaseră": "apăsa",
    "apăsaserăm": "apăsa",
    "apăsaserăți": "apăsa",
    "apăsaseși": "apăsa",
    "apăsași": "apăsa",
    "apăsat": "apăsa",
    "apăsați": "apăsa",
    "apăsatu": "apăsa",
    "apăsau": "apăsa",
    "apese": "apăsa",
    "apeși": "apăsa",
    "neapăsând": "apăsa",
    "neapăsându": "apăsa",
    "nemaiapăsând": "apăsa",
    "nemaiapăsându": "apăsa",
    "apăsabilă": "apăsabil",
    "apăsabile": "apăsabil",
    "apăsabili": "apăsabil",
    "apăsarea": "apăsare",
    "apăsări": "apăsare",
    "apăsării": "apăsare",
    "apăsările": "apăsare",
    "apăsata": "apăsat",
    "apăsată": "apăsat",
    "apăsate": "apăsat",
    "apăsatei": "apăsat",
    "apăsatele": "apăsat",
    "apăsatelor": "apăsat",
    "apăsați": "apăsat",
    "apăsații": "apăsat",
    "apăsaților": "apăsat",
    "apăsatul": "apăsat",
    "apăsatului": "apăsat",
    "apăsătoare": "apăsător",
    "apăsătoarea": "apăsător",
    "apăsătoarei": "apăsător",
    "apăsătoarele": "apăsător",
    "apăsătoarelor": "apăsător",
    "apăsători": "apăsător",
    "apăsătorii": "apăsător",
    "apăsătorilor": "apăsător",
    "apăsătorul": "apăsător",
    "apăsătorului": "apăsător",
    "apăsătura": "apăsătură",
    "apăsături": "apăsătură",
    "apăsăturii": "apăsătură",
    "apăsăturile": "apăsătură",
    "apăsăturilor": "apăsătură",
    "apatica": "apatic",
    "apatică": "apatic",
    "apatice": "apatic",
    "apaticei": "apatic",
    "apaticele": "apatic",
    "apaticelor": "apatic",
    "apatici": "apatic",
    "apaticii": "apatic",
    "apaticilor": "apatic",
    "apaticul": "apatic",
    "apaticului": "apatic",
    "apatia": "apatie",
    "apatiei": "apatie",
    "apatii": "apatie",
    "apatiile": "apatie",
    "apatiilor": "apatie",
    "apătoasa": "apătos",
    "apătoasă": "apătos",
    "apătoase": "apătos",
    "apătoasei": "apătos",
    "apătoasele": "apătos",
    "apătoaselor": "apătos",
    "apătoși": "apătos",
    "apătoșii": "apătos",
    "apătoșilor": "apătos",
    "apătosul": "apătos",
    "apătosului": "apătos",
    "apeducte": "apeduct",
    "apeductele": "apeduct",
    "apeductelor": "apeduct",
    "apeductul": "apeduct",
    "apeductului": "apeduct",
    "apelul": "apel",
    "apelului": "apel",
    "apeluri": "apel",
    "apelurile": "apel",
    "apelurilor": "apel",
    "apelă": "apela",
    "apelai": "apela",
    "apelam": "apela",
    "apelăm": "apela",
    "apelând": "apela",
    "apelându": "apela",
    "apelară": "apela",
    "apelarăm": "apela",
    "apelarăți": "apela",
    "apelase": "apela",
    "apelasem": "apela",
    "apelaseră": "apela",
    "apelaserăm": "apela",
    "apelaserăți": "apela",
    "apelaseși": "apela",
    "apelași": "apela",
    "apelat": "apela",
    "apelați": "apela",
    "apelatu": "apela",
    "apelau": "apela",
    "apelează": "apela",
    "apelez": "apela",
    "apeleze": "apela",
    "apelezi": "apela",
    "neapelând": "apela",
    "neapelându": "apela",
    "nemaiapelând": "apela",
    "nemaiapelându": "apela",
    "apelarea": "apelare",
    "apelări": "apelare",
    "apelării": "apelare",
    "apelările": "apelare",
    "apelata": "apelat",
    "apelată": "apelat",
    "apelate": "apelat",
    "apelatei": "apelat",
    "apelatele": "apelat",
    "apelatelor": "apelat",
    "apelați": "apelat",
    "apelații": "apelat",
    "apelaților": "apelat",
    "apelatul": "apelat",
    "apelatului": "apelat",
    "ap.": "apelativ",
    "apelativa": "apelativ",
    "apelativă": "apelativ",
    "apelative": "apelativ",
    "apelativei": "apelativ",
    "apelativele": "apelativ",
    "apelativelor": "apelativ",
    "apelativi": "apelativ",
    "apelativii": "apelativ",
    "apelativilor": "apelativ",
    "apelativul": "apelativ",
    "apelativului": "apelativ",
    "apelpisita": "apelpisit",
    "apelpisită": "apelpisit",
    "apelpisite": "apelpisit",
    "apelpisitei": "apelpisit",
    "apelpisitele": "apelpisit",
    "apelpisitelor": "apelpisit",
    "apelpisiți": "apelpisit",
    "apelpisiții": "apelpisit",
    "apelpisiților": "apelpisit",
    "apelpisitul": "apelpisit",
    "apelpisitului": "apelpisit",
    "apendicele": "apendice",
    "apendicelor": "apendice",
    "apendicelui": "apendice",
    "apendicita": "apendicită",
    "apendicite": "apendicită",
    "apendicitei": "apendicită",
    "apendicitele": "apendicită",
    "apendicitelor": "apendicită",
    "aperceptiva": "aperceptiv",
    "aperceptivă": "aperceptiv",
    "aperceptive": "aperceptiv",
    "aperceptivei": "aperceptiv",
    "aperceptivele": "aperceptiv",
    "aperceptivelor": "aperceptiv",
    "aperceptivi": "aperceptiv",
    "aperceptivii": "aperceptiv",
    "aperceptivilor": "aperceptiv",
    "aperceptivul": "aperceptiv",
    "aperceptivului": "aperceptiv",
    "aperiodica": "aperiodic",
    "aperiodică": "aperiodic",
    "aperiodice": "aperiodic",
    "aperiodicei": "aperiodic",
    "aperiodicele": "aperiodic",
    "aperiodicelor": "aperiodic",
    "aperiodici": "aperiodic",
    "aperiodicii": "aperiodic",
    "aperiodicilor": "aperiodic",
    "aperiodicul": "aperiodic",
    "aperiodicului": "aperiodic",
    "apetala": "apetal",
    "apetală": "apetal",
    "apetale": "apetal",
    "apetalei": "apetal",
    "apetalele": "apetal",
    "apetalelor": "apetal",
    "apetali": "apetal",
    "apetalii": "apetal",
    "apetalilor": "apetal",
    "apetalul": "apetal",
    "apetalului": "apetal",
    "apetenta": "apetent",
    "apetentă": "apetent",
    "apetente": "apetent",
    "apetentei": "apetent",
    "apetentele": "apetent",
    "apetentelor": "apetent",
    "apetenți": "apetent",
    "apetenții": "apetent",
    "apetenților": "apetent",
    "apetentul": "apetent",
    "apetentului": "apetent",
    "apetența": "apetență",
    "apetențe": "apetență",
    "apetenței": "apetență",
    "apetențele": "apetență",
    "apetențelor": "apetență",
    "apetisanta": "apetisant",
    "apetisantă": "apetisant",
    "apetisante": "apetisant",
    "apetisantei": "apetisant",
    "apetisantele": "apetisant",
    "apetisantelor": "apetisant",
    "apetisanți": "apetisant",
    "apetisanții": "apetisant",
    "apetisanților": "apetisant",
    "apetisantul": "apetisant",
    "apetisantului": "apetisant",
    "apetitul": "apetit",
    "apetitului": "apetit",
    "apetituri": "apetit",
    "apetiturile": "apetit",
    "apetiturilor": "apetit",
    "apicala": "apical",
    "apicală": "apical",
    "apicale": "apical",
    "apicalei": "apical",
    "apicalele": "apical",
    "apicalelor": "apical",
    "apicali": "apical",
    "apicalii": "apical",
    "apicalilor": "apical",
    "apicalul": "apical",
    "apicalului": "apical",
    "apicola": "apicol",
    "apicolă": "apicol",
    "apicole": "apicol",
    "apicolei": "apicol",
    "apicolele": "apicol",
    "apicolelor": "apicol",
    "apicoli": "apicol",
    "apicolii": "apicol",
    "apicolilor": "apicol",
    "apicolul": "apicol",
    "apicolului": "apicol",
    "apicultori": "apicultor",
    "apicultorii": "apicultor",
    "apicultorilor": "apicultor",
    "apicultorul": "apicultor",
    "apicultorului": "apicultor",
    "apicultura": "apicultură",
    "apiculturi": "apicultură",
    "apiculturii": "apicultură",
    "apiculturile": "apicultură",
    "apiculturilor": "apicultură",
    "aplană": "aplana",
    "aplanai": "aplana",
    "aplanam": "aplana",
    "aplanăm": "aplana",
    "aplanând": "aplana",
    "aplanară": "aplana",
    "aplanarăm": "aplana",
    "aplanarăți": "aplana",
    "aplanase": "aplana",
    "aplanasem": "aplana",
    "aplanaseră": "aplana",
    "aplanaserăm": "aplana",
    "aplanaserăți": "aplana",
    "aplanaseși": "aplana",
    "aplanași": "aplana",
    "aplanat": "aplana",
    "aplanați": "aplana",
    "aplanatu": "aplana",
    "aplanau": "aplana",
    "aplanează": "aplana",
    "aplanez": "aplana",
    "aplaneze": "aplana",
    "aplanezi": "aplana",
    "neaplanând": "aplana",
    "nemaiaplanând": "aplana",
    "aplanarea": "aplanare",
    "aplanări": "aplanare",
    "aplanării": "aplanare",
    "aplanările": "aplanare",
    "aplanata": "aplanat",
    "aplanată": "aplanat",
    "aplanate": "aplanat",
    "aplanatei": "aplanat",
    "aplanatele": "aplanat",
    "aplanatelor": "aplanat",
    "aplanați": "aplanat",
    "aplanații": "aplanat",
    "aplanaților": "aplanat",
    "aplanatul": "aplanat",
    "aplanatului": "aplanat",
    "aplatiză": "aplatiza",
    "aplatizai": "aplatiza",
    "aplatizam": "aplatiza",
    "aplatizăm": "aplatiza",
    "aplatizând": "aplatiza",
    "aplatizându": "aplatiza",
    "aplatizară": "aplatiza",
    "aplatizarăm": "aplatiza",
    "aplatizarăți": "aplatiza",
    "aplatizase": "aplatiza",
    "aplatizasem": "aplatiza",
    "aplatizaseră": "aplatiza",
    "aplatizaserăm": "aplatiza",
    "aplatizaserăți": "aplatiza",
    "aplatizaseși": "aplatiza",
    "aplatizași": "aplatiza",
    "aplatizat": "aplatiza",
    "aplatizați": "aplatiza",
    "aplatizatu": "aplatiza",
    "aplatizau": "aplatiza",
    "aplatizează": "aplatiza",
    "aplatizez": "aplatiza",
    "aplatizeze": "aplatiza",
    "aplatizezi": "aplatiza",
    "neaplatizând": "aplatiza",
    "neaplatizându": "aplatiza",
    "nemaiaplatizând": "aplatiza",
    "nemaiaplatizându": "aplatiza",
    "aplatizarea": "aplatizare",
    "aplatizări": "aplatizare",
    "aplatizării": "aplatizare",
    "aplatizările": "aplatizare",
    "aplatizata": "aplatizat",
    "aplatizată": "aplatizat",
    "aplatizate": "aplatizat",
    "aplatizatei": "aplatizat",
    "aplatizatele": "aplatizat",
    "aplatizatelor": "aplatizat",
    "aplatizați": "aplatizat",
    "aplatizații": "aplatizat",
    "aplatizaților": "aplatizat",
    "aplatizatul": "aplatizat",
    "aplatizatului": "aplatizat",
    "aplaud": "aplauda",
    "aplaudă": "aplauda",
    "aplaudai": "aplauda",
    "aplaudam": "aplauda",
    "aplaudăm": "aplauda",
    "aplaudând": "aplauda",
    "aplaudându": "aplauda",
    "aplaudară": "aplauda",
    "aplaudarăm": "aplauda",
    "aplaudarăți": "aplauda",
    "aplaudase": "aplauda",
    "aplaudasem": "aplauda",
    "aplaudaseră": "aplauda",
    "aplaudaserăm": "aplauda",
    "aplaudaserăți": "aplauda",
    "aplaudaseși": "aplauda",
    "aplaudași": "aplauda",
    "aplaudat": "aplauda",
    "aplaudați": "aplauda",
    "aplaudatu": "aplauda",
    "aplaudau": "aplauda",
    "aplaude": "aplauda",
    "aplauzi": "aplauda",
    "neaplaudând": "aplauda",
    "neaplaudându": "aplauda",
    "nemaiaplaudând": "aplauda",
    "nemaiaplaudându": "aplauda",
    "aplaudarea": "aplaudare",
    "aplaudări": "aplaudare",
    "aplaudării": "aplaudare",
    "aplaudările": "aplaudare",
    "aplaudata": "aplaudat",
    "aplaudată": "aplaudat",
    "aplaudate": "aplaudat",
    "aplaudatei": "aplaudat",
    "aplaudatele": "aplaudat",
    "aplaudatelor": "aplaudat",
    "aplaudați": "aplaudat",
    "aplaudații": "aplaudat",
    "aplaudaților": "aplaudat",
    "aplaudatul": "aplaudat",
    "aplaudatului": "aplaudat",
    "aplauzele": "aplauze",
    "aplauzelor": "aplauze",
    "apleacă": "apleca",
    "aplec": "apleca",
    "aplecă": "apleca",
    "aplecai": "apleca",
    "aplecam": "apleca",
    "aplecăm": "apleca",
    "aplecând": "apleca",
    "aplecându": "apleca",
    "aplecară": "apleca",
    "aplecarăm": "apleca",
    "aplecarăți": "apleca",
    "aplecase": "apleca",
    "aplecasem": "apleca",
    "aplecaseră": "apleca",
    "aplecaserăm": "apleca",
    "aplecaserăți": "apleca",
    "aplecaseși": "apleca",
    "aplecași": "apleca",
    "aplecat": "apleca",
    "aplecați": "apleca",
    "aplecatu": "apleca",
    "aplecau": "apleca",
    "aplece": "apleca",
    "apleci": "apleca",
    "neaplecând": "apleca",
    "neaplecându": "apleca",
    "nemaiaplecând": "apleca",
    "nemaiaplecându": "apleca",
    "aplecarea": "aplecare",
    "aplecări": "aplecare",
    "aplecării": "aplecare",
    "aplecările": "aplecare",
    "aplecata": "aplecat",
    "aplecată": "aplecat",
    "aplecate": "aplecat",
    "aplecatei": "aplecat",
    "aplecatele": "aplecat",
    "aplecatelor": "aplecat",
    "aplecați": "aplecat",
    "aplecații": "aplecat",
    "aplecaților": "aplecat",
    "aplecatul": "aplecat",
    "aplecatului": "aplecat",
    "aplic": "aplica",
    "aplică": "aplica",
    "aplicai": "aplica",
    "aplicam": "aplica",
    "aplicăm": "aplica",
    "aplicând": "aplica",
    "aplicându": "aplica",
    "aplicară": "aplica",
    "aplicarăm": "aplica",
    "aplicarăți": "aplica",
    "aplicase": "aplica",
    "aplicasem": "aplica",
    "aplicaseră": "aplica",
    "aplicaserăm": "aplica",
    "aplicaserăți": "aplica",
    "aplicaseși": "aplica",
    "aplicași": "aplica",
    "aplicat": "aplica",
    "aplicați": "aplica",
    "aplicatu": "aplica",
    "aplicau": "aplica",
    "aplice": "aplica",
    "aplici": "aplica",
    "neaplicând": "aplica",
    "neaplicându": "aplica",
    "nemaiaplicând": "aplica",
    "nemaiaplicându": "aplica",
    "aplicabilă": "aplicabil",
    "aplicabile": "aplicabil",
    "aplicabili": "aplicabil",
    "aplicarea": "aplicare",
    "aplicări": "aplicare",
    "aplicării": "aplicare",
    "aplicările": "aplicare",
    "aplicata": "aplicat",
    "aplicată": "aplicat",
    "aplicate": "aplicat",
    "aplicatei": "aplicat",
    "aplicatele": "aplicat",
    "aplicatelor": "aplicat",
    "aplicați": "aplicat",
    "aplicații": "aplicat",
    "aplicaților": "aplicat",
    "aplicatul": "aplicat",
    "aplicatului": "aplicat",
    "aplicația": "aplicație",
    "aplicației": "aplicație",
    "aplicații": "aplicație",
    "aplicațiile": "aplicație",
    "aplicațiilor": "aplicație",
    "aplicativa": "aplicativ",
    "aplicativă": "aplicativ",
    "aplicative": "aplicativ",
    "aplicativei": "aplicativ",
    "aplicativele": "aplicativ",
    "aplicativelor": "aplicativ",
    "aplicativi": "aplicativ",
    "aplicativii": "aplicativ",
    "aplicativilor": "aplicativ",
    "aplicativul": "aplicativ",
    "aplicativului": "aplicativ",
    "aplombul": "aplomb",
    "aplombului": "aplomb",
    "aplomburi": "aplomb",
    "aplomburile": "aplomb",
    "aplomburilor": "aplomb",
    "apneea": "apnee",
    "apocaliptica": "apocaliptic",
    "apocaliptică": "apocaliptic",
    "apocaliptice": "apocaliptic",
    "apocalipticei": "apocaliptic",
    "apocalipticele": "apocaliptic",
    "apocalipticelor": "apocaliptic",
    "apocaliptici": "apocaliptic",
    "apocalipticii": "apocaliptic",
    "apocalipticilor": "apocaliptic",
    "apocalipticul": "apocaliptic",
    "apocalipticului": "apocaliptic",
    "apocopa": "apocopă",
    "apocope": "apocopă",
    "apocopei": "apocopă",
    "apocopele": "apocopă",
    "apocopelor": "apocopă",
    "apocrifa": "apocrif",
    "apocrifă": "apocrif",
    "apocrife": "apocrif",
    "apocrifei": "apocrif",
    "apocrifele": "apocrif",
    "apocrifelor": "apocrif",
    "apocrifi": "apocrif",
    "apocrifii": "apocrif",
    "apocrifilor": "apocrif",
    "apocriful": "apocrif",
    "apocrifului": "apocrif",
    "apodictica": "apodictic",
    "apodictică": "apodictic",
    "apodictice": "apodictic",
    "apodicticei": "apodictic",
    "apodicticele": "apodictic",
    "apodicticelor": "apodictic",
    "apodictici": "apodictic",
    "apodicticii": "apodictic",
    "apodicticilor": "apodictic",
    "apodicticul": "apodictic",
    "apodicticului": "apodictic",
    "apogee": "apogeu",
    "apogeele": "apogeu",
    "apogeelor": "apogeu",
    "apogeul": "apogeu",
    "apogeului": "apogeu",
    "apolitica": "apolitic",
    "apolitică": "apolitic",
    "apolitice": "apolitic",
    "apoliticei": "apolitic",
    "apoliticele": "apolitic",
    "apoliticelor": "apolitic",
    "apolitici": "apolitic",
    "apoliticii": "apolitic",
    "apoliticilor": "apolitic",
    "apoliticul": "apolitic",
    "apoliticului": "apolitic",
    "apologeți": "apologet",
    "apologeții": "apologet",
    "apologeților": "apologet",
    "apologetul": "apologet",
    "apologetului": "apologet",
    "apologetica": "apologetic",
    "apologetică": "apologetic",
    "apologetice": "apologetic",
    "apologeticei": "apologetic",
    "apologeticele": "apologetic",
    "apologeticelor": "apologetic",
    "apologetici": "apologetic",
    "apologeticii": "apologetic",
    "apologeticilor": "apologetic",
    "apologeticul": "apologetic",
    "apologeticului": "apologetic",
    "apologia": "apologie",
    "apologiei": "apologie",
    "apologii": "apologie",
    "apologiile": "apologie",
    "apologiilor": "apologie",
    "apometre": "apometru",
    "apometrele": "apometru",
    "apometrelor": "apometru",
    "apometrul": "apometru",
    "apometrului": "apometru",
    "aponevrotica": "aponevrotic",
    "aponevrotică": "aponevrotic",
    "aponevrotice": "aponevrotic",
    "aponevroticei": "aponevrotic",
    "aponevroticele": "aponevrotic",
    "aponevroticelor": "aponevrotic",
    "aponevrotici": "aponevrotic",
    "aponevroticii": "aponevrotic",
    "aponevroticilor": "aponevrotic",
    "aponevroticul": "aponevrotic",
    "aponevroticului": "aponevrotic",
    "apoplectica": "apoplectic",
    "apoplectică": "apoplectic",
    "apoplectice": "apoplectic",
    "apoplecticei": "apoplectic",
    "apoplecticele": "apoplectic",
    "apoplecticelor": "apoplectic",
    "apoplectici": "apoplectic",
    "apoplecticii": "apoplectic",
    "apoplecticilor": "apoplectic",
    "apoplecticul": "apoplectic",
    "apoplecticului": "apoplectic",
    "apoplexia": "apoplexie",
    "apoplexiei": "apoplexie",
    "apoplexii": "apoplexie",
    "apoplexiile": "apoplexie",
    "apoplexiilor": "apoplexie",
    "aporetică": "aporetic",
    "aporetice": "aporetic",
    "aporetici": "aporetic",
    "aportul": "aport",
    "aportului": "aport",
    "aporturi": "aport",
    "aporturile": "aport",
    "aporturilor": "aport",
    "apoasa": "apos",
    "apoasă": "apos",
    "apoase": "apos",
    "apoasei": "apos",
    "apoasele": "apos",
    "apoaselor": "apos",
    "apoaso": "apos",
    "apoși": "apos",
    "apoșii": "apos",
    "apoșilor": "apos",
    "aposul": "apos",
    "aposule": "apos",
    "aposului": "apos",
    "apostata": "apostat",
    "apostată": "apostat",
    "apostate": "apostat",
    "apostatei": "apostat",
    "apostatele": "apostat",
    "apostatelor": "apostat",
    "apostați": "apostat",
    "apostații": "apostat",
    "apostaților": "apostat",
    "apostatul": "apostat",
    "apostatului": "apostat",
    "apostazia": "apostazie",
    "apostaziei": "apostazie",
    "apostazii": "apostazie",
    "apostaziile": "apostazie",
    "apostaziilor": "apostazie",
    "apostila": "apostilă",
    "apostile": "apostilă",
    "apostilei": "apostilă",
    "apostilele": "apostilă",
    "apostilelor": "apostilă",
    "apostoli": "apostol",
    "apostolii": "apostol",
    "apostolilor": "apostol",
    "apostolul": "apostol",
    "apostolului": "apostol",
    "apostolate": "apostolat",
    "apostolatele": "apostolat",
    "apostolatelor": "apostolat",
    "apostolatul": "apostolat",
    "apostolatului": "apostolat",
    "apostolica": "apostolic",
    "apostolică": "apostolic",
    "apostolice": "apostolic",
    "apostolicei": "apostolic",
    "apostolicele": "apostolic",
    "apostolicelor": "apostolic",
    "apostolici": "apostolic",
    "apostolicii": "apostolic",
    "apostolicilor": "apostolic",
    "apostolicul": "apostolic",
    "apostolicului": "apostolic",
    "apostroful": "apostrof",
    "apostrofului": "apostrof",
    "apostrofuri": "apostrof",
    "apostrofurile": "apostrof",
    "apostrofurilor": "apostrof",
    "apostrofă": "apostrofa",
    "apostrofai": "apostrofa",
    "apostrofam": "apostrofa",
    "apostrofăm": "apostrofa",
    "apostrofând": "apostrofa",
    "apostrofându": "apostrofa",
    "apostrofară": "apostrofa",
    "apostrofarăm": "apostrofa",
    "apostrofarăți": "apostrofa",
    "apostrofase": "apostrofa",
    "apostrofasem": "apostrofa",
    "apostrofaseră": "apostrofa",
    "apostrofaserăm": "apostrofa",
    "apostrofaserăți": "apostrofa",
    "apostrofaseși": "apostrofa",
    "apostrofași": "apostrofa",
    "apostrofat": "apostrofa",
    "apostrofați": "apostrofa",
    "apostrofatu": "apostrofa",
    "apostrofau": "apostrofa",
    "apostrofează": "apostrofa",
    "apostrofez": "apostrofa",
    "apostrofeze": "apostrofa",
    "apostrofezi": "apostrofa",
    "neapostrofând": "apostrofa",
    "neapostrofându": "apostrofa",
    "nemaiapostrofând": "apostrofa",
    "nemaiapostrofându": "apostrofa",
    "apostrofa": "apostrofă",
    "apostrofe": "apostrofă",
    "apostrofei": "apostrofă",
    "apostrofele": "apostrofă",
    "apostrofelor": "apostrofă",
    "apostrofarea": "apostrofare",
    "apostrofări": "apostrofare",
    "apostrofării": "apostrofare",
    "apostrofările": "apostrofare",
    "apostrofata": "apostrofat",
    "apostrofată": "apostrofat",
    "apostrofate": "apostrofat",
    "apostrofatei": "apostrofat",
    "apostrofatele": "apostrofat",
    "apostrofatelor": "apostrofat",
    "apostrofați": "apostrofat",
    "apostrofații": "apostrofat",
    "apostrofaților": "apostrofat",
    "apostrofatul": "apostrofat",
    "apostrofatului": "apostrofat",
    "apoteotica": "apoteotic",
    "apoteotică": "apoteotic",
    "apoteotice": "apoteotic",
    "apoteoticei": "apoteotic",
    "apoteoticele": "apoteotic",
    "apoteoticelor": "apoteotic",
    "apoteotici": "apoteotic",
    "apoteoticii": "apoteotic",
    "apoteoticilor": "apoteotic",
    "apoteoticul": "apoteotic",
    "apoteoticului": "apoteotic",
    "apoteoza": "apoteoză",
    "apoteoze": "apoteoză",
    "apoteozei": "apoteoză",
    "apoteozele": "apoteoză",
    "apoteozelor": "apoteoză",
    "apoziția": "apoziție",
    "apoziției": "apoziție",
    "apoziții": "apoziție",
    "apozițiile": "apoziție",
    "apozițiilor": "apoziție",
    "apreciai": "aprecia",
    "apreciam": "aprecia",
    "apreciară": "aprecia",
    "apreciarăm": "aprecia",
    "apreciarăți": "aprecia",
    "apreciase": "aprecia",
    "apreciasem": "aprecia",
    "apreciaseră": "aprecia",
    "apreciaserăm": "aprecia",
    "apreciaserăți": "aprecia",
    "apreciaseși": "aprecia",
    "apreciași": "aprecia",
    "apreciat": "aprecia",
    "apreciați": "aprecia",
    "apreciatu": "aprecia",
    "apreciau": "aprecia",
    "apreciază": "aprecia",
    "aprecie": "aprecia",
    "apreciem": "aprecia",
    "apreciez": "aprecia",
    "aprecieze": "aprecia",
    "apreciezi": "aprecia",
    "apreciind": "aprecia",
    "apreciindu": "aprecia",
    "neapreciind": "aprecia",
    "neapreciindu": "aprecia",
    "nemaiapreciind": "aprecia",
    "nemaiapreciindu": "aprecia",
    "apreciabilă": "apreciabil",
    "apreciabile": "apreciabil",
    "apreciabili": "apreciabil",
    "apreciata": "apreciat",
    "apreciată": "apreciat",
    "apreciate": "apreciat",
    "apreciatei": "apreciat",
    "apreciatele": "apreciat",
    "apreciatelor": "apreciat",
    "apreciați": "apreciat",
    "apreciații": "apreciat",
    "apreciaților": "apreciat",
    "apreciatul": "apreciat",
    "apreciatului": "apreciat",
    "apreciativa": "apreciativ",
    "apreciativă": "apreciativ",
    "apreciative": "apreciativ",
    "apreciativei": "apreciativ",
    "apreciativele": "apreciativ",
    "apreciativelor": "apreciativ",
    "apreciativi": "apreciativ",
    "apreciativii": "apreciativ",
    "apreciativilor": "apreciativ",
    "apreciativul": "apreciativ",
    "apreciativului": "apreciativ",
    "apreciatoarea": "apreciatoare",
    "apreciatoarei": "apreciatoare",
    "apreciatoarele": "apreciatoare",
    "apreciatoarelor": "apreciatoare",
    "apreciatoare": "apreciator",
    "apreciatoarea": "apreciator",
    "apreciatoarei": "apreciator",
    "apreciatoarele": "apreciator",
    "apreciatoarelor": "apreciator",
    "apreciatori": "apreciator",
    "apreciatorii": "apreciator",
    "apreciatorilor": "apreciator",
    "apreciatorul": "apreciator",
    "apreciatorului": "apreciator",
    "aprecierea": "apreciere",
    "aprecieri": "apreciere",
    "aprecierii": "apreciere",
    "aprecierile": "apreciere",
    "aprehensiunea": "aprehensiune",
    "aprehensiuni": "aprehensiune",
    "aprehensiunii": "aprehensiune",
    "aprehensiunile": "aprehensiune",
    "aprehensiunilor": "aprehensiune",
    "apretai": "apreta",
    "apretam": "apreta",
    "apretăm": "apreta",
    "apretând": "apreta",
    "apretându": "apreta",
    "apretară": "apreta",
    "apretarăm": "apreta",
    "apretarăți": "apreta",
    "apretase": "apreta",
    "apretasem": "apreta",
    "apretaseră": "apreta",
    "apretaserăm": "apreta",
    "apretaserăți": "apreta",
    "apretaseși": "apreta",
    "apretași": "apreta",
    "apretat": "apreta",
    "apretați": "apreta",
    "apretatu": "apreta",
    "apretarea": "apretare",
    "apretări": "apretare",
    "apretării": "apretare",
    "apretările": "apretare",
    "apretata": "apretat",
    "apretată": "apretat",
    "apretate": "apretat",
    "apretatei": "apretat",
    "apretatele": "apretat",
    "apretatelor": "apretat",
    "apretați": "apretat",
    "apretații": "apretat",
    "apretaților": "apretat",
    "apretatul": "apretat",
    "apretatului": "apretat",
    "apriata": "apriat",
    "apriată": "apriat",
    "apriate": "apriat",
    "apriatei": "apriat",
    "apriatele": "apriat",
    "apriatelor": "apriat",
    "apriați": "apriat",
    "apriații": "apriat",
    "apriaților": "apriat",
    "apriatul": "apriat",
    "apriatului": "apriat",
    "apriga": "aprig",
    "aprigă": "aprig",
    "aprige": "aprig",
    "aprigei": "aprig",
    "aprigele": "aprig",
    "aprigelor": "aprig",
    "aprigi": "aprig",
    "aprigii": "aprig",
    "aprigilor": "aprig",
    "aprigul": "aprig",
    "aprigului": "aprig",
    "april'": "aprilie",
    "aprind": "aprinde",
    "aprindă": "aprinde",
    "aprindea": "aprinde",
    "aprindeai": "aprinde",
    "aprindeam": "aprinde",
    "aprindeați": "aprinde",
    "aprindeau": "aprinde",
    "aprindem": "aprinde",
    "aprindeți": "aprinde",
    "aprins": "aprinde",
    "aprinse": "aprinde",
    "aprinsei": "aprinde",
    "aprinseră": "aprinde",
    "aprinserăm": "aprinde",
    "aprinserăți": "aprinde",
    "aprinsese": "aprinde",
    "aprinsesem": "aprinde",
    "aprinseseră": "aprinde",
    "aprinseserăm": "aprinde",
    "aprinseserăți": "aprinde",
    "aprinseseși": "aprinde",
    "aprinseși": "aprinde",
    "aprinsu": "aprinde",
    "aprinzând": "aprinde",
    "aprinzându": "aprinde",
    "aprinzi": "aprinde",
    "neaprinzând": "aprinde",
    "neaprinzându": "aprinde",
    "nemaiaprinzând": "aprinde",
    "nemaiaprinzându": "aprinde",
    "aprinderea": "aprindere",
    "aprinderi": "aprindere",
    "aprinderii": "aprindere",
    "aprinderile": "aprindere",
    "aprinsa": "aprins",
    "aprinsă": "aprins",
    "aprinse": "aprins",
    "aprinsei": "aprins",
    "aprinsele": "aprins",
    "aprinselor": "aprins",
    "aprinși": "aprins",
    "aprinșii": "aprins",
    "aprinșilor": "aprins",
    "aprinsul": "aprins",
    "aprinsului": "aprins",
    "aprinzătoare": "aprinzător",
    "aprinzătoarele": "aprinzător",
    "aprinzătoarelor": "aprinzător",
    "aprinzători": "aprinzător",
    "aprinzătorii": "aprinzător",
    "aprinzătorilor": "aprinzător",
    "aprinzătorul": "aprinzător",
    "aprinzătorului": "aprinzător",
    "apriorica": "aprioric",
    "apriorică": "aprioric",
    "apriorice": "aprioric",
    "aprioricei": "aprioric",
    "aprioricele": "aprioric",
    "aprioricelor": "aprioric",
    "apriorici": "aprioric",
    "aprioricii": "aprioric",
    "aprioricilor": "aprioric",
    "aprioricul": "aprioric",
    "aprioricului": "aprioric",
    "aproapele": "aproape",
    "aproapelui": "aproape",
    "aproapelui": "aproapele",
    "aprob": "aproba",
    "aprobă": "aproba",
    "aprobai": "aproba",
    "aprobam": "aproba",
    "aprobăm": "aproba",
    "aprobând": "aproba",
    "aprobându": "aproba",
    "aprobară": "aproba",
    "aprobarăm": "aproba",
    "aprobarăți": "aproba",
    "aprobase": "aproba",
    "aprobasem": "aproba",
    "aprobaseră": "aproba",
    "aprobaserăm": "aproba",
    "aprobaserăți": "aproba",
    "aprobaseși": "aproba",
    "aprobași": "aproba",
    "aprobat": "aproba",
    "aprobați": "aproba",
    "aprobatu": "aproba",
    "aprobau": "aproba",
    "aprobe": "aproba",
    "aprobi": "aproba",
    "neaprobând": "aproba",
    "neaprobându": "aproba",
    "nemaiaprobând": "aproba",
    "nemaiaprobându": "aproba",
    "aprobarea": "aprobare",
    "aprobări": "aprobare",
    "aprobării": "aprobare",
    "aprobările": "aprobare",
    "aprobata": "aprobat",
    "aprobată": "aprobat",
    "aprobate": "aprobat",
    "aprobatei": "aprobat",
    "aprobatele": "aprobat",
    "aprobatelor": "aprobat",
    "aprobați": "aprobat",
    "aprobații": "aprobat",
    "aprobaților": "aprobat",
    "aprobatul": "aprobat",
    "aprobatului": "aprobat",
    "aprobativa": "aprobativ",
    "aprobativă": "aprobativ",
    "aprobative": "aprobativ",
    "aprobativei": "aprobativ",
    "aprobativele": "aprobativ",
    "aprobativelor": "aprobativ",
    "aprobativi": "aprobativ",
    "aprobativii": "aprobativ",
    "aprobativilor": "aprobativ",
    "aprobativul": "aprobativ",
    "aprobativului": "aprobativ",
    "aprobatoare": "aprobator",
    "aprobatoarea": "aprobator",
    "aprobatoarei": "aprobator",
    "aprobatoarele": "aprobator",
    "aprobatoarelor": "aprobator",
    "aprobatori": "aprobator",
    "aprobatorii": "aprobator",
    "aprobatorilor": "aprobator",
    "aprobatorul": "aprobator",
    "aprobatorului": "aprobator",
    "aprodul": "aprod",
    "aprodului": "aprod",
    "aprozi": "aprod",
    "aprozii": "aprod",
    "aprozilor": "aprod",
    "aprofundă": "aprofunda",
    "aprofundai": "aprofunda",
    "aprofundam": "aprofunda",
    "aprofundăm": "aprofunda",
    "aprofundând": "aprofunda",
    "aprofundându": "aprofunda",
    "aprofundară": "aprofunda",
    "aprofundarăm": "aprofunda",
    "aprofundarăți": "aprofunda",
    "aprofundase": "aprofunda",
    "aprofundasem": "aprofunda",
    "aprofundaseră": "aprofunda",
    "aprofundaserăm": "aprofunda",
    "aprofundaserăți": "aprofunda",
    "aprofundaseși": "aprofunda",
    "aprofundași": "aprofunda",
    "aprofundat": "aprofunda",
    "aprofundați": "aprofunda",
    "aprofundatu": "aprofunda",
    "aprofundau": "aprofunda",
    "aprofundează": "aprofunda",
    "aprofundez": "aprofunda",
    "aprofundeze": "aprofunda",
    "aprofundezi": "aprofunda",
    "neaprofundând": "aprofunda",
    "neaprofundându": "aprofunda",
    "nemaiaprofundând": "aprofunda",
    "nemaiaprofundându": "aprofunda",
    "aprofundarea": "aprofundare",
    "aprofundări": "aprofundare",
    "aprofundării": "aprofundare",
    "aprofundările": "aprofundare",
    "aprofundata": "aprofundat",
    "aprofundată": "aprofundat",
    "aprofundate": "aprofundat",
    "aprofundatei": "aprofundat",
    "aprofundatele": "aprofundat",
    "aprofundatelor": "aprofundat",
    "aprofundați": "aprofundat",
    "aprofundații": "aprofundat",
    "aprofundaților": "aprofundat",
    "aprofundatul": "aprofundat",
    "aprofundatului": "aprofundat",
    "apropiai": "apropia",
    "apropiam": "apropia",
    "apropiară": "apropia",
    "apropiarăm": "apropia",
    "apropiarăți": "apropia",
    "apropiase": "apropia",
    "apropiasem": "apropia",
    "apropiaseră": "apropia",
    "apropiaserăm": "apropia",
    "apropiaserăți": "apropia",
    "apropiaseși": "apropia",
    "apropiași": "apropia",
    "apropiat": "apropia",
    "apropiați": "apropia",
    "apropiatu": "apropia",
    "apropiau": "apropia",
    "apropie": "apropia",
    "apropiem": "apropia",
    "apropii": "apropia",
    "apropiind": "apropia",
    "apropiindu": "apropia",
    "neapropiind": "apropia",
    "neapropiindu": "apropia",
    "nemaiapropiind": "apropia",
    "nemaiapropiindu": "apropia",
    "apropiata": "apropiat",
    "apropiată": "apropiat",
    "apropiate": "apropiat",
    "apropiatei": "apropiat",
    "apropiatele": "apropiat",
    "apropiatelor": "apropiat",
    "apropiați": "apropiat",
    "apropiații": "apropiat",
    "apropiaților": "apropiat",
    "apropiatul": "apropiat",
    "apropiatului": "apropiat",
    "apropiata": "apropiată",
    "apropiate": "apropiată",
    "apropiatei": "apropiată",
    "apropiatele": "apropiată",
    "apropiatelor": "apropiată",
    "apropierea": "apropiere",
    "apropieri": "apropiere",
    "apropierii": "apropiere",
    "apropierile": "apropiere",
    "apropoul": "apropo",
    "apropoului": "apropo",
    "apropouri": "apropo",
    "apropourile": "apropo",
    "apropourilor": "apropo",
    "aprovizionă": "aproviziona",
    "aprovizionai": "aproviziona",
    "aprovizionam": "aproviziona",
    "aprovizionăm": "aproviziona",
    "aprovizionând": "aproviziona",
    "aprovizionându": "aproviziona",
    "aprovizionară": "aproviziona",
    "aprovizionarăm": "aproviziona",
    "aprovizionarăți": "aproviziona",
    "aprovizionase": "aproviziona",
    "aprovizionasem": "aproviziona",
    "aprovizionaseră": "aproviziona",
    "aprovizionaserăm": "aproviziona",
    "aprovizionaserăți": "aproviziona",
    "aprovizionaseși": "aproviziona",
    "aprovizionași": "aproviziona",
    "aprovizionat": "aproviziona",
    "aprovizionați": "aproviziona",
    "aprovizionatu": "aproviziona",
    "aprovizionau": "aproviziona",
    "aprovizionează": "aproviziona",
    "aprovizionez": "aproviziona",
    "aprovizioneze": "aproviziona",
    "aprovizionezi": "aproviziona",
    "neaprovizionând": "aproviziona",
    "neaprovizionându": "aproviziona",
    "nemaiaprovizionând": "aproviziona",
    "nemaiaprovizionându": "aproviziona",
    "aprovizionarea": "aprovizionare",
    "aprovizionări": "aprovizionare",
    "aprovizionării": "aprovizionare",
    "aprovizionările": "aprovizionare",
    "aprovizionărilor": "aprovizionare",
    "aprovizionata": "aprovizionat",
    "aprovizionată": "aprovizionat",
    "aprovizionate": "aprovizionat",
    "aprovizionatei": "aprovizionat",
    "aprovizionatele": "aprovizionat",
    "aprovizionatelor": "aprovizionat",
    "aprovizionați": "aprovizionat",
    "aprovizionații": "aprovizionat",
    "aprovizionaților": "aprovizionat",
    "aprovizionatul": "aprovizionat",
    "aprovizionatului": "aprovizionat",
    "aproximarea": "aproximare",
    "aproximări": "aproximare",
    "aproximării": "aproximare",
    "aproximările": "aproximare",
    "aproximărilor": "aproximare",
    "aproximația": "aproximație",
    "aproximației": "aproximație",
    "aproximații": "aproximație",
    "aproximațiile": "aproximație",
    "aproximațiilor": "aproximație",
    "aprox.": "aproximativ",
    "aproximativa": "aproximativ",
    "aproximativă": "aproximativ",
    "aproximative": "aproximativ",
    "aproximativei": "aproximativ",
    "aproximativele": "aproximativ",
    "aproximativelor": "aproximativ",
    "aproximativi": "aproximativ",
    "aproximativii": "aproximativ",
    "aproximativilor": "aproximativ",
    "aproximativul": "aproximativ",
    "aproximativului": "aproximativ",
    "apta": "apt",
    "aptă": "apt",
    "apte": "apt",
    "aptei": "apt",
    "aptele": "apt",
    "aptelor": "apt",
    "apți": "apt",
    "apții": "apt",
    "apților": "apt",
    "aptul": "apt",
    "aptului": "apt",
    "aptera": "apter",
    "apteră": "apter",
    "aptere": "apter",
    "apterei": "apter",
    "apterele": "apter",
    "apterelor": "apter",
    "apteri": "apter",
    "apterii": "apter",
    "apterilor": "apter",
    "apterul": "apter",
    "apterului": "apter",
    "aptitudinea": "aptitudine",
    "aptitudini": "aptitudine",
    "aptitudinii": "aptitudine",
    "aptitudinile": "aptitudine",
    "aptitudinilor": "aptitudine",
    "apuc": "apuca",
    "apucă": "apuca",
    "apucai": "apuca",
    "apucam": "apuca",
    "apucăm": "apuca",
    "apucând": "apuca",
    "apucându": "apuca",
    "apucară": "apuca",
    "apucarăm": "apuca",
    "apucarăți": "apuca",
    "apucase": "apuca",
    "apucasem": "apuca",
    "apucaseră": "apuca",
    "apucaserăm": "apuca",
    "apucaserăți": "apuca",
    "apucaseși": "apuca",
    "apucași": "apuca",
    "apucat": "apuca",
    "apucați": "apuca",
    "apucatu": "apuca",
    "apucau": "apuca",
    "apuce": "apuca",
    "apuci": "apuca",
    "neapucând": "apuca",
    "neapucându": "apuca",
    "nemaiapucând": "apuca",
    "nemaiapucându": "apuca",
    "apucarea": "apucare",
    "apucări": "apucare",
    "apucării": "apucare",
    "apucările": "apucare",
    "apucata": "apucat",
    "apucată": "apucat",
    "apucate": "apucat",
    "apucatei": "apucat",
    "apucatele": "apucat",
    "apucatelor": "apucat",
    "apucați": "apucat",
    "apucații": "apucat",
    "apucaților": "apucat",
    "apucatul": "apucat",
    "apucatului": "apucat",
    "apucata": "apucată",
    "apucate": "apucată",
    "apucatei": "apucată",
    "apucatele": "apucată",
    "apucatelor": "apucată",
    "apucătoarea": "apucătoare",
    "apucătoarei": "apucătoare",
    "apucătoarele": "apucătoare",
    "apucătoarelor": "apucătoare",
    "apucătoare": "apucător",
    "apucătoarea": "apucător",
    "apucătoarei": "apucător",
    "apucătoarele": "apucător",
    "apucătoarelor": "apucător",
    "apucători": "apucător",
    "apucătorii": "apucător",
    "apucătorilor": "apucător",
    "apucătorul": "apucător",
    "apucătorului": "apucător",
    "apucătura": "apucătură",
    "apucături": "apucătură",
    "apucăturii": "apucătură",
    "apucăturile": "apucătură",
    "apucăturilor": "apucătură",
    "apui": "apune",
    "apun": "apune",
    "apună": "apune",
    "apunând": "apune",
    "apunându": "apune",
    "apunea": "apune",
    "apuneai": "apune",
    "apuneam": "apune",
    "apuneați": "apune",
    "apuneau": "apune",
    "apunem": "apune",
    "apuneți": "apune",
    "apus": "apune",
    "apuse": "apune",
    "apusei": "apune",
    "apuseră": "apune",
    "apuserăm": "apune",
    "apuserăți": "apune",
    "apusese": "apune",
    "apusesem": "apune",
    "apuseseră": "apune",
    "apuseserăm": "apune",
    "apuseserăți": "apune",
    "apuseseși": "apune",
    "apuseși": "apune",
    "apusu": "apune",
    "neapunând": "apune",
    "neapunându": "apune",
    "nemaiapunând": "apune",
    "nemaiapunându": "apune",
    "apunerea": "apunere",
    "apuneri": "apunere",
    "apunerii": "apunere",
    "apunerile": "apunere",
    "apusa": "apus",
    "apusă": "apus",
    "apuse": "apus",
    "apusei": "apus",
    "apusele": "apus",
    "apuselor": "apus",
    "apuși": "apus",
    "apușii": "apus",
    "apușilor": "apus",
    "apusul": "apus",
    "apusului": "apus",
    "apuseana": "apusean",
    "apuseană": "apusean",
    "apuseanul": "apusean",
    "apuseanului": "apusean",
    "apusene": "apusean",
    "apusenei": "apusean",
    "apusenele": "apusean",
    "apusenelor": "apusean",
    "apuseni": "apusean",
    "apusenii": "apusean",
    "apusenilor": "apusean",
    "aq.": "aqua",
    "ari": "ar",
    "arii": "ar",
    "arilor": "ar",
    "arul": "ar",
    "arului": "ar",
    "ar": "ara",
    "ară": "ara",
    "arai": "ara",
    "aram": "ara",
    "arăm": "ara",
    "arând": "ara",
    "arându": "ara",
    "arară": "ara",
    "ararăm": "ara",
    "ararăți": "ara",
    "arase": "ara",
    "arasem": "ara",
    "araseră": "ara",
    "araserăm": "ara",
    "araserăți": "ara",
    "araseși": "ara",
    "arași": "ara",
    "arat": "ara",
    "arați": "ara",
    "aratu": "ara",
    "arau": "ara",
    "are": "ara",
    "ari": "ara",
    "nearând": "ara",
    "nearându": "ara",
    "nemaiarând": "ara",
    "nemaiarându": "ara",
    "araba": "arab",
    "arabă": "arab",
    "arabe": "arab",
    "arabei": "arab",
    "arabele": "arab",
    "arabelor": "arab",
    "arabi": "arab",
    "arabii": "arab",
    "arabilor": "arab",
    "arabul": "arab",
    "arabului": "arab",
    "arabescul": "arabesc",
    "arabescului": "arabesc",
    "arabescuri": "arabesc",
    "arabescurile": "arabesc",
    "arabescurilor": "arabesc",
    "arabica": "arabic",
    "arabică": "arabic",
    "arabice": "arabic",
    "arabicei": "arabic",
    "arabicele": "arabic",
    "arabicelor": "arabic",
    "arabici": "arabic",
    "arabicii": "arabic",
    "arabicilor": "arabic",
    "arabicul": "arabic",
    "arabicului": "arabic",
    "arabila": "arabil",
    "arabilă": "arabil",
    "arabile": "arabil",
    "arabilei": "arabil",
    "arabilele": "arabil",
    "arabilelor": "arabil",
    "arabili": "arabil",
    "arabilii": "arabil",
    "arabililor": "arabil",
    "arabilul": "arabil",
    "arabilului": "arabil",
    "Aradul": "Arad",
    "Aradului": "Arad",
    "arădeana": "arădean",
    "arădeană": "arădean",
    "arădeanul": "arădean",
    "arădeanului": "arădean",
    "arădene": "arădean",
    "arădenei": "arădean",
    "arădenele": "arădean",
    "arădenelor": "arădean",
    "arădeni": "arădean",
    "arădenii": "arădean",
    "arădenilor": "arădean",
    "aragazul": "aragaz",
    "aragazului": "aragaz",
    "aragazuri": "aragaz",
    "aragazurile": "aragaz",
    "aragazurilor": "aragaz",
    "arahida": "arahidă",
    "arahide": "arahidă",
    "arahidei": "arahidă",
    "arahidele": "arahidă",
    "arahidelor": "arahidă",
    "arahnida": "arahnidă",
    "arahnide": "arahnidă",
    "arahnidei": "arahnidă",
    "arahnidele": "arahnidă",
    "arahnidelor": "arahnidă",
    "arama": "aramă",
    "arame": "aramă",
    "aramei": "aramă",
    "aramele": "aramă",
    "aramelor": "aramă",
    "arămia": "arămiu",
    "arămie": "arămiu",
    "arămiei": "arămiu",
    "arămii": "arămiu",
    "arămiii": "arămiu",
    "arămiile": "arămiu",
    "arămiilor": "arămiu",
    "arămiul": "arămiu",
    "arămiului": "arămiu",
    "aranjă": "aranja",
    "aranjai": "aranja",
    "aranjam": "aranja",
    "aranjăm": "aranja",
    "aranjând": "aranja",
    "aranjară": "aranja",
    "aranjarăm": "aranja",
    "aranjarăți": "aranja",
    "aranjase": "aranja",
    "aranjasem": "aranja",
    "aranjaseră": "aranja",
    "aranjaserăm": "aranja",
    "aranjaserăți": "aranja",
    "aranjaseși": "aranja",
    "aranjași": "aranja",
    "aranjat": "aranja",
    "aranjați": "aranja",
    "aranjau": "aranja",
    "aranjează": "aranja",
    "aranjez": "aranja",
    "aranjeze": "aranja",
    "aranjezi": "aranja",
    "nearanjând": "aranja",
    "nemaiaranjând": "aranja",
    "aranjamente": "aranjament",
    "aranjamentele": "aranjament",
    "aranjamentelor": "aranjament",
    "aranjamentul": "aranjament",
    "aranjamentului": "aranjament",
    "aranjarea": "aranjare",
    "aranjări": "aranjare",
    "aranjării": "aranjare",
    "aranjările": "aranjare",
    "aranjata": "aranjat",
    "aranjată": "aranjat",
    "aranjate": "aranjat",
    "aranjatei": "aranjat",
    "aranjatele": "aranjat",
    "aranjatelor": "aranjat",
    "aranjați": "aranjat",
    "aranjații": "aranjat",
    "aranjaților": "aranjat",
    "aranjatul": "aranjat",
    "aranjatului": "aranjat",
    "arata": "arat",
    "arată": "arat",
    "arate": "arat",
    "aratei": "arat",
    "aratele": "arat",
    "aratelor": "arat",
    "arați": "arat",
    "arații": "arat",
    "araților": "arat",
    "aratul": "arat",
    "aratului": "arat",
    "arăt": "arăta",
    "arată": "arăta",
    "arăta'": "arăta",
    "arătă": "arăta",
    "arătai": "arăta",
    "arătam": "arăta",
    "arătăm": "arăta",
    "arătând": "arăta",
    "arătându": "arăta",
    "arătară": "arăta",
    "arătarăm": "arăta",
    "arătarăți": "arăta",
    "arătase": "arăta",
    "arătasem": "arăta",
    "arătaseră": "arăta",
    "arătaserăm": "arăta",
    "arătaserăți": "arăta",
    "arătaseși": "arăta",
    "arătași": "arăta",
    "arătat": "arăta",
    "arătați": "arăta",
    "arătatu": "arăta",
    "arătau": "arăta",
    "arate": "arăta",
    "arăți": "arăta",
    "nearătând": "arăta",
    "nearătându": "arăta",
    "nemaiarătând": "arăta",
    "nemaiarătându": "arăta",
    "arătarea": "arătare",
    "arătări": "arătare",
    "arătării": "arătare",
    "arătările": "arătare",
    "arătărilor": "arătare",
    "arăta'": "arătat",
    "arătata": "arătat",
    "arătată": "arătat",
    "arătate": "arătat",
    "arătatei": "arătat",
    "arătatele": "arătat",
    "arătatelor": "arătat",
    "arătați": "arătat",
    "arătații": "arătat",
    "arătaților": "arătat",
    "arătatul": "arătat",
    "arătatului": "arătat",
    "arătătoare": "arătător",
    "arătătoarele": "arătător",
    "arătătoarelor": "arătător",
    "arătătorul": "arătător",
    "arătătorului": "arătător",
    "arătoare": "arător",
    "arătoarea": "arător",
    "arătoarei": "arător",
    "arătoarele": "arător",
    "arătoarelor": "arător",
    "arători": "arător",
    "arătorii": "arător",
    "arătorilor": "arător",
    "arătorul": "arător",
    "arătorului": "arător",
    "arătoasa": "arătos",
    "arătoasă": "arătos",
    "arătoase": "arătos",
    "arătoasei": "arătos",
    "arătoasele": "arătos",
    "arătoaselor": "arătos",
    "arătoși": "arătos",
    "arătoșii": "arătos",
    "arătoșilor": "arătos",
    "arătosul": "arătos",
    "arătosului": "arătos",
    "arătura": "arătură",
    "arături": "arătură",
    "arăturii": "arătură",
    "arăturile": "arătură",
    "arăturilor": "arătură",
    "arbaleta": "arbaletă",
    "arbalete": "arbaletă",
    "arbaletei": "arbaletă",
    "arbaletele": "arbaletă",
    "arbaletelor": "arbaletă",
    "arbitră": "arbitra",
    "arbitrai": "arbitra",
    "arbitram": "arbitra",
    "arbitrăm": "arbitra",
    "arbitrând": "arbitra",
    "arbitrându": "arbitra",
    "arbitrară": "arbitra",
    "arbitrarăm": "arbitra",
    "arbitrarăți": "arbitra",
    "arbitrase": "arbitra",
    "arbitrasem": "arbitra",
    "arbitraseră": "arbitra",
    "arbitraserăm": "arbitra",
    "arbitraserăți": "arbitra",
    "arbitraseși": "arbitra",
    "arbitrași": "arbitra",
    "arbitrat": "arbitra",
    "arbitrați": "arbitra",
    "arbitratu": "arbitra",
    "arbitrau": "arbitra",
    "arbitrează": "arbitra",
    "arbitrez": "arbitra",
    "arbitreze": "arbitra",
    "arbitrezi": "arbitra",
    "arbitraje": "arbitraj",
    "arbitrajele": "arbitraj",
    "arbitrajelor": "arbitraj",
    "arbitrajul": "arbitraj",
    "arbitrajului": "arbitraj",
    "arbitrala": "arbitral",
    "arbitrală": "arbitral",
    "arbitrale": "arbitral",
    "arbitralei": "arbitral",
    "arbitralele": "arbitral",
    "arbitralelor": "arbitral",
    "arbitrali": "arbitral",
    "arbitralii": "arbitral",
    "arbitralilor": "arbitral",
    "arbitralul": "arbitral",
    "arbitralului": "arbitral",
    "arbitrara": "arbitrar",
    "arbitrară": "arbitrar",
    "arbitrare": "arbitrar",
    "arbitrarei": "arbitrar",
    "arbitrarele": "arbitrar",
    "arbitrarelor": "arbitrar",
    "arbitrari": "arbitrar",
    "arbitrarii": "arbitrar",
    "arbitrarilor": "arbitrar",
    "arbitrarul": "arbitrar",
    "arbitrarului": "arbitrar",
    "arbitrată": "arbitrat",
    "arbitrate": "arbitrat",
    "arbitrați": "arbitrat",
    "arbitri": "arbitru",
    "arbitrii": "arbitru",
    "arbitrilor": "arbitru",
    "arbitrul": "arbitru",
    "arbitrului": "arbitru",
    "arboră": "arbora",
    "arborai": "arbora",
    "arboram": "arbora",
    "arborăm": "arbora",
    "arborând": "arbora",
    "arborându": "arbora",
    "arborară": "arbora",
    "arborarăm": "arbora",
    "arborarăți": "arbora",
    "arborase": "arbora",
    "arborasem": "arbora",
    "arboraseră": "arbora",
    "arboraserăm": "arbora",
    "arboraserăți": "arbora",
    "arboraseși": "arbora",
    "arborași": "arbora",
    "arborat": "arbora",
    "arborați": "arbora",
    "arboratu": "arbora",
    "arborau": "arbora",
    "arborează": "arbora",
    "arborez": "arbora",
    "arboreze": "arbora",
    "arborezi": "arbora",
    "nearborând": "arbora",
    "nearborându": "arbora",
    "nemaiarborând": "arbora",
    "nemaiarborându": "arbora",
    "arborada": "arboradă",
    "arborade": "arboradă",
    "arboradei": "arboradă",
    "arboradele": "arboradă",
    "arboradelor": "arboradă",
    "arborarea": "arborare",
    "arborări": "arborare",
    "arborării": "arborare",
    "arborările": "arborare",
    "arborata": "arborat",
    "arborată": "arborat",
    "arborate": "arborat",
    "arboratei": "arborat",
    "arboratele": "arborat",
    "arboratelor": "arborat",
    "arborați": "arborat",
    "arborații": "arborat",
    "arboraților": "arborat",
    "arboratul": "arborat",
    "arboratului": "arborat",
    "arborele": "arbore",
    "arborelui": "arbore",
    "arbori": "arbore",
    "arborii": "arbore",
    "arborilor": "arbore",
    "arborescenta": "arborescent",
    "arborescentă": "arborescent",
    "arborescente": "arborescent",
    "arborescentei": "arborescent",
    "arborescentele": "arborescent",
    "arborescentelor": "arborescent",
    "arborescenți": "arborescent",
    "arborescenții": "arborescent",
    "arborescenților": "arborescent",
    "arborescentul": "arborescent",
    "arborescentului": "arborescent",
    "arbuști": "arbust",
    "arbuștii": "arbust",
    "arbuștilor": "arbust",
    "arbustul": "arbust",
    "arbustului": "arbust",
    "arce": "arc",
    "arcele": "arc",
    "arcelor": "arc",
    "arcul": "arc",
    "arcului": "arc",
    "arcuri": "arc",
    "arcurile": "arc",
    "arcurilor": "arc",
    "arca": "arcă",
    "arcada": "arcadă",
    "arcade": "arcadă",
    "arcadei": "arcadă",
    "arcadele": "arcadă",
    "arcadelor": "arcadă",
    "arcane": "arcan",
    "arcanele": "arcan",
    "arcanelor": "arcan",
    "arcanul": "arcan",
    "arcanului": "arcan",
    "arcași": "arcaș",
    "arcașii": "arcaș",
    "arcașilor": "arcaș",
    "arcașul": "arcaș",
    "arcașului": "arcaș",
    "arcata": "arcat",
    "arcată": "arcat",
    "arcate": "arcat",
    "arcatei": "arcat",
    "arcatele": "arcat",
    "arcatelor": "arcat",
    "arcați": "arcat",
    "arcații": "arcat",
    "arcaților": "arcat",
    "arcatul": "arcat",
    "arcatului": "arcat",
    "archebuza": "archebuză",
    "archebuze": "archebuză",
    "archebuzei": "archebuză",
    "archebuzele": "archebuză",
    "archebuzelor": "archebuză",
    "arctica": "arctic",
    "arctică": "arctic",
    "arctice": "arctic",
    "arcticei": "arctic",
    "arcticele": "arctic",
    "arcticelor": "arctic",
    "arctici": "arctic",
    "arcticii": "arctic",
    "arcticilor": "arctic",
    "arcticul": "arctic",
    "arcticului": "arctic",
    "arcuia": "arcui",
    "arcuiai": "arcui",
    "arcuiam": "arcui",
    "arcuiască": "arcui",
    "arcuiați": "arcui",
    "arcuiau": "arcui",
    "arcuiesc": "arcui",
    "arcuiește": "arcui",
    "arcuiești": "arcui",
    "arcuii": "arcui",
    "arcuim": "arcui",
    "arcuind": "arcui",
    "arcuindu": "arcui",
    "arcuiră": "arcui",
    "arcuirăm": "arcui",
    "arcuirăți": "arcui",
    "arcuise": "arcui",
    "arcuisem": "arcui",
    "arcuiseră": "arcui",
    "arcuiserăm": "arcui",
    "arcuiserăți": "arcui",
    "arcuiseși": "arcui",
    "arcuiși": "arcui",
    "arcuit": "arcui",
    "arcuiți": "arcui",
    "arcuitu": "arcui",
    "arcuirea": "arcuire",
    "arcuiri": "arcuire",
    "arcuirii": "arcuire",
    "arcuirile": "arcuire",
    "arcuita": "arcuit",
    "arcuită": "arcuit",
    "arcuite": "arcuit",
    "arcuitei": "arcuit",
    "arcuitele": "arcuit",
    "arcuitelor": "arcuit",
    "arcuiți": "arcuit",
    "arcuiții": "arcuit",
    "arcuiților": "arcuit",
    "arcuitul": "arcuit",
    "arcuitului": "arcuit",
    "ard": "arde",
    "ardă": "arde",
    "ardea": "arde",
    "ardeai": "arde",
    "ardeam": "arde",
    "ardeați": "arde",
    "ardeau": "arde",
    "ardem": "arde",
    "ardeți": "arde",
    "ars": "arde",
    "arse": "arde",
    "arsei": "arde",
    "arseră": "arde",
    "arserăm": "arde",
    "arserăți": "arde",
    "arsese": "arde",
    "arsesem": "arde",
    "arseseră": "arde",
    "arseserăm": "arde",
    "arseserăți": "arde",
    "arseseși": "arde",
    "arseși": "arde",
    "arzând": "arde",
    "arzându": "arde",
    "arzi": "arde",
    "nearzând": "arde",
    "nearzându": "arde",
    "nemaiarzând": "arde",
    "nemaiarzându": "arde",
    "Ardealul": "Ardeal",
    "Ardealului": "Ardeal",
    "ardeleana": "ardelean",
    "ardeleană": "ardelean",
    "ardeleanul": "ardelean",
    "ardeleanului": "ardelean",
    "ardelene": "ardelean",
    "ardelenei": "ardelean",
    "ardelenele": "ardelean",
    "ardelenelor": "ardelean",
    "ardeleni": "ardelean",
    "ardelenii": "ardelean",
    "ardelenilor": "ardelean",
    "ardeleneasca": "ardelenesc",
    "ardelenească": "ardelenesc",
    "ardelenescul": "ardelenesc",
    "ardelenescului": "ardelenesc",
    "ardelenești": "ardelenesc",
    "ardeleneștii": "ardelenesc",
    "ardeleneștile": "ardelenesc",
    "ardeleneștilor": "ardelenesc",
    "ardenta": "ardent",
    "ardentă": "ardent",
    "ardente": "ardent",
    "ardentei": "ardent",
    "ardentele": "ardent",
    "ardentelor": "ardent",
    "ardenți": "ardent",
    "ardenții": "ardent",
    "ardenților": "ardent",
    "ardentul": "ardent",
    "ardentului": "ardent",
    "arderea": "ardere",
    "arderi": "ardere",
    "arderii": "ardere",
    "arderile": "ardere",
    "ardezia": "ardezie",
    "ardeziei": "ardezie",
    "ardezii": "ardezie",
    "ardeziile": "ardezie",
    "ardeziilor": "ardezie",
    "ardoarea": "ardoare",
    "ardori": "ardoare",
    "ardorii": "ardoare",
    "ardorile": "ardoare",
    "ardorilor": "ardoare",
    "arealul": "areal",
    "arealului": "areal",
    "arealuri": "areal",
    "arealurile": "areal",
    "arealurilor": "areal",
    "arena": "arenă",
    "arene": "arenă",
    "arenei": "arenă",
    "arenele": "arenă",
    "arenelor": "arenă",
    "arendă": "arenda",
    "arendai": "arenda",
    "arendam": "arenda",
    "arendăm": "arenda",
    "arendând": "arenda",
    "arendară": "arenda",
    "arendarăm": "arenda",
    "arendarăți": "arenda",
    "arendase": "arenda",
    "arendasem": "arenda",
    "arendaseră": "arenda",
    "arendaserăm": "arenda",
    "arendaserăți": "arenda",
    "arendaseși": "arenda",
    "arendași": "arenda",
    "arendat": "arenda",
    "arendați": "arenda",
    "arendau": "arenda",
    "arendează": "arenda",
    "arendez": "arenda",
    "arendeze": "arenda",
    "arendezi": "arenda",
    "nearendând": "arenda",
    "nemaiarendând": "arenda",
    "arenda": "arendă",
    "arenzi": "arendă",
    "arenzii": "arendă",
    "arenzile": "arendă",
    "arenzilor": "arendă",
    "arendarea": "arendare",
    "arendări": "arendare",
    "arendării": "arendare",
    "arendările": "arendare",
    "arendași": "arendaș",
    "arendașii": "arendaș",
    "arendașilor": "arendaș",
    "arendașul": "arendaș",
    "arendașului": "arendaș",
    "arendata": "arendat",
    "arendată": "arendat",
    "arendate": "arendat",
    "arendatei": "arendat",
    "arendatele": "arendat",
    "arendatelor": "arendat",
    "arendați": "arendat",
    "arendații": "arendat",
    "arendaților": "arendat",
    "arendatul": "arendat",
    "arendatului": "arendat",
    "areometre": "areometru",
    "areometrele": "areometru",
    "areometrelor": "areometru",
    "areometrul": "areometru",
    "areometrului": "areometru",
    "areopagul": "areopag",
    "areopagului": "areopag",
    "areopaguri": "areopag",
    "areopagurile": "areopag",
    "areopagurilor": "areopag",
    "arestul": "arest",
    "arestului": "arest",
    "aresturi": "arest",
    "aresturile": "arest",
    "aresturilor": "arest",
    "arestă": "aresta",
    "arestai": "aresta",
    "arestam": "aresta",
    "arestăm": "aresta",
    "arestând": "aresta",
    "arestându": "aresta",
    "arestară": "aresta",
    "arestarăm": "aresta",
    "arestarăți": "aresta",
    "arestase": "aresta",
    "arestasem": "aresta",
    "arestaseră": "aresta",
    "arestaserăm": "aresta",
    "arestaserăți": "aresta",
    "arestaseși": "aresta",
    "arestași": "aresta",
    "arestat": "aresta",
    "arestați": "aresta",
    "arestatu": "aresta",
    "arestau": "aresta",
    "arestează": "aresta",
    "arestez": "aresta",
    "aresteze": "aresta",
    "arestezi": "aresta",
    "nearestând": "aresta",
    "nearestându": "aresta",
    "nemaiarestând": "aresta",
    "nemaiarestându": "aresta",
    "arestarea": "arestare",
    "arestări": "arestare",
    "arestării": "arestare",
    "arestările": "arestare",
    "arestata": "arestat",
    "arestată": "arestat",
    "arestate": "arestat",
    "arestatei": "arestat",
    "arestatele": "arestat",
    "arestatelor": "arestat",
    "arestați": "arestat",
    "arestații": "arestat",
    "arestaților": "arestat",
    "arestatul": "arestat",
    "arestatului": "arestat",
    "arestata": "arestată",
    "arestate": "arestată",
    "arestatei": "arestată",
    "arestatele": "arestată",
    "arestatelor": "arestată",
    "argăsea": "argăsi",
    "argăseai": "argăsi",
    "argăseam": "argăsi",
    "argăsească": "argăsi",
    "argăseați": "argăsi",
    "argăseau": "argăsi",
    "argăsesc": "argăsi",
    "argăsește": "argăsi",
    "argăsești": "argăsi",
    "argăsii": "argăsi",
    "argăsim": "argăsi",
    "argăsind": "argăsi",
    "argăsindu": "argăsi",
    "argăsiră": "argăsi",
    "argăsirăm": "argăsi",
    "argăsirăți": "argăsi",
    "argăsise": "argăsi",
    "argăsisem": "argăsi",
    "argăsiseră": "argăsi",
    "argăsiserăm": "argăsi",
    "argăsiserăți": "argăsi",
    "argăsiseși": "argăsi",
    "argăsiși": "argăsi",
    "argăsit": "argăsi",
    "argăsiți": "argăsi",
    "argăsitu": "argăsi",
    "neargăsind": "argăsi",
    "neargăsindu": "argăsi",
    "nemaiargăsind": "argăsi",
    "nemaiargăsindu": "argăsi",
    "argăsirea": "argăsire",
    "argăsiri": "argăsire",
    "argăsirii": "argăsire",
    "argăsirile": "argăsire",
    "argăsita": "argăsit",
    "argăsită": "argăsit",
    "argăsite": "argăsit",
    "argăsitei": "argăsit",
    "argăsitele": "argăsit",
    "argăsitelor": "argăsit",
    "argăsiți": "argăsit",
    "argăsiții": "argăsit",
    "argăsiților": "argăsit",
    "argăsitul": "argăsit",
    "argăsitului": "argăsit",
    "argați": "argat",
    "argații": "argat",
    "argaților": "argat",
    "argatul": "argat",
    "argatului": "argat",
    "argentifera": "argentifer",
    "argentiferă": "argentifer",
    "argentifere": "argentifer",
    "argentiferei": "argentifer",
    "argentiferele": "argentifer",
    "argentiferelor": "argentifer",
    "argentiferi": "argentifer",
    "argentiferii": "argentifer",
    "argentiferilor": "argentifer",
    "argentiferul": "argentifer",
    "argentiferului": "argentifer",
    "Ar.": "Argentina",
    "Argentină": "Argentina",
    "Argentinei": "Argentina",
    "Argentini": "Argentina",
    "Argeșul": "Argeș",
    "Argeșului": "Argeș",
    "argeșeana": "argeșean",
    "argeșeană": "argeșean",
    "argeșeanul": "argeșean",
    "argeșeanului": "argeșean",
    "argeșene": "argeșean",
    "argeșenei": "argeșean",
    "argeșenele": "argeșean",
    "argeșenelor": "argeșean",
    "argeșeni": "argeșean",
    "argeșenii": "argeșean",
    "argeșenilor": "argeșean",
    "argeșeanca": "argeșeancă",
    "argeșence": "argeșeancă",
    "argeșencei": "argeșeancă",
    "argeșencele": "argeșeancă",
    "argeșencelor": "argeșeancă",
    "arghirofilia": "arghirofilie",
    "arghirofiliei": "arghirofilie",
    "arghirofilii": "arghirofilie",
    "arghirofiliile": "arghirofilie",
    "arghirofiliilor": "arghirofilie",
    "argianii": "argian",
    "argianilor": "argian",
    "argianul": "argian",
    "argianului": "argian",
    "argieni": "argian",
    "argiloasa": "argilos",
    "argiloasă": "argilos",
    "argiloase": "argilos",
    "argiloasei": "argilos",
    "argiloasele": "argilos",
    "argiloaselor": "argilos",
    "argiloși": "argilos",
    "argiloșii": "argilos",
    "argiloșilor": "argilos",
    "argilosul": "argilos",
    "argilosului": "argilos",
    "Ag": "argint",
    "arginți": "argint",
    "arginții": "argint",
    "arginților": "argint",
    "argintul": "argint",
    "argintului": "argint",
    "argintăria": "argintărie",
    "argintăriei": "argintărie",
    "argintării": "argintărie",
    "argintăriile": "argintărie",
    "argintăriilor": "argintărie",
    "argintia": "argintiu",
    "argintie": "argintiu",
    "argintiei": "argintiu",
    "argintii": "argintiu",
    "argintiii": "argintiu",
    "argintiile": "argintiu",
    "argintiilor": "argintiu",
    "argintiul": "argintiu",
    "argintiului": "argintiu",
    "argintoasa": "argintos",
    "argintoasă": "argintos",
    "argintoase": "argintos",
    "argintoasei": "argintos",
    "argintoasele": "argintos",
    "argintoaselor": "argintos",
    "argintoși": "argintos",
    "argintoșii": "argintos",
    "argintoșilor": "argintos",
    "argintosul": "argintos",
    "argintosului": "argintos",
    "argintuita": "argintuit",
    "argintuită": "argintuit",
    "argintuite": "argintuit",
    "argintuitei": "argintuit",
    "argintuitele": "argintuit",
    "argintuitelor": "argintuit",
    "argintuiți": "argintuit",
    "argintuiții": "argintuit",
    "argintuiților": "argintuit",
    "argintuitul": "argintuit",
    "argintuitului": "argintuit",
    "argintului-viu": "argint-viu",
    "argintul-viu": "argint-viu",
    "Ar": "argon",
    "argonul": "argon",
    "argonului": "argon",
    "arg.": "argotic",
    "argotica": "argotic",
    "argotică": "argotic",
    "argotice": "argotic",
    "argoticei": "argotic",
    "argoticele": "argotic",
    "argoticelor": "argotic",
    "argotici": "argotic",
    "argoticii": "argotic",
    "argoticilor": "argotic",
    "argoticul": "argotic",
    "argoticului": "argotic",
    "argoul": "argou",
    "argoului": "argou",
    "argouri": "argou",
    "argourile": "argou",
    "argourilor": "argou",
    "argumente": "argument",
    "argumentele": "argument",
    "argumentelor": "argument",
    "argumentul": "argument",
    "argumentului": "argument",
    "argumentă": "argumenta",
    "argumentai": "argumenta",
    "argumentam": "argumenta",
    "argumentăm": "argumenta",
    "argumentând": "argumenta",
    "argumentându": "argumenta",
    "argumentară": "argumenta",
    "argumentarăm": "argumenta",
    "argumentarăți": "argumenta",
    "argumentase": "argumenta",
    "argumentasem": "argumenta",
    "argumentaseră": "argumenta",
    "argumentaserăm": "argumenta",
    "argumentaserăți": "argumenta",
    "argumentaseși": "argumenta",
    "argumentași": "argumenta",
    "argumentat": "argumenta",
    "argumentați": "argumenta",
    "argumentatu": "argumenta",
    "argumentau": "argumenta",
    "argumentează": "argumenta",
    "argumentez": "argumenta",
    "argumenteze": "argumenta",
    "argumentezi": "argumenta",
    "neargumentând": "argumenta",
    "neargumentându": "argumenta",
    "nemaiargumentând": "argumenta",
    "nemaiargumentându": "argumenta",
    "argumentarea": "argumentare",
    "argumentări": "argumentare",
    "argumentării": "argumentare",
    "argumentările": "argumentare",
    "argumentata": "argumentat",
    "argumentată": "argumentat",
    "argumentate": "argumentat",
    "argumentatei": "argumentat",
    "argumentatele": "argumentat",
    "argumentatelor": "argumentat",
    "argumentați": "argumentat",
    "argumentații": "argumentat",
    "argumentaților": "argumentat",
    "argumentatul": "argumentat",
    "argumentatului": "argumentat",
    "argumentația": "argumentație",
    "argumentației": "argumentație",
    "argumentații": "argumentație",
    "argumentațiile": "argumentație",
    "argumentațiilor": "argumentație",
    "argumentativa": "argumentativ",
    "argumentativă": "argumentativ",
    "argumentative": "argumentativ",
    "argumentativei": "argumentativ",
    "argumentativele": "argumentativ",
    "argumentativelor": "argumentativ",
    "argumentativi": "argumentativ",
    "argumentativii": "argumentativ",
    "argumentativilor": "argumentativ",
    "argumentativul": "argumentativ",
    "argumentativului": "argumentativ",
    "arhaica": "arhaic",
    "arhaică": "arhaic",
    "arhaice": "arhaic",
    "arhaicei": "arhaic",
    "arhaicele": "arhaic",
    "arhaicelor": "arhaic",
    "arhaici": "arhaic",
    "arhaicii": "arhaic",
    "arhaicilor": "arhaic",
    "arhaicul": "arhaic",
    "arhaicului": "arhaic",
    "arhaisme": "arhaism",
    "arhaismele": "arhaism",
    "arhaismelor": "arhaism",
    "arhaismul": "arhaism",
    "arhaismului": "arhaism",
    "arh.": "arhaizant",
    "arhaizantă": "arhaizant",
    "arhaizante": "arhaizant",
    "arhaizanți": "arhaizant",
    "arhangheli": "arhanghel",
    "arhanghelii": "arhanghel",
    "arhanghelilor": "arhanghel",
    "arhanghelul": "arhanghel",
    "arhanghelului": "arhanghel",
    "arheologi": "arheolog",
    "arheologii": "arheolog",
    "arheologilor": "arheolog",
    "arheologul": "arheolog",
    "arheologului": "arheolog",
    "arheologica": "arheologic",
    "arheologică": "arheologic",
    "arheologice": "arheologic",
    "arheologicei": "arheologic",
    "arheologicele": "arheologic",
    "arheologicelor": "arheologic",
    "arheologici": "arheologic",
    "arheologicii": "arheologic",
    "arheologicilor": "arheologic",
    "arheologicul": "arheologic",
    "arheologicului": "arheologic",
    "arheol.": "arheologie",
    "arheologia": "arheologie",
    "arheologiei": "arheologie",
    "arheologii": "arheologie",
    "arheologiile": "arheologie",
    "arheologiilor": "arheologie",
    "arhetipul": "arhetip",
    "arhetipului": "arhetip",
    "arhetipuri": "arhetip",
    "arhetipurile": "arhetip",
    "arhetipurilor": "arhetip",
    "arhicunoscuta": "arhicunoscut",
    "arhicunoscută": "arhicunoscut",
    "arhicunoscute": "arhicunoscut",
    "arhicunoscutei": "arhicunoscut",
    "arhicunoscutele": "arhicunoscut",
    "arhicunoscutelor": "arhicunoscut",
    "arhicunoscuți": "arhicunoscut",
    "arhicunoscuții": "arhicunoscut",
    "arhicunoscuților": "arhicunoscut",
    "arhicunoscutul": "arhicunoscut",
    "arhicunoscutului": "arhicunoscut",
    "arhidiecezana": "arhidiecezan",
    "arhidiecezană": "arhidiecezan",
    "arhidiecezane": "arhidiecezan",
    "arhidiecezanei": "arhidiecezan",
    "arhidiecezanele": "arhidiecezan",
    "arhidiecezanelor": "arhidiecezan",
    "arhidiecezani": "arhidiecezan",
    "arhidiecezanii": "arhidiecezan",
    "arhidiecezanilor": "arhidiecezan",
    "arhidiecezanul": "arhidiecezan",
    "arhidiecezanului": "arhidiecezan",
    "arhiepiscopala": "arhiepiscopal",
    "arhiepiscopală": "arhiepiscopal",
    "arhiepiscopale": "arhiepiscopal",
    "arhiepiscopalei": "arhiepiscopal",
    "arhiepiscopalele": "arhiepiscopal",
    "arhiepiscopalelor": "arhiepiscopal",
    "arhiepiscopali": "arhiepiscopal",
    "arhiepiscopalii": "arhiepiscopal",
    "arhiepiscopalilor": "arhiepiscopal",
    "arhiepiscopalul": "arhiepiscopal",
    "arhiepiscopalului": "arhiepiscopal",
    "arhiepiscopia": "arhiepiscopie",
    "arhiepiscopiei": "arhiepiscopie",
    "arhiepiscopii": "arhiepiscopie",
    "arhiepiscopiile": "arhiepiscopie",
    "arhiepiscopiilor": "arhiepiscopie",
    "arhierei": "arhiereu",
    "arhiereii": "arhiereu",
    "arhiereilor": "arhiereu",
    "arhiereul": "arhiereu",
    "arhiereului": "arhiereu",
    "arhimandriți": "arhimandrit",
    "arhimandriții": "arhimandrit",
    "arhimandriților": "arhimandrit",
    "arhimandritul": "arhimandrit",
    "arhimandritului": "arhimandrit",
    "arhimulțumea": "arhimulțumi",
    "arhimulțumeai": "arhimulțumi",
    "arhimulțumeam": "arhimulțumi",
    "arhimulțumească": "arhimulțumi",
    "arhimulțumeați": "arhimulțumi",
    "arhimulțumeau": "arhimulțumi",
    "arhimulțumesc": "arhimulțumi",
    "arhimulțumește": "arhimulțumi",
    "arhimulțumești": "arhimulțumi",
    "arhimulțumii": "arhimulțumi",
    "arhimulțumim": "arhimulțumi",
    "arhimulțumind": "arhimulțumi",
    "arhimulțumindu": "arhimulțumi",
    "arhimulțumiră": "arhimulțumi",
    "arhimulțumirăm": "arhimulțumi",
    "arhimulțumirăți": "arhimulțumi",
    "arhimulțumise": "arhimulțumi",
    "arhimulțumisem": "arhimulțumi",
    "arhimulțumiseră": "arhimulțumi",
    "arhimulțumiserăm": "arhimulțumi",
    "arhimulțumiserăți": "arhimulțumi",
    "arhimulțumiseși": "arhimulțumi",
    "arhimulțumiși": "arhimulțumi",
    "arhimulțumit": "arhimulțumi",
    "arhimulțumiți": "arhimulțumi",
    "arhimulțumitu": "arhimulțumi",
    "arhimulțumită": "arhimulțumit",
    "arhimulțumite": "arhimulțumit",
    "arhimulțumiți": "arhimulțumit",
    "arhipelagul": "arhipelag",
    "arhipelagului": "arhipelag",
    "arhipelaguri": "arhipelag",
    "arhipelagurile": "arhipelag",
    "arhipelagurilor": "arhipelag",
    "arhiplina": "arhiplin",
    "arhiplină": "arhiplin",
    "arhipline": "arhiplin",
    "arhiplinei": "arhiplin",
    "arhiplinele": "arhiplin",
    "arhiplinelor": "arhiplin",
    "arhiplini": "arhiplin",
    "arhiplinii": "arhiplin",
    "arhiplinilor": "arhiplin",
    "arhiplinul": "arhiplin",
    "arhiplinului": "arhiplin",
    "arh.": "arhitect",
    "arhitecți": "arhitect",
    "arhitecții": "arhitect",
    "arhitecților": "arhitect",
    "arhitectul": "arhitect",
    "arhitectului": "arhitect",
    "arhitectonica": "arhitectonic",
    "arhitectonică": "arhitectonic",
    "arhitectonice": "arhitectonic",
    "arhitectonicei": "arhitectonic",
    "arhitectonicele": "arhitectonic",
    "arhitectonicelor": "arhitectonic",
    "arhitectonici": "arhitectonic",
    "arhitectonicii": "arhitectonic",
    "arhitectonicilor": "arhitectonic",
    "arhitectonicul": "arhitectonic",
    "arhitectonicului": "arhitectonic",
    "arhit.": "arhitectură",
    "arhitectura": "arhitectură",
    "arhitecturi": "arhitectură",
    "arhitecturii": "arhitectură",
    "arhitecturile": "arhitectură",
    "arhitecturilor": "arhitectură",
    "arhitecturala": "arhitectural",
    "arhitecturală": "arhitectural",
    "arhitecturale": "arhitectural",
    "arhitecturalei": "arhitectural",
    "arhitecturalele": "arhitectural",
    "arhitecturalelor": "arhitectural",
    "arhitecturali": "arhitectural",
    "arhitecturalii": "arhitectural",
    "arhitecturalilor": "arhitectural",
    "arhitecturalul": "arhitectural",
    "arhitecturalului": "arhitectural",
    "arhivai": "arhiva",
    "arhivam": "arhiva",
    "arhivând": "arhiva",
    "arhivându": "arhiva",
    "arhivară": "arhiva",
    "arhivarăm": "arhiva",
    "arhivarăți": "arhiva",
    "arhivase": "arhiva",
    "arhivasem": "arhiva",
    "arhivaseră": "arhiva",
    "arhivaserăm": "arhiva",
    "arhivaserăți": "arhiva",
    "arhivaseși": "arhiva",
    "arhivași": "arhiva",
    "arhivat": "arhiva",
    "arhivați": "arhiva",
    "arhivatu": "arhiva",
    "arhivau": "arhiva",
    "arhive": "arhiva",
    "arhivi": "arhiva",
    "arhiva": "arhivă",
    "arhive": "arhivă",
    "arhivei": "arhivă",
    "arhivele": "arhivă",
    "arhivelor": "arhivă",
    "arhivari": "arhivar",
    "arhivarii": "arhivar",
    "arhivarilor": "arhivar",
    "arhivarul": "arhivar",
    "arhivarului": "arhivar",
    "arhivarea": "arhivare",
    "arhivată": "arhivat",
    "arhivate": "arhivat",
    "arhivați": "arhivat",
    "arhivatul": "arhivat",
    "arhivatului": "arhivat",
    "arhiviști": "arhivist",
    "arhiviștii": "arhivist",
    "arhiviștilor": "arhivist",
    "arhivistul": "arhivist",
    "arhivistului": "arhivist",
    "arhivista": "arhivistă",
    "arhiviste": "arhivistă",
    "arhivistei": "arhivistă",
    "arhivistele": "arhivistă",
    "arhivistelor": "arhivistă",
    "ariana": "arian",
    "ariană": "arian",
    "ariani": "arian",
    "arianii": "arian",
    "arianilor": "arian",
    "arianul": "arian",
    "arianului": "arian",
    "ariene": "arian",
    "arienei": "arian",
    "arienele": "arian",
    "arienelor": "arian",
    "arieni": "arian",
    "arienii": "arian",
    "arienilor": "arian",
    "aricii": "arici",
    "aricilor": "arici",
    "ariciul": "arici",
    "ariciului": "arici",
    "aricii-de-mare": "arici-de-mare",
    "aricilor-de-mare": "arici-de-mare",
    "ariciul-de-mare": "arici-de-mare",
    "ariciului-de-mare": "arici-de-mare",
    "arida": "arid",
    "aridă": "arid",
    "aride": "arid",
    "aridei": "arid",
    "aridele": "arid",
    "aridelor": "arid",
    "aridul": "arid",
    "aridului": "arid",
    "arizi": "arid",
    "arizii": "arid",
    "arizilor": "arid",
    "aria": "arie",
    "ariei": "arie",
    "arii": "arie",
    "ariile": "arie",
    "ariilor": "arie",
    "arierata": "arierat",
    "arierată": "arierat",
    "arierate": "arierat",
    "arieratei": "arierat",
    "arieratele": "arierat",
    "arieratelor": "arierat",
    "arierați": "arierat",
    "arierații": "arierat",
    "arieraților": "arierat",
    "arieratul": "arierat",
    "arieratului": "arierat",
    "arierata": "arierată",
    "arierate": "arierată",
    "arieratei": "arierată",
    "arieratele": "arierată",
    "arieratelor": "arierată",
    "arietatea": "arietate",
    "arietăți": "arietate",
    "arietății": "arietate",
    "arietățile": "arietate",
    "arietăților": "arietate",
    "arinoasa": "arinos",
    "arinoasă": "arinos",
    "arinoase": "arinos",
    "arinoasei": "arinos",
    "arinoasele": "arinos",
    "arinoaselor": "arinos",
    "arinoși": "arinos",
    "arinoșii": "arinos",
    "arinoșilor": "arinos",
    "arinosul": "arinos",
    "arinosului": "arinos",
    "aripa": "aripă",
    "aripi": "aripă",
    "aripii": "aripă",
    "aripile": "aripă",
    "aripilor": "aripă",
    "aripata": "aripat",
    "aripată": "aripat",
    "aripate": "aripat",
    "aripatei": "aripat",
    "aripatele": "aripat",
    "aripatelor": "aripat",
    "aripați": "aripat",
    "aripații": "aripat",
    "aripaților": "aripat",
    "aripatul": "aripat",
    "aripatului": "aripat",
    "aripioara": "aripioară",
    "aripioare": "aripioară",
    "aripioarei": "aripioară",
    "aripioarele": "aripioară",
    "aripioarelor": "aripioară",
    "aristocrata": "aristocrat",
    "aristocrată": "aristocrat",
    "aristocrate": "aristocrat",
    "aristocratei": "aristocrat",
    "aristocratele": "aristocrat",
    "aristocratelor": "aristocrat",
    "aristocrați": "aristocrat",
    "aristocrații": "aristocrat",
    "aristocraților": "aristocrat",
    "aristocratul": "aristocrat",
    "aristocratului": "aristocrat",
    "aristocrata": "aristocrată",
    "aristocrate": "aristocrată",
    "aristocratele": "aristocrată",
    "aristocratelor": "aristocrată",
    "aristocratica": "aristocratic",
    "aristocratică": "aristocratic",
    "aristocratice": "aristocratic",
    "aristocraticei": "aristocratic",
    "aristocraticele": "aristocratic",
    "aristocraticelor": "aristocratic",
    "aristocratici": "aristocratic",
    "aristocraticii": "aristocratic",
    "aristocraticilor": "aristocratic",
    "aristocraticul": "aristocratic",
    "aristocraticului": "aristocratic",
    "aristocrația": "aristocrație",
    "aristocrației": "aristocrație",
    "aristocrații": "aristocrație",
    "aristocrațiile": "aristocrație",
    "aristocrațiilor": "aristocrație",
    "aristotelică": "aristotelic",
    "aristotelice": "aristotelic",
    "aristotelici": "aristotelic",
    "aristotelicianul": "aristotelician",
    "aristotelicianului": "aristotelician",
    "aristotelicieni": "aristotelician",
    "aristotelicienii": "aristotelician",
    "aristotelicienilor": "aristotelician",
    "aritmetica": "aritmetic",
    "aritmetică": "aritmetic",
    "aritmetice": "aritmetic",
    "aritmeticei": "aritmetic",
    "aritmeticele": "aritmetic",
    "aritmeticelor": "aritmetic",
    "aritmetici": "aritmetic",
    "aritmeticii": "aritmetic",
    "aritmeticilor": "aritmetic",
    "aritmeticul": "aritmetic",
    "aritmeticului": "aritmetic",
    "aritmetica": "aritmetică",
    "aritmetici": "aritmetică",
    "aritmeticii": "aritmetică",
    "aritmeticile": "aritmetică",
    "aritmeticilor": "aritmetică",
    "aritmeticienii": "aritmetician",
    "aritmica": "aritmic",
    "aritmică": "aritmic",
    "aritmice": "aritmic",
    "aritmicei": "aritmic",
    "aritmicelor": "aritmic",
    "aritmici": "aritmic",
    "aritmicii": "aritmic",
    "aritmicilor": "aritmic",
    "aritmicul": "aritmic",
    "aritmicului": "aritmic",
    "aritmia": "aritmie",
    "aritmiei": "aritmie",
    "aritmii": "aritmie",
    "aritmiile": "aritmie",
    "aritmiilor": "aritmie",
    "arivista": "arivist",
    "arivistă": "arivist",
    "ariviste": "arivist",
    "arivistei": "arivist",
    "arivistele": "arivist",
    "arivistelor": "arivist",
    "ariviști": "arivist",
    "ariviștii": "arivist",
    "ariviștilor": "arivist",
    "arivistul": "arivist",
    "arivistului": "arivist",
    "arivista": "arivistă",
    "ariviste": "arivistă",
    "arivistei": "arivistă",
    "arivistele": "arivistă",
    "arivistelor": "arivistă",
    "arlechini": "arlechin",
    "arlechinii": "arlechin",
    "arlechinilor": "arlechin",
    "arlechinul": "arlechin",
    "arlechinului": "arlechin",
    "armă": "arma",
    "armai": "arma",
    "armam": "arma",
    "armăm": "arma",
    "armând": "arma",
    "armându": "arma",
    "armară": "arma",
    "armarăm": "arma",
    "armarăți": "arma",
    "armase": "arma",
    "armasem": "arma",
    "armaseră": "arma",
    "armaserăm": "arma",
    "armaserăți": "arma",
    "armaseși": "arma",
    "armași": "arma",
    "armat": "arma",
    "armați": "arma",
    "armatu": "arma",
    "armau": "arma",
    "armează": "arma",
    "armez": "arma",
    "armeze": "arma",
    "armezi": "arma",
    "nearmând": "arma",
    "nearmându": "arma",
    "nemaiarmând": "arma",
    "nemaiarmându": "arma",
    "arma": "armă",
    "arme": "armă",
    "armei": "armă",
    "armele": "armă",
    "armelor": "armă",
    "armamente": "armament",
    "armamentele": "armament",
    "armamentul": "armament",
    "armamentului": "armament",
    "armâna": "armân",
    "armână": "armân",
    "armâne": "armân",
    "armânei": "armân",
    "armânele": "armân",
    "armânelor": "armân",
    "armâni": "armân",
    "armânii": "armân",
    "armânilor": "armân",
    "armânul": "armân",
    "armânului": "armân",
    "armarea": "armare",
    "armări": "armare",
    "armării": "armare",
    "armările": "armare",
    "armamentelor": "armaș",
    "armași": "armaș",
    "armașii": "armaș",
    "armașilor": "armaș",
    "armașul": "armaș",
    "armașului": "armaș",
    "armata": "armat",
    "armată": "armat",
    "armate": "armat",
    "armatei": "armat",
    "armatele": "armat",
    "armatelor": "armat",
    "armați": "armat",
    "armații": "armat",
    "armaților": "armat",
    "armatul": "armat",
    "armatului": "armat",
    "armata": "armată",
    "armate": "armată",
    "armatei": "armată",
    "armatele": "armată",
    "armatelor": "armată",
    "armatori": "armator",
    "armatorii": "armator",
    "armatorilor": "armator",
    "armatorul": "armator",
    "armatorului": "armator",
    "armătura": "armătură",
    "armături": "armătură",
    "armăturii": "armătură",
    "armăturile": "armătură",
    "armăturilor": "armătură",
    "armeana": "armean",
    "armeană": "armean",
    "armeanul": "armean",
    "armeanului": "armean",
    "armene": "armean",
    "armenei": "armean",
    "armenele": "armean",
    "armenelor": "armean",
    "armeni": "armean",
    "armenii": "armean",
    "armenilor": "armean",
    "armeneasca": "armenesc",
    "armenească": "armenesc",
    "armenescul": "armenesc",
    "armenescului": "armenesc",
    "armenești": "armenesc",
    "armeneștii": "armenesc",
    "armeneștile": "armenesc",
    "armeneștilor": "armenesc",
    "Armenie": "Armenia",
    "Armeniei": "Armenia",
    "Armenii": "Armenia",
    "armindeni": "arminden",
    "armindenii": "arminden",
    "armindenilor": "arminden",
    "armindenul": "arminden",
    "armindenului": "arminden",
    "armistiții": "armistițiu",
    "armistițiile": "armistițiu",
    "armistițiilor": "armistițiu",
    "armistițiul": "armistițiu",
    "armistițiului": "armistițiu",
    "armonica": "armonic",
    "armonică": "armonic",
    "armonice": "armonic",
    "armonicei": "armonic",
    "armonicele": "armonic",
    "armonicelor": "armonic",
    "armonici": "armonic",
    "armonicii": "armonic",
    "armonicilor": "armonic",
    "armonicul": "armonic",
    "armonicului": "armonic",
    "armonica": "armonică",
    "armonici": "armonică",
    "armonicii": "armonică",
    "armonicile": "armonică",
    "armonicilor": "armonică",
    "armonia": "armonie",
    "armoniei": "armonie",
    "armonii": "armonie",
    "armoniile": "armonie",
    "armoniilor": "armonie",
    "armonioasa": "armonios",
    "armonioasă": "armonios",
    "armonioase": "armonios",
    "armonioasei": "armonios",
    "armonioasele": "armonios",
    "armonioaselor": "armonios",
    "armonioși": "armonios",
    "armonioșii": "armonios",
    "armonioșilor": "armonios",
    "armoniosul": "armonios",
    "armoniosului": "armonios",
    "armoniză": "armoniza",
    "armonizai": "armoniza",
    "armonizam": "armoniza",
    "armonizăm": "armoniza",
    "armonizând": "armoniza",
    "armonizându": "armoniza",
    "armonizară": "armoniza",
    "armonizarăm": "armoniza",
    "armonizarăți": "armoniza",
    "armonizase": "armoniza",
    "armonizasem": "armoniza",
    "armonizaseră": "armoniza",
    "armonizaserăm": "armoniza",
    "armonizaserăți": "armoniza",
    "armonizaseși": "armoniza",
    "armonizași": "armoniza",
    "armonizat": "armoniza",
    "armonizați": "armoniza",
    "armonizatu": "armoniza",
    "armonizau": "armoniza",
    "armonizează": "armoniza",
    "armonizez": "armoniza",
    "armonizeze": "armoniza",
    "armonizezi": "armoniza",
    "nearmonizând": "armoniza",
    "nearmonizându": "armoniza",
    "nemaiarmonizând": "armoniza",
    "nemaiarmonizându": "armoniza",
    "armonizarea": "armonizare",
    "armonizări": "armonizare",
    "armonizării": "armonizare",
    "armonizările": "armonizare",
    "armonizata": "armonizat",
    "armonizată": "armonizat",
    "armonizate": "armonizat",
    "armonizatei": "armonizat",
    "armonizatele": "armonizat",
    "armonizatelor": "armonizat",
    "armonizați": "armonizat",
    "armonizații": "armonizat",
    "armonizaților": "armonizat",
    "armonizatul": "armonizat",
    "armonizatului": "armonizat",
    "armura": "armură",
    "armuri": "armură",
    "armurii": "armură",
    "armurile": "armură",
    "armurilor": "armură",
    "armurieri": "armurier",
    "armurierii": "armurier",
    "armurierilor": "armurier",
    "armurierul": "armurier",
    "armurierului": "armurier",
    "arnăuți": "arnăut",
    "arnăuții": "arnăut",
    "arnăuților": "arnăut",
    "arnăutul": "arnăut",
    "arnăutului": "arnăut",
    "arnăuțeasca": "arnăuțesc",
    "arnăuțească": "arnăuțesc",
    "arnăuțescul": "arnăuțesc",
    "arnăuțescului": "arnăuțesc",
    "arnăuțești": "arnăuțesc",
    "arnăuțeștii": "arnăuțesc",
    "arnăuțeștile": "arnăuțesc",
    "arnăuțeștilor": "arnăuțesc",
    "arog": "aroga",
    "arogă": "aroga",
    "arogai": "aroga",
    "arogam": "aroga",
    "arogăm": "aroga",
    "arogând": "aroga",
    "arogându": "aroga",
    "arogară": "aroga",
    "arogarăm": "aroga",
    "arogarăți": "aroga",
    "arogase": "aroga",
    "arogasem": "aroga",
    "arogaseră": "aroga",
    "arogaserăm": "aroga",
    "arogaserăți": "aroga",
    "arogaseși": "aroga",
    "arogași": "aroga",
    "arogat": "aroga",
    "arogați": "aroga",
    "arogatu": "aroga",
    "arogau": "aroga",
    "aroge": "aroga",
    "arogi": "aroga",
    "nearogând": "aroga",
    "nearogându": "aroga",
    "nemaiarogând": "aroga",
    "nemaiarogându": "aroga",
    "aroganta": "arogant",
    "arogantă": "arogant",
    "arogante": "arogant",
    "arogantei": "arogant",
    "arogantele": "arogant",
    "arogantelor": "arogant",
    "aroganți": "arogant",
    "aroganții": "arogant",
    "aroganților": "arogant",
    "arogantul": "arogant",
    "arogantului": "arogant",
    "aroganța": "aroganță",
    "aroganțe": "aroganță",
    "aroganței": "aroganță",
    "aroganțele": "aroganță",
    "aroganțelor": "aroganță",
    "arogarea": "arogare",
    "arogări": "arogare",
    "arogării": "arogare",
    "arogările": "arogare",
    "arogata": "arogat",
    "arogată": "arogat",
    "arogate": "arogat",
    "arogatei": "arogat",
    "arogatele": "arogat",
    "arogatelor": "arogat",
    "arogați": "arogat",
    "arogații": "arogat",
    "arogaților": "arogat",
    "arogatul": "arogat",
    "arogatului": "arogat",
    "aroma": "aromă",
    "arome": "aromă",
    "aromei": "aromă",
    "aromele": "aromă",
    "aromelor": "aromă",
    "aromâna": "aromân",
    "aromână": "aromân",
    "aromâne": "aromân",
    "aromânei": "aromân",
    "aromânele": "aromân",
    "aromânelor": "aromân",
    "aromâni": "aromân",
    "aromânii": "aromân",
    "aromânilor": "aromân",
    "aromânul": "aromân",
    "aromânului": "aromân",
    "aromânca": "aromâncă",
    "aromânce": "aromâncă",
    "aromâncei": "aromâncă",
    "aromâncele": "aromâncă",
    "aromâncelor": "aromâncă",
    "aromata": "aromat",
    "aromată": "aromat",
    "aromate": "aromat",
    "aromatei": "aromat",
    "aromatele": "aromat",
    "aromatelor": "aromat",
    "aromați": "aromat",
    "aromații": "aromat",
    "aromaților": "aromat",
    "aromatul": "aromat",
    "aromatului": "aromat",
    "aromatica": "aromatic",
    "aromatică": "aromatic",
    "aromatice": "aromatic",
    "aromaticei": "aromatic",
    "aromaticele": "aromatic",
    "aromaticelor": "aromatic",
    "aromatici": "aromatic",
    "aromaticii": "aromatic",
    "aromaticilor": "aromatic",
    "aromaticul": "aromatic",
    "aromaticului": "aromatic",
    "aromatizata": "aromatizat",
    "aromatizată": "aromatizat",
    "aromatizate": "aromatizat",
    "aromatizatei": "aromatizat",
    "aromatizatele": "aromatizat",
    "aromatizatelor": "aromatizat",
    "aromatizați": "aromatizat",
    "aromatizații": "aromatizat",
    "aromatizaților": "aromatizat",
    "aromatizatul": "aromatizat",
    "aromatizatului": "aromatizat",
    "aromeala": "aromeală",
    "aromeli": "aromeală",
    "aromelii": "aromeală",
    "aromelile": "aromeală",
    "arondarea": "arondare",
    "arondări": "arondare",
    "arondării": "arondare",
    "arondările": "arondare",
    "arondărilor": "arondare",
    "arondată": "arondat",
    "arondate": "arondat",
    "arondați": "arondat",
    "arpagicul": "arpagic",
    "arpagicului": "arpagic",
    "arsa": "ars",
    "arsă": "ars",
    "arse": "ars",
    "arsei": "ars",
    "arsele": "ars",
    "arselor": "ars",
    "arși": "ars",
    "arșii": "ars",
    "arșilor": "ars",
    "arsul": "ars",
    "arsului": "ars",
    "arsenale": "arsenal",
    "arsenalele": "arsenal",
    "arsenalelor": "arsenal",
    "arsenalul": "arsenal",
    "arsenalului": "arsenal",
    "arsenice": "arsenic",
    "arsenicele": "arsenic",
    "arsenicelor": "arsenic",
    "arsenici": "arsenic",
    "arsenicii": "arsenic",
    "arsenicilor": "arsenic",
    "arsenicul": "arsenic",
    "arsenicului": "arsenic",
    "arsenicala": "arsenical",
    "arsenicală": "arsenical",
    "arsenicale": "arsenical",
    "arsenicalei": "arsenical",
    "arsenicalele": "arsenical",
    "arsenicalelor": "arsenical",
    "arsenicali": "arsenical",
    "arsenicalii": "arsenical",
    "arsenicalilor": "arsenical",
    "arsenicalul": "arsenical",
    "arsenicalului": "arsenical",
    "arsenioși": "arsenios",
    "arsenioșii": "arsenios",
    "arsenioșilor": "arsenios",
    "arseniosul": "arsenios",
    "arseniosului": "arsenios",
    "arșice": "arșic",
    "arșicele": "arșic",
    "arșicelor": "arșic",
    "arșicul": "arșic",
    "arșicului": "arșic",
    "arșini": "arșin",
    "arșinii": "arșin",
    "arșinilor": "arșin",
    "arșinul": "arșin",
    "arșinului": "arșin",
    "arșița": "arșiță",
    "arșițe": "arșiță",
    "arșiței": "arșiță",
    "arșițele": "arșiță",
    "arșițelor": "arșiță",
    "arsura": "arsură",
    "arsuri": "arsură",
    "arsurii": "arsură",
    "arsurile": "arsură",
    "arsurilor": "arsură",
    "arta": "artă",
    "arte": "artă",
    "artei": "artă",
    "artele": "artă",
    "artelor": "artă",
    "arțagul": "arțag",
    "arțagului": "arțag",
    "arțaguri": "arțag",
    "arțagurile": "arțag",
    "arțagurilor": "arțag",
    "arțăgoasa": "arțăgos",
    "arțăgoasă": "arțăgos",
    "arțăgoase": "arțăgos",
    "arțăgoasei": "arțăgos",
    "arțăgoasele": "arțăgos",
    "arțăgoaselor": "arțăgos",
    "arțăgoși": "arțăgos",
    "arțăgoșii": "arțăgos",
    "arțăgoșilor": "arțăgos",
    "arțăgosul": "arțăgos",
    "arțăgosului": "arțăgos",
    "artera": "arteră",
    "artere": "arteră",
    "arterei": "arteră",
    "arterele": "arteră",
    "arterelor": "arteră",
    "arteriala": "arterial",
    "arterială": "arterial",
    "arteriale": "arterial",
    "arterialei": "arterial",
    "arterialele": "arterial",
    "arterialelor": "arterial",
    "arteriali": "arterial",
    "arterialii": "arterial",
    "arterialilor": "arterial",
    "arterialul": "arterial",
    "arterialului": "arterial",
    "arteriola": "arteriolă",
    "arteriole": "arteriolă",
    "arteriolei": "arteriolă",
    "arteriolele": "arteriolă",
    "arteriolelor": "arteriolă",
    "arterioscleroza": "arterioscleroză",
    "arterioscleroze": "arterioscleroză",
    "arteriosclerozei": "arterioscleroză",
    "arteriosclerozele": "arterioscleroză",
    "arteriosclerozelor": "arterioscleroză",
    "arterita": "arterită",
    "arterite": "arterită",
    "arteritei": "arterită",
    "arteritele": "arterită",
    "arteritelor": "arterită",
    "arteziana": "artezian",
    "arteziană": "artezian",
    "artezianul": "artezian",
    "artezianului": "artezian",
    "arteziene": "artezian",
    "artezienei": "artezian",
    "artezienele": "artezian",
    "artezienelor": "artezian",
    "artezieni": "artezian",
    "artezienii": "artezian",
    "artezienilor": "artezian",
    "art.": "articol",
    "articole": "articol",
    "articolele": "articol",
    "articolelor": "articol",
    "articolul": "articol",
    "articolului": "articol",
    "articulă": "articula",
    "articulai": "articula",
    "articulam": "articula",
    "articulăm": "articula",
    "articulând": "articula",
    "articulându": "articula",
    "articulară": "articula",
    "articularăm": "articula",
    "articularăți": "articula",
    "articulase": "articula",
    "articulasem": "articula",
    "articulaseră": "articula",
    "articulaserăm": "articula",
    "articulaserăți": "articula",
    "articulaseși": "articula",
    "articulași": "articula",
    "articulat": "articula",
    "articulați": "articula",
    "articulatu": "articula",
    "articulau": "articula",
    "articulează": "articula",
    "articulez": "articula",
    "articuleze": "articula",
    "articulezi": "articula",
    "nearticulând": "articula",
    "nearticulându": "articula",
    "nemaiarticulând": "articula",
    "nemaiarticulându": "articula",
    "articulara": "articular",
    "articulară": "articular",
    "articulare": "articular",
    "articularei": "articular",
    "articularele": "articular",
    "articularelor": "articular",
    "articulari": "articular",
    "articularii": "articular",
    "articularilor": "articular",
    "articularul": "articular",
    "articularului": "articular",
    "articularea": "articulare",
    "articulări": "articulare",
    "articulării": "articulare",
    "articulările": "articulare",
    "articulata": "articulat",
    "articulată": "articulat",
    "articulate": "articulat",
    "articulatei": "articulat",
    "articulatele": "articulat",
    "articulatelor": "articulat",
    "articulați": "articulat",
    "articulații": "articulat",
    "articulaților": "articulat",
    "articulatul": "articulat",
    "articulatului": "articulat",
    "articulația": "articulație",
    "articulației": "articulație",
    "articulații": "articulație",
    "articulațiile": "articulație",
    "articulațiilor": "articulație",
    "artificiala": "artificial",
    "artificială": "artificial",
    "artificiale": "artificial",
    "artificialei": "artificial",
    "artificialele": "artificial",
    "artificialelor": "artificial",
    "artificiali": "artificial",
    "artificialii": "artificial",
    "artificialilor": "artificial",
    "artificialul": "artificial",
    "artificialului": "artificial",
    "artificieri": "artificier",
    "artificierii": "artificier",
    "artificierilor": "artificier",
    "artificierul": "artificier",
    "artificierului": "artificier",
    "artificioasa": "artificios",
    "artificioasă": "artificios",
    "artificioase": "artificios",
    "artificioasei": "artificios",
    "artificioasele": "artificios",
    "artificioaselor": "artificios",
    "artificioși": "artificios",
    "artificioșii": "artificios",
    "artificioșilor": "artificios",
    "artificiosul": "artificios",
    "artificiosului": "artificios",
    "artificii": "artificiu",
    "artificiile": "artificiu",
    "artificiilor": "artificiu",
    "artificiul": "artificiu",
    "artificiului": "artificiu",
    "artileria": "artilerie",
    "artileriei": "artilerie",
    "artilerii": "artilerie",
    "artileriile": "artilerie",
    "artileriilor": "artilerie",
    "artileriști": "artilerist",
    "artileriștii": "artilerist",
    "artileriștilor": "artilerist",
    "artileristul": "artilerist",
    "artileristului": "artilerist",
    "artilerista": "artileristă",
    "artileriste": "artileristă",
    "artileristei": "artileristă",
    "artileristele": "artileristă",
    "artileristelor": "artileristă",
    "artiști": "artist",
    "artiștii": "artist",
    "artiștilor": "artist",
    "artistul": "artist",
    "artistului": "artist",
    "artista": "artistă",
    "artiste": "artistă",
    "artistei": "artistă",
    "artistele": "artistă",
    "artistelor": "artistă",
    "artistica": "artistic",
    "artistică": "artistic",
    "artistice": "artistic",
    "artisticei": "artistic",
    "artisticele": "artistic",
    "artisticelor": "artistic",
    "artistici": "artistic",
    "artisticii": "artistic",
    "artisticilor": "artistic",
    "artisticul": "artistic",
    "artisticului": "artistic",
    "artizani": "artizan",
    "artizanii": "artizan",
    "artizanilor": "artizan",
    "artizanul": "artizan",
    "artizanului": "artizan",
    "artizanate": "artizanat",
    "artizanatele": "artizanat",
    "artizanatelor": "artizanat",
    "artizanatul": "artizanat",
    "artizanatului": "artizanat",
    "artrita": "artrită",
    "artrite": "artrită",
    "artritei": "artrită",
    "artritele": "artrită",
    "artritelor": "artrită",
    "artritica": "artritic",
    "artritică": "artritic",
    "artritice": "artritic",
    "artriticei": "artritic",
    "artriticele": "artritic",
    "artriticelor": "artritic",
    "artritici": "artritic",
    "artriticii": "artritic",
    "artriticilor": "artritic",
    "artriticul": "artritic",
    "artriticului": "artritic",
    "artroza": "artroză",
    "artroze": "artroză",
    "artrozei": "artroză",
    "artrozele": "artroză",
    "artrozelor": "artroză",
    "arunc": "arunca",
    "aruncă": "arunca",
    "aruncai": "arunca",
    "aruncam": "arunca",
    "aruncăm": "arunca",
    "aruncând": "arunca",
    "aruncându": "arunca",
    "aruncară": "arunca",
    "aruncarăm": "arunca",
    "aruncarăți": "arunca",
    "aruncase": "arunca",
    "aruncasem": "arunca",
    "aruncaseră": "arunca",
    "aruncaserăm": "arunca",
    "aruncaserăți": "arunca",
    "aruncaseși": "arunca",
    "aruncași": "arunca",
    "aruncat": "arunca",
    "aruncați": "arunca",
    "aruncatu": "arunca",
    "aruncau": "arunca",
    "arunce": "arunca",
    "arunci": "arunca",
    "nearuncând": "arunca",
    "nearuncându": "arunca",
    "nemaiaruncând": "arunca",
    "nemaiaruncându": "arunca",
    "aruncarea": "aruncare",
    "aruncări": "aruncare",
    "aruncării": "aruncare",
    "aruncările": "aruncare",
    "aruncata": "aruncat",
    "aruncată": "aruncat",
    "aruncate": "aruncat",
    "aruncatei": "aruncat",
    "aruncatele": "aruncat",
    "aruncatelor": "aruncat",
    "aruncați": "aruncat",
    "aruncații": "aruncat",
    "aruncaților": "aruncat",
    "aruncatul": "aruncat",
    "aruncatului": "aruncat",
    "aruncătoare": "aruncător",
    "aruncătoarele": "aruncător",
    "aruncătoarelor": "aruncător",
    "aruncătorul": "aruncător",
    "aruncătorului": "aruncător",
    "aruncătura": "aruncătură",
    "aruncături": "aruncătură",
    "aruncăturii": "aruncătură",
    "aruncăturile": "aruncătură",
    "aruncăturilor": "aruncătură",
    "arvanita": "arvanit",
    "arvanită": "arvanit",
    "arvanite": "arvanit",
    "arvanitei": "arvanit",
    "arvanitele": "arvanit",
    "arvanitelor": "arvanit",
    "arvaniți": "arvanit",
    "arvaniții": "arvanit",
    "arvaniților": "arvanit",
    "arvanitul": "arvanit",
    "arvanitului": "arvanit",
    "arvuna": "arvună",
    "arvune": "arvună",
    "arvunei": "arvună",
    "arvunele": "arvună",
    "arvunelor": "arvună",
    "arzătoare": "arzător",
    "arzătoarea": "arzător",
    "arzătoarei": "arzător",
    "arzătoarele": "arzător",
    "arzătoarelor": "arzător",
    "arzători": "arzător",
    "arzătorii": "arzător",
    "arzătorilor": "arzător",
    "arzătorul": "arzător",
    "arzătorului": "arzător",
    "ași": "as",
    "așii": "as",
    "așilor": "as",
    "asul": "as",
    "asului": "as",
    "așa-": "așa",
    "asaltul": "asalt",
    "asaltului": "asalt",
    "asalturi": "asalt",
    "asalturile": "asalt",
    "asalturilor": "asalt",
    "asaltă": "asalta",
    "asaltai": "asalta",
    "asaltam": "asalta",
    "asaltăm": "asalta",
    "asaltând": "asalta",
    "asaltându": "asalta",
    "asaltară": "asalta",
    "asaltarăm": "asalta",
    "asaltarăți": "asalta",
    "asaltase": "asalta",
    "asaltasem": "asalta",
    "asaltaseră": "asalta",
    "asaltaserăm": "asalta",
    "asaltaserăți": "asalta",
    "asaltaseși": "asalta",
    "asaltași": "asalta",
    "asaltat": "asalta",
    "asaltați": "asalta",
    "asaltatu": "asalta",
    "asaltau": "asalta",
    "asaltează": "asalta",
    "asaltez": "asalta",
    "asalteze": "asalta",
    "asaltezi": "asalta",
    "neasaltând": "asalta",
    "neasaltându": "asalta",
    "nemaiasaltând": "asalta",
    "nemaiasaltându": "asalta",
    "asaltarea": "asaltare",
    "asaltări": "asaltare",
    "asaltării": "asaltare",
    "asaltările": "asaltare",
    "asaltata": "asaltat",
    "asaltată": "asaltat",
    "asaltate": "asaltat",
    "asaltatei": "asaltat",
    "asaltatele": "asaltat",
    "asaltatelor": "asaltat",
    "asaltați": "asaltat",
    "asaltații": "asaltat",
    "asaltaților": "asaltat",
    "asaltatul": "asaltat",
    "asaltatului": "asaltat",
    "asamblă": "asambla",
    "asamblai": "asambla",
    "asamblam": "asambla",
    "asamblăm": "asambla",
    "asamblând": "asambla",
    "asamblându": "asambla",
    "asamblară": "asambla",
    "asamblarăm": "asambla",
    "asamblarăți": "asambla",
    "asamblase": "asambla",
    "asamblasem": "asambla",
    "asamblaseră": "asambla",
    "asamblaserăm": "asambla",
    "asamblaserăți": "asambla",
    "asamblaseși": "asambla",
    "asamblași": "asambla",
    "asamblat": "asambla",
    "asamblați": "asambla",
    "asamblatu": "asambla",
    "asamblau": "asambla",
    "asamblează": "asambla",
    "asamblez": "asambla",
    "asambleze": "asambla",
    "asamblezi": "asambla",
    "neasamblând": "asambla",
    "neasamblându": "asambla",
    "nemaiasamblând": "asambla",
    "nemaiasamblându": "asambla",
    "asamblarea": "asamblare",
    "asamblări": "asamblare",
    "asamblării": "asamblare",
    "asamblările": "asamblare",
    "asamblata": "asamblat",
    "asamblată": "asamblat",
    "asamblate": "asamblat",
    "asamblatei": "asamblat",
    "asamblatele": "asamblat",
    "asamblatelor": "asamblat",
    "asamblați": "asamblat",
    "asamblații": "asamblat",
    "asamblaților": "asamblat",
    "asamblatul": "asamblat",
    "asamblatului": "asamblat",
    "asană": "asana",
    "asanai": "asana",
    "asanam": "asana",
    "asanăm": "asana",
    "asanând": "asana",
    "asanându": "asana",
    "asanară": "asana",
    "asanarăm": "asana",
    "asanarăți": "asana",
    "asanase": "asana",
    "asanasem": "asana",
    "asanaseră": "asana",
    "asanaserăm": "asana",
    "asanaserăți": "asana",
    "asanaseși": "asana",
    "asanași": "asana",
    "asanat": "asana",
    "asanați": "asana",
    "asanatu": "asana",
    "asanau": "asana",
    "asanează": "asana",
    "asanez": "asana",
    "asaneze": "asana",
    "asanezi": "asana",
    "neasanând": "asana",
    "neasanându": "asana",
    "nemaiasanând": "asana",
    "nemaiasanându": "asana",
    "asana": "asană",
    "asane": "asană",
    "asanei": "asană",
    "asanele": "asană",
    "asanelor": "asană",
    "asanarea": "asanare",
    "asanări": "asanare",
    "asanării": "asanare",
    "asanările": "asanare",
    "asanata": "asanat",
    "asanată": "asanat",
    "asanate": "asanat",
    "asanatei": "asanat",
    "asanatele": "asanat",
    "asanatelor": "asanat",
    "asanați": "asanat",
    "asanații": "asanat",
    "asanaților": "asanat",
    "asanatul": "asanat",
    "asanatului": "asanat",
    "așa-numita": "așa-numit",
    "așa-numită": "așa-numit",
    "așa-numite": "așa-numit",
    "așa-numitei": "așa-numit",
    "așa-numitele": "așa-numit",
    "așa-numitelor": "așa-numit",
    "așa-numiți": "așa-numit",
    "așa-numiții": "așa-numit",
    "așa-numiților": "așa-numit",
    "așa-numitul": "așa-numit",
    "așa-numitului": "așa-numit",
    "asasini": "asasin",
    "asasinii": "asasin",
    "asasinilor": "asasin",
    "asasinul": "asasin",
    "asasinului": "asasin",
    "asasină": "asasina",
    "asasinai": "asasina",
    "asasinam": "asasina",
    "asasinăm": "asasina",
    "asasinând": "asasina",
    "asasinându": "asasina",
    "asasinară": "asasina",
    "asasinarăm": "asasina",
    "asasinarăți": "asasina",
    "asasinase": "asasina",
    "asasinasem": "asasina",
    "asasinaseră": "asasina",
    "asasinaserăm": "asasina",
    "asasinaserăți": "asasina",
    "asasinaseși": "asasina",
    "asasinași": "asasina",
    "asasinat": "asasina",
    "asasinați": "asasina",
    "asasinatu": "asasina",
    "asasinau": "asasina",
    "asasinează": "asasina",
    "asasinez": "asasina",
    "asasineze": "asasina",
    "asasinezi": "asasina",
    "neasasinând": "asasina",
    "neasasinându": "asasina",
    "nemaiasasinând": "asasina",
    "nemaiasasinându": "asasina",
    "asasina": "asasină",
    "asasine": "asasină",
    "asasinei": "asasină",
    "asasinele": "asasină",
    "asasinelor": "asasină",
    "asasinarea": "asasinare",
    "asasinări": "asasinare",
    "asasinării": "asasinare",
    "asasinările": "asasinare",
    "asasinata": "asasinat",
    "asasinată": "asasinat",
    "asasinate": "asasinat",
    "asasinatei": "asasinat",
    "asasinatele": "asasinat",
    "asasinatelor": "asasinat",
    "asasinați": "asasinat",
    "asasinații": "asasinat",
    "asasinaților": "asasinat",
    "asasinatul": "asasinat",
    "asasinatului": "asasinat",
    "așa-zisa": "așa-zis",
    "așa-zisă": "așa-zis",
    "așa-zise": "așa-zis",
    "așa-zisei": "așa-zis",
    "așa-zisele": "așa-zis",
    "așa-ziselor": "așa-zis",
    "așa-ziși": "așa-zis",
    "așa-zișii": "așa-zis",
    "așa-zișilor": "așa-zis",
    "așa-zisul": "așa-zis",
    "așa-zisului": "așa-zis",
    "ascendenta": "ascendent",
    "ascendentă": "ascendent",
    "ascendente": "ascendent",
    "ascendentei": "ascendent",
    "ascendentele": "ascendent",
    "ascendentelor": "ascendent",
    "ascendenți": "ascendent",
    "ascendenții": "ascendent",
    "ascendenților": "ascendent",
    "ascendentul": "ascendent",
    "ascendentului": "ascendent",
    "ascendența": "ascendență",
    "ascendențe": "ascendență",
    "ascendenței": "ascendență",
    "ascendențele": "ascendență",
    "ascendențelor": "ascendență",
    "ascensionala": "ascensional",
    "ascensională": "ascensional",
    "ascensionale": "ascensional",
    "ascensionalei": "ascensional",
    "ascensionalele": "ascensional",
    "ascensionalelor": "ascensional",
    "ascensionali": "ascensional",
    "ascensionalii": "ascensional",
    "ascensionalilor": "ascensional",
    "ascensionalul": "ascensional",
    "ascensionalului": "ascensional",
    "ascensiunea": "ascensiune",
    "ascensiuni": "ascensiune",
    "ascensiunii": "ascensiune",
    "ascensiunile": "ascensiune",
    "ascensiunilor": "ascensiune",
    "ascensoare": "ascensor",
    "ascensoarele": "ascensor",
    "ascensoarelor": "ascensor",
    "ascensorul": "ascensor",
    "ascensorului": "ascensor",
    "asceți": "ascet",
    "asceții": "ascet",
    "asceților": "ascet",
    "ascetul": "ascet",
    "ascetului": "ascet",
    "asceta": "ascetă",
    "ascete": "ascetă",
    "ascetei": "ascetă",
    "ascetele": "ascetă",
    "ascetelor": "ascetă",
    "ascetica": "ascetic",
    "ascetică": "ascetic",
    "ascetice": "ascetic",
    "asceticei": "ascetic",
    "asceticele": "ascetic",
    "asceticelor": "ascetic",
    "ascetici": "ascetic",
    "asceticii": "ascetic",
    "asceticilor": "ascetic",
    "asceticul": "ascetic",
    "asceticului": "ascetic",
    "ascetisme": "ascetism",
    "ascetismele": "ascetism",
    "ascetismelor": "ascetism",
    "ascetismul": "ascetism",
    "ascetismului": "ascetism",
    "asceza": "asceză",
    "asceze": "asceză",
    "ascezei": "asceză",
    "ascezele": "asceză",
    "ascezelor": "asceză",
    "așchia": "așchie",
    "așchiei": "așchie",
    "așchii": "așchie",
    "așchiile": "așchie",
    "așchiilor": "așchie",
    "așchioasa": "așchios",
    "așchioasă": "așchios",
    "așchioase": "așchios",
    "așchioasei": "așchios",
    "așchioasele": "așchios",
    "așchioaselor": "așchios",
    "așchioși": "așchios",
    "așchioșii": "așchios",
    "așchioșilor": "așchios",
    "așchiosul": "așchios",
    "așchiosului": "așchios",
    "asclepiade": "asclepiad",
    "asclepiadele": "asclepiad",
    "asclepiadelor": "asclepiad",
    "asclepiadul": "asclepiad",
    "asclepiadului": "asclepiad",
    "asclepiazi": "asclepiad",
    "Asclepiazii": "Asclepiad",
    "asclepiazilor": "asclepiad",
    "ascult": "asculta",
    "ascultă": "asculta",
    "ascultai": "asculta",
    "ascultam": "asculta",
    "ascultăm": "asculta",
    "ascultând": "asculta",
    "ascultându": "asculta",
    "ascultară": "asculta",
    "ascultarăm": "asculta",
    "ascultarăți": "asculta",
    "ascultase": "asculta",
    "ascultasem": "asculta",
    "ascultaseră": "asculta",
    "ascultaserăm": "asculta",
    "ascultaserăți": "asculta",
    "ascultaseși": "asculta",
    "ascultași": "asculta",
    "ascultat": "asculta",
    "ascultați": "asculta",
    "ascultatu": "asculta",
    "ascultau": "asculta",
    "asculte": "asculta",
    "asculți": "asculta",
    "neascultând": "asculta",
    "neascultându": "asculta",
    "nemaiascultând": "asculta",
    "nemaiascultându": "asculta",
    "ascultarea": "ascultare",
    "ascultări": "ascultare",
    "ascultării": "ascultare",
    "ascultările": "ascultare",
    "ascultata": "ascultat",
    "ascultată": "ascultat",
    "ascultate": "ascultat",
    "ascultatei": "ascultat",
    "ascultatele": "ascultat",
    "ascultatelor": "ascultat",
    "ascultați": "ascultat",
    "ascultații": "ascultat",
    "ascultaților": "ascultat",
    "ascultatul": "ascultat",
    "ascultatului": "ascultat",
    "ascultătoarea": "ascultătoare",
    "ascultătoarei": "ascultătoare",
    "ascultătoarele": "ascultătoare",
    "ascultătoarelor": "ascultătoare",
    "ascultătoare": "ascultător",
    "ascultătoarea": "ascultător",
    "ascultătoarei": "ascultător",
    "ascultătoarele": "ascultător",
    "ascultătoarelor": "ascultător",
    "ascultători": "ascultător",
    "ascultătorii": "ascultător",
    "ascultătorilor": "ascultător",
    "ascultătorul": "ascultător",
    "ascultătorului": "ascultător",
    "ascund": "ascunde",
    "ascundă": "ascunde",
    "ascundea": "ascunde",
    "ascundeai": "ascunde",
    "ascundeam": "ascunde",
    "ascundeați": "ascunde",
    "ascundeau": "ascunde",
    "ascundem": "ascunde",
    "ascundeți": "ascunde",
    "ascuns": "ascunde",
    "ascunse": "ascunde",
    "ascunsei": "ascunde",
    "ascunseră": "ascunde",
    "ascunserăm": "ascunde",
    "ascunserăți": "ascunde",
    "ascunsese": "ascunde",
    "ascunsesem": "ascunde",
    "ascunseseră": "ascunde",
    "ascunseserăm": "ascunde",
    "ascunseserăți": "ascunde",
    "ascunseseși": "ascunde",
    "ascunseși": "ascunde",
    "ascunsu": "ascunde",
    "ascunzând": "ascunde",
    "ascunzându": "ascunde",
    "ascunzi": "ascunde",
    "neascunzând": "ascunde",
    "neascunzându": "ascunde",
    "nemaiascunzând": "ascunde",
    "nemaiascunzându": "ascunde",
    "ascunderea": "ascundere",
    "ascunderi": "ascundere",
    "ascunderii": "ascundere",
    "ascunderile": "ascundere",
    "ascunsa": "ascuns",
    "ascunsă": "ascuns",
    "ascunse": "ascuns",
    "ascunsei": "ascuns",
    "ascunsele": "ascuns",
    "ascunselor": "ascuns",
    "ascunși": "ascuns",
    "ascunșii": "ascuns",
    "ascunșilor": "ascuns",
    "ascunsul": "ascuns",
    "ascunsului": "ascuns",
    "ascunzătoarea": "ascunzătoare",
    "ascunzătoarei": "ascunzătoare",
    "ascunzători": "ascunzătoare",
    "ascunzătorile": "ascunzătoare",
    "ascunzătorilor": "ascunzătoare",
    "ascunzișul": "ascunziș",
    "ascunzișului": "ascunziș",
    "ascunzișuri": "ascunziș",
    "ascunzișurile": "ascunziș",
    "ascunzișurilor": "ascunziș",
    "ascut": "ascuți",
    "ascută": "ascuți",
    "ascute": "ascuți",
    "ascuțea": "ascuți",
    "ascuțeai": "ascuți",
    "ascuțeam": "ascuți",
    "ascuțeați": "ascuți",
    "ascuțeau": "ascuți",
    "ascuții": "ascuți",
    "ascuțim": "ascuți",
    "ascuțind": "ascuți",
    "ascuțindu": "ascuți",
    "ascuțiră": "ascuți",
    "ascuțirăm": "ascuți",
    "ascuțirăți": "ascuți",
    "ascuțise": "ascuți",
    "ascuțisem": "ascuți",
    "ascuțiseră": "ascuți",
    "ascuțiserăm": "ascuți",
    "ascuțiserăți": "ascuți",
    "ascuțiseși": "ascuți",
    "ascuțiși": "ascuți",
    "ascuțit": "ascuți",
    "ascuțiți": "ascuți",
    "ascuțitu": "ascuți",
    "neascuțind": "ascuți",
    "neascuțindu": "ascuți",
    "nemaiascuțind": "ascuți",
    "nemaiascuțindu": "ascuți",
    "ascuțimea": "ascuțime",
    "ascuțimi": "ascuțime",
    "ascuțimii": "ascuțime",
    "ascuțimile": "ascuțime",
    "ascuțimilor": "ascuțime",
    "ascuțirea": "ascuțire",
    "ascuțiri": "ascuțire",
    "ascuțirii": "ascuțire",
    "ascuțirile": "ascuțire",
    "ascunși": "ascuțit",
    "ascuțita": "ascuțit",
    "ascuțită": "ascuțit",
    "ascuțite": "ascuțit",
    "ascuțitei": "ascuțit",
    "ascuțitele": "ascuțit",
    "ascuțitelor": "ascuțit",
    "ascuțiți": "ascuțit",
    "ascuțiții": "ascuțit",
    "ascuțiților": "ascuțit",
    "ascuțitul": "ascuțit",
    "ascuțitului": "ascuțit",
    "ascuțitoarea": "ascuțitoare",
    "ascuțitoarei": "ascuțitoare",
    "ascuțitori": "ascuțitoare",
    "ascuțitorile": "ascuțitoare",
    "ascuțitorilor": "ascuțitoare",
    "ascuțitori": "ascuțitor",
    "ascuțitorii": "ascuțitor",
    "ascuțitorilor": "ascuțitor",
    "ascuțitorul": "ascuțitor",
    "ascuțitorului": "ascuțitor",
    "asediai": "asedia",
    "asediam": "asedia",
    "asediară": "asedia",
    "asediarăm": "asedia",
    "asediarăți": "asedia",
    "asediase": "asedia",
    "asediasem": "asedia",
    "asediaseră": "asedia",
    "asediaserăm": "asedia",
    "asediaserăți": "asedia",
    "asediaseși": "asedia",
    "asediași": "asedia",
    "asediat": "asedia",
    "asediați": "asedia",
    "asediatu": "asedia",
    "asediau": "asedia",
    "asediază": "asedia",
    "asedie": "asedia",
    "asediem": "asedia",
    "asediez": "asedia",
    "asedieze": "asedia",
    "asediezi": "asedia",
    "asediind": "asedia",
    "asediindu": "asedia",
    "neasediind": "asedia",
    "neasediindu": "asedia",
    "nemaiasediind": "asedia",
    "nemaiasediindu": "asedia",
    "asediata": "asediat",
    "asediată": "asediat",
    "asediate": "asediat",
    "asediatei": "asediat",
    "asediatele": "asediat",
    "asediatelor": "asediat",
    "asediați": "asediat",
    "asediații": "asediat",
    "asediaților": "asediat",
    "asediatul": "asediat",
    "asediatului": "asediat",
    "asedierea": "asediere",
    "asedieri": "asediere",
    "asedierii": "asediere",
    "asedierile": "asediere",
    "asedii": "asediu",
    "asediile": "asediu",
    "asediilor": "asediu",
    "asediul": "asediu",
    "asediului": "asediu",
    "aseleniză": "aseleniza",
    "aselenizai": "aseleniza",
    "aselenizam": "aseleniza",
    "aselenizăm": "aseleniza",
    "aselenizând": "aseleniza",
    "aselenizară": "aseleniza",
    "aselenizarăm": "aseleniza",
    "aselenizarăți": "aseleniza",
    "aselenizase": "aseleniza",
    "aselenizasem": "aseleniza",
    "aselenizaseră": "aseleniza",
    "aselenizaserăm": "aseleniza",
    "aselenizaserăți": "aseleniza",
    "aselenizaseși": "aseleniza",
    "aselenizași": "aseleniza",
    "aselenizat": "aseleniza",
    "aselenizați": "aseleniza",
    "aselenizau": "aseleniza",
    "aselenizează": "aseleniza",
    "aselenizeze": "aseleniza",
    "aselenizezi": "aseleniza",
    "neaselenizând": "aseleniza",
    "nemaiaselenizând": "aseleniza",
    "aselenizarea": "aselenizare",
    "aselenizări": "aselenizare",
    "aselenizării": "aselenizare",
    "aselenizările": "aselenizare",
    "aselenizata": "aselenizat",
    "aselenizată": "aselenizat",
    "aselenizate": "aselenizat",
    "aselenizatei": "aselenizat",
    "aselenizatele": "aselenizat",
    "aselenizatelor": "aselenizat",
    "aselenizați": "aselenizat",
    "aselenizații": "aselenizat",
    "aselenizaților": "aselenizat",
    "aselenizatul": "aselenizat",
    "aselenizatului": "aselenizat",
    "aseamănă": "asemăna",
    "asemăn": "asemăna",
    "asemănă": "asemăna",
    "asemănai": "asemăna",
    "asemănam": "asemăna",
    "asemănăm": "asemăna",
    "asemănând": "asemăna",
    "asemănându": "asemăna",
    "asemănară": "asemăna",
    "asemănarăm": "asemăna",
    "asemănarăți": "asemăna",
    "asemănase": "asemăna",
    "asemănasem": "asemăna",
    "asemănaseră": "asemăna",
    "asemănaserăm": "asemăna",
    "asemănaserăți": "asemăna",
    "asemănaseși": "asemăna",
    "asemănași": "asemăna",
    "asemănat": "asemăna",
    "asemănați": "asemăna",
    "asemănatu": "asemăna",
    "asemănau": "asemăna",
    "asemene": "asemăna",
    "asemeni": "asemăna",
    "neasemănând": "asemăna",
    "neasemănându": "asemăna",
    "nemaiasemănând": "asemăna",
    "nemaiasemănându": "asemăna",
    "asemănarea": "asemănare",
    "asemănări": "asemănare",
    "asemănării": "asemănare",
    "asemănările": "asemănare",
    "asemănărilor": "asemănare",
    "asemănata": "asemănat",
    "asemănată": "asemănat",
    "asemănate": "asemănat",
    "asemănatei": "asemănat",
    "asemănatele": "asemănat",
    "asemănatelor": "asemănat",
    "asemănați": "asemănat",
    "asemănații": "asemănat",
    "asemănaților": "asemănat",
    "asemănatul": "asemănat",
    "asemănatului": "asemănat",
    "asemănătoare": "asemănător",
    "asemănătoarea": "asemănător",
    "asemănătoarei": "asemănător",
    "asemănătoarele": "asemănător",
    "asemănătoarelor": "asemănător",
    "asemănători": "asemănător",
    "asemănătorii": "asemănător",
    "asemănătorilor": "asemănător",
    "asemănătorul": "asemănător",
    "asemănătorului": "asemănător",
    "asemuia": "asemui",
    "asemuiai": "asemui",
    "asemuiam": "asemui",
    "asemuiască": "asemui",
    "asemuiați": "asemui",
    "asemuiau": "asemui",
    "asemuie": "asemui",
    "asemuiesc": "asemui",
    "asemuiește": "asemui",
    "asemuiești": "asemui",
    "asemuii": "asemui",
    "asemuim": "asemui",
    "asemuind": "asemui",
    "asemuindu": "asemui",
    "asemuiră": "asemui",
    "asemuirăm": "asemui",
    "asemuirăți": "asemui",
    "asemuise": "asemui",
    "asemuisem": "asemui",
    "asemuiseră": "asemui",
    "asemuiserăm": "asemui",
    "asemuiserăți": "asemui",
    "asemuiseși": "asemui",
    "asemuiși": "asemui",
    "asemuit": "asemui",
    "asemuiți": "asemui",
    "asemuitu": "asemui",
    "neasemuind": "asemui",
    "neasemuindu": "asemui",
    "nemaiasemuind": "asemui",
    "nemaiasemuindu": "asemui",
    "asemuirea": "asemuire",
    "asemuiri": "asemuire",
    "asemuirii": "asemuire",
    "asemuirile": "asemuire",
    "asemuirilor": "asemuire",
    "asemuita": "asemuit",
    "asemuită": "asemuit",
    "asemuite": "asemuit",
    "asemuitei": "asemuit",
    "asemuitele": "asemuit",
    "asemuitelor": "asemuit",
    "asemuiți": "asemuit",
    "asemuiții": "asemuit",
    "asemuiților": "asemuit",
    "asemuitul": "asemuit",
    "asemuitului": "asemuit",
    "asentimente": "asentiment",
    "asentimentele": "asentiment",
    "asentimentelor": "asentiment",
    "asentimentul": "asentiment",
    "asentimentului": "asentiment",
    "aseptica": "aseptic",
    "aseptică": "aseptic",
    "aseptice": "aseptic",
    "asepticei": "aseptic",
    "asepticele": "aseptic",
    "asepticelor": "aseptic",
    "aseptici": "aseptic",
    "asepticii": "aseptic",
    "asepticilor": "aseptic",
    "asepticul": "aseptic",
    "asepticului": "aseptic",
    "aserțiunea": "aserțiune",
    "aserțiuni": "aserțiune",
    "aserțiunii": "aserțiune",
    "aserțiunile": "aserțiune",
    "aserțiunilor": "aserțiune",
    "asertorica": "asertoric",
    "asertorică": "asertoric",
    "asertorice": "asertoric",
    "asertoricei": "asertoric",
    "asertoricele": "asertoric",
    "asertoricelor": "asertoric",
    "asertorici": "asertoric",
    "asertoricii": "asertoric",
    "asertoricilor": "asertoric",
    "asertoricul": "asertoric",
    "asertoricului": "asertoric",
    "aservea": "aservi",
    "aserveai": "aservi",
    "aserveam": "aservi",
    "aservească": "aservi",
    "aserveați": "aservi",
    "aserveau": "aservi",
    "aservesc": "aservi",
    "aservește": "aservi",
    "aservești": "aservi",
    "aservii": "aservi",
    "aservim": "aservi",
    "aservind": "aservi",
    "aservindu": "aservi",
    "aserviră": "aservi",
    "aservirăm": "aservi",
    "aservirăți": "aservi",
    "aservise": "aservi",
    "aservisem": "aservi",
    "aserviseră": "aservi",
    "aserviserăm": "aservi",
    "aserviserăți": "aservi",
    "aserviseși": "aservi",
    "aserviși": "aservi",
    "aservit": "aservi",
    "aserviți": "aservi",
    "aservitu": "aservi",
    "neaservind": "aservi",
    "neaservindu": "aservi",
    "nemaiaservind": "aservi",
    "nemaiaservindu": "aservi",
    "aservirea": "aservire",
    "aserviri": "aservire",
    "aservirii": "aservire",
    "aservirile": "aservire",
    "aservita": "aservit",
    "aservită": "aservit",
    "aservite": "aservit",
    "aservitei": "aservit",
    "aservitele": "aservit",
    "aservitelor": "aservit",
    "aserviți": "aservit",
    "aserviții": "aservit",
    "aserviților": "aservit",
    "aservitul": "aservit",
    "aservitului": "aservit",
    "aservita": "aservită",
    "aservite": "aservită",
    "aservitei": "aservită",
    "aservitele": "aservită",
    "aservitelor": "aservită",
    "asesoarea": "asesoare",
    "asesoarei": "asesoare",
    "asesoarele": "asesoare",
    "asesoarelor": "asesoare",
    "asesori": "asesor",
    "asesorii": "asesor",
    "asesorilor": "asesor",
    "asesorul": "asesor",
    "asesorului": "asesor",
    "asexuata": "asexuat",
    "asexuată": "asexuat",
    "asexuate": "asexuat",
    "asexuatei": "asexuat",
    "asexuatele": "asexuat",
    "asexuatelor": "asexuat",
    "asexuați": "asexuat",
    "asexuații": "asexuat",
    "asexuaților": "asexuat",
    "asexuatul": "asexuat",
    "asexuatului": "asexuat",
    "așază": "așeza",
    "așează": "așeza",
    "așez": "așeza",
    "așeză": "așeza",
    "așezai": "așeza",
    "așezam": "așeza",
    "așezăm": "așeza",
    "așezând": "așeza",
    "așezându": "așeza",
    "așezară": "așeza",
    "așezarăm": "așeza",
    "așezarăți": "așeza",
    "așezase": "așeza",
    "așezasem": "așeza",
    "așezaseră": "așeza",
    "așezaserăm": "așeza",
    "așezaserăți": "așeza",
    "așezaseși": "așeza",
    "așezași": "așeza",
    "așezat": "așeza",
    "așezați": "așeza",
    "așezatu": "așeza",
    "așezau": "așeza",
    "așeze": "așeza",
    "așezi": "așeza",
    "neașezând": "așeza",
    "neașezându": "așeza",
    "nemaiașezând": "așeza",
    "nemaiașezându": "așeza",
    "așezământul": "așezământ",
    "așezământului": "așezământ",
    "așezăminte": "așezământ",
    "așezămintele": "așezământ",
    "așezămintelor": "așezământ",
    "așezarea": "așezare",
    "așezări": "așezare",
    "așezării": "așezare",
    "așezările": "așezare",
    "așezata": "așezat",
    "așezată": "așezat",
    "așezate": "așezat",
    "așezatei": "așezat",
    "așezatele": "așezat",
    "așezatelor": "așezat",
    "așezați": "așezat",
    "așezații": "așezat",
    "așezaților": "așezat",
    "așezatul": "așezat",
    "așezatului": "așezat",
    "asezonă": "asezona",
    "asezonai": "asezona",
    "asezonam": "asezona",
    "asezonăm": "asezona",
    "asezonând": "asezona",
    "asezonându": "asezona",
    "asezonară": "asezona",
    "asezonarăm": "asezona",
    "asezonarăți": "asezona",
    "asezonase": "asezona",
    "asezonasem": "asezona",
    "asezonaseră": "asezona",
    "asezonaserăm": "asezona",
    "asezonaserăți": "asezona",
    "asezonaseși": "asezona",
    "asezonași": "asezona",
    "asezonat": "asezona",
    "asezonați": "asezona",
    "asezonatu": "asezona",
    "asezonau": "asezona",
    "asezonează": "asezona",
    "asezonez": "asezona",
    "asezoneze": "asezona",
    "asezonezi": "asezona",
    "neasezonând": "asezona",
    "neasezonându": "asezona",
    "nemaiasezonând": "asezona",
    "nemaiasezonându": "asezona",
    "asezonarea": "asezonare",
    "asezonări": "asezonare",
    "asezonării": "asezonare",
    "asezonările": "asezonare",
    "asezonata": "asezonat",
    "asezonată": "asezonat",
    "asezonate": "asezonat",
    "asezonatei": "asezonat",
    "asezonatele": "asezonat",
    "asezonatelor": "asezonat",
    "asezonați": "asezonat",
    "asezonații": "asezonat",
    "asezonaților": "asezonat",
    "asezonatul": "asezonat",
    "asezonatului": "asezonat",
    "asfaltul": "asfalt",
    "asfaltului": "asfalt",
    "asfalturi": "asfalt",
    "asfalturile": "asfalt",
    "asfalturilor": "asfalt",
    "asfaltica": "asfaltic",
    "asfaltică": "asfaltic",
    "asfaltice": "asfaltic",
    "asfalticei": "asfaltic",
    "asfalticele": "asfaltic",
    "asfalticelor": "asfaltic",
    "asfaltici": "asfaltic",
    "asfalticii": "asfaltic",
    "asfalticilor": "asfaltic",
    "asfalticul": "asfaltic",
    "asfalticului": "asfaltic",
    "asfințita": "asfințit",
    "asfințită": "asfințit",
    "asfințite": "asfințit",
    "asfințitei": "asfințit",
    "asfințitele": "asfințit",
    "asfințitelor": "asfințit",
    "asfințiți": "asfințit",
    "asfințiții": "asfințit",
    "asfințiților": "asfințit",
    "asfințitul": "asfințit",
    "asfințitului": "asfințit",
    "asfințituri": "asfințit",
    "asfințiturile": "asfințit",
    "asfințiturilor": "asfințit",
    "asfixiai": "asfixia",
    "asfixiam": "asfixia",
    "asfixiară": "asfixia",
    "asfixiarăm": "asfixia",
    "asfixiarăți": "asfixia",
    "asfixiase": "asfixia",
    "asfixiasem": "asfixia",
    "asfixiaseră": "asfixia",
    "asfixiaserăm": "asfixia",
    "asfixiaserăți": "asfixia",
    "asfixiaseși": "asfixia",
    "asfixiași": "asfixia",
    "asfixiat": "asfixia",
    "asfixiați": "asfixia",
    "asfixiau": "asfixia",
    "asfixiază": "asfixia",
    "asfixie": "asfixia",
    "asfixiem": "asfixia",
    "asfixiez": "asfixia",
    "asfixieze": "asfixia",
    "asfixiezi": "asfixia",
    "asfixiind": "asfixia",
    "neasfixiind": "asfixia",
    "nemaiasfixiind": "asfixia",
    "asfixianta": "asfixiant",
    "asfixiantă": "asfixiant",
    "asfixiante": "asfixiant",
    "asfixiantei": "asfixiant",
    "asfixiantele": "asfixiant",
    "asfixiantelor": "asfixiant",
    "asfixianți": "asfixiant",
    "asfixianții": "asfixiant",
    "asfixianților": "asfixiant",
    "asfixiantul": "asfixiant",
    "asfixiantului": "asfixiant",
    "asfixiata": "asfixiat",
    "asfixiată": "asfixiat",
    "asfixiate": "asfixiat",
    "asfixiatei": "asfixiat",
    "asfixiatele": "asfixiat",
    "asfixiatelor": "asfixiat",
    "asfixiați": "asfixiat",
    "asfixiații": "asfixiat",
    "asfixiaților": "asfixiat",
    "asfixiatul": "asfixiat",
    "asfixiatului": "asfixiat",
    "asfixiata": "asfixiată",
    "asfixiate": "asfixiată",
    "asfixiatei": "asfixiată",
    "asfixiatele": "asfixiată",
    "asfixiatelor": "asfixiată",
    "asfixiatul": "asfixiată",
    "asfixiatului": "asfixiată",
    "asfixia": "asfixie",
    "asfixiei": "asfixie",
    "asfixii": "asfixie",
    "asfixiile": "asfixie",
    "asfixiilor": "asfixie",
    "asfixierea": "asfixiere",
    "asfixieri": "asfixiere",
    "asfixierii": "asfixiere",
    "asfixierile": "asfixiere",
    "Asie": "Asia",
    "Asiei": "Asia",
    "Asii": "Asia",
    "asiatica": "asiatic",
    "asiatică": "asiatic",
    "asiatice": "asiatic",
    "asiaticei": "asiatic",
    "asiaticele": "asiatic",
    "asiaticelor": "asiatic",
    "asiatici": "asiatic",
    "asiaticii": "asiatic",
    "asiaticilor": "asiatic",
    "asiaticul": "asiatic",
    "asiaticului": "asiatic",
    "asiatica": "asiatică",
    "asiatice": "asiatică",
    "asiaticei": "asiatică",
    "asiaticele": "asiatică",
    "asiaticelor": "asiatică",
    "asiduitatea": "asiduitate",
    "asiduități": "asiduitate",
    "asiduității": "asiduitate",
    "asiduitățile": "asiduitate",
    "asiduităților": "asiduitate",
    "asidua": "asiduu",
    "asiduă": "asiduu",
    "asidue": "asiduu",
    "asiduei": "asiduu",
    "asiduele": "asiduu",
    "asiduelor": "asiduu",
    "asidui": "asiduu",
    "asiduii": "asiduu",
    "asiduilor": "asiduu",
    "asiduul": "asiduu",
    "asiduului": "asiduu",
    "asigur": "asigura",
    "asigură": "asigura",
    "asigurai": "asigura",
    "asiguram": "asigura",
    "asigurăm": "asigura",
    "asigurând": "asigura",
    "asigurându": "asigura",
    "asigurară": "asigura",
    "asigurarăm": "asigura",
    "asigurarăți": "asigura",
    "asigurase": "asigura",
    "asigurasem": "asigura",
    "asiguraseră": "asigura",
    "asiguraserăm": "asigura",
    "asiguraserăți": "asigura",
    "asiguraseși": "asigura",
    "asigurași": "asigura",
    "asigurat": "asigura",
    "asigurați": "asigura",
    "asiguratu": "asigura",
    "asigurau": "asigura",
    "asigure": "asigura",
    "asiguri": "asigura",
    "neasigurând": "asigura",
    "neasigurându": "asigura",
    "nemaiasigurând": "asigura",
    "nemaiasigurându": "asigura",
    "asigurarea": "asigurare",
    "asigurări": "asigurare",
    "asigurării": "asigurare",
    "asigurările": "asigurare",
    "asigurărilor": "asigurare",
    "asigurata": "asigurat",
    "asigurată": "asigurat",
    "asigurate": "asigurat",
    "asiguratei": "asigurat",
    "asiguratele": "asigurat",
    "asiguratelor": "asigurat",
    "asigurați": "asigurat",
    "asigurații": "asigurat",
    "asiguraților": "asigurat",
    "asiguratul": "asigurat",
    "asiguratului": "asigurat",
    "asigurata": "asigurată",
    "asigurate": "asigurată",
    "asiguratei": "asigurată",
    "asiguratele": "asigurată",
    "asiguratelor": "asigurată",
    "asigurătoare": "asigurător",
    "asigurătoarea": "asigurător",
    "asigurătoarei": "asigurător",
    "asigurătoarele": "asigurător",
    "asigurătoarelor": "asigurător",
    "asigurători": "asigurător",
    "asigurătorii": "asigurător",
    "asigurătorilor": "asigurător",
    "asigurătorul": "asigurător",
    "asigurătorului": "asigurător",
    "asimetrica": "asimetric",
    "asimetrică": "asimetric",
    "asimetrice": "asimetric",
    "asimetricei": "asimetric",
    "asimetricele": "asimetric",
    "asimetricelor": "asimetric",
    "asimetrici": "asimetric",
    "asimetricii": "asimetric",
    "asimetricilor": "asimetric",
    "asimetricul": "asimetric",
    "asimetricului": "asimetric",
    "asimilă": "asimila",
    "asimilai": "asimila",
    "asimilam": "asimila",
    "asimilăm": "asimila",
    "asimilând": "asimila",
    "asimilându": "asimila",
    "asimilară": "asimila",
    "asimilarăm": "asimila",
    "asimilarăți": "asimila",
    "asimilase": "asimila",
    "asimilasem": "asimila",
    "asimilaseră": "asimila",
    "asimilaserăm": "asimila",
    "asimilaserăți": "asimila",
    "asimilaseși": "asimila",
    "asimilași": "asimila",
    "asimilat": "asimila",
    "asimilați": "asimila",
    "asimilatu": "asimila",
    "asimilau": "asimila",
    "asimilează": "asimila",
    "asimilez": "asimila",
    "asimileze": "asimila",
    "asimilezi": "asimila",
    "neasimilând": "asimila",
    "neasimilându": "asimila",
    "nemaiasimilând": "asimila",
    "nemaiasimilându": "asimila",
    "asimilabilă": "asimilabil",
    "asimilabile": "asimilabil",
    "asimilabili": "asimilabil",
    "asimilarea": "asimilare",
    "asimilări": "asimilare",
    "asimilării": "asimilare",
    "asimilările": "asimilare",
    "asimilata": "asimilat",
    "asimilată": "asimilat",
    "asimilate": "asimilat",
    "asimilatei": "asimilat",
    "asimilatele": "asimilat",
    "asimilatelor": "asimilat",
    "asimilați": "asimilat",
    "asimilații": "asimilat",
    "asimilaților": "asimilat",
    "asimilatul": "asimilat",
    "asimilatului": "asimilat",
    "asimilația": "asimilație",
    "asimilației": "asimilație",
    "asimilații": "asimilație",
    "asimilațiile": "asimilație",
    "asimilațiilor": "asimilație",
    "asini": "asin",
    "asinii": "asin",
    "asinilor": "asin",
    "asinul": "asin",
    "asinului": "asin",
    "asiriana": "asirian",
    "asiriană": "asirian",
    "asirianul": "asirian",
    "asirianului": "asirian",
    "asiriene": "asirian",
    "asirienei": "asirian",
    "asirienele": "asirian",
    "asirienelor": "asirian",
    "asirieni": "asirian",
    "asirienii": "asirian",
    "asirienilor": "asirian",
    "asist": "asista",
    "asistă": "asista",
    "asistai": "asista",
    "asistam": "asista",
    "asistăm": "asista",
    "asistând": "asista",
    "asistându": "asista",
    "asistară": "asista",
    "asistarăm": "asista",
    "asistarăți": "asista",
    "asistase": "asista",
    "asistasem": "asista",
    "asistaseră": "asista",
    "asistaserăm": "asista",
    "asistaserăți": "asista",
    "asistaseși": "asista",
    "asistași": "asista",
    "asistat": "asista",
    "asistați": "asista",
    "asistatu": "asista",
    "asistau": "asista",
    "asiste": "asista",
    "asiști": "asista",
    "neasistând": "asista",
    "neasistându": "asista",
    "nemaiasistând": "asista",
    "nemaiasistându": "asista",
    "asistarea": "asistare",
    "asistări": "asistare",
    "asistării": "asistare",
    "asistările": "asistare",
    "asistata": "asistat",
    "asistată": "asistat",
    "asistate": "asistat",
    "asistatei": "asistat",
    "asistatele": "asistat",
    "asistatelor": "asistat",
    "asistați": "asistat",
    "asistații": "asistat",
    "asistaților": "asistat",
    "asistatul": "asistat",
    "asistatului": "asistat",
    "asist.": "asistent",
    "asistenta": "asistent",
    "asistentă": "asistent",
    "asistente": "asistent",
    "asistentei": "asistent",
    "asistentele": "asistent",
    "asistentelor": "asistent",
    "asistenți": "asistent",
    "asistenții": "asistent",
    "asistenților": "asistent",
    "asistentul": "asistent",
    "asistentului": "asistent",
    "asistenta": "asistentă",
    "asistente": "asistentă",
    "asistentei": "asistentă",
    "asistentele": "asistentă",
    "asistentelor": "asistentă",
    "asistența": "asistență",
    "asistențe": "asistență",
    "asistenței": "asistență",
    "asistențele": "asistență",
    "asistențelor": "asistență",
    "asmut": "asmuți",
    "asmută": "asmuți",
    "asmute": "asmuți",
    "asmuțea": "asmuți",
    "asmuțeai": "asmuți",
    "asmuțeam": "asmuți",
    "asmuțeați": "asmuți",
    "asmuțeau": "asmuți",
    "asmuții": "asmuți",
    "asmuțim": "asmuți",
    "asmuțind": "asmuți",
    "asmuțindu": "asmuți",
    "asmuțiră": "asmuți",
    "asmuțirăm": "asmuți",
    "asmuțirăți": "asmuți",
    "asmuțise": "asmuți",
    "asmuțisem": "asmuți",
    "asmuțiseră": "asmuți",
    "asmuțiserăm": "asmuți",
    "asmuțiserăți": "asmuți",
    "asmuțiseși": "asmuți",
    "asmuțiși": "asmuți",
    "asmuțit": "asmuți",
    "asmuțiți": "asmuți",
    "asmuțitu": "asmuți",
    "neasmuțind": "asmuți",
    "neasmuțindu": "asmuți",
    "nemaiasmuțind": "asmuți",
    "nemaiasmuțindu": "asmuți",
    "asmuțirea": "asmuțire",
    "asmuțiri": "asmuțire",
    "asmuțirii": "asmuțire",
    "asmuțirile": "asmuțire",
    "asmuțita": "asmuțit",
    "asmuțită": "asmuțit",
    "asmuțite": "asmuțit",
    "asmuțitei": "asmuțit",
    "asmuțitele": "asmuțit",
    "asmuțitelor": "asmuțit",
    "asmuțiți": "asmuțit",
    "asmuțiții": "asmuțit",
    "asmuțiților": "asmuțit",
    "asmuțitul": "asmuțit",
    "asmuțitului": "asmuțit",
    "asociai": "asocia",
    "asociam": "asocia",
    "asociară": "asocia",
    "asociarăm": "asocia",
    "asociarăți": "asocia",
    "asociase": "asocia",
    "asociasem": "asocia",
    "asociaseră": "asocia",
    "asociaserăm": "asocia",
    "asociaserăți": "asocia",
    "asociaseși": "asocia",
    "asociași": "asocia",
    "asociat": "asocia",
    "asociați": "asocia",
    "asociatu": "asocia",
    "asociau": "asocia",
    "asociază": "asocia",
    "asocie": "asocia",
    "asociem": "asocia",
    "asociez": "asocia",
    "asocieze": "asocia",
    "asociezi": "asocia",
    "asociind": "asocia",
    "asociindu": "asocia",
    "neasociind": "asocia",
    "neasociindu": "asocia",
    "nemaiasociind": "asocia",
    "nemaiasociindu": "asocia",
    "asociata": "asociat",
    "asociată": "asociat",
    "asociate": "asociat",
    "asociatei": "asociat",
    "asociatele": "asociat",
    "asociatelor": "asociat",
    "asociați": "asociat",
    "asociații": "asociat",
    "asociaților": "asociat",
    "asociatu": "asociat",
    "asociatul": "asociat",
    "asociatului": "asociat",
    "asociata": "asociată",
    "asociate": "asociată",
    "asociatei": "asociată",
    "asociatele": "asociată",
    "asociatelor": "asociată",
    "asociația": "asociație",
    "asociației": "asociație",
    "asociații": "asociație",
    "asociațiile": "asociație",
    "asociațiilor": "asociație",
    "asociaționista": "asociaționist",
    "asociaționistă": "asociaționist",
    "asociaționiste": "asociaționist",
    "asociaționistei": "asociaționist",
    "asociaționistele": "asociaționist",
    "asociaționistelor": "asociaționist",
    "asociaționiști": "asociaționist",
    "asociaționiștii": "asociaționist",
    "asociaționiștilor": "asociaționist",
    "asociaționistul": "asociaționist",
    "asociaționistului": "asociaționist",
    "asociativa": "asociativ",
    "asociativă": "asociativ",
    "asociative": "asociativ",
    "asociativei": "asociativ",
    "asociativele": "asociativ",
    "asociativelor": "asociativ",
    "asociativi": "asociativ",
    "asociativii": "asociativ",
    "asociativilor": "asociativ",
    "asociativul": "asociativ",
    "asociativului": "asociativ",
    "asocierea": "asociere",
    "asocieri": "asociere",
    "asocierii": "asociere",
    "asocierile": "asociere",
    "asonanța": "asonanță",
    "asonanțe": "asonanță",
    "asonanței": "asonanță",
    "asonanțele": "asonanță",
    "asonanțelor": "asonanță",
    "asortă": "asorta",
    "asortai": "asorta",
    "asortam": "asorta",
    "asortăm": "asorta",
    "asortând": "asorta",
    "asortară": "asorta",
    "asortarăm": "asorta",
    "asortarăți": "asorta",
    "asortase": "asorta",
    "asortasem": "asorta",
    "asortaseră": "asorta",
    "asortaserăm": "asorta",
    "asortaserăți": "asorta",
    "asortaseși": "asorta",
    "asortași": "asorta",
    "asortat": "asorta",
    "asortați": "asorta",
    "asortau": "asorta",
    "asortează": "asorta",
    "asortez": "asorta",
    "asorteze": "asorta",
    "asortezi": "asorta",
    "neasortând": "asorta",
    "nemaiasortând": "asorta",
    "asortarea": "asortare",
    "asortări": "asortare",
    "asortării": "asortare",
    "asortările": "asortare",
    "asortata": "asortat",
    "asortată": "asortat",
    "asortate": "asortat",
    "asortatei": "asortat",
    "asortatele": "asortat",
    "asortatelor": "asortat",
    "asortați": "asortat",
    "asortații": "asortat",
    "asortaților": "asortat",
    "asortatul": "asortat",
    "asortatului": "asortat",
    "asortimente": "asortiment",
    "asortimentele": "asortiment",
    "asortimentelor": "asortiment",
    "asortimentul": "asortiment",
    "asortimentului": "asortiment",
    "aspecte": "aspect",
    "aspectele": "aspect",
    "aspectelor": "aspect",
    "aspectul": "aspect",
    "aspectului": "aspect",
    "aspectuoasa": "aspectuos",
    "aspectuoasă": "aspectuos",
    "aspectuoase": "aspectuos",
    "aspectuoasei": "aspectuos",
    "aspectuoasele": "aspectuos",
    "aspectuoaselor": "aspectuos",
    "aspectuoși": "aspectuos",
    "aspectuoșii": "aspectuos",
    "aspectuoșilor": "aspectuos",
    "aspectuosul": "aspectuos",
    "aspectuosului": "aspectuos",
    "asperitatea": "asperitate",
    "asperități": "asperitate",
    "asperității": "asperitate",
    "asperitățile": "asperitate",
    "asperităților": "asperitate",
    "aspersiunea": "aspersiune",
    "aspersiuni": "aspersiune",
    "aspersiunii": "aspersiune",
    "aspersiunile": "aspersiune",
    "aspersiunilor": "aspersiune",
    "aspicul": "aspic",
    "aspicului": "aspic",
    "aspicuri": "aspic",
    "aspicurile": "aspic",
    "aspicurilor": "aspic",
    "aspida": "aspidă",
    "aspide": "aspidă",
    "aspidei": "aspidă",
    "aspidele": "aspidă",
    "aspidelor": "aspidă",
    "aspir": "aspira",
    "aspiră": "aspira",
    "aspirai": "aspira",
    "aspiram": "aspira",
    "aspirăm": "aspira",
    "aspirând": "aspira",
    "aspirându": "aspira",
    "aspirară": "aspira",
    "aspirarăm": "aspira",
    "aspirarăți": "aspira",
    "aspirase": "aspira",
    "aspirasem": "aspira",
    "aspiraseră": "aspira",
    "aspiraserăm": "aspira",
    "aspiraserăți": "aspira",
    "aspiraseși": "aspira",
    "aspirași": "aspira",
    "aspirat": "aspira",
    "aspirați": "aspira",
    "aspiratu": "aspira",
    "aspirau": "aspira",
    "aspire": "aspira",
    "aspiri": "aspira",
    "neaspirând": "aspira",
    "neaspirându": "aspira",
    "nemaiaspirând": "aspira",
    "nemaiaspirându": "aspira",
    "aspiranta": "aspirant",
    "aspirantă": "aspirant",
    "aspirante": "aspirant",
    "aspirantei": "aspirant",
    "aspirantele": "aspirant",
    "aspirantelor": "aspirant",
    "aspiranți": "aspirant",
    "aspiranții": "aspirant",
    "aspiranților": "aspirant",
    "aspirantul": "aspirant",
    "aspirantului": "aspirant",
    "aspirarea": "aspirare",
    "aspirări": "aspirare",
    "aspirării": "aspirare",
    "aspirările": "aspirare",
    "aspirata": "aspirat",
    "aspirată": "aspirat",
    "aspirate": "aspirat",
    "aspiratei": "aspirat",
    "aspiratele": "aspirat",
    "aspiratelor": "aspirat",
    "aspirați": "aspirat",
    "aspirații": "aspirat",
    "aspiraților": "aspirat",
    "aspiratul": "aspirat",
    "aspiratului": "aspirat",
    "aspirația": "aspirație",
    "aspirației": "aspirație",
    "aspirații": "aspirație",
    "aspirațiile": "aspirație",
    "aspirațiilor": "aspirație",
    "aspiratoare": "aspirator",
    "aspiratoarea": "aspirator",
    "aspiratoarei": "aspirator",
    "aspiratoarele": "aspirator",
    "aspiratoarelor": "aspirator",
    "aspiratori": "aspirator",
    "aspiratorii": "aspirator",
    "aspiratorilor": "aspirator",
    "aspiratorul": "aspirator",
    "aspiratorului": "aspirator",
    "asprea": "aspri",
    "aspreai": "aspri",
    "aspream": "aspri",
    "asprească": "aspri",
    "aspreați": "aspri",
    "aspreau": "aspri",
    "aspresc": "aspri",
    "asprește": "aspri",
    "asprești": "aspri",
    "asprii": "aspri",
    "asprim": "aspri",
    "asprind": "aspri",
    "asprindu": "aspri",
    "aspriră": "aspri",
    "asprirăm": "aspri",
    "asprirăți": "aspri",
    "asprise": "aspri",
    "asprisem": "aspri",
    "aspriseră": "aspri",
    "aspriserăm": "aspri",
    "aspriserăți": "aspri",
    "aspriseși": "aspri",
    "aspriși": "aspri",
    "asprit": "aspri",
    "aspriți": "aspri",
    "aspritu": "aspri",
    "asprimea": "asprime",
    "asprimi": "asprime",
    "asprimii": "asprime",
    "asprimile": "asprime",
    "asprimilor": "asprime",
    "asprita": "asprit",
    "asprită": "asprit",
    "asprite": "asprit",
    "aspritei": "asprit",
    "aspritele": "asprit",
    "aspritelor": "asprit",
    "aspriți": "asprit",
    "aspriții": "asprit",
    "aspriților": "asprit",
    "aspritul": "asprit",
    "aspritului": "asprit",
    "aspra": "aspru",
    "aspră": "aspru",
    "aspre": "aspru",
    "asprei": "aspru",
    "asprele": "aspru",
    "asprelor": "aspru",
    "aspri": "aspru",
    "asprii": "aspru",
    "asprilor": "aspru",
    "asprul": "aspru",
    "asprului": "aspru",
    "astă": "ăst",
    "aste": "ăst",
    "ăstei": "ăst",
    "ăști": "ăst",
    "ăstor": "ăst",
    "ăstui": "ăst",
    "ast": "asta",
    "ast-": "ăsta",
    "asta": "ăsta",
    "astea": "ăsta",
    "ăsteia": "ăsta",
    "ăștia": "ăsta",
    "ăstora": "ăsta",
    "ăstuia": "ăsta",
    "astâmpărul": "astâmpăr",
    "astâmpărului": "astâmpăr",
    "astâmpăr": "astâmpăra",
    "astâmpără": "astâmpăra",
    "astâmpărai": "astâmpăra",
    "astâmpăram": "astâmpăra",
    "astâmpărăm": "astâmpăra",
    "astâmpărând": "astâmpăra",
    "astâmpărându": "astâmpăra",
    "astâmpărară": "astâmpăra",
    "astâmpărarăm": "astâmpăra",
    "astâmpărarăți": "astâmpăra",
    "astâmpărase": "astâmpăra",
    "astâmpărasem": "astâmpăra",
    "astâmpăraseră": "astâmpăra",
    "astâmpăraserăm": "astâmpăra",
    "astâmpăraserăți": "astâmpăra",
    "astâmpăraseși": "astâmpăra",
    "astâmpărași": "astâmpăra",
    "astâmpărat": "astâmpăra",
    "astâmpărați": "astâmpăra",
    "astâmpăratu": "astâmpăra",
    "astâmpărau": "astâmpăra",
    "astâmpăre": "astâmpăra",
    "astâmpere": "astâmpăra",
    "astâmperi": "astâmpăra",
    "astâmpărarea": "astâmpărare",
    "astâmpărări": "astâmpărare",
    "astâmpărării": "astâmpărare",
    "astâmpărările": "astâmpărare",
    "astâmpărărilor": "astâmpărare",
    "astâmpărată": "astâmpărat",
    "astâmpărate": "astâmpărat",
    "astâmpărați": "astâmpărat",
    "astenica": "astenic",
    "astenică": "astenic",
    "astenice": "astenic",
    "astenicei": "astenic",
    "astenicele": "astenic",
    "astenicelor": "astenic",
    "astenici": "astenic",
    "astenicii": "astenic",
    "astenicilor": "astenic",
    "astenicul": "astenic",
    "astenicului": "astenic",
    "astenia": "astenie",
    "asteniei": "astenie",
    "astenii": "astenie",
    "asteniile": "astenie",
    "asteniilor": "astenie",
    "așteaptă": "aștepta",
    "aștept": "aștepta",
    "așteptă": "aștepta",
    "așteptai": "aștepta",
    "așteptam": "aștepta",
    "așteptăm": "aștepta",
    "așteptând": "aștepta",
    "așteptându": "aștepta",
    "așteptară": "aștepta",
    "așteptarăm": "aștepta",
    "așteptarăți": "aștepta",
    "așteptase": "aștepta",
    "așteptasem": "aștepta",
    "așteptaseră": "aștepta",
    "așteptaserăm": "aștepta",
    "așteptaserăți": "aștepta",
    "așteptaseși": "aștepta",
    "așteptași": "aștepta",
    "așteptat": "aștepta",
    "așteptați": "aștepta",
    "așteptatu": "aștepta",
    "așteptau": "aștepta",
    "aștepte": "aștepta",
    "aștepți": "aștepta",
    "neașteptând": "aștepta",
    "neașteptându": "aștepta",
    "nemaiașteptând": "aștepta",
    "nemaiașteptându": "aștepta",
    "așteptarea": "așteptare",
    "așteptări": "așteptare",
    "așteptării": "așteptare",
    "așteptările": "așteptare",
    "așteptărilor": "așteptare",
    "așteptata": "așteptat",
    "așteptată": "așteptat",
    "așteptate": "așteptat",
    "așteptatei": "așteptat",
    "așteptatele": "așteptat",
    "așteptatelor": "așteptat",
    "așteptați": "așteptat",
    "așteptații": "așteptat",
    "așteptaților": "așteptat",
    "așteptatul": "așteptat",
    "așteptatului": "așteptat",
    "asteriscul": "asterisc",
    "asteriscului": "asterisc",
    "asteriscuri": "asterisc",
    "asteriscurile": "asterisc",
    "asteriscurilor": "asterisc",
    "aștearnă": "așterne",
    "aștern": "așterne",
    "așternând": "așterne",
    "așternându": "așterne",
    "așternea": "așterne",
    "așterneai": "așterne",
    "așterneam": "așterne",
    "așterneați": "așterne",
    "așterneau": "așterne",
    "așternem": "așterne",
    "așterneți": "așterne",
    "așterni": "așterne",
    "așternu": "așterne",
    "așternui": "așterne",
    "așternură": "așterne",
    "așternurăm": "așterne",
    "așternurăți": "așterne",
    "așternuse": "așterne",
    "așternusem": "așterne",
    "așternuseră": "așterne",
    "așternuserăm": "așterne",
    "așternuserăți": "așterne",
    "așternuseși": "așterne",
    "așternuși": "așterne",
    "așternut": "așterne",
    "așternutu": "așterne",
    "neașternând": "așterne",
    "neașternându": "așterne",
    "nemaiașternând": "așterne",
    "nemaiașternându": "așterne",
    "așternerea": "așternere",
    "așterneri": "așternere",
    "așternerii": "așternere",
    "așternerile": "așternere",
    "așternuta": "așternut",
    "așternută": "așternut",
    "așternute": "așternut",
    "așternutei": "așternut",
    "așternutele": "așternut",
    "așternutelor": "așternut",
    "așternuți": "așternut",
    "așternuții": "așternut",
    "așternuților": "așternut",
    "așternutul": "așternut",
    "așternutului": "așternut",
    "așternuturi": "așternut",
    "așternuturile": "așternut",
    "așternuturilor": "așternut",
    "asteroidul": "asteroid",
    "asteroidului": "asteroid",
    "asteroizi": "asteroid",
    "asteroizii": "asteroid",
    "asteroizilor": "asteroid",
    "astigmatica": "astigmatic",
    "astigmatică": "astigmatic",
    "astigmatice": "astigmatic",
    "astigmaticei": "astigmatic",
    "astigmaticele": "astigmatic",
    "astigmaticelor": "astigmatic",
    "astigmatici": "astigmatic",
    "astigmaticii": "astigmatic",
    "astigmaticilor": "astigmatic",
    "astigmaticul": "astigmatic",
    "astigmaticului": "astigmatic",
    "astmul": "astm",
    "astmului": "astm",
    "astma": "astmă",
    "astme": "astmă",
    "astmei": "astmă",
    "astmele": "astmă",
    "astmelor": "astmă",
    "astmatica": "astmatic",
    "astmatică": "astmatic",
    "astmatice": "astmatic",
    "astmaticei": "astmatic",
    "astmaticele": "astmatic",
    "astmatici": "astmatic",
    "astmaticii": "astmatic",
    "astmaticilor": "astmatic",
    "astmaticul": "astmatic",
    "astmaticului": "astmatic",
    "astrala": "astral",
    "astrală": "astral",
    "astrale": "astral",
    "astralei": "astral",
    "astralele": "astral",
    "astralelor": "astral",
    "astrali": "astral",
    "astralii": "astral",
    "astralilor": "astral",
    "astralul": "astral",
    "astralului": "astral",
    "astringenta": "astringent",
    "astringentă": "astringent",
    "astringente": "astringent",
    "astringentei": "astringent",
    "astringentele": "astringent",
    "astringentelor": "astringent",
    "astringenți": "astringent",
    "astringenții": "astringent",
    "astringenților": "astringent",
    "astringentul": "astringent",
    "astringentului": "astringent",
    "astrologica": "astrologic",
    "astrologică": "astrologic",
    "astrologice": "astrologic",
    "astrologicei": "astrologic",
    "astrologicele": "astrologic",
    "astrologicelor": "astrologic",
    "astrologici": "astrologic",
    "astrologicii": "astrologic",
    "astrologicilor": "astrologic",
    "astrologicul": "astrologic",
    "astrologicului": "astrologic",
    "astronauți": "astronaut",
    "astronauții": "astronaut",
    "astronauților": "astronaut",
    "astronautul": "astronaut",
    "astronautului": "astronaut",
    "astronautica": "astronautică",
    "astronautici": "astronautică",
    "astronauticii": "astronautică",
    "astronauticile": "astronautică",
    "astronauticilor": "astronautică",
    "astronava": "astronavă",
    "astronave": "astronavă",
    "astronavei": "astronavă",
    "astronavele": "astronavă",
    "astronavelor": "astronavă",
    "astronomi": "astronom",
    "astronomii": "astronom",
    "astronomilor": "astronom",
    "astronomul": "astronom",
    "astronomului": "astronom",
    "astr.": "astronomic",
    "astronomica": "astronomic",
    "astronomică": "astronomic",
    "astronomice": "astronomic",
    "astronomicei": "astronomic",
    "astronomicele": "astronomic",
    "astronomicelor": "astronomic",
    "astronomici": "astronomic",
    "astronomicii": "astronomic",
    "astronomicilor": "astronomic",
    "astronomicul": "astronomic",
    "astronomicului": "astronomic",
    "astron.": "astronomie",
    "astronomia": "astronomie",
    "astronomiei": "astronomie",
    "astronomii": "astronomie",
    "astre": "astru",
    "astrele": "astru",
    "astrelor": "astru",
    "aștri": "astru",
    "aștrii": "astru",
    "aștrilor": "astru",
    "astrul": "astru",
    "astrului": "astru",
    "astup": "astupa",
    "astupă": "astupa",
    "astupai": "astupa",
    "astupam": "astupa",
    "astupăm": "astupa",
    "astupând": "astupa",
    "astupându": "astupa",
    "astupară": "astupa",
    "astuparăm": "astupa",
    "astuparăți": "astupa",
    "astupase": "astupa",
    "astupasem": "astupa",
    "astupaseră": "astupa",
    "astupaserăm": "astupa",
    "astupaserăți": "astupa",
    "astupaseși": "astupa",
    "astupași": "astupa",
    "astupat": "astupa",
    "astupați": "astupa",
    "astupatu": "astupa",
    "astupau": "astupa",
    "astupe": "astupa",
    "astupi": "astupa",
    "neastupând": "astupa",
    "neastupându": "astupa",
    "nemaiastupând": "astupa",
    "nemaiastupându": "astupa",
    "astuparea": "astupare",
    "astupări": "astupare",
    "astupării": "astupare",
    "astupările": "astupare",
    "astupata": "astupat",
    "astupată": "astupat",
    "astupate": "astupat",
    "astupatei": "astupat",
    "astupatele": "astupat",
    "astupatelor": "astupat",
    "astupați": "astupat",
    "astupații": "astupat",
    "astupaților": "astupat",
    "astupatul": "astupat",
    "astupatului": "astupat",
    "astupătoarea": "astupătoare",
    "astupătoarei": "astupătoare",
    "astupătorile": "astupătoare",
    "astupătorilor": "astupătoare",
    "asud": "asuda",
    "asudă": "asuda",
    "asudai": "asuda",
    "asudam": "asuda",
    "asudăm": "asuda",
    "asudând": "asuda",
    "asudându": "asuda",
    "asudară": "asuda",
    "asudarăm": "asuda",
    "asudarăți": "asuda",
    "asudase": "asuda",
    "asudasem": "asuda",
    "asudaseră": "asuda",
    "asudaserăm": "asuda",
    "asudaserăți": "asuda",
    "asudaseși": "asuda",
    "asudași": "asuda",
    "asudat": "asuda",
    "asudați": "asuda",
    "asudatu": "asuda",
    "asudau": "asuda",
    "asude": "asuda",
    "asuzi": "asuda",
    "asudată": "asudat",
    "asudate": "asudat",
    "asudați": "asudat",
    "asum": "asuma",
    "asumă": "asuma",
    "asumai": "asuma",
    "asumam": "asuma",
    "asumăm": "asuma",
    "asumând": "asuma",
    "asumându": "asuma",
    "asumară": "asuma",
    "asumarăm": "asuma",
    "asumarăți": "asuma",
    "asumase": "asuma",
    "asumasem": "asuma",
    "asumaseră": "asuma",
    "asumaserăm": "asuma",
    "asumaserăți": "asuma",
    "asumaseși": "asuma",
    "asumași": "asuma",
    "asumat": "asuma",
    "asumați": "asuma",
    "asumatu": "asuma",
    "asumau": "asuma",
    "asume": "asuma",
    "asumi": "asuma",
    "neasumând": "asuma",
    "neasumându": "asuma",
    "nemaiasumând": "asuma",
    "nemaiasumându": "asuma",
    "asumarea": "asumare",
    "asumări": "asumare",
    "asumării": "asumare",
    "asumările": "asumare",
    "asumata": "asumat",
    "asumată": "asumat",
    "asumate": "asumat",
    "asumatei": "asumat",
    "asumatele": "asumat",
    "asumatelor": "asumat",
    "asumați": "asumat",
    "asumații": "asumat",
    "asumaților": "asumat",
    "asumatul": "asumat",
    "asumatului": "asumat",
    "as.": "asupra",
    "asupră": "asupra",
    "asupreala": "asupreală",
    "asupreli": "asupreală",
    "asuprelii": "asupreală",
    "asuprelile": "asupreală",
    "asuprelilor": "asupreală",
    "asuprea": "asupri",
    "asupreai": "asupri",
    "asupream": "asupri",
    "asuprească": "asupri",
    "asupreați": "asupri",
    "asupreau": "asupri",
    "asupresc": "asupri",
    "asuprește": "asupri",
    "asuprești": "asupri",
    "asuprii": "asupri",
    "asuprim": "asupri",
    "asuprind": "asupri",
    "asuprindu": "asupri",
    "asupriră": "asupri",
    "asuprirăm": "asupri",
    "asuprirăți": "asupri",
    "asuprise": "asupri",
    "asuprisem": "asupri",
    "asupriseră": "asupri",
    "asupriserăm": "asupri",
    "asupriserăți": "asupri",
    "asupriseși": "asupri",
    "asupriși": "asupri",
    "asuprit": "asupri",
    "asupriți": "asupri",
    "asupritu": "asupri",
    "neasuprind": "asupri",
    "neasuprindu": "asupri",
    "nemaiasuprind": "asupri",
    "nemaiasuprindu": "asupri",
    "asuprirea": "asuprire",
    "asupriri": "asuprire",
    "asupririi": "asuprire",
    "asupririle": "asuprire",
    "asuprita": "asuprit",
    "asuprită": "asuprit",
    "asuprite": "asuprit",
    "asupritei": "asuprit",
    "asupritele": "asuprit",
    "asupritelor": "asuprit",
    "asupriți": "asuprit",
    "asupriții": "asuprit",
    "asupriților": "asuprit",
    "asupritul": "asuprit",
    "asupritului": "asuprit",
    "asuprita": "asuprită",
    "asuprite": "asuprită",
    "asupritei": "asuprită",
    "asupritele": "asuprită",
    "asupritelor": "asuprită",
    "asupritoarea": "asupritoare",
    "asupritoarei": "asupritoare",
    "asupritoarele": "asupritoare",
    "asupritoarelor": "asupritoare",
    "asupritoare": "asupritor",
    "asupritoarea": "asupritor",
    "asupritoarei": "asupritor",
    "asupritoarele": "asupritor",
    "asupritoarelor": "asupritor",
    "asupritori": "asupritor",
    "asupritorii": "asupritor",
    "asupritorilor": "asupritor",
    "asupritorul": "asupritor",
    "asupritorului": "asupritor",
    "asurzea": "asurzi",
    "asurzeai": "asurzi",
    "asurzeam": "asurzi",
    "asurzească": "asurzi",
    "asurzeați": "asurzi",
    "asurzeau": "asurzi",
    "asurzesc": "asurzi",
    "asurzește": "asurzi",
    "asurzești": "asurzi",
    "asurzii": "asurzi",
    "asurzim": "asurzi",
    "asurzind": "asurzi",
    "asurzindu": "asurzi",
    "asurziră": "asurzi",
    "asurzirăm": "asurzi",
    "asurzirăți": "asurzi",
    "asurzise": "asurzi",
    "asurzisem": "asurzi",
    "asurziseră": "asurzi",
    "asurziserăm": "asurzi",
    "asurziserăți": "asurzi",
    "asurziseși": "asurzi",
    "asurziși": "asurzi",
    "asurzit": "asurzi",
    "asurziți": "asurzi",
    "asurzitu": "asurzi",
    "neasurzind": "asurzi",
    "neasurzindu": "asurzi",
    "nemaiasurzind": "asurzi",
    "nemaiasurzindu": "asurzi",
    "asurzirea": "asurzire",
    "asurziri": "asurzire",
    "asurzirii": "asurzire",
    "asurzirile": "asurzire",
    "asurzita": "asurzit",
    "asurzită": "asurzit",
    "asurzite": "asurzit",
    "asurzitei": "asurzit",
    "asurzitele": "asurzit",
    "asurzitelor": "asurzit",
    "asurziți": "asurzit",
    "asurziții": "asurzit",
    "asurziților": "asurzit",
    "asurzitul": "asurzit",
    "asurzitului": "asurzit",
    "asurzitoare": "asurzitor",
    "asurzitoarea": "asurzitor",
    "asurzitoarei": "asurzitor",
    "asurzitoarele": "asurzitor",
    "asurzitoarelor": "asurzitor",
    "asurzitori": "asurzitor",
    "asurzitorii": "asurzitor",
    "asurzitorilor": "asurzitor",
    "asurzitorul": "asurzitor",
    "asurzitorului": "asurzitor",
    "ața": "ață",
    "ațe": "ață",
    "aței": "ață",
    "ațele": "ață",
    "ațelor": "ață",
    "atacul": "atac",
    "atacului": "atac",
    "atacuri": "atac",
    "atacurile": "atac",
    "atacurilor": "atac",
    "atac": "ataca",
    "atacă": "ataca",
    "atacai": "ataca",
    "atacam": "ataca",
    "atacăm": "ataca",
    "atacând": "ataca",
    "atacându": "ataca",
    "atacară": "ataca",
    "atacarăm": "ataca",
    "atacarăți": "ataca",
    "atacase": "ataca",
    "atacasem": "ataca",
    "atacaseră": "ataca",
    "atacaserăm": "ataca",
    "atacaserăți": "ataca",
    "atacaseși": "ataca",
    "atacași": "ataca",
    "atacat": "ataca",
    "atacați": "ataca",
    "atacatu": "ataca",
    "atacau": "ataca",
    "atace": "ataca",
    "ataci": "ataca",
    "neatacând": "ataca",
    "neatacându": "ataca",
    "nemaiatacând": "ataca",
    "nemaiatacându": "ataca",
    "atacabila": "atacabil",
    "atacabilă": "atacabil",
    "atacabile": "atacabil",
    "atacabilei": "atacabil",
    "atacabilele": "atacabil",
    "atacabilelor": "atacabil",
    "atacabili": "atacabil",
    "atacabilii": "atacabil",
    "atacabililor": "atacabil",
    "atacabilul": "atacabil",
    "atacabilului": "atacabil",
    "atacanți": "atacant",
    "atacanții": "atacant",
    "atacantul": "atacant",
    "atacantului": "atacant",
    "atacanta": "atacantă",
    "atacante": "atacantă",
    "atacantele": "atacantă",
    "atacantelor": "atacantă",
    "atacantey": "atacantă",
    "atacarea": "atacare",
    "atacări": "atacare",
    "atacării": "atacare",
    "atacările": "atacare",
    "atacata": "atacat",
    "atacată": "atacat",
    "atacate": "atacat",
    "atacatei": "atacat",
    "atacatele": "atacat",
    "atacatelor": "atacat",
    "atacați": "atacat",
    "atacații": "atacat",
    "atacaților": "atacat",
    "atacatul": "atacat",
    "atacatului": "atacat",
    "atacatoarea": "atacatoare",
    "atacatoarei": "atacatoare",
    "atacatoarele": "atacatoare",
    "atacatoarelor": "atacatoare",
    "atacatoare": "atacator",
    "atacatoarea": "atacator",
    "atacatoarei": "atacator",
    "atacatoarele": "atacator",
    "atacatoarelor": "atacator",
    "atacatori": "atacator",
    "atacatorii": "atacator",
    "atacatorilor": "atacator",
    "atacatorul": "atacator",
    "atacatorului": "atacator",
    "Atalantei": "Atalanta",
    "ataror": "atare",
    "atârn": "atârna",
    "atârnă": "atârna",
    "atârnai": "atârna",
    "atârnam": "atârna",
    "atârnăm": "atârna",
    "atârnând": "atârna",
    "atârnându": "atârna",
    "atârnară": "atârna",
    "atârnarăm": "atârna",
    "atârnarăți": "atârna",
    "atârnase": "atârna",
    "atârnasem": "atârna",
    "atârnaseră": "atârna",
    "atârnaserăm": "atârna",
    "atârnaserăți": "atârna",
    "atârnaseși": "atârna",
    "atârnași": "atârna",
    "atârnat": "atârna",
    "atârnați": "atârna",
    "atârnatu": "atârna",
    "atârnau": "atârna",
    "atârne": "atârna",
    "atârni": "atârna",
    "neatârnând": "atârna",
    "neatârnându": "atârna",
    "nemaiatârnând": "atârna",
    "nemaiatârnându": "atârna",
    "atârnarea": "atârnare",
    "atârnări": "atârnare",
    "atârnării": "atârnare",
    "atârnările": "atârnare",
    "atârnata": "atârnat",
    "atârnată": "atârnat",
    "atârnate": "atârnat",
    "atârnatei": "atârnat",
    "atârnatele": "atârnat",
    "atârnatelor": "atârnat",
    "atârnați": "atârnat",
    "atârnații": "atârnat",
    "atârnaților": "atârnat",
    "atârnatul": "atârnat",
    "atârnatului": "atârnat",
    "atârnători": "atârnător",
    "atârnătorii": "atârnător",
    "atârnătorilor": "atârnător",
    "atârnătorul": "atârnător",
    "atârnătorului": "atârnător",
    "atașe": "ataș",
    "atașele": "ataș",
    "atașelor": "ataș",
    "atașul": "ataș",
    "atașului": "ataș",
    "atașă": "atașa",
    "atașai": "atașa",
    "atașam": "atașa",
    "atașăm": "atașa",
    "atașând": "atașa",
    "atașându": "atașa",
    "atașară": "atașa",
    "atașarăm": "atașa",
    "atașarăți": "atașa",
    "atașase": "atașa",
    "atașasem": "atașa",
    "atașaseră": "atașa",
    "atașaserăm": "atașa",
    "atașaserăți": "atașa",
    "atașaseși": "atașa",
    "atașași": "atașa",
    "atașat": "atașa",
    "atașați": "atașa",
    "atașatu": "atașa",
    "atașau": "atașa",
    "atașează": "atașa",
    "atașez": "atașa",
    "atașeze": "atașa",
    "atașezi": "atașa",
    "neatașând": "atașa",
    "neatașându": "atașa",
    "nemaiatașând": "atașa",
    "nemaiatașându": "atașa",
    "atașamente": "atașament",
    "atașamentele": "atașament",
    "atașamentelor": "atașament",
    "atașamentul": "atașament",
    "atașamentului": "atașament",
    "atașarea": "atașare",
    "atașări": "atașare",
    "atașării": "atașare",
    "atașările": "atașare",
    "atașata": "atașat",
    "atașată": "atașat",
    "atașate": "atașat",
    "atașatei": "atașat",
    "atașatele": "atașat",
    "atașatelor": "atașat",
    "atașați": "atașat",
    "atașații": "atașat",
    "atașaților": "atașat",
    "atașatul": "atașat",
    "atașatului": "atașat",
    "atașata": "atașată",
    "atașate": "atașată",
    "atașatei": "atașată",
    "atașatele": "atașată",
    "atașatelor": "atașată",
    "atâta": "atât",
    "atâtea": "atât",
    "atâți": "atât",
    "atâția": "atât",
    "atâtor": "atât",
    "atâtora": "atât",
    "ațâț": "ațâța",
    "ațâță": "ațâța",
    "ațâțai": "ațâța",
    "ațâțam": "ațâța",
    "ațâțăm": "ațâța",
    "ațâțând": "ațâța",
    "ațâțându": "ațâța",
    "ațâțară": "ațâța",
    "ațâțarăm": "ațâța",
    "ațâțarăți": "ațâța",
    "ațâțase": "ațâța",
    "ațâțasem": "ațâța",
    "ațâțaseră": "ațâța",
    "ațâțaserăm": "ațâța",
    "ațâțaserăți": "ațâța",
    "ațâțaseși": "ațâța",
    "ațâțași": "ațâța",
    "ațâțat": "ațâța",
    "ațâțați": "ațâța",
    "ațâțatu": "ațâța",
    "ațâțau": "ațâța",
    "ațâțe": "ațâța",
    "ațâți": "ațâța",
    "neațâțând": "ațâța",
    "neațâțându": "ațâța",
    "nemaiațâțând": "ațâța",
    "nemaiațâțându": "ațâța",
    "ațâțarea": "ațâțare",
    "ațâțări": "ațâțare",
    "ațâțării": "ațâțare",
    "ațâțările": "ațâțare",
    "ațâțata": "ațâțat",
    "ațâțată": "ațâțat",
    "ațâțate": "ațâțat",
    "ațâțatei": "ațâțat",
    "ațâțatele": "ațâțat",
    "ațâțatelor": "ațâțat",
    "ațâțați": "ațâțat",
    "ațâțații": "ațâțat",
    "ațâțaților": "ațâțat",
    "ațâțatul": "ațâțat",
    "ațâțatului": "ațâțat",
    "ațâțătoare": "ațâțător",
    "ațâțătoarea": "ațâțător",
    "ațâțătoarei": "ațâțător",
    "ațâțătoarele": "ațâțător",
    "ațâțătoarelor": "ațâțător",
    "ațâțători": "ațâțător",
    "ațâțătorii": "ațâțător",
    "ațâțătorilor": "ațâțător",
    "ațâțătorul": "ațâțător",
    "ațâțătorului": "ațâțător",
    "atavica": "atavic",
    "atavică": "atavic",
    "atavice": "atavic",
    "atavicei": "atavic",
    "atavicele": "atavic",
    "atavicelor": "atavic",
    "atavici": "atavic",
    "atavicii": "atavic",
    "atavicilor": "atavic",
    "atavicul": "atavic",
    "atavicului": "atavic",
    "atavisme": "atavism",
    "atavismele": "atavism",
    "atavismelor": "atavism",
    "atavismul": "atavism",
    "atavismului": "atavism",
    "atea": "atee",
    "ateei": "atee",
    "ateelor": "atee",
    "ateisme": "ateism",
    "ateismele": "ateism",
    "ateismelor": "ateism",
    "ateismul": "ateism",
    "ateismului": "ateism",
    "ateista": "ateist",
    "ateistă": "ateist",
    "ateiste": "ateist",
    "ateistei": "ateist",
    "ateistele": "ateist",
    "ateistelor": "ateist",
    "ateiști": "ateist",
    "ateiștii": "ateist",
    "ateiștilor": "ateist",
    "ateistul": "ateist",
    "ateistului": "ateist",
    "ateizarea": "ateizare",
    "ateizări": "ateizare",
    "ateizării": "ateizare",
    "ateizările": "ateizare",
    "ateizărilor": "ateizare",
    "ateliere": "atelier",
    "atelierele": "atelier",
    "atelierelor": "atelier",
    "atelierul": "atelier",
    "atelierului": "atelier",
    "Atenei": "Atena",
    "atenansa": "atenansă",
    "atenanse": "atenansă",
    "atenansei": "atenansă",
    "atenansele": "atenansă",
    "atenanselor": "atenansă",
    "atenee": "ateneu",
    "ateneele": "ateneu",
    "ateneelor": "ateneu",
    "ateneul": "ateneu",
    "ateneului": "ateneu",
    "ateniana": "atenian",
    "ateniană": "atenian",
    "atenianul": "atenian",
    "atenianului": "atenian",
    "ateniene": "atenian",
    "atenienei": "atenian",
    "atenienele": "atenian",
    "atenienelor": "atenian",
    "atenieni": "atenian",
    "atenienii": "atenian",
    "atenienilor": "atenian",
    "atenta": "atent",
    "atentă": "atent",
    "atente": "atent",
    "atentei": "atent",
    "atentele": "atent",
    "atentelor": "atent",
    "atenți": "atent",
    "atenții": "atent",
    "atenților": "atent",
    "atentul": "atent",
    "atentului": "atent",
    "atentă": "atenta",
    "atentai": "atenta",
    "atentam": "atenta",
    "atentăm": "atenta",
    "atentând": "atenta",
    "atentându": "atenta",
    "atentară": "atenta",
    "atentarăm": "atenta",
    "atentarăți": "atenta",
    "atentase": "atenta",
    "atentasem": "atenta",
    "atentaseră": "atenta",
    "atentaserăm": "atenta",
    "atentaserăți": "atenta",
    "atentaseși": "atenta",
    "atentași": "atenta",
    "atentat": "atenta",
    "atentați": "atenta",
    "atentatu": "atenta",
    "atentau": "atenta",
    "atentează": "atenta",
    "atentez": "atenta",
    "atenteze": "atenta",
    "atentezi": "atenta",
    "neatentând": "atenta",
    "neatentându": "atenta",
    "nemaiatentând": "atenta",
    "nemaiatentându": "atenta",
    "atentarea": "atentare",
    "atentări": "atentare",
    "atentării": "atentare",
    "atentările": "atentare",
    "atentata": "atentat",
    "atentată": "atentat",
    "atentate": "atentat",
    "atentatei": "atentat",
    "atentatele": "atentat",
    "atentatelor": "atentat",
    "atentați": "atentat",
    "atentații": "atentat",
    "atentaților": "atentat",
    "atentatul": "atentat",
    "atentatului": "atentat",
    "atentatoarea": "atentatoare",
    "atentatoarei": "atentatoare",
    "atentatoarele": "atentatoare",
    "atentatoarelor": "atentatoare",
    "atentatori": "atentator",
    "atentatorii": "atentator",
    "atentatorilor": "atentator",
    "atentatorul": "atentator",
    "atentatorului": "atentator",
    "atenția": "atenție",
    "atenției": "atenție",
    "atenții": "atenție",
    "atențiile": "atenție",
    "atențiilor": "atenție",
    "atenționă": "atenționa",
    "atenționai": "atenționa",
    "atenționam": "atenționa",
    "atenționăm": "atenționa",
    "atenționând": "atenționa",
    "atenționându": "atenționa",
    "atenționară": "atenționa",
    "atenționarăm": "atenționa",
    "atenționarăți": "atenționa",
    "atenționase": "atenționa",
    "atenționasem": "atenționa",
    "atenționaseră": "atenționa",
    "atenționaserăm": "atenționa",
    "atenționaserăți": "atenționa",
    "atenționaseși": "atenționa",
    "atenționași": "atenționa",
    "atenționat": "atenționa",
    "atenționați": "atenționa",
    "atenționatu": "atenționa",
    "atenționau": "atenționa",
    "atenționează": "atenționa",
    "atenționez": "atenționa",
    "atenționeze": "atenționa",
    "atenționezi": "atenționa",
    "atenționarea": "atenționare",
    "atenționări": "atenționare",
    "atenționării": "atenționare",
    "atenționările": "atenționare",
    "atenționărilor": "atenționare",
    "atenționata": "atenționat",
    "atenționată": "atenționat",
    "atenționate": "atenționat",
    "atenționatei": "atenționat",
    "atenționatele": "atenționat",
    "atenționatelor": "atenționat",
    "atenționați": "atenționat",
    "atenționații": "atenționat",
    "atenționaților": "atenționat",
    "atenționatul": "atenționat",
    "atenționatului": "atenționat",
    "atențiunea": "atențiune",
    "atențiuni": "atențiune",
    "atențiunii": "atențiune",
    "atențiunile": "atențiune",
    "atențiunilor": "atențiune",
    "atenuă": "atenua",
    "atenuai": "atenua",
    "atenuam": "atenua",
    "atenuăm": "atenua",
    "atenuând": "atenua",
    "atenuându": "atenua",
    "atenuară": "atenua",
    "atenuarăm": "atenua",
    "atenuarăți": "atenua",
    "atenuase": "atenua",
    "atenuasem": "atenua",
    "atenuaseră": "atenua",
    "atenuaserăm": "atenua",
    "atenuaserăți": "atenua",
    "atenuaseși": "atenua",
    "atenuași": "atenua",
    "atenuat": "atenua",
    "atenuați": "atenua",
    "atenuatu": "atenua",
    "atenuau": "atenua",
    "atenuează": "atenua",
    "atenuez": "atenua",
    "atenueze": "atenua",
    "atenuezi": "atenua",
    "neatenuând": "atenua",
    "neatenuându": "atenua",
    "nemaiatenuând": "atenua",
    "nemaiatenuându": "atenua",
    "atenuanta": "atenuant",
    "atenuantă": "atenuant",
    "atenuante": "atenuant",
    "atenuantei": "atenuant",
    "atenuantele": "atenuant",
    "atenuantelor": "atenuant",
    "atenuanți": "atenuant",
    "atenuanții": "atenuant",
    "atenuanților": "atenuant",
    "atenuantul": "atenuant",
    "atenuantului": "atenuant",
    "atenuarea": "atenuare",
    "atenuări": "atenuare",
    "atenuării": "atenuare",
    "atenuările": "atenuare",
    "atenuata": "atenuat",
    "atenuată": "atenuat",
    "atenuate": "atenuat",
    "atenuatei": "atenuat",
    "atenuatele": "atenuat",
    "atenuatelor": "atenuat",
    "atenuați": "atenuat",
    "atenuații": "atenuat",
    "atenuaților": "atenuat",
    "atenuatul": "atenuat",
    "atenuatului": "atenuat",
    "ateriză": "ateriza",
    "aterizai": "ateriza",
    "aterizam": "ateriza",
    "aterizăm": "ateriza",
    "aterizând": "ateriza",
    "aterizându": "ateriza",
    "aterizară": "ateriza",
    "aterizarăm": "ateriza",
    "aterizarăți": "ateriza",
    "aterizase": "ateriza",
    "aterizasem": "ateriza",
    "aterizaseră": "ateriza",
    "aterizaserăm": "ateriza",
    "aterizaserăți": "ateriza",
    "aterizaseși": "ateriza",
    "aterizași": "ateriza",
    "aterizat": "ateriza",
    "aterizați": "ateriza",
    "aterizatu": "ateriza",
    "aterizau": "ateriza",
    "aterizează": "ateriza",
    "aterizez": "ateriza",
    "aterizeze": "ateriza",
    "aterizezi": "ateriza",
    "neaterizând": "ateriza",
    "neaterizându": "ateriza",
    "nemaiaterizând": "ateriza",
    "nemaiaterizându": "ateriza",
    "aterizarea": "aterizare",
    "aterizări": "aterizare",
    "aterizării": "aterizare",
    "aterizările": "aterizare",
    "aterizata": "aterizat",
    "aterizată": "aterizat",
    "aterizate": "aterizat",
    "aterizatei": "aterizat",
    "aterizatele": "aterizat",
    "aterizatelor": "aterizat",
    "aterizați": "aterizat",
    "aterizații": "aterizat",
    "aterizaților": "aterizat",
    "aterizatul": "aterizat",
    "aterizatului": "aterizat",
    "atermana": "aterman",
    "atermană": "aterman",
    "atermane": "aterman",
    "atermanei": "aterman",
    "atermanele": "aterman",
    "atermanelor": "aterman",
    "atermani": "aterman",
    "atermanii": "aterman",
    "atermanilor": "aterman",
    "atermanul": "aterman",
    "atermanului": "aterman",
    "atest": "atesta",
    "atestă": "atesta",
    "atestai": "atesta",
    "atestam": "atesta",
    "atestăm": "atesta",
    "atestând": "atesta",
    "atestându": "atesta",
    "atestară": "atesta",
    "atestarăm": "atesta",
    "atestarăți": "atesta",
    "atestase": "atesta",
    "atestasem": "atesta",
    "atestaseră": "atesta",
    "atestaserăm": "atesta",
    "atestaserăți": "atesta",
    "atestaseși": "atesta",
    "atestași": "atesta",
    "atestat": "atesta",
    "atestați": "atesta",
    "atestatu": "atesta",
    "atestau": "atesta",
    "ateste": "atesta",
    "atești": "atesta",
    "neatestând": "atesta",
    "neatestându": "atesta",
    "nemaiatestând": "atesta",
    "nemaiatestându": "atesta",
    "atestarea": "atestare",
    "atestări": "atestare",
    "atestării": "atestare",
    "atestările": "atestare",
    "atestata": "atestat",
    "atestată": "atestat",
    "atestate": "atestat",
    "atestatei": "atestat",
    "atestatele": "atestat",
    "atestatelor": "atestat",
    "atestați": "atestat",
    "atestații": "atestat",
    "atestaților": "atestat",
    "atestatul": "atestat",
    "atestatului": "atestat",
    "atei": "ateu",
    "ateii": "ateu",
    "ateilor": "ateu",
    "ateul": "ateu",
    "ateului": "ateu",
    "athoniți": "athonit",
    "athoniții": "athonit",
    "athoniților": "athonit",
    "athonitul": "athonit",
    "athonitului": "athonit",
    "atica": "atic",
    "atică": "atic",
    "atice": "atic",
    "aticei": "atic",
    "aticele": "atic",
    "aticelor": "atic",
    "atici": "atic",
    "aticii": "atic",
    "aticilor": "atic",
    "aticul": "atic",
    "aticului": "atic",
    "ații": "aține",
    "ațin": "aține",
    "ațină": "aține",
    "aținând": "aține",
    "aținându": "aține",
    "aținea": "aține",
    "ațineai": "aține",
    "ațineam": "aține",
    "ațineați": "aține",
    "ațineau": "aține",
    "aținem": "aține",
    "ațineți": "aține",
    "aținu": "aține",
    "aținui": "aține",
    "aținură": "aține",
    "aținurăm": "aține",
    "aținurăți": "aține",
    "aținuse": "aține",
    "aținusem": "aține",
    "aținuseră": "aține",
    "aținuserăm": "aține",
    "aținuserăți": "aține",
    "aținuseși": "aține",
    "aținuși": "aține",
    "aținut": "aține",
    "aținutu": "aține",
    "neaținând": "aține",
    "neaținându": "aține",
    "nemaiaținând": "aține",
    "nemaiaținându": "aține",
    "aținerea": "aținere",
    "ațineri": "aținere",
    "aținerii": "aținere",
    "aținerile": "aținere",
    "ating": "atinge",
    "atingă": "atinge",
    "atingând": "atinge",
    "atingându": "atinge",
    "atingea": "atinge",
    "atingeai": "atinge",
    "atingeam": "atinge",
    "atingeați": "atinge",
    "atingeau": "atinge",
    "atingem": "atinge",
    "atingeți": "atinge",
    "atingi": "atinge",
    "atins": "atinge",
    "atinse": "atinge",
    "atinsei": "atinge",
    "atinseră": "atinge",
    "atinserăm": "atinge",
    "atinserăți": "atinge",
    "atinsese": "atinge",
    "atinsesem": "atinge",
    "atinseseră": "atinge",
    "atinseserăm": "atinge",
    "atinseserăți": "atinge",
    "atinseseși": "atinge",
    "atinseși": "atinge",
    "atinsu": "atinge",
    "neatingând": "atinge",
    "neatingându": "atinge",
    "nemaiatingând": "atinge",
    "nemaiatingându": "atinge",
    "atingerea": "atingere",
    "atingeri": "atingere",
    "atingerii": "atingere",
    "atingerile": "atingere",
    "atinsa": "atins",
    "atinsă": "atins",
    "atinse": "atins",
    "atinsei": "atins",
    "atinsele": "atins",
    "atinselor": "atins",
    "atinși": "atins",
    "atinșii": "atins",
    "atinșilor": "atins",
    "atinsul": "atins",
    "atinsului": "atins",
    "ațintea": "aținti",
    "aținteai": "aținti",
    "aținteam": "aținti",
    "ațintească": "aținti",
    "aținteați": "aținti",
    "aținteau": "aținti",
    "ațintesc": "aținti",
    "ațintește": "aținti",
    "ațintești": "aținti",
    "ațintii": "aținti",
    "ațintim": "aținti",
    "ațintind": "aținti",
    "ațintindu": "aținti",
    "ațintiră": "aținti",
    "ațintirăm": "aținti",
    "ațintirăți": "aținti",
    "ațintise": "aținti",
    "ațintisem": "aținti",
    "ațintiseră": "aținti",
    "ațintiserăm": "aținti",
    "ațintiserăți": "aținti",
    "ațintiseși": "aținti",
    "ațintiși": "aținti",
    "ațintit": "aținti",
    "ațintiți": "aținti",
    "ațintitu": "aținti",
    "ațintirea": "ațintire",
    "ațintiri": "ațintire",
    "ațintirii": "ațintire",
    "ațintirile": "ațintire",
    "ațintirilor": "ațintire",
    "ațintita": "ațintit",
    "ațintită": "ațintit",
    "ațintite": "ațintit",
    "ațintitei": "ațintit",
    "ațintitele": "ațintit",
    "ațintitelor": "ațintit",
    "ațintiți": "ațintit",
    "ațintiții": "ațintit",
    "ațintiților": "ațintit",
    "ațintitul": "ațintit",
    "ațintitului": "ațintit",
    "aținuta": "aținut",
    "aținută": "aținut",
    "aținute": "aținut",
    "aținutei": "aținut",
    "aținutele": "aținut",
    "aținutelor": "aținut",
    "aținuți": "aținut",
    "aținuții": "aținut",
    "aținuților": "aținut",
    "aținutul": "aținut",
    "aținutului": "aținut",
    "ațipea": "ațipi",
    "ațipeai": "ațipi",
    "ațipeam": "ațipi",
    "ațipească": "ațipi",
    "ațipeați": "ațipi",
    "ațipeau": "ațipi",
    "ațipesc": "ațipi",
    "ațipește": "ațipi",
    "ațipești": "ațipi",
    "ațipii": "ațipi",
    "ațipim": "ațipi",
    "ațipind": "ațipi",
    "ațipindu": "ațipi",
    "ațipiră": "ațipi",
    "ațipirăm": "ațipi",
    "ațipirăți": "ațipi",
    "ațipise": "ațipi",
    "ațipisem": "ațipi",
    "ațipiseră": "ațipi",
    "ațipiserăm": "ațipi",
    "ațipiserăți": "ațipi",
    "ațipiseși": "ațipi",
    "ațipiși": "ațipi",
    "ațipit": "ațipi",
    "ațipiți": "ațipi",
    "ațipitu": "ațipi",
    "neațipind": "ațipi",
    "neațipindu": "ațipi",
    "nemaiațipind": "ațipi",
    "nemaiațipindu": "ațipi",
    "atipică": "atipic",
    "atipice": "atipic",
    "atipici": "atipic",
    "ațipirea": "ațipire",
    "ațipiri": "ațipire",
    "ațipirii": "ațipire",
    "ațipirile": "ațipire",
    "ațipita": "ațipit",
    "ațipită": "ațipit",
    "ațipite": "ațipit",
    "ațipitei": "ațipit",
    "ațipitele": "ațipit",
    "ațipitelor": "ațipit",
    "ațipiți": "ațipit",
    "ațipiții": "ațipit",
    "ațipiților": "ațipit",
    "ațipitul": "ațipit",
    "ațipitului": "ațipit",
    "atitudinea": "atitudine",
    "atitudini": "atitudine",
    "atitudinii": "atitudine",
    "atitudinile": "atitudine",
    "atitudinilor": "atitudine",
    "Atlantă": "Atlanta",
    "Atlante": "Atlanta",
    "Atlantei": "Atlanta",
    "atlantica": "atlantic",
    "atlantică": "atlantic",
    "atlantice": "atlantic",
    "atlanticei": "atlantic",
    "atlanticele": "atlantic",
    "atlanticelor": "atlantic",
    "atlantici": "atlantic",
    "atlanticii": "atlantic",
    "atlanticilor": "atlantic",
    "atlanticul": "atlantic",
    "Atlanticului": "Atlantic",
    "atlase": "atlas",
    "atlasele": "atlas",
    "atlaselor": "atlas",
    "atlasul": "atlas",
    "atlasului": "atlas",
    "atlazul": "atlaz",
    "atlazului": "atlaz",
    "atlazuri": "atlaz",
    "atlazurile": "atlaz",
    "atlazurilor": "atlaz",
    "atleți": "atlet",
    "atleții": "atlet",
    "atleților": "atlet",
    "atletul": "atlet",
    "atletului": "atlet",
    "atleta": "atletă",
    "atlete": "atletă",
    "atletei": "atletă",
    "atletele": "atletă",
    "atletelor": "atletă",
    "atletica": "atletic",
    "atletică": "atletic",
    "atletice": "atletic",
    "atleticei": "atletic",
    "atleticele": "atletic",
    "atleticelor": "atletic",
    "atletici": "atletic",
    "atleticii": "atletic",
    "atleticilor": "atletic",
    "atleticul": "atletic",
    "atleticului": "atletic",
    "atletisme": "atletism",
    "atletismele": "atletism",
    "atletismelor": "atletism",
    "atletismul": "atletism",
    "atletismului": "atletism",
    "atmosfera": "atmosferă",
    "atmosfere": "atmosferă",
    "atmosferei": "atmosferă",
    "atmosferele": "atmosferă",
    "atmosferelor": "atmosferă",
    "ata": "atmosferă_absolută",
    "at": "atmosferă_tehnică",
    "atmosferica": "atmosferic",
    "atmosferică": "atmosferic",
    "atmosferice": "atmosferic",
    "atmosfericei": "atmosferic",
    "atmosfericele": "atmosferic",
    "atmosfericelor": "atmosferic",
    "atmosferici": "atmosferic",
    "atmosfericii": "atmosferic",
    "atmosfericilor": "atmosferic",
    "atmosfericul": "atmosferic",
    "atmosfericului": "atmosferic",
    "atoatestăpânitoarea": "atoatestăpânitoare",
    "atoatestăpânitoarei": "atoatestăpânitoare",
    "atoatestăpânitoarele": "atoatestăpânitoare",
    "atoatestăpânitoarelor": "atoatestăpânitoare",
    "atoatestăpânitoare": "atoatestăpânitor",
    "atoatestăpânitoarea": "atoatestăpânitor",
    "atoatestăpânitoarei": "atoatestăpânitor",
    "atoatestăpânitoarele": "atoatestăpânitor",
    "atoatestăpânitoarelor": "atoatestăpânitor",
    "atoatestăpânitori": "atoatestăpânitor",
    "atoatestăpânitorii": "atoatestăpânitor",
    "atoatestăpânitorilor": "atoatestăpânitor",
    "atoatestăpânitorul": "atoatestăpânitor",
    "atoatestăpânitorului": "atoatestăpânitor",
    "atoatevăzătoare": "atoatevăzător",
    "atoatevăzătoarea": "atoatevăzător",
    "atoatevăzătoarei": "atoatevăzător",
    "atoatevăzătoarele": "atoatevăzător",
    "atoatevăzătoarelor": "atoatevăzător",
    "atoatevăzători": "atoatevăzător",
    "atoatevăzătorii": "atoatevăzător",
    "atoatevăzătorilor": "atoatevăzător",
    "atoatevăzătorul": "atoatevăzător",
    "atoatevăzătorului": "atoatevăzător",
    "atoli": "atol",
    "atolii": "atol",
    "atolilor": "atol",
    "atolul": "atol",
    "atolului": "atol",
    "atomi": "atom",
    "atomii": "atom",
    "atomilor": "atom",
    "atomul": "atom",
    "atomului": "atom",
    "atomica": "atomic",
    "atomică": "atomic",
    "atomice": "atomic",
    "atomicei": "atomic",
    "atomicele": "atomic",
    "atomicelor": "atomic",
    "atomici": "atomic",
    "atomicii": "atomic",
    "atomicilor": "atomic",
    "atomicul": "atomic",
    "atomicului": "atomic",
    "atomista": "atomist",
    "atomistă": "atomist",
    "atomiste": "atomist",
    "atomistei": "atomist",
    "atomistele": "atomist",
    "atomistelor": "atomist",
    "atomiști": "atomist",
    "atomiștii": "atomist",
    "atomiștilor": "atomist",
    "atomistul": "atomist",
    "atomistului": "atomist",
    "atona": "aton",
    "atonă": "aton",
    "atone": "aton",
    "atonei": "aton",
    "atonele": "aton",
    "atonelor": "aton",
    "atoni": "aton",
    "atonii": "aton",
    "atonilor": "aton",
    "atonul": "aton",
    "atonului": "aton",
    "atonica": "atonic",
    "atonică": "atonic",
    "atonice": "atonic",
    "atonicei": "atonic",
    "atonicele": "atonic",
    "atonicelor": "atonic",
    "atonici": "atonic",
    "atonicii": "atonic",
    "atonicilor": "atonic",
    "atonicul": "atonic",
    "atonicului": "atonic",
    "ațoasa": "ațos",
    "ațoasă": "ațos",
    "ațoase": "ațos",
    "ațoasei": "ațos",
    "ațoasele": "ațos",
    "ațoaselor": "ațos",
    "ațoși": "ațos",
    "ațoșii": "ațos",
    "ațoșilor": "ațos",
    "ațosul": "ațos",
    "ațosului": "ațos",
    "atotbiruitoare": "atotbiruitor",
    "atotbiruitoarea": "atotbiruitor",
    "atotbiruitoarei": "atotbiruitor",
    "atotbiruitoarele": "atotbiruitor",
    "atotbiruitoarelor": "atotbiruitor",
    "atotbiruitori": "atotbiruitor",
    "atotbiruitorii": "atotbiruitor",
    "atotbiruitorilor": "atotbiruitor",
    "atotbiruitorul": "atotbiruitor",
    "atotbiruitorului": "atotbiruitor",
    "atotcunoscătoarea": "atotcunoscătoare",
    "atotcunoscătoarei": "atotcunoscătoare",
    "atotcunoscătoarele": "atotcunoscătoare",
    "atotcunoscătoarelor": "atotcunoscătoare",
    "atotcunoscătoare": "atotcunoscător",
    "atotcunoscătoarea": "atotcunoscător",
    "atotcunoscătoarei": "atotcunoscător",
    "atotcunoscătoarele": "atotcunoscător",
    "atotcunoscătoarelor": "atotcunoscător",
    "atotcunoscători": "atotcunoscător",
    "atotcunoscătorii": "atotcunoscător",
    "atotcunoscătorilor": "atotcunoscător",
    "atotcunoscătorul": "atotcunoscător",
    "atotcunoscătorului": "atotcunoscător",
    "atotcuprinderea": "atotcuprindere",
    "atotcuprinderi": "atotcuprindere",
    "atotcuprinderii": "atotcuprindere",
    "atotcuprinderile": "atotcuprindere",
    "atotcuprinderilor": "atotcuprindere",
    "atotcuprinzătoare": "atotcuprinzător",
    "atotcuprinzătoarea": "atotcuprinzător",
    "atotcuprinzătoarei": "atotcuprinzător",
    "atotcuprinzătoarele": "atotcuprinzător",
    "atotcuprinzătoarelor": "atotcuprinzător",
    "atotcuprinzători": "atotcuprinzător",
    "atotcuprinzătorii": "atotcuprinzător",
    "atotcuprinzătorilor": "atotcuprinzător",
    "atotcuprinzătorul": "atotcuprinzător",
    "atotcuprinzătorului": "atotcuprinzător",
    "atotînțelegătoarea": "atotînțelegătoare",
    "atotînțelegătoarei": "atotînțelegătoare",
    "atotînțelegătoarele": "atotînțelegătoare",
    "atotînțelegătoarelor": "atotînțelegătoare",
    "atotînțelegătoare": "atotînțelegător",
    "atotînțelegătoarea": "atotînțelegător",
    "atotînțelegătoarei": "atotînțelegător",
    "atotînțelegătoarele": "atotînțelegător",
    "atotînțelegătoarelor": "atotînțelegător",
    "atotînțelegători": "atotînțelegător",
    "atotînțelegătorii": "atotînțelegător",
    "atotînțelegătorilor": "atotînțelegător",
    "atotînțelegătorul": "atotînțelegător",
    "atotînțelegătorului": "atotînțelegător",
    "atotputernica": "atotputernic",
    "atotputernică": "atotputernic",
    "atotputernice": "atotputernic",
    "atotputernicei": "atotputernic",
    "atotputernicele": "atotputernic",
    "atotputernicelor": "atotputernic",
    "atotputernici": "atotputernic",
    "atotputernicii": "atotputernic",
    "atotputernicilor": "atotputernic",
    "atotputernicul": "atotputernic",
    "atotputernicului": "atotputernic",
    "atotputernica": "atotputernică",
    "atotputernice": "atotputernică",
    "atotputernicei": "atotputernică",
    "atotputernicele": "atotputernică",
    "atotputernicelor": "atotputernică",
    "atotputernicia": "atotputernicie",
    "atotputerniciei": "atotputernicie",
    "atotputernicii": "atotputernicie",
    "atotștiutoare": "atotștiutor",
    "atotștiutoarea": "atotștiutor",
    "atotștiutoarei": "atotștiutor",
    "atotștiutoarele": "atotștiutor",
    "atotștiutoarelor": "atotștiutor",
    "atotștiutori": "atotștiutor",
    "atotștiutorii": "atotștiutor",
    "atotștiutorilor": "atotștiutor",
    "atotștiutorul": "atotștiutor",
    "atotștiutorului": "atotștiutor",
    "atotvăzătoare": "atotvăzător",
    "atotvăzătoarea": "atotvăzător",
    "atotvăzătoarei": "atotvăzător",
    "atotvăzătoarele": "atotvăzător",
    "atotvăzătoarelor": "atotvăzător",
    "atotvăzători": "atotvăzător",
    "atotvăzătorii": "atotvăzător",
    "atotvăzătorilor": "atotvăzător",
    "atotvăzătorul": "atotvăzător",
    "atotvăzătorului": "atotvăzător",
    "atracția": "atracție",
    "atracției": "atracție",
    "atracții": "atracție",
    "atracțiile": "atracție",
    "atracțiilor": "atracție",
    "atractiva": "atractiv",
    "atractivă": "atractiv",
    "atractive": "atractiv",
    "atractivei": "atractiv",
    "atractivele": "atractiv",
    "atractivelor": "atractiv",
    "atractivi": "atractiv",
    "atractivii": "atractiv",
    "atractivilor": "atractiv",
    "atractivul": "atractiv",
    "atractivului": "atractiv",
    "atrăgătoare": "atrăgător",
    "atrăgătoarea": "atrăgător",
    "atrăgătoarei": "atrăgător",
    "atrăgătoarele": "atrăgător",
    "atrăgătoarelor": "atrăgător",
    "atrăgători": "atrăgător",
    "atrăgătorii": "atrăgător",
    "atrăgătorilor": "atrăgător",
    "atrăgătorul": "atrăgător",
    "atrăgătorului": "atrăgător",
    "atrag": "atrage",
    "atragă": "atrage",
    "atrăgând": "atrage",
    "atrăgându": "atrage",
    "atrăgea": "atrage",
    "atrăgeai": "atrage",
    "atrăgeam": "atrage",
    "atrăgeați": "atrage",
    "atrăgeau": "atrage",
    "atragem": "atrage",
    "atrageți": "atrage",
    "atragi": "atrage",
    "atras": "atrage",
    "atrase": "atrage",
    "atrăsei": "atrage",
    "atraseră": "atrage",
    "atraserăm": "atrage",
    "atraserăți": "atrage",
    "atrăsese": "atrage",
    "atrăsesem": "atrage",
    "atrăseseră": "atrage",
    "atrăseserăm": "atrage",
    "atrăseserăți": "atrage",
    "atrăseseși": "atrage",
    "atrăseși": "atrage",
    "atrasu": "atrage",
    "neatrăgând": "atrage",
    "neatrăgându": "atrage",
    "nemaiatrăgând": "atrage",
    "nemaiatrăgându": "atrage",
    "atragerea": "atragere",
    "atrageri": "atragere",
    "atragerii": "atragere",
    "atragerile": "atragere",
    "atrasa": "atras",
    "atrasă": "atras",
    "atrase": "atras",
    "atrasei": "atras",
    "atrasele": "atras",
    "atraselor": "atras",
    "atrași": "atras",
    "atrașii": "atras",
    "atrașilor": "atras",
    "atrasul": "atras",
    "atrasului": "atras",
    "atribuia": "atribui",
    "atribuiai": "atribui",
    "atribuiam": "atribui",
    "atribuiați": "atribui",
    "atribuiau": "atribui",
    "atribuie": "atribui",
    "atribuii": "atribui",
    "atribuim": "atribui",
    "atribuind": "atribui",
    "atribuindu": "atribui",
    "atribuiră": "atribui",
    "atribuirăm": "atribui",
    "atribuirăți": "atribui",
    "atribuise": "atribui",
    "atribuisem": "atribui",
    "atribuiseră": "atribui",
    "atribuiserăm": "atribui",
    "atribuiserăți": "atribui",
    "atribuiseși": "atribui",
    "atribuiși": "atribui",
    "atribuit": "atribui",
    "atribuiți": "atribui",
    "atribuitu": "atribui",
    "neatribuind": "atribui",
    "neatribuindu": "atribui",
    "nemaiatribuind": "atribui",
    "nemaiatribuindu": "atribui",
    "atribuirea": "atribuire",
    "atribuiri": "atribuire",
    "atribuirii": "atribuire",
    "atribuirile": "atribuire",
    "atribuita": "atribuit",
    "atribuită": "atribuit",
    "atribuite": "atribuit",
    "atribuitei": "atribuit",
    "atribuitele": "atribuit",
    "atribuitelor": "atribuit",
    "atribuiți": "atribuit",
    "atribuiții": "atribuit",
    "atribuiților": "atribuit",
    "atribuitul": "atribuit",
    "atribuitului": "atribuit",
    "atribute": "atribut",
    "atributele": "atribut",
    "atributelor": "atribut",
    "atributul": "atribut",
    "atributului": "atribut",
    "atribuția": "atribuție",
    "atribuției": "atribuție",
    "atribuții": "atribuție",
    "atribuțiile": "atribuție",
    "atribuțiilor": "atribuție",
    "atribuțiunea": "atribuțiune",
    "atribuțiuni": "atribuțiune",
    "atribuțiunii": "atribuțiune",
    "atribuțiunile": "atribuțiune",
    "atribuțiunilor": "atribuțiune",
    "atributiva": "atributiv",
    "atributivă": "atributiv",
    "atributive": "atributiv",
    "atributivei": "atributiv",
    "atributivele": "atributiv",
    "atributivelor": "atributiv",
    "atributivi": "atributiv",
    "atributivii": "atributiv",
    "atributivilor": "atributiv",
    "atributivul": "atributiv",
    "atributivului": "atributiv",
    "Atrizi": "Atrid",
    "atrocitatea": "atrocitate",
    "atrocități": "atrocitate",
    "atrocității": "atrocitate",
    "atrocitățile": "atrocitate",
    "atrocităților": "atrocitate",
    "atrofiai": "atrofia",
    "atrofiam": "atrofia",
    "atrofiară": "atrofia",
    "atrofiarăm": "atrofia",
    "atrofiarăți": "atrofia",
    "atrofiase": "atrofia",
    "atrofiasem": "atrofia",
    "atrofiaseră": "atrofia",
    "atrofiaserăm": "atrofia",
    "atrofiaserăți": "atrofia",
    "atrofiaseși": "atrofia",
    "atrofiași": "atrofia",
    "atrofiat": "atrofia",
    "atrofiați": "atrofia",
    "atrofiatu": "atrofia",
    "atrofiau": "atrofia",
    "atrofiază": "atrofia",
    "atrofie": "atrofia",
    "atrofiem": "atrofia",
    "atrofiez": "atrofia",
    "atrofieze": "atrofia",
    "atrofiezi": "atrofia",
    "atrofiind": "atrofia",
    "atrofiindu": "atrofia",
    "neatrofiind": "atrofia",
    "neatrofiindu": "atrofia",
    "nemaiatrofiind": "atrofia",
    "nemaiatrofiindu": "atrofia",
    "atrofiata": "atrofiat",
    "atrofiată": "atrofiat",
    "atrofiate": "atrofiat",
    "atrofiatei": "atrofiat",
    "atrofiatele": "atrofiat",
    "atrofiatelor": "atrofiat",
    "atrofiați": "atrofiat",
    "atrofiații": "atrofiat",
    "atrofiaților": "atrofiat",
    "atrofiatul": "atrofiat",
    "atrofiatului": "atrofiat",
    "atrofiata": "atrofiată",
    "atrofiate": "atrofiată",
    "atrofiatei": "atrofiată",
    "atrofiatele": "atrofiată",
    "atrofiatelor": "atrofiată",
    "atrofia": "atrofie",
    "atrofiei": "atrofie",
    "atrofii": "atrofie",
    "atrofiile": "atrofie",
    "atrofiilor": "atrofie",
    "atrofierea": "atrofiere",
    "atrofieri": "atrofiere",
    "atrofierii": "atrofiere",
    "atrofierile": "atrofiere",
    "atuul": "atu",
    "atuului": "atu",
    "atuuri": "atu",
    "atuurile": "atu",
    "atuurilor": "atu",
    "auz": "aud",
    "audiai": "audia",
    "audiam": "audia",
    "audiară": "audia",
    "audiarăm": "audia",
    "audiarăți": "audia",
    "audiase": "audia",
    "audiasem": "audia",
    "audiaseră": "audia",
    "audiaserăm": "audia",
    "audiaserăți": "audia",
    "audiaseși": "audia",
    "audiași": "audia",
    "audiat": "audia",
    "audiați": "audia",
    "audiatu": "audia",
    "audiau": "audia",
    "audiază": "audia",
    "audie": "audia",
    "audiem": "audia",
    "audiez": "audia",
    "audieze": "audia",
    "audiezi": "audia",
    "audiind": "audia",
    "audiindu": "audia",
    "neaudiind": "audia",
    "neaudiindu": "audia",
    "nemaiaudiind": "audia",
    "nemaiaudiindu": "audia",
    "audiata": "audiat",
    "audiată": "audiat",
    "audiate": "audiat",
    "audiatei": "audiat",
    "audiatele": "audiat",
    "audiatelor": "audiat",
    "audiați": "audiat",
    "audiații": "audiat",
    "audiaților": "audiat",
    "audiatul": "audiat",
    "audiatului": "audiat",
    "audibila": "audibil",
    "audibilă": "audibil",
    "audibile": "audibil",
    "audibilei": "audibil",
    "audibilele": "audibil",
    "audibilelor": "audibil",
    "audibili": "audibil",
    "audibilii": "audibil",
    "audibililor": "audibil",
    "audibilul": "audibil",
    "audibilului": "audibil",
    "audiența": "audiență",
    "audiențe": "audiență",
    "audienței": "audiență",
    "audiențele": "audiență",
    "audierea": "audiere",
    "audieri": "audiere",
    "audierii": "audiere",
    "audierile": "audiere",
    "auditul": "audit",
    "auditului": "audit",
    "audiția": "audiție",
    "audiției": "audiție",
    "audiții": "audiție",
    "audițiile": "audiție",
    "audițiilor": "audiție",
    "auditiva": "auditiv",
    "auditivă": "auditiv",
    "auditive": "auditiv",
    "auditivei": "auditiv",
    "auditivele": "auditiv",
    "auditivelor": "auditiv",
    "auditivi": "auditiv",
    "auditivii": "auditiv",
    "auditivilor": "auditiv",
    "auditivul": "auditiv",
    "auditivului": "auditiv",
    "auditoarea": "auditoare",
    "auditoarei": "auditoare",
    "auditoarele": "auditoare",
    "auditoarelor": "auditoare",
    "auditoare": "auditor",
    "auditoarea": "auditor",
    "auditoarei": "auditor",
    "auditoarele": "auditor",
    "auditoarelor": "auditor",
    "auditori": "auditor",
    "auditorii": "auditor",
    "auditorilor": "auditor",
    "auditorul": "auditor",
    "auditorului": "auditor",
    "auditorii": "auditoriu",
    "auditoriile": "auditoriu",
    "auditoriilor": "auditoriu",
    "auditoriul": "auditoriu",
    "auditoriului": "auditoriu",
    "augmentă": "augmenta",
    "augmentai": "augmenta",
    "augmentam": "augmenta",
    "augmentăm": "augmenta",
    "augmentând": "augmenta",
    "augmentându": "augmenta",
    "augmentară": "augmenta",
    "augmentarăm": "augmenta",
    "augmentarăți": "augmenta",
    "augmentase": "augmenta",
    "augmentasem": "augmenta",
    "augmentaseră": "augmenta",
    "augmentaserăm": "augmenta",
    "augmentaserăți": "augmenta",
    "augmentaseși": "augmenta",
    "augmentași": "augmenta",
    "augmentat": "augmenta",
    "augmentați": "augmenta",
    "augmentatu": "augmenta",
    "augmentau": "augmenta",
    "augmentează": "augmenta",
    "augmentez": "augmenta",
    "augmenteze": "augmenta",
    "augmentezi": "augmenta",
    "neaugmentând": "augmenta",
    "neaugmentându": "augmenta",
    "nemaiaugmentând": "augmenta",
    "nemaiaugmentându": "augmenta",
    "augmentarea": "augmentare",
    "augmentări": "augmentare",
    "augmentării": "augmentare",
    "augmentările": "augmentare",
    "augmentata": "augmentat",
    "augmentată": "augmentat",
    "augmentate": "augmentat",
    "augmentatei": "augmentat",
    "augmentatele": "augmentat",
    "augmentatelor": "augmentat",
    "augmentați": "augmentat",
    "augmentații": "augmentat",
    "augmentaților": "augmentat",
    "augmentatul": "augmentat",
    "augmentatului": "augmentat",
    "augmentative": "augmentativ",
    "augmentativele": "augmentativ",
    "augmentativelor": "augmentativ",
    "augmentativi": "augmentativ",
    "augmentativul": "augmentativ",
    "augmentativului": "augmentativ",
    "augure": "augur",
    "augurele": "augur",
    "augurelor": "augur",
    "auguri": "augur",
    "augurii": "augur",
    "augurilor": "augur",
    "augurul": "augur",
    "augurului": "augur",
    "aug.": "august",
    "augusta": "august",
    "augustă": "august",
    "auguste": "august",
    "augustei": "august",
    "augustele": "august",
    "augustelor": "august",
    "auguști": "august",
    "auguștii": "august",
    "auguștilor": "august",
    "augustul": "august",
    "augustului": "august",
    "aula": "aulă",
    "aule": "aulă",
    "aulei": "aulă",
    "aulele": "aulă",
    "aulelor": "aulă",
    "Au": "aur",
    "aurul": "aur",
    "aurului": "aur",
    "aura": "aură",
    "aure": "aură",
    "aurei": "aură",
    "aurele": "aură",
    "aurelor": "aură",
    "Aurele": "Aurel",
    "aureola": "aureolă",
    "aureole": "aureolă",
    "aureolei": "aureolă",
    "aureolele": "aureolă",
    "aureolelor": "aureolă",
    "aureolata": "aureolat",
    "aureolată": "aureolat",
    "aureolate": "aureolat",
    "aureolatei": "aureolat",
    "aureolatele": "aureolat",
    "aureolatelor": "aureolat",
    "aureolați": "aureolat",
    "aureolații": "aureolat",
    "aureolaților": "aureolat",
    "aureolatul": "aureolat",
    "aureolatului": "aureolat",
    "aurea": "auri",
    "aureai": "auri",
    "auream": "auri",
    "aurească": "auri",
    "aureați": "auri",
    "aureau": "auri",
    "auresc": "auri",
    "aurește": "auri",
    "aurești": "auri",
    "aurii": "auri",
    "aurim": "auri",
    "aurind": "auri",
    "aurindu": "auri",
    "auriră": "auri",
    "aurirăm": "auri",
    "aurirăți": "auri",
    "aurise": "auri",
    "aurisem": "auri",
    "auriseră": "auri",
    "auriserăm": "auri",
    "auriserăți": "auri",
    "auriseși": "auri",
    "auriși": "auri",
    "aurit": "auri",
    "auriți": "auri",
    "auritu": "auri",
    "neaurind": "auri",
    "neaurindu": "auri",
    "nemaiaurind": "auri",
    "nemaiaurindu": "auri",
    "auricule": "auricul",
    "auriculele": "auricul",
    "auriculelor": "auricul",
    "auriculul": "auricul",
    "auriculului": "auricul",
    "auriculara": "auricular",
    "auriculară": "auricular",
    "auriculare": "auricular",
    "auricularei": "auricular",
    "auricularele": "auricular",
    "auricularelor": "auricular",
    "auriculari": "auricular",
    "auricularii": "auricular",
    "auricularilor": "auricular",
    "auricularul": "auricular",
    "auricularului": "auricular",
    "aurifera": "aurifer",
    "auriferă": "aurifer",
    "aurifere": "aurifer",
    "auriferei": "aurifer",
    "auriferele": "aurifer",
    "auriferelor": "aurifer",
    "auriferi": "aurifer",
    "auriferii": "aurifer",
    "auriferilor": "aurifer",
    "auriferul": "aurifer",
    "auriferului": "aurifer",
    "aurirea": "aurire",
    "auriri": "aurire",
    "auririi": "aurire",
    "auririle": "aurire",
    "aurita": "aurit",
    "aurită": "aurit",
    "aurite": "aurit",
    "auritei": "aurit",
    "auritele": "aurit",
    "auritelor": "aurit",
    "auriți": "aurit",
    "auriții": "aurit",
    "auriților": "aurit",
    "auritul": "aurit",
    "auritului": "aurit",
    "auziții": "aurit",
    "auria": "auriu",
    "aurie": "auriu",
    "auriei": "auriu",
    "auriele": "auriu",
    "aurielor": "auriu",
    "aurii": "auriu",
    "auriii": "auriu",
    "auriilor": "auriu",
    "auriul": "auriu",
    "auriului": "auriu",
    "auriu-cenușiu-verzuie": "auriu-cenușiu-verzui",
    "aurolaci": "aurolac",
    "aurolacii": "aurolac",
    "aurolacilor": "aurolac",
    "aurolacul": "aurolac",
    "aurolacului": "aurolac",
    "aurolaca": "aurolacă",
    "aurolace": "aurolacă",
    "aurolacei": "aurolacă",
    "aurolacele": "aurolacă",
    "aurolacelor": "aurolacă",
    "aurora": "auroră",
    "aurore": "auroră",
    "aurorei": "auroră",
    "aurorele": "auroră",
    "aurorelor": "auroră",
    "auspicii": "auspiciu",
    "auspiciile": "auspiciu",
    "auspiciilor": "auspiciu",
    "auspiciul": "auspiciu",
    "auspiciului": "auspiciu",
    "austera": "auster",
    "austeră": "auster",
    "austere": "auster",
    "austerei": "auster",
    "austerele": "auster",
    "austerelor": "auster",
    "austeri": "auster",
    "austerii": "auster",
    "austerilor": "auster",
    "austerul": "auster",
    "austerului": "auster",
    "austeritatea": "austeritate",
    "austerități": "austeritate",
    "austerității": "austeritate",
    "austeritățile": "austeritate",
    "austerităților": "austeritate",
    "australa": "austral",
    "australă": "austral",
    "australe": "austral",
    "australei": "austral",
    "australele": "austral",
    "australelor": "austral",
    "australi": "austral",
    "australii": "austral",
    "australilor": "austral",
    "australul": "austral",
    "australului": "austral",
    "Austr.": "Australia",
    "Australie": "Australia",
    "Australiei": "Australia",
    "Australii": "Australia",
    "australiana": "australian",
    "australiană": "australian",
    "australianul": "australian",
    "australianului": "australian",
    "australiene": "australian",
    "australienei": "australian",
    "australienele": "australian",
    "australienelor": "australian",
    "australieni": "australian",
    "australienii": "australian",
    "australienilor": "australian",
    "australianca": "australiancă",
    "australience": "australiancă",
    "australiencei": "australiancă",
    "australiencele": "australiancă",
    "australiencelor": "australiancă",
    "Aus.": "Austria",
    "Austrie": "Austria",
    "Austriei": "Austria",
    "Austrii": "Austria",
    "austriaca": "austriac",
    "austriacă": "austriac",
    "austriacul": "austriac",
    "austriacului": "austriac",
    "austriece": "austriac",
    "austriecei": "austriac",
    "austriecele": "austriac",
    "austriecelor": "austriac",
    "austrieci": "austriac",
    "austriecii": "austriac",
    "austriecilor": "austriac",
    "austriaca": "austriacă",
    "austriece": "austriacă",
    "austriecei": "austriacă",
    "austriecele": "austriacă",
    "austriecelor": "austriacă",
    "austro-ungară": "austro-ungar",
    "austro-ungare": "austro-ungar",
    "austro-ungari": "austro-ungar",
    "austre": "austru",
    "austrele": "austru",
    "austrelor": "austru",
    "austrul": "austru",
    "austrului": "austru",
    "autarhica": "autarhic",
    "autarhică": "autarhic",
    "autarhice": "autarhic",
    "autarhicei": "autarhic",
    "autarhicele": "autarhic",
    "autarhicelor": "autarhic",
    "autarhici": "autarhic",
    "autarhicii": "autarhic",
    "autarhicilor": "autarhic",
    "autarhicul": "autarhic",
    "autarhicului": "autarhic",
    "autentica": "autentic",
    "autentică": "autentic",
    "autentice": "autentic",
    "autenticei": "autentic",
    "autenticele": "autentic",
    "autenticelor": "autentic",
    "autentici": "autentic",
    "autenticii": "autentic",
    "autenticilor": "autentic",
    "autenticul": "autentic",
    "autenticului": "autentic",
    "autentific": "autentifica",
    "autentifică": "autentifica",
    "autentificai": "autentifica",
    "autentificam": "autentifica",
    "autentificăm": "autentifica",
    "autentificând": "autentifica",
    "autentificându": "autentifica",
    "autentificară": "autentifica",
    "autentificarăm": "autentifica",
    "autentificarăți": "autentifica",
    "autentificase": "autentifica",
    "autentificasem": "autentifica",
    "autentificaseră": "autentifica",
    "autentificaserăm": "autentifica",
    "autentificaserăți": "autentifica",
    "autentificaseși": "autentifica",
    "autentificași": "autentifica",
    "autentificat": "autentifica",
    "autentificați": "autentifica",
    "autentificatu": "autentifica",
    "autentificau": "autentifica",
    "autentifice": "autentifica",
    "autentifici": "autentifica",
    "neautentificând": "autentifica",
    "neautentificându": "autentifica",
    "nemaiautentificând": "autentifica",
    "nemaiautentificându": "autentifica",
    "autentificarea": "autentificare",
    "autentificări": "autentificare",
    "autentificării": "autentificare",
    "autentificările": "autentificare",
    "autentificata": "autentificat",
    "autentificată": "autentificat",
    "autentificate": "autentificat",
    "autentificatei": "autentificat",
    "autentificatele": "autentificat",
    "autentificatelor": "autentificat",
    "autentificați": "autentificat",
    "autentificații": "autentificat",
    "autentificaților": "autentificat",
    "autentificatul": "autentificat",
    "autentificatului": "autentificat",
    "autoamăgirea": "autoamăgire",
    "autoamăgiri": "autoamăgire",
    "autoamăgirii": "autoamăgire",
    "autoamăgirile": "autoamăgire",
    "autoamăgirilor": "autoamăgire",
    "autoanaliza": "autoanaliză",
    "autoanalize": "autoanaliză",
    "autoanalizei": "autoanaliză",
    "autoanalizele": "autoanaliză",
    "autoanalizelor": "autoanaliză",
    "auto-anihilarea": "auto-anihilare",
    "auto-anihilări": "auto-anihilare",
    "auto-anihilării": "auto-anihilare",
    "auto-anihilările": "auto-anihilare",
    "auto-anihilărilor": "auto-anihilare",
    "autoapăr": "autoapăra",
    "autoapără": "autoapăra",
    "autoapărai": "autoapăra",
    "autoapăram": "autoapăra",
    "autoapărăm": "autoapăra",
    "autoapărând": "autoapăra",
    "autoapărându": "autoapăra",
    "autoapărară": "autoapăra",
    "autoapărarăm": "autoapăra",
    "autoapărarăți": "autoapăra",
    "autoapărase": "autoapăra",
    "autoapărasem": "autoapăra",
    "autoapăraseră": "autoapăra",
    "autoapăraserăm": "autoapăra",
    "autoapăraserăți": "autoapăra",
    "autoapăraseși": "autoapăra",
    "autoapărași": "autoapăra",
    "autoapărat": "autoapăra",
    "autoapărați": "autoapăra",
    "autoapăratu": "autoapăra",
    "autoapărau": "autoapăra",
    "autoapărabilă": "autoapărabil",
    "autoapărabile": "autoapărabil",
    "autoapărabili": "autoapărabil",
    "autoapărarea": "autoapărare",
    "autoapărări": "autoapărare",
    "autoapărării": "autoapărare",
    "autoapărările": "autoapărare",
    "autoapărata": "autoapărat",
    "autoapărată": "autoapărat",
    "autoapărate": "autoapărat",
    "autoapăratei": "autoapărat",
    "autoapăratele": "autoapărat",
    "autoapăratelor": "autoapărat",
    "autoapărați": "autoapărat",
    "autoapărații": "autoapărat",
    "autoapăraților": "autoapărat",
    "autoapăratul": "autoapărat",
    "autoapăratului": "autoapărat",
    "autoapărătoarea": "autoapărătoare",
    "autoapărătoarei": "autoapărătoare",
    "autoapărătoarele": "autoapărătoare",
    "autoapărătoarelor": "autoapărătoare",
    "autoapărătoare": "autoapărător",
    "autoapărătoarea": "autoapărător",
    "autoapărătoarei": "autoapărător",
    "autoapărătoarele": "autoapărător",
    "autoapărătoarelor": "autoapărător",
    "autoapărători": "autoapărător",
    "autoapărătorii": "autoapărător",
    "autoapărătorilor": "autoapărător",
    "autoapărătorul": "autoapărător",
    "autoapărătorului": "autoapărător",
    "autoarea": "autoare",
    "autoarei": "autoare",
    "autoarele": "autoare",
    "autoarelor": "autoare",
    "auto-asigur": "auto-asigura",
    "auto-asigură": "auto-asigura",
    "auto-asigurai": "auto-asigura",
    "auto-asiguram": "auto-asigura",
    "auto-asigurăm": "auto-asigura",
    "auto-asigurând": "auto-asigura",
    "auto-asigurându": "auto-asigura",
    "auto-asigurară": "auto-asigura",
    "auto-asigurarăm": "auto-asigura",
    "auto-asigurarăți": "auto-asigura",
    "auto-asigurase": "auto-asigura",
    "auto-asigurasem": "auto-asigura",
    "auto-asiguraseră": "auto-asigura",
    "auto-asiguraserăm": "auto-asigura",
    "auto-asiguraserăți": "auto-asigura",
    "auto-asiguraseși": "auto-asigura",
    "auto-asigurași": "auto-asigura",
    "auto-asigurat": "auto-asigura",
    "auto-asigurați": "auto-asigura",
    "auto-asiguratu": "auto-asigura",
    "auto-asigurau": "auto-asigura",
    "auto-asigure": "auto-asigura",
    "auto-asiguri": "auto-asigura",
    "auto-asigurată": "auto-asigurat",
    "auto-asigurate": "auto-asigurat",
    "auto-asigurați": "auto-asigurat",
    "autobaza": "autobază",
    "autobaze": "autobază",
    "autobazei": "autobază",
    "autobazele": "autobază",
    "autobazelor": "autobază",
    "autobiografica": "autobiografic",
    "autobiografică": "autobiografic",
    "autobiografice": "autobiografic",
    "autobiograficei": "autobiografic",
    "autobiograficele": "autobiografic",
    "autobiograficelor": "autobiografic",
    "autobiografici": "autobiografic",
    "autobiograficii": "autobiografic",
    "autobiograficilor": "autobiografic",
    "autobiograficul": "autobiografic",
    "autobiograficului": "autobiografic",
    "autobiografia": "autobiografie",
    "autobiografiei": "autobiografie",
    "autobiografii": "autobiografie",
    "autobiografiile": "autobiografie",
    "autobiografiilor": "autobiografie",
    "autoblindate": "autoblindat",
    "autoblindatele": "autoblindat",
    "autoblindatelor": "autoblindat",
    "autoblindatul": "autoblindat",
    "autoblindatului": "autoblindat",
    "autobuze": "autobuz",
    "autobuzele": "autobuz",
    "autobuzelor": "autobuz",
    "autobuzul": "autobuz",
    "autobuzului": "autobuz",
    "autocare": "autocar",
    "autocarele": "autocar",
    "autocarelor": "autocar",
    "autocarul": "autocar",
    "autocarului": "autocar",
    "autocefala": "autocefal",
    "autocefală": "autocefal",
    "autocefale": "autocefal",
    "autocefalei": "autocefal",
    "autocefalele": "autocefal",
    "autocefalelor": "autocefal",
    "autocefali": "autocefal",
    "autocefalii": "autocefal",
    "autocefalilor": "autocefal",
    "autocefalul": "autocefal",
    "autocefalului": "autocefal",
    "autocompătimirii": "autocompătimire",
    "autocontrazicerea": "autocontrazicere",
    "autocontraziceri": "autocontrazicere",
    "autocontrazicerii": "autocontrazicere",
    "autocontrazicerile": "autocontrazicere",
    "autocontrazicerilor": "autocontrazicere",
    "auto-conving": "auto-convinge",
    "auto-convingă": "auto-convinge",
    "auto-convingând": "auto-convinge",
    "auto-convingându": "auto-convinge",
    "auto-convingea": "auto-convinge",
    "auto-convingeai": "auto-convinge",
    "auto-convingeam": "auto-convinge",
    "auto-convingeați": "auto-convinge",
    "auto-convingeau": "auto-convinge",
    "auto-convingem": "auto-convinge",
    "auto-convingeți": "auto-convinge",
    "auto-convingi": "auto-convinge",
    "auto-convins": "auto-convinge",
    "auto-convinse": "auto-convinge",
    "auto-convinsei": "auto-convinge",
    "auto-convinseră": "auto-convinge",
    "auto-convinserăm": "auto-convinge",
    "auto-convinserăți": "auto-convinge",
    "auto-convinsese": "auto-convinge",
    "auto-convinsesem": "auto-convinge",
    "auto-convinseseră": "auto-convinge",
    "auto-convinseserăm": "auto-convinge",
    "auto-convinseserăți": "auto-convinge",
    "auto-convinseseși": "auto-convinge",
    "auto-convinseși": "auto-convinge",
    "auto-convinsu": "auto-convinge",
    "autoconvingerea": "autoconvingere",
    "autoconvingeri": "autoconvingere",
    "autoconvingerii": "autoconvingere",
    "autoconvingerile": "autoconvingere",
    "autoconvingerilor": "autoconvingere",
    "auto-convinsă": "auto-convins",
    "auto-convinse": "auto-convins",
    "auto-convinși": "auto-convins",
    "autocratica": "autocratic",
    "autocratică": "autocratic",
    "autocratice": "autocratic",
    "autocraticei": "autocratic",
    "autocraticele": "autocratic",
    "autocraticelor": "autocratic",
    "autocratici": "autocratic",
    "autocraticii": "autocratic",
    "autocraticilor": "autocratic",
    "autocraticul": "autocratic",
    "autocraticului": "autocratic",
    "autocritica": "autocritic",
    "autocritică": "autocritic",
    "autocritice": "autocritic",
    "autocriticei": "autocritic",
    "autocriticele": "autocritic",
    "autocriticelor": "autocritic",
    "autocritici": "autocritic",
    "autocriticii": "autocritic",
    "autocriticilor": "autocritic",
    "autocriticul": "autocritic",
    "autocriticului": "autocritic",
    "autocunoașterea": "autocunoaștere",
    "autocunoașteri": "autocunoaștere",
    "autocunoașterii": "autocunoaștere",
    "autocunoașterile": "autocunoaștere",
    "autocunoașterilor": "autocunoaștere",
    "autodafeul": "autodafe",
    "autodafeului": "autodafe",
    "autodafeuri": "autodafe",
    "autodafeurile": "autodafe",
    "autodafeurilor": "autodafe",
    "autodefinea": "autodefini",
    "autodefineai": "autodefini",
    "autodefineam": "autodefini",
    "autodefinească": "autodefini",
    "autodefineați": "autodefini",
    "autodefineau": "autodefini",
    "autodefinesc": "autodefini",
    "autodefinește": "autodefini",
    "autodefinești": "autodefini",
    "autodefinii": "autodefini",
    "autodefinim": "autodefini",
    "autodefinind": "autodefini",
    "autodefinindu": "autodefini",
    "autodefiniră": "autodefini",
    "autodefinirăm": "autodefini",
    "autodefinirăți": "autodefini",
    "autodefinise": "autodefini",
    "autodefinisem": "autodefini",
    "autodefiniseră": "autodefini",
    "autodefiniserăm": "autodefini",
    "autodefiniserăți": "autodefini",
    "autodefiniseși": "autodefini",
    "autodefiniși": "autodefini",
    "autodefinit": "autodefini",
    "autodefiniți": "autodefini",
    "autodefinitu": "autodefini",
    "autodefinită": "autodefinit",
    "autodefinite": "autodefinit",
    "autodefiniți": "autodefinit",
    "autodenunțătoarea": "autodenunțătoare",
    "autodenunțătoarei": "autodenunțătoare",
    "autodenunțătoarele": "autodenunțătoare",
    "autodenunțătoarelor": "autodenunțătoare",
    "autodenunțătoare": "autodenunțător",
    "autodenunțătoarea": "autodenunțător",
    "autodenunțătoarei": "autodenunțător",
    "autodenunțătoarele": "autodenunțător",
    "autodenunțătoarelor": "autodenunțător",
    "autodenunțători": "autodenunțător",
    "autodenunțătorii": "autodenunțător",
    "autodenunțătorilor": "autodenunțător",
    "autodenunțătorul": "autodenunțător",
    "autodenunțătorului": "autodenunțător",
    "autodezvăluirea": "autodezvăluire",
    "autodezvăluiri": "autodezvăluire",
    "autodezvăluirii": "autodezvăluire",
    "autodezvăluirile": "autodezvăluire",
    "autodezvăluirilor": "autodezvăluire",
    "autodidacta": "autodidact",
    "autodidactă": "autodidact",
    "autodidacte": "autodidact",
    "autodidactei": "autodidact",
    "autodidactele": "autodidact",
    "autodidactelor": "autodidact",
    "autodidacți": "autodidact",
    "autodidacții": "autodidact",
    "autodidacților": "autodidact",
    "autodidactul": "autodidact",
    "autodidactului": "autodidact",
    "autodisciplina": "autodisciplină",
    "autodiscipline": "autodisciplină",
    "autodisciplinei": "autodisciplină",
    "autodisciplinele": "autodisciplină",
    "autodisciplinelor": "autodisciplină",
    "autodisponibilizarea": "autodisponibilizare",
    "autodisponibilizări": "autodisponibilizare",
    "autodisponibilizării": "autodisponibilizare",
    "autodisponibilizările": "autodisponibilizare",
    "autodisponibilizați": "autodisponibilizat",
    "autodisponibilizații": "autodisponibilizat",
    "autodisponibilizaților": "autodisponibilizat",
    "autodisponibilizatul": "autodisponibilizat",
    "autodisponibilizatului": "autodisponibilizat",
    "autodistrugerea": "autodistrugere",
    "autodistrugeri": "autodistrugere",
    "autodistrugerii": "autodistrugere",
    "autodistrugerile": "autodistrugere",
    "autodistrugerilor": "autodistrugere",
    "auto-examinarea": "auto-examinare",
    "auto-examinări": "auto-examinare",
    "auto-examinării": "auto-examinare",
    "auto-examinările": "auto-examinare",
    "auto-examinărilor": "auto-examinare",
    "autoflagelarea": "autoflagelare",
    "autoflagelări": "autoflagelare",
    "autoflagelării": "autoflagelare",
    "autoflagelările": "autoflagelare",
    "autoflagelărilor": "autoflagelare",
    "autoformarea": "autoformare",
    "autoformări": "autoformare",
    "autoformării": "autoformare",
    "autoformările": "autoformare",
    "autoformărilor": "autoformare",
    "autogena": "autogen",
    "autogenă": "autogen",
    "autogene": "autogen",
    "autogenei": "autogen",
    "autogenele": "autogen",
    "autogenelor": "autogen",
    "autogeni": "autogen",
    "autogenii": "autogen",
    "autogenilor": "autogen",
    "autogenul": "autogen",
    "autogenului": "autogen",
    "autogestionara": "autogestionar",
    "autogestionară": "autogestionar",
    "autogestionare": "autogestionar",
    "autogestionarei": "autogestionar",
    "autogestionarele": "autogestionar",
    "autogestionarelor": "autogestionar",
    "autogestionari": "autogestionar",
    "autogestionarii": "autogestionar",
    "autogestionarilor": "autogestionar",
    "autogestionarul": "autogestionar",
    "autogestionarului": "autogestionar",
    "autografa": "autograf",
    "autografă": "autograf",
    "autografe": "autograf",
    "autografei": "autograf",
    "autografele": "autograf",
    "autografelor": "autograf",
    "autografi": "autograf",
    "autografii": "autograf",
    "autografilor": "autograf",
    "autograful": "autograf",
    "autografului": "autograf",
    "auto-hipnoza": "auto-hipnoză",
    "auto-hipnoze": "auto-hipnoză",
    "auto-hipnozei": "auto-hipnoză",
    "auto-hipnozele": "auto-hipnoză",
    "auto-hipnozelor": "auto-hipnoză",
    "autohtona": "autohton",
    "autohtonă": "autohton",
    "autohtone": "autohton",
    "autohtonei": "autohton",
    "autohtonele": "autohton",
    "autohtonelor": "autohton",
    "autohtoni": "autohton",
    "autohtonii": "autohton",
    "autohtonilor": "autohton",
    "autohtonul": "autohton",
    "autohtonului": "autohton",
    "autoiluzionarea": "autoiluzionare",
    "autoiluzionări": "autoiluzionare",
    "autoiluzionării": "autoiluzionare",
    "autoiluzionările": "autoiluzionare",
    "autoiluzionărilor": "autoiluzionare",
    "autoimpusa": "autoimpus",
    "autoimpusă": "autoimpus",
    "autoimpuse": "autoimpus",
    "autoimpusei": "autoimpus",
    "autoimpusele": "autoimpus",
    "autoimpuselor": "autoimpus",
    "autoimpuși": "autoimpus",
    "autoimpușii": "autoimpus",
    "autoimpușilor": "autoimpus",
    "autoimpusul": "autoimpus",
    "autoimpusului": "autoimpus",
    "auto-învinovățea": "auto-învinovăți",
    "auto-învinovățeai": "auto-învinovăți",
    "auto-învinovățeam": "auto-învinovăți",
    "auto-învinovățească": "auto-învinovăți",
    "auto-învinovățeați": "auto-învinovăți",
    "auto-învinovățeau": "auto-învinovăți",
    "auto-învinovățesc": "auto-învinovăți",
    "auto-învinovățește": "auto-învinovăți",
    "auto-învinovățești": "auto-învinovăți",
    "auto-învinovății": "auto-învinovăți",
    "auto-învinovățim": "auto-învinovăți",
    "auto-învinovățind": "auto-învinovăți",
    "auto-învinovățindu": "auto-învinovăți",
    "auto-învinovățiră": "auto-învinovăți",
    "auto-învinovățirăm": "auto-învinovăți",
    "auto-învinovățirăți": "auto-învinovăți",
    "auto-învinovățise": "auto-învinovăți",
    "auto-învinovățisem": "auto-învinovăți",
    "auto-învinovățiseră": "auto-învinovăți",
    "auto-învinovățiserăm": "auto-învinovăți",
    "auto-învinovățiserăți": "auto-învinovăți",
    "auto-învinovățiseși": "auto-învinovăți",
    "auto-învinovățiși": "auto-învinovăți",
    "auto-învinovățit": "auto-învinovăți",
    "auto-învinovățiți": "auto-învinovăți",
    "auto-învinovățitu": "auto-învinovăți",
    "auto-învinovățită": "auto-învinovățit",
    "auto-învinovățite": "auto-învinovățit",
    "auto-învinovățiți": "auto-învinovățit",
    "autoînvinuia": "autoînvinui",
    "autoînvinuiai": "autoînvinui",
    "autoînvinuiam": "autoînvinui",
    "autoînvinuiască": "autoînvinui",
    "autoînvinuiați": "autoînvinui",
    "autoînvinuiau": "autoînvinui",
    "autoînvinuiește": "autoînvinui",
    "autoînvinuiești": "autoînvinui",
    "autoînvinuii": "autoînvinui",
    "autoînvinuim": "autoînvinui",
    "autoînvinuind": "autoînvinui",
    "autoînvinuindu": "autoînvinui",
    "autoînvinuiră": "autoînvinui",
    "autoînvinuirăm": "autoînvinui",
    "autoînvinuirăți": "autoînvinui",
    "autoînvinuisc": "autoînvinui",
    "autoînvinuise": "autoînvinui",
    "autoînvinuisem": "autoînvinui",
    "autoînvinuiseră": "autoînvinui",
    "autoînvinuiserăm": "autoînvinui",
    "autoînvinuiserăți": "autoînvinui",
    "autoînvinuiseși": "autoînvinui",
    "autoînvinuiși": "autoînvinui",
    "autoînvinuit": "autoînvinui",
    "autoînvinuiți": "autoînvinui",
    "autoînvinuitu": "autoînvinui",
    "autoînvinuită": "autoînvinuit",
    "autoînvinuite": "autoînvinuit",
    "autoînvinuiți": "autoînvinuit",
    "automata": "automat",
    "automată": "automat",
    "automate": "automat",
    "automatei": "automat",
    "automatele": "automat",
    "automatelor": "automat",
    "automați": "automat",
    "automații": "automat",
    "automaților": "automat",
    "automatul": "automat",
    "automatului": "automat",
    "automatica": "automatic",
    "automatică": "automatic",
    "automatice": "automatic",
    "automaticei": "automatic",
    "automaticele": "automatic",
    "automaticelor": "automatic",
    "automatici": "automatic",
    "automaticii": "automatic",
    "automaticilor": "automatic",
    "automaticul": "automatic",
    "automaticului": "automatic",
    "automatisme": "automatism",
    "automatismele": "automatism",
    "automatismelor": "automatism",
    "automatismul": "automatism",
    "automatismului": "automatism",
    "automobila": "automobil",
    "automobilă": "automobil",
    "automobile": "automobil",
    "automobilei": "automobil",
    "automobilele": "automobil",
    "automobilelor": "automobil",
    "automobili": "automobil",
    "automobilii": "automobil",
    "automobililor": "automobil",
    "automobilul": "automobil",
    "automobilului": "automobil",
    "automobilistica": "automobilistic",
    "automobilistică": "automobilistic",
    "automobilistice": "automobilistic",
    "automobilisticei": "automobilistic",
    "automobilisticele": "automobilistic",
    "automobilisticelor": "automobilistic",
    "automobilistici": "automobilistic",
    "automobilisticii": "automobilistic",
    "automobilisticilor": "automobilistic",
    "automobilisticul": "automobilistic",
    "automobilisticului": "automobilistic",
    "automulțumirea": "automulțumire",
    "automulțumiri": "automulțumire",
    "automulțumirii": "automulțumire",
    "automulțumirile": "automulțumire",
    "automulțumirilor": "automulțumire",
    "autonegarea": "autonegare",
    "autonegări": "autonegare",
    "autonegării": "autonegare",
    "autonegările": "autonegare",
    "autonegărilor": "autonegare",
    "autonoma": "autonom",
    "autonomă": "autonom",
    "autonome": "autonom",
    "autonomei": "autonom",
    "autonomele": "autonom",
    "autonomelor": "autonom",
    "autonomi": "autonom",
    "autonomii": "autonom",
    "autonomilor": "autonom",
    "autonomul": "autonom",
    "autonomului": "autonom",
    "autonomia": "autonomie",
    "autonomiei": "autonomie",
    "autonomii": "autonomie",
    "autonomiile": "autonomie",
    "autonomiilor": "autonomie",
    "autoproclamata": "autoproclamat",
    "autoproclamată": "autoproclamat",
    "autoproclamate": "autoproclamat",
    "autoproclamatei": "autoproclamat",
    "autoproclamatele": "autoproclamat",
    "autoproclamatelor": "autoproclamat",
    "autoproclamați": "autoproclamat",
    "autoproclamații": "autoproclamat",
    "autoproclamaților": "autoproclamat",
    "autoproclamatul": "autoproclamat",
    "autoproclamatului": "autoproclamat",
    "autopropulsata": "autopropulsat",
    "autopropulsată": "autopropulsat",
    "autopropulsate": "autopropulsat",
    "autopropulsatei": "autopropulsat",
    "autopropulsatele": "autopropulsat",
    "autopropulsatelor": "autopropulsat",
    "autopropulsați": "autopropulsat",
    "autopropulsații": "autopropulsat",
    "autopropulsaților": "autopropulsat",
    "autopropulsatul": "autopropulsat",
    "autopropulsatului": "autopropulsat",
    "autopsia": "autopsie",
    "autopsiei": "autopsie",
    "autopsii": "autopsie",
    "autopsiile": "autopsie",
    "autopsiilor": "autopsie",
    "autopsierea": "autopsiere",
    "autopsieri": "autopsiere",
    "autopsierii": "autopsiere",
    "autopsierile": "autopsiere",
    "autori": "autor",
    "autorii": "autor",
    "autorilor": "autor",
    "autorul": "autor",
    "autorului": "autor",
    "autoritara": "autoritar",
    "autoritară": "autoritar",
    "autoritare": "autoritar",
    "autoritarei": "autoritar",
    "autoritarele": "autoritar",
    "autoritarelor": "autoritar",
    "autoritari": "autoritar",
    "autoritarii": "autoritar",
    "autoritarilor": "autoritar",
    "autoritarul": "autoritar",
    "autoritarului": "autoritar",
    "autoritatea": "autoritate",
    "autorități": "autoritate",
    "autorității": "autoritate",
    "autoritățile": "autoritate",
    "autorităților": "autoritate",
    "autoriză": "autoriza",
    "autorizai": "autoriza",
    "autorizam": "autoriza",
    "autorizăm": "autoriza",
    "autorizând": "autoriza",
    "autorizându": "autoriza",
    "autorizară": "autoriza",
    "autorizarăm": "autoriza",
    "autorizarăți": "autoriza",
    "autorizase": "autoriza",
    "autorizasem": "autoriza",
    "autorizaseră": "autoriza",
    "autorizaserăm": "autoriza",
    "autorizaserăți": "autoriza",
    "autorizaseși": "autoriza",
    "autorizași": "autoriza",
    "autorizat": "autoriza",
    "autorizați": "autoriza",
    "autorizatu": "autoriza",
    "autorizau": "autoriza",
    "autorizează": "autoriza",
    "autorizez": "autoriza",
    "autorizeze": "autoriza",
    "autorizezi": "autoriza",
    "neautorizând": "autoriza",
    "neautorizându": "autoriza",
    "nemaiautorizând": "autoriza",
    "nemaiautorizându": "autoriza",
    "autorizarea": "autorizare",
    "autorizări": "autorizare",
    "autorizării": "autorizare",
    "autorizările": "autorizare",
    "autorizata": "autorizat",
    "autorizată": "autorizat",
    "autorizate": "autorizat",
    "autorizatei": "autorizat",
    "autorizatele": "autorizat",
    "autorizatelor": "autorizat",
    "autorizați": "autorizat",
    "autorizații": "autorizat",
    "autorizaților": "autorizat",
    "autorizatul": "autorizat",
    "autorizatului": "autorizat",
    "autorizația": "autorizație",
    "autorizației": "autorizație",
    "autorizații": "autorizație",
    "autorizațiile": "autorizație",
    "autorizațiilor": "autorizație",
    "autostrada": "autostradă",
    "autostrăzi": "autostradă",
    "autostrăzii": "autostradă",
    "autostrăzile": "autostradă",
    "autostrăzilor": "autostradă",
    "autotrenul": "autotren",
    "autotrenului": "autotren",
    "autotrenuri": "autotren",
    "autotrenurile": "autotren",
    "autotrenurilor": "autotren",
    "autoturisme": "autoturism",
    "autoturismele": "autoturism",
    "autoturismelor": "autoturism",
    "autoturismul": "autoturism",
    "autoturismului": "autoturism",
    "autoumilirea": "autoumilire",
    "autoumiliri": "autoumilire",
    "autoumilirii": "autoumilire",
    "autoumilirile": "autoumilire",
    "autoumilirilor": "autoumilire",
    "autovehicule": "autovehicul",
    "autovehiculele": "autovehicul",
    "autovehiculelor": "autovehicul",
    "autovehiculul": "autovehicul",
    "autovehiculului": "autovehicul",
    "autumnala": "autumnal",
    "autumnală": "autumnal",
    "autumnale": "autumnal",
    "autumnalei": "autumnal",
    "autumnalele": "autumnal",
    "autumnalelor": "autumnal",
    "autumnali": "autumnal",
    "autumnalii": "autumnal",
    "autumnalilor": "autumnal",
    "autumnalul": "autumnal",
    "autumnalului": "autumnal",
    "auxiliara": "auxiliar",
    "auxiliară": "auxiliar",
    "auxiliare": "auxiliar",
    "auxiliarei": "auxiliar",
    "auxiliarele": "auxiliar",
    "auxiliarelor": "auxiliar",
    "auxiliari": "auxiliar",
    "auxiliarii": "auxiliar",
    "auxiliarilor": "auxiliar",
    "auxiliarul": "auxiliar",
    "auxiliarului": "auxiliar",
    "auzul": "auz",
    "auzului": "auz",
    "aud": "auzi",
    "audă": "auzi",
    "aude": "auzi",
    "auzea": "auzi",
    "auzeai": "auzi",
    "auzeam": "auzi",
    "auzeați": "auzi",
    "auzeau": "auzi",
    "auzii": "auzi",
    "auzim": "auzi",
    "auzind": "auzi",
    "auzindu": "auzi",
    "auziră": "auzi",
    "auzirăm": "auzi",
    "auzirăți": "auzi",
    "auzise": "auzi",
    "auzisem": "auzi",
    "auziseră": "auzi",
    "auziserăm": "auzi",
    "auziserăți": "auzi",
    "auziseși": "auzi",
    "auziși": "auzi",
    "auzit": "auzi",
    "auziți": "auzi",
    "auzitu": "auzi",
    "neauzind": "auzi",
    "neauzindu": "auzi",
    "nemaiauzind": "auzi",
    "nemaiauzindu": "auzi",
    "auzirea": "auzire",
    "auziri": "auzire",
    "auzirii": "auzire",
    "auzirile": "auzire",
    "auzirilor": "auzire",
    "auzita": "auzit",
    "auzită": "auzit",
    "auzite": "auzit",
    "auzitei": "auzit",
    "auzitele": "auzit",
    "auzitelor": "auzit",
    "auziți": "auzit",
    "auziții": "auzit",
    "auziților": "auzit",
    "auzitul": "auzit",
    "auzitului": "auzit",
    "avalanșa": "avalanșă",
    "avalanșe": "avalanșă",
    "avalanșei": "avalanșă",
    "avalanșele": "avalanșă",
    "avalanșelor": "avalanșă",
    "avaliști": "avalist",
    "avaliștii": "avalist",
    "avaliștilor": "avalist",
    "avalistul": "avalist",
    "avalistului": "avalist",
    "avalista": "avalistă",
    "avaliste": "avalistă",
    "avalistei": "avalistă",
    "avalistele": "avalistă",
    "avalistelor": "avalistă",
    "avaliză": "avaliza",
    "avalizai": "avaliza",
    "avalizam": "avaliza",
    "avalizăm": "avaliza",
    "avalizând": "avaliza",
    "avalizându": "avaliza",
    "avalizară": "avaliza",
    "avalizarăm": "avaliza",
    "avalizarăți": "avaliza",
    "avalizase": "avaliza",
    "avalizasem": "avaliza",
    "avalizaseră": "avaliza",
    "avalizaserăm": "avaliza",
    "avalizaserăți": "avaliza",
    "avalizaseși": "avaliza",
    "avalizași": "avaliza",
    "avalizat": "avaliza",
    "avalizați": "avaliza",
    "avalizatu": "avaliza",
    "avalizau": "avaliza",
    "avalizează": "avaliza",
    "avalizez": "avaliza",
    "avalizeze": "avaliza",
    "avalizezi": "avaliza",
    "avalizarea": "avalizare",
    "avalizări": "avalizare",
    "avalizării": "avalizare",
    "avalizările": "avalizare",
    "avalizata": "avalizat",
    "avalizată": "avalizat",
    "avalizate": "avalizat",
    "avalizatei": "avalizat",
    "avalizatele": "avalizat",
    "avalizatelor": "avalizat",
    "avalizați": "avalizat",
    "avalizații": "avalizat",
    "avalizaților": "avalizat",
    "avalizatul": "avalizat",
    "avalizatului": "avalizat",
    "avana": "avan",
    "avană": "avan",
    "avane": "avan",
    "avanei": "avan",
    "avanele": "avan",
    "avanelor": "avan",
    "avani": "avan",
    "avanii": "avan",
    "avanilor": "avan",
    "avanul": "avan",
    "avanului": "avan",
    "avangarda": "avangardă",
    "avangardei": "avangardă",
    "avangărzi": "avangardă",
    "avangărzii": "avangardă",
    "avangărzile": "avangardă",
    "avangărzilor": "avangardă",
    "avangardismul": "avangardism",
    "avangardismului": "avangardism",
    "avangardista": "avangardist",
    "avangardistă": "avangardist",
    "avangardiste": "avangardist",
    "avangardistei": "avangardist",
    "avangardistele": "avangardist",
    "avangardistelor": "avangardist",
    "avangardiști": "avangardist",
    "avangardiștii": "avangardist",
    "avangardiștilor": "avangardist",
    "avangardistul": "avangardist",
    "avangardistului": "avangardist",
    "avangardista": "avangardistă",
    "avangardiste": "avangardistă",
    "avangardistei": "avangardistă",
    "avangardistele": "avangardistă",
    "avangardistelor": "avangardistă",
    "avanpostul": "avanpost",
    "avanpostului": "avanpost",
    "avanposturi": "avanpost",
    "avanposturile": "avanpost",
    "avanposturilor": "avanpost",
    "avanpremiera": "avanpremieră",
    "avanpremiere": "avanpremieră",
    "avanpremierei": "avanpremieră",
    "avanpremierele": "avanpremieră",
    "avanpremierelor": "avanpremieră",
    "avansul": "avans",
    "avansului": "avans",
    "avansuri": "avans",
    "avansurile": "avans",
    "avansurilor": "avans",
    "avansă": "avansa",
    "avansai": "avansa",
    "avansam": "avansa",
    "avansăm": "avansa",
    "avansând": "avansa",
    "avansându": "avansa",
    "avansară": "avansa",
    "avansarăm": "avansa",
    "avansarăți": "avansa",
    "avansase": "avansa",
    "avansasem": "avansa",
    "avansaseră": "avansa",
    "avansaserăm": "avansa",
    "avansaserăți": "avansa",
    "avansaseși": "avansa",
    "avansași": "avansa",
    "avansat": "avansa",
    "avansați": "avansa",
    "avansatu": "avansa",
    "avansau": "avansa",
    "avansează": "avansa",
    "avansez": "avansa",
    "avanseze": "avansa",
    "avansezi": "avansa",
    "neavansând": "avansa",
    "neavansându": "avansa",
    "nemaiavansând": "avansa",
    "nemaiavansându": "avansa",
    "avansarea": "avansare",
    "avansări": "avansare",
    "avansării": "avansare",
    "avansările": "avansare",
    "avansata": "avansat",
    "avansată": "avansat",
    "avansate": "avansat",
    "avansatei": "avansat",
    "avansatele": "avansat",
    "avansatelor": "avansat",
    "avansați": "avansat",
    "avansații": "avansat",
    "avansaților": "avansat",
    "avansatul": "avansat",
    "avansatului": "avansat",
    "avansata": "avansată",
    "avansate": "avansată",
    "avansatei": "avansată",
    "avansatele": "avansată",
    "avansatelor": "avansată",
    "avanscena": "avanscenă",
    "avanscene": "avanscenă",
    "avanscenei": "avanscenă",
    "avanscenele": "avanscenă",
    "avanscenelor": "avanscenă",
    "avântul": "avânt",
    "avântului": "avânt",
    "avânturi": "avânt",
    "avânturile": "avânt",
    "avânturilor": "avânt",
    "avânt": "avânta",
    "avântă": "avânta",
    "avântai": "avânta",
    "avântam": "avânta",
    "avântăm": "avânta",
    "avântând": "avânta",
    "avântându": "avânta",
    "avântară": "avânta",
    "avântarăm": "avânta",
    "avântarăți": "avânta",
    "avântase": "avânta",
    "avântasem": "avânta",
    "avântaseră": "avânta",
    "avântaserăm": "avânta",
    "avântaserăți": "avânta",
    "avântaseși": "avânta",
    "avântași": "avânta",
    "avântat": "avânta",
    "avântați": "avânta",
    "avântatu": "avânta",
    "avântau": "avânta",
    "avânte": "avânta",
    "avânți": "avânta",
    "avantaje": "avantaj",
    "avantajele": "avantaj",
    "avantajelor": "avantaj",
    "avantajul": "avantaj",
    "avantajului": "avantaj",
    "avantajai": "avantaja",
    "avantajam": "avantaja",
    "avantajând": "avantaja",
    "avantajându": "avantaja",
    "avantajară": "avantaja",
    "avantajarăm": "avantaja",
    "avantajarăți": "avantaja",
    "avantajase": "avantaja",
    "avantajasem": "avantaja",
    "avantajaseră": "avantaja",
    "avantajaserăm": "avantaja",
    "avantajaserăți": "avantaja",
    "avantajaseși": "avantaja",
    "avantajași": "avantaja",
    "avantajat": "avantaja",
    "avantajați": "avantaja",
    "avantajatu": "avantaja",
    "avantajau": "avantaja",
    "avantaje": "avantaja",
    "avantajează": "avantaja",
    "avantaji": "avantaja",
    "avantajarea": "avantajare",
    "avantajată": "avantajat",
    "avantajate": "avantajat",
    "avantajați": "avantajat",
    "avantajatul": "avantajat",
    "avantajatului": "avantajat",
    "avantajoasa": "avantajos",
    "avantajoasă": "avantajos",
    "avantajoase": "avantajos",
    "avantajoasei": "avantajos",
    "avantajoasele": "avantajos",
    "avantajoaselor": "avantajos",
    "avantajoși": "avantajos",
    "avantajoșii": "avantajos",
    "avantajoșilor": "avantajos",
    "avantajosul": "avantajos",
    "avantajosului": "avantajos",
    "avântași": "avântat",
    "avântată": "avântat",
    "avântate": "avântat",
    "avara": "avar",
    "avară": "avar",
    "avare": "avar",
    "avarei": "avar",
    "avarele": "avar",
    "avarelor": "avar",
    "avari": "avar",
    "avarii": "avar",
    "avarilor": "avar",
    "avarul": "avar",
    "avarului": "avar",
    "avara": "avară",
    "avare": "avară",
    "avarei": "avară",
    "avarele": "avară",
    "avarelor": "avară",
    "avariai": "avaria",
    "avariam": "avaria",
    "avariară": "avaria",
    "avariarăm": "avaria",
    "avariarăți": "avaria",
    "avariase": "avaria",
    "avariasem": "avaria",
    "avariaseră": "avaria",
    "avariaserăm": "avaria",
    "avariaserăți": "avaria",
    "avariaseși": "avaria",
    "avariași": "avaria",
    "avariat": "avaria",
    "avariați": "avaria",
    "avariatu": "avaria",
    "avariau": "avaria",
    "avariază": "avaria",
    "avarie": "avaria",
    "avariem": "avaria",
    "avariez": "avaria",
    "avarieze": "avaria",
    "avariezi": "avaria",
    "avariind": "avaria",
    "avariindu": "avaria",
    "neavariind": "avaria",
    "neavariindu": "avaria",
    "nemaiavariind": "avaria",
    "nemaiavariindu": "avaria",
    "avariata": "avariat",
    "avariată": "avariat",
    "avariate": "avariat",
    "avariatei": "avariat",
    "avariatele": "avariat",
    "avariatelor": "avariat",
    "avariați": "avariat",
    "avariații": "avariat",
    "avariaților": "avariat",
    "avariatul": "avariat",
    "avariatului": "avariat",
    "avaria": "avarie",
    "avariei": "avarie",
    "avarii": "avarie",
    "avariile": "avarie",
    "avariilor": "avarie",
    "avarierea": "avariere",
    "avarieri": "avariere",
    "avarierii": "avariere",
    "avarierile": "avariere",
    "avariția": "avariție",
    "avariției": "avariție",
    "avariții": "avariție",
    "avarițiile": "avariție",
    "avarițiilor": "avariție",
    "avatarul": "avatar",
    "avatarului": "avatar",
    "avataruri": "avatar",
    "avatarurile": "avatar",
    "avatarurilor": "avatar",
    "a": "avea",
    "a-": "avea",
    "ai": "avea",
    "aibă": "avea",
    "am": "avea",
    "ar": "avea",
    "are": "avea",
    "aș": "avea",
    "ați": "avea",
    "au": "avea",
    "având": "avea",
    "avându": "avea",
    "aveai": "avea",
    "aveam": "avea",
    "aveați": "avea",
    "aveau": "avea",
    "avem": "avea",
    "aveți": "avea",
    "avu": "avea",
    "avui": "avea",
    "avură": "avea",
    "avurăm": "avea",
    "avurăți": "avea",
    "avuse": "avea",
    "avusei": "avea",
    "avuseră": "avea",
    "avuserăm": "avea",
    "avuserăți": "avea",
    "avusese": "avea",
    "avusesei": "avea",
    "avusesem": "avea",
    "avuseseră": "avea",
    "avuseserăm": "avea",
    "avuseserăți": "avea",
    "avuseseși": "avea",
    "avuseși": "avea",
    "avuși": "avea",
    "avut": "avea",
    "avutu": "avea",
    "neavând": "avea",
    "neavându": "avea",
    "nemaiavând": "avea",
    "nemaiavându": "avea",
    "aventură": "aventura",
    "aventurai": "aventura",
    "aventuram": "aventura",
    "aventurăm": "aventura",
    "aventurând": "aventura",
    "aventurându": "aventura",
    "aventurară": "aventura",
    "aventurarăm": "aventura",
    "aventurarăți": "aventura",
    "aventurase": "aventura",
    "aventurasem": "aventura",
    "aventuraseră": "aventura",
    "aventuraserăm": "aventura",
    "aventuraserăți": "aventura",
    "aventuraseși": "aventura",
    "aventurași": "aventura",
    "aventurat": "aventura",
    "aventurați": "aventura",
    "aventuratu": "aventura",
    "aventurau": "aventura",
    "aventurează": "aventura",
    "aventurez": "aventura",
    "aventureze": "aventura",
    "aventurezi": "aventura",
    "neaventurând": "aventura",
    "neaventurându": "aventura",
    "nemaiaventurând": "aventura",
    "nemaiaventurându": "aventura",
    "aventura": "aventură",
    "aventuri": "aventură",
    "aventurii": "aventură",
    "aventurile": "aventură",
    "aventurilor": "aventură",
    "aventurarea": "aventurare",
    "aventurări": "aventurare",
    "aventurării": "aventurare",
    "aventurările": "aventurare",
    "aventurata": "aventurat",
    "aventurată": "aventurat",
    "aventurate": "aventurat",
    "aventuratei": "aventurat",
    "aventuratele": "aventurat",
    "aventuratelor": "aventurat",
    "aventurați": "aventurat",
    "aventurații": "aventurat",
    "aventuraților": "aventurat",
    "aventuratul": "aventurat",
    "aventuratului": "aventurat",
    "aventurieri": "aventurier",
    "aventurierii": "aventurier",
    "aventurierilor": "aventurier",
    "aventurierul": "aventurier",
    "aventurierului": "aventurier",
    "aventuriera": "aventurieră",
    "aventuriere": "aventurieră",
    "aventurierei": "aventurieră",
    "aventurierele": "aventurieră",
    "aventurierelor": "aventurieră",
    "aventuroasa": "aventuros",
    "aventuroasă": "aventuros",
    "aventuroase": "aventuros",
    "aventuroasei": "aventuros",
    "aventuroasele": "aventuros",
    "aventuroaselor": "aventuros",
    "aventuroși": "aventuros",
    "aventuroșii": "aventuros",
    "aventuroșilor": "aventuros",
    "aventurosul": "aventuros",
    "aventurosului": "aventuros",
    "Av.": "avenue",
    "Ave.": "avenue",
    "averea": "avere",
    "averi": "avere",
    "averii": "avere",
    "averile": "avere",
    "averilor": "avere",
    "aversul": "avers",
    "aversului": "avers",
    "aversuri": "avers",
    "aversurile": "avers",
    "aversurilor": "avers",
    "aversa": "aversă",
    "averse": "aversă",
    "aversei": "aversă",
    "aversele": "aversă",
    "averselor": "aversă",
    "aversiunea": "aversiune",
    "aversiuni": "aversiune",
    "aversiunii": "aversiune",
    "aversiunile": "aversiune",
    "aversiunilor": "aversiune",
    "avertismente": "avertisment",
    "avertismentele": "avertisment",
    "avertismentelor": "avertisment",
    "avertismentul": "avertisment",
    "avertismentului": "avertisment",
    "avertiză": "avertiza",
    "avertizai": "avertiza",
    "avertizam": "avertiza",
    "avertizăm": "avertiza",
    "avertizând": "avertiza",
    "avertizându": "avertiza",
    "avertizară": "avertiza",
    "avertizarăm": "avertiza",
    "avertizarăți": "avertiza",
    "avertizase": "avertiza",
    "avertizasem": "avertiza",
    "avertizaseră": "avertiza",
    "avertizaserăm": "avertiza",
    "avertizaserăți": "avertiza",
    "avertizaseși": "avertiza",
    "avertizași": "avertiza",
    "avertizat": "avertiza",
    "avertizați": "avertiza",
    "avertizatu": "avertiza",
    "avertizau": "avertiza",
    "avertizează": "avertiza",
    "avertizez": "avertiza",
    "avertizeze": "avertiza",
    "avertizezi": "avertiza",
    "neavertizând": "avertiza",
    "neavertizându": "avertiza",
    "nemaiavertizând": "avertiza",
    "nemaiavertizându": "avertiza",
    "avertizarea": "avertizare",
    "avertizări": "avertizare",
    "avertizării": "avertizare",
    "avertizările": "avertizare",
    "avertizata": "avertizat",
    "avertizată": "avertizat",
    "avertizate": "avertizat",
    "avertizatei": "avertizat",
    "avertizatele": "avertizat",
    "avertizatelor": "avertizat",
    "avertizați": "avertizat",
    "avertizații": "avertizat",
    "avertizaților": "avertizat",
    "avertizatul": "avertizat",
    "avertizatului": "avertizat",
    "aviatica": "aviatic",
    "aviatică": "aviatic",
    "aviatice": "aviatic",
    "aviaticei": "aviatic",
    "aviaticele": "aviatic",
    "aviaticelor": "aviatic",
    "aviatici": "aviatic",
    "aviaticii": "aviatic",
    "aviaticilor": "aviatic",
    "aviaticul": "aviatic",
    "aviaticului": "aviatic",
    "aviația": "aviație",
    "aviației": "aviație",
    "aviații": "aviație",
    "aviațiile": "aviație",
    "aviațiilor": "aviație",
    "aviatoarea": "aviatoare",
    "aviatoarei": "aviatoare",
    "aviatoarele": "aviatoare",
    "aviatoarelor": "aviatoare",
    "aviatori": "aviator",
    "aviatorii": "aviator",
    "aviatorilor": "aviator",
    "aviatorul": "aviator",
    "aviatorului": "aviator",
    "avicola": "avicol",
    "avicolă": "avicol",
    "avicole": "avicol",
    "avicolei": "avicol",
    "avicolele": "avicol",
    "avicolelor": "avicol",
    "avicoli": "avicol",
    "avicolii": "avicol",
    "avicolilor": "avicol",
    "avicolul": "avicol",
    "avicolului": "avicol",
    "avicultoarea": "avicultoare",
    "avicultoarei": "avicultoare",
    "avicultoarele": "avicultoare",
    "avicultoarelor": "avicultoare",
    "avicultori": "avicultor",
    "avicultorii": "avicultor",
    "avicultorilor": "avicultor",
    "avicultorul": "avicultor",
    "avicultorului": "avicultor",
    "av.": "avicultură",
    "avicultura": "avicultură",
    "aviculturi": "avicultură",
    "aviculturii": "avicultură",
    "aviculturile": "avicultură",
    "aviculturilor": "avicultură",
    "avida": "avid",
    "avidă": "avid",
    "avide": "avid",
    "avidei": "avid",
    "avidele": "avid",
    "avidelor": "avid",
    "avidul": "avid",
    "avidului": "avid",
    "avizi": "avid",
    "avizii": "avid",
    "avizilor": "avid",
    "avioane": "avion",
    "avioanele": "avion",
    "avioanelor": "avion",
    "avionul": "avion",
    "avionului": "avion",
    "avioneta": "avionetă",
    "avionete": "avionetă",
    "avionetei": "avionetă",
    "avionetele": "avionetă",
    "avionetelor": "avionetă",
    "avitaminoza": "avitaminoză",
    "avitaminoze": "avitaminoză",
    "avitaminozei": "avitaminoză",
    "avitaminozele": "avitaminoză",
    "avitaminozelor": "avitaminoză",
    "avize": "aviz",
    "avizele": "aviz",
    "avizelor": "aviz",
    "avizul": "aviz",
    "avizului": "aviz",
    "aviză": "aviza",
    "avizai": "aviza",
    "avizam": "aviza",
    "avizăm": "aviza",
    "avizând": "aviza",
    "avizându": "aviza",
    "avizară": "aviza",
    "avizarăm": "aviza",
    "avizarăți": "aviza",
    "avizase": "aviza",
    "avizasem": "aviza",
    "avizaseră": "aviza",
    "avizaserăm": "aviza",
    "avizaserăți": "aviza",
    "avizaseși": "aviza",
    "avizași": "aviza",
    "avizat": "aviza",
    "avizați": "aviza",
    "avizatu": "aviza",
    "avizau": "aviza",
    "avizează": "aviza",
    "avizez": "aviza",
    "avizeze": "aviza",
    "avizezi": "aviza",
    "neavizând": "aviza",
    "neavizându": "aviza",
    "nemaiavizând": "aviza",
    "nemaiavizându": "aviza",
    "avizarea": "avizare",
    "avizări": "avizare",
    "avizării": "avizare",
    "avizările": "avizare",
    "avizata": "avizat",
    "avizată": "avizat",
    "avizate": "avizat",
    "avizatei": "avizat",
    "avizatele": "avizat",
    "avizatelor": "avizat",
    "avizați": "avizat",
    "avizații": "avizat",
    "avizaților": "avizat",
    "avizatul": "avizat",
    "avizatului": "avizat",
    "aviziere": "avizier",
    "avizierele": "avizier",
    "avizierelor": "avizier",
    "avizierul": "avizier",
    "avizierului": "avizier",
    "avocați": "avocat",
    "avocații": "avocat",
    "avocaților": "avocat",
    "avocatul": "avocat",
    "avocatului": "avocat",
    "avortă": "avorta",
    "avortai": "avorta",
    "avortam": "avorta",
    "avortăm": "avorta",
    "avortând": "avorta",
    "avortându": "avorta",
    "avortară": "avorta",
    "avortarăm": "avorta",
    "avortarăți": "avorta",
    "avortase": "avorta",
    "avortasem": "avorta",
    "avortaseră": "avorta",
    "avortaserăm": "avorta",
    "avortaserăți": "avorta",
    "avortaseși": "avorta",
    "avortași": "avorta",
    "avortat": "avorta",
    "avortați": "avorta",
    "avortatu": "avorta",
    "avortau": "avorta",
    "avortează": "avorta",
    "avortez": "avorta",
    "avorteze": "avorta",
    "avortezi": "avorta",
    "neavortând": "avorta",
    "neavortându": "avorta",
    "nemaiavortând": "avorta",
    "nemaiavortându": "avorta",
    "avortarea": "avortare",
    "avortări": "avortare",
    "avortării": "avortare",
    "avortările": "avortare",
    "avortata": "avortat",
    "avortată": "avortat",
    "avortate": "avortat",
    "avortatei": "avortat",
    "avortatele": "avortat",
    "avortatelor": "avortat",
    "avortați": "avortat",
    "avortații": "avortat",
    "avortaților": "avortat",
    "avortatul": "avortat",
    "avortatului": "avortat",
    "avortoni": "avorton",
    "avortonii": "avorton",
    "avortonilor": "avorton",
    "avortonul": "avorton",
    "avortonului": "avorton",
    "avuabila": "avuabil",
    "avuabilă": "avuabil",
    "avuabile": "avuabil",
    "avuabilei": "avuabil",
    "avuabilele": "avuabil",
    "avuabilelor": "avuabil",
    "avuabili": "avuabil",
    "avuabilii": "avuabil",
    "avuabililor": "avuabil",
    "avuabilul": "avuabil",
    "avuabilului": "avuabil",
    "avuta": "avut",
    "avută": "avut",
    "avute": "avut",
    "avutei": "avut",
    "avutele": "avut",
    "avutelor": "avut",
    "avuți": "avut",
    "avuții": "avut",
    "avuților": "avut",
    "avutul": "avut",
    "avutului": "avut",
    "avuta": "avută",
    "avute": "avută",
    "avutei": "avută",
    "avutele": "avută",
    "avutelor": "avută",
    "avuția": "avuție",
    "avuției": "avuție",
    "avuții": "avuție",
    "avuțiile": "avuție",
    "avuțiilor": "avuție",
    "axe": "ax",
    "axele": "ax",
    "axelor": "ax",
    "axul": "ax",
    "axului": "ax",
    "axă": "axa",
    "axai": "axa",
    "axam": "axa",
    "axăm": "axa",
    "axând": "axa",
    "axându": "axa",
    "axară": "axa",
    "axarăm": "axa",
    "axarăți": "axa",
    "axase": "axa",
    "axasem": "axa",
    "axaseră": "axa",
    "axaserăm": "axa",
    "axaserăți": "axa",
    "axaseși": "axa",
    "axași": "axa",
    "axat": "axa",
    "axați": "axa",
    "axatu": "axa",
    "axau": "axa",
    "axează": "axa",
    "axez": "axa",
    "axeze": "axa",
    "axezi": "axa",
    "neaxând": "axa",
    "neaxându": "axa",
    "nemaiaxând": "axa",
    "nemaiaxându": "axa",
    "axa": "axă",
    "axe": "axă",
    "axei": "axă",
    "axele": "axă",
    "axelor": "axă",
    "axarea": "axare",
    "axări": "axare",
    "axării": "axare",
    "axările": "axare",
    "axata": "axat",
    "axată": "axat",
    "axate": "axat",
    "axatei": "axat",
    "axatele": "axat",
    "axatelor": "axat",
    "axați": "axat",
    "axații": "axat",
    "axaților": "axat",
    "axatul": "axat",
    "axatului": "axat",
    "axiala": "axial",
    "axială": "axial",
    "axiale": "axial",
    "axialei": "axial",
    "axialele": "axial",
    "axialelor": "axial",
    "axiali": "axial",
    "axialii": "axial",
    "axialilor": "axial",
    "axialul": "axial",
    "axialului": "axial",
    "axilara": "axilar",
    "axilară": "axilar",
    "axilare": "axilar",
    "axilarei": "axilar",
    "axilarele": "axilar",
    "axilarelor": "axilar",
    "axilari": "axilar",
    "axilarii": "axilar",
    "axilarilor": "axilar",
    "axilarul": "axilar",
    "axilarului": "axilar",
    "axiologia": "axiologie",
    "axiologiei": "axiologie",
    "axiologii": "axiologie",
    "axiologiile": "axiologie",
    "axiologiilor": "axiologie",
    "axioma": "axiomă",
    "axiome": "axiomă",
    "axiomei": "axiomă",
    "axiomele": "axiomă",
    "axiomelor": "axiomă",
    "axiomatica": "axiomatic",
    "axiomatică": "axiomatic",
    "axiomatice": "axiomatic",
    "axiomaticei": "axiomatic",
    "axiomaticele": "axiomatic",
    "axiomaticelor": "axiomatic",
    "axiomatici": "axiomatic",
    "axiomaticii": "axiomatic",
    "axiomaticilor": "axiomatic",
    "axiomaticul": "axiomatic",
    "axiomaticului": "axiomatic",
    "axiomatizarea": "axiomatizare",
    "axiomatizări": "axiomatizare",
    "axiomatizării": "axiomatizare",
    "axiomatizările": "axiomatizare",
    "axiomatizărilor": "axiomatizare",
    "axiomatizată": "axiomatizat",
    "axiomatizate": "axiomatizat",
    "axiomatizați": "axiomatizat",
    "azbestul": "azbest",
    "azbestului": "azbest",
    "azbesturi": "azbest",
    "azbesturile": "azbest",
    "azbesturilor": "azbest",
    "azbocimente": "azbociment",
    "azbocimentele": "azbociment",
    "azbocimentelor": "azbociment",
    "azbocimentul": "azbociment",
    "azbocimentului": "azbociment",
    "azilul": "azil",
    "azilului": "azil",
    "aziluri": "azil",
    "azilurile": "azil",
    "azilurilor": "azil",
    "azimutala": "azimutal",
    "azimutală": "azimutal",
    "azimutale": "azimutal",
    "azimutalei": "azimutal",
    "azimutalele": "azimutal",
    "azimutalelor": "azimutal",
    "azimutali": "azimutal",
    "azimutalii": "azimutal",
    "azimutalilor": "azimutal",
    "azimutalul": "azimutal",
    "azimutalului": "azimutal",
    "azotul": "azot",
    "azotului": "azot",
    "azotica": "azotic",
    "azotică": "azotic",
    "azotice": "azotic",
    "azoticei": "azotic",
    "azoticele": "azotic",
    "azoticelor": "azotic",
    "azotici": "azotic",
    "azoticii": "azotic",
    "azoticilor": "azotic",
    "azoticul": "azotic",
    "azoticului": "azotic",
    "azotoasa": "azotos",
    "azotoasă": "azotos",
    "azotoase": "azotos",
    "azotoasei": "azotos",
    "azotoasele": "azotos",
    "azotoaselor": "azotos",
    "azotoși": "azotos",
    "azotoșii": "azotos",
    "azotoșilor": "azotos",
    "azotosul": "azotos",
    "azotosului": "azotos",
    "azurul": "azur",
    "azurului": "azur",
    "azurata": "azurat",
    "azurată": "azurat",
    "azurate": "azurat",
    "azuratei": "azurat",
    "azuratele": "azurat",
    "azuratelor": "azurat",
    "azurați": "azurat",
    "azurații": "azurat",
    "azuraților": "azurat",
    "azuratul": "azurat",
    "azuratului": "azurat",
    "azuria": "azuriu",
    "azurie": "azuriu",
    "azuriei": "azuriu",
    "azurii": "azuriu",
    "azuriii": "azuriu",
    "azuriile": "azuriu",
    "azuriilor": "azuriu",
    "azuriul": "azuriu",
    "azuriului": "azuriu",
    "azvârl": "azvârli",
    "azvârle": "azvârli",
    "azvârlea": "azvârli",
    "azvârleai": "azvârli",
    "azvârleam": "azvârli",
    "azvârleați": "azvârli",
    "azvârleau": "azvârli",
    "azvârlii": "azvârli",
    "azvârlim": "azvârli",
    "azvârlind": "azvârli",
    "azvârlindu": "azvârli",
    "azvârliră": "azvârli",
    "azvârlirăm": "azvârli",
    "azvârlirăți": "azvârli",
    "azvârlise": "azvârli",
    "azvârlisem": "azvârli",
    "azvârliseră": "azvârli",
    "azvârliserăm": "azvârli",
    "azvârliserăți": "azvârli",
    "azvârliseși": "azvârli",
    "azvârliși": "azvârli",
    "azvârlit": "azvârli",
    "azvârliți": "azvârli",
    "azvârlitu": "azvârli",
    "neazvârlind": "azvârli",
    "neazvârlindu": "azvârli",
    "nemaiazvârlind": "azvârli",
    "nemaiazvârlindu": "azvârli",
    "azvârlirea": "azvârlire",
    "azvârliri": "azvârlire",
    "azvârlirii": "azvârlire",
    "azvârlirile": "azvârlire",
    "azvârlita": "azvârlit",
    "azvârlită": "azvârlit",
    "azvârlite": "azvârlit",
    "azvârlitei": "azvârlit",
    "azvârlitele": "azvârlit",
    "azvârlitelor": "azvârlit",
    "azvârliți": "azvârlit",
    "azvârliții": "azvârlit",
    "azvârliților": "azvârlit",
    "azvârlitul": "azvârlit",
    "azvârlitului": "azvârlit",
    "baba": "babă",
    "babe": "babă",
    "babei": "babă",
    "babele": "babă",
    "babelor": "babă",
    "babo": "babă",
    "babilonia": "babilonie",
    "babiloniei": "babilonie",
    "babilonii": "babilonie",
    "babiloniile": "babilonie",
    "babiloniilor": "babilonie",
    "babordul": "babord",
    "babordului": "babord",
    "baborduri": "babord",
    "babordurile": "babord",
    "babordurilor": "babord",
    "bacul": "bac",
    "bacului": "bac",
    "bacuri": "bac",
    "bacurile": "bac",
    "bacurilor": "bac",
    "bacalaureate": "bacalaureat",
    "bacalaureatele": "bacalaureat",
    "bacalaureatelor": "bacalaureat",
    "bacalaureatul": "bacalaureat",
    "bacalaureatului": "bacalaureat",
    "bacanta": "bacantă",
    "bacante": "bacantă",
    "bacantei": "bacantă",
    "bacantele": "bacantă",
    "bacantelor": "bacantă",
    "Bacăul": "Bacău",
    "Bacăului": "Bacău",
    "bachelita": "bachelită",
    "bachelite": "bachelită",
    "bachelitei": "bachelită",
    "bachelitele": "bachelită",
    "bachelitelor": "bachelită",
    "bacii": "baci",
    "bacilor": "baci",
    "baciul": "baci",
    "baciului": "baci",
    "bacili": "bacil",
    "bacilii": "bacil",
    "bacililor": "bacil",
    "bacilul": "bacil",
    "bacilului": "bacil",
    "bacteria": "bacterie",
    "bacteriei": "bacterie",
    "bacterii": "bacterie",
    "bacteriile": "bacterie",
    "bacteriilor": "bacterie",
    "bacteriologia": "bacteriologie",
    "bacteriologiei": "bacteriologie",
    "bacteriologii": "bacteriologie",
    "bacteriologiile": "bacteriologie",
    "bacteriologiilor": "bacteriologie",
    "Badahșanul": "Badahșan",
    "Badahșanului": "Badahșan",
    "bădărani": "bădăran",
    "bădăranii": "bădăran",
    "bădăranilor": "bădăran",
    "bădăranul": "bădăran",
    "bădăranului": "bădăran",
    "bădărana": "bădărană",
    "bădărane": "bădărană",
    "bădăranei": "bădărană",
    "bădăranele": "bădărană",
    "bădăranelor": "bădărană",
    "bădia": "bădie",
    "bădiei": "bădie",
    "bădii": "bădie",
    "bădiii": "bădie",
    "bădiilor": "bădie",
    "badijonă": "badijona",
    "badijonai": "badijona",
    "badijonam": "badijona",
    "badijonăm": "badijona",
    "badijonând": "badijona",
    "badijonându": "badijona",
    "badijonară": "badijona",
    "badijonarăm": "badijona",
    "badijonarăți": "badijona",
    "badijonase": "badijona",
    "badijonasem": "badijona",
    "badijonaseră": "badijona",
    "badijonaserăm": "badijona",
    "badijonaserăți": "badijona",
    "badijonaseși": "badijona",
    "badijonași": "badijona",
    "badijonat": "badijona",
    "badijonați": "badijona",
    "badijonatu": "badijona",
    "badijonau": "badijona",
    "badijonează": "badijona",
    "badijonez": "badijona",
    "badijoneze": "badijona",
    "badijonezi": "badijona",
    "nebadijonând": "badijona",
    "nebadijonându": "badijona",
    "nemaibadijonând": "badijona",
    "nemaibadijonându": "badijona",
    "badijonarea": "badijonare",
    "badijonări": "badijonare",
    "badijonării": "badijonare",
    "badijonările": "badijonare",
    "badijonata": "badijonat",
    "badijonată": "badijonat",
    "badijonate": "badijonat",
    "badijonatei": "badijonat",
    "badijonatele": "badijonat",
    "badijonatelor": "badijonat",
    "badijonați": "badijonat",
    "badijonații": "badijonat",
    "badijonaților": "badijonat",
    "badijonatul": "badijonat",
    "badijonatului": "badijonat",
    "bag": "băga",
    "bagă": "băga",
    "băgă": "băga",
    "băgai": "băga",
    "băgam": "băga",
    "băgăm": "băga",
    "băgând": "băga",
    "băgându": "băga",
    "băgară": "băga",
    "băgarăm": "băga",
    "băgarăți": "băga",
    "băgase": "băga",
    "băgasem": "băga",
    "băgaseră": "băga",
    "băgaserăm": "băga",
    "băgaserăți": "băga",
    "băgaseși": "băga",
    "băgași": "băga",
    "băgat": "băga",
    "băgați": "băga",
    "băgatu": "băga",
    "băgau": "băga",
    "bage": "băga",
    "bagi": "băga",
    "nebăgând": "băga",
    "nebăgându": "băga",
    "nemaibăgând": "băga",
    "nemaibăgându": "băga",
    "bagaje": "bagaj",
    "bagajele": "bagaj",
    "bagajelor": "bagaj",
    "bagajul": "bagaj",
    "bagajului": "bagaj",
    "băgarea": "băgare",
    "băgareo": "băgare",
    "băgări": "băgare",
    "băgării": "băgare",
    "băgările": "băgare",
    "băgărilor": "băgare",
    "băgăreți": "băgăreț",
    "băgăreții": "băgăreț",
    "băgăreților": "băgăreț",
    "băgărețul": "băgăreț",
    "băgărețului": "băgăreț",
    "băgata": "băgat",
    "băgată": "băgat",
    "băgate": "băgat",
    "băgatei": "băgat",
    "băgatele": "băgat",
    "băgatelor": "băgat",
    "băgați": "băgat",
    "băgații": "băgat",
    "băgaților": "băgat",
    "băgato": "băgat",
    "băgatul": "băgat",
    "băgatule": "băgat",
    "băgatului": "băgat",
    "bagatela": "bagatelă",
    "bagatele": "bagatelă",
    "bagatelei": "bagatelă",
    "bagatelele": "bagatelă",
    "bagatelelor": "bagatelă",
    "bagateliză": "bagateliza",
    "bagatelizai": "bagateliza",
    "bagatelizam": "bagateliza",
    "bagatelizăm": "bagateliza",
    "bagatelizând": "bagateliza",
    "bagatelizându": "bagateliza",
    "bagatelizară": "bagateliza",
    "bagatelizarăm": "bagateliza",
    "bagatelizarăți": "bagateliza",
    "bagatelizase": "bagateliza",
    "bagatelizasem": "bagateliza",
    "bagatelizaseră": "bagateliza",
    "bagatelizaserăm": "bagateliza",
    "bagatelizaserăți": "bagateliza",
    "bagatelizaseși": "bagateliza",
    "bagatelizași": "bagateliza",
    "bagatelizat": "bagateliza",
    "bagatelizați": "bagateliza",
    "bagatelizatu": "bagateliza",
    "bagatelizau": "bagateliza",
    "bagatelizează": "bagateliza",
    "bagatelizez": "bagateliza",
    "bagatelizeze": "bagateliza",
    "bagatelizezi": "bagateliza",
    "nebagatelizând": "bagateliza",
    "nebagatelizându": "bagateliza",
    "nemaibagatelizând": "bagateliza",
    "nemaibagatelizându": "bagateliza",
    "bagatelizarea": "bagatelizare",
    "bagatelizări": "bagatelizare",
    "bagatelizării": "bagatelizare",
    "bagatelizările": "bagatelizare",
    "bagatelizata": "bagatelizat",
    "bagatelizată": "bagatelizat",
    "bagatelizate": "bagatelizat",
    "bagatelizatei": "bagatelizat",
    "bagatelizatele": "bagatelizat",
    "bagatelizatelor": "bagatelizat",
    "bagatelizați": "bagatelizat",
    "bagatelizații": "bagatelizat",
    "bagatelizaților": "bagatelizat",
    "bagatelizatul": "bagatelizat",
    "bagatelizatului": "bagatelizat",
    "bagheta": "baghetă",
    "baghete": "baghetă",
    "baghetei": "baghetă",
    "baghetele": "baghetă",
    "baghetelor": "baghetă",
    "bahica": "bahic",
    "bahică": "bahic",
    "bahice": "bahic",
    "bahicei": "bahic",
    "bahicele": "bahic",
    "bahicelor": "bahic",
    "bahici": "bahic",
    "bahicii": "bahic",
    "bahicilor": "bahic",
    "bahicul": "bahic",
    "bahicului": "bahic",
    "băhnita": "băhnit",
    "băhnită": "băhnit",
    "băhnite": "băhnit",
    "băhnitei": "băhnit",
    "băhnitele": "băhnit",
    "băhnitelor": "băhnit",
    "băhnito": "băhnit",
    "băhnitul": "băhnit",
    "băhnitule": "băhnit",
    "băhnitului": "băhnit",
    "băhnita": "băhnită",
    "băhnite": "băhnită",
    "băhnitei": "băhnită",
    "băhnitele": "băhnită",
    "băhnitelor": "băhnită",
    "băhnito": "băhnită",
    "Bahrinul": "Bahrin",
    "Bahrinului": "Bahrin",
    "baiul": "bai",
    "baiului": "bai",
    "baiuri": "bai",
    "baiurile": "bai",
    "baiurilor": "bai",
    "baiadera": "baiaderă",
    "baiadere": "baiaderă",
    "baiaderei": "baiaderă",
    "baiaderele": "baiaderă",
    "baiaderelor": "baiaderă",
    "băiatul": "băiat",
    "băiatule": "băiat",
    "băiatului": "băiat",
    "băieți": "băiat",
    "băieții": "băiat",
    "băieților": "băiat",
    "băi": "baie",
    "baia": "baie",
    "băii": "baie",
    "băile": "baie",
    "băilor": "baie",
    "baiera": "baieră",
    "baiere": "baieră",
    "baierei": "baieră",
    "baierele": "baieră",
    "baierelor": "baieră",
    "băieși": "băieș",
    "băieșii": "băieș",
    "băieșilor": "băieș",
    "băieșul": "băieș",
    "băieșului": "băieș",
    "băietani": "băietan",
    "băietanii": "băietan",
    "băietanilor": "băietan",
    "băietanul": "băietan",
    "băietanului": "băietan",
    "băiețandri": "băiețandru",
    "băiețandrii": "băiețandru",
    "băiețandrilor": "băiețandru",
    "băiețandrul": "băiețandru",
    "băiețandrului": "băiețandru",
    "băiețași": "băiețaș",
    "băiețașii": "băiețaș",
    "băiețașilor": "băiețaș",
    "băiețașul": "băiețaș",
    "băiețașule": "băiețaș",
    "băiețașului": "băiețaș",
    "băieței": "băiețel",
    "băiețeii": "băiețel",
    "băiețeilor": "băiețel",
    "băiețelul": "băiețel",
    "băiețelule": "băiețel",
    "băiețelului": "băiețel",
    "băiețeasca": "băiețesc",
    "băiețească": "băiețesc",
    "băiețescul": "băiețesc",
    "băiețescului": "băiețesc",
    "băiețești": "băiețesc",
    "băiețeștii": "băiețesc",
    "băiețeștile": "băiețesc",
    "băiețeștilor": "băiețesc",
    "băiețoaica": "băiețoaică",
    "băiețoaice": "băiețoaică",
    "băiețoaicei": "băiețoaică",
    "băiețoaicele": "băiețoaică",
    "băiețoaicelor": "băiețoaică",
    "băiețoii": "băiețoi",
    "băiețoilor": "băiețoi",
    "băiețoiul": "băiețoi",
    "băiețoiule": "băiețoi",
    "băiețoiului": "băiețoi",
    "bâiguia": "bâigui",
    "bâiguiai": "bâigui",
    "bâiguiam": "bâigui",
    "bâiguiați": "bâigui",
    "bâiguiau": "bâigui",
    "bâiguie": "bâigui",
    "bâiguiește": "bâigui",
    "bâiguii": "bâigui",
    "bâiguim": "bâigui",
    "bâiguind": "bâigui",
    "bâiguindu": "bâigui",
    "bâiguiră": "bâigui",
    "bâiguirăm": "bâigui",
    "bâiguirăți": "bâigui",
    "bâiguise": "bâigui",
    "bâiguisem": "bâigui",
    "bâiguiseră": "bâigui",
    "bâiguiserăm": "bâigui",
    "bâiguiserăți": "bâigui",
    "bâiguiseși": "bâigui",
    "bâiguiși": "bâigui",
    "bâiguit": "bâigui",
    "bâiguiți": "bâigui",
    "bâiguitu": "bâigui",
    "bâiguită": "bâiguit",
    "bâiguite": "bâiguit",
    "bâiguiți": "bâiguit",
    "baioneta": "baionetă",
    "baionete": "baionetă",
    "baionetei": "baionetă",
    "baionetele": "baionetă",
    "baionetelor": "baionetă",
    "bâjbâia": "bâjbâi",
    "bâjbâiai": "bâjbâi",
    "bâjbâiam": "bâjbâi",
    "bâjbâiați": "bâjbâi",
    "bâjbâiau": "bâjbâi",
    "bâjbâie": "bâjbâi",
    "bâjbâiește": "bâjbâi",
    "bâjbâii": "bâjbâi",
    "bâjbâim": "bâjbâi",
    "bâjbâind": "bâjbâi",
    "bâjbâindu": "bâjbâi",
    "bâjbâiră": "bâjbâi",
    "bâjbâirăm": "bâjbâi",
    "bâjbâirăți": "bâjbâi",
    "bâjbâise": "bâjbâi",
    "bâjbâisem": "bâjbâi",
    "bâjbâiseră": "bâjbâi",
    "bâjbâiserăm": "bâjbâi",
    "bâjbâiserăți": "bâjbâi",
    "bâjbâiseși": "bâjbâi",
    "bâjbâiși": "bâjbâi",
    "bâjbâit": "bâjbâi",
    "bâjbâiți": "bâjbâi",
    "bâjbâitu": "bâjbâi",
    "bâjbâiala": "bâjbâială",
    "bâjbâieli": "bâjbâială",
    "bâjbâielii": "bâjbâială",
    "bâjbâielile": "bâjbâială",
    "bâjbâielilor": "bâjbâială",
    "bâjbâita": "bâjbâit",
    "bâjbâită": "bâjbâit",
    "bâjbâite": "bâjbâit",
    "bâjbâitei": "bâjbâit",
    "bâjbâitele": "bâjbâit",
    "bâjbâitelor": "bâjbâit",
    "bâjbâiți": "bâjbâit",
    "bâjbâiții": "bâjbâit",
    "bâjbâiților": "bâjbâit",
    "bâjbâitul": "bâjbâit",
    "bâjbâitului": "bâjbâit",
    "băjenari": "băjenar",
    "băjenarii": "băjenar",
    "băjenarilor": "băjenar",
    "băjenarul": "băjenar",
    "băjenarului": "băjenar",
    "băjenia": "băjenie",
    "băjeniei": "băjenie",
    "băjenii": "băjenie",
    "băjeniile": "băjenie",
    "băjeniilor": "băjenie",
    "balul": "bal",
    "balului": "bal",
    "baluri": "bal",
    "balurile": "bal",
    "balurilor": "bal",
    "bălăbăneala": "bălăbăneală",
    "bălăbănealo": "bălăbăneală",
    "bălăbăneli": "bălăbăneală",
    "bălăbănelii": "bălăbăneală",
    "bălăbănelile": "bălăbăneală",
    "bălăbănelilor": "bălăbăneală",
    "bălăbănea": "bălăbăni",
    "bălăbăneai": "bălăbăni",
    "bălăbăneam": "bălăbăni",
    "bălăbănească": "bălăbăni",
    "bălăbăneați": "bălăbăni",
    "bălăbăneau": "bălăbăni",
    "bălăbănesc": "bălăbăni",
    "bălăbănește": "bălăbăni",
    "bălăbănești": "bălăbăni",
    "bălăbănii": "bălăbăni",
    "bălăbănim": "bălăbăni",
    "bălăbănind": "bălăbăni",
    "bălăbănindu": "bălăbăni",
    "bălăbăniră": "bălăbăni",
    "bălăbănirăm": "bălăbăni",
    "bălăbănirăți": "bălăbăni",
    "bălăbănise": "bălăbăni",
    "bălăbănisem": "bălăbăni",
    "bălăbăniseră": "bălăbăni",
    "bălăbăniserăm": "bălăbăni",
    "bălăbăniserăți": "bălăbăni",
    "bălăbăniseși": "bălăbăni",
    "bălăbăniși": "bălăbăni",
    "bălăbănit": "bălăbăni",
    "bălăbăniți": "bălăbăni",
    "bălăbănitu": "bălăbăni",
    "nebălăbănind": "bălăbăni",
    "nebălăbănindu": "bălăbăni",
    "nemaibălăbănind": "bălăbăni",
    "nemaibălăbănindu": "bălăbăni",
    "bălăbănita": "bălăbănit",
    "bălăbănită": "bălăbănit",
    "bălăbănite": "bălăbănit",
    "bălăbănitei": "bălăbănit",
    "bălăbănitele": "bălăbănit",
    "bălăbănitelor": "bălăbănit",
    "bălăbăniți": "bălăbănit",
    "bălăbăniții": "bălăbănit",
    "bălăbăniților": "bălăbănit",
    "bălăbănitul": "bălăbănit",
    "bălăbănitule": "bălăbănit",
    "bălăbănitului": "bălăbănit",
    "bălăceala": "bălăceală",
    "bălăcealo": "bălăceală",
    "bălăceli": "bălăceală",
    "bălăcelii": "bălăceală",
    "bălăcelile": "bălăceală",
    "bălăcelilor": "bălăceală",
    "bălăcea": "bălăci",
    "bălăceai": "bălăci",
    "bălăceam": "bălăci",
    "bălăcească": "bălăci",
    "bălăceați": "bălăci",
    "bălăceau": "bălăci",
    "bălăcesc": "bălăci",
    "bălăcește": "bălăci",
    "bălăcești": "bălăci",
    "bălăcii": "bălăci",
    "bălăcim": "bălăci",
    "bălăcind": "bălăci",
    "bălăcindu": "bălăci",
    "bălăciră": "bălăci",
    "bălăcirăm": "bălăci",
    "bălăcirăți": "bălăci",
    "bălăcise": "bălăci",
    "bălăcisem": "bălăci",
    "bălăciseră": "bălăci",
    "bălăciserăm": "bălăci",
    "bălăciserăți": "bălăci",
    "bălăciseși": "bălăci",
    "bălăciși": "bălăci",
    "bălăcit": "bălăci",
    "bălăciți": "bălăci",
    "bălăcitu": "bălăci",
    "nebălăcind": "bălăci",
    "nebălăcindu": "bălăci",
    "nemaibălăcind": "bălăci",
    "nemaibălăcindu": "bălăci",
    "bălăcirea": "bălăcire",
    "bălăcireo": "bălăcire",
    "bălăciri": "bălăcire",
    "bălăcirii": "bălăcire",
    "bălăcirile": "bălăcire",
    "bălăcirilor": "bălăcire",
    "bălăcita": "bălăcit",
    "bălăcită": "bălăcit",
    "bălăcite": "bălăcit",
    "bălăcitei": "bălăcit",
    "bălăcitele": "bălăcit",
    "bălăcitelor": "bălăcit",
    "bălăciți": "bălăcit",
    "bălăciții": "bălăcit",
    "bălăciților": "bălăcit",
    "bălăcito": "bălăcit",
    "bălăcitul": "bălăcit",
    "bălăcitule": "bălăcit",
    "bălăcitului": "bălăcit",
    "balada": "baladă",
    "balade": "baladă",
    "baladei": "baladă",
    "baladele": "baladă",
    "baladelor": "baladă",
    "bălaia": "bălai",
    "bălaie": "bălai",
    "bălaiei": "bălai",
    "bălaiele": "bălai",
    "bălaielor": "bălai",
    "bălaii": "bălai",
    "bălailor": "bălai",
    "bălaiul": "bălai",
    "bălaiului": "bălai",
    "bălăiori": "bălăior",
    "bălăiorii": "bălăior",
    "bălăiorilor": "bălăior",
    "bălăiorul": "bălăior",
    "bălăiorului": "bălăior",
    "balamale": "balama",
    "balamalei": "balama",
    "balamalele": "balama",
    "balamalelor": "balama",
    "balamao": "balama",
    "balamaua": "balama",
    "balamucul": "balamuc",
    "balamucului": "balamuc",
    "balamucuri": "balamuc",
    "balamucurile": "balamuc",
    "balamucurilor": "balamuc",
    "bălana": "bălan",
    "bălană": "bălan",
    "bălane": "bălan",
    "bălanei": "bălan",
    "bălanele": "bălan",
    "bălanelor": "bălan",
    "bălani": "bălan",
    "bălanii": "bălan",
    "bălanilor": "bălan",
    "bălanul": "bălan",
    "bălanului": "bălan",
    "balansă": "balansa",
    "balansai": "balansa",
    "balansam": "balansa",
    "balansăm": "balansa",
    "balansând": "balansa",
    "balansându": "balansa",
    "balansară": "balansa",
    "balansarăm": "balansa",
    "balansarăți": "balansa",
    "balansase": "balansa",
    "balansasem": "balansa",
    "balansaseră": "balansa",
    "balansaserăm": "balansa",
    "balansaserăți": "balansa",
    "balansaseși": "balansa",
    "balansași": "balansa",
    "balansat": "balansa",
    "balansați": "balansa",
    "balansatu": "balansa",
    "balansau": "balansa",
    "balansează": "balansa",
    "balansez": "balansa",
    "balanseze": "balansa",
    "balansezi": "balansa",
    "balansarea": "balansare",
    "balansări": "balansare",
    "balansării": "balansare",
    "balansările": "balansare",
    "balansată": "balansat",
    "balansate": "balansat",
    "balansați": "balansat",
    "balansoare": "balansoar",
    "balansoarele": "balansoar",
    "balansoarelor": "balansoar",
    "balansoarul": "balansoar",
    "balansoarului": "balansoar",
    "balanța": "balanță",
    "balanțe": "balanță",
    "balanței": "balanță",
    "balanțele": "balanță",
    "balanțelor": "balanță",
    "balanțo": "balanță",
    "bălăriei": "bălărie",
    "bălării": "bălărie",
    "bălăriile": "bălărie",
    "bălăriilor": "bălărie",
    "balastul": "balast",
    "balastului": "balast",
    "balasturi": "balast",
    "balasturile": "balast",
    "balasturilor": "balast",
    "balastiera": "balastieră",
    "balastiere": "balastieră",
    "balastierei": "balastieră",
    "balastierele": "balastieră",
    "balastierelor": "balastieră",
    "balauri": "balaur",
    "balaurii": "balaur",
    "balaurilor": "balaur",
    "balaurul": "balaur",
    "balaurului": "balaur",
    "bâlba": "bâlbă",
    "bâlbe": "bâlbă",
    "bâlbei": "bâlbă",
    "bâlbele": "bâlbă",
    "bâlbelor": "bâlbă",
    "bâlbâia": "bâlbâi",
    "bâlbâiai": "bâlbâi",
    "bâlbâiam": "bâlbâi",
    "bâlbâiați": "bâlbâi",
    "bâlbâiau": "bâlbâi",
    "bâlbâie": "bâlbâi",
    "bâlbâii": "bâlbâi",
    "bâlbâim": "bâlbâi",
    "bâlbâind": "bâlbâi",
    "bâlbâindu": "bâlbâi",
    "bâlbâiră": "bâlbâi",
    "bâlbâirăm": "bâlbâi",
    "bâlbâirăți": "bâlbâi",
    "bâlbâise": "bâlbâi",
    "bâlbâisem": "bâlbâi",
    "bâlbâiseră": "bâlbâi",
    "bâlbâiserăm": "bâlbâi",
    "bâlbâiserăți": "bâlbâi",
    "bâlbâiseși": "bâlbâi",
    "bâlbâiși": "bâlbâi",
    "bâlbâit": "bâlbâi",
    "bâlbâiți": "bâlbâi",
    "bâlbâitu": "bâlbâi",
    "bâlbâiala": "bâlbâială",
    "bâlbâieli": "bâlbâială",
    "bâlbâielii": "bâlbâială",
    "bâlbâielile": "bâlbâială",
    "bâlbâielilor": "bâlbâială",
    "bâlbâită": "bâlbâit",
    "bâlbâite": "bâlbâit",
    "bâlbâiți": "bâlbâit",
    "balcanica": "balcanic",
    "balcanică": "balcanic",
    "balcanice": "balcanic",
    "balcanicei": "balcanic",
    "balcanicele": "balcanic",
    "balcanicelor": "balcanic",
    "balcanici": "balcanic",
    "balcanicii": "balcanic",
    "balcanicilor": "balcanic",
    "balcanicul": "balcanic",
    "balcanicului": "balcanic",
    "bâlciul": "bâlci",
    "bâlciului": "bâlci",
    "bâlciuri": "bâlci",
    "bâlciurile": "bâlci",
    "bâlciurilor": "bâlci",
    "balcoane": "balcon",
    "balcoanele": "balcon",
    "balcoanelor": "balcon",
    "balconul": "balcon",
    "balconului": "balcon",
    "baldachine": "baldachin",
    "baldachinele": "baldachin",
    "baldachinelor": "baldachin",
    "baldachinul": "baldachin",
    "baldachinului": "baldachin",
    "balega": "balegă",
    "balegi": "balegă",
    "balegii": "balegă",
    "balegile": "balegă",
    "balegilor": "balegă",
    "bălegarul": "bălegar",
    "bălegarului": "bălegar",
    "balena": "balenă",
    "balene": "balenă",
    "balenei": "balenă",
    "balenele": "balenă",
    "balenelor": "balenă",
    "baleniera": "balenieră",
    "baleniere": "balenieră",
    "balenierei": "balenieră",
    "balenierele": "balenieră",
    "balenierelor": "balenieră",
    "balerini": "balerin",
    "balerinii": "balerin",
    "balerinilor": "balerin",
    "balerinul": "balerin",
    "balerinului": "balerin",
    "balerina": "balerină",
    "balerine": "balerină",
    "balerinei": "balerină",
    "balerinele": "balerină",
    "balerinelor": "balerină",
    "balete": "balet",
    "baletele": "balet",
    "baletelor": "balet",
    "baletul": "balet",
    "baletului": "balet",
    "balistica": "balistic",
    "balistică": "balistic",
    "balistice": "balistic",
    "balisticei": "balistic",
    "balisticele": "balistic",
    "balisticelor": "balistic",
    "balistici": "balistic",
    "balisticii": "balistic",
    "balisticilor": "balistic",
    "balisticul": "balistic",
    "balisticului": "balistic",
    "baliverna": "balivernă",
    "baliverne": "balivernă",
    "balivernei": "balivernă",
    "balivernele": "balivernă",
    "balivernelor": "balivernă",
    "baliza": "baliză",
    "balize": "baliză",
    "balizei": "baliză",
    "balizele": "baliză",
    "balizelor": "baliză",
    "bălmăjeala": "bălmăjeală",
    "bălmăjealo": "bălmăjeală",
    "bălmăjeli": "bălmăjeală",
    "bălmăjelii": "bălmăjeală",
    "bălmăjelile": "bălmăjeală",
    "bălmăjelilor": "bălmăjeală",
    "bălmăjea": "bălmăji",
    "bălmăjeai": "bălmăji",
    "bălmăjeam": "bălmăji",
    "bălmăjească": "bălmăji",
    "bălmăjeați": "bălmăji",
    "bălmăjeau": "bălmăji",
    "bălmăjesc": "bălmăji",
    "bălmăjește": "bălmăji",
    "bălmăjești": "bălmăji",
    "bălmăjii": "bălmăji",
    "bălmăjim": "bălmăji",
    "bălmăjind": "bălmăji",
    "bălmăjindu": "bălmăji",
    "bălmăjiră": "bălmăji",
    "bălmăjirăm": "bălmăji",
    "bălmăjirăți": "bălmăji",
    "bălmăjise": "bălmăji",
    "bălmăjisem": "bălmăji",
    "bălmăjiseră": "bălmăji",
    "bălmăjiserăm": "bălmăji",
    "bălmăjiserăți": "bălmăji",
    "bălmăjiseși": "bălmăji",
    "bălmăjiși": "bălmăji",
    "bălmăjit": "bălmăji",
    "bălmăjiți": "bălmăji",
    "bălmăjitu": "bălmăji",
    "nebălmăjind": "bălmăji",
    "nebălmăjindu": "bălmăji",
    "nemaibălmăjind": "bălmăji",
    "nemaibălmăjindu": "bălmăji",
    "bălmăjirea": "bălmăjire",
    "bălmăjireo": "bălmăjire",
    "bălmăjiri": "bălmăjire",
    "bălmăjirii": "bălmăjire",
    "bălmăjirile": "bălmăjire",
    "bălmăjirilor": "bălmăjire",
    "bălmăjita": "bălmăjit",
    "bălmăjită": "bălmăjit",
    "bălmăjite": "bălmăjit",
    "bălmăjitei": "bălmăjit",
    "bălmăjitele": "bălmăjit",
    "bălmăjitelor": "bălmăjit",
    "bălmăjiți": "bălmăjit",
    "bălmăjiții": "bălmăjit",
    "bălmăjiților": "bălmăjit",
    "bălmăjito": "bălmăjit",
    "bălmăjitul": "bălmăjit",
    "bălmăjitule": "bălmăjit",
    "bălmăjitului": "bălmăjit",
    "balneara": "balnear",
    "balneară": "balnear",
    "balneare": "balnear",
    "balnearei": "balnear",
    "balnearele": "balnear",
    "balnearelor": "balnear",
    "balneari": "balnear",
    "balnearii": "balnear",
    "balnearilor": "balnear",
    "balnearul": "balnear",
    "balnearului": "balnear",
    "balneologi": "balneolog",
    "balneologii": "balneolog",
    "balneologilor": "balneolog",
    "balneologul": "balneolog",
    "balneologului": "balneolog",
    "balneologa": "balneologă",
    "balneologe": "balneologă",
    "balneologei": "balneologă",
    "balneologele": "balneologă",
    "balneologelor": "balneologă",
    "balneologia": "balneologie",
    "balneologiei": "balneologie",
    "balneologii": "balneologie",
    "balneologiile": "balneologie",
    "balneologiilor": "balneologie",
    "balneoterapica": "balneoterapic",
    "balneoterapică": "balneoterapic",
    "balneoterapice": "balneoterapic",
    "balneoterapicei": "balneoterapic",
    "balneoterapicele": "balneoterapic",
    "balneoterapicelor": "balneoterapic",
    "balneoterapici": "balneoterapic",
    "balneoterapicii": "balneoterapic",
    "balneoterapicilor": "balneoterapic",
    "balneoterapicul": "balneoterapic",
    "balneoterapicului": "balneoterapic",
    "balneoterapia": "balneoterapie",
    "balneoterapiei": "balneoterapie",
    "balneoterapii": "balneoterapie",
    "balneoterapiile": "balneoterapie",
    "balneoterapiilor": "balneoterapie",
    "baloane": "balon",
    "baloanele": "balon",
    "baloanelor": "balon",
    "balonul": "balon",
    "balonului": "balon",
    "balonă": "balona",
    "balonai": "balona",
    "balonam": "balona",
    "balonăm": "balona",
    "balonând": "balona",
    "balonându": "balona",
    "balonară": "balona",
    "balonarăm": "balona",
    "balonarăți": "balona",
    "balonase": "balona",
    "balonasem": "balona",
    "balonaseră": "balona",
    "balonaserăm": "balona",
    "balonaserăți": "balona",
    "balonaseși": "balona",
    "balonași": "balona",
    "balonat": "balona",
    "balonați": "balona",
    "balonatu": "balona",
    "balonau": "balona",
    "balonează": "balona",
    "balonez": "balona",
    "baloneze": "balona",
    "balonezi": "balona",
    "nebalonând": "balona",
    "nebalonându": "balona",
    "nemaibalonând": "balona",
    "nemaibalonându": "balona",
    "balonarea": "balonare",
    "balonări": "balonare",
    "balonării": "balonare",
    "balonările": "balonare",
    "balonata": "balonat",
    "balonată": "balonat",
    "balonate": "balonat",
    "balonatei": "balonat",
    "balonatele": "balonat",
    "balonatelor": "balonat",
    "balonați": "balonat",
    "balonații": "balonat",
    "balonaților": "balonat",
    "balonatul": "balonat",
    "balonatului": "balonat",
    "băloasa": "bălos",
    "băloasă": "bălos",
    "băloase": "bălos",
    "băloasei": "bălos",
    "băloasele": "bălos",
    "băloaselor": "bălos",
    "băloaso": "bălos",
    "băloși": "bălos",
    "băloșii": "bălos",
    "băloșilor": "bălos",
    "bălosul": "bălos",
    "bălosule": "bălos",
    "bălosului": "bălos",
    "balotul": "balot",
    "balotului": "balot",
    "baloturi": "balot",
    "baloturile": "balot",
    "baloturilor": "balot",
    "balotaje": "balotaj",
    "balotajele": "balotaj",
    "balotajelor": "balotaj",
    "balotajul": "balotaj",
    "balotajului": "balotaj",
    "Baloteștiul": "Balotești",
    "Baloteștiului": "Balotești",
    "balsamul": "balsam",
    "balsamului": "balsam",
    "balsamuri": "balsam",
    "balsamurile": "balsam",
    "balsamurilor": "balsam",
    "balta": "baltă",
    "bălți": "baltă",
    "bălții": "baltă",
    "bălțile": "baltă",
    "bălților": "baltă",
    "balto": "baltă",
    "baltagul": "baltag",
    "baltagului": "baltag",
    "baltaguri": "baltag",
    "baltagurile": "baltag",
    "baltagurilor": "baltag",
    "băltăreața": "băltăreț",
    "băltăreață": "băltăreț",
    "băltărețe": "băltăreț",
    "băltăreței": "băltăreț",
    "băltărețele": "băltăreț",
    "băltărețelor": "băltăreț",
    "băltăreți": "băltăreț",
    "băltăreții": "băltăreț",
    "băltăreților": "băltăreț",
    "băltărețul": "băltăreț",
    "băltărețului": "băltăreț",
    "bălțata": "bălțat",
    "bălțată": "bălțat",
    "bălțate": "bălțat",
    "bălțatei": "bălțat",
    "bălțatele": "bălțat",
    "bălțatelor": "bălțat",
    "bălțați": "bălțat",
    "bălțații": "bălțat",
    "bălțaților": "bălțat",
    "bălțatul": "bălțat",
    "bălțatului": "bălțat",
    "bălțata": "bălțată",
    "bălțate": "bălțată",
    "bălțatei": "bălțată",
    "bălțatele": "bălțată",
    "bălțatelor": "bălțată",
    "băltea": "bălti",
    "bălteai": "bălti",
    "bălteam": "bălti",
    "băltească": "bălti",
    "bălteați": "bălti",
    "bălteau": "bălti",
    "băltesc": "bălti",
    "băltește": "bălti",
    "băltești": "bălti",
    "băltii": "bălti",
    "băltim": "bălti",
    "băltind": "bălti",
    "băltindu": "bălti",
    "băltiră": "bălti",
    "băltirăm": "bălti",
    "băltirăți": "bălti",
    "băltise": "bălti",
    "băltisem": "bălti",
    "băltiseră": "bălti",
    "băltiserăm": "bălti",
    "băltiserăți": "bălti",
    "băltiseși": "bălti",
    "băltiși": "bălti",
    "băltit": "bălti",
    "băltiți": "bălti",
    "băltitu": "bălti",
    "baltică": "baltic",
    "baltice": "baltic",
    "baltici": "baltic",
    "băltită": "băltit",
    "băltite": "băltit",
    "băltiți": "băltit",
    "băltoaca": "băltoacă",
    "băltoace": "băltoacă",
    "băltoacei": "băltoacă",
    "băltoacele": "băltoacă",
    "băltoacelor": "băltoacă",
    "băltoaco": "băltoacă",
    "bani": "ban",
    "banii": "ban",
    "banilor": "ban",
    "banul": "ban",
    "banului": "ban",
    "banala": "banal",
    "banală": "banal",
    "banale": "banal",
    "banalei": "banal",
    "banalele": "banal",
    "banalelor": "banal",
    "banali": "banal",
    "banalii": "banal",
    "banalilor": "banal",
    "banalul": "banal",
    "banalului": "banal",
    "banalitatea": "banalitate",
    "banalitateo": "banalitate",
    "banalități": "banalitate",
    "banalității": "banalitate",
    "banalitățile": "banalitate",
    "banalităților": "banalitate",
    "banana": "banană",
    "banane": "banană",
    "bananei": "banană",
    "bananele": "banană",
    "bananelor": "banană",
    "Banatul": "Banat",
    "Banatului": "Banat",
    "bănatul": "bănat",
    "bănatului": "bănat",
    "bănaturi": "bănat",
    "bănaturile": "bănat",
    "bănaturilor": "bănat",
    "bănățeana": "bănățean",
    "bănățeană": "bănățean",
    "bănățeanul": "bănățean",
    "bănățeanului": "bănățean",
    "bănățene": "bănățean",
    "bănățenei": "bănățean",
    "bănățenele": "bănățean",
    "bănățenelor": "bănățean",
    "bănățeni": "bănățean",
    "bănățenii": "bănățean",
    "bănățenilor": "bănățean",
    "bănățeanca": "bănățeancă",
    "bănățence": "bănățeancă",
    "bănățencei": "bănățeancă",
    "bănățencele": "bănățeancă",
    "bănățencelor": "bănățeancă",
    "bancul": "banc",
    "bancului": "banc",
    "bancuri": "banc",
    "bancurile": "banc",
    "bancurilor": "banc",
    "banca": "bancă",
    "bănci": "bancă",
    "băncii": "bancă",
    "băncile": "bancă",
    "băncilor": "bancă",
    "BCR": "Banca_Comercială_Română",
    "B.D.F.": "Banca_Dacia_Felix",
    "BERD": "Banca_Europeană_de_Reconstrucție_și_Dezvoltare",
    "BIR": "Banca_Internațională_a_Religiilor",
    "BIRD": "Banca_Internațională_de_Reconstrucție_și_Dezvoltare",
    "B.N.R.": "Banca_Națională_a_României",
    "Băncii_Naționale_a_României": "Banca_Națională_a_României",
    "BNR": "Banca_Națională_a_României",
    "BRCE": "Banca_Română_de_Comerț_Exterior",
    "BRD": "Banca_Română_de_Dezvoltare",
    "bancara": "bancar",
    "bancară": "bancar",
    "bancare": "bancar",
    "bancarei": "bancar",
    "bancarele": "bancar",
    "bancarelor": "bancar",
    "bancari": "bancar",
    "bancarii": "bancar",
    "bancarilor": "bancar",
    "bancarul": "bancar",
    "bancarului": "bancar",
    "bancheri": "bancher",
    "bancherii": "bancher",
    "bancherilor": "bancher",
    "bancherul": "bancher",
    "bancherului": "bancher",
    "banchete": "banchet",
    "banchetele": "banchet",
    "banchetelor": "banchet",
    "banchetul": "banchet",
    "banchetului": "banchet",
    "bancheta": "banchetă",
    "banchete": "banchetă",
    "banchetei": "banchetă",
    "banchetele": "banchetă",
    "banchetelor": "banchetă",
    "bancheto": "banchetă",
    "banchiza": "banchiză",
    "banchize": "banchiză",
    "banchizei": "banchiză",
    "banchizele": "banchiză",
    "banchizelor": "banchiză",
    "bancnota": "bancnotă",
    "bancnote": "bancnotă",
    "bancnotei": "bancnotă",
    "bancnotele": "bancnotă",
    "bancnotelor": "bancnotă",
    "bancruta": "bancrută",
    "bancrute": "bancrută",
    "bancrutei": "bancrută",
    "bancrutele": "bancrută",
    "bancrutelor": "bancrută",
    "banda": "bandă",
    "bande": "bandă",
    "bandei": "bandă",
    "bandele": "bandă",
    "bandelor": "bandă",
    "bando": "bandă",
    "bandajă": "bandaja",
    "bandajai": "bandaja",
    "bandajam": "bandaja",
    "bandajăm": "bandaja",
    "bandajând": "bandaja",
    "bandajându": "bandaja",
    "bandajară": "bandaja",
    "bandajarăm": "bandaja",
    "bandajarăți": "bandaja",
    "bandajase": "bandaja",
    "bandajasem": "bandaja",
    "bandajaseră": "bandaja",
    "bandajaserăm": "bandaja",
    "bandajaserăți": "bandaja",
    "bandajaseși": "bandaja",
    "bandajași": "bandaja",
    "bandajat": "bandaja",
    "bandajați": "bandaja",
    "bandajatu": "bandaja",
    "bandajau": "bandaja",
    "bandajează": "bandaja",
    "bandajez": "bandaja",
    "bandajeze": "bandaja",
    "bandajezi": "bandaja",
    "nebandajând": "bandaja",
    "nebandajându": "bandaja",
    "nemaibandajând": "bandaja",
    "nemaibandajându": "bandaja",
    "bandajarea": "bandajare",
    "bandajareo": "bandajare",
    "bandajări": "bandajare",
    "bandajării": "bandajare",
    "bandajările": "bandajare",
    "bandajărilor": "bandajare",
    "bandajata": "bandajat",
    "bandajată": "bandajat",
    "bandajate": "bandajat",
    "bandajatei": "bandajat",
    "bandajatele": "bandajat",
    "bandajatelor": "bandajat",
    "bandajați": "bandajat",
    "bandajații": "bandajat",
    "bandajaților": "bandajat",
    "bandajato": "bandajat",
    "bandajatul": "bandajat",
    "bandajatule": "bandajat",
    "bandajatului": "bandajat",
    "banderola": "banderolă",
    "banderole": "banderolă",
    "banderolei": "banderolă",
    "banderolele": "banderolă",
    "banderolelor": "banderolă",
    "bandiți": "bandit",
    "bandiții": "bandit",
    "bandiților": "bandit",
    "banditul": "bandit",
    "banditule": "bandit",
    "banditului": "bandit",
    "banduliera": "bandulieră",
    "banduliere": "bandulieră",
    "bandulierei": "bandulieră",
    "bandulierele": "bandulieră",
    "bandulierelor": "bandulieră",
    "băneasca": "bănesc",
    "bănească": "bănesc",
    "bănescul": "bănesc",
    "bănescului": "bănesc",
    "bănești": "bănesc",
    "băneștii": "bănesc",
    "băneștile": "bănesc",
    "băneștilor": "bănesc",
    "bănetul": "bănet",
    "bănetului": "bănet",
    "banița": "baniță",
    "banițe": "baniță",
    "baniței": "baniță",
    "banițele": "baniță",
    "banițelor": "baniță",
    "bănoasa": "bănos",
    "bănoasă": "bănos",
    "bănoase": "bănos",
    "bănoasei": "bănos",
    "bănoasele": "bănos",
    "bănoaselor": "bănos",
    "bănoaso": "bănos",
    "bănoși": "bănos",
    "bănoșii": "bănos",
    "bănoșilor": "bănos",
    "bănosul": "bănos",
    "bănosule": "bănos",
    "bănosului": "bănos",
    "bântuia": "bântui",
    "bântuiai": "bântui",
    "bântuiam": "bântui",
    "bântuiați": "bântui",
    "bântuiau": "bântui",
    "bântuie": "bântui",
    "bântuii": "bântui",
    "bântuim": "bântui",
    "bântuind": "bântui",
    "bântuindu": "bântui",
    "bântuiră": "bântui",
    "bântuirăm": "bântui",
    "bântuirăți": "bântui",
    "bântuise": "bântui",
    "bântuisem": "bântui",
    "bântuiseră": "bântui",
    "bântuiserăm": "bântui",
    "bântuiserăți": "bântui",
    "bântuiseși": "bântui",
    "bântuiși": "bântui",
    "bântuit": "bântui",
    "bântuiți": "bântui",
    "bântuitu": "bântui",
    "nebântuind": "bântui",
    "nebântuindu": "bântui",
    "nemaibântuind": "bântui",
    "nemaibântuindu": "bântui",
    "bântuirea": "bântuire",
    "bântuiri": "bântuire",
    "bântuirii": "bântuire",
    "bântuirile": "bântuire",
    "bântuita": "bântuit",
    "bântuită": "bântuit",
    "bântuite": "bântuit",
    "bântuitei": "bântuit",
    "bântuitele": "bântuit",
    "bântuitelor": "bântuit",
    "bântuiți": "bântuit",
    "bântuiții": "bântuit",
    "bântuiților": "bântuit",
    "bântuitul": "bântuit",
    "bântuitului": "bântuit",
    "bănuia": "bănui",
    "bănuiai": "bănui",
    "bănuiam": "bănui",
    "bănuiască": "bănui",
    "bănuiați": "bănui",
    "bănuiau": "bănui",
    "bănuie": "bănui",
    "bănuiesc": "bănui",
    "bănuiește": "bănui",
    "bănuiești": "bănui",
    "bănuii": "bănui",
    "bănuim": "bănui",
    "bănuind": "bănui",
    "bănuindu": "bănui",
    "bănuiră": "bănui",
    "bănuirăm": "bănui",
    "bănuirăți": "bănui",
    "bănuise": "bănui",
    "bănuisem": "bănui",
    "bănuiseră": "bănui",
    "bănuiserăm": "bănui",
    "bănuiserăți": "bănui",
    "bănuiseși": "bănui",
    "bănuiși": "bănui",
    "bănuit": "bănui",
    "bănuiți": "bănui",
    "bănuitu": "bănui",
    "nebănuind": "bănui",
    "nebănuindu": "bănui",
    "nemaibănuind": "bănui",
    "nemaibănuindu": "bănui",
    "bănuiala": "bănuială",
    "bănuieli": "bănuială",
    "bănuielii": "bănuială",
    "bănuielile": "bănuială",
    "bănuirea": "bănuire",
    "bănuiri": "bănuire",
    "bănuirii": "bănuire",
    "bănuirile": "bănuire",
    "bănuita": "bănuit",
    "bănuită": "bănuit",
    "bănuite": "bănuit",
    "bănuitei": "bănuit",
    "bănuitele": "bănuit",
    "bănuitelor": "bănuit",
    "bănuiți": "bănuit",
    "bănuiții": "bănuit",
    "bănuiților": "bănuit",
    "bănuitul": "bănuit",
    "bănuitului": "bănuit",
    "bănuita": "bănuită",
    "bănuite": "bănuită",
    "bănuitei": "bănuită",
    "bănuitele": "bănuită",
    "bănuitelor": "bănuită",
    "bănuitoare": "bănuitor",
    "bănuitoarea": "bănuitor",
    "bănuitoarei": "bănuitor",
    "bănuitoarele": "bănuitor",
    "bănuitoarelor": "bănuitor",
    "bănuitori": "bănuitor",
    "bănuitorii": "bănuitor",
    "bănuitorilor": "bănuitor",
    "bănuitorul": "bănuitor",
    "bănuitorului": "bănuitor",
    "bănuți": "bănuț",
    "bănuții": "bănuț",
    "bănuților": "bănuț",
    "bănuțul": "bănuț",
    "bănuțului": "bănuț",
    "baptista": "baptist",
    "baptistă": "baptist",
    "baptiste": "baptist",
    "baptistei": "baptist",
    "baptistele": "baptist",
    "baptistelor": "baptist",
    "baptiști": "baptist",
    "baptiștii": "baptist",
    "baptiștilor": "baptist",
    "baptistul": "baptist",
    "baptistului": "baptist",
    "baptista": "baptistă",
    "baptiste": "baptistă",
    "baptistei": "baptistă",
    "baptistele": "baptistă",
    "baptistelor": "baptistă",
    "barul": "bar",
    "barule": "bar",
    "barului": "bar",
    "baruri": "bar",
    "barurile": "bar",
    "barurilor": "bar",
    "bară": "bara",
    "barai": "bara",
    "baram": "bara",
    "barăm": "bara",
    "barând": "bara",
    "barându": "bara",
    "barară": "bara",
    "bararăm": "bara",
    "bararăți": "bara",
    "barase": "bara",
    "barasem": "bara",
    "baraseră": "bara",
    "baraserăm": "bara",
    "baraserăți": "bara",
    "baraseși": "bara",
    "barași": "bara",
    "barat": "bara",
    "barați": "bara",
    "baratu": "bara",
    "barau": "bara",
    "barează": "bara",
    "barez": "bara",
    "bareze": "bara",
    "barezi": "bara",
    "nebarând": "bara",
    "nebarându": "bara",
    "nemaibarând": "bara",
    "nemaibarându": "bara",
    "bara": "bară",
    "bare": "bară",
    "barei": "bară",
    "barele": "bară",
    "barelor": "bară",
    "baraca": "baracă",
    "barăci": "baracă",
    "barăcii": "baracă",
    "barăcile": "baracă",
    "barăcilor": "baracă",
    "bărăcuța": "bărăcuță",
    "bărăcuțe": "bărăcuță",
    "bărăcuței": "bărăcuță",
    "bărăcuțele": "bărăcuță",
    "bărăcuțelor": "bărăcuță",
    "baraje": "baraj",
    "barajele": "baraj",
    "barajelor": "baraj",
    "barajul": "baraj",
    "barajului": "baraj",
    "bararea": "barare",
    "barări": "barare",
    "barării": "barare",
    "barările": "barare",
    "barata": "barat",
    "barată": "barat",
    "barate": "barat",
    "baratei": "barat",
    "baratele": "barat",
    "baratelor": "barat",
    "barați": "barat",
    "barații": "barat",
    "baraților": "barat",
    "baratul": "barat",
    "baratului": "barat",
    "barba": "barbă",
    "bărbi": "barbă",
    "bărbii": "barbă",
    "bărbile": "barbă",
    "bărbilor": "barbă",
    "barbo": "barbă",
    "barbara": "barbar",
    "barbară": "barbar",
    "barbare": "barbar",
    "barbarei": "barbar",
    "barbarele": "barbar",
    "barbarelor": "barbar",
    "barbari": "barbar",
    "barbarii": "barbar",
    "barbarilor": "barbar",
    "barbarul": "barbar",
    "barbarului": "barbar",
    "barbara": "barbară",
    "barbare": "barbară",
    "barbarei": "barbară",
    "barbarele": "barbară",
    "barbarelor": "barbară",
    "barbaria": "barbarie",
    "barbariei": "barbarie",
    "barbarii": "barbarie",
    "barbariile": "barbarie",
    "barbariilor": "barbarie",
    "barbarisme": "barbarism",
    "barbarismele": "barbarism",
    "barbarismelor": "barbarism",
    "barbarismul": "barbarism",
    "barbarismului": "barbarism",
    "bărbați": "bărbat",
    "bărbații": "bărbat",
    "bărbaților": "bărbat",
    "bărbatul": "bărbat",
    "bărbatului": "bărbat",
    "bărbăteasca": "bărbătesc",
    "bărbătească": "bărbătesc",
    "bărbătescul": "bărbătesc",
    "bărbătescului": "bărbătesc",
    "bărbătești": "bărbătesc",
    "bărbăteștii": "bărbătesc",
    "bărbăteștile": "bărbătesc",
    "bărbăteștilor": "bărbătesc",
    "bărbăția": "bărbăție",
    "bărbăției": "bărbăție",
    "bărbății": "bărbăție",
    "bărbățiile": "bărbăție",
    "bărbățiilor": "bărbăție",
    "bărbătoasa": "bărbătos",
    "bărbătoasă": "bărbătos",
    "bărbătoase": "bărbătos",
    "bărbătoasei": "bărbătos",
    "bărbătoasele": "bărbătos",
    "bărbătoaselor": "bărbătos",
    "bărbătoși": "bărbătos",
    "bărbătoșii": "bărbătos",
    "bărbătoșilor": "bărbătos",
    "bărbătosul": "bărbătos",
    "bărbătosului": "bărbătos",
    "barbeta": "barbetă",
    "barbete": "barbetă",
    "barbetei": "barbetă",
    "barbetele": "barbetă",
    "barbetelor": "barbetă",
    "bărbia": "bărbie",
    "bărbiei": "bărbie",
    "bărbii": "bărbie",
    "bărbiile": "bărbie",
    "bărbiilor": "bărbie",
    "bărbio": "bărbie",
    "bărbieri": "bărbier",
    "bărbierii": "bărbier",
    "bărbierilor": "bărbier",
    "bărbieru": "bărbier",
    "bărbierul": "bărbier",
    "bărbierule": "bărbier",
    "bărbierului": "bărbier",
    "bărbiereala": "bărbiereală",
    "bărbierealo": "bărbiereală",
    "bărbiereli": "bărbiereală",
    "bărbierelii": "bărbiereală",
    "bărbierelile": "bărbiereală",
    "bărbierelilor": "bărbiereală",
    "bărbierea": "bărbieri",
    "bărbiereai": "bărbieri",
    "bărbieream": "bărbieri",
    "bărbierească": "bărbieri",
    "bărbiereați": "bărbieri",
    "bărbiereau": "bărbieri",
    "bărbieresc": "bărbieri",
    "bărbierește": "bărbieri",
    "bărbierești": "bărbieri",
    "bărbierii": "bărbieri",
    "bărbierim": "bărbieri",
    "bărbierind": "bărbieri",
    "bărbierindu": "bărbieri",
    "bărbieriră": "bărbieri",
    "bărbierirăm": "bărbieri",
    "bărbierirăți": "bărbieri",
    "bărbierise": "bărbieri",
    "bărbierisem": "bărbieri",
    "bărbieriseră": "bărbieri",
    "bărbieriserăm": "bărbieri",
    "bărbieriserăți": "bărbieri",
    "bărbieriseși": "bărbieri",
    "bărbieriși": "bărbieri",
    "bărbierit": "bărbieri",
    "bărbieriți": "bărbieri",
    "bărbieritu": "bărbieri",
    "nebărbierind": "bărbieri",
    "nebărbierindu": "bărbieri",
    "nemaibărbierind": "bărbieri",
    "nemaibărbierindu": "bărbieri",
    "bărbierirea": "bărbierire",
    "bărbierireo": "bărbierire",
    "bărbieriri": "bărbierire",
    "bărbieririi": "bărbierire",
    "bărbieririle": "bărbierire",
    "bărbieririlor": "bărbierire",
    "bărbierita": "bărbierit",
    "bărbierită": "bărbierit",
    "bărbierite": "bărbierit",
    "bărbieritei": "bărbierit",
    "bărbieritele": "bărbierit",
    "bărbieritelor": "bărbierit",
    "bărbieriți": "bărbierit",
    "bărbieriții": "bărbierit",
    "bărbieriților": "bărbierit",
    "bărbierito": "bărbierit",
    "bărbieritul": "bărbierit",
    "bărbieritule": "bărbierit",
    "bărbieritului": "bărbierit",
    "barbișoane": "barbișon",
    "barbișoanele": "barbișon",
    "barbișoanelor": "barbișon",
    "barbișonul": "barbișon",
    "barbișonului": "barbișon",
    "bărboasa": "bărboasă",
    "bărboase": "bărboasă",
    "bărboasei": "bărboasă",
    "bărboasele": "bărboasă",
    "bărboaselor": "bărboasă",
    "bărboasa": "bărbos",
    "bărboasă": "bărbos",
    "bărboase": "bărbos",
    "bărboasei": "bărbos",
    "bărboasele": "bărbos",
    "bărboaselor": "bărbos",
    "bărboși": "bărbos",
    "bărboșii": "bărbos",
    "bărboșilor": "bărbos",
    "bărbosul": "bărbos",
    "bărbosului": "bărbos",
    "barca": "barcă",
    "bărci": "barcă",
    "bărcii": "barcă",
    "bărcile": "barcă",
    "bărcilor": "barcă",
    "barco": "barcă",
    "Barcelonă": "Barcelona",
    "Barcelone": "Barcelona",
    "Barcelonei": "Barcelona",
    "bărcuța": "bărcuță",
    "bărcuțe": "bărcuță",
    "bărcuței": "bărcuță",
    "bărcuțele": "bărcuță",
    "bărcuțelor": "bărcuță",
    "bardul": "bard",
    "bardului": "bard",
    "barzi": "bard",
    "barzii": "bard",
    "barzilor": "bard",
    "barda": "bardă",
    "barde": "bardă",
    "bardei": "bardă",
    "bardele": "bardă",
    "bardelor": "bardă",
    "baremul": "barem",
    "baremului": "barem",
    "baremuri": "barem",
    "baremurile": "barem",
    "baremurilor": "barem",
    "bareta": "baretă",
    "barete": "baretă",
    "baretei": "baretă",
    "baretele": "baretă",
    "baretelor": "baretă",
    "bârfea": "bârfi",
    "bârfeai": "bârfi",
    "bârfeam": "bârfi",
    "bârfească": "bârfi",
    "bârfeați": "bârfi",
    "bârfeau": "bârfi",
    "bârfesc": "bârfi",
    "bârfește": "bârfi",
    "bârfești": "bârfi",
    "bârfii": "bârfi",
    "bârfim": "bârfi",
    "bârfind": "bârfi",
    "bârfindu": "bârfi",
    "bârfiră": "bârfi",
    "bârfirăm": "bârfi",
    "bârfirăți": "bârfi",
    "bârfise": "bârfi",
    "bârfisem": "bârfi",
    "bârfiseră": "bârfi",
    "bârfiserăm": "bârfi",
    "bârfiserăți": "bârfi",
    "bârfiseși": "bârfi",
    "bârfiși": "bârfi",
    "bârfit": "bârfi",
    "bârfiți": "bârfi",
    "bârfitu": "bârfi",
    "bârfita": "bârfit",
    "bârfită": "bârfit",
    "bârfite": "bârfit",
    "bârfitei": "bârfit",
    "bârfitele": "bârfit",
    "bârfitelor": "bârfit",
    "bârfiți": "bârfit",
    "bârfiții": "bârfit",
    "bârfiților": "bârfit",
    "bârfitul": "bârfit",
    "bârfitului": "bârfit",
    "bârfitoarea": "bârfitoare",
    "bârfitoarei": "bârfitoare",
    "bârfitoarele": "bârfitoare",
    "bârfitoarelor": "bârfitoare",
    "bârfitori": "bârfitor",
    "bârfitorii": "bârfitor",
    "bârfitorilor": "bârfitor",
    "bârfitorul": "bârfitor",
    "bârfitorului": "bârfitor",
    "barica": "baric",
    "barică": "baric",
    "barice": "baric",
    "baricei": "baric",
    "baricele": "baric",
    "baricelor": "baric",
    "barici": "baric",
    "baricii": "baric",
    "baricilor": "baric",
    "baricul": "baric",
    "baricului": "baric",
    "batantă": "baric",
    "baricada": "baricadă",
    "baricade": "baricadă",
    "baricadei": "baricadă",
    "baricadele": "baricadă",
    "baricadelor": "baricadă",
    "bariera": "barieră",
    "bariere": "barieră",
    "barierei": "barieră",
    "barierele": "barieră",
    "barierelor": "barieră",
    "bariero": "barieră",
    "barili": "baril",
    "barilii": "baril",
    "barililor": "baril",
    "barilul": "baril",
    "barilului": "baril",
    "barisfera": "barisferă",
    "barisfere": "barisferă",
    "barisferei": "barisferă",
    "barisferele": "barisferă",
    "barisferelor": "barisferă",
    "baritoni": "bariton",
    "baritonii": "bariton",
    "baritonilor": "bariton",
    "baritonul": "bariton",
    "baritonului": "bariton",
    "bariul": "bariu",
    "bariului": "bariu",
    "Bârladul": "Bârlad",
    "Bârladului": "Bârlad",
    "bârlogul": "bârlog",
    "bârlogului": "bârlog",
    "bârloguri": "bârlog",
    "bârlogurile": "bârlog",
    "bârlogurilor": "bârlog",
    "barmani": "barman",
    "barmanii": "barman",
    "barmanilor": "barman",
    "barmanul": "barman",
    "barmanule": "barman",
    "barmanului": "barman",
    "baroana": "baroană",
    "baroane": "baroană",
    "baroanei": "baroană",
    "baroanele": "baroană",
    "baroanelor": "baroană",
    "baroca": "baroc",
    "barocă": "baroc",
    "baroce": "baroc",
    "barocei": "baroc",
    "barocele": "baroc",
    "barocelor": "baroc",
    "baroci": "baroc",
    "barocii": "baroc",
    "barocilor": "baroc",
    "barocul": "baroc",
    "barocului": "baroc",
    "barocuri": "baroc",
    "barocurile": "baroc",
    "barocurilor": "baroc",
    "barometre": "barometru",
    "barometrele": "barometru",
    "barometrelor": "barometru",
    "barometrul": "barometru",
    "barometrului": "barometru",
    "baroni": "baron",
    "baronii": "baron",
    "baronilor": "baron",
    "baronul": "baron",
    "baronului": "baron",
    "baroase": "baros",
    "baroasele": "baros",
    "baroaselor": "baros",
    "barosul": "baros",
    "barosului": "baros",
    "baroul": "barou",
    "baroului": "barou",
    "barouri": "barou",
    "barourile": "barou",
    "barourilor": "barou",
    "bârsana": "bârsan",
    "bârsană": "bârsan",
    "bârsane": "bârsan",
    "bârsanei": "bârsan",
    "bârsanele": "bârsan",
    "bârsanelor": "bârsan",
    "bârsani": "bârsan",
    "bârsanii": "bârsan",
    "bârsanilor": "bârsan",
    "bârsanul": "bârsan",
    "bârsanului": "bârsan",
    "bărulețe": "băruleț",
    "bărulețele": "băruleț",
    "bărulețelor": "băruleț",
    "bărulețul": "băruleț",
    "bărulețule": "băruleț",
    "bărulețului": "băruleț",
    "basul": "bas",
    "basului": "bas",
    "basuri": "bas",
    "basurile": "bas",
    "basurilor": "bas",
    "baș-agale": "baș-aga",
    "basarabeana": "basarabean",
    "basarabeană": "basarabean",
    "basarabeanul": "basarabean",
    "basarabeanului": "basarabean",
    "basarabene": "basarabean",
    "basarabenei": "basarabean",
    "basarabenele": "basarabean",
    "basarabenelor": "basarabean",
    "basarabeni": "basarabean",
    "basarabenii": "basarabean",
    "basarabenilor": "basarabean",
    "basarabeanca": "basarabeancă",
    "basarabence": "basarabeancă",
    "basarabencei": "basarabeancă",
    "basarabencele": "basarabeancă",
    "basarabencelor": "basarabeancă",
    "Basarabie": "Basarabia",
    "Basarabiei": "Basarabia",
    "Basarabii": "Basarabia",
    "baș-boieri": "baș-boier",
    "baș-boierilor": "baș-boier",
    "baș-boierul": "baș-boier",
    "baș-boierului": "baș-boier",
    "baș-caimacami": "baș-caimacam",
    "baș-caimacamilor": "baș-caimacam",
    "baș-caimacamul": "baș-caimacam",
    "baș-caimacamului": "baș-caimacam",
    "baschetul": "baschet",
    "baschetului": "baschet",
    "baș-ciohodari": "baș-ciohodar",
    "baș-ciohodarilor": "baș-ciohodar",
    "baș-ciohodarul": "baș-ciohodar",
    "baș-ciohodarului": "baș-ciohodar",
    "bascula": "basculă",
    "bascule": "basculă",
    "basculei": "basculă",
    "basculele": "basculă",
    "basculelor": "basculă",
    "basculanta": "basculantă",
    "basculante": "basculantă",
    "basculantei": "basculantă",
    "basculantele": "basculantă",
    "basculantelor": "basculantă",
    "basme": "basm",
    "basmele": "basm",
    "basmelor": "basm",
    "basmul": "basm",
    "basmului": "basm",
    "basmale": "basma",
    "basmalei": "basma",
    "basmalele": "basma",
    "basmalelor": "basma",
    "basmaua": "basma",
    "băsmuirea": "băsmuire",
    "băsmuiri": "băsmuire",
    "băsmuirii": "băsmuire",
    "băsmuirile": "băsmuire",
    "băsmuirilor": "băsmuire",
    "băsmuitoare": "băsmuitor",
    "băsmuitoarea": "băsmuitor",
    "băsmuitoarei": "băsmuitor",
    "băsmuitoarele": "băsmuitor",
    "băsmuitoarelor": "băsmuitor",
    "băsmuitori": "băsmuitor",
    "băsmuitorii": "băsmuitor",
    "băsmuitorilor": "băsmuitor",
    "băsmuitorul": "băsmuitor",
    "băsmuitorului": "băsmuitor",
    "basna": "basnă",
    "basorelieful": "basorelief",
    "basoreliefului": "basorelief",
    "basoreliefuri": "basorelief",
    "basoreliefurile": "basorelief",
    "basoreliefurilor": "basorelief",
    "bastarda": "bastard",
    "bastardă": "bastard",
    "bastarde": "bastard",
    "bastardei": "bastard",
    "bastardele": "bastard",
    "bastardelor": "bastard",
    "bastardul": "bastard",
    "bastardului": "bastard",
    "bastarzi": "bastard",
    "bastarzii": "bastard",
    "bastarzilor": "bastard",
    "bastarda": "bastardă",
    "bastarde": "bastardă",
    "bastardei": "bastardă",
    "bastardele": "bastardă",
    "bastardelor": "bastardă",
    "bastimente": "bastiment",
    "bastimentele": "bastiment",
    "bastimentelor": "bastiment",
    "bastimentul": "bastiment",
    "bastimentului": "bastiment",
    "băștinașa": "băștinaș",
    "băștinașă": "băștinaș",
    "băștinașe": "băștinaș",
    "băștinașei": "băștinaș",
    "băștinașele": "băștinaș",
    "băștinașelor": "băștinaș",
    "băștinași": "băștinaș",
    "băștinașii": "băștinaș",
    "băștinașilor": "băștinaș",
    "băștinașul": "băștinaș",
    "băștinașului": "băștinaș",
    "bastioane": "bastion",
    "bastioanele": "bastion",
    "bastioanelor": "bastion",
    "bastionul": "bastion",
    "bastionului": "bastion",
    "bastoane": "baston",
    "bastoanele": "baston",
    "bastoanelor": "baston",
    "bastonul": "baston",
    "bastonule": "baston",
    "bastonului": "baston",
    "bățul": "băț",
    "bățule": "băț",
    "bățului": "băț",
    "bețe": "băț",
    "bețele": "băț",
    "bețelor": "băț",
    "bâta": "bâtă",
    "bâte": "bâtă",
    "bâtei": "bâtă",
    "bâtele": "bâtă",
    "bâtelor": "bâtă",
    "bâțâia": "bâțâi",
    "bâțâiai": "bâțâi",
    "bâțâiam": "bâțâi",
    "bâțâiați": "bâțâi",
    "bâțâiau": "bâțâi",
    "bâțâie": "bâțâi",
    "bâțâii": "bâțâi",
    "bâțâim": "bâțâi",
    "bâțâind": "bâțâi",
    "bâțâindu": "bâțâi",
    "bâțâiră": "bâțâi",
    "bâțâirăm": "bâțâi",
    "bâțâirăți": "bâțâi",
    "bâțâise": "bâțâi",
    "bâțâisem": "bâțâi",
    "bâțâiseră": "bâțâi",
    "bâțâiserăm": "bâțâi",
    "bâțâiserăți": "bâțâi",
    "bâțâiseși": "bâțâi",
    "bâțâiși": "bâțâi",
    "bâțâit": "bâțâi",
    "bâțâiți": "bâțâi",
    "bâțâitu": "bâțâi",
    "nebâțâind": "bâțâi",
    "nebâțâindu": "bâțâi",
    "nemaibâțâind": "bâțâi",
    "nemaibâțâindu": "bâțâi",
    "bâțâiala": "bâțâială",
    "bâțâialo": "bâțâială",
    "bâțâieli": "bâțâială",
    "bâțâielii": "bâțâială",
    "bâțâielile": "bâțâială",
    "bâțâielilor": "bâțâială",
    "bătăi": "bătaie",
    "bătaia": "bătaie",
    "bătăii": "bătaie",
    "bătăile": "bătaie",
    "bătăilor": "bătaie",
    "bătaio": "bătaie",
    "bătăioasa": "bătăioasă",
    "bătăioase": "bătăioasă",
    "bătăioasei": "bătăioasă",
    "bătăioasele": "bătăioasă",
    "bătăioaselor": "bătăioasă",
    "bătăioasa": "bătăios",
    "bătăioasă": "bătăios",
    "bătăioase": "bătăios",
    "bătăioasei": "bătăios",
    "bătăioasele": "bătăios",
    "bătăioaselor": "bătăios",
    "bătăioși": "bătăios",
    "bătăioșii": "bătăios",
    "bătăioșilor": "bătăios",
    "bătăiosul": "bătăios",
    "bătăiosului": "bătăios",
    "bâțâirea": "bâțâire",
    "bâțâireo": "bâțâire",
    "bâțâiri": "bâțâire",
    "bâțâirii": "bâțâire",
    "bâțâirile": "bâțâire",
    "bâțâirilor": "bâțâire",
    "bâțâita": "bâțâit",
    "bâțâită": "bâțâit",
    "bâțâite": "bâțâit",
    "bâțâitei": "bâțâit",
    "bâțâitele": "bâțâit",
    "bâțâitelor": "bâțâit",
    "bâțâiți": "bâțâit",
    "bâțâiții": "bâțâit",
    "bâțâiților": "bâțâit",
    "bâțâito": "bâțâit",
    "bâțâitul": "bâțâit",
    "bâțâitule": "bâțâit",
    "bâțâitului": "bâțâit",
    "bâțâitoarea": "bâțâitoare",
    "bâțâitoarei": "bâțâitoare",
    "bâțâitoarele": "bâțâitoare",
    "bâțâitoarelor": "bâțâitoare",
    "bâțâitoareo": "bâțâitoare",
    "bâțâitoare": "bâțâitor",
    "bâțâitoarea": "bâțâitor",
    "bâțâitoarei": "bâțâitor",
    "bâțâitoarele": "bâțâitor",
    "bâțâitoarelor": "bâțâitor",
    "bâțâitoareo": "bâțâitor",
    "bâțâitori": "bâțâitor",
    "bâțâitorii": "bâțâitor",
    "bâțâitorilor": "bâțâitor",
    "bâțâitorul": "bâțâitor",
    "bâțâitorule": "bâțâitor",
    "bâțâitorului": "bâțâitor",
    "batali": "batal",
    "batalii": "batal",
    "batalilor": "batal",
    "batalul": "batal",
    "batalului": "batal",
    "bătălia": "bătălie",
    "bătăliei": "bătălie",
    "bătălii": "bătălie",
    "bătăliile": "bătălie",
    "bătăliilor": "bătălie",
    "bătălio": "bătălie",
    "batalioane": "batalion",
    "batalioanele": "batalion",
    "batalioanelor": "batalion",
    "batalionul": "batalion",
    "batalionului": "batalion",
    "batanta": "batant",
    "batante": "batant",
    "batantei": "batant",
    "batantele": "batant",
    "batantelor": "batant",
    "batanți": "batant",
    "batanții": "batant",
    "batanților": "batant",
    "batantul": "batant",
    "batantule": "batant",
    "batantului": "batant",
    "bătătorita": "bătătorit",
    "bătătorită": "bătătorit",
    "bătătorite": "bătătorit",
    "bătătoritei": "bătătorit",
    "bătătoritele": "bătătorit",
    "bătătoritelor": "bătătorit",
    "bătătoriți": "bătătorit",
    "bătătoriții": "bătătorit",
    "bătătoriților": "bătătorit",
    "bătătoritul": "bătătorit",
    "bătătoritului": "bătătorit",
    "bătătura": "bătătură",
    "bătături": "bătătură",
    "bătăturii": "bătătură",
    "bătăturile": "bătătură",
    "bătăturilor": "bătătură",
    "bătăuși": "bătăuș",
    "bătăușii": "bătăuș",
    "bătăușilor": "bătăuș",
    "bătăușul": "bătăuș",
    "bătăușului": "bătăuș",
    "bat": "bate",
    "bată": "bate",
    "bătând": "bate",
    "bătându": "bate",
    "bătea": "bate",
    "băteai": "bate",
    "băteam": "bate",
    "băteați": "bate",
    "băteau": "bate",
    "batem": "bate",
    "bateți": "bate",
    "bați": "bate",
    "bătu": "bate",
    "bătui": "bate",
    "bătură": "bate",
    "băturăm": "bate",
    "băturăți": "bate",
    "bătuse": "bate",
    "bătusem": "bate",
    "bătuseră": "bate",
    "bătuserăm": "bate",
    "bătuserăți": "bate",
    "bătuseși": "bate",
    "bătuși": "bate",
    "bătut": "bate",
    "bătutu": "bate",
    "nebătând": "bate",
    "nebătându": "bate",
    "nemaibătând": "bate",
    "nemaibătându": "bate",
    "baterea": "batere",
    "batereo": "batere",
    "bateri": "batere",
    "baterii": "batere",
    "baterile": "batere",
    "baterilor": "batere",
    "bateria": "baterie",
    "bateriei": "baterie",
    "baterii": "baterie",
    "bateriile": "baterie",
    "bateriilor": "baterie",
    "batista": "batistă",
    "batiste": "batistă",
    "batistei": "batistă",
    "batistele": "batistă",
    "batistelor": "batistă",
    "batjocoreala": "batjocoreală",
    "batjocorealo": "batjocoreală",
    "batjocoreli": "batjocoreală",
    "batjocorelii": "batjocoreală",
    "batjocorelile": "batjocoreală",
    "batjocorelilor": "batjocoreală",
    "batjocorea": "batjocori",
    "batjocoreai": "batjocori",
    "batjocoream": "batjocori",
    "batjocorească": "batjocori",
    "batjocoreați": "batjocori",
    "batjocoreau": "batjocori",
    "batjocoresc": "batjocori",
    "batjocorește": "batjocori",
    "batjocorești": "batjocori",
    "batjocorii": "batjocori",
    "batjocorim": "batjocori",
    "batjocorind": "batjocori",
    "batjocorindu": "batjocori",
    "batjocoriră": "batjocori",
    "batjocorirăm": "batjocori",
    "batjocorirăți": "batjocori",
    "batjocorise": "batjocori",
    "batjocorisem": "batjocori",
    "batjocoriseră": "batjocori",
    "batjocoriserăm": "batjocori",
    "batjocoriserăți": "batjocori",
    "batjocoriseși": "batjocori",
    "batjocoriși": "batjocori",
    "batjocorit": "batjocori",
    "batjocoriți": "batjocori",
    "batjocoritu": "batjocori",
    "nebatjocorind": "batjocori",
    "nebatjocorindu": "batjocori",
    "nemaibatjocorind": "batjocori",
    "nemaibatjocorindu": "batjocori",
    "batjocorirea": "batjocorire",
    "batjocorireo": "batjocorire",
    "batjocoriri": "batjocorire",
    "batjocoririi": "batjocorire",
    "batjocoririle": "batjocorire",
    "batjocoririlor": "batjocorire",
    "batjocorita": "batjocorit",
    "batjocorită": "batjocorit",
    "batjocorite": "batjocorit",
    "batjocoritei": "batjocorit",
    "batjocoritele": "batjocorit",
    "batjocoritelor": "batjocorit",
    "batjocoriți": "batjocorit",
    "batjocoriții": "batjocorit",
    "batjocoriților": "batjocorit",
    "batjocorito": "batjocorit",
    "batjocoritul": "batjocorit",
    "batjocoritule": "batjocorit",
    "batjocoritului": "batjocorit",
    "batjocoritoarea": "batjocoritoare",
    "batjocoritoarei": "batjocoritoare",
    "batjocoritoarele": "batjocoritoare",
    "batjocoritoarelor": "batjocoritoare",
    "batjocoritoareo": "batjocoritoare",
    "batjocoritoare": "batjocoritor",
    "batjocoritoarea": "batjocoritor",
    "batjocoritoarei": "batjocoritor",
    "batjocoritoarele": "batjocoritor",
    "batjocoritoarelor": "batjocoritor",
    "batjocoritoareo": "batjocoritor",
    "batjocoritori": "batjocoritor",
    "batjocoritorii": "batjocoritor",
    "batjocoritorilor": "batjocoritor",
    "batjocoritorul": "batjocoritor",
    "batjocoritorule": "batjocoritor",
    "batjocoritorului": "batjocoritor",
    "batjocura": "batjocură",
    "batjocuri": "batjocură",
    "batjocurii": "batjocură",
    "batjocurile": "batjocură",
    "batjocurilor": "batjocură",
    "batoane": "baton",
    "batoanele": "baton",
    "batoanelor": "baton",
    "batonul": "baton",
    "batonule": "baton",
    "batonului": "baton",
    "bățoasa": "bățos",
    "bățoasă": "bățos",
    "bățoase": "bățos",
    "bățoasei": "bățos",
    "bățoasele": "bățos",
    "bățoaselor": "bățos",
    "bățoaso": "bățos",
    "bățoși": "bățos",
    "bățoșii": "bățos",
    "bățoșilor": "bățos",
    "bățosul": "bățos",
    "bățosule": "bățos",
    "bățosului": "bățos",
    "bătrâna": "bătrân",
    "bătrână": "bătrân",
    "bătrâne": "bătrân",
    "bătrânei": "bătrân",
    "bătrânele": "bătrân",
    "bătrânelor": "bătrân",
    "bătrâni": "bătrân",
    "bătrânii": "bătrân",
    "bătrânilor": "bătrân",
    "bătrânul": "bătrân",
    "bătrânule": "bătrân",
    "bătrânului": "bătrân",
    "bătrâna": "bătrână",
    "bătrâne": "bătrână",
    "bătrânei": "bătrână",
    "bătrânele": "bătrână",
    "bătrânelor": "bătrână",
    "bătrâno": "bătrână",
    "bătrânei": "bătrânel",
    "bătrâneii": "bătrânel",
    "bătrâneilor": "bătrânel",
    "bătrânelul": "bătrânel",
    "bătrânelule": "bătrânel",
    "bătrânelului": "bătrânel",
    "bătrânica": "bătrânel",
    "bătrânică": "bătrânel",
    "bătrânice": "bătrânel",
    "bătrânici": "bătrânel",
    "bătrânicii": "bătrânel",
    "bătrânicile": "bătrânel",
    "bătrânicilor": "bătrânel",
    "bătrânețea": "bătrânețe",
    "bătrâneți": "bătrânețe",
    "bătrâneții": "bătrânețe",
    "bătrânețile": "bătrânețe",
    "bătrâneților": "bătrânețe",
    "bătrânica": "bătrânică",
    "bătrânice": "bătrânică",
    "bătrânici": "bătrânică",
    "bătrânicii": "bătrânică",
    "bătrânicile": "bătrânică",
    "bătrânicilor": "bătrânică",
    "bătucita": "bătucit",
    "bătucită": "bătucit",
    "bătucite": "bătucit",
    "bătucitei": "bătucit",
    "bătucitele": "bătucit",
    "bătucitelor": "bătucit",
    "bătuciți": "bătucit",
    "bătuciții": "bătucit",
    "bătuciților": "bătucit",
    "bătucitul": "bătucit",
    "bătucitului": "bătucit",
    "bătuta": "bătut",
    "bătută": "bătut",
    "bătute": "bătut",
    "bătutei": "bătut",
    "bătutele": "bătut",
    "bătutelor": "bătut",
    "bătuți": "bătut",
    "bătuții": "bătut",
    "bătuților": "bătut",
    "bătuto": "bătut",
    "bătutul": "bătut",
    "bătutule": "bătut",
    "bătutului": "bătut",
    "bătuta": "bătută",
    "bătute": "bătută",
    "bătutei": "bătută",
    "bătutele": "bătută",
    "bătutelor": "bătută",
    "bătuto": "bătută",
    "băubilă": "băubil",
    "băubile": "băubil",
    "băubili": "băubil",
    "băuta": "băut",
    "băută": "băut",
    "băute": "băut",
    "băutei": "băut",
    "băutele": "băut",
    "băutelor": "băut",
    "băuți": "băut",
    "băuții": "băut",
    "băuților": "băut",
    "băutul": "băut",
    "băutului": "băut",
    "băuta": "băută",
    "băute": "băută",
    "băutei": "băută",
    "băutele": "băută",
    "băutelor": "băută",
    "băutoarea": "băutoare",
    "băutoarei": "băutoare",
    "băutoarele": "băutoare",
    "băutoarelor": "băutoare",
    "băutoare": "băutor",
    "băutoarea": "băutor",
    "băutoarei": "băutor",
    "băutoarele": "băutor",
    "băutoarelor": "băutor",
    "băutori": "băutor",
    "băutorii": "băutor",
    "băutorilor": "băutor",
    "băutorul": "băutor",
    "băutorului": "băutor",
    "băutura": "băutură",
    "băuturi": "băutură",
    "băuturii": "băutură",
    "băuturile": "băutură",
    "băuturilor": "băutură",
    "bază": "baza",
    "bazai": "baza",
    "bazam": "baza",
    "bazăm": "baza",
    "bazând": "baza",
    "bazându": "baza",
    "bazară": "baza",
    "bazarăm": "baza",
    "bazarăți": "baza",
    "bazase": "baza",
    "bazasem": "baza",
    "bazaseră": "baza",
    "bazaserăm": "baza",
    "bazaserăți": "baza",
    "bazaseși": "baza",
    "bazași": "baza",
    "bazat": "baza",
    "bazați": "baza",
    "bazatu": "baza",
    "bazau": "baza",
    "bazează": "baza",
    "bazez": "baza",
    "bazeze": "baza",
    "bazezi": "baza",
    "nebazând": "baza",
    "nebazându": "baza",
    "nemaibazând": "baza",
    "nemaibazându": "baza",
    "baza": "bază",
    "baze": "bază",
    "bazei": "bază",
    "bazele": "bază",
    "bazelor": "bază",
    "bazaconia": "bazaconie",
    "bazaconiei": "bazaconie",
    "bazaconii": "bazaconie",
    "bazaconiile": "bazaconie",
    "bazaconiilor": "bazaconie",
    "bâzâia": "bâzâi",
    "bâzâiai": "bâzâi",
    "bâzâiam": "bâzâi",
    "bâzâiați": "bâzâi",
    "bâzâiau": "bâzâi",
    "bâzâie": "bâzâi",
    "bâzâii": "bâzâi",
    "bâzâim": "bâzâi",
    "bâzâind": "bâzâi",
    "bâzâindu": "bâzâi",
    "bâzâiră": "bâzâi",
    "bâzâirăm": "bâzâi",
    "bâzâirăți": "bâzâi",
    "bâzâise": "bâzâi",
    "bâzâisem": "bâzâi",
    "bâzâiseră": "bâzâi",
    "bâzâiserăm": "bâzâi",
    "bâzâiserăți": "bâzâi",
    "bâzâiseși": "bâzâi",
    "bâzâiși": "bâzâi",
    "bâzâit": "bâzâi",
    "bâzâiți": "bâzâi",
    "bâzâitu": "bâzâi",
    "nebâzâind": "bâzâi",
    "nebâzâindu": "bâzâi",
    "nemaibâzâind": "bâzâi",
    "nemaibâzâindu": "bâzâi",
    "bâzâiala": "bâzâială",
    "bâzâialo": "bâzâială",
    "bâzâieli": "bâzâială",
    "bâzâielii": "bâzâială",
    "bâzâielile": "bâzâială",
    "bâzâielilor": "bâzâială",
    "bâzâirea": "bâzâire",
    "bâzâireo": "bâzâire",
    "bâzâiri": "bâzâire",
    "bâzâirii": "bâzâire",
    "bâzâirile": "bâzâire",
    "bâzâirilor": "bâzâire",
    "bâzâita": "bâzâit",
    "bâzâită": "bâzâit",
    "bâzâite": "bâzâit",
    "bâzâitei": "bâzâit",
    "bâzâitele": "bâzâit",
    "bâzâitelor": "bâzâit",
    "bâzâiți": "bâzâit",
    "bâzâiții": "bâzâit",
    "bâzâiților": "bâzâit",
    "bâzâito": "bâzâit",
    "bâzâitul": "bâzâit",
    "bâzâitule": "bâzâit",
    "bâzâitului": "bâzâit",
    "bâzâita": "bâzâită",
    "bâzâite": "bâzâită",
    "bâzâitei": "bâzâită",
    "bâzâitele": "bâzâită",
    "bâzâitelor": "bâzâită",
    "bâzâito": "bâzâită",
    "bâzâitoarea": "bâzâitoare",
    "bâzâitoarei": "bâzâitoare",
    "bâzâitoarele": "bâzâitoare",
    "bâzâitoarelor": "bâzâitoare",
    "bâzâitoareo": "bâzâitoare",
    "bâzâitoare": "bâzâitor",
    "bâzâitoarea": "bâzâitor",
    "bâzâitoarei": "bâzâitor",
    "bâzâitoarele": "bâzâitor",
    "bâzâitoarelor": "bâzâitor",
    "bâzâitoareo": "bâzâitor",
    "bâzâitori": "bâzâitor",
    "bâzâitorii": "bâzâitor",
    "bâzâitorilor": "bâzâitor",
    "bâzâitorul": "bâzâitor",
    "bâzâitorule": "bâzâitor",
    "bâzâitorului": "bâzâitor",
    "bazarul": "bazar",
    "bazarului": "bazar",
    "bazaruri": "bazar",
    "bazarurile": "bazar",
    "bazarurilor": "bazar",
    "bazarea": "bazare",
    "bazări": "bazare",
    "bazării": "bazare",
    "bazările": "bazare",
    "bazata": "bazat",
    "bazată": "bazat",
    "bazate": "bazat",
    "bazatei": "bazat",
    "bazatele": "bazat",
    "bazatelor": "bazat",
    "bazați": "bazat",
    "bazații": "bazat",
    "bazaților": "bazat",
    "bazatul": "bazat",
    "bazatului": "bazat",
    "bazilica": "bazilică",
    "bazilici": "bazilică",
    "bazilicii": "bazilică",
    "bazilicile": "bazilică",
    "bazilicilor": "bazilică",
    "bazine": "bazin",
    "bazinele": "bazin",
    "bazinelor": "bazin",
    "bazinul": "bazin",
    "bazinului": "bazin",
    "bând": "bea",
    "bându": "bea",
    "bău": "bea",
    "băui": "bea",
    "băură": "bea",
    "băurăm": "bea",
    "băurăți": "bea",
    "băuse": "bea",
    "băusem": "bea",
    "băuseră": "bea",
    "băuserăm": "bea",
    "băuserăți": "bea",
    "băuseși": "bea",
    "băuși": "bea",
    "băut": "bea",
    "băutu": "bea",
    "beai": "bea",
    "beam": "bea",
    "beați": "bea",
    "beau": "bea",
    "bei": "bea",
    "bem": "bea",
    "beți": "bea",
    "nebând": "bea",
    "nebându": "bea",
    "nemaibând": "bea",
    "nemaibându": "bea",
    "beata": "beat",
    "beată": "beat",
    "beatul": "beat",
    "beatului": "beat",
    "bete": "beat",
    "betei": "beat",
    "betele": "beat",
    "betelor": "beat",
    "beți": "beat",
    "beții": "beat",
    "beților": "beat",
    "beatitudinea": "beatitudine",
    "beatitudini": "beatitudine",
    "beatitudinii": "beatitudine",
    "beatitudinile": "beatitudine",
    "beatitudinilor": "beatitudine",
    "bebeluși": "bebeluș",
    "bebelușii": "bebeluș",
    "bebelușilor": "bebeluș",
    "bebelușul": "bebeluș",
    "bebelușului": "bebeluș",
    "becul": "bec",
    "becului": "bec",
    "becuri": "bec",
    "becurile": "bec",
    "becurilor": "bec",
    "beciul": "beci",
    "beciule": "beci",
    "beciului": "beci",
    "beciuri": "beci",
    "beciurile": "beci",
    "beciurilor": "beci",
    "becisnica": "becisnic",
    "becisnică": "becisnic",
    "becisnice": "becisnic",
    "becisnicei": "becisnic",
    "becisnicele": "becisnic",
    "becisnicelor": "becisnic",
    "becisnici": "becisnic",
    "becisnicii": "becisnic",
    "becisnicilor": "becisnic",
    "becisnicul": "becisnic",
    "becisnicului": "becisnic",
    "beduina": "beduin",
    "beduină": "beduin",
    "beduine": "beduin",
    "beduinei": "beduin",
    "beduinele": "beduin",
    "beduinelor": "beduin",
    "beduini": "beduin",
    "beduinii": "beduin",
    "beduinilor": "beduin",
    "beduinul": "beduin",
    "beduinului": "beduin",
    "behăia": "behăi",
    "behăiai": "behăi",
    "behăiam": "behăi",
    "behăiați": "behăi",
    "behăiau": "behăi",
    "behăie": "behăi",
    "behăii": "behăi",
    "behăim": "behăi",
    "behăind": "behăi",
    "behăindu": "behăi",
    "behăiră": "behăi",
    "behăirăm": "behăi",
    "behăirăți": "behăi",
    "behăise": "behăi",
    "behăisem": "behăi",
    "behăiseră": "behăi",
    "behăiserăm": "behăi",
    "behăiserăți": "behăi",
    "behăiseși": "behăi",
    "behăiși": "behăi",
    "behăit": "behăi",
    "behăiți": "behăi",
    "behăitu": "behăi",
    "nebehăind": "behăi",
    "nebehăindu": "behăi",
    "nemaibehăind": "behăi",
    "nemaibehăindu": "behăi",
    "behăiala": "behăială",
    "behăialo": "behăială",
    "behăieli": "behăială",
    "behăielii": "behăială",
    "behăielile": "behăială",
    "behăielilor": "behăială",
    "behăirea": "behăire",
    "behăireo": "behăire",
    "behăiri": "behăire",
    "behăirii": "behăire",
    "behăirile": "behăire",
    "behăirilor": "behăire",
    "behăita": "behăit",
    "behăită": "behăit",
    "behăite": "behăit",
    "behăitei": "behăit",
    "behăitele": "behăit",
    "behăitelor": "behăit",
    "behăiți": "behăit",
    "behăiții": "behăit",
    "behăiților": "behăit",
    "behăito": "behăit",
    "behăitul": "behăit",
    "behăitule": "behăit",
    "behăitului": "behăit",
    "behăitoarea": "behăitoare",
    "behăitoarei": "behăitoare",
    "behăitoarele": "behăitoare",
    "behăitoarelor": "behăitoare",
    "behăitoareo": "behăitoare",
    "behăitoare": "behăitor",
    "behăitoarea": "behăitor",
    "behăitoarei": "behăitor",
    "behăitoarele": "behăitor",
    "behăitoarelor": "behăitor",
    "behăitoareo": "behăitor",
    "behăitori": "behăitor",
    "behăitorii": "behăitor",
    "behăitorilor": "behăitor",
    "behăitorul": "behăitor",
    "behăitorule": "behăitor",
    "behăitorului": "behăitor",
    "beii": "bei",
    "beilor": "bei",
    "beiul": "bei",
    "beiului": "bei",
    "Beijingul": "Beijing",
    "Beijingului": "Beijing",
    "beilicul": "beilic",
    "beilicului": "beilic",
    "beilicuri": "beilic",
    "beilicurile": "beilic",
    "beilicurilor": "beilic",
    "Beirutul": "Beirut",
    "Beirutului": "Beirut",
    "beizadeaua": "beizadea",
    "beizadele": "beizadea",
    "beizadelei": "beizadea",
    "beizadelele": "beizadea",
    "beizadelelor": "beizadea",
    "bejenia": "bejenie",
    "bejeniei": "bejenie",
    "bejenii": "bejenie",
    "bejeniile": "bejenie",
    "bejeniilor": "bejenie",
    "bejeniți": "bejenit",
    "bejeniții": "bejenit",
    "bejeniților": "bejenit",
    "bejenitul": "bejenit",
    "bejenitului": "bejenit",
    "B": "bel",
    "beli": "bel",
    "belii": "bel",
    "belilor": "bel",
    "belul": "bel",
    "belului": "bel",
    "beladona": "beladonă",
    "beladone": "beladonă",
    "beladonei": "beladonă",
    "beladonele": "beladonă",
    "beladonelor": "beladonă",
    "Belarusul": "Belarus",
    "Belarusului": "Belarus",
    "bele-artele": "bele-arte",
    "bele-artelor": "bele-arte",
    "Bel.": "Belgia",
    "Belgie": "Belgia",
    "Belgiei": "Belgia",
    "Belgii": "Belgia",
    "belgiana": "belgian",
    "belgiană": "belgian",
    "belgianul": "belgian",
    "belgianului": "belgian",
    "belgiene": "belgian",
    "belgienei": "belgian",
    "belgienele": "belgian",
    "belgienelor": "belgian",
    "belgieni": "belgian",
    "belgienii": "belgian",
    "belgienilor": "belgian",
    "belgianca": "belgiancă",
    "belgience": "belgiancă",
    "belgiencei": "belgiancă",
    "belgiencele": "belgiancă",
    "belgiencelor": "belgiancă",
    "belicoasa": "belicos",
    "belicoasă": "belicos",
    "belicoase": "belicos",
    "belicoasei": "belicos",
    "belicoasele": "belicos",
    "belicoaselor": "belicos",
    "belicoși": "belicos",
    "belicoșii": "belicos",
    "belicoșilor": "belicos",
    "belicosul": "belicos",
    "belicosului": "belicos",
    "beligeranta": "beligerant",
    "beligerantă": "beligerant",
    "beligerante": "beligerant",
    "beligerantei": "beligerant",
    "beligerantele": "beligerant",
    "beligerantelor": "beligerant",
    "beligeranți": "beligerant",
    "beligeranții": "beligerant",
    "beligeranților": "beligerant",
    "beligerantul": "beligerant",
    "beligerantului": "beligerant",
    "belinografe": "belinograf",
    "belinografele": "belinograf",
    "belinografelor": "belinograf",
    "belinograful": "belinograf",
    "belinografului": "belinograf",
    "belșugul": "belșug",
    "belșugului": "belșug",
    "belșuguri": "belșug",
    "belșugurile": "belșug",
    "belșugurilor": "belșug",
    "belvederea": "belvedere",
    "belvederi": "belvedere",
    "belvederii": "belvedere",
    "belvederile": "belvedere",
    "belvederilor": "belvedere",
    "bena": "benă",
    "bene": "benă",
    "benei": "benă",
    "benele": "benă",
    "benelor": "benă",
    "benchetuia": "benchetui",
    "benchetuiai": "benchetui",
    "benchetuiam": "benchetui",
    "benchetuiască": "benchetui",
    "benchetuiați": "benchetui",
    "benchetuiau": "benchetui",
    "benchetuiesc": "benchetui",
    "benchetuiește": "benchetui",
    "benchetuiești": "benchetui",
    "benchetuii": "benchetui",
    "benchetuim": "benchetui",
    "benchetuind": "benchetui",
    "benchetuindu": "benchetui",
    "benchetuiră": "benchetui",
    "benchetuirăm": "benchetui",
    "benchetuirăți": "benchetui",
    "benchetuise": "benchetui",
    "benchetuisem": "benchetui",
    "benchetuiseră": "benchetui",
    "benchetuiserăm": "benchetui",
    "benchetuiserăți": "benchetui",
    "benchetuiseși": "benchetui",
    "benchetuiși": "benchetui",
    "benchetuit": "benchetui",
    "benchetuiți": "benchetui",
    "benchetuirea": "benchetuire",
    "benchetuiri": "benchetuire",
    "benchetuirii": "benchetuire",
    "benchetuirile": "benchetuire",
    "benefica": "benefic",
    "benefică": "benefic",
    "benefice": "benefic",
    "beneficei": "benefic",
    "beneficele": "benefic",
    "beneficelor": "benefic",
    "benefici": "benefic",
    "beneficii": "benefic",
    "beneficilor": "benefic",
    "beneficul": "benefic",
    "beneficului": "benefic",
    "beneficiai": "beneficia",
    "beneficiam": "beneficia",
    "beneficiară": "beneficia",
    "beneficiarăm": "beneficia",
    "beneficiarăți": "beneficia",
    "beneficiase": "beneficia",
    "beneficiasem": "beneficia",
    "beneficiaseră": "beneficia",
    "beneficiaserăm": "beneficia",
    "beneficiaserăți": "beneficia",
    "beneficiaseși": "beneficia",
    "beneficiași": "beneficia",
    "beneficiat": "beneficia",
    "beneficiați": "beneficia",
    "beneficiatu": "beneficia",
    "beneficiau": "beneficia",
    "beneficiază": "beneficia",
    "beneficie": "beneficia",
    "beneficiem": "beneficia",
    "beneficiez": "beneficia",
    "beneficieze": "beneficia",
    "beneficiezi": "beneficia",
    "beneficiind": "beneficia",
    "beneficiindu": "beneficia",
    "nebeneficiind": "beneficia",
    "nebeneficiindu": "beneficia",
    "nemaibeneficiind": "beneficia",
    "nemaibeneficiindu": "beneficia",
    "beneficiari": "beneficiar",
    "beneficiarii": "beneficiar",
    "beneficiarilor": "beneficiar",
    "beneficiarul": "beneficiar",
    "beneficiarului": "beneficiar",
    "beneficiara": "beneficiară",
    "beneficiare": "beneficiară",
    "beneficiarei": "beneficiară",
    "beneficiarele": "beneficiară",
    "beneficiarelor": "beneficiară",
    "beneficiata": "beneficiat",
    "beneficiată": "beneficiat",
    "beneficiate": "beneficiat",
    "beneficiatei": "beneficiat",
    "beneficiatele": "beneficiat",
    "beneficiatelor": "beneficiat",
    "beneficiați": "beneficiat",
    "beneficiații": "beneficiat",
    "beneficiaților": "beneficiat",
    "beneficiatul": "beneficiat",
    "beneficiatului": "beneficiat",
    "beneficierea": "beneficiere",
    "beneficieri": "beneficiere",
    "beneficierii": "beneficiere",
    "beneficierile": "beneficiere",
    "beneficii": "beneficiu",
    "beneficiile": "beneficiu",
    "beneficiilor": "beneficiu",
    "beneficiul": "beneficiu",
    "beneficiului": "beneficiu",
    "benevola": "benevol",
    "benevolă": "benevol",
    "benevole": "benevol",
    "benevolei": "benevol",
    "benevolele": "benevol",
    "benevolelor": "benevol",
    "benevoli": "benevol",
    "benevolii": "benevol",
    "benevolilor": "benevol",
    "benevolul": "benevol",
    "benevolului": "benevol",
    "bengale": "bengal",
    "bengalele": "bengal",
    "bengalelor": "bengal",
    "bengalul": "bengal",
    "bengalului": "bengal",
    "bengaleza": "bengalez",
    "bengaleză": "bengalez",
    "bengaleze": "bengalez",
    "bengalezei": "bengalez",
    "bengalezele": "bengalez",
    "bengalezelor": "bengalez",
    "bengalezi": "bengalez",
    "bengalezii": "bengalez",
    "bengalezilor": "bengalez",
    "bengalezul": "bengalez",
    "bengalezului": "bengalez",
    "bengaleza": "bengaleză",
    "bengaleze": "bengaleză",
    "bengalezei": "bengaleză",
    "bengalezele": "bengaleză",
    "bengalezelor": "bengaleză",
    "Bengalie": "Bengalia",
    "Bengaliei": "Bengalia",
    "Bengalii": "Bengalia",
    "benghiul": "benghi",
    "benghiului": "benghi",
    "benghiuri": "benghi",
    "benghiurile": "benghi",
    "benghiurilor": "benghi",
    "benigna": "benign",
    "benignă": "benign",
    "benigne": "benign",
    "benignei": "benign",
    "benignele": "benign",
    "benignelor": "benign",
    "benigni": "benign",
    "benignii": "benign",
    "benignilor": "benign",
    "benignul": "benign",
    "benignului": "benign",
    "benzina": "benzină",
    "benzine": "benzină",
    "benzinei": "benzină",
    "benzinele": "benzină",
    "benzinelor": "benzină",
    "benzinăria": "benzinărie",
    "benzinăriei": "benzinărie",
    "benzinării": "benzinărie",
    "benzinăriile": "benzinărie",
    "benzinăriilor": "benzinărie",
    "berăria": "berărie",
    "berăriei": "berărie",
    "berării": "berărie",
    "berăriile": "berărie",
    "berăriilor": "berărie",
    "berbanți": "berbant",
    "berbanții": "berbant",
    "berbanților": "berbant",
    "berbantul": "berbant",
    "berbantului": "berbant",
    "berbecuți": "berbecuț",
    "berbecuții": "berbecuț",
    "berbecuților": "berbecuț",
    "berbecuțul": "berbecuț",
    "berbecuțului": "berbecuț",
    "bearca": "berc",
    "bearcă": "berc",
    "berce": "berc",
    "bercei": "berc",
    "bercele": "berc",
    "bercelor": "berc",
    "berci": "berc",
    "bercii": "berc",
    "bercilor": "berc",
    "bercul": "berc",
    "bercului": "berc",
    "berea": "bere",
    "bereo": "bere",
    "beri": "bere",
    "berii": "bere",
    "berile": "bere",
    "berilor": "bere",
    "berecheți": "berechet",
    "berecheții": "berechet",
    "berecheților": "berechet",
    "berechetul": "berechet",
    "berechetului": "berechet",
    "beregata": "beregată",
    "beregate": "beregată",
    "beregatei": "beregată",
    "beregatele": "beregată",
    "beregatelor": "beregată",
    "Be": "beriliu",
    "beriliul": "beriliu",
    "beriliului": "beriliu",
    "Berlinul": "Berlin",
    "Berlinului": "Berlin",
    "berna": "bernă",
    "berne": "bernă",
    "bernei": "bernă",
    "bernele": "bernă",
    "bernelor": "bernă",
    "beșica": "beșică",
    "beșici": "beșică",
    "beșicii": "beșică",
    "beșicile": "beșică",
    "beșicilor": "beșică",
    "beșico": "beșică",
    "beștelea": "beșteli",
    "beșteleai": "beșteli",
    "beșteleam": "beșteli",
    "beștelească": "beșteli",
    "beșteleați": "beșteli",
    "beșteleau": "beșteli",
    "beștelesc": "beșteli",
    "beștelește": "beșteli",
    "beștelești": "beșteli",
    "beștelii": "beșteli",
    "beștelim": "beșteli",
    "beștelind": "beșteli",
    "beștelindu": "beșteli",
    "beșteliră": "beșteli",
    "beștelirăm": "beșteli",
    "beștelirăți": "beșteli",
    "beștelise": "beșteli",
    "beștelisem": "beșteli",
    "beșteliseră": "beșteli",
    "beșteliserăm": "beșteli",
    "beșteliserăți": "beșteli",
    "beșteliseși": "beșteli",
    "beșteliși": "beșteli",
    "beștelit": "beșteli",
    "beșteliți": "beșteli",
    "beștelitu": "beșteli",
    "beștelită": "beștelit",
    "beștelite": "beștelit",
    "beșteliți": "beștelit",
    "bestiala": "bestial",
    "bestială": "bestial",
    "bestiale": "bestial",
    "bestialei": "bestial",
    "bestialele": "bestial",
    "bestialelor": "bestial",
    "bestiali": "bestial",
    "bestialii": "bestial",
    "bestialilor": "bestial",
    "bestialul": "bestial",
    "bestialului": "bestial",
    "bestialitatea": "bestialitate",
    "bestialități": "bestialitate",
    "bestialității": "bestialitate",
    "bestialitățile": "bestialitate",
    "bestialităților": "bestialitate",
    "bestia": "bestie",
    "bestiei": "bestie",
    "bestii": "bestie",
    "bestiile": "bestie",
    "bestiilor": "bestie",
    "beteaga": "beteag",
    "beteagă": "beteag",
    "beteagul": "beteag",
    "beteagului": "beteag",
    "betege": "beteag",
    "betegei": "beteag",
    "betegele": "beteag",
    "betegelor": "beteag",
    "betegi": "beteag",
    "betegii": "beteag",
    "betegilor": "beteag",
    "beteala": "beteală",
    "beteli": "beteală",
    "betelii": "beteală",
    "betelile": "beteală",
    "betelilor": "beteală",
    "betegea": "betegi",
    "betegeai": "betegi",
    "betegeam": "betegi",
    "betegească": "betegi",
    "betegeați": "betegi",
    "betegeau": "betegi",
    "betegesc": "betegi",
    "betegește": "betegi",
    "betegești": "betegi",
    "betegii": "betegi",
    "betegim": "betegi",
    "betegind": "betegi",
    "betegindu": "betegi",
    "betegiră": "betegi",
    "betegirăm": "betegi",
    "betegirăți": "betegi",
    "betegise": "betegi",
    "betegisem": "betegi",
    "betegiseră": "betegi",
    "betegiserăm": "betegi",
    "betegiserăți": "betegi",
    "betegiseși": "betegi",
    "betegiși": "betegi",
    "betegit": "betegi",
    "betegiți": "betegi",
    "betegitu": "betegi",
    "betegită": "betegit",
    "betegite": "betegit",
    "betegiți": "betegit",
    "betelia": "betelie",
    "beteliei": "betelie",
    "betelii": "betelie",
    "beteliile": "betelie",
    "beteliilor": "betelie",
    "beteșugul": "beteșug",
    "beteșugului": "beteșug",
    "beteșuguri": "beteșug",
    "beteșugurile": "beteșug",
    "beteșugurilor": "beteșug",
    "beția": "beție",
    "beției": "beție",
    "beții": "beție",
    "bețiile": "beție",
    "bețiilor": "beție",
    "bețiva": "bețiv",
    "bețivă": "bețiv",
    "bețive": "bețiv",
    "bețivei": "bețiv",
    "bețivele": "bețiv",
    "bețivelor": "bețiv",
    "bețivi": "bețiv",
    "bețivii": "bețiv",
    "bețivilor": "bețiv",
    "bețivo": "bețiv",
    "bețivul": "bețiv",
    "bețivule": "bețiv",
    "bețivului": "bețiv",
    "bețiva": "bețivă",
    "bețive": "bețivă",
    "bețivei": "bețivă",
    "bețivele": "bețivă",
    "bețivelor": "bețivă",
    "bețivo": "bețivă",
    "betoane": "beton",
    "betoanele": "beton",
    "betoanelor": "beton",
    "betonul": "beton",
    "betonului": "beton",
    "betoniera": "betonieră",
    "betoniere": "betonieră",
    "betonierei": "betonieră",
    "betonierele": "betonieră",
    "betonierelor": "betonieră",
    "bezeaua": "bezea",
    "bezele": "bezea",
    "bezelei": "bezea",
    "bezelele": "bezea",
    "bezelelor": "bezea",
    "besmetice": "bezmetic",
    "bezmetica": "bezmetic",
    "bezmetică": "bezmetic",
    "bezmetice": "bezmetic",
    "bezmeticei": "bezmetic",
    "bezmeticele": "bezmetic",
    "bezmeticelor": "bezmetic",
    "bezmetici": "bezmetic",
    "bezmeticii": "bezmetic",
    "bezmeticilor": "bezmetic",
    "bezmeticul": "bezmetic",
    "bezmeticului": "bezmetic",
    "bezna": "beznă",
    "bezne": "beznă",
    "beznei": "beznă",
    "beznele": "beznă",
    "beznelor": "beznă",
    "bietei": "biata",
    "bietele": "biata",
    "bietelor": "biata",
    "biatloane": "biatlon",
    "biatloanele": "biatlon",
    "biatloanelor": "biatlon",
    "biatlonul": "biatlon",
    "biatlonului": "biatlon",
    "bibeloul": "bibelou",
    "bibeloului": "bibelou",
    "bibelouri": "bibelou",
    "bibelourile": "bibelou",
    "bibelourilor": "bibelou",
    "biblica": "biblic",
    "biblică": "biblic",
    "biblice": "biblic",
    "biblicei": "biblic",
    "biblicele": "biblic",
    "biblicelor": "biblic",
    "biblici": "biblic",
    "biblicii": "biblic",
    "biblicilor": "biblic",
    "biblicul": "biblic",
    "biblicului": "biblic",
    "biblia": "biblie",
    "bibliei": "biblie",
    "biblii": "biblie",
    "bibliile": "biblie",
    "bibliilor": "biblie",
    "bibliografia": "bibliografie",
    "bibliografiei": "bibliografie",
    "bibliografii": "bibliografie",
    "bibliografiile": "bibliografie",
    "bibliografiilor": "bibliografie",
    "biblioraftul": "biblioraft",
    "biblioraftului": "biblioraft",
    "bibliorafturi": "biblioraft",
    "bibliorafturile": "biblioraft",
    "bibliorafturilor": "biblioraft",
    "biblioteca": "bibliotecă",
    "biblioteci": "bibliotecă",
    "bibliotecii": "bibliotecă",
    "bibliotecile": "bibliotecă",
    "bibliotecilor": "bibliotecă",
    "biblioteco": "bibliotecă",
    "bibliotecari": "bibliotecar",
    "bibliotecarii": "bibliotecar",
    "bibliotecarilor": "bibliotecar",
    "bibliotecarul": "bibliotecar",
    "bibliotecarului": "bibliotecar",
    "bibliotecara": "bibliotecară",
    "bibliotecare": "bibliotecară",
    "bibliotecarei": "bibliotecară",
    "bibliotecarele": "bibliotecară",
    "bibliotecarelor": "bibliotecară",
    "bibliotecuța": "bibliotecuță",
    "bibliotecuțe": "bibliotecuță",
    "bibliotecuței": "bibliotecuță",
    "bibliotecuțele": "bibliotecuță",
    "bibliotecuțelor": "bibliotecuță",
    "bibliotecuțo": "bibliotecuță",
    "Bicazul": "Bicaz",
    "Bicazului": "Bicaz",
    "bicefala": "bicefal",
    "bicefală": "bicefal",
    "bicefale": "bicefal",
    "bicefalei": "bicefal",
    "bicefalele": "bicefal",
    "bicefalelor": "bicefal",
    "bicefali": "bicefal",
    "bicefalii": "bicefal",
    "bicefalilor": "bicefal",
    "bicefalul": "bicefal",
    "bicefalului": "bicefal",
    "bicepși": "biceps",
    "bicepșii": "biceps",
    "bicepșilor": "biceps",
    "bicepsul": "biceps",
    "bicepsule": "biceps",
    "bicepsului": "biceps",
    "bice": "bici",
    "bicele": "bici",
    "bicelor": "bici",
    "biciul": "bici",
    "biciule": "bici",
    "biciului": "bici",
    "bicicleta": "bicicletă",
    "biciclete": "bicicletă",
    "bicicletei": "bicicletă",
    "bicicletele": "bicicletă",
    "bicicletelor": "bicicletă",
    "bicicleto": "bicicletă",
    "bicicliști": "biciclist",
    "bicicliștii": "biciclist",
    "bicicliștilor": "biciclist",
    "biciclistul": "biciclist",
    "biciclistului": "biciclist",
    "bicisnica": "bicisnic",
    "bicisnică": "bicisnic",
    "bicisnice": "bicisnic",
    "bicisnicei": "bicisnic",
    "bicisnicele": "bicisnic",
    "bicisnicelor": "bicisnic",
    "bicisnici": "bicisnic",
    "bicisnicii": "bicisnic",
    "bicisnicilor": "bicisnic",
    "bicisnicul": "bicisnic",
    "bicisnicului": "bicisnic",
    "biciuia": "biciui",
    "biciuiai": "biciui",
    "biciuiam": "biciui",
    "biciuiască": "biciui",
    "biciuiați": "biciui",
    "biciuiau": "biciui",
    "biciuiesc": "biciui",
    "biciuiește": "biciui",
    "biciuiești": "biciui",
    "biciuii": "biciui",
    "biciuim": "biciui",
    "biciuind": "biciui",
    "biciuindu": "biciui",
    "biciuiră": "biciui",
    "biciuirăm": "biciui",
    "biciuirăți": "biciui",
    "biciuise": "biciui",
    "biciuisem": "biciui",
    "biciuiseră": "biciui",
    "biciuiserăm": "biciui",
    "biciuiserăți": "biciui",
    "biciuiseși": "biciui",
    "biciuiși": "biciui",
    "biciuit": "biciui",
    "biciuiți": "biciui",
    "biciuitu": "biciui",
    "nebiciuind": "biciui",
    "nebiciuindu": "biciui",
    "nemaibiciuind": "biciui",
    "nemaibiciuindu": "biciui",
    "biciuiala": "biciuială",
    "biciuialo": "biciuială",
    "biciuieli": "biciuială",
    "biciuielii": "biciuială",
    "biciuielile": "biciuială",
    "biciuielilor": "biciuială",
    "biciuirea": "biciuire",
    "biciuireo": "biciuire",
    "biciuiri": "biciuire",
    "biciuirii": "biciuire",
    "biciuirile": "biciuire",
    "biciuirilor": "biciuire",
    "biciuita": "biciuit",
    "biciuită": "biciuit",
    "biciuite": "biciuit",
    "biciuitei": "biciuit",
    "biciuitele": "biciuit",
    "biciuitelor": "biciuit",
    "biciuiți": "biciuit",
    "biciuiții": "biciuit",
    "biciuiților": "biciuit",
    "biciuito": "biciuit",
    "biciuitul": "biciuit",
    "biciuitule": "biciuit",
    "biciuitului": "biciuit",
    "biciuitoare": "biciuitor",
    "biciuitoarea": "biciuitor",
    "biciuitoarei": "biciuitor",
    "biciuitoarele": "biciuitor",
    "biciuitoarelor": "biciuitor",
    "biciuitoareo": "biciuitor",
    "biciuitori": "biciuitor",
    "biciuitorii": "biciuitor",
    "biciuitorilor": "biciuitor",
    "biciuitorul": "biciuitor",
    "biciuitorule": "biciuitor",
    "biciuitorului": "biciuitor",
    "biconcava": "biconcav",
    "biconcavă": "biconcav",
    "biconcave": "biconcav",
    "biconcavei": "biconcav",
    "biconcavele": "biconcav",
    "biconcavelor": "biconcav",
    "biconcavi": "biconcav",
    "biconcavii": "biconcav",
    "biconcavilor": "biconcav",
    "biconcavul": "biconcav",
    "biconcavului": "biconcav",
    "bidimensională": "bidimensional",
    "bidimensionale": "bidimensional",
    "bidimensionali": "bidimensional",
    "bidivii": "bidiviu",
    "bidiviii": "bidiviu",
    "bidiviilor": "bidiviu",
    "bidiviul": "bidiviu",
    "bidiviului": "bidiviu",
    "bieful": "bief",
    "biefului": "bief",
    "biefuri": "bief",
    "biefurile": "bief",
    "biefurilor": "bief",
    "biela": "bielă",
    "biele": "bielă",
    "bielei": "bielă",
    "bielele": "bielă",
    "bielelor": "bielă",
    "bienala": "bienal",
    "bienală": "bienal",
    "bienale": "bienal",
    "bienalei": "bienal",
    "bienalele": "bienal",
    "bienalelor": "bienal",
    "bienali": "bienal",
    "bienalii": "bienal",
    "bienalilor": "bienal",
    "bienalul": "bienal",
    "bienalului": "bienal",
    "biata": "biet",
    "biată": "biet",
    "biete": "biet",
    "bietei": "biet",
    "bietele": "biet",
    "bietelor": "biet",
    "bieți": "biet",
    "bieții": "biet",
    "bieților": "biet",
    "bietul": "biet",
    "bietului": "biet",
    "bieții": "bietul",
    "bieților": "bietul",
    "bietului": "bietul",
    "bifă": "bifa",
    "bifai": "bifa",
    "bifam": "bifa",
    "bifăm": "bifa",
    "bifând": "bifa",
    "bifându": "bifa",
    "bifară": "bifa",
    "bifarăm": "bifa",
    "bifarăți": "bifa",
    "bifase": "bifa",
    "bifasem": "bifa",
    "bifaseră": "bifa",
    "bifaserăm": "bifa",
    "bifaserăți": "bifa",
    "bifaseși": "bifa",
    "bifași": "bifa",
    "bifat": "bifa",
    "bifați": "bifa",
    "bifatu": "bifa",
    "bifau": "bifa",
    "bifează": "bifa",
    "bifez": "bifa",
    "bifeze": "bifa",
    "bifezi": "bifa",
    "nebifând": "bifa",
    "nebifându": "bifa",
    "nemaibifând": "bifa",
    "nemaibifându": "bifa",
    "bifarea": "bifare",
    "bifări": "bifare",
    "bifării": "bifare",
    "bifările": "bifare",
    "bifata": "bifat",
    "bifată": "bifat",
    "bifate": "bifat",
    "bifatei": "bifat",
    "bifatele": "bifat",
    "bifatelor": "bifat",
    "bifați": "bifat",
    "bifații": "bifat",
    "bifaților": "bifat",
    "bifatul": "bifat",
    "bifatului": "bifat",
    "biftecul": "biftec",
    "biftecului": "biftec",
    "biftecuri": "biftec",
    "biftecurile": "biftec",
    "biftecurilor": "biftec",
    "bifurc": "bifurca",
    "bifurcă": "bifurca",
    "bifurcai": "bifurca",
    "bifurcam": "bifurca",
    "bifurcăm": "bifurca",
    "bifurcând": "bifurca",
    "bifurcându": "bifurca",
    "bifurcară": "bifurca",
    "bifurcarăm": "bifurca",
    "bifurcarăți": "bifurca",
    "bifurcase": "bifurca",
    "bifurcasem": "bifurca",
    "bifurcaseră": "bifurca",
    "bifurcaserăm": "bifurca",
    "bifurcaserăți": "bifurca",
    "bifurcaseși": "bifurca",
    "bifurcași": "bifurca",
    "bifurcat": "bifurca",
    "bifurcați": "bifurca",
    "bifurcatu": "bifurca",
    "bifurcau": "bifurca",
    "bifurce": "bifurca",
    "bifurci": "bifurca",
    "nebifurcând": "bifurca",
    "nebifurcându": "bifurca",
    "nemaibifurcând": "bifurca",
    "nemaibifurcându": "bifurca",
    "bifurcarea": "bifurcare",
    "bifurcări": "bifurcare",
    "bifurcării": "bifurcare",
    "bifurcările": "bifurcare",
    "bifurcata": "bifurcat",
    "bifurcată": "bifurcat",
    "bifurcate": "bifurcat",
    "bifurcatei": "bifurcat",
    "bifurcatele": "bifurcat",
    "bifurcatelor": "bifurcat",
    "bifurcați": "bifurcat",
    "bifurcații": "bifurcat",
    "bifurcaților": "bifurcat",
    "bifurcatul": "bifurcat",
    "bifurcatului": "bifurcat",
    "bigami": "bigam",
    "bigamii": "bigam",
    "bigamilor": "bigam",
    "bigamul": "bigam",
    "bigamului": "bigam",
    "bigama": "bigamă",
    "bigame": "bigamă",
    "bigamei": "bigamă",
    "bigamele": "bigamă",
    "bigamelor": "bigamă",
    "bigoți": "bigot",
    "bigoții": "bigot",
    "bigoților": "bigot",
    "bigotul": "bigot",
    "bigotului": "bigot",
    "bigota": "bigotă",
    "bigote": "bigotă",
    "bigotei": "bigotă",
    "bigotele": "bigotă",
    "bigotelor": "bigotă",
    "bigotisme": "bigotism",
    "bigotismele": "bigotism",
    "bigotismelor": "bigotism",
    "bigotismul": "bigotism",
    "bigotismului": "bigotism",
    "bigudiul": "bigudiu",
    "bigudiului": "bigudiu",
    "bigudiuri": "bigudiu",
    "bigudiurile": "bigudiu",
    "bigudiurilor": "bigudiu",
    "bijuteria": "bijuterie",
    "bijuteriei": "bijuterie",
    "bijuterii": "bijuterie",
    "bijuteriile": "bijuterie",
    "bijuteriilor": "bijuterie",
    "bijutieri": "bijutier",
    "bijutierii": "bijutier",
    "bijutierilor": "bijutier",
    "bijutierul": "bijutier",
    "bijutierului": "bijutier",
    "bila": "bilă",
    "bile": "bilă",
    "bilei": "bilă",
    "bilele": "bilă",
    "bilelor": "bilă",
    "bilo": "bilă",
    "bilanțul": "bilanț",
    "bilanțului": "bilanț",
    "bilanțuri": "bilanț",
    "bilanțurile": "bilanț",
    "bilanțurilor": "bilanț",
    "bilaterala": "bilateral",
    "bilaterală": "bilateral",
    "bilaterale": "bilateral",
    "bilateralei": "bilateral",
    "bilateralele": "bilateral",
    "bilateralelor": "bilateral",
    "bilaterali": "bilateral",
    "bilateralii": "bilateral",
    "bilateralilor": "bilateral",
    "bilateralul": "bilateral",
    "bilateralului": "bilateral",
    "bilete": "bilet",
    "biletele": "bilet",
    "biletelor": "bilet",
    "biletul": "bilet",
    "biletule": "bilet",
    "biletului": "bilet",
    "bilețele": "bilețel",
    "bilețelele": "bilețel",
    "bilețelelor": "bilețel",
    "bilețelul": "bilețel",
    "bilețelule": "bilețel",
    "bilețelului": "bilețel",
    "bilingva": "bilingv",
    "bilingvă": "bilingv",
    "bilingve": "bilingv",
    "bilingvei": "bilingv",
    "bilingvele": "bilingv",
    "bilingvelor": "bilingv",
    "bilingvi": "bilingv",
    "bilingvii": "bilingv",
    "bilingvilor": "bilingv",
    "bilingvul": "bilingv",
    "bilingvului": "bilingv",
    "bilingvismul": "bilingvism",
    "bilingvismului": "bilingvism",
    "bilunara": "bilunar",
    "bilunară": "bilunar",
    "bilunare": "bilunar",
    "bilunarei": "bilunar",
    "bilunarele": "bilunar",
    "bilunarelor": "bilunar",
    "bilunari": "bilunar",
    "bilunarii": "bilunar",
    "bilunarilor": "bilunar",
    "bilunarul": "bilunar",
    "bilunarului": "bilunar",
    "bimana": "biman",
    "bimană": "biman",
    "bimane": "biman",
    "bimanei": "biman",
    "bimanele": "biman",
    "bimanelor": "biman",
    "bimani": "biman",
    "bimanii": "biman",
    "bimanilor": "biman",
    "bimanul": "biman",
    "bimanului": "biman",
    "bimilenara": "bimilenar",
    "bimilenară": "bimilenar",
    "bimilenare": "bimilenar",
    "bimilenarei": "bimilenar",
    "bimilenarele": "bimilenar",
    "bimilenarelor": "bimilenar",
    "bimilenari": "bimilenar",
    "bimilenarii": "bimilenar",
    "bimilenarilor": "bimilenar",
    "bimilenarul": "bimilenar",
    "bimilenarului": "bimilenar",
    "binale": "bina",
    "binara": "binar",
    "binară": "binar",
    "binare": "binar",
    "binarei": "binar",
    "binarele": "binar",
    "binarelor": "binar",
    "binari": "binar",
    "binarii": "binar",
    "binarilor": "binar",
    "binarul": "binar",
    "binarului": "binar",
    "binele": "bine",
    "binelui": "bine",
    "bine_credincioasa": "bine_credincios",
    "bine_credincioasă": "bine_credincios",
    "bine_credincioase": "bine_credincios",
    "bine_credincioasei": "bine_credincios",
    "bine_credincioasele": "bine_credincios",
    "bine_credincioaselor": "bine_credincios",
    "bine_credincioși": "bine_credincios",
    "bine_credincioșii": "bine_credincios",
    "bine_credincioșilor": "bine_credincios",
    "bine_credinciosul": "bine_credincios",
    "bine_credinciosului": "bine_credincios",
    "bine_crescută": "bine_crescut",
    "bine_crescute": "bine_crescut",
    "bine_crescuți": "bine_crescut",
    "bine_cunoscuta": "bine_cunoscut",
    "bine_cunoscută": "bine_cunoscut",
    "bine_cunoscute": "bine_cunoscut",
    "bine_cunoscutei": "bine_cunoscut",
    "bine_cunoscutele": "bine_cunoscut",
    "bine_cunoscutelor": "bine_cunoscut",
    "bine_cunoscuți": "bine_cunoscut",
    "bine_cunoscuții": "bine_cunoscut",
    "bine_cunoscuților": "bine_cunoscut",
    "bine_cunoscutul": "bine_cunoscut",
    "bine_cunoscutului": "bine_cunoscut",
    "binecunoscutele": "bine_cunoscut",
    "bine-crescută": "bine-crescut",
    "bine-crescute": "bine-crescut",
    "bine-crescuți": "bine-crescut",
    "binecunoscutele": "binecunoscut",
    "bine-cunoscuta": "bine-cunoscut",
    "bine-cunoscută": "bine-cunoscut",
    "bine-cunoscute": "bine-cunoscut",
    "bine-cunoscutei": "bine-cunoscut",
    "bine-cunoscutele": "bine-cunoscut",
    "bine-cunoscutelor": "bine-cunoscut",
    "bine-cunoscuți": "bine-cunoscut",
    "bine-cunoscuții": "bine-cunoscut",
    "bine-cunoscuților": "bine-cunoscut",
    "bine-cunoscutul": "bine-cunoscut",
    "bine-cunoscutului": "bine-cunoscut",
    "binecuvântă": "binecuvânta",
    "binecuvântai": "binecuvânta",
    "binecuvântam": "binecuvânta",
    "binecuvântăm": "binecuvânta",
    "binecuvântând": "binecuvânta",
    "binecuvântându": "binecuvânta",
    "binecuvântară": "binecuvânta",
    "binecuvântarăm": "binecuvânta",
    "binecuvântarăți": "binecuvânta",
    "binecuvântase": "binecuvânta",
    "binecuvântasem": "binecuvânta",
    "binecuvântaseră": "binecuvânta",
    "binecuvântaserăm": "binecuvânta",
    "binecuvântaserăți": "binecuvânta",
    "binecuvântaseși": "binecuvânta",
    "binecuvântași": "binecuvânta",
    "binecuvântat": "binecuvânta",
    "binecuvântați": "binecuvânta",
    "binecuvântatu": "binecuvânta",
    "binecuvântau": "binecuvânta",
    "binecuvântează": "binecuvânta",
    "binecuvântez": "binecuvânta",
    "binecuvânteze": "binecuvânta",
    "binecuvântezi": "binecuvânta",
    "binecuvântarea": "binecuvântare",
    "binecuvântări": "binecuvântare",
    "binecuvântării": "binecuvântare",
    "binecuvântările": "binecuvântare",
    "binecuvântărilor": "binecuvântare",
    "binecuvântata": "binecuvântat",
    "binecuvântată": "binecuvântat",
    "binecuvântate": "binecuvântat",
    "binecuvântatei": "binecuvântat",
    "binecuvântatele": "binecuvântat",
    "binecuvântatelor": "binecuvântat",
    "binecuvântați": "binecuvântat",
    "binecuvântații": "binecuvântat",
    "binecuvântaților": "binecuvântat",
    "binecuvântatul": "binecuvântat",
    "binecuvântatului": "binecuvântat",
    "binedispui": "binedispune",
    "binedispun": "binedispune",
    "binedispună": "binedispune",
    "binedispunând": "binedispune",
    "binedispunându": "binedispune",
    "binedispunea": "binedispune",
    "binedispuneai": "binedispune",
    "binedispuneam": "binedispune",
    "binedispuneați": "binedispune",
    "binedispuneau": "binedispune",
    "binedispunem": "binedispune",
    "binedispuneți": "binedispune",
    "binedispus": "binedispune",
    "binedispuse": "binedispune",
    "binedispusei": "binedispune",
    "binedispuseră": "binedispune",
    "binedispuserăm": "binedispune",
    "binedispuserăți": "binedispune",
    "binedispusese": "binedispune",
    "binedispusesem": "binedispune",
    "binedispuseseră": "binedispune",
    "binedispuseserăm": "binedispune",
    "binedispuseserăți": "binedispune",
    "binedispuseseși": "binedispune",
    "binedispuseși": "binedispune",
    "binedispusu": "binedispune",
    "binedispusă": "binedispus",
    "binedispuse": "binedispus",
    "binedispuși": "binedispus",
    "binefăcătoarea": "binefăcătoare",
    "binefăcătoarei": "binefăcătoare",
    "binefăcătoarele": "binefăcătoare",
    "binefăcătoarelor": "binefăcătoare",
    "binefăcătoareo": "binefăcătoare",
    "binefăcătoare": "binefăcător",
    "binefăcători": "binefăcător",
    "binefăcătorii": "binefăcător",
    "binefăcătorilor": "binefăcător",
    "binefăcătorul": "binefăcător",
    "binefăcătorule": "binefăcător",
    "binefăcătorului": "binefăcător",
    "binefacerea": "binefacere",
    "binefaceri": "binefacere",
    "binefacerii": "binefacere",
    "binefacerile": "binefacere",
    "binefacerilor": "binefacere",
    "binemerit": "binemerita",
    "binemerită": "binemerita",
    "binemeritai": "binemerita",
    "binemeritam": "binemerita",
    "binemerităm": "binemerita",
    "binemeritând": "binemerita",
    "binemeritându": "binemerita",
    "binemeritară": "binemerita",
    "binemeritarăm": "binemerita",
    "binemeritarăți": "binemerita",
    "binemeritase": "binemerita",
    "binemeritasem": "binemerita",
    "binemeritaseră": "binemerita",
    "binemeritaserăm": "binemerita",
    "binemeritaserăți": "binemerita",
    "binemeritaseși": "binemerita",
    "binemeritași": "binemerita",
    "binemeritat": "binemerita",
    "binemeritați": "binemerita",
    "binemeritatu": "binemerita",
    "binemeritau": "binemerita",
    "binemerite": "binemerita",
    "binemeriți": "binemerita",
    "nebinemeritând": "binemerita",
    "nebinemeritându": "binemerita",
    "nemaibinemeritând": "binemerita",
    "nemaibinemeritându": "binemerita",
    "binemeritarea": "binemeritare",
    "binemeritări": "binemeritare",
    "binemeritării": "binemeritare",
    "binemeritările": "binemeritare",
    "binemeritata": "binemeritat",
    "binemeritată": "binemeritat",
    "binemeritate": "binemeritat",
    "binemeritatei": "binemeritat",
    "binemeritatele": "binemeritat",
    "binemeritatelor": "binemeritat",
    "binemeritați": "binemeritat",
    "binemeritații": "binemeritat",
    "binemeritaților": "binemeritat",
    "binemeritatul": "binemeritat",
    "binemeritatului": "binemeritat",
    "binevoită": "binemeritat",
    "bineplăcuta": "bineplăcut",
    "bineplăcută": "bineplăcut",
    "bineplăcute": "bineplăcut",
    "bineplăcutei": "bineplăcut",
    "bineplăcutele": "bineplăcut",
    "bineplăcutelor": "bineplăcut",
    "bineplăcuți": "bineplăcut",
    "bineplăcuții": "bineplăcut",
    "bineplăcuților": "bineplăcut",
    "bineplăcutul": "bineplăcut",
    "bineplăcutului": "bineplăcut",
    "bineștiuta": "bineștiut",
    "bineștiută": "bineștiut",
    "bineștiute": "bineștiut",
    "bineștiutei": "bineștiut",
    "bineștiutele": "bineștiut",
    "bineștiutelor": "bineștiut",
    "bineștiuți": "bineștiut",
    "bineștiuții": "bineștiut",
    "bineștiuților": "bineștiut",
    "bineștiutul": "bineștiut",
    "bineștiutului": "bineștiut",
    "binețea": "binețe",
    "binețele": "binețe",
    "binețelor": "binețe",
    "bineți": "binețe",
    "bineții": "binețe",
    "binevenita": "binevenit",
    "binevenită": "binevenit",
    "binevenite": "binevenit",
    "binevenitei": "binevenit",
    "binevenitele": "binevenit",
    "binevenitelor": "binevenit",
    "bineveniți": "binevenit",
    "bineveniții": "binevenit",
    "bineveniților": "binevenit",
    "binevenitul": "binevenit",
    "binevenitului": "binevenit",
    "binevoia": "binevoi",
    "binevoiai": "binevoi",
    "binevoiam": "binevoi",
    "binevoiască": "binevoi",
    "binevoiați": "binevoi",
    "binevoiau": "binevoi",
    "binevoiesc": "binevoi",
    "binevoiește": "binevoi",
    "binevoiești": "binevoi",
    "binevoii": "binevoi",
    "binevoim": "binevoi",
    "binevoind": "binevoi",
    "binevoindu": "binevoi",
    "binevoiră": "binevoi",
    "binevoirăm": "binevoi",
    "binevoirăți": "binevoi",
    "binevoise": "binevoi",
    "binevoisem": "binevoi",
    "binevoiseră": "binevoi",
    "binevoiserăm": "binevoi",
    "binevoiserăți": "binevoi",
    "binevoiseși": "binevoi",
    "binevoiși": "binevoi",
    "binevoit": "binevoi",
    "binevoiți": "binevoi",
    "binevoitu": "binevoi",
    "nebinevoind": "binevoi",
    "nebinevoindu": "binevoi",
    "nemaibinevoind": "binevoi",
    "nemaibinevoindu": "binevoi",
    "binevoirea": "binevoire",
    "binevoiri": "binevoire",
    "binevoirii": "binevoire",
    "binevoirile": "binevoire",
    "binevoita": "binevoit",
    "binevoită": "binevoit",
    "binevoite": "binevoit",
    "binevoitei": "binevoit",
    "binevoitele": "binevoit",
    "binevoitelor": "binevoit",
    "binevoiți": "binevoit",
    "binevoiții": "binevoit",
    "binevoiților": "binevoit",
    "binevoitul": "binevoit",
    "binevoitului": "binevoit",
    "binevoitoarea": "binevoitoare",
    "binevoitoarei": "binevoitoare",
    "binevoitoarele": "binevoitoare",
    "binevoitoarelor": "binevoitoare",
    "binevoitoareo": "binevoitoare",
    "binevoitoare": "binevoitor",
    "binevoitoarea": "binevoitor",
    "binevoitoarei": "binevoitor",
    "binevoitoarele": "binevoitor",
    "binevoitoarelor": "binevoitor",
    "binevoitoareo": "binevoitor",
    "binevoitori": "binevoitor",
    "binevoitorii": "binevoitor",
    "binevoitorilor": "binevoitor",
    "binevoitorul": "binevoitor",
    "binevoitorule": "binevoitor",
    "binevoitorului": "binevoitor",
    "binoclul": "binoclu",
    "binoclului": "binoclu",
    "binocluri": "binoclu",
    "binoclurile": "binoclu",
    "binoclurilor": "binoclu",
    "biobibliografia": "biobibliografie",
    "biobibliografiei": "biobibliografie",
    "biobibliografii": "biobibliografie",
    "biobibliografiile": "biobibliografie",
    "biobibliografiilor": "biobibliografie",
    "biocenoza": "biocenoză",
    "biocenoze": "biocenoză",
    "biocenozei": "biocenoză",
    "biocenozele": "biocenoză",
    "biocenozelor": "biocenoză",
    "biochim.": "biochimie",
    "biochimia": "biochimie",
    "biochimiei": "biochimie",
    "biochimii": "biochimie",
    "biochimiile": "biochimie",
    "biochimiilor": "biochimie",
    "bioenergetica": "bioenergetic",
    "bioenergetică": "bioenergetic",
    "bioenergetice": "bioenergetic",
    "bioenergeticei": "bioenergetic",
    "bioenergeticele": "bioenergetic",
    "bioenergeticelor": "bioenergetic",
    "bioenergetici": "bioenergetic",
    "bioenergeticii": "bioenergetic",
    "bioenergeticilor": "bioenergetic",
    "bioenergetico": "bioenergetic",
    "bioenergeticul": "bioenergetic",
    "bioenergeticule": "bioenergetic",
    "bioenergeticului": "bioenergetic",
    "bioenergetica": "bioenergetică",
    "bioenergetici": "bioenergetică",
    "bioenergeticii": "bioenergetică",
    "bioenergetico": "bioenergetică",
    "bioenergia": "bioenergie",
    "bioenergiei": "bioenergie",
    "bioenergii": "bioenergie",
    "bioenergiile": "bioenergie",
    "bioenergiilor": "bioenergie",
    "biofizica": "biofizică",
    "biofizici": "biofizică",
    "biofizicii": "biofizică",
    "biofizicile": "biofizică",
    "biofizicilor": "biofizică",
    "biogena": "biogen",
    "biogenă": "biogen",
    "biogene": "biogen",
    "biogenei": "biogen",
    "biogenele": "biogen",
    "biogenelor": "biogen",
    "biogeni": "biogen",
    "biogenii": "biogen",
    "biogenilor": "biogen",
    "biogenul": "biogen",
    "biogenului": "biogen",
    "biogeneza": "biogeneză",
    "biogeneze": "biogeneză",
    "biogenezei": "biogeneză",
    "biogenezele": "biogeneză",
    "biogenezelor": "biogeneză",
    "biografica": "biografic",
    "biografică": "biografic",
    "biografice": "biografic",
    "biograficei": "biografic",
    "biograficele": "biografic",
    "biograficelor": "biografic",
    "biografici": "biografic",
    "biograficii": "biografic",
    "biograficilor": "biografic",
    "biograficul": "biografic",
    "biograficului": "biografic",
    "biografia": "biografie",
    "biografiei": "biografie",
    "biografii": "biografie",
    "biografiile": "biografie",
    "biografiilor": "biografie",
    "biologi": "biolog",
    "biologii": "biolog",
    "biologilor": "biolog",
    "biologul": "biolog",
    "biologule": "biolog",
    "biologului": "biolog",
    "biologa": "biologă",
    "biologe": "biologă",
    "biologei": "biologă",
    "biologele": "biologă",
    "biologelor": "biologă",
    "biologo": "biologă",
    "biologica": "biologic",
    "biologică": "biologic",
    "biologice": "biologic",
    "biologicei": "biologic",
    "biologicele": "biologic",
    "biologicelor": "biologic",
    "biologici": "biologic",
    "biologicii": "biologic",
    "biologicilor": "biologic",
    "biologico": "biologic",
    "biologicul": "biologic",
    "biologicule": "biologic",
    "biologicului": "biologic",
    "biol.": "biologie",
    "biologia": "biologie",
    "biologiei": "biologie",
    "biologii": "biologie",
    "biologiile": "biologie",
    "biologiilor": "biologie",
    "bionica": "bionică",
    "bionici": "bionică",
    "bionicii": "bionică",
    "bionicile": "bionică",
    "bionicilor": "bionică",
    "biopsia": "biopsie",
    "biopsiei": "biopsie",
    "biopsii": "biopsie",
    "biopsiile": "biopsie",
    "biopsiilor": "biopsie",
    "biosfera": "biosferă",
    "biosfere": "biosferă",
    "biosferei": "biosferă",
    "biosferele": "biosferă",
    "biosferelor": "biosferă",
    "bioterapeutica": "bioterapeutic",
    "bioterapeutică": "bioterapeutic",
    "bioterapeutice": "bioterapeutic",
    "bioterapeuticei": "bioterapeutic",
    "bioterapeuticele": "bioterapeutic",
    "bioterapeuticelor": "bioterapeutic",
    "bioterapeutici": "bioterapeutic",
    "bioterapeuticii": "bioterapeutic",
    "bioterapeuticilor": "bioterapeutic",
    "bioterapeuticul": "bioterapeutic",
    "bioterapeuticului": "bioterapeutic",
    "bioterapia": "bioterapie",
    "bioterapiei": "bioterapie",
    "bioterapii": "bioterapie",
    "bioterapiile": "bioterapie",
    "bioterapiilor": "bioterapie",
    "biovindecătoare": "biovindecător",
    "biovindecătoarea": "biovindecător",
    "biovindecătoarei": "biovindecător",
    "biovindecătoarele": "biovindecător",
    "biovindecătoarelor": "biovindecător",
    "biovindecători": "biovindecător",
    "biovindecătorii": "biovindecător",
    "biovindecătorilor": "biovindecător",
    "biovindecătorul": "biovindecător",
    "biovindecătorului": "biovindecător",
    "bioxidul": "bioxid",
    "bioxidului": "bioxid",
    "bioxizi": "bioxid",
    "bioxizii": "bioxid",
    "bioxizilor": "bioxid",
    "bipartita": "bipartit",
    "bipartită": "bipartit",
    "bipartite": "bipartit",
    "bipartitei": "bipartit",
    "bipartitele": "bipartit",
    "bipartitelor": "bipartit",
    "bipartiți": "bipartit",
    "bipartiții": "bipartit",
    "bipartiților": "bipartit",
    "bipartitul": "bipartit",
    "bipartitului": "bipartit",
    "birul": "bir",
    "birului": "bir",
    "biruri": "bir",
    "birurile": "bir",
    "birurilor": "bir",
    "birja": "birjă",
    "birje": "birjă",
    "birjei": "birjă",
    "birjele": "birjă",
    "birjelor": "birjă",
    "birlici": "birlic",
    "birlicii": "birlic",
    "birlicilor": "birlic",
    "birlicul": "birlic",
    "birlicului": "birlic",
    "birlicuri": "birlic",
    "birlicurile": "birlic",
    "birlicurilor": "birlic",
    "Birmanie": "Birmania",
    "Birmaniei": "Birmania",
    "Birmanii": "Birmania",
    "birocrata": "birocrat",
    "birocrată": "birocrat",
    "birocrate": "birocrat",
    "birocratei": "birocrat",
    "birocratele": "birocrat",
    "birocratelor": "birocrat",
    "birocrați": "birocrat",
    "birocrații": "birocrat",
    "birocraților": "birocrat",
    "birocratul": "birocrat",
    "birocratului": "birocrat",
    "birocrata": "birocrată",
    "birocrate": "birocrată",
    "birocratei": "birocrată",
    "birocratele": "birocrată",
    "birocratelor": "birocrată",
    "birocrația": "birocrație",
    "birocrației": "birocrație",
    "birocrații": "birocrație",
    "birocrațiile": "birocrație",
    "birocrațiilor": "birocrație",
    "birocratisme": "birocratism",
    "birocratismele": "birocratism",
    "birocratismelor": "birocratism",
    "birocratismul": "birocratism",
    "birocratismului": "birocratism",
    "bir.": "birou",
    "biroul": "birou",
    "biroului": "birou",
    "birouri": "birou",
    "birourile": "birou",
    "birourilor": "birou",
    "birtul": "birt",
    "birtului": "birt",
    "birturi": "birt",
    "birturile": "birt",
    "birturilor": "birt",
    "biruia": "birui",
    "biruiai": "birui",
    "biruiam": "birui",
    "biruiască": "birui",
    "biruiați": "birui",
    "biruiau": "birui",
    "biruie": "birui",
    "biruiesc": "birui",
    "biruiește": "birui",
    "biruiești": "birui",
    "biruii": "birui",
    "biruim": "birui",
    "biruind": "birui",
    "biruindu": "birui",
    "biruiră": "birui",
    "biruirăm": "birui",
    "biruirăți": "birui",
    "biruise": "birui",
    "biruisem": "birui",
    "biruiseră": "birui",
    "biruiserăm": "birui",
    "biruiserăți": "birui",
    "biruiseși": "birui",
    "biruiși": "birui",
    "biruit": "birui",
    "biruiți": "birui",
    "biruitu": "birui",
    "nebiruind": "birui",
    "nebiruindu": "birui",
    "nemaibiruind": "birui",
    "nemaibiruindu": "birui",
    "biruința": "biruință",
    "biruințe": "biruință",
    "biruinței": "biruință",
    "biruințele": "biruință",
    "biruirea": "biruire",
    "biruiri": "biruire",
    "biruirii": "biruire",
    "biruirile": "biruire",
    "biruirilor": "biruire",
    "biruita": "biruit",
    "biruită": "biruit",
    "biruite": "biruit",
    "biruitei": "biruit",
    "biruitele": "biruit",
    "biruitelor": "biruit",
    "biruiți": "biruit",
    "biruiții": "biruit",
    "biruiților": "biruit",
    "biruitul": "biruit",
    "biruitului": "biruit",
    "biruita": "biruită",
    "biruite": "biruită",
    "biruitei": "biruită",
    "biruitele": "biruită",
    "biruitelor": "biruită",
    "biruitoarea": "biruitoare",
    "biruitoarei": "biruitoare",
    "biruitoarele": "biruitoare",
    "biruitoarelor": "biruitoare",
    "biruitoare": "biruitor",
    "biruitoarea": "biruitor",
    "biruitoarei": "biruitor",
    "biruitoarele": "biruitor",
    "biruitoarelor": "biruitor",
    "biruitori": "biruitor",
    "biruitorii": "biruitor",
    "biruitorilor": "biruitor",
    "biruitorul": "biruitor",
    "biruitorului": "biruitor",
    "bisă": "bisa",
    "bisai": "bisa",
    "bisam": "bisa",
    "bisăm": "bisa",
    "bisând": "bisa",
    "bisându": "bisa",
    "bisară": "bisa",
    "bisarăm": "bisa",
    "bisarăți": "bisa",
    "bisase": "bisa",
    "bisasem": "bisa",
    "bisaseră": "bisa",
    "bisaserăm": "bisa",
    "bisaserăți": "bisa",
    "bisaseși": "bisa",
    "bisași": "bisa",
    "bisat": "bisa",
    "bisați": "bisa",
    "bisatu": "bisa",
    "bisau": "bisa",
    "bisează": "bisa",
    "bisez": "bisa",
    "biseze": "bisa",
    "bisezi": "bisa",
    "nebisând": "bisa",
    "nebisându": "bisa",
    "nemaibisând": "bisa",
    "nemaibisându": "bisa",
    "bisarea": "bisare",
    "bisări": "bisare",
    "bisării": "bisare",
    "bisările": "bisare",
    "bisata": "bisat",
    "bisată": "bisat",
    "bisate": "bisat",
    "bisatei": "bisat",
    "bisatele": "bisat",
    "bisatelor": "bisat",
    "bisați": "bisat",
    "bisații": "bisat",
    "bisaților": "bisat",
    "bisatul": "bisat",
    "bisatului": "bisat",
    "bisecți": "bisect",
    "bisecții": "bisect",
    "bisecților": "bisect",
    "bisectul": "bisect",
    "bisectului": "bisect",
    "biserica": "biserică",
    "biserici": "biserică",
    "bisericii": "biserică",
    "bisericile": "biserică",
    "bisericilor": "biserică",
    "biserico": "biserică",
    "bis.": "bisericesc",
    "bisericeasca": "bisericesc",
    "bisericească": "bisericesc",
    "bisericescul": "bisericesc",
    "bisericescului": "bisericesc",
    "bisericești": "bisericesc",
    "bisericeștii": "bisericesc",
    "bisericeștile": "bisericesc",
    "bisericeștilor": "bisericesc",
    "bisericuța": "bisericuță",
    "bisericuțe": "bisericuță",
    "bisericuței": "bisericuță",
    "bisericuțele": "bisericuță",
    "bisericuțelor": "bisericuță",
    "bisextila": "bisextil",
    "bisextilă": "bisextil",
    "bisextile": "bisextil",
    "bisextilei": "bisextil",
    "bisextilele": "bisextil",
    "bisextilelor": "bisextil",
    "bisextili": "bisextil",
    "bisextilii": "bisextil",
    "bisextililor": "bisextil",
    "bisextilul": "bisextil",
    "bisextilului": "bisextil",
    "bisexuata": "bisexuat",
    "bisexuată": "bisexuat",
    "bisexuate": "bisexuat",
    "bisexuatei": "bisexuat",
    "bisexuatele": "bisexuat",
    "bisexuatelor": "bisexuat",
    "bisexuați": "bisexuat",
    "bisexuații": "bisexuat",
    "bisexuaților": "bisexuat",
    "bisexuatul": "bisexuat",
    "bisexuatului": "bisexuat",
    "Bi": "bismut",
    "bismutul": "bismut",
    "bismutului": "bismut",
    "bișnița": "bișniță",
    "bișnițe": "bișniță",
    "bișniței": "bișniță",
    "bișnițele": "bișniță",
    "bișnițelor": "bișniță",
    "Bistriță": "Bistrița",
    "Bistrițe": "Bistrița",
    "Bistriței": "Bistrița",
    "bistrițeana": "bistrițean",
    "bistrițeană": "bistrițean",
    "bistrițeanul": "bistrițean",
    "bistrițeanului": "bistrițean",
    "bistrițene": "bistrițean",
    "bistrițenei": "bistrițean",
    "bistrițenele": "bistrițean",
    "bistrițenelor": "bistrițean",
    "bistrițeni": "bistrițean",
    "bistrițenii": "bistrițean",
    "bistrițenilor": "bistrițean",
    "bistrițeanca": "bistrițeancă",
    "bistrițence": "bistrițeancă",
    "bistrițencei": "bistrițeancă",
    "bistrițencele": "bistrițeancă",
    "bistrițencelor": "bistrițeancă",
    "bisturie": "bisturiu",
    "bisturiele": "bisturiu",
    "bisturielor": "bisturiu",
    "bisturiul": "bisturiu",
    "bisturiului": "bisturiu",
    "bitumul": "bitum",
    "bitumului": "bitum",
    "bivoli": "bivol",
    "bivolii": "bivol",
    "bivolilor": "bivol",
    "bivolul": "bivol",
    "bivolului": "bivol",
    "bivuacul": "bivuac",
    "bivuacului": "bivuac",
    "bivuacuri": "bivuac",
    "bivuacurile": "bivuac",
    "bivuacurilor": "bivuac",
    "Bizanțul": "Bizanț",
    "Bizanțului": "Bizanț",
    "bizantina": "bizantin",
    "bizantină": "bizantin",
    "bizantine": "bizantin",
    "bizantinei": "bizantin",
    "bizantinele": "bizantin",
    "bizantinelor": "bizantin",
    "bizantini": "bizantin",
    "bizantinii": "bizantin",
    "bizantinilor": "bizantin",
    "bizantinul": "bizantin",
    "bizantinului": "bizantin",
    "bizantina": "bizantină",
    "bizantine": "bizantină",
    "bizantinei": "bizantină",
    "bizantinele": "bizantină",
    "bizantinelor": "bizantină",
    "bizantinologi": "bizantinolog",
    "bizantinologii": "bizantinolog",
    "bizantinologilor": "bizantinolog",
    "bizantinologul": "bizantinolog",
    "bizantinologului": "bizantinolog",
    "bizara": "bizar",
    "bizară": "bizar",
    "bizare": "bizar",
    "bizarei": "bizar",
    "bizarele": "bizar",
    "bizarelor": "bizar",
    "bizari": "bizar",
    "bizarii": "bizar",
    "bizarilor": "bizar",
    "bizarul": "bizar",
    "bizarului": "bizar",
    "bizoni": "bizon",
    "bizonii": "bizon",
    "bizonilor": "bizon",
    "bizonul": "bizon",
    "bizonule": "bizon",
    "bizonului": "bizon",
    "bizuia": "bizui",
    "bizuiai": "bizui",
    "bizuiam": "bizui",
    "bizuiască": "bizui",
    "bizuiați": "bizui",
    "bizuiau": "bizui",
    "bizuie": "bizui",
    "bizuiesc": "bizui",
    "bizuiește": "bizui",
    "bizuiești": "bizui",
    "bizuii": "bizui",
    "bizuim": "bizui",
    "bizuind": "bizui",
    "bizuindu": "bizui",
    "bizuiră": "bizui",
    "bizuirăm": "bizui",
    "bizuirăți": "bizui",
    "bizuise": "bizui",
    "bizuisem": "bizui",
    "bizuiseră": "bizui",
    "bizuiserăm": "bizui",
    "bizuiserăți": "bizui",
    "bizuiseși": "bizui",
    "bizuiși": "bizui",
    "bizuit": "bizui",
    "bizuiți": "bizui",
    "bizuitu": "bizui",
    "nebizuind": "bizui",
    "nebizuindu": "bizui",
    "nemaibizuind": "bizui",
    "nemaibizuindu": "bizui",
    "bizuiala": "bizuială",
    "bizuialo": "bizuială",
    "bizuieli": "bizuială",
    "bizuielii": "bizuială",
    "bizuielile": "bizuială",
    "bizuielilor": "bizuială",
    "bizuirea": "bizuire",
    "bizuireo": "bizuire",
    "bizuiri": "bizuire",
    "bizuirii": "bizuire",
    "bizuirile": "bizuire",
    "bizuirilor": "bizuire",
    "bizuita": "bizuit",
    "bizuită": "bizuit",
    "bizuite": "bizuit",
    "bizuitei": "bizuit",
    "bizuitele": "bizuit",
    "bizuitelor": "bizuit",
    "bizuiți": "bizuit",
    "bizuiții": "bizuit",
    "bizuiților": "bizuit",
    "bizuito": "bizuit",
    "bizuitul": "bizuit",
    "bizuitule": "bizuit",
    "bizuitului": "bizuit",
    "bizuitoare": "bizuitor",
    "bizuitoarea": "bizuitor",
    "bizuitoarei": "bizuitor",
    "bizuitoarele": "bizuitor",
    "bizuitoarelor": "bizuitor",
    "bizuitoareo": "bizuitor",
    "bizuitori": "bizuitor",
    "bizuitorii": "bizuitor",
    "bizuitorilor": "bizuitor",
    "bizuitorul": "bizuitor",
    "bizuitorule": "bizuitor",
    "bizuitorului": "bizuitor",
    "blachei": "blacheu",
    "blacheii": "blacheu",
    "blacheilor": "blacheu",
    "blacheul": "blacheu",
    "blacheului": "blacheu",
    "blagoslovita": "blagoslovit",
    "blagoslovită": "blagoslovit",
    "blagoslovite": "blagoslovit",
    "blagoslovitei": "blagoslovit",
    "blagoslovitele": "blagoslovit",
    "blagoslovitelor": "blagoslovit",
    "blagosloviți": "blagoslovit",
    "blagosloviții": "blagoslovit",
    "blagosloviților": "blagoslovit",
    "blagoslovitul": "blagoslovit",
    "blagoslovitului": "blagoslovit",
    "Blajul": "Blaj",
    "Blajului": "Blaj",
    "blajina": "blajin",
    "blajină": "blajin",
    "blajine": "blajin",
    "blajinei": "blajin",
    "blajinele": "blajin",
    "blajinelor": "blajin",
    "blajini": "blajin",
    "blajinii": "blajin",
    "blajinilor": "blajin",
    "blajinul": "blajin",
    "blajinului": "blajin",
    "blamul": "blam",
    "blamului": "blam",
    "blamuri": "blam",
    "blamurile": "blam",
    "blamurilor": "blam",
    "blamă": "blama",
    "blamai": "blama",
    "blamam": "blama",
    "blamăm": "blama",
    "blamând": "blama",
    "blamându": "blama",
    "blamară": "blama",
    "blamarăm": "blama",
    "blamarăți": "blama",
    "blamase": "blama",
    "blamasem": "blama",
    "blamaseră": "blama",
    "blamaserăm": "blama",
    "blamaserăți": "blama",
    "blamaseși": "blama",
    "blamași": "blama",
    "blamat": "blama",
    "blamați": "blama",
    "blamatu": "blama",
    "blamau": "blama",
    "blamează": "blama",
    "blamez": "blama",
    "blameze": "blama",
    "blamezi": "blama",
    "neblamând": "blama",
    "neblamându": "blama",
    "nemaiblamând": "blama",
    "nemaiblamându": "blama",
    "blamabila": "blamabil",
    "blamabilă": "blamabil",
    "blamabile": "blamabil",
    "blamabilei": "blamabil",
    "blamabilele": "blamabil",
    "blamabilelor": "blamabil",
    "blamabili": "blamabil",
    "blamabilii": "blamabil",
    "blamabililor": "blamabil",
    "blamabilul": "blamabil",
    "blamabilului": "blamabil",
    "blamarea": "blamare",
    "blamări": "blamare",
    "blamării": "blamare",
    "blamările": "blamare",
    "blamata": "blamat",
    "blamată": "blamat",
    "blamate": "blamat",
    "blamatei": "blamat",
    "blamatele": "blamat",
    "blamatelor": "blamat",
    "blamați": "blamat",
    "blamații": "blamat",
    "blamaților": "blamat",
    "blamatul": "blamat",
    "blamatului": "blamat",
    "blamata": "blamată",
    "blamate": "blamată",
    "blamatei": "blamată",
    "blamatele": "blamată",
    "blamatelor": "blamată",
    "blana": "blană",
    "blăni": "blană",
    "blănii": "blană",
    "blănile": "blană",
    "blănilor": "blană",
    "blănuri": "blană",
    "blănurile": "blană",
    "blănurilor": "blană",
    "blancheta": "blanchetă",
    "blanchete": "blanchetă",
    "blanchetei": "blanchetă",
    "blanchetele": "blanchetă",
    "blanchetelor": "blanchetă",
    "blânda": "blând",
    "blândă": "blând",
    "blânde": "blând",
    "blândei": "blând",
    "blândele": "blând",
    "blândelor": "blând",
    "blândo": "blând",
    "blândul": "blând",
    "blândule": "blând",
    "blândului": "blând",
    "blânzi": "blând",
    "blânzii": "blând",
    "blânzilor": "blând",
    "blândețea": "blândețe",
    "blândețeo": "blândețe",
    "blândeți": "blândețe",
    "blândeții": "blândețe",
    "blândețile": "blândețe",
    "blândeților": "blândețe",
    "blasfemia": "blasfemie",
    "blasfemiei": "blasfemie",
    "blasfemii": "blasfemie",
    "blasfemiile": "blasfemie",
    "blasfemiilor": "blasfemie",
    "blasfemio": "blasfemie",
    "blatista": "blatist",
    "blatistă": "blatist",
    "blatiste": "blatist",
    "blatistei": "blatist",
    "blatistele": "blatist",
    "blatistelor": "blatist",
    "blatiști": "blatist",
    "blatiștii": "blatist",
    "blatiștilor": "blatist",
    "blatistul": "blatist",
    "blatistului": "blatist",
    "blatista": "blatistă",
    "blatiste": "blatistă",
    "blatistei": "blatistă",
    "blatistele": "blatistă",
    "blatistelor": "blatistă",
    "blază": "blaza",
    "blazai": "blaza",
    "blazam": "blaza",
    "blazăm": "blaza",
    "blazând": "blaza",
    "blazându": "blaza",
    "blazară": "blaza",
    "blazarăm": "blaza",
    "blazarăți": "blaza",
    "blazase": "blaza",
    "blazasem": "blaza",
    "blazaseră": "blaza",
    "blazaserăm": "blaza",
    "blazaserăți": "blaza",
    "blazaseși": "blaza",
    "blazași": "blaza",
    "blazat": "blaza",
    "blazați": "blaza",
    "blazatu": "blaza",
    "blazau": "blaza",
    "blazează": "blaza",
    "blazez": "blaza",
    "blazeze": "blaza",
    "blazezi": "blaza",
    "neblazând": "blaza",
    "neblazându": "blaza",
    "nemaiblazând": "blaza",
    "nemaiblazându": "blaza",
    "blazarea": "blazare",
    "blazări": "blazare",
    "blazării": "blazare",
    "blazările": "blazare",
    "blazata": "blazat",
    "blazată": "blazat",
    "blazate": "blazat",
    "blazatei": "blazat",
    "blazatele": "blazat",
    "blazatelor": "blazat",
    "blazați": "blazat",
    "blazații": "blazat",
    "blazaților": "blazat",
    "blazatul": "blazat",
    "blazatului": "blazat",
    "blazata": "blazată",
    "blazate": "blazată",
    "blazatei": "blazată",
    "blazatele": "blazată",
    "blazatelor": "blazată",
    "blazoane": "blazon",
    "blazoanele": "blazon",
    "blazoanelor": "blazon",
    "blazonul": "blazon",
    "blazonului": "blazon",
    "blefarita": "blefarită",
    "blefarite": "blefarită",
    "blefaritei": "blefarită",
    "blefaritele": "blefarită",
    "blefaritelor": "blefarită",
    "blenoragia": "blenoragie",
    "blenoragiei": "blenoragie",
    "blenoragii": "blenoragie",
    "blenoragiile": "blenoragie",
    "blenoragiilor": "blenoragie",
    "bleotocăreala": "bleotocăreală",
    "bleotocărealo": "bleotocăreală",
    "bleotocăreli": "bleotocăreală",
    "bleotocărelii": "bleotocăreală",
    "bleotocărelile": "bleotocăreală",
    "bleotocărelilor": "bleotocăreală",
    "bleotocărea": "bleotocări",
    "bleotocăreai": "bleotocări",
    "bleotocăream": "bleotocări",
    "bleotocărească": "bleotocări",
    "bleotocăreați": "bleotocări",
    "bleotocăreau": "bleotocări",
    "bleotocăresc": "bleotocări",
    "bleotocărește": "bleotocări",
    "bleotocărești": "bleotocări",
    "bleotocării": "bleotocări",
    "bleotocărim": "bleotocări",
    "bleotocărind": "bleotocări",
    "bleotocărindu": "bleotocări",
    "bleotocăriră": "bleotocări",
    "bleotocărirăm": "bleotocări",
    "bleotocărirăți": "bleotocări",
    "bleotocărise": "bleotocări",
    "bleotocărisem": "bleotocări",
    "bleotocăriseră": "bleotocări",
    "bleotocăriserăm": "bleotocări",
    "bleotocăriserăți": "bleotocări",
    "bleotocăriseși": "bleotocări",
    "bleotocăriși": "bleotocări",
    "bleotocărit": "bleotocări",
    "bleotocăriți": "bleotocări",
    "bleotocăritu": "bleotocări",
    "nebleotocărind": "bleotocări",
    "nebleotocărindu": "bleotocări",
    "nemaibleotocărind": "bleotocări",
    "nemaibleotocărindu": "bleotocări",
    "bleotocărirea": "bleotocărire",
    "bleotocărireo": "bleotocărire",
    "bleotocăriri": "bleotocărire",
    "bleotocăririi": "bleotocărire",
    "bleotocăririle": "bleotocărire",
    "bleotocăririlor": "bleotocărire",
    "bleotocărita": "bleotocărit",
    "bleotocărită": "bleotocărit",
    "bleotocărite": "bleotocărit",
    "bleotocăritei": "bleotocărit",
    "bleotocăritele": "bleotocărit",
    "bleotocăritelor": "bleotocărit",
    "bleotocăriți": "bleotocărit",
    "bleotocăriții": "bleotocărit",
    "bleotocăriților": "bleotocărit",
    "bleotocărito": "bleotocărit",
    "bleotocăritul": "bleotocărit",
    "bleotocăritule": "bleotocărit",
    "bleotocăritului": "bleotocărit",
    "blesteme": "blestem",
    "blestemele": "blestem",
    "blestemelor": "blestem",
    "blestemul": "blestem",
    "blestemului": "blestem",
    "blestemata": "blestemat",
    "blestemată": "blestemat",
    "blestemate": "blestemat",
    "blestematei": "blestemat",
    "blestematele": "blestemat",
    "blestematelor": "blestemat",
    "blestemați": "blestemat",
    "blestemații": "blestemat",
    "blestemaților": "blestemat",
    "blestematul": "blestemat",
    "blestematului": "blestemat",
    "blide": "blid",
    "blidele": "blid",
    "blidelor": "blid",
    "blidul": "blid",
    "blidule": "blid",
    "blidului": "blid",
    "blindaje": "blindaj",
    "blindajele": "blindaj",
    "blindajelor": "blindaj",
    "blindajul": "blindaj",
    "blindajului": "blindaj",
    "blindata": "blindat",
    "blindată": "blindat",
    "blindate": "blindat",
    "blindatei": "blindat",
    "blindatele": "blindat",
    "blindatelor": "blindat",
    "blindați": "blindat",
    "blindații": "blindat",
    "blindaților": "blindat",
    "blindatul": "blindat",
    "blindatului": "blindat",
    "blocul": "bloc",
    "blocului": "bloc",
    "blocuri": "bloc",
    "blocurile": "bloc",
    "blocurilor": "bloc",
    "blocă": "bloca",
    "blocai": "bloca",
    "blocam": "bloca",
    "blocăm": "bloca",
    "blocând": "bloca",
    "blocându": "bloca",
    "blocară": "bloca",
    "blocarăm": "bloca",
    "blocarăți": "bloca",
    "blocase": "bloca",
    "blocasem": "bloca",
    "blocaseră": "bloca",
    "blocaserăm": "bloca",
    "blocaserăți": "bloca",
    "blocaseși": "bloca",
    "blocași": "bloca",
    "blocat": "bloca",
    "blocați": "bloca",
    "blocatu": "bloca",
    "blocau": "bloca",
    "blochează": "bloca",
    "blochez": "bloca",
    "blocheze": "bloca",
    "blochezi": "bloca",
    "neblocând": "bloca",
    "neblocându": "bloca",
    "nemaiblocând": "bloca",
    "nemaiblocându": "bloca",
    "blocada": "blocadă",
    "blocade": "blocadă",
    "blocadei": "blocadă",
    "blocadele": "blocadă",
    "blocadelor": "blocadă",
    "blocaje": "blocaj",
    "blocajele": "blocaj",
    "blocajelor": "blocaj",
    "blocajul": "blocaj",
    "blocajului": "blocaj",
    "blocarea": "blocare",
    "blocări": "blocare",
    "blocării": "blocare",
    "blocările": "blocare",
    "blocata": "blocat",
    "blocată": "blocat",
    "blocate": "blocat",
    "blocatei": "blocat",
    "blocatele": "blocat",
    "blocatelor": "blocat",
    "blocați": "blocat",
    "blocații": "blocat",
    "blocaților": "blocat",
    "blocatul": "blocat",
    "blocatului": "blocat",
    "blocnotesul": "blocnotes",
    "blocnotesului": "blocnotes",
    "blocnotesuri": "blocnotes",
    "blocnotesurile": "blocnotes",
    "blocnotesurilor": "blocnotes",
    "bl.": "blocul",
    "BNS": "Blocul_Național_Sindical",
    "blonda": "blond",
    "blondă": "blond",
    "blonde": "blond",
    "blondei": "blond",
    "blondele": "blond",
    "blondelor": "blond",
    "blondo": "blond",
    "blondul": "blond",
    "blondule": "blond",
    "blondului": "blond",
    "blonzi": "blond",
    "blonzii": "blond",
    "blonzilor": "blond",
    "bluful": "bluf",
    "blufului": "bluf",
    "blufuri": "bluf",
    "blufurile": "bluf",
    "blufurilor": "bluf",
    "blugii": "blugi",
    "blugilor": "blugi",
    "blumul": "blum",
    "blumului": "blum",
    "blumuri": "blum",
    "blumurile": "blum",
    "blumurilor": "blum",
    "blumingul": "bluming",
    "blumingului": "bluming",
    "bluminguri": "bluming",
    "blumingurile": "bluming",
    "blumingurilor": "bluming",
    "bluza": "bluză",
    "bluze": "bluză",
    "bluzei": "bluză",
    "bluzele": "bluză",
    "bluzelor": "bluză",
    "boaba": "boabă",
    "boabe": "boabă",
    "boabei": "boabă",
    "boabele": "boabă",
    "boabelor": "boabă",
    "boacăna": "boacănă",
    "boacăne": "boacănă",
    "boacănei": "boacănă",
    "boacănele": "boacănă",
    "boacănelor": "boacănă",
    "boaita": "boaită",
    "boaite": "boaită",
    "boaitei": "boaită",
    "boaitele": "boaită",
    "boaitelor": "boaită",
    "boala": "boală",
    "boalo": "boală",
    "boli": "boală",
    "bolii": "boală",
    "bolile": "boală",
    "bolilor": "boală",
    "boarea": "boare",
    "bori": "boare",
    "borii": "boare",
    "borile": "boare",
    "borilor": "boare",
    "boabe": "bob",
    "boabele": "bob",
    "boabelor": "bob",
    "bobul": "bob",
    "bobule": "bob",
    "bobului": "bob",
    "boburi": "bob",
    "boburile": "bob",
    "boburilor": "bob",
    "bobârnace": "bobârnac",
    "bobârnacele": "bobârnac",
    "bobârnacelor": "bobârnac",
    "bobârnacul": "bobârnac",
    "bobârnacului": "bobârnac",
    "bobină": "bobina",
    "bobinai": "bobina",
    "bobinam": "bobina",
    "bobinăm": "bobina",
    "bobinând": "bobina",
    "bobinându": "bobina",
    "bobinară": "bobina",
    "bobinarăm": "bobina",
    "bobinarăți": "bobina",
    "bobinase": "bobina",
    "bobinasem": "bobina",
    "bobinaseră": "bobina",
    "bobinaserăm": "bobina",
    "bobinaserăți": "bobina",
    "bobinaseși": "bobina",
    "bobinași": "bobina",
    "bobinat": "bobina",
    "bobinați": "bobina",
    "bobinatu": "bobina",
    "bobinau": "bobina",
    "bobinează": "bobina",
    "bobinez": "bobina",
    "bobineze": "bobina",
    "bobinezi": "bobina",
    "nebobinând": "bobina",
    "nebobinându": "bobina",
    "nemaibobinând": "bobina",
    "nemaibobinându": "bobina",
    "bobina": "bobină",
    "bobine": "bobină",
    "bobinei": "bobină",
    "bobinele": "bobină",
    "bobinelor": "bobină",
    "bobinarea": "bobinare",
    "bobinări": "bobinare",
    "bobinării": "bobinare",
    "bobinările": "bobinare",
    "bobinata": "bobinat",
    "bobinată": "bobinat",
    "bobinate": "bobinat",
    "bobinatei": "bobinat",
    "bobinatele": "bobinat",
    "bobinatelor": "bobinat",
    "bobinați": "bobinat",
    "bobinații": "bobinat",
    "bobinaților": "bobinat",
    "bobinatul": "bobinat",
    "bobinatului": "bobinat",
    "boboaca": "boboacă",
    "boboace": "boboacă",
    "boboacei": "boboacă",
    "boboacele": "boboacă",
    "boboacelor": "boboacă",
    "boboaco": "boboacă",
    "boboci": "boboc",
    "bobocii": "boboc",
    "bobocilor": "boboc",
    "bobocul": "boboc",
    "bobocule": "boboc",
    "bobocului": "boboc",
    "bobocei": "bobocel",
    "boboceii": "bobocel",
    "boboceilor": "bobocel",
    "bobocelul": "bobocel",
    "bobocelule": "bobocel",
    "bobocelului": "bobocel",
    "bocanci": "bocanc",
    "bocancii": "bocanc",
    "bocancilor": "bocanc",
    "bocancul": "bocanc",
    "bocancului": "bocanc",
    "bocete": "bocet",
    "bocetele": "bocet",
    "bocetelor": "bocet",
    "bocetul": "bocet",
    "bocetului": "bocet",
    "bocea": "boci",
    "boceai": "boci",
    "boceam": "boci",
    "bocească": "boci",
    "boceați": "boci",
    "boceau": "boci",
    "bocesc": "boci",
    "bocește": "boci",
    "bocești": "boci",
    "bocii": "boci",
    "bocim": "boci",
    "bocind": "boci",
    "bocindu": "boci",
    "bociră": "boci",
    "bocirăm": "boci",
    "bocirăți": "boci",
    "bocise": "boci",
    "bocisem": "boci",
    "bociseră": "boci",
    "bociserăm": "boci",
    "bociserăți": "boci",
    "bociseși": "boci",
    "bociși": "boci",
    "bocit": "boci",
    "bociți": "boci",
    "bocitu": "boci",
    "bocirea": "bocire",
    "bociri": "bocire",
    "bocirii": "bocire",
    "bocirile": "bocire",
    "bocirilor": "bocire",
    "bocită": "bocit",
    "bocite": "bocit",
    "bociți": "bocit",
    "bocna": "bocnă",
    "bocne": "bocnă",
    "bocnei": "bocnă",
    "bocnele": "bocnă",
    "bocnelor": "bocnă",
    "bodega": "bodegă",
    "bodegi": "bodegă",
    "bodegii": "bodegă",
    "bodegile": "bodegă",
    "bodegilor": "bodegă",
    "bodogăneala": "bodogăneală",
    "bodogănealo": "bodogăneală",
    "bodogăneli": "bodogăneală",
    "bodogănelii": "bodogăneală",
    "bodogănelile": "bodogăneală",
    "bodogănelilor": "bodogăneală",
    "bodogănea": "bodogăni",
    "bodogăneai": "bodogăni",
    "bodogăneam": "bodogăni",
    "bodogănească": "bodogăni",
    "bodogăneați": "bodogăni",
    "bodogăneau": "bodogăni",
    "bodogănesc": "bodogăni",
    "bodogănește": "bodogăni",
    "bodogănești": "bodogăni",
    "bodogănii": "bodogăni",
    "bodogănim": "bodogăni",
    "bodogănind": "bodogăni",
    "bodogănindu": "bodogăni",
    "bodogăniră": "bodogăni",
    "bodogănirăm": "bodogăni",
    "bodogănirăți": "bodogăni",
    "bodogănise": "bodogăni",
    "bodogănisem": "bodogăni",
    "bodogăniseră": "bodogăni",
    "bodogăniserăm": "bodogăni",
    "bodogăniserăți": "bodogăni",
    "bodogăniseși": "bodogăni",
    "bodogăniși": "bodogăni",
    "bodogănit": "bodogăni",
    "bodogăniți": "bodogăni",
    "bodogănitu": "bodogăni",
    "nebodogănind": "bodogăni",
    "nebodogănindu": "bodogăni",
    "nemaibodogănind": "bodogăni",
    "nemaibodogănindu": "bodogăni",
    "bodogănirea": "bodogănire",
    "bodogănireo": "bodogănire",
    "bodogăniri": "bodogănire",
    "bodogănirii": "bodogănire",
    "bodogănirile": "bodogănire",
    "bodogănirilor": "bodogănire",
    "bodogănita": "bodogănit",
    "bodogănită": "bodogănit",
    "bodogănite": "bodogănit",
    "bodogănitei": "bodogănit",
    "bodogănitele": "bodogănit",
    "bodogănitelor": "bodogănit",
    "bodogăniți": "bodogănit",
    "bodogăniții": "bodogănit",
    "bodogăniților": "bodogănit",
    "bodogănito": "bodogănit",
    "bodogănitul": "bodogănit",
    "bodogănitule": "bodogănit",
    "bodogănitului": "bodogănit",
    "boemi": "boem",
    "boemii": "boem",
    "boemilor": "boem",
    "boemul": "boem",
    "boemului": "boem",
    "boema": "boemă",
    "boeme": "boemă",
    "boemei": "boemă",
    "boemele": "boemă",
    "boemelor": "boemă",
    "bogata": "bogat",
    "bogată": "bogat",
    "bogate": "bogat",
    "bogatei": "bogat",
    "bogatele": "bogat",
    "bogatelor": "bogat",
    "bogați": "bogat",
    "bogații": "bogat",
    "bogaților": "bogat",
    "bogato": "bogat",
    "bogatul": "bogat",
    "bogatule": "bogat",
    "bogatului": "bogat",
    "bogătani": "bogătan",
    "bogătanii": "bogătan",
    "bogătanilor": "bogătan",
    "bogătanul": "bogătan",
    "bogătanului": "bogătan",
    "bogăția": "bogăție",
    "bogăției": "bogăție",
    "bogății": "bogăție",
    "bogățiile": "bogăție",
    "bogățiilor": "bogăție",
    "bogheta": "boghet",
    "boghetă": "boghet",
    "boghete": "boghet",
    "boghetei": "boghet",
    "boghetele": "boghet",
    "boghetelor": "boghet",
    "bogheți": "boghet",
    "bogheții": "boghet",
    "bogheților": "boghet",
    "boghetul": "boghet",
    "boghetului": "boghet",
    "boiangeria": "boiangerie",
    "boiangeriei": "boiangerie",
    "boiangerii": "boiangerie",
    "boiangeriile": "boiangerie",
    "boiangeriilor": "boiangerie",
    "boiangii": "boiangiu",
    "boiangiii": "boiangiu",
    "boiangiilor": "boiangiu",
    "boiangiul": "boiangiu",
    "boiangiului": "boiangiu",
    "boicotul": "boicot",
    "boicotului": "boicot",
    "boicoturi": "boicot",
    "boicoturile": "boicot",
    "boicoturilor": "boicot",
    "boicotă": "boicota",
    "boicotai": "boicota",
    "boicotam": "boicota",
    "boicotăm": "boicota",
    "boicotând": "boicota",
    "boicotându": "boicota",
    "boicotară": "boicota",
    "boicotarăm": "boicota",
    "boicotarăți": "boicota",
    "boicotase": "boicota",
    "boicotasem": "boicota",
    "boicotaseră": "boicota",
    "boicotaserăm": "boicota",
    "boicotaserăți": "boicota",
    "boicotaseși": "boicota",
    "boicotași": "boicota",
    "boicotat": "boicota",
    "boicotați": "boicota",
    "boicotatu": "boicota",
    "boicotau": "boicota",
    "boicotează": "boicota",
    "boicotez": "boicota",
    "boicoteze": "boicota",
    "boicotezi": "boicota",
    "neboicotând": "boicota",
    "neboicotându": "boicota",
    "nemaiboicotând": "boicota",
    "nemaiboicotându": "boicota",
    "boicotarea": "boicotare",
    "boicotări": "boicotare",
    "boicotării": "boicotare",
    "boicotările": "boicotare",
    "boicotata": "boicotat",
    "boicotată": "boicotat",
    "boicotate": "boicotat",
    "boicotatei": "boicotat",
    "boicotatele": "boicotat",
    "boicotatelor": "boicotat",
    "boicotați": "boicotat",
    "boicotații": "boicotat",
    "boicotaților": "boicotat",
    "boicotatul": "boicotat",
    "boicotatului": "boicotat",
    "boieri": "boier",
    "boierii": "boier",
    "boierilor": "boier",
    "boierul": "boier",
    "boierului": "boier",
    "boiereasca": "boieresc",
    "boierească": "boieresc",
    "boierescul": "boieresc",
    "boierescului": "boieresc",
    "boierești": "boieresc",
    "boiereștii": "boieresc",
    "boiereștile": "boieresc",
    "boiereștilor": "boieresc",
    "boierimea": "boierime",
    "boierimi": "boierime",
    "boierimii": "boierime",
    "boierimile": "boierime",
    "boierimilor": "boierime",
    "boieroaica": "boieroaică",
    "boieroaice": "boieroaică",
    "boieroaicei": "boieroaică",
    "boieroaicele": "boieroaică",
    "boieroaicelor": "boieroaică",
    "boilere": "boiler",
    "boilerele": "boiler",
    "boilerelor": "boiler",
    "boilerul": "boiler",
    "boilerului": "boiler",
    "boiștea": "boiște",
    "boiști": "boiște",
    "boiștii": "boiște",
    "boiștile": "boiște",
    "boiștilor": "boiște",
    "boita": "boit",
    "boită": "boit",
    "boite": "boit",
    "boitei": "boit",
    "boitele": "boit",
    "boitelor": "boit",
    "boiți": "boit",
    "boiții": "boit",
    "boiților": "boit",
    "boitul": "boit",
    "boitului": "boit",
    "boita": "boită",
    "boite": "boită",
    "boitei": "boită",
    "boitele": "boită",
    "boitelor": "boită",
    "bojdeuca": "bojdeucă",
    "bojdeuci": "bojdeucă",
    "bojdeucii": "bojdeucă",
    "bojdeucile": "bojdeucă",
    "bojdeucilor": "bojdeucă",
    "bolul": "bol",
    "bolului": "bol",
    "boluri": "bol",
    "bolurile": "bol",
    "bolurilor": "bol",
    "bolboroseala": "bolboroseală",
    "bolborosealo": "bolboroseală",
    "bolboroseli": "bolboroseală",
    "bolboroselii": "bolboroseală",
    "bolboroselile": "bolboroseală",
    "bolboroselilor": "bolboroseală",
    "bolborosea": "bolborosi",
    "bolboroseai": "bolborosi",
    "bolboroseam": "bolborosi",
    "bolborosească": "bolborosi",
    "bolboroseați": "bolborosi",
    "bolboroseau": "bolborosi",
    "bolborosesc": "bolborosi",
    "bolborosește": "bolborosi",
    "bolborosești": "bolborosi",
    "bolborosii": "bolborosi",
    "bolborosim": "bolborosi",
    "bolborosind": "bolborosi",
    "bolborosindu": "bolborosi",
    "bolborosiră": "bolborosi",
    "bolborosirăm": "bolborosi",
    "bolborosirăți": "bolborosi",
    "bolborosise": "bolborosi",
    "bolborosisem": "bolborosi",
    "bolborosiseră": "bolborosi",
    "bolborosiserăm": "bolborosi",
    "bolborosiserăți": "bolborosi",
    "bolborosiseși": "bolborosi",
    "bolborosiși": "bolborosi",
    "bolborosit": "bolborosi",
    "bolborosiți": "bolborosi",
    "bolborositu": "bolborosi",
    "nebolborosind": "bolborosi",
    "nebolborosindu": "bolborosi",
    "nemaibolborosind": "bolborosi",
    "nemaibolborosindu": "bolborosi",
    "bolborosirea": "bolborosire",
    "bolborosireo": "bolborosire",
    "bolborosiri": "bolborosire",
    "bolborosirii": "bolborosire",
    "bolborosirile": "bolborosire",
    "bolborosirilor": "bolborosire",
    "bolborosita": "bolborosit",
    "bolborosită": "bolborosit",
    "bolborosite": "bolborosit",
    "bolborositei": "bolborosit",
    "bolborositele": "bolborosit",
    "bolborositelor": "bolborosit",
    "bolborosiți": "bolborosit",
    "bolborosiții": "bolborosit",
    "bolborosiților": "bolborosit",
    "bolborosito": "bolborosit",
    "bolborositul": "bolborosit",
    "bolborositule": "bolborosit",
    "bolborositului": "bolborosit",
    "boldul": "bold",
    "boldului": "bold",
    "bolduri": "bold",
    "boldurile": "bold",
    "boldurilor": "bold",
    "boleroul": "bolero",
    "boleroului": "bolero",
    "bolerouri": "bolero",
    "bolerourile": "bolero",
    "bolerourilor": "bolero",
    "bolea": "boli",
    "boleai": "boli",
    "boleam": "boli",
    "bolească": "boli",
    "boleați": "boli",
    "boleau": "boli",
    "bolesc": "boli",
    "bolește": "boli",
    "bolești": "boli",
    "bolii": "boli",
    "bolim": "boli",
    "bolind": "boli",
    "bolindu": "boli",
    "boliră": "boli",
    "bolirăm": "boli",
    "bolirăți": "boli",
    "bolise": "boli",
    "bolisem": "boli",
    "boliseră": "boli",
    "boliserăm": "boli",
    "boliserăți": "boli",
    "boliseși": "boli",
    "boliși": "boli",
    "bolit": "boli",
    "boliți": "boli",
    "bolitu": "boli",
    "bolidul": "bolid",
    "bolidului": "bolid",
    "bolizi": "bolid",
    "bolizii": "bolid",
    "bolizilor": "bolid",
    "bolirea": "bolire",
    "boliri": "bolire",
    "bolirii": "bolire",
    "bolirile": "bolire",
    "bolirilor": "bolire",
    "bolită": "bolit",
    "bolite": "bolit",
    "boliți": "bolit",
    "bolnava": "bolnav",
    "bolnavă": "bolnav",
    "bolnave": "bolnav",
    "bolnavei": "bolnav",
    "bolnavele": "bolnav",
    "bolnavelor": "bolnav",
    "bolnavi": "bolnav",
    "bolnavii": "bolnav",
    "bolnavilor": "bolnav",
    "bolnavo": "bolnav",
    "bolnavul": "bolnav",
    "bolnavule": "bolnav",
    "bolnavului": "bolnav",
    "bolnava": "bolnavă",
    "bolnave": "bolnavă",
    "bolnavei": "bolnavă",
    "bolnavele": "bolnavă",
    "bolnavelor": "bolnavă",
    "bolnavo": "bolnavă",
    "bolnăvicioasa": "bolnăvicios",
    "bolnăvicioasă": "bolnăvicios",
    "bolnăvicioase": "bolnăvicios",
    "bolnăvicioasei": "bolnăvicios",
    "bolnăvicioasele": "bolnăvicios",
    "bolnăvicioaselor": "bolnăvicios",
    "bolnăvicioaso": "bolnăvicios",
    "bolnăvicioși": "bolnăvicios",
    "bolnăvicioșii": "bolnăvicios",
    "bolnăvicioșilor": "bolnăvicios",
    "bolnăviciosul": "bolnăvicios",
    "bolnăviciosule": "bolnăvicios",
    "bolnăviciosului": "bolnăvicios",
    "bolovani": "bolovan",
    "bolovanii": "bolovan",
    "bolovanilor": "bolovan",
    "bolovanul": "bolovan",
    "bolovanule": "bolovan",
    "bolovanului": "bolovan",
    "bolovănoasa": "bolovănos",
    "bolovănoasă": "bolovănos",
    "bolovănoase": "bolovănos",
    "bolovănoasei": "bolovănos",
    "bolovănoasele": "bolovănos",
    "bolovănoaselor": "bolovănos",
    "bolovănoaso": "bolovănos",
    "bolovănoși": "bolovănos",
    "bolovănoșii": "bolovănos",
    "bolovănoșilor": "bolovănos",
    "bolovănosul": "bolovănos",
    "bolovănosule": "bolovănos",
    "bolovănosului": "bolovănos",
    "bolșevica": "bolșevică",
    "bolșevice": "bolșevică",
    "bolșevicei": "bolșevică",
    "bolșevicele": "bolșevică",
    "bolșevicelor": "bolșevică",
    "bolșevisme": "bolșevism",
    "bolșevismele": "bolșevism",
    "bolșevismelor": "bolșevism",
    "bolșevismul": "bolșevism",
    "bolșevismului": "bolșevism",
    "bolta": "boltă",
    "bolți": "boltă",
    "bolții": "boltă",
    "bolțile": "boltă",
    "bolților": "boltă",
    "boltirea": "boltire",
    "boltiri": "boltire",
    "boltirii": "boltire",
    "boltirile": "boltire",
    "boltirilor": "boltire",
    "boltita": "boltit",
    "boltită": "boltit",
    "boltite": "boltit",
    "boltitei": "boltit",
    "boltitele": "boltit",
    "boltitelor": "boltit",
    "boltiți": "boltit",
    "boltiții": "boltit",
    "boltiților": "boltit",
    "boltitul": "boltit",
    "boltitului": "boltit",
    "bombă": "bomba",
    "bombai": "bomba",
    "bombam": "bomba",
    "bombăm": "bomba",
    "bombând": "bomba",
    "bombându": "bomba",
    "bombară": "bomba",
    "bombarăm": "bomba",
    "bombarăți": "bomba",
    "bombase": "bomba",
    "bombasem": "bomba",
    "bombaseră": "bomba",
    "bombaserăm": "bomba",
    "bombaserăți": "bomba",
    "bombaseși": "bomba",
    "bombași": "bomba",
    "bombat": "bomba",
    "bombați": "bomba",
    "bombatu": "bomba",
    "bombau": "bomba",
    "bombează": "bomba",
    "bombez": "bomba",
    "bombeze": "bomba",
    "bombezi": "bomba",
    "nebombând": "bomba",
    "nebombându": "bomba",
    "nemaibombând": "bomba",
    "nemaibombându": "bomba",
    "bomba": "bombă",
    "bombe": "bombă",
    "bombei": "bombă",
    "bombele": "bombă",
    "bombelor": "bombă",
    "bombănea": "bombăni",
    "bombăneai": "bombăni",
    "bombăneam": "bombăni",
    "bombănească": "bombăni",
    "bombăneați": "bombăni",
    "bombăneau": "bombăni",
    "bombănesc": "bombăni",
    "bombănește": "bombăni",
    "bombănești": "bombăni",
    "bombănii": "bombăni",
    "bombănim": "bombăni",
    "bombănind": "bombăni",
    "bombănindu": "bombăni",
    "bombăniră": "bombăni",
    "bombănirăm": "bombăni",
    "bombănirăți": "bombăni",
    "bombănise": "bombăni",
    "bombănisem": "bombăni",
    "bombăniseră": "bombăni",
    "bombăniserăm": "bombăni",
    "bombăniserăți": "bombăni",
    "bombăniseși": "bombăni",
    "bombăniși": "bombăni",
    "bombănit": "bombăni",
    "bombăniți": "bombăni",
    "bombănitu": "bombăni",
    "bombănită": "bombănit",
    "bombănite": "bombănit",
    "bombăniți": "bombănit",
    "bombardă": "bombarda",
    "bombardai": "bombarda",
    "bombardam": "bombarda",
    "bombardăm": "bombarda",
    "bombardând": "bombarda",
    "bombardându": "bombarda",
    "bombardară": "bombarda",
    "bombardarăm": "bombarda",
    "bombardarăți": "bombarda",
    "bombardase": "bombarda",
    "bombardasem": "bombarda",
    "bombardaseră": "bombarda",
    "bombardaserăm": "bombarda",
    "bombardaserăți": "bombarda",
    "bombardaseși": "bombarda",
    "bombardași": "bombarda",
    "bombardat": "bombarda",
    "bombardați": "bombarda",
    "bombardatu": "bombarda",
    "bombardau": "bombarda",
    "bombardează": "bombarda",
    "bombardez": "bombarda",
    "bombardeze": "bombarda",
    "bombardezi": "bombarda",
    "nebombardând": "bombarda",
    "nebombardându": "bombarda",
    "nemaibombardând": "bombarda",
    "nemaibombardându": "bombarda",
    "bombarda": "bombardă",
    "bombarde": "bombardă",
    "bombardei": "bombardă",
    "bombardele": "bombardă",
    "bombardelor": "bombardă",
    "bombardamente": "bombardament",
    "bombardamentele": "bombardament",
    "bombardamentelor": "bombardament",
    "bombardamentul": "bombardament",
    "bombardamentului": "bombardament",
    "bombardarea": "bombardare",
    "bombardări": "bombardare",
    "bombardării": "bombardare",
    "bombardările": "bombardare",
    "bombardata": "bombardat",
    "bombardată": "bombardat",
    "bombardate": "bombardat",
    "bombardatei": "bombardat",
    "bombardatele": "bombardat",
    "bombardatelor": "bombardat",
    "bombardați": "bombardat",
    "bombardații": "bombardat",
    "bombardaților": "bombardat",
    "bombardatul": "bombardat",
    "bombardatului": "bombardat",
    "bombardiere": "bombardier",
    "bombardierele": "bombardier",
    "bombardierelor": "bombardier",
    "bombardierul": "bombardier",
    "bombardierului": "bombardier",
    "bombarea": "bombare",
    "bombări": "bombare",
    "bombării": "bombare",
    "bombările": "bombare",
    "bombastica": "bombastic",
    "bombastică": "bombastic",
    "bombastice": "bombastic",
    "bombasticei": "bombastic",
    "bombasticele": "bombastic",
    "bombasticelor": "bombastic",
    "bombastici": "bombastic",
    "bombasticii": "bombastic",
    "bombasticilor": "bombastic",
    "bombasticul": "bombastic",
    "bombasticului": "bombastic",
    "bombata": "bombat",
    "bombată": "bombat",
    "bombate": "bombat",
    "bombatei": "bombat",
    "bombatele": "bombat",
    "bombatelor": "bombat",
    "bombați": "bombat",
    "bombații": "bombat",
    "bombaților": "bombat",
    "bombatul": "bombat",
    "bombatului": "bombat",
    "bombeul": "bombeu",
    "bombeului": "bombeu",
    "bombeuri": "bombeu",
    "bombeurile": "bombeu",
    "bombeurilor": "bombeu",
    "bomboana": "bomboană",
    "bomboane": "bomboană",
    "bomboanei": "bomboană",
    "bomboanele": "bomboană",
    "bomboanelor": "bomboană",
    "bomfaiere": "bomfaier",
    "bomfaierele": "bomfaier",
    "bomfaierelor": "bomfaier",
    "bomfaierul": "bomfaier",
    "bomfaierului": "bomfaier",
    "bonul": "bon",
    "bonului": "bon",
    "bonuri": "bon",
    "bonurile": "bon",
    "bonurilor": "bon",
    "bona": "bonă",
    "bone": "bonă",
    "bonei": "bonă",
    "bonele": "bonă",
    "bonelor": "bonă",
    "bondari": "bondar",
    "bondarii": "bondar",
    "bondarilor": "bondar",
    "bondarul": "bondar",
    "bondarului": "bondar",
    "bondoaca": "bondoc",
    "bondoacă": "bondoc",
    "bondoace": "bondoc",
    "bondoacei": "bondoc",
    "bondoacele": "bondoc",
    "bondoacelor": "bondoc",
    "bondoci": "bondoc",
    "bondocii": "bondoc",
    "bondocilor": "bondoc",
    "bondocul": "bondoc",
    "bondocului": "bondoc",
    "boniere": "bonier",
    "bonierele": "bonier",
    "bonierelor": "bonier",
    "bonierul": "bonier",
    "bonierului": "bonier",
    "bonific": "bonifica",
    "bonifică": "bonifica",
    "bonificai": "bonifica",
    "bonificam": "bonifica",
    "bonificăm": "bonifica",
    "bonificând": "bonifica",
    "bonificându": "bonifica",
    "bonificară": "bonifica",
    "bonificarăm": "bonifica",
    "bonificarăți": "bonifica",
    "bonificase": "bonifica",
    "bonificasem": "bonifica",
    "bonificaseră": "bonifica",
    "bonificaserăm": "bonifica",
    "bonificaserăți": "bonifica",
    "bonificaseși": "bonifica",
    "bonificași": "bonifica",
    "bonificat": "bonifica",
    "bonificați": "bonifica",
    "bonificatu": "bonifica",
    "bonificau": "bonifica",
    "bonifice": "bonifica",
    "bonifici": "bonifica",
    "nebonificând": "bonifica",
    "nebonificându": "bonifica",
    "nemaibonificând": "bonifica",
    "nemaibonificându": "bonifica",
    "bonificarea": "bonificare",
    "bonificări": "bonificare",
    "bonificării": "bonificare",
    "bonificările": "bonificare",
    "bonificata": "bonificat",
    "bonificată": "bonificat",
    "bonificate": "bonificat",
    "bonificatei": "bonificat",
    "bonificatele": "bonificat",
    "bonificatelor": "bonificat",
    "bonificați": "bonificat",
    "bonificații": "bonificat",
    "bonificaților": "bonificat",
    "bonificatul": "bonificat",
    "bonificatului": "bonificat",
    "bonificația": "bonificație",
    "bonificației": "bonificație",
    "bonificații": "bonificație",
    "bonificațiile": "bonificație",
    "bonificațiilor": "bonificație",
    "bonitatea": "bonitate",
    "bonități": "bonitate",
    "bonității": "bonitate",
    "bonitățile": "bonitate",
    "bonităților": "bonitate",
    "bonoma": "bonom",
    "bonomă": "bonom",
    "bonome": "bonom",
    "bonomei": "bonom",
    "bonomele": "bonom",
    "bonomelor": "bonom",
    "bonomi": "bonom",
    "bonomii": "bonom",
    "bonomilor": "bonom",
    "bonomul": "bonom",
    "bonomului": "bonom",
    "boanta": "bont",
    "boantă": "bont",
    "boante": "bont",
    "boantei": "bont",
    "boantele": "bont",
    "boantelor": "bont",
    "bonți": "bont",
    "bonții": "bont",
    "bonților": "bont",
    "bontul": "bont",
    "bontului": "bont",
    "bontonul": "bonton",
    "bontonului": "bonton",
    "bontonuri": "bonton",
    "bontonurile": "bonton",
    "bontonurilor": "bonton",
    "bonusul": "bonus",
    "bonusului": "bonus",
    "bonusuri": "bonus",
    "bonusurile": "bonus",
    "bonusurilor": "bonus",
    "B": "bor",
    "borul": "bor",
    "borului": "bor",
    "borcane": "borcan",
    "borcanele": "borcan",
    "borcanelor": "borcan",
    "borcanul": "borcan",
    "borcanule": "borcan",
    "borcanului": "borcan",
    "borcănele": "borcănel",
    "borcănelele": "borcănel",
    "borcănelelor": "borcănel",
    "borcănelul": "borcănel",
    "borcănelule": "borcănel",
    "borcănelului": "borcănel",
    "bordul": "bord",
    "bordului": "bord",
    "borduri": "bord",
    "bordurile": "bord",
    "bordurilor": "bord",
    "bordeie": "bordei",
    "bordeiele": "bordei",
    "bordeielor": "bordei",
    "bordeiul": "bordei",
    "bordeiului": "bordei",
    "bordelul": "bordel",
    "bordelului": "bordel",
    "bordeluri": "bordel",
    "bordelurile": "bordel",
    "bordelurilor": "bordel",
    "borderoul": "borderou",
    "borderoului": "borderou",
    "borderouri": "borderou",
    "borderourile": "borderou",
    "borderourilor": "borderou",
    "bordura": "bordură",
    "borduri": "bordură",
    "bordurii": "bordură",
    "bordurile": "bordură",
    "bordurilor": "bordură",
    "boreala": "boreal",
    "boreală": "boreal",
    "boreale": "boreal",
    "borealei": "boreal",
    "borealele": "boreal",
    "borealelor": "boreal",
    "boreali": "boreal",
    "borealii": "boreal",
    "borealilor": "boreal",
    "borealul": "boreal",
    "borealului": "boreal",
    "borfași": "borfaș",
    "borfașii": "borfaș",
    "borfașilor": "borfaș",
    "borfașul": "borfaș",
    "borfașului": "borfaș",
    "borfășia": "borfășie",
    "borfășiei": "borfășie",
    "borfășii": "borfășie",
    "borfășiile": "borfășie",
    "borfășiilor": "borfășie",
    "bormașina": "bormașină",
    "bormașini": "bormașină",
    "bormașinii": "bormașină",
    "bormașinile": "bormașină",
    "bormașinilor": "bormașină",
    "borna": "bornă",
    "borne": "bornă",
    "bornei": "bornă",
    "bornele": "bornă",
    "bornelor": "bornă",
    "boroana": "boroană",
    "boroane": "boroană",
    "boroanei": "boroană",
    "boroanele": "boroană",
    "boroanelor": "boroană",
    "borșul": "borș",
    "borșului": "borș",
    "borșuri": "borș",
    "borșurile": "borș",
    "borșurilor": "borș",
    "borvize": "borviz",
    "borvizele": "borviz",
    "borvizelor": "borviz",
    "borvizul": "borviz",
    "borvizului": "borviz",
    "boscari": "boscar",
    "boscarii": "boscar",
    "boscarilor": "boscar",
    "boscarul": "boscar",
    "boscarului": "boscar",
    "boschete": "boschet",
    "boschetele": "boschet",
    "boschetelor": "boschet",
    "boschetul": "boschet",
    "boschetului": "boschet",
    "boschetari": "boschetar",
    "boschetarii": "boschetar",
    "boschetarilor": "boschetar",
    "boschetarul": "boschetar",
    "boschetarului": "boschetar",
    "boscorodea": "boscorodi",
    "boscorodeai": "boscorodi",
    "boscorodeam": "boscorodi",
    "boscorodească": "boscorodi",
    "boscorodeați": "boscorodi",
    "boscorodeau": "boscorodi",
    "boscorodesc": "boscorodi",
    "boscorodește": "boscorodi",
    "boscorodești": "boscorodi",
    "boscorodii": "boscorodi",
    "boscorodim": "boscorodi",
    "boscorodind": "boscorodi",
    "boscorodindu": "boscorodi",
    "boscorodiră": "boscorodi",
    "boscorodirăm": "boscorodi",
    "boscorodirăți": "boscorodi",
    "boscorodise": "boscorodi",
    "boscorodisem": "boscorodi",
    "boscorodiseră": "boscorodi",
    "boscorodiserăm": "boscorodi",
    "boscorodiserăți": "boscorodi",
    "boscorodiseși": "boscorodi",
    "boscorodiși": "boscorodi",
    "boscorodit": "boscorodi",
    "boscorodiți": "boscorodi",
    "boscoroditu": "boscorodi",
    "neboscorodind": "boscorodi",
    "neboscorodindu": "boscorodi",
    "nemaiboscorodind": "boscorodi",
    "nemaiboscorodindu": "boscorodi",
    "boscorodirea": "boscorodire",
    "boscorodiri": "boscorodire",
    "boscorodirii": "boscorodire",
    "boscorodirile": "boscorodire",
    "boscorodita": "boscorodit",
    "boscorodită": "boscorodit",
    "boscorodite": "boscorodit",
    "boscoroditei": "boscorodit",
    "boscoroditele": "boscorodit",
    "boscoroditelor": "boscorodit",
    "boscorodiți": "boscorodit",
    "boscorodiții": "boscorodit",
    "boscorodiților": "boscorodit",
    "boscoroditul": "boscorodit",
    "boscoroditului": "boscorodit",
    "bosniaca": "bosniac",
    "bosniacă": "bosniac",
    "bosniace": "bosniac",
    "bosniacei": "bosniac",
    "bosniacele": "bosniac",
    "bosniacelor": "bosniac",
    "bosniaci": "bosniac",
    "bosniacii": "bosniac",
    "bosniacilor": "bosniac",
    "bosniacul": "bosniac",
    "bosniacului": "bosniac",
    "bosniece": "bosniac",
    "bosniecei": "bosniac",
    "bosniecele": "bosniac",
    "bosniecelor": "bosniac",
    "bosnieci": "bosniac",
    "bosniecii": "bosniac",
    "bosniecilor": "bosniac",
    "bosniaca": "bosniacă",
    "bosniece": "bosniacă",
    "bosniecei": "bosniacă",
    "bosniecele": "bosniacă",
    "bosniecelor": "bosniacă",
    "bosumflă": "bosumfla",
    "bosumflai": "bosumfla",
    "bosumflam": "bosumfla",
    "bosumflăm": "bosumfla",
    "bosumflând": "bosumfla",
    "bosumflându": "bosumfla",
    "bosumflară": "bosumfla",
    "bosumflarăm": "bosumfla",
    "bosumflarăți": "bosumfla",
    "bosumflase": "bosumfla",
    "bosumflasem": "bosumfla",
    "bosumflaseră": "bosumfla",
    "bosumflaserăm": "bosumfla",
    "bosumflaserăți": "bosumfla",
    "bosumflaseși": "bosumfla",
    "bosumflași": "bosumfla",
    "bosumflat": "bosumfla",
    "bosumflați": "bosumfla",
    "bosumflau": "bosumfla",
    "bosumfle": "bosumfla",
    "bosumfli": "bosumfla",
    "bosumflu": "bosumfla",
    "bosumflarea": "bosumflare",
    "bosumflări": "bosumflare",
    "bosumflării": "bosumflare",
    "bosumflările": "bosumflare",
    "bosumflărilor": "bosumflare",
    "bosumflata": "bosumflat",
    "bosumflată": "bosumflat",
    "bosumflate": "bosumflat",
    "bosumflatei": "bosumflat",
    "bosumflatele": "bosumflat",
    "bosumflatelor": "bosumflat",
    "bosumflați": "bosumflat",
    "bosumflații": "bosumflat",
    "bosumflaților": "bosumflat",
    "bosumflato": "bosumflat",
    "bosumflatul": "bosumflat",
    "bosumflatule": "bosumflat",
    "bosumflatului": "bosumflat",
    "botu'": "bot",
    "botul": "bot",
    "botule": "bot",
    "botului": "bot",
    "boturi": "bot",
    "boturile": "bot",
    "boturilor": "bot",
    "bot.": "botanică",
    "botanica": "botanică",
    "botanicele": "botanică",
    "botanicelor": "botanică",
    "botanici": "botanică",
    "botanicii": "botanică",
    "botezul": "botez",
    "botezului": "botez",
    "botezuri": "botez",
    "botezurile": "botez",
    "botezurilor": "botez",
    "botez": "boteza",
    "boteză": "boteza",
    "botezai": "boteza",
    "botezam": "boteza",
    "botezăm": "boteza",
    "botezând": "boteza",
    "botezându": "boteza",
    "botezară": "boteza",
    "botezarăm": "boteza",
    "botezarăți": "boteza",
    "botezase": "boteza",
    "botezasem": "boteza",
    "botezaseră": "boteza",
    "botezaserăm": "boteza",
    "botezaserăți": "boteza",
    "botezaseși": "boteza",
    "botezași": "boteza",
    "botezat": "boteza",
    "botezați": "boteza",
    "botezatu": "boteza",
    "botezau": "boteza",
    "boteze": "boteza",
    "botezi": "boteza",
    "botezata": "botezat",
    "botezată": "botezat",
    "botezate": "botezat",
    "botezatei": "botezat",
    "botezatele": "botezat",
    "botezatelor": "botezat",
    "botezați": "botezat",
    "botezații": "botezat",
    "botezaților": "botezat",
    "botezatul": "botezat",
    "botezatului": "botezat",
    "botezata": "botezată",
    "botezate": "botezată",
    "botezatei": "botezată",
    "botezatele": "botezată",
    "botezatelor": "botezată",
    "botoasa": "botoasă",
    "botoase": "botoasă",
    "botoasei": "botoasă",
    "botoasele": "botoasă",
    "botoaselor": "botoasă",
    "botoasa": "botos",
    "botoasă": "botos",
    "botoase": "botos",
    "botoasei": "botos",
    "botoasele": "botos",
    "botoaselor": "botos",
    "botoși": "botos",
    "botoșii": "botos",
    "botoșilor": "botos",
    "botosul": "botos",
    "botosului": "botos",
    "Botoșaniul": "Botoșani",
    "Botoșaniului": "Botoșani",
    "boi": "bou",
    "boii": "bou",
    "boilor": "bou",
    "boul": "bou",
    "boule": "bou",
    "boului": "bou",
    "boi-de-apă": "bou-de-apă",
    "boi-de-baltă": "bou-de-baltă",
    "boi-de-mare": "bou-de-mare",
    "boii-Domnului": "boul-Domnului",
    "boii-lui-Dumnezeu": "boul-lui-Dumnezeu",
    "boii-popii": "boul-popii",
    "bouri": "bour",
    "bourii": "bour",
    "bourilor": "bour",
    "bourul": "bour",
    "bourului": "bour",
    "bovina": "bovin",
    "bovină": "bovin",
    "bovine": "bovin",
    "bovinei": "bovin",
    "bovinele": "bovin",
    "bovinelor": "bovin",
    "bovini": "bovin",
    "bovinii": "bovin",
    "bovinilor": "bovin",
    "bovinul": "bovin",
    "bovinului": "bovin",
    "boxul": "box",
    "boxule": "box",
    "boxului": "box",
    "boxă": "boxa",
    "boxai": "boxa",
    "boxam": "boxa",
    "boxăm": "boxa",
    "boxând": "boxa",
    "boxându": "boxa",
    "boxară": "boxa",
    "boxarăm": "boxa",
    "boxarăți": "boxa",
    "boxase": "boxa",
    "boxasem": "boxa",
    "boxaseră": "boxa",
    "boxaserăm": "boxa",
    "boxaserăți": "boxa",
    "boxaseși": "boxa",
    "boxași": "boxa",
    "boxat": "boxa",
    "boxați": "boxa",
    "boxatu": "boxa",
    "boxau": "boxa",
    "boxează": "boxa",
    "boxez": "boxa",
    "boxeze": "boxa",
    "boxezi": "boxa",
    "neboxând": "boxa",
    "neboxându": "boxa",
    "nemaiboxând": "boxa",
    "nemaiboxându": "boxa",
    "boxa": "boxă",
    "boxe": "boxă",
    "boxei": "boxă",
    "boxele": "boxă",
    "boxelor": "boxă",
    "boxarea": "boxare",
    "boxareo": "boxare",
    "boxări": "boxare",
    "boxării": "boxare",
    "boxările": "boxare",
    "boxărilor": "boxare",
    "boxata": "boxat",
    "boxată": "boxat",
    "boxate": "boxat",
    "boxatei": "boxat",
    "boxatele": "boxat",
    "boxatelor": "boxat",
    "boxați": "boxat",
    "boxații": "boxat",
    "boxaților": "boxat",
    "boxato": "boxat",
    "boxatul": "boxat",
    "boxatule": "boxat",
    "boxatului": "boxat",
    "boxeri": "boxer",
    "boxerii": "boxer",
    "boxerilor": "boxer",
    "boxerul": "boxer",
    "boxerule": "boxer",
    "boxerului": "boxer",
    "braconaje": "braconaj",
    "braconajele": "braconaj",
    "braconajelor": "braconaj",
    "braconajul": "braconaj",
    "braconajului": "braconaj",
    "bracteea": "bractee",
    "bracteei": "bractee",
    "bracteele": "bractee",
    "bracteelor": "bractee",
    "bradul": "brad",
    "bradului": "brad",
    "brazi": "brad",
    "brazii": "brad",
    "brazilor": "brad",
    "brădetul": "brădet",
    "brădetului": "brădet",
    "brădeturi": "brădet",
    "brădeturile": "brădet",
    "brădeturilor": "brădet",
    "brazi-roșii": "brad-roșu",
    "brahiala": "brahial",
    "brahială": "brahial",
    "brahiale": "brahial",
    "brahialei": "brahial",
    "brahialele": "brahial",
    "brahialelor": "brahial",
    "brahiali": "brahial",
    "brahialii": "brahial",
    "brahialilor": "brahial",
    "brahialul": "brahial",
    "brahialului": "brahial",
    "Brăilă": "Brăila",
    "Brăile": "Brăila",
    "Brăilei": "Brăila",
    "brambureala": "brambureală",
    "brambureli": "brambureală",
    "bramburelii": "brambureală",
    "bramburelile": "brambureală",
    "bramburelilor": "brambureală",
    "brânca": "brâncă",
    "brânci": "brâncă",
    "brâncii": "brâncă",
    "brâncile": "brâncă",
    "brâncilor": "brâncă",
    "brancarda": "brancardă",
    "brancarde": "brancardă",
    "brancardei": "brancardă",
    "brancardele": "brancardă",
    "brancardelor": "brancardă",
    "brancardieri": "brancardier",
    "brancardierii": "brancardier",
    "brancardierilor": "brancardier",
    "brancardierul": "brancardier",
    "brancardierului": "brancardier",
    "brânciul": "brânci",
    "brânciului": "brânci",
    "brandul": "brand",
    "brandului": "brand",
    "branduri": "brand",
    "brandurile": "brand",
    "brandurilor": "brand",
    "Brândușe": "Brândușa",
    "Brândușei": "Brândușa",
    "braniștea": "braniște",
    "braniști": "braniște",
    "braniștii": "braniște",
    "braniștile": "braniște",
    "braniștilor": "braniște",
    "branșă": "branșa",
    "branșai": "branșa",
    "branșam": "branșa",
    "branșăm": "branșa",
    "branșând": "branșa",
    "branșându": "branșa",
    "branșară": "branșa",
    "branșarăm": "branșa",
    "branșarăți": "branșa",
    "branșase": "branșa",
    "branșasem": "branșa",
    "branșaseră": "branșa",
    "branșaserăm": "branșa",
    "branșaserăți": "branșa",
    "branșaseși": "branșa",
    "branșași": "branșa",
    "branșat": "branșa",
    "branșați": "branșa",
    "branșatu": "branșa",
    "branșau": "branșa",
    "branșează": "branșa",
    "branșez": "branșa",
    "branșeze": "branșa",
    "branșezi": "branșa",
    "branșa": "branșă",
    "branșe": "branșă",
    "branșei": "branșă",
    "branșele": "branșă",
    "branșelor": "branșă",
    "branșamente": "branșament",
    "branșamentele": "branșament",
    "branșamentelor": "branșament",
    "branșamentul": "branșament",
    "branșamentului": "branșament",
    "branșarea": "branșare",
    "branșări": "branșare",
    "branșării": "branșare",
    "branșările": "branșare",
    "branșata": "branșat",
    "branșată": "branșat",
    "branșate": "branșat",
    "branșatei": "branșat",
    "branșatele": "branșat",
    "branșatelor": "branșat",
    "branșați": "branșat",
    "branșații": "branșat",
    "branșaților": "branșat",
    "branșatul": "branșat",
    "branșatului": "branșat",
    "branțul": "branț",
    "branțului": "branț",
    "branțuri": "branț",
    "branțurile": "branț",
    "branțurilor": "branț",
    "brânza": "brânză",
    "brânze": "brânză",
    "brânzei": "brânză",
    "brânzii": "brânză",
    "brânzo": "brânză",
    "brasarda": "brasardă",
    "brasarde": "brasardă",
    "brasardei": "brasardă",
    "brasardele": "brasardă",
    "brasardelor": "brasardă",
    "braseria": "braserie",
    "braseriei": "braserie",
    "braserii": "braserie",
    "braseriile": "braserie",
    "braseriilor": "braserie",
    "brasiera": "brasieră",
    "brasiere": "brasieră",
    "brasierei": "brasieră",
    "brasierele": "brasieră",
    "brasierelor": "brasieră",
    "brașoava": "brașoavă",
    "brașoave": "brașoavă",
    "brașoavei": "brașoavă",
    "brașoavele": "brașoavă",
    "brașoavelor": "brașoavă",
    "Brașovul": "Brașov",
    "Brașovului": "Brașov",
    "brațe": "braț",
    "brațele": "braț",
    "brațelor": "braț",
    "brațul": "braț",
    "brațului": "braț",
    "brățara": "brățară",
    "brățări": "brățară",
    "brățării": "brățară",
    "brățările": "brățară",
    "brățărilor": "brățară",
    "brâie": "brâu",
    "brâiele": "brâu",
    "brâielor": "brâu",
    "brâul": "brâu",
    "brâule": "brâu",
    "brâului": "brâu",
    "brava": "brav",
    "bravă": "brav",
    "brave": "brav",
    "bravei": "brav",
    "bravele": "brav",
    "bravelor": "brav",
    "bravi": "brav",
    "bravii": "brav",
    "bravilor": "brav",
    "bravul": "brav",
    "bravului": "brav",
    "bravada": "bravadă",
    "bravade": "bravadă",
    "bravadei": "bravadă",
    "bravadele": "bravadă",
    "bravadelor": "bravadă",
    "bravura": "bravură",
    "bravuri": "bravură",
    "bravurii": "bravură",
    "bravurile": "bravură",
    "bravurilor": "bravură",
    "brazda": "brazdă",
    "brazde": "brazdă",
    "brazdei": "brazdă",
    "brazdele": "brazdă",
    "brazdelor": "brazdă",
    "brăzdă": "brăzda",
    "brăzdai": "brăzda",
    "brăzdam": "brăzda",
    "brăzdăm": "brăzda",
    "brăzdând": "brăzda",
    "brăzdându": "brăzda",
    "brăzdară": "brăzda",
    "brăzdarăm": "brăzda",
    "brăzdarăți": "brăzda",
    "brăzdase": "brăzda",
    "brăzdasem": "brăzda",
    "brăzdaseră": "brăzda",
    "brăzdaserăm": "brăzda",
    "brăzdaserăți": "brăzda",
    "brăzdaseși": "brăzda",
    "brăzdași": "brăzda",
    "brăzdat": "brăzda",
    "brăzdați": "brăzda",
    "brăzdatu": "brăzda",
    "brăzdau": "brăzda",
    "brăzdează": "brăzda",
    "brăzdez": "brăzda",
    "brăzdeze": "brăzda",
    "brăzdezi": "brăzda",
    "nebrăzdând": "brăzda",
    "nebrăzdându": "brăzda",
    "nemaibrăzdând": "brăzda",
    "nemaibrăzdându": "brăzda",
    "brăzdarea": "brăzdare",
    "brăzdareo": "brăzdare",
    "brăzdări": "brăzdare",
    "brăzdării": "brăzdare",
    "brăzdările": "brăzdare",
    "brăzdărilor": "brăzdare",
    "brăzdata": "brăzdat",
    "brăzdată": "brăzdat",
    "brăzdate": "brăzdat",
    "brăzdatei": "brăzdat",
    "brăzdatele": "brăzdat",
    "brăzdatelor": "brăzdat",
    "brăzdați": "brăzdat",
    "brăzdații": "brăzdat",
    "brăzdaților": "brăzdat",
    "brăzdato": "brăzdat",
    "brăzdatul": "brăzdat",
    "brăzdatule": "brăzdat",
    "brăzdatului": "brăzdat",
    "Braziul": "Brazi",
    "Brazilie": "Brazilia",
    "Braziliei": "Brazilia",
    "Brazilii": "Brazilia",
    "braziliana": "brazilian",
    "braziliană": "brazilian",
    "braziliano": "brazilian",
    "brazilianul": "brazilian",
    "brazilianule": "brazilian",
    "brazilianului": "brazilian",
    "braziliene": "brazilian",
    "brazilienei": "brazilian",
    "brazilienele": "brazilian",
    "brazilienelor": "brazilian",
    "brazilieni": "brazilian",
    "brazilienii": "brazilian",
    "brazilienilor": "brazilian",
    "brazilianca": "braziliancă",
    "brazilianco": "braziliancă",
    "brazilience": "braziliancă",
    "braziliencei": "braziliancă",
    "braziliencele": "braziliancă",
    "braziliencelor": "braziliancă",
    "breasla": "breaslă",
    "bresle": "breaslă",
    "breslei": "breaslă",
    "breslele": "breaslă",
    "breslelor": "breaslă",
    "breaza": "breaz",
    "brează": "breaz",
    "breazul": "breaz",
    "breazului": "breaz",
    "breji": "breaz",
    "brejii": "breaz",
    "brejilor": "breaz",
    "breze": "breaz",
    "brezei": "breaz",
    "brezele": "breaz",
    "brezelor": "breaz",
    "brelocul": "breloc",
    "brelocului": "breloc",
    "brelocuri": "breloc",
    "brelocurile": "breloc",
    "brelocurilor": "breloc",
    "breșa": "breșă",
    "breșe": "breșă",
    "breșei": "breșă",
    "breșele": "breșă",
    "breșelor": "breșă",
    "brevete": "brevet",
    "brevetele": "brevet",
    "brevetelor": "brevet",
    "brevetul": "brevet",
    "brevetului": "brevet",
    "brevetă": "breveta",
    "brevetai": "breveta",
    "brevetam": "breveta",
    "brevetăm": "breveta",
    "brevetând": "breveta",
    "brevetându": "breveta",
    "brevetară": "breveta",
    "brevetarăm": "breveta",
    "brevetarăți": "breveta",
    "brevetase": "breveta",
    "brevetasem": "breveta",
    "brevetaseră": "breveta",
    "brevetaserăm": "breveta",
    "brevetaserăți": "breveta",
    "brevetaseși": "breveta",
    "brevetași": "breveta",
    "brevetat": "breveta",
    "brevetați": "breveta",
    "brevetatu": "breveta",
    "brevetau": "breveta",
    "brevetează": "breveta",
    "brevetez": "breveta",
    "breveteze": "breveta",
    "brevetezi": "breveta",
    "nebrevetând": "breveta",
    "nebrevetându": "breveta",
    "nemaibrevetând": "breveta",
    "nemaibrevetându": "breveta",
    "brevetarea": "brevetare",
    "brevetări": "brevetare",
    "brevetării": "brevetare",
    "brevetările": "brevetare",
    "brevetata": "brevetat",
    "brevetată": "brevetat",
    "brevetate": "brevetat",
    "brevetatei": "brevetat",
    "brevetatele": "brevetat",
    "brevetatelor": "brevetat",
    "brevetați": "brevetat",
    "brevetații": "brevetat",
    "brevetaților": "brevetat",
    "brevetatul": "brevetat",
    "brevetatului": "brevetat",
    "breviare": "breviar",
    "breviarele": "breviar",
    "breviarelor": "breviar",
    "breviarul": "breviar",
    "breviarului": "breviar",
    "brianta": "briant",
    "briantă": "briant",
    "briante": "briant",
    "briantei": "briant",
    "briantele": "briant",
    "briantelor": "briant",
    "brianți": "briant",
    "brianții": "briant",
    "brianților": "briant",
    "briantul": "briant",
    "briantului": "briant",
    "bricul": "bric",
    "bricului": "bric",
    "bricuri": "bric",
    "bricurile": "bric",
    "bricurilor": "bric",
    "briceagul": "briceag",
    "briceagule": "briceag",
    "briceagului": "briceag",
    "bricege": "briceag",
    "bricegele": "briceag",
    "bricegelor": "briceag",
    "bricheta": "brichetă",
    "brichete": "brichetă",
    "brichetei": "brichetă",
    "brichetele": "brichetă",
    "brichetelor": "brichetă",
    "brice": "brici",
    "bricele": "brici",
    "bricelor": "brici",
    "briciul": "brici",
    "briciului": "brici",
    "brigada": "brigadă",
    "brigăzi": "brigadă",
    "brigăzii": "brigadă",
    "brigăzile": "brigadă",
    "brigăzilor": "brigadă",
    "brigadieri": "brigadier",
    "brigadierii": "brigadier",
    "brigadierilor": "brigadier",
    "brigadierul": "brigadier",
    "brigadierului": "brigadier",
    "brigadiera": "brigadieră",
    "brigadiere": "brigadieră",
    "brigadierei": "brigadieră",
    "brigadierele": "brigadieră",
    "brigadierelor": "brigadieră",
    "brigandul": "brigand",
    "brigandului": "brigand",
    "briganzi": "brigand",
    "briganzii": "brigand",
    "briganzilor": "brigand",
    "briliante": "briliant",
    "briliantele": "briliant",
    "briliantelor": "briliant",
    "briliantul": "briliant",
    "briliantului": "briliant",
    "brișca": "brișcă",
    "briști": "brișcă",
    "briștii": "brișcă",
    "briștile": "brișcă",
    "briștilor": "brișcă",
    "britanica": "britanic",
    "britanică": "britanic",
    "britanice": "britanic",
    "britanicei": "britanic",
    "britanicele": "britanic",
    "britanicelor": "britanic",
    "britanici": "britanic",
    "britanicii": "britanic",
    "britanicilor": "britanic",
    "britanicul": "britanic",
    "britanicule": "britanic",
    "britanicului": "britanic",
    "britanica": "britanică",
    "britanice": "britanică",
    "britanicei": "britanică",
    "britanicele": "britanică",
    "britanicelor": "britanică",
    "briza": "briză",
    "brize": "briză",
    "brizei": "briză",
    "brizele": "briză",
    "brizelor": "briză",
    "brizbizul": "brizbiz",
    "brizbizului": "brizbiz",
    "brizbizuri": "brizbiz",
    "brizbizurile": "brizbiz",
    "brizbizurilor": "brizbiz",
    "broasca": "broască",
    "broasco": "broască",
    "broaște": "broască",
    "broaștei": "broască",
    "broaștele": "broască",
    "broaștelor": "broască",
    "broasca-țestoasă": "broască-țestoasă",
    "broaștei-țestoase": "broască-țestoasă",
    "broaștele-țestoase": "broască-țestoasă",
    "broaștelor-țestoase": "broască-țestoasă",
    "broaște-țestoase": "broască-țestoasă",
    "broboada": "broboadă",
    "broboade": "broboadă",
    "broboadei": "broboadă",
    "broboadele": "broboadă",
    "broboadelor": "broboadă",
    "broboana": "broboană",
    "broboane": "broboană",
    "broboanei": "broboană",
    "broboanele": "broboană",
    "broboanelor": "broboană",
    "brocartul": "brocart",
    "brocartului": "brocart",
    "brocarturi": "brocart",
    "brocarturile": "brocart",
    "brocarturilor": "brocart",
    "brodă": "broda",
    "brodai": "broda",
    "brodam": "broda",
    "brodăm": "broda",
    "brodând": "broda",
    "brodându": "broda",
    "brodară": "broda",
    "brodarăm": "broda",
    "brodarăți": "broda",
    "brodase": "broda",
    "brodasem": "broda",
    "brodaseră": "broda",
    "brodaserăm": "broda",
    "brodaserăți": "broda",
    "brodaseși": "broda",
    "brodași": "broda",
    "brodat": "broda",
    "brodați": "broda",
    "brodatu": "broda",
    "brodau": "broda",
    "brodează": "broda",
    "brodez": "broda",
    "brodeze": "broda",
    "brodezi": "broda",
    "nebrodând": "broda",
    "nebrodându": "broda",
    "nemaibrodând": "broda",
    "nemaibrodându": "broda",
    "brodată": "brodat",
    "brodate": "brodat",
    "brodați": "brodat",
    "broderia": "broderie",
    "broderiei": "broderie",
    "broderii": "broderie",
    "broderiile": "broderie",
    "broderiilor": "broderie",
    "brokeri": "broker",
    "brokerii": "broker",
    "brokerilor": "broker",
    "brokerul": "broker",
    "brokerului": "broker",
    "Br": "brom",
    "bromul": "brom",
    "bromului": "brom",
    "bronhia": "bronhie",
    "bronhiei": "bronhie",
    "bronhii": "bronhie",
    "bronhiile": "bronhie",
    "bronhiilor": "bronhie",
    "bronhopneumonia": "bronhopneumonie",
    "bronhopneumoniei": "bronhopneumonie",
    "bronhopneumonii": "bronhopneumonie",
    "bronhopneumoniile": "bronhopneumonie",
    "bronhopneumoniilor": "bronhopneumonie",
    "bronhopneumopatia": "bronhopneumopatie",
    "bronhopneumopatiei": "bronhopneumopatie",
    "bronhopneumopatii": "bronhopneumopatie",
    "bronhopneumopatiile": "bronhopneumopatie",
    "bronhopneumopatiilor": "bronhopneumopatie",
    "bronșica": "bronșic",
    "bronșică": "bronșic",
    "bronșice": "bronșic",
    "bronșicei": "bronșic",
    "bronșicele": "bronșic",
    "bronșicelor": "bronșic",
    "bronșici": "bronșic",
    "bronșicii": "bronșic",
    "bronșicilor": "bronșic",
    "bronșicul": "bronșic",
    "bronșicului": "bronșic",
    "bronșita": "bronșită",
    "bronșite": "bronșită",
    "bronșitei": "bronșită",
    "bronșitele": "bronșită",
    "bronșitelor": "bronșită",
    "bronzul": "bronz",
    "bronzului": "bronz",
    "bronzuri": "bronz",
    "bronzurile": "bronz",
    "bronzurilor": "bronz",
    "broșă": "broșa",
    "broșai": "broșa",
    "broșam": "broșa",
    "broșăm": "broșa",
    "broșând": "broșa",
    "broșându": "broșa",
    "broșară": "broșa",
    "broșarăm": "broșa",
    "broșarăți": "broșa",
    "broșase": "broșa",
    "broșasem": "broșa",
    "broșaseră": "broșa",
    "broșaserăm": "broșa",
    "broșaserăți": "broșa",
    "broșaseși": "broșa",
    "broșași": "broșa",
    "broșat": "broșa",
    "broșați": "broșa",
    "broșatu": "broșa",
    "broșau": "broșa",
    "broșează": "broșa",
    "broșez": "broșa",
    "broșeze": "broșa",
    "broșezi": "broșa",
    "nebroșând": "broșa",
    "nebroșându": "broșa",
    "nemaibroșând": "broșa",
    "nemaibroșându": "broșa",
    "broșa": "broșă",
    "broșe": "broșă",
    "broșei": "broșă",
    "broșele": "broșă",
    "broșelor": "broșă",
    "broșo": "broșă",
    "broșarea": "broșare",
    "broșări": "broșare",
    "broșării": "broșare",
    "broșările": "broșare",
    "broșata": "broșat",
    "broșată": "broșat",
    "broșate": "broșat",
    "broșatei": "broșat",
    "broșatele": "broșat",
    "broșatelor": "broșat",
    "broșați": "broșat",
    "broșații": "broșat",
    "broșaților": "broșat",
    "broșatul": "broșat",
    "broșatului": "broșat",
    "broșura": "broșură",
    "broșuri": "broșură",
    "broșurii": "broșură",
    "broșurile": "broșură",
    "broșurilor": "broșură",
    "broșurele": "broșurică",
    "broșurelei": "broșurică",
    "broșurelele": "broșurică",
    "broșurelelor": "broșurică",
    "broșurica": "broșurică",
    "bruftuluia": "bruftului",
    "bruftuluiai": "bruftului",
    "bruftuluiam": "bruftului",
    "bruftuluiască": "bruftului",
    "bruftuluiați": "bruftului",
    "bruftuluiau": "bruftului",
    "bruftuluiesc": "bruftului",
    "bruftuluiește": "bruftului",
    "bruftuluiești": "bruftului",
    "bruftuluii": "bruftului",
    "bruftuluim": "bruftului",
    "bruftuluind": "bruftului",
    "bruftuluindu": "bruftului",
    "bruftuluiră": "bruftului",
    "bruftuluirăm": "bruftului",
    "bruftuluirăți": "bruftului",
    "bruftuluise": "bruftului",
    "bruftuluisem": "bruftului",
    "bruftuluiseră": "bruftului",
    "bruftuluiserăm": "bruftului",
    "bruftuluiserăți": "bruftului",
    "bruftuluiseși": "bruftului",
    "bruftuluiși": "bruftului",
    "bruftuluit": "bruftului",
    "bruftuluiți": "bruftului",
    "bruftuluitu": "bruftului",
    "nebruftuluind": "bruftului",
    "nebruftuluindu": "bruftului",
    "nemaibruftuluind": "bruftului",
    "nemaibruftuluindu": "bruftului",
    "bruftuluiala": "bruftuluială",
    "bruftuluialo": "bruftuluială",
    "bruftuluieli": "bruftuluială",
    "bruftuluielii": "bruftuluială",
    "bruftuluielile": "bruftuluială",
    "bruftuluielilor": "bruftuluială",
    "bruftuluirea": "bruftuluire",
    "bruftuluireo": "bruftuluire",
    "bruftuluiri": "bruftuluire",
    "bruftuluirii": "bruftuluire",
    "bruftuluirile": "bruftuluire",
    "bruftuluirilor": "bruftuluire",
    "bruftuluita": "bruftuluit",
    "bruftuluită": "bruftuluit",
    "bruftuluite": "bruftuluit",
    "bruftuluitei": "bruftuluit",
    "bruftuluitele": "bruftuluit",
    "bruftuluitelor": "bruftuluit",
    "bruftuluiți": "bruftuluit",
    "bruftuluiții": "bruftuluit",
    "bruftuluiților": "bruftuluit",
    "bruftuluito": "bruftuluit",
    "bruftuluitul": "bruftuluit",
    "bruftuluitule": "bruftuluit",
    "bruftuluitului": "bruftuluit",
    "bruftuluitoarea": "bruftuluitoare",
    "bruftuluitoarei": "bruftuluitoare",
    "bruftuluitoarele": "bruftuluitoare",
    "bruftuluitoarelor": "bruftuluitoare",
    "bruftuluitoareo": "bruftuluitoare",
    "bruftuluitoare": "bruftuluitor",
    "bruftuluitoarea": "bruftuluitor",
    "bruftuluitoarei": "bruftuluitor",
    "bruftuluitoarele": "bruftuluitor",
    "bruftuluitoarelor": "bruftuluitor",
    "bruftuluitoareo": "bruftuluitor",
    "bruftuluitori": "bruftuluitor",
    "bruftuluitorii": "bruftuluitor",
    "bruftuluitorilor": "bruftuluitor",
    "bruftuluitorul": "bruftuluitor",
    "bruftuluitorule": "bruftuluitor",
    "bruftuluitorului": "bruftuluitor",
    "bruiai": "bruia",
    "bruiam": "bruia",
    "bruiară": "bruia",
    "bruiarăm": "bruia",
    "bruiarăți": "bruia",
    "bruiase": "bruia",
    "bruiasem": "bruia",
    "bruiaseră": "bruia",
    "bruiaserăm": "bruia",
    "bruiaserăți": "bruia",
    "bruiaseși": "bruia",
    "bruiași": "bruia",
    "bruiat": "bruia",
    "bruiați": "bruia",
    "bruiatu": "bruia",
    "bruiau": "bruia",
    "bruiază": "bruia",
    "bruie": "bruia",
    "bruiem": "bruia",
    "bruiez": "bruia",
    "bruieze": "bruia",
    "bruiezi": "bruia",
    "bruind": "bruia",
    "bruindu": "bruia",
    "nebruiind": "bruia",
    "nebruiindu": "bruia",
    "nemaibruiind": "bruia",
    "nemaibruiindu": "bruia",
    "bruiata": "bruiat",
    "bruiată": "bruiat",
    "bruiate": "bruiat",
    "bruiatei": "bruiat",
    "bruiatele": "bruiat",
    "bruiatelor": "bruiat",
    "bruiați": "bruiat",
    "bruiații": "bruiat",
    "bruiaților": "bruiat",
    "bruiatul": "bruiat",
    "bruiatului": "bruiat",
    "bruierea": "bruiere",
    "bruieri": "bruiere",
    "bruierii": "bruiere",
    "bruierile": "bruiere",
    "bruma": "brumă",
    "brume": "brumă",
    "brumei": "brumă",
    "brumele": "brumă",
    "brumelor": "brumă",
    "brumata": "brumat",
    "brumată": "brumat",
    "brumate": "brumat",
    "brumatei": "brumat",
    "brumatele": "brumat",
    "brumatelor": "brumat",
    "brumați": "brumat",
    "brumații": "brumat",
    "brumaților": "brumat",
    "brumatul": "brumat",
    "brumatului": "brumat",
    "brumata": "brumată",
    "brumate": "brumată",
    "brumatei": "brumată",
    "brumatele": "brumată",
    "brumatelor": "brumată",
    "bruna": "brun",
    "brună": "brun",
    "brune": "brun",
    "brunei": "brun",
    "brunele": "brun",
    "brunelor": "brun",
    "bruni": "brun",
    "brunii": "brun",
    "brunilor": "brun",
    "brunul": "brun",
    "brunului": "brun",
    "bruneta": "brunet",
    "brunetă": "brunet",
    "brunete": "brunet",
    "brunetei": "brunet",
    "brunetele": "brunet",
    "brunetelor": "brunet",
    "bruneți": "brunet",
    "bruneții": "brunet",
    "bruneților": "brunet",
    "bruneto": "brunet",
    "brunetul": "brunet",
    "brunetule": "brunet",
    "brunetului": "brunet",
    "bruneta": "brunetă",
    "brunete": "brunetă",
    "brunetei": "brunetă",
    "brunetele": "brunetă",
    "brunetelor": "brunetă",
    "bruneto": "brunetă",
    "brusca": "brusc",
    "bruscă": "brusc",
    "bruscul": "brusc",
    "bruscului": "brusc",
    "bruște": "brusc",
    "bruștei": "brusc",
    "bruștele": "brusc",
    "bruștelor": "brusc",
    "bruști": "brusc",
    "bruștii": "brusc",
    "bruștilor": "brusc",
    "bruscăm": "brusca",
    "bruscând": "brusca",
    "bruscându": "brusca",
    "bruscat": "brusca",
    "bruscați": "brusca",
    "bruscatu": "brusca",
    "bruschează": "brusca",
    "bruschez": "brusca",
    "bruscheze": "brusca",
    "bruschezi": "brusca",
    "nebruscând": "brusca",
    "nebruscându": "brusca",
    "nemaibruscând": "brusca",
    "nemaibruscându": "brusca",
    "bruscarea": "bruscare",
    "bruscări": "bruscare",
    "bruscării": "bruscare",
    "bruscările": "bruscare",
    "bruscata": "bruscat",
    "bruscată": "bruscat",
    "bruscate": "bruscat",
    "bruscatei": "bruscat",
    "bruscatele": "bruscat",
    "bruscatelor": "bruscat",
    "bruscați": "bruscat",
    "bruscații": "bruscat",
    "bruscaților": "bruscat",
    "bruscatul": "bruscat",
    "bruscatului": "bruscat",
    "bruscata": "bruscată",
    "bruscate": "bruscată",
    "bruscatei": "bruscată",
    "bruscatele": "bruscată",
    "bruscatelor": "bruscată",
    "bruschețea": "bruschețe",
    "bruscheți": "bruschețe",
    "bruscheții": "bruschețe",
    "bruschețile": "bruschețe",
    "bruscheților": "bruschețe",
    "bruta": "brut",
    "brută": "brut",
    "brute": "brut",
    "brutei": "brut",
    "brutele": "brut",
    "brutelor": "brut",
    "bruți": "brut",
    "bruții": "brut",
    "bruților": "brut",
    "brutul": "brut",
    "brutului": "brut",
    "bruta": "brută",
    "brute": "brută",
    "brutei": "brută",
    "brutele": "brută",
    "brutelor": "brută",
    "brutala": "brutal",
    "brutală": "brutal",
    "brutale": "brutal",
    "brutalei": "brutal",
    "brutalele": "brutal",
    "brutalelor": "brutal",
    "brutali": "brutal",
    "brutalii": "brutal",
    "brutalilor": "brutal",
    "brutalul": "brutal",
    "brutalului": "brutal",
    "brutalitatea": "brutalitate",
    "brutalități": "brutalitate",
    "brutalității": "brutalitate",
    "brutalitățile": "brutalitate",
    "brutalităților": "brutalitate",
    "buba": "bubă",
    "bube": "bubă",
    "bubei": "bubă",
    "bubele": "bubă",
    "bubelor": "bubă",
    "buba-neagră": "bubă-neagră",
    "bubei-negre": "bubă-neagră",
    "bubele-negre": "bubă-neagră",
    "bubelor-negre": "bubă-neagră",
    "bube-negre": "bubă-neagră",
    "buboaie": "buboi",
    "buboaiele": "buboi",
    "buboaielor": "buboi",
    "buboiul": "buboi",
    "buboiului": "buboi",
    "bubuia": "bubui",
    "bubuiai": "bubui",
    "bubuiam": "bubui",
    "bubuiască": "bubui",
    "bubuiați": "bubui",
    "bubuiau": "bubui",
    "bubuiesc": "bubui",
    "bubuiește": "bubui",
    "bubuiești": "bubui",
    "bubuii": "bubui",
    "bubuim": "bubui",
    "bubuind": "bubui",
    "bubuindu": "bubui",
    "bubuiră": "bubui",
    "bubuirăm": "bubui",
    "bubuirăți": "bubui",
    "bubuise": "bubui",
    "bubuisem": "bubui",
    "bubuiseră": "bubui",
    "bubuiserăm": "bubui",
    "bubuiserăți": "bubui",
    "bubuiseși": "bubui",
    "bubuiși": "bubui",
    "bubuit": "bubui",
    "bubuiți": "bubui",
    "bubuitu": "bubui",
    "nebubuind": "bubui",
    "nebubuindu": "bubui",
    "nemaibubuind": "bubui",
    "nemaibubuindu": "bubui",
    "bubuiala": "bubuială",
    "bubuialo": "bubuială",
    "bubuieli": "bubuială",
    "bubuielii": "bubuială",
    "bubuielile": "bubuială",
    "bubuielilor": "bubuială",
    "bubuirea": "bubuire",
    "bubuireo": "bubuire",
    "bubuiri": "bubuire",
    "bubuirii": "bubuire",
    "bubuirile": "bubuire",
    "bubuirilor": "bubuire",
    "bubuita": "bubuit",
    "bubuită": "bubuit",
    "bubuite": "bubuit",
    "bubuiți": "bubuit",
    "bubuiții": "bubuit",
    "bubuiților": "bubuit",
    "bubuitul": "bubuit",
    "bubuitule": "bubuit",
    "bubuitului": "bubuit",
    "bubuitoare": "bubuitor",
    "bubuitoarea": "bubuitor",
    "bubuitoarei": "bubuitor",
    "bubuitoarele": "bubuitor",
    "bubuitoarelor": "bubuitor",
    "bubuitori": "bubuitor",
    "bubuitorii": "bubuitor",
    "bubuitorilor": "bubuitor",
    "bubuitorul": "bubuitor",
    "bubuitorule": "bubuitor",
    "bubuitorului": "bubuitor",
    "bubuitura": "bubuitură",
    "bubuituri": "bubuitură",
    "bubuiturii": "bubuitură",
    "bubuiturile": "bubuitură",
    "bubuiturilor": "bubuitură",
    "buburuza": "buburuză",
    "buburuze": "buburuză",
    "buburuzei": "buburuză",
    "buburuzele": "buburuză",
    "buburuzelor": "buburuză",
    "buca": "bucă",
    "buci": "bucă",
    "bucii": "bucă",
    "bucile": "bucă",
    "bucilor": "bucă",
    "buco": "bucă",
    "bucala": "bucal",
    "bucală": "bucal",
    "bucale": "bucal",
    "bucalei": "bucal",
    "bucalele": "bucal",
    "bucalelor": "bucal",
    "bucali": "bucal",
    "bucalii": "bucal",
    "bucalilor": "bucal",
    "bucalul": "bucal",
    "bucalului": "bucal",
    "buc.": "bucată",
    "bucata": "bucată",
    "bucate": "bucată",
    "bucatele": "bucată",
    "bucatelor": "bucată",
    "bucăți": "bucată",
    "bucății": "bucată",
    "bucățile": "bucată",
    "bucăților": "bucată",
    "bucato": "bucată",
    "bucătari": "bucătar",
    "bucătarii": "bucătar",
    "bucătarilor": "bucătar",
    "bucătarul": "bucătar",
    "bucătarului": "bucătar",
    "bucătăreasa": "bucătăreasă",
    "bucătărese": "bucătăreasă",
    "bucătăresei": "bucătăreasă",
    "bucătăresele": "bucătăreasă",
    "bucătăreselor": "bucătăreasă",
    "bucătăria": "bucătărie",
    "bucătăriei": "bucătărie",
    "bucătării": "bucătărie",
    "bucătăriile": "bucătărie",
    "bucătăriilor": "bucătărie",
    "bucătărio": "bucătărie",
    "bucățele": "bucățică",
    "bucățelei": "bucățică",
    "bucățelele": "bucățică",
    "bucățelelor": "bucățică",
    "bucățica": "bucățică",
    "bucățico": "bucățică",
    "buceaua": "bucea",
    "bucele": "bucea",
    "bucelei": "bucea",
    "bucelele": "bucea",
    "bucelelor": "bucea",
    "buchea": "buche",
    "buchi": "buche",
    "buchii": "buche",
    "buchile": "buche",
    "buchilor": "buche",
    "buchete": "buchet",
    "buchetele": "buchet",
    "buchetelor": "buchet",
    "buchetul": "buchet",
    "buchetule": "buchet",
    "buchetului": "buchet",
    "buchețele": "buchețel",
    "buchețelele": "buchețel",
    "buchețelelor": "buchețel",
    "buchețelul": "buchețel",
    "buchețelule": "buchețel",
    "buchețelului": "buchețel",
    "buchetiera": "buchetieră",
    "buchetiere": "buchetieră",
    "buchetierei": "buchetieră",
    "buchetierele": "buchetieră",
    "buchetierelor": "buchetieră",
    "buchiseala": "buchiseală",
    "buchiseli": "buchiseală",
    "buchiselii": "buchiseală",
    "buchiselile": "buchiseală",
    "buchisirea": "buchisire",
    "buchisiri": "buchisire",
    "buchisirii": "buchisire",
    "buchisirile": "buchisire",
    "buchisita": "buchisit",
    "buchisită": "buchisit",
    "buchisite": "buchisit",
    "buchisitei": "buchisit",
    "buchisitele": "buchisit",
    "buchisitelor": "buchisit",
    "buchisiți": "buchisit",
    "buchisiții": "buchisit",
    "buchisiților": "buchisit",
    "buchisitul": "buchisit",
    "buchisitului": "buchisit",
    "buciume": "bucium",
    "buciumele": "bucium",
    "buciumelor": "bucium",
    "buciumul": "bucium",
    "buciumului": "bucium",
    "bucium": "buciuma",
    "buciumă": "buciuma",
    "buciumai": "buciuma",
    "buciumam": "buciuma",
    "buciumăm": "buciuma",
    "buciumând": "buciuma",
    "buciumându": "buciuma",
    "buciumară": "buciuma",
    "buciumarăm": "buciuma",
    "buciumarăți": "buciuma",
    "buciumase": "buciuma",
    "buciumasem": "buciuma",
    "buciumaseră": "buciuma",
    "buciumaserăm": "buciuma",
    "buciumaserăți": "buciuma",
    "buciumaseși": "buciuma",
    "buciumași": "buciuma",
    "buciumat": "buciuma",
    "buciumați": "buciuma",
    "buciumatu": "buciuma",
    "buciumau": "buciuma",
    "buciume": "buciuma",
    "buciumi": "buciuma",
    "nebuciumând": "buciuma",
    "nebuciumându": "buciuma",
    "nemaibuciumând": "buciuma",
    "nemaibuciumându": "buciuma",
    "buciumarea": "buciumare",
    "buciumări": "buciumare",
    "buciumării": "buciumare",
    "buciumările": "buciumare",
    "buciumata": "buciumat",
    "buciumată": "buciumat",
    "buciumate": "buciumat",
    "buciumatei": "buciumat",
    "buciumatele": "buciumat",
    "buciumatelor": "buciumat",
    "buciumați": "buciumat",
    "buciumații": "buciumat",
    "buciumaților": "buciumat",
    "buciumatul": "buciumat",
    "buciumatului": "buciumat",
    "bucla": "buclă",
    "bucle": "buclă",
    "buclei": "buclă",
    "buclele": "buclă",
    "buclelor": "buclă",
    "buclo": "buclă",
    "bucoavna": "bucoavnă",
    "bucoavne": "bucoavnă",
    "bucoavnei": "bucoavnă",
    "bucoavnele": "bucoavnă",
    "bucoavnelor": "bucoavnă",
    "bucolica": "bucolică",
    "bucolice": "bucolică",
    "bucolicei": "bucolică",
    "bucolicele": "bucolică",
    "bucolicelor": "bucolică",
    "Bucovină": "Bucovina",
    "Bucovine": "Bucovina",
    "Bucovinei": "Bucovina",
    "bucovineana": "bucovinean",
    "bucovineană": "bucovinean",
    "bucovineanul": "bucovinean",
    "bucovineanului": "bucovinean",
    "bucovinene": "bucovinean",
    "bucovinenei": "bucovinean",
    "bucovinenele": "bucovinean",
    "bucovinenelor": "bucovinean",
    "bucovineni": "bucovinean",
    "bucovinenii": "bucovinean",
    "bucovinenilor": "bucovinean",
    "bucovineanca": "bucovineancă",
    "bucovinence": "bucovineancă",
    "bucovinencei": "bucovineancă",
    "bucovinencele": "bucovineancă",
    "bucovinencelor": "bucovineancă",
    "bucșa": "bucșă",
    "bucșe": "bucșă",
    "bucșei": "bucșă",
    "bucșele": "bucșă",
    "bucșelor": "bucșă",
    "bucur": "bucura",
    "bucură": "bucura",
    "bucurai": "bucura",
    "bucuram": "bucura",
    "bucurăm": "bucura",
    "bucurând": "bucura",
    "bucurându": "bucura",
    "bucurară": "bucura",
    "bucurarăm": "bucura",
    "bucurarăți": "bucura",
    "bucurase": "bucura",
    "bucurasem": "bucura",
    "bucuraseră": "bucura",
    "bucuraserăm": "bucura",
    "bucuraserăți": "bucura",
    "bucuraseși": "bucura",
    "bucurași": "bucura",
    "bucurat": "bucura",
    "bucurați": "bucura",
    "bucuratu": "bucura",
    "bucurau": "bucura",
    "bucure": "bucura",
    "bucuri": "bucura",
    "nebucurând": "bucura",
    "nebucurându": "bucura",
    "nemaibucurând": "bucura",
    "nemaibucurându": "bucura",
    "bucurarea": "bucurare",
    "bucurareo": "bucurare",
    "bucurări": "bucurare",
    "bucurării": "bucurare",
    "bucurările": "bucurare",
    "bucurărilor": "bucurare",
    "bucurata": "bucurat",
    "bucurată": "bucurat",
    "bucurate": "bucurat",
    "bucuratei": "bucurat",
    "bucuratele": "bucurat",
    "bucuratelor": "bucurat",
    "bucurați": "bucurat",
    "bucurații": "bucurat",
    "bucuraților": "bucurat",
    "bucurato": "bucurat",
    "bucuratul": "bucurat",
    "bucuratule": "bucurat",
    "bucuratului": "bucurat",
    "bucureșteana": "bucureștean",
    "bucureșteană": "bucureștean",
    "bucureșteanul": "bucureștean",
    "bucureșteanului": "bucureștean",
    "bucureștene": "bucureștean",
    "bucureștenei": "bucureștean",
    "bucureștenele": "bucureștean",
    "bucureștenelor": "bucureștean",
    "bucureșteni": "bucureștean",
    "bucureștenii": "bucureștean",
    "bucureștenilor": "bucureștean",
    "bucureșteanca": "bucureșteancă",
    "bucureștence": "bucureșteancă",
    "bucureștencei": "bucureșteancă",
    "bucureștencele": "bucureșteancă",
    "bucureștencelor": "bucureșteancă",
    "Bucureștii": "București",
    "Bucureștilor": "București",
    "Bucureștiul": "București",
    "Bucureștiului": "București",
    "bucuria": "bucurie",
    "bucuriei": "bucurie",
    "bucurii": "bucurie",
    "bucuriile": "bucurie",
    "bucuriilor": "bucurie",
    "bucurio": "bucurie",
    "bucuroasa": "bucuros",
    "bucuroasă": "bucuros",
    "bucuroase": "bucuros",
    "bucuroasei": "bucuros",
    "bucuroasele": "bucuros",
    "bucuroaselor": "bucuros",
    "bucuroaso": "bucuros",
    "bucuroși": "bucuros",
    "bucuroșii": "bucuros",
    "bucuroșilor": "bucuros",
    "bucurosul": "bucuros",
    "bucurosule": "bucuros",
    "bucurosului": "bucuros",
    "Budapestă": "Budapesta",
    "Budapeste": "Budapesta",
    "Budapestei": "Budapesta",
    "budapestană": "budapestan",
    "budapestanii": "budapestan",
    "budismul": "budism",
    "budismului": "budism",
    "budoare": "budoar",
    "budoarele": "budoar",
    "budoarelor": "budoar",
    "budoarul": "budoar",
    "budoarului": "budoar",
    "bufa": "buf",
    "bufă": "buf",
    "bufe": "buf",
    "bufei": "buf",
    "bufele": "buf",
    "bufelor": "buf",
    "bufi": "buf",
    "bufii": "buf",
    "bufilor": "buf",
    "buful": "buf",
    "bufului": "buf",
    "bufanta": "bufant",
    "bufantă": "bufant",
    "bufante": "bufant",
    "bufantei": "bufant",
    "bufantele": "bufant",
    "bufantelor": "bufant",
    "bufanți": "bufant",
    "bufanții": "bufant",
    "bufanților": "bufant",
    "bufantul": "bufant",
    "bufantului": "bufant",
    "bufete": "bufet",
    "bufetele": "bufet",
    "bufetelor": "bufet",
    "bufetul": "bufet",
    "bufetului": "bufet",
    "bufneala": "bufneală",
    "bufnealo": "bufneală",
    "bufneli": "bufneală",
    "bufnelii": "bufneală",
    "bufnelile": "bufneală",
    "bufnelilor": "bufneală",
    "bufnea": "bufni",
    "bufneai": "bufni",
    "bufneam": "bufni",
    "bufnească": "bufni",
    "bufneați": "bufni",
    "bufneau": "bufni",
    "bufnesc": "bufni",
    "bufnește": "bufni",
    "bufnești": "bufni",
    "bufnii": "bufni",
    "bufnim": "bufni",
    "bufnind": "bufni",
    "bufnindu": "bufni",
    "bufniră": "bufni",
    "bufnirăm": "bufni",
    "bufnirăți": "bufni",
    "bufnise": "bufni",
    "bufnisem": "bufni",
    "bufniseră": "bufni",
    "bufniserăm": "bufni",
    "bufniserăți": "bufni",
    "bufniseși": "bufni",
    "bufniși": "bufni",
    "bufnit": "bufni",
    "bufniți": "bufni",
    "bufnitu": "bufni",
    "nebufnind": "bufni",
    "nebufnindu": "bufni",
    "nemaibufnind": "bufni",
    "nemaibufnindu": "bufni",
    "bufnirea": "bufnire",
    "bufnireo": "bufnire",
    "bufniri": "bufnire",
    "bufnirii": "bufnire",
    "bufnirile": "bufnire",
    "bufnirilor": "bufnire",
    "bufniți": "bufnit",
    "bufniții": "bufnit",
    "bufniților": "bufnit",
    "bufnitul": "bufnit",
    "bufnitului": "bufnit",
    "bufnitura": "bufnitură",
    "bufnituri": "bufnitură",
    "bufniturii": "bufnitură",
    "bufniturile": "bufnitură",
    "bufniturilor": "bufnitură",
    "bufoni": "bufon",
    "bufonii": "bufon",
    "bufonilor": "bufon",
    "bufonul": "bufon",
    "bufonului": "bufon",
    "bugete": "buget",
    "bugetele": "buget",
    "bugetelor": "buget",
    "bugetul": "buget",
    "bugetului": "buget",
    "bugetara": "bugetar",
    "bugetară": "bugetar",
    "bugetare": "bugetar",
    "bugetarei": "bugetar",
    "bugetarele": "bugetar",
    "bugetarelor": "bugetar",
    "bugetari": "bugetar",
    "bugetarii": "bugetar",
    "bugetarilor": "bugetar",
    "bugetarul": "bugetar",
    "bugetarului": "bugetar",
    "buhul": "buh",
    "buhului": "buh",
    "buhuri": "buh",
    "buhurile": "buh",
    "buhurilor": "buh",
    "buhăia": "buhăi",
    "buhăiai": "buhăi",
    "buhăiam": "buhăi",
    "buhăiască": "buhăi",
    "buhăiați": "buhăi",
    "buhăiau": "buhăi",
    "buhăiesc": "buhăi",
    "buhăiește": "buhăi",
    "buhăiești": "buhăi",
    "buhăii": "buhăi",
    "buhăim": "buhăi",
    "buhăind": "buhăi",
    "buhăindu": "buhăi",
    "buhăiră": "buhăi",
    "buhăirăm": "buhăi",
    "buhăirăți": "buhăi",
    "buhăise": "buhăi",
    "buhăisem": "buhăi",
    "buhăiseră": "buhăi",
    "buhăiserăm": "buhăi",
    "buhăiserăți": "buhăi",
    "buhăiseși": "buhăi",
    "buhăiși": "buhăi",
    "buhăit": "buhăi",
    "buhăiți": "buhăi",
    "buhăitu": "buhăi",
    "nebuhăind": "buhăi",
    "nebuhăindu": "buhăi",
    "nemaibuhăind": "buhăi",
    "nemaibuhăindu": "buhăi",
    "buhăiala": "buhăială",
    "buhăialo": "buhăială",
    "buhăieli": "buhăială",
    "buhăielii": "buhăială",
    "buhăielile": "buhăială",
    "buhăielilor": "buhăială",
    "buhăirea": "buhăire",
    "buhăireo": "buhăire",
    "buhăiri": "buhăire",
    "buhăirii": "buhăire",
    "buhăirile": "buhăire",
    "buhăirilor": "buhăire",
    "buhăita": "buhăit",
    "buhăită": "buhăit",
    "buhăite": "buhăit",
    "buhăitei": "buhăit",
    "buhăitele": "buhăit",
    "buhăitelor": "buhăit",
    "buhăiți": "buhăit",
    "buhăiții": "buhăit",
    "buhăiților": "buhăit",
    "buhăito": "buhăit",
    "buhăitul": "buhăit",
    "buhăitule": "buhăit",
    "buhăitului": "buhăit",
    "buhăita": "buhăită",
    "buhăite": "buhăită",
    "buhăitei": "buhăită",
    "buhăitele": "buhăită",
    "buhăitelor": "buhăită",
    "buhăito": "buhăită",
    "buiandrugi": "buiandrug",
    "buiandrugii": "buiandrug",
    "buiandrugilor": "buiandrug",
    "buiandrugul": "buiandrug",
    "buiandrugului": "buiandrug",
    "buiestrași": "buiestraș",
    "buiestrașii": "buiestraș",
    "buiestrașilor": "buiestraș",
    "buiestrașul": "buiestraș",
    "buiestrașului": "buiestraș",
    "buiastra": "buiestru",
    "buiastră": "buiestru",
    "buiestre": "buiestru",
    "buiestrei": "buiestru",
    "buiestrele": "buiestru",
    "buiestrelor": "buiestru",
    "buieștri": "buiestru",
    "buieștrii": "buiestru",
    "buieștrilor": "buiestru",
    "buiestrul": "buiestru",
    "buiestrului": "buiestru",
    "buimaca": "buimac",
    "buimacă": "buimac",
    "buimace": "buimac",
    "buimacei": "buimac",
    "buimacele": "buimac",
    "buimacelor": "buimac",
    "buimaci": "buimac",
    "buimacii": "buimac",
    "buimacilor": "buimac",
    "buimacul": "buimac",
    "buimacului": "buimac",
    "buimăceala": "buimăceală",
    "buimăcealo": "buimăceală",
    "buimăceli": "buimăceală",
    "buimăcelii": "buimăceală",
    "buimăcelile": "buimăceală",
    "buimăcelilor": "buimăceală",
    "buimăcea": "buimăci",
    "buimăceai": "buimăci",
    "buimăceam": "buimăci",
    "buimăcească": "buimăci",
    "buimăceați": "buimăci",
    "buimăceau": "buimăci",
    "buimăcesc": "buimăci",
    "buimăcește": "buimăci",
    "buimăcești": "buimăci",
    "buimăcii": "buimăci",
    "buimăcim": "buimăci",
    "buimăcind": "buimăci",
    "buimăcindu": "buimăci",
    "buimăciră": "buimăci",
    "buimăcirăm": "buimăci",
    "buimăcirăți": "buimăci",
    "buimăcise": "buimăci",
    "buimăcisem": "buimăci",
    "buimăciseră": "buimăci",
    "buimăciserăm": "buimăci",
    "buimăciserăți": "buimăci",
    "buimăciseși": "buimăci",
    "buimăciși": "buimăci",
    "buimăcit": "buimăci",
    "buimăciți": "buimăci",
    "buimăcitu": "buimăci",
    "nebuimăcind": "buimăci",
    "nebuimăcindu": "buimăci",
    "nemaibuimăcind": "buimăci",
    "nemaibuimăcindu": "buimăci",
    "buimăcirea": "buimăcire",
    "buimăcireo": "buimăcire",
    "buimăciri": "buimăcire",
    "buimăcirii": "buimăcire",
    "buimăcirile": "buimăcire",
    "buimăcirilor": "buimăcire",
    "buimăcita": "buimăcit",
    "buimăcită": "buimăcit",
    "buimăcite": "buimăcit",
    "buimăcitei": "buimăcit",
    "buimăcitele": "buimăcit",
    "buimăcitelor": "buimăcit",
    "buimăciți": "buimăcit",
    "buimăciții": "buimăcit",
    "buimăciților": "buimăcit",
    "buimăcito": "buimăcit",
    "buimăcitul": "buimăcit",
    "buimăcitule": "buimăcit",
    "buimăcitului": "buimăcit",
    "bujia": "bujie",
    "bujiei": "bujie",
    "bujii": "bujie",
    "bujiile": "bujie",
    "bujiilor": "bujie",
    "bula": "bulă",
    "bule": "bulă",
    "bulei": "bulă",
    "bulele": "bulă",
    "bulelor": "bulă",
    "bulboana": "bulboană",
    "bulboane": "bulboană",
    "bulboanei": "bulboană",
    "bulboanele": "bulboană",
    "bulboanelor": "bulboană",
    "bulbuci": "bulbuc",
    "bulbucii": "bulbuc",
    "bulbucilor": "bulbuc",
    "bulbucul": "bulbuc",
    "bulbucului": "bulbuc",
    "bulbuc": "bulbuca",
    "bulbucă": "bulbuca",
    "bulbucai": "bulbuca",
    "bulbucam": "bulbuca",
    "bulbucăm": "bulbuca",
    "bulbucând": "bulbuca",
    "bulbucându": "bulbuca",
    "bulbucară": "bulbuca",
    "bulbucarăm": "bulbuca",
    "bulbucarăți": "bulbuca",
    "bulbucase": "bulbuca",
    "bulbucasem": "bulbuca",
    "bulbucaseră": "bulbuca",
    "bulbucaserăm": "bulbuca",
    "bulbucaserăți": "bulbuca",
    "bulbucaseși": "bulbuca",
    "bulbucași": "bulbuca",
    "bulbucat": "bulbuca",
    "bulbucați": "bulbuca",
    "bulbucatu": "bulbuca",
    "bulbucau": "bulbuca",
    "bulbuce": "bulbuca",
    "bulbuci": "bulbuca",
    "nebulbucând": "bulbuca",
    "nebulbucându": "bulbuca",
    "nemaibulbucând": "bulbuca",
    "nemaibulbucându": "bulbuca",
    "bulbucarea": "bulbucare",
    "bulbucări": "bulbucare",
    "bulbucării": "bulbucare",
    "bulbucările": "bulbucare",
    "bulbucata": "bulbucat",
    "bulbucată": "bulbucat",
    "bulbucate": "bulbucat",
    "bulbucatei": "bulbucat",
    "bulbucatele": "bulbucat",
    "bulbucatelor": "bulbucat",
    "bulbucați": "bulbucat",
    "bulbucații": "bulbucat",
    "bulbucaților": "bulbucat",
    "bulbucatul": "bulbucat",
    "bulbucatului": "bulbucat",
    "bulbucata": "bulbucată",
    "bulbucate": "bulbucată",
    "bulbucatei": "bulbucată",
    "bulbucatele": "bulbucată",
    "bulbucatelor": "bulbucată",
    "buldogi": "buldog",
    "buldogii": "buldog",
    "buldogilor": "buldog",
    "buldogul": "buldog",
    "buldogului": "buldog",
    "buldozere": "buldozer",
    "buldozerele": "buldozer",
    "buldozerelor": "buldozer",
    "buldozerul": "buldozer",
    "buldozerului": "buldozer",
    "buletine": "buletin",
    "buletinele": "buletin",
    "buletinelor": "buletin",
    "buletinul": "buletin",
    "buletinului": "buletin",
    "B.I.": "Buletin_de_Identitate",
    "Bd.": "bulevard",
    "bulevarde": "bulevard",
    "bulevardele": "bulevard",
    "bulevardelor": "bulevard",
    "bulevardul": "bulevard",
    "bulevardului": "bulevard",
    "bulevardiera": "bulevardier",
    "bulevardieră": "bulevardier",
    "bulevardiere": "bulevardier",
    "bulevardierei": "bulevardier",
    "bulevardierele": "bulevardier",
    "bulevardierelor": "bulevardier",
    "bulevardieri": "bulevardier",
    "bulevardierii": "bulevardier",
    "bulevardierilor": "bulevardier",
    "bulevardierul": "bulevardier",
    "bulevardierului": "bulevardier",
    "bd.": "bulevardul",
    "b-dul": "bulevardul",
    "bulgara": "bulgar",
    "bulgară": "bulgar",
    "bulgare": "bulgar",
    "bulgarei": "bulgar",
    "bulgarele": "bulgar",
    "bulgarelor": "bulgar",
    "bulgari": "bulgar",
    "bulgarii": "bulgar",
    "bulgarilor": "bulgar",
    "bulgarul": "bulgar",
    "bulgarului": "bulgar",
    "bulgărele": "bulgăre",
    "bulgărelui": "bulgăre",
    "bulgări": "bulgăre",
    "bulgării": "bulgăre",
    "bulgărilor": "bulgăre",
    "Bulgarie": "Bulgaria",
    "Bulgariei": "Bulgaria",
    "Bulgarii": "Bulgaria",
    "bulgăroaica": "bulgăroaică",
    "bulgăroaice": "bulgăroaică",
    "bulgăroaicei": "bulgăroaică",
    "bulgăroaicele": "bulgăroaică",
    "bulgăroaicelor": "bulgăroaică",
    "bulibășeala": "bulibășeală",
    "bulibășeli": "bulibășeală",
    "bulibășelii": "bulibășeală",
    "bulibășelile": "bulibășeală",
    "bulibășelilor": "bulibășeală",
    "buline": "bulin",
    "bulinele": "bulin",
    "bulinelor": "bulin",
    "bulinul": "bulin",
    "bulinului": "bulin",
    "bulionul": "bulion",
    "bulionului": "bulion",
    "buloane": "bulon",
    "buloanele": "bulon",
    "buloanelor": "bulon",
    "bulonul": "bulon",
    "bulonului": "bulon",
    "bulucul": "buluc",
    "bulucului": "buluc",
    "bulucuri": "buluc",
    "bulucurile": "buluc",
    "bulucurilor": "buluc",
    "bulumaci": "bulumac",
    "bulumacii": "bulumac",
    "bulumacilor": "bulumac",
    "bulumacul": "bulumac",
    "bulumacului": "bulumac",
    "bulversă": "bulversa",
    "bulversai": "bulversa",
    "bulversam": "bulversa",
    "bulversăm": "bulversa",
    "bulversând": "bulversa",
    "bulversându": "bulversa",
    "bulversară": "bulversa",
    "bulversarăm": "bulversa",
    "bulversarăți": "bulversa",
    "bulversase": "bulversa",
    "bulversasem": "bulversa",
    "bulversaseră": "bulversa",
    "bulversaserăm": "bulversa",
    "bulversaserăți": "bulversa",
    "bulversaseși": "bulversa",
    "bulversași": "bulversa",
    "bulversat": "bulversa",
    "bulversați": "bulversa",
    "bulversatu": "bulversa",
    "bulversau": "bulversa",
    "bulversează": "bulversa",
    "bulversez": "bulversa",
    "bulverseze": "bulversa",
    "bulversezi": "bulversa",
    "bulversarea": "bulversare",
    "bulversări": "bulversare",
    "bulversării": "bulversare",
    "bulversările": "bulversare",
    "bulversata": "bulversat",
    "bulversată": "bulversat",
    "bulversate": "bulversat",
    "bulversatei": "bulversat",
    "bulversatele": "bulversat",
    "bulversatelor": "bulversat",
    "bulversați": "bulversat",
    "bulversații": "bulversat",
    "bulversaților": "bulversat",
    "bulversatul": "bulversat",
    "bulversatului": "bulversat",
    "bulzi": "bulz",
    "bulzii": "bulz",
    "bulzilor": "bulz",
    "bulzul": "bulz",
    "bulzului": "bulz",
    "bumb.": "bumbac",
    "bumbacul": "bumbac",
    "bumbacului": "bumbac",
    "bumerangul": "bumerang",
    "bumerangului": "bumerang",
    "bumeranguri": "bumerang",
    "bumerangurile": "bumerang",
    "bumerangurilor": "bumerang",
    "buna": "bun",
    "bună": "bun",
    "bune": "bun",
    "bunei": "bun",
    "bunele": "bun",
    "bunelor": "bun",
    "buni": "bun",
    "bunii": "bun",
    "bunilor": "bun",
    "bunul": "bun",
    "bunului": "bun",
    "bunuri": "bun",
    "bunurile": "bun",
    "bunurilor": "bun",
    "buna": "bună",
    "bune": "bună",
    "bunei": "bună",
    "bunele": "bună",
    "bunelor": "bună",
    "buna-credință": "bună-credință",
    "bunei-credințe": "bună-credință",
    "buna-cuviință": "bună-cuviință",
    "bunei-cuviințe": "bună-cuviință",
    "bunăstarea": "bunăstare",
    "bunăstareo": "bunăstare",
    "bunăstări": "bunăstare",
    "bunăstării": "bunăstare",
    "bunăstările": "bunăstare",
    "bunăstărilor": "bunăstare",
    "bunăștiința": "bunăștiință",
    "bunăștiințe": "bunăștiință",
    "bunăștiinței": "bunăștiință",
    "bunăștiințele": "bunăștiință",
    "bunăștiințelor": "bunăștiință",
    "bunătatea": "bunătate",
    "bunătateo": "bunătate",
    "bunătăți": "bunătate",
    "bunătății": "bunătate",
    "bunătățile": "bunătate",
    "bunătăților": "bunătate",
    "bunăvoia": "bunăvoie",
    "bunăvoința": "bunăvoință",
    "bunăvoințe": "bunăvoință",
    "bunăvoinței": "bunăvoință",
    "bunăvoințele": "bunăvoință",
    "bunăvoințelor": "bunăvoință",
    "buncăre": "buncăr",
    "buncărele": "buncăr",
    "buncărelor": "buncăr",
    "buncărul": "buncăr",
    "buncărului": "buncăr",
    "bungândind": "bungândi",
    "bungândit": "bungândi",
    "bungânditoare": "bungânditor",
    "bunul-gust": "bun-gust",
    "bunului-gust": "bun-gust",
    "bunică-": "bunic",
    "bunici": "bunic",
    "bunicii": "bunic",
    "bunicilor": "bunic",
    "bunicul": "bunic",
    "bunicule": "bunic",
    "bunicului": "bunic",
    "bunica": "bunică",
    "bunică-": "bunică",
    "bunice": "bunică",
    "bunici": "bunică",
    "bunicii": "bunică",
    "bunicile": "bunică",
    "bunicilor": "bunică",
    "bunul-plac": "bun-plac",
    "bunului-plac": "bun-plac",
    "bunul-simț": "bun-simț",
    "bunului-simț": "bun-simț",
    "bunuța": "bunuț",
    "bunuță": "bunuț",
    "bunuțe": "bunuț",
    "bunuței": "bunuț",
    "bunuțele": "bunuț",
    "bunuțelor": "bunuț",
    "bunuți": "bunuț",
    "bunuții": "bunuț",
    "bunuților": "bunuț",
    "bunuțul": "bunuț",
    "bunuțului": "bunuț",
    "burdușeala": "burdușeală",
    "burdușeli": "burdușeală",
    "burdușelii": "burdușeală",
    "burdușelile": "burdușeală",
    "burdușea": "burduși",
    "burdușeai": "burduși",
    "burdușeam": "burduși",
    "burdușească": "burduși",
    "burdușeați": "burduși",
    "burdușeau": "burduși",
    "burdușesc": "burduși",
    "burdușește": "burduși",
    "burdușești": "burduși",
    "burdușii": "burduși",
    "burdușim": "burduși",
    "burdușind": "burduși",
    "burdușindu": "burduși",
    "burdușiră": "burduși",
    "burdușirăm": "burduși",
    "burdușirăți": "burduși",
    "burdușise": "burduși",
    "burdușisem": "burduși",
    "burdușiseră": "burduși",
    "burdușiserăm": "burduși",
    "burdușiserăți": "burduși",
    "burdușiseși": "burduși",
    "burdușiși": "burduși",
    "burdușit": "burduși",
    "burdușiți": "burduși",
    "burdușitu": "burduși",
    "neburdușind": "burduși",
    "neburdușindu": "burduși",
    "nemaiburdușind": "burduși",
    "nemaiburdușindu": "burduși",
    "burdușirea": "burdușire",
    "burdușiri": "burdușire",
    "burdușirii": "burdușire",
    "burdușirile": "burdușire",
    "burdușita": "burdușit",
    "burdușită": "burdușit",
    "burdușite": "burdușit",
    "burdușitei": "burdușit",
    "burdușitele": "burdușit",
    "burdușitelor": "burdușit",
    "burdușiți": "burdușit",
    "burdușiții": "burdușit",
    "burdușiților": "burdușit",
    "burdușitul": "burdușit",
    "burdușitului": "burdușit",
    "buretul": "buret",
    "buretului": "buret",
    "buretele": "burete",
    "buretelui": "burete",
    "bureți": "burete",
    "bureții": "burete",
    "bureților": "burete",
    "burgul": "burg",
    "burgului": "burg",
    "burguri": "burg",
    "burgurile": "burg",
    "burgurilor": "burg",
    "burghezi": "burghez",
    "burghezii": "burghez",
    "burghezilor": "burghez",
    "burghezul": "burghez",
    "burghezului": "burghez",
    "burgheza": "burgheză",
    "burgheze": "burgheză",
    "burghezei": "burgheză",
    "burghezele": "burgheză",
    "burghezelor": "burgheză",
    "burghezia": "burghezie",
    "burgheziei": "burghezie",
    "burghezii": "burghezie",
    "burgheziile": "burghezie",
    "burgheziilor": "burghezie",
    "burghezo-democratică": "burghezo-democratic",
    "burghezo-democratice": "burghezo-democratic",
    "burghezo-democratici": "burghezo-democratic",
    "burghezo-moșierească": "burghezo-moșieresc",
    "burghezo-moșierești": "burghezo-moșieresc",
    "burghezo-moșierimea": "burghezo-moșierime",
    "burghezo-moșierimi": "burghezo-moșierime",
    "burghezo-moșierimii": "burghezo-moșierime",
    "burghie": "burghiu",
    "burghiele": "burghiu",
    "burghielor": "burghiu",
    "burghiul": "burghiu",
    "burghiului": "burghiu",
    "burice": "buric",
    "buricele": "buric",
    "buricelor": "buric",
    "buricul": "buric",
    "buricului": "buric",
    "burlaci": "burlac",
    "burlacii": "burlac",
    "burlacilor": "burlac",
    "burlacul": "burlac",
    "burlacului": "burlac",
    "burlane": "burlan",
    "burlanele": "burlan",
    "burlanelor": "burlan",
    "burlanul": "burlan",
    "burlanule": "burlan",
    "burlanului": "burlan",
    "burlesca": "burlesc",
    "burlescul": "burlesc",
    "burlescului": "burlesc",
    "burlești": "burlesc",
    "burleștii": "burlesc",
    "burleștile": "burlesc",
    "burleștilor": "burlesc",
    "burnițai": "burnița",
    "burnițam": "burnița",
    "burnițăm": "burnița",
    "burnițând": "burnița",
    "burnițându": "burnița",
    "burnițară": "burnița",
    "burnițarăm": "burnița",
    "burnițarăți": "burnița",
    "burnițase": "burnița",
    "burnițasem": "burnița",
    "burnițaseră": "burnița",
    "burnițaserăm": "burnița",
    "burnițaserăți": "burnița",
    "burnițaseși": "burnița",
    "burnițași": "burnița",
    "burnițat": "burnița",
    "burnițați": "burnița",
    "burnițatu": "burnița",
    "burnițau": "burnița",
    "burnițe": "burnița",
    "burnițează": "burnița",
    "burnițez": "burnița",
    "burnițeze": "burnița",
    "burnițezi": "burnița",
    "neburnițând": "burnița",
    "neburnițându": "burnița",
    "nemaiburnițând": "burnița",
    "nemaiburnițându": "burnița",
    "burnița": "burniță",
    "burnițe": "burniță",
    "burniței": "burniță",
    "burnițele": "burniță",
    "burnițelor": "burniță",
    "burnițarea": "burnițare",
    "burnițări": "burnițare",
    "burnițării": "burnițare",
    "burnițările": "burnițare",
    "burnițata": "burnițat",
    "burnițată": "burnițat",
    "burnițate": "burnițat",
    "burnițatei": "burnițat",
    "burnițatele": "burnițat",
    "burnițatelor": "burnițat",
    "burnițați": "burnițat",
    "burnițații": "burnițat",
    "burnițaților": "burnițat",
    "burnițatul": "burnițat",
    "burnițatului": "burnițat",
    "bursa": "bursă",
    "burse": "bursă",
    "bursei": "bursă",
    "bursele": "bursă",
    "burselor": "bursă",
    "BVB": "Bursa_de_Valori_București",
    "bursiera": "bursier",
    "bursieră": "bursier",
    "bursiere": "bursier",
    "bursierei": "bursier",
    "bursierele": "bursier",
    "bursierelor": "bursier",
    "bursieri": "bursier",
    "bursierii": "bursier",
    "bursierilor": "bursier",
    "bursierul": "bursier",
    "bursierului": "bursier",
    "bursiera": "bursieră",
    "bursiere": "bursieră",
    "bursierei": "bursieră",
    "bursierele": "bursieră",
    "bursierelor": "bursieră",
    "burta": "burtă",
    "burți": "burtă",
    "burții": "burtă",
    "burțile": "burtă",
    "burților": "burtă",
    "neburtăsimt": "burtăsimți",
    "buruiana": "buruiană",
    "buruiano": "buruiană",
    "buruieni": "buruiană",
    "buruienii": "buruiană",
    "buruienile": "buruiană",
    "buruienilor": "buruiană",
    "burzuluia": "burzului",
    "burzuluiai": "burzului",
    "burzuluiam": "burzului",
    "burzuluiască": "burzului",
    "burzuluiați": "burzului",
    "burzuluiau": "burzului",
    "burzuluiesc": "burzului",
    "burzuluiește": "burzului",
    "burzuluiești": "burzului",
    "burzuluii": "burzului",
    "burzuluim": "burzului",
    "burzuluind": "burzului",
    "burzuluindu": "burzului",
    "burzuluiră": "burzului",
    "burzuluirăm": "burzului",
    "burzuluirăți": "burzului",
    "burzuluise": "burzului",
    "burzuluisem": "burzului",
    "burzuluiseră": "burzului",
    "burzuluiserăm": "burzului",
    "burzuluiserăți": "burzului",
    "burzuluiseși": "burzului",
    "burzuluiși": "burzului",
    "burzuluit": "burzului",
    "burzuluiți": "burzului",
    "burzuluitu": "burzului",
    "neburzuluind": "burzului",
    "neburzuluindu": "burzului",
    "nemaiburzuluind": "burzului",
    "nemaiburzuluindu": "burzului",
    "burzuluiala": "burzuluială",
    "burzuluieli": "burzuluială",
    "burzuluielii": "burzuluială",
    "burzuluielile": "burzuluială",
    "burzuluirea": "burzuluire",
    "burzuluiri": "burzuluire",
    "burzuluirii": "burzuluire",
    "burzuluirile": "burzuluire",
    "burzuluita": "burzuluit",
    "burzuluită": "burzuluit",
    "burzuluite": "burzuluit",
    "burzuluitei": "burzuluit",
    "burzuluitele": "burzuluit",
    "burzuluitelor": "burzuluit",
    "burzuluiți": "burzuluit",
    "burzuluiții": "burzuluit",
    "burzuluiților": "burzuluit",
    "burzuluitul": "burzuluit",
    "burzuluitului": "burzuluit",
    "busculada": "busculadă",
    "busculade": "busculadă",
    "busculadei": "busculadă",
    "busculadele": "busculadă",
    "busculadelor": "busculadă",
    "bușeala": "bușeală",
    "bușealo": "bușeală",
    "bușeli": "bușeală",
    "bușelii": "bușeală",
    "bușelile": "bușeală",
    "bușelilor": "bușeală",
    "bușea": "buși",
    "bușeai": "buși",
    "bușeam": "buși",
    "bușească": "buși",
    "bușeați": "buși",
    "bușeau": "buși",
    "bușesc": "buși",
    "bușește": "buși",
    "bușești": "buși",
    "bușii": "buși",
    "bușim": "buși",
    "bușind": "buși",
    "bușindu": "buși",
    "bușiră": "buși",
    "bușirăm": "buși",
    "bușirăți": "buși",
    "bușise": "buși",
    "bușisem": "buși",
    "bușiseră": "buși",
    "bușiserăm": "buși",
    "bușiserăți": "buși",
    "bușiseși": "buși",
    "bușiși": "buși",
    "bușit": "buși",
    "bușiți": "buși",
    "bușitu": "buși",
    "nebușind": "buși",
    "nebușindu": "buși",
    "nemaibușind": "buși",
    "nemaibușindu": "buși",
    "bușirea": "bușire",
    "bușireo": "bușire",
    "bușiri": "bușire",
    "bușirii": "bușire",
    "bușirile": "bușire",
    "bușirilor": "bușire",
    "bușita": "bușit",
    "bușită": "bușit",
    "bușite": "bușit",
    "bușitei": "bușit",
    "bușitele": "bușit",
    "bușitelor": "bușit",
    "bușiți": "bușit",
    "bușiții": "bușit",
    "bușiților": "bușit",
    "bușito": "bușit",
    "bușitul": "bușit",
    "bușitule": "bușit",
    "bușitului": "bușit",
    "bușitura": "bușitură",
    "bușituri": "bușitură",
    "bușiturii": "bușitură",
    "bușiturile": "bușitură",
    "bușiturilor": "bușitură",
    "busola": "busolă",
    "busole": "busolă",
    "busolei": "busolă",
    "busolele": "busolă",
    "busolelor": "busolă",
    "bușoane": "bușon",
    "bușoanele": "bușon",
    "bușoanelor": "bușon",
    "bușonul": "bușon",
    "bușonului": "bușon",
    "bustul": "bust",
    "bustului": "bust",
    "busturi": "bust",
    "busturile": "bust",
    "busturilor": "bust",
    "bușteanul": "buștean",
    "bușteanului": "buștean",
    "bușteni": "buștean",
    "buștenii": "buștean",
    "buștenilor": "buștean",
    "busuiocul": "busuioc",
    "busuiocului": "busuioc",
    "butada": "butadă",
    "butade": "butadă",
    "butadei": "butadă",
    "butadele": "butadă",
    "butadelor": "butadă",
    "butășită": "butășit",
    "butășite": "butășit",
    "butășiți": "butășit",
    "butelia": "butelie",
    "buteliei": "butelie",
    "butelii": "butelie",
    "buteliile": "butelie",
    "buteliilor": "butelie",
    "butoaie": "butoi",
    "butoaiele": "butoi",
    "butoaielor": "butoi",
    "butoiul": "butoi",
    "butoiului": "butoi",
    "butoane": "buton",
    "butoanele": "buton",
    "butoanelor": "buton",
    "butonul": "buton",
    "butonule": "buton",
    "butonului": "buton",
    "butoniera": "butonieră",
    "butoniere": "butonieră",
    "butonierei": "butonieră",
    "butonierele": "butonieră",
    "butonierelor": "butonieră",
    "butuci": "butuc",
    "butucii": "butuc",
    "butucilor": "butuc",
    "butucul": "butuc",
    "butucului": "butuc",
    "butucănoasa": "butucănos",
    "butucănoasă": "butucănos",
    "butucănoase": "butucănos",
    "butucănoasei": "butucănos",
    "butucănoasele": "butucănos",
    "butucănoaselor": "butucănos",
    "butucănoaso": "butucănos",
    "butucănoși": "butucănos",
    "butucănoșii": "butucănos",
    "butucănoșilor": "butucănos",
    "butucănosul": "butucănos",
    "butucănosule": "butucănos",
    "butucănosului": "butucănos",
    "butura": "butură",
    "buturi": "butură",
    "buturii": "butură",
    "buturile": "butură",
    "buturilor": "butură",
    "buza": "buză",
    "buze": "buză",
    "buzei": "buză",
    "buzele": "buză",
    "buzelor": "buză",
    "buzo": "buză",
    "Buzăul": "Buzău",
    "Buzăului": "Buzău",
    "buzdugane": "buzdugan",
    "buzduganele": "buzdugan",
    "buzduganelor": "buzdugan",
    "buzduganul": "buzdugan",
    "buzduganului": "buzdugan",
    "buzunare": "buzunar",
    "buzunarele": "buzunar",
    "buzunarelor": "buzunar",
    "buzunarul": "buzunar",
    "buzunarule": "buzunar",
    "buzunarului": "buzunar",
    "buzunărea": "buzunări",
    "buzunăreai": "buzunări",
    "buzunăream": "buzunări",
    "buzunărească": "buzunări",
    "buzunăreați": "buzunări",
    "buzunăreau": "buzunări",
    "buzunăresc": "buzunări",
    "buzunărește": "buzunări",
    "buzunărești": "buzunări",
    "buzunării": "buzunări",
    "buzunărim": "buzunări",
    "buzunărind": "buzunări",
    "buzunărindu": "buzunări",
    "buzunăriră": "buzunări",
    "buzunărirăm": "buzunări",
    "buzunărirăți": "buzunări",
    "buzunărise": "buzunări",
    "buzunărisem": "buzunări",
    "buzunăriseră": "buzunări",
    "buzunăriserăm": "buzunări",
    "buzunăriserăți": "buzunări",
    "buzunăriseși": "buzunări",
    "buzunăriși": "buzunări",
    "buzunărit": "buzunări",
    "buzunăriți": "buzunări",
    "buzunăritu": "buzunări",
    "buzunărită": "buzunărit",
    "buzunărite": "buzunărit",
    "buzunăriți": "buzunărit",
    "buzunăritul": "buzunărit",
    "buzunăritului": "buzunărit",
    "c-": "că",
    "cabala": "cabală",
    "cabale": "cabală",
    "cabalei": "cabală",
    "cabalele": "cabală",
    "cabalelor": "cabală",
    "cabalo": "cabală",
    "cabalina": "cabalin",
    "cabalină": "cabalin",
    "cabaline": "cabalin",
    "cabalinei": "cabalin",
    "cabalinele": "cabalin",
    "cabalinelor": "cabalin",
    "cabalina": "cabalină",
    "cabaline": "cabalină",
    "cabalinei": "cabalină",
    "cabalinele": "cabalină",
    "cabalinelor": "cabalină",
    "cabalino": "cabalină",
    "cabalistă": "cabalist",
    "cabaliste": "cabalist",
    "cabalistei": "cabalist",
    "cabalistele": "cabalist",
    "cabalistelor": "cabalist",
    "cabaliști": "cabalist",
    "cabaliștii": "cabalist",
    "cabaliștilor": "cabalist",
    "cabalisto": "cabalist",
    "cabalistul": "cabalist",
    "cabalistule": "cabalist",
    "cabalistului": "cabalist",
    "cabalistica": "cabalistic",
    "cabalistică": "cabalistic",
    "cabalistice": "cabalistic",
    "cabalisticei": "cabalistic",
    "cabalisticele": "cabalistic",
    "cabalisticelor": "cabalistic",
    "cabalistici": "cabalistic",
    "cabalisticii": "cabalistic",
    "cabalisticilor": "cabalistic",
    "cabalistico": "cabalistic",
    "cabalisticul": "cabalistic",
    "cabalisticule": "cabalistic",
    "cabalisticului": "cabalistic",
    "cabana": "cabană",
    "cabane": "cabană",
    "cabanei": "cabană",
    "cabanele": "cabană",
    "cabanelor": "cabană",
    "cabano": "cabană",
    "cabanieri": "cabanier",
    "cabanierii": "cabanier",
    "cabanierilor": "cabanier",
    "cabanierul": "cabanier",
    "cabanierule": "cabanier",
    "cabanierului": "cabanier",
    "cabaniera": "cabanieră",
    "cabaniere": "cabanieră",
    "cabanierei": "cabanieră",
    "cabanierele": "cabanieră",
    "cabanierelor": "cabanieră",
    "cabaniero": "cabanieră",
    "cabanoși": "cabanos",
    "cabanoșii": "cabanos",
    "cabanoșilor": "cabanos",
    "cabanosul": "cabanos",
    "cabanosule": "cabanos",
    "cabanosului": "cabanos",
    "cabarete": "cabaret",
    "cabaretele": "cabaret",
    "cabaretelor": "cabaret",
    "cabaretul": "cabaret",
    "cabaretule": "cabaret",
    "cabaretului": "cabaret",
    "cabestane": "cabestan",
    "cabestanele": "cabestan",
    "cabestanelor": "cabestan",
    "cabestanul": "cabestan",
    "cabestanule": "cabestan",
    "cabestanului": "cabestan",
    "cabina": "cabină",
    "cabine": "cabină",
    "cabinei": "cabină",
    "cabinele": "cabină",
    "cabinelor": "cabină",
    "cabino": "cabină",
    "cab.": "cabinet",
    "cabinete": "cabinet",
    "cabinetele": "cabinet",
    "cabinetelor": "cabinet",
    "cabinetul": "cabinet",
    "cabinetule": "cabinet",
    "cabinetului": "cabinet",
    "cablaje": "cablaj",
    "cablajele": "cablaj",
    "cablajelor": "cablaj",
    "cablajul": "cablaj",
    "cablajule": "cablaj",
    "cablajului": "cablaj",
    "cablograma": "cablogramă",
    "cablograme": "cablogramă",
    "cablogramei": "cablogramă",
    "cablogramele": "cablogramă",
    "cablogramelor": "cablogramă",
    "cablogramo": "cablogramă",
    "cablul": "cablu",
    "cablule": "cablu",
    "cablului": "cablu",
    "cabluri": "cablu",
    "cablurile": "cablu",
    "cablurilor": "cablu",
    "cabotaje": "cabotaj",
    "cabotajele": "cabotaj",
    "cabotajelor": "cabotaj",
    "cabotajul": "cabotaj",
    "cabotajule": "cabotaj",
    "cabotajului": "cabotaj",
    "cabotiere": "cabotier",
    "cabotierele": "cabotier",
    "cabotierelor": "cabotier",
    "cabotierul": "cabotier",
    "cabotierule": "cabotier",
    "cabotierului": "cabotier",
    "cabotini": "cabotin",
    "cabotinii": "cabotin",
    "cabotinilor": "cabotin",
    "cabotinul": "cabotin",
    "cabotinule": "cabotin",
    "cabotinului": "cabotin",
    "cabotina": "cabotină",
    "cabotine": "cabotină",
    "cabotinei": "cabotină",
    "cabotinele": "cabotină",
    "cabotinelor": "cabotină",
    "cabotino": "cabotină",
    "cabotinaje": "cabotinaj",
    "cabotinajele": "cabotinaj",
    "cabotinajelor": "cabotinaj",
    "cabotinajul": "cabotinaj",
    "cabotinajule": "cabotinaj",
    "cabotinajului": "cabotinaj",
    "cabotinisme": "cabotinism",
    "cabotinismele": "cabotinism",
    "cabotinismelor": "cabotinism",
    "cabotinismul": "cabotinism",
    "cabotinismule": "cabotinism",
    "cabotinismului": "cabotinism",
    "cabră": "cabra",
    "cabrai": "cabra",
    "cabram": "cabra",
    "cabrăm": "cabra",
    "cabrând": "cabra",
    "cabrându": "cabra",
    "cabrară": "cabra",
    "cabrarăm": "cabra",
    "cabrarăți": "cabra",
    "cabrase": "cabra",
    "cabrasem": "cabra",
    "cabraseră": "cabra",
    "cabraserăm": "cabra",
    "cabraserăți": "cabra",
    "cabraseși": "cabra",
    "cabrași": "cabra",
    "cabrat": "cabra",
    "cabrați": "cabra",
    "cabratu": "cabra",
    "cabrau": "cabra",
    "cabrează": "cabra",
    "cabrez": "cabra",
    "cabreze": "cabra",
    "cabrezi": "cabra",
    "necabrând": "cabra",
    "necabrându": "cabra",
    "nemaicabrând": "cabra",
    "nemaicabrându": "cabra",
    "cabraje": "cabraj",
    "cabrajele": "cabraj",
    "cabrajelor": "cabraj",
    "cabrajul": "cabraj",
    "cabrajule": "cabraj",
    "cabrajului": "cabraj",
    "cabrarea": "cabrare",
    "cabrareo": "cabrare",
    "cabrări": "cabrare",
    "cabrării": "cabrare",
    "cabrările": "cabrare",
    "cabrărilor": "cabrare",
    "cabrată": "cabrat",
    "cabrate": "cabrat",
    "cabrați": "cabrat",
    "cabrioleta": "cabrioletă",
    "cabriolete": "cabrioletă",
    "cabrioletei": "cabrioletă",
    "cabrioletele": "cabrioletă",
    "cabrioletelor": "cabrioletă",
    "cabrioleto": "cabrioletă",
    "cacealmale": "cacealma",
    "cacealmalei": "cacealma",
    "cacealmalele": "cacealma",
    "cacealmalelor": "cacealma",
    "cacealmao": "cacealma",
    "cacealmaua": "cacealma",
    "căciula": "căciulă",
    "căciuli": "căciulă",
    "căciulii": "căciulă",
    "căciulile": "căciulă",
    "căciulilor": "căciulă",
    "căciulo": "căciulă",
    "căciuleala": "căciuleală",
    "căciulealo": "căciuleală",
    "căciuleli": "căciuleală",
    "căciulelii": "căciuleală",
    "căciulelile": "căciuleală",
    "căciulelilor": "căciuleală",
    "căciulea": "căciuli",
    "căciuleai": "căciuli",
    "căciuleam": "căciuli",
    "căciulească": "căciuli",
    "căciuleați": "căciuli",
    "căciuleau": "căciuli",
    "căciulesc": "căciuli",
    "căciulește": "căciuli",
    "căciulești": "căciuli",
    "căciulii": "căciuli",
    "căciulim": "căciuli",
    "căciulind": "căciuli",
    "căciulindu": "căciuli",
    "căciuliră": "căciuli",
    "căciulirăm": "căciuli",
    "căciulirăți": "căciuli",
    "căciulise": "căciuli",
    "căciulisem": "căciuli",
    "căciuliseră": "căciuli",
    "căciuliserăm": "căciuli",
    "căciuliserăți": "căciuli",
    "căciuliseși": "căciuli",
    "căciuliși": "căciuli",
    "căciulit": "căciuli",
    "căciuliți": "căciuli",
    "căciulitu": "căciuli",
    "necăciulind": "căciuli",
    "necăciulindu": "căciuli",
    "nemaicăciulind": "căciuli",
    "nemaicăciulindu": "căciuli",
    "căciulirea": "căciulire",
    "căciulireo": "căciulire",
    "căciuliri": "căciulire",
    "căciulirii": "căciulire",
    "căciulirile": "căciulire",
    "căciulirilor": "căciulire",
    "căciulită": "căciulit",
    "căciulite": "căciulit",
    "căciuliți": "căciulit",
    "căciulița": "căciuliță",
    "căciulițe": "căciuliță",
    "căciuliței": "căciuliță",
    "căciulițele": "căciuliță",
    "căciulițelor": "căciuliță",
    "căciulițo": "căciuliță",
    "căciuloaie": "căciuloi",
    "căciuloaiele": "căciuloi",
    "căciuloaielor": "căciuloi",
    "căciuloiul": "căciuloi",
    "căciuloiule": "căciuloi",
    "căciuloiului": "căciuloi",
    "cacofonica": "cacofonic",
    "cacofonică": "cacofonic",
    "cacofonice": "cacofonic",
    "cacofonicei": "cacofonic",
    "cacofonicele": "cacofonic",
    "cacofonicelor": "cacofonic",
    "cacofonici": "cacofonic",
    "cacofonicii": "cacofonic",
    "cacofonicilor": "cacofonic",
    "cacofonico": "cacofonic",
    "cacofonicul": "cacofonic",
    "cacofonicule": "cacofonic",
    "cacofonicului": "cacofonic",
    "cacofonia": "cacofonie",
    "cacofoniei": "cacofonie",
    "cacofonii": "cacofonie",
    "cacofoniile": "cacofonie",
    "cacofoniilor": "cacofonie",
    "cacofonio": "cacofonie",
    "cactuși": "cactus",
    "cactușii": "cactus",
    "cactușilor": "cactus",
    "cactusul": "cactus",
    "cactusule": "cactus",
    "cactusului": "cactus",
    "cada": "cadă",
    "cado": "cadă",
    "căzi": "cadă",
    "căzii": "cadă",
    "căzile": "cadă",
    "căzilor": "cadă",
    "cadâna": "cadână",
    "cadâne": "cadână",
    "cadânei": "cadână",
    "cadânele": "cadână",
    "cadânelor": "cadână",
    "cadâno": "cadână",
    "cadastră": "cadastra",
    "cadastrai": "cadastra",
    "cadastram": "cadastra",
    "cadastrăm": "cadastra",
    "cadastrând": "cadastra",
    "cadastrându": "cadastra",
    "cadastrară": "cadastra",
    "cadastrarăm": "cadastra",
    "cadastrarăți": "cadastra",
    "cadastrase": "cadastra",
    "cadastrasem": "cadastra",
    "cadastraseră": "cadastra",
    "cadastraserăm": "cadastra",
    "cadastraserăți": "cadastra",
    "cadastraseși": "cadastra",
    "cadastrași": "cadastra",
    "cadastrat": "cadastra",
    "cadastrați": "cadastra",
    "cadastratu": "cadastra",
    "cadastrau": "cadastra",
    "cadastrează": "cadastra",
    "cadastrez": "cadastra",
    "cadastreze": "cadastra",
    "cadastrezi": "cadastra",
    "necadastrând": "cadastra",
    "necadastrându": "cadastra",
    "nemaicadastrând": "cadastra",
    "nemaicadastrându": "cadastra",
    "cadastrala": "cadastral",
    "cadastrală": "cadastral",
    "cadastrale": "cadastral",
    "cadastralei": "cadastral",
    "cadastralele": "cadastral",
    "cadastralelor": "cadastral",
    "cadastrali": "cadastral",
    "cadastralii": "cadastral",
    "cadastralilor": "cadastral",
    "cadastralo": "cadastral",
    "cadastralul": "cadastral",
    "cadastralule": "cadastral",
    "cadastralului": "cadastral",
    "cadastrarea": "cadastrare",
    "cadastrareo": "cadastrare",
    "cadastrări": "cadastrare",
    "cadastrării": "cadastrare",
    "cadastrările": "cadastrare",
    "cadastrărilor": "cadastrare",
    "cadastrată": "cadastrat",
    "cadastrate": "cadastrat",
    "cadastrați": "cadastrat",
    "cadastrul": "cadastru",
    "cadastrule": "cadastru",
    "cadastrului": "cadastru",
    "cadaverica": "cadaveric",
    "cadaverică": "cadaveric",
    "cadaverice": "cadaveric",
    "cadavericei": "cadaveric",
    "cadavericele": "cadaveric",
    "cadavericelor": "cadaveric",
    "cadaverici": "cadaveric",
    "cadavericii": "cadaveric",
    "cadavericilor": "cadaveric",
    "cadaverico": "cadaveric",
    "cadavericul": "cadaveric",
    "cadavericule": "cadaveric",
    "cadavericului": "cadaveric",
    "cadavre": "cadavru",
    "cadavrele": "cadavru",
    "cadavrelor": "cadavru",
    "cadavrul": "cadavru",
    "cadavrule": "cadavru",
    "cadavrului": "cadavru",
    "cad": "cădea",
    "cadă": "cădea",
    "cade": "cădea",
    "cădeai": "cădea",
    "cădeam": "cădea",
    "cădeați": "cădea",
    "cădeau": "cădea",
    "cădem": "cădea",
    "cădeți": "cădea",
    "căzând": "cădea",
    "căzându": "cădea",
    "cazi": "cădea",
    "căzu": "cădea",
    "căzui": "cădea",
    "căzură": "cădea",
    "căzurăm": "cădea",
    "căzurăți": "cădea",
    "căzuse": "cădea",
    "căzusem": "cădea",
    "căzuseră": "cădea",
    "căzuserăm": "cădea",
    "căzuserăți": "cădea",
    "căzuseși": "cădea",
    "căzuși": "cădea",
    "căzut": "cădea",
    "căzutu": "cădea",
    "necăzând": "cădea",
    "necăzându": "cădea",
    "nemaicăzând": "cădea",
    "nemaicăzându": "cădea",
    "cădelniță": "cădelnița",
    "cădelnițai": "cădelnița",
    "cădelnițam": "cădelnița",
    "cădelnițăm": "cădelnița",
    "cădelnițând": "cădelnița",
    "cădelnițându": "cădelnița",
    "cădelnițară": "cădelnița",
    "cădelnițarăm": "cădelnița",
    "cădelnițarăți": "cădelnița",
    "cădelnițase": "cădelnița",
    "cădelnițasem": "cădelnița",
    "cădelnițaseră": "cădelnița",
    "cădelnițaserăm": "cădelnița",
    "cădelnițaserăți": "cădelnița",
    "cădelnițaseși": "cădelnița",
    "cădelnițași": "cădelnița",
    "cădelnițat": "cădelnița",
    "cădelnițați": "cădelnița",
    "cădelnițatu": "cădelnița",
    "cădelnițau": "cădelnița",
    "cădelnițează": "cădelnița",
    "cădelnițez": "cădelnița",
    "cădelnițeze": "cădelnița",
    "cădelnițezi": "cădelnița",
    "necădelnițând": "cădelnița",
    "necădelnițându": "cădelnița",
    "nemaicădelnițând": "cădelnița",
    "nemaicădelnițându": "cădelnița",
    "cădelnița": "cădelniță",
    "cădelnițe": "cădelniță",
    "cădelniței": "cădelniță",
    "cădelnițele": "cădelniță",
    "cădelnițelor": "cădelniță",
    "cădelnițo": "cădelniță",
    "cădelnițată": "cădelnițat",
    "cădelnițate": "cădelnițat",
    "cădelnițați": "cădelnițat",
    "cadență": "cadența",
    "cadențai": "cadența",
    "cadențam": "cadența",
    "cadențăm": "cadența",
    "cadențând": "cadența",
    "cadențându": "cadența",
    "cadențară": "cadența",
    "cadențarăm": "cadența",
    "cadențarăți": "cadența",
    "cadențase": "cadența",
    "cadențasem": "cadența",
    "cadențaseră": "cadența",
    "cadențaserăm": "cadența",
    "cadențaserăți": "cadența",
    "cadențaseși": "cadența",
    "cadențași": "cadența",
    "cadențat": "cadența",
    "cadențați": "cadența",
    "cadențatu": "cadența",
    "cadențau": "cadența",
    "cadențează": "cadența",
    "cadențez": "cadența",
    "cadențeze": "cadența",
    "cadențezi": "cadența",
    "necadențând": "cadența",
    "necadențându": "cadența",
    "nemaicadențând": "cadența",
    "nemaicadențându": "cadența",
    "cadența": "cadență",
    "cadențe": "cadență",
    "cadenței": "cadență",
    "cadențele": "cadență",
    "cadențelor": "cadență",
    "cadențo": "cadență",
    "cadențata": "cadențat",
    "cadențată": "cadențat",
    "cadențate": "cadențat",
    "cadențatei": "cadențat",
    "cadențatele": "cadențat",
    "cadențatelor": "cadențat",
    "cadențați": "cadențat",
    "cadențații": "cadențat",
    "cadențaților": "cadențat",
    "cadențato": "cadențat",
    "cadențatul": "cadențat",
    "cadențatule": "cadențat",
    "cadențatului": "cadențat",
    "căderea": "cădere",
    "cădereo": "cădere",
    "căderi": "cădere",
    "căderii": "cădere",
    "căderile": "cădere",
    "căderilor": "cădere",
    "cadeți": "cadet",
    "cadeții": "cadet",
    "cadeților": "cadet",
    "cadetul": "cadet",
    "cadetule": "cadet",
    "cadetului": "cadet",
    "cadii": "cadiu",
    "cadiii": "cadiu",
    "cadiilor": "cadiu",
    "cadiul": "cadiu",
    "cadiule": "cadiu",
    "cadiului": "cadiu",
    "cadmiai": "cadmia",
    "cadmiam": "cadmia",
    "cadmiară": "cadmia",
    "cadmiarăm": "cadmia",
    "cadmiarăți": "cadmia",
    "cadmiase": "cadmia",
    "cadmiasem": "cadmia",
    "cadmiaseră": "cadmia",
    "cadmiaserăm": "cadmia",
    "cadmiaserăți": "cadmia",
    "cadmiaseși": "cadmia",
    "cadmiași": "cadmia",
    "cadmiat": "cadmia",
    "cadmiați": "cadmia",
    "cadmiatu": "cadmia",
    "cadmiau": "cadmia",
    "cadmiază": "cadmia",
    "cadmie": "cadmia",
    "cadmiem": "cadmia",
    "cadmiez": "cadmia",
    "cadmieze": "cadmia",
    "cadmiezi": "cadmia",
    "cadmiind": "cadmia",
    "cadmiindu": "cadmia",
    "necadmiind": "cadmia",
    "necadmiindu": "cadmia",
    "nemaicadmiind": "cadmia",
    "nemaicadmiindu": "cadmia",
    "cadmiată": "cadmiat",
    "cadmiate": "cadmiat",
    "cadmiați": "cadmiat",
    "cadmierea": "cadmiere",
    "cadmiereo": "cadmiere",
    "cadmieri": "cadmiere",
    "cadmierii": "cadmiere",
    "cadmierile": "cadmiere",
    "cadmierilor": "cadmiere",
    "cadmiul": "cadmiu",
    "cadmiule": "cadmiu",
    "cadmiului": "cadmiu",
    "Cd": "cadmiu",
    "cadoul": "cadou",
    "cadoule": "cadou",
    "cadoului": "cadou",
    "cadouri": "cadou",
    "cadourile": "cadou",
    "cadourilor": "cadou",
    "cadră": "cadra",
    "cadrai": "cadra",
    "cadram": "cadra",
    "cadrăm": "cadra",
    "cadrând": "cadra",
    "cadrându": "cadra",
    "cadrară": "cadra",
    "cadrarăm": "cadra",
    "cadrarăți": "cadra",
    "cadrase": "cadra",
    "cadrasem": "cadra",
    "cadraseră": "cadra",
    "cadraserăm": "cadra",
    "cadraserăți": "cadra",
    "cadraseși": "cadra",
    "cadrași": "cadra",
    "cadrat": "cadra",
    "cadrați": "cadra",
    "cadratu": "cadra",
    "cadrau": "cadra",
    "cadrează": "cadra",
    "cadrez": "cadra",
    "cadreze": "cadra",
    "cadrezi": "cadra",
    "necadrând": "cadra",
    "necadrându": "cadra",
    "nemaicadrând": "cadra",
    "nemaicadrându": "cadra",
    "cadrane": "cadran",
    "cadranele": "cadran",
    "cadranelor": "cadran",
    "cadranul": "cadran",
    "cadranule": "cadran",
    "cadranului": "cadran",
    "cadrată": "cadrat",
    "cadrate": "cadrat",
    "cadrați": "cadrat",
    "cadrilul": "cadril",
    "cadrilule": "cadril",
    "cadrilului": "cadril",
    "cadriluri": "cadril",
    "cadrilurile": "cadril",
    "cadrilurilor": "cadril",
    "cadrilata": "cadrilat",
    "cadrilată": "cadrilat",
    "cadrilate": "cadrilat",
    "cadrilatei": "cadrilat",
    "cadrilatele": "cadrilat",
    "cadrilatelor": "cadrilat",
    "cadrilați": "cadrilat",
    "cadrilații": "cadrilat",
    "cadrilaților": "cadrilat",
    "cadrilato": "cadrilat",
    "cadrilatul": "cadrilat",
    "cadrilatule": "cadrilat",
    "cadrilatului": "cadrilat",
    "cadre": "cadru",
    "cadrele": "cadru",
    "cadrelor": "cadru",
    "cadrul": "cadru",
    "cadrule": "cadru",
    "cadrului": "cadru",
    "caduca": "caduc",
    "caducă": "caduc",
    "caduce": "caduc",
    "caducei": "caduc",
    "caducele": "caduc",
    "caducelor": "caduc",
    "caduci": "caduc",
    "caducii": "caduc",
    "caducilor": "caduc",
    "caduco": "caduc",
    "caducul": "caduc",
    "caducule": "caduc",
    "caducului": "caduc",
    "caducitatea": "caducitate",
    "caducitateo": "caducitate",
    "caducități": "caducitate",
    "caducității": "caducitate",
    "caducitățile": "caducitate",
    "caducităților": "caducitate",
    "cafeao": "cafea",
    "cafeaua": "cafea",
    "cafele": "cafea",
    "cafelei": "cafea",
    "cafelele": "cafea",
    "cafelelor": "cafea",
    "cafegioaica": "cafegioaică",
    "cafegioaice": "cafegioaică",
    "cafegioaicei": "cafegioaică",
    "cafegioaicele": "cafegioaică",
    "cafegioaicelor": "cafegioaică",
    "cafegioaico": "cafegioaică",
    "cafegii": "cafegiu",
    "cafegiii": "cafegiu",
    "cafegiilor": "cafegiu",
    "cafegiul": "cafegiu",
    "cafegiule": "cafegiu",
    "cafegiului": "cafegiu",
    "cafeina": "cafeină",
    "cafeine": "cafeină",
    "cafeinei": "cafeină",
    "cafeinele": "cafeină",
    "cafeinelor": "cafeină",
    "cafeino": "cafeină",
    "cafeluța": "cafeluță",
    "cafeluțe": "cafeluță",
    "cafeluței": "cafeluță",
    "cafeluțele": "cafeluță",
    "cafeluțelor": "cafeluță",
    "cafeluțo": "cafeluță",
    "cafeneao": "cafenea",
    "cafeneaua": "cafenea",
    "cafenele": "cafenea",
    "cafenelei": "cafenea",
    "cafenelele": "cafenea",
    "cafenelelor": "cafenea",
    "cafenie": "cafeniu",
    "cafenii": "cafeniu",
    "caftane": "caftan",
    "caftanele": "caftan",
    "caftanelor": "caftan",
    "caftanul": "caftan",
    "caftanule": "caftan",
    "caftanului": "caftan",
    "căftănele": "căftănel",
    "căftănelele": "căftănel",
    "căftănelelor": "căftănel",
    "căftănelul": "căftănel",
    "căftănelule": "căftănel",
    "căftănelului": "căftănel",
    "cagula": "cagulă",
    "cagule": "cagulă",
    "cagulei": "cagulă",
    "cagulele": "cagulă",
    "cagulelor": "cagulă",
    "cagulo": "cagulă",
    "cahla": "cahlă",
    "cahle": "cahlă",
    "cahlei": "cahlă",
    "cahlele": "cahlă",
    "cahlelor": "cahlă",
    "cahlo": "cahlă",
    "căia": "căi",
    "căiai": "căi",
    "căiam": "căi",
    "căiască": "căi",
    "căiați": "căi",
    "căiau": "căi",
    "căiesc": "căi",
    "căiește": "căi",
    "căiești": "căi",
    "căii": "căi",
    "căim": "căi",
    "căind": "căi",
    "căindu": "căi",
    "căiră": "căi",
    "căirăm": "căi",
    "căirăți": "căi",
    "căise": "căi",
    "căisem": "căi",
    "căiseră": "căi",
    "căiserăm": "căi",
    "căiserăți": "căi",
    "căiseși": "căi",
    "căiși": "căi",
    "căit": "căi",
    "căiți": "căi",
    "căitu": "căi",
    "necăind": "căi",
    "necăindu": "căi",
    "nemaicăind": "căi",
    "nemaicăindu": "căi",
    "caiao": "caia",
    "caiaua": "caia",
    "caiele": "caia",
    "caielei": "caia",
    "caielele": "caia",
    "caielelor": "caia",
    "caiace": "caiac",
    "caiacele": "caiac",
    "caiacelor": "caiac",
    "caiacul": "caiac",
    "caiacule": "caiac",
    "caiacului": "caiac",
    "caiafa": "caiafă",
    "caiafe": "caiafă",
    "caiafei": "caiafă",
    "caiafele": "caiafă",
    "caiafelor": "caiafă",
    "caiafo": "caiafă",
    "caice": "caic",
    "caicele": "caic",
    "caicelor": "caic",
    "caicul": "caic",
    "caicule": "caic",
    "caicului": "caic",
    "caiere": "caier",
    "caierele": "caier",
    "caierelor": "caier",
    "caierul": "caier",
    "caierule": "caier",
    "caierului": "caier",
    "caiete": "caiet",
    "caietele": "caiet",
    "caietelor": "caiet",
    "caietul": "caiet",
    "caietule": "caiet",
    "caietului": "caiet",
    "caiețele": "caiețel",
    "caiețelele": "caiețel",
    "caiețelelor": "caiețel",
    "caiețelul": "caiețel",
    "caiețelule": "caiețel",
    "caiețelului": "caiețel",
    "C.F.R.": "Căile_Ferate_Române",
    "Căilor_Ferate_Române": "Căile_Ferate_Române",
    "CFR": "Căile_Ferate_Române",
    "caimacul": "caimac",
    "caimacule": "caimac",
    "caimacului": "caimac",
    "caimacuri": "caimac",
    "caimacurile": "caimac",
    "caimacurilor": "caimac",
    "caimacami": "caimacam",
    "caimacamii": "caimacam",
    "caimacamilor": "caimacam",
    "caimacamul": "caimacam",
    "caimacamule": "caimacam",
    "caimacamului": "caimacam",
    "căimăcămia": "căimăcămie",
    "căimăcămiei": "căimăcămie",
    "căimăcămii": "căimăcămie",
    "căimăcămiile": "căimăcămie",
    "căimăcămiilor": "căimăcămie",
    "căimăcămio": "căimăcămie",
    "caimani": "caiman",
    "caimanii": "caiman",
    "caimanilor": "caiman",
    "caimanul": "caiman",
    "caimanule": "caiman",
    "caimanului": "caiman",
    "căină": "căina",
    "căinai": "căina",
    "căinam": "căina",
    "căinăm": "căina",
    "căinând": "căina",
    "căinându": "căina",
    "căinară": "căina",
    "căinarăm": "căina",
    "căinarăți": "căina",
    "căinase": "căina",
    "căinasem": "căina",
    "căinaseră": "căina",
    "căinaserăm": "căina",
    "căinaserăți": "căina",
    "căinaseși": "căina",
    "căinași": "căina",
    "căinat": "căina",
    "căinați": "căina",
    "căinatu": "căina",
    "căinau": "căina",
    "căinează": "căina",
    "căinez": "căina",
    "căineze": "căina",
    "căinezi": "căina",
    "necăinând": "căina",
    "necăinându": "căina",
    "nemaicăinând": "căina",
    "nemaicăinându": "căina",
    "căinarea": "căinare",
    "căinareo": "căinare",
    "căinări": "căinare",
    "căinării": "căinare",
    "căinările": "căinare",
    "căinărilor": "căinare",
    "căinată": "căinat",
    "căinate": "căinat",
    "căinați": "căinat",
    "câinele": "câine",
    "câinelui": "câine",
    "câini": "câine",
    "câinii": "câine",
    "câinilor": "câine",
    "câini-de-mare": "câine-de-mare",
    "câineasca": "câinesc",
    "câinească": "câinesc",
    "câineasco": "câinesc",
    "câinescul": "câinesc",
    "câinescule": "câinesc",
    "câinescului": "câinesc",
    "câinești": "câinesc",
    "câineștii": "câinesc",
    "câineștile": "câinesc",
    "câineștilor": "câinesc",
    "câinoșenia": "câinoșenie",
    "câinoșeniei": "câinoșenie",
    "câinoșenii": "câinoșenie",
    "câinoșeniile": "câinoșenie",
    "câinoșeniilor": "câinoșenie",
    "câinoșenio": "câinoșenie",
    "cainozoica": "cainozoic",
    "cainozoică": "cainozoic",
    "cainozoice": "cainozoic",
    "cainozoicei": "cainozoic",
    "cainozoicele": "cainozoic",
    "cainozoicelor": "cainozoic",
    "cainozoici": "cainozoic",
    "cainozoicii": "cainozoic",
    "cainozoicilor": "cainozoic",
    "cainozoico": "cainozoic",
    "cainozoicul": "cainozoic",
    "cainozoicule": "cainozoic",
    "cainozoicului": "cainozoic",
    "căința": "căință",
    "căințe": "căință",
    "căinței": "căință",
    "căințele": "căință",
    "căințelor": "căință",
    "căințo": "căință",
    "caiși": "cais",
    "caișii": "cais",
    "caișilor": "cais",
    "caisul": "cais",
    "caisule": "cais",
    "caisului": "cais",
    "caisa": "caisă",
    "caise": "caisă",
    "caisei": "caisă",
    "caisele": "caisă",
    "caiselor": "caisă",
    "caiso": "caisă",
    "căită": "căit",
    "căite": "căit",
    "căiți": "căit",
    "cai": "cal",
    "caii": "cal",
    "cailor": "cal",
    "calul": "cal",
    "calule": "cal",
    "calului": "cal",
    "CP": "Cal_Putere",
    "cală": "cala",
    "calai": "cala",
    "calam": "cala",
    "calăm": "cala",
    "calând": "cala",
    "calându": "cala",
    "calară": "cala",
    "calarăm": "cala",
    "calarăți": "cala",
    "calase": "cala",
    "calasem": "cala",
    "calaseră": "cala",
    "calaserăm": "cala",
    "calaserăți": "cala",
    "calaseși": "cala",
    "calași": "cala",
    "calat": "cala",
    "calați": "cala",
    "calatu": "cala",
    "calau": "cala",
    "calează": "cala",
    "calez": "cala",
    "caleze": "cala",
    "calezi": "cala",
    "necalând": "cala",
    "necalându": "cala",
    "nemaicalând": "cala",
    "nemaicalându": "cala",
    "cala": "cală",
    "cale": "cală",
    "calei": "cală",
    "calele": "cală",
    "calelor": "cală",
    "calo": "cală",
    "calabalâcul": "calabalâc",
    "calabalâcule": "calabalâc",
    "calabalâcului": "calabalâc",
    "calabalâcuri": "calabalâc",
    "calabalâcurile": "calabalâc",
    "calabalâcurilor": "calabalâc",
    "calafatul": "calafat",
    "calafatule": "calafat",
    "calafatului": "calafat",
    "calafaturi": "calafat",
    "calafaturile": "calafat",
    "calafaturilor": "calafat",
    "călăfătuia": "călăfătui",
    "călăfătuiai": "călăfătui",
    "călăfătuiam": "călăfătui",
    "călăfătuiască": "călăfătui",
    "călăfătuiați": "călăfătui",
    "călăfătuiau": "călăfătui",
    "călăfătuiesc": "călăfătui",
    "călăfătuiește": "călăfătui",
    "călăfătuiești": "călăfătui",
    "călăfătuii": "călăfătui",
    "călăfătuim": "călăfătui",
    "călăfătuind": "călăfătui",
    "călăfătuindu": "călăfătui",
    "călăfătuiră": "călăfătui",
    "călăfătuirăm": "călăfătui",
    "călăfătuirăți": "călăfătui",
    "călăfătuise": "călăfătui",
    "călăfătuisem": "călăfătui",
    "călăfătuiseră": "călăfătui",
    "călăfătuiserăm": "călăfătui",
    "călăfătuiserăți": "călăfătui",
    "călăfătuiseși": "călăfătui",
    "călăfătuiși": "călăfătui",
    "călăfătuit": "călăfătui",
    "călăfătuiți": "călăfătui",
    "călăfătuitu": "călăfătui",
    "necălăfătuind": "călăfătui",
    "necălăfătuindu": "călăfătui",
    "nemaicălăfătuind": "călăfătui",
    "nemaicălăfătuindu": "călăfătui",
    "călăfătuită": "călăfătuit",
    "călăfătuite": "călăfătuit",
    "călăfătuiți": "călăfătuit",
    "calaicanul": "calaican",
    "calaicanule": "calaican",
    "calaicanului": "calaican",
    "calaje": "calaj",
    "calajele": "calaj",
    "calajelor": "calaj",
    "calajul": "calaj",
    "calajule": "calaj",
    "calajului": "calaj",
    "calamburul": "calambur",
    "calamburule": "calambur",
    "calamburului": "calambur",
    "calambururi": "calambur",
    "calambururile": "calambur",
    "calambururilor": "calambur",
    "calamina": "calamină",
    "calamine": "calamină",
    "calaminei": "calamină",
    "calaminele": "calamină",
    "calaminelor": "calamină",
    "calamino": "calamină",
    "calamitatea": "calamitate",
    "calamitateo": "calamitate",
    "calamități": "calamitate",
    "calamității": "calamitate",
    "calamitățile": "calamitate",
    "calamităților": "calamitate",
    "calandre": "calandru",
    "calandrele": "calandru",
    "calandrelor": "calandru",
    "calandrul": "calandru",
    "calandrule": "calandru",
    "calandrului": "calandru",
    "calapoade": "calapod",
    "calapoadele": "calapod",
    "calapoadelor": "calapod",
    "calapodul": "calapod",
    "calapodule": "calapod",
    "calapodului": "calapod",
    "călărași": "călăraș",
    "călărașii": "călăraș",
    "călărașilor": "călăraș",
    "călărașul": "călăraș",
    "călărașule": "călăraș",
    "călărașului": "călăraș",
    "călăreața": "călăreață",
    "călăreațo": "călăreață",
    "călărețe": "călăreață",
    "călăreței": "călăreață",
    "călărețele": "călăreață",
    "călărețelor": "călăreață",
    "călăreți": "călăreț",
    "călăreții": "călăreț",
    "călăreților": "călăreț",
    "călărețul": "călăreț",
    "călărețule": "călăreț",
    "călărețului": "călăreț",
    "călărea": "călări",
    "călăreai": "călări",
    "călăream": "călări",
    "călărească": "călări",
    "călăreați": "călări",
    "călăreau": "călări",
    "călăresc": "călări",
    "călărește": "călări",
    "călărești": "călări",
    "călării": "călări",
    "călărim": "călări",
    "călărind": "călări",
    "călărindu": "călări",
    "călăriră": "călări",
    "călărirăm": "călări",
    "călărirăți": "călări",
    "călărise": "călări",
    "călărisem": "călări",
    "călăriseră": "călări",
    "călăriserăm": "călări",
    "călăriserăți": "călări",
    "călăriseși": "călări",
    "călăriși": "călări",
    "călărit": "călări",
    "călăriți": "călări",
    "călăritu": "călări",
    "necălărind": "călări",
    "necălărindu": "călări",
    "nemaicălărind": "călări",
    "nemaicălărindu": "călări",
    "călăria": "călărie",
    "călăriei": "călărie",
    "călării": "călărie",
    "călărio": "călărie",
    "călărimea": "călărime",
    "călărimeo": "călărime",
    "călărimi": "călărime",
    "călărimii": "călărime",
    "călărimile": "călărime",
    "călărimilor": "călărime",
    "călărită": "călărit",
    "călărite": "călărit",
    "călăriți": "călărit",
    "calată": "calat",
    "calate": "calat",
    "calați": "calat",
    "călătoarea": "călătoare",
    "călătoarei": "călătoare",
    "călătoarele": "călătoare",
    "călătoarelor": "călătoare",
    "călătoareo": "călătoare",
    "călătoare": "călător",
    "călătoarea": "călător",
    "călătoarei": "călător",
    "călătoarele": "călător",
    "călătoarelor": "călător",
    "călătoareo": "călător",
    "călători": "călător",
    "călătorii": "călător",
    "călătorilor": "călător",
    "călătorul": "călător",
    "călătorule": "călător",
    "călătorului": "călător",
    "călăuzitori": "călător",
    "călătorea": "călători",
    "călătoreai": "călători",
    "călătoream": "călători",
    "călătorească": "călători",
    "călătoreați": "călători",
    "călătoreau": "călători",
    "călătoresc": "călători",
    "călătorește": "călători",
    "călătorești": "călători",
    "călătorii": "călători",
    "călătorim": "călători",
    "călătorind": "călători",
    "călătorindu": "călători",
    "călătoriră": "călători",
    "călătorirăm": "călători",
    "călătorirăți": "călători",
    "călătorise": "călători",
    "călătorisem": "călători",
    "călătoriseră": "călători",
    "călătoriserăm": "călători",
    "călătoriserăți": "călători",
    "călătoriseși": "călători",
    "călătoriși": "călători",
    "călătorit": "călători",
    "călătoriți": "călători",
    "călătoritu": "călători",
    "necălătorind": "călători",
    "necălătorindu": "călători",
    "nemaicălătorind": "călători",
    "nemaicălătorindu": "călători",
    "călătoria": "călătorie",
    "călătoriei": "călătorie",
    "călătorii": "călătorie",
    "călătoriile": "călătorie",
    "călătoriilor": "călătorie",
    "călătorio": "călătorie",
    "călătorita": "călătorit",
    "călătorită": "călătorit",
    "călătorite": "călătorit",
    "călătoritei": "călătorit",
    "călătoritele": "călătorit",
    "călătoritelor": "călătorit",
    "călătoriți": "călătorit",
    "călătoriții": "călătorit",
    "călătoriților": "călătorit",
    "călătorito": "călătorit",
    "călătoritul": "călătorit",
    "călătoritule": "călătorit",
    "călătoritului": "călătorit",
    "călăi": "călău",
    "călăii": "călău",
    "călăilor": "călău",
    "călăul": "călău",
    "călăule": "călău",
    "călăului": "călău",
    "călăuza": "călăuză",
    "călăuze": "călăuză",
    "călăuzei": "călăuză",
    "călăuzele": "călăuză",
    "călăuzelor": "călăuză",
    "călăuzo": "călăuză",
    "călăuzea": "călăuzi",
    "călăuzeai": "călăuzi",
    "călăuzeam": "călăuzi",
    "călăuzească": "călăuzi",
    "călăuzeați": "călăuzi",
    "călăuzeau": "călăuzi",
    "călăuzesc": "călăuzi",
    "călăuzește": "călăuzi",
    "călăuzești": "călăuzi",
    "călăuzii": "călăuzi",
    "călăuzim": "călăuzi",
    "călăuzind": "călăuzi",
    "călăuzindu": "călăuzi",
    "călăuziră": "călăuzi",
    "călăuzirăm": "călăuzi",
    "călăuzirăți": "călăuzi",
    "călăuzise": "călăuzi",
    "călăuzisem": "călăuzi",
    "călăuziseră": "călăuzi",
    "călăuziserăm": "călăuzi",
    "călăuziserăți": "călăuzi",
    "călăuziseși": "călăuzi",
    "călăuziși": "călăuzi",
    "călăuzit": "călăuzi",
    "călăuziți": "călăuzi",
    "călăuzitu": "călăuzi",
    "necălăuzind": "călăuzi",
    "necălăuzindu": "călăuzi",
    "nemaicălăuzind": "călăuzi",
    "nemaicălăuzindu": "călăuzi",
    "călăuzirea": "călăuzire",
    "călăuzireo": "călăuzire",
    "călăuziri": "călăuzire",
    "călăuzirii": "călăuzire",
    "călăuzirile": "călăuzire",
    "călăuzirilor": "călăuzire",
    "călăuzita": "călăuzit",
    "călăuzită": "călăuzit",
    "călăuzite": "călăuzit",
    "călăuzitei": "călăuzit",
    "călăuzitele": "călăuzit",
    "călăuzitelor": "călăuzit",
    "călăuziți": "călăuzit",
    "călăuziții": "călăuzit",
    "călăuziților": "călăuzit",
    "călăuzito": "călăuzit",
    "călăuzitul": "călăuzit",
    "călăuzitule": "călăuzit",
    "călăuzitului": "călăuzit",
    "călăuzitoarea": "călăuzitoare",
    "călăuzitoarei": "călăuzitoare",
    "călăuzitoarele": "călăuzitoare",
    "călăuzitoarelor": "călăuzitoare",
    "călăuzitoareo": "călăuzitoare",
    "călăuzitoare": "călăuzitor",
    "călăuzitoarea": "călăuzitor",
    "călăuzitoarei": "călăuzitor",
    "călăuzitoarele": "călăuzitor",
    "călăuzitoarelor": "călăuzitor",
    "călăuzitoareo": "călăuzitor",
    "călăuzitorii": "călăuzitor",
    "călăuzitorilor": "călăuzitor",
    "călăuzitorul": "călăuzitor",
    "călăuzitorule": "călăuzitor",
    "călăuzitorului": "călăuzitor",
    "calcul": "calc",
    "calcului": "calc",
    "calcuri": "calc",
    "calcurile": "calc",
    "calcurilor": "calc",
    "calc": "călca",
    "calcă": "călca",
    "călcă": "călca",
    "călcai": "călca",
    "călcam": "călca",
    "călcăm": "călca",
    "călcând": "călca",
    "călcându": "călca",
    "călcară": "călca",
    "călcarăm": "călca",
    "călcarăți": "călca",
    "călcase": "călca",
    "călcasem": "călca",
    "călcaseră": "călca",
    "călcaserăm": "călca",
    "călcaserăți": "călca",
    "călcaseși": "călca",
    "călcași": "călca",
    "călcat": "călca",
    "călcați": "călca",
    "călcatu": "călca",
    "călcau": "călca",
    "calce": "călca",
    "calci": "călca",
    "necălcând": "călca",
    "necălcându": "călca",
    "nemaicălcând": "călca",
    "nemaicălcându": "călca",
    "călcâie": "călcâi",
    "călcâiele": "călcâi",
    "călcâielor": "călcâi",
    "călcâiul": "călcâi",
    "călcâiule": "călcâi",
    "călcâiului": "călcâi",
    "călcâiașe": "călcâiaș",
    "călcâiașele": "călcâiaș",
    "călcâiașelor": "călcâiaș",
    "călcâiașul": "călcâiaș",
    "călcâiașule": "călcâiaș",
    "călcâiașului": "călcâiaș",
    "calcani": "calcan",
    "calcanii": "calcan",
    "calcanilor": "calcan",
    "calcanul": "calcan",
    "calcanule": "calcan",
    "calcanului": "calcan",
    "calcanee": "calcaneu",
    "calcaneele": "calcaneu",
    "calcaneelor": "calcaneu",
    "calcaneul": "calcaneu",
    "calcaneule": "calcaneu",
    "calcaneului": "calcaneu",
    "calcare": "calcar",
    "calcarele": "calcar",
    "calcarelor": "calcar",
    "calcarul": "calcar",
    "calcarule": "calcar",
    "calcarului": "calcar",
    "călcarea": "călcare",
    "călcareo": "călcare",
    "călcări": "călcare",
    "călcării": "călcare",
    "călcările": "călcare",
    "călcărilor": "călcare",
    "călcată": "călcat",
    "călcate": "călcat",
    "călcați": "călcat",
    "călcatul": "călcat",
    "călcatule": "călcat",
    "călcatului": "călcat",
    "călcătoarea": "călcătoare",
    "călcătoarei": "călcătoare",
    "călcătoarele": "călcătoare",
    "călcătoarelor": "călcătoare",
    "călcătoareo": "călcătoare",
    "călcători": "călcător",
    "călcătorii": "călcător",
    "călcătorilor": "călcător",
    "călcătorul": "călcător",
    "călcătorule": "călcător",
    "călcătorului": "călcător",
    "călcătoreasa": "călcătoreasă",
    "călcătoreaso": "călcătoreasă",
    "călcătorese": "călcătoreasă",
    "călcătoresei": "călcătoreasă",
    "călcătoresele": "călcătoreasă",
    "călcătoreselor": "călcătoreasă",
    "călcătoria": "călcătorie",
    "călcătoriei": "călcătorie",
    "călcătorii": "călcătorie",
    "călcătoriile": "călcătorie",
    "călcătoriilor": "călcătorie",
    "călcătorio": "călcătorie",
    "călcătura": "călcătură",
    "călcături": "călcătură",
    "călcăturii": "călcătură",
    "călcăturile": "călcătură",
    "călcăturilor": "călcătură",
    "călcăturo": "călcătură",
    "calchiai": "calchia",
    "calchiam": "calchia",
    "calchiară": "calchia",
    "calchiarăm": "calchia",
    "calchiarăți": "calchia",
    "calchiase": "calchia",
    "calchiasem": "calchia",
    "calchiaseră": "calchia",
    "calchiaserăm": "calchia",
    "calchiaserăți": "calchia",
    "calchiaseși": "calchia",
    "calchiași": "calchia",
    "calchiat": "calchia",
    "calchiați": "calchia",
    "calchiatu": "calchia",
    "calchiau": "calchia",
    "calchiază": "calchia",
    "calchie": "calchia",
    "calchiem": "calchia",
    "calchiez": "calchia",
    "calchieze": "calchia",
    "calchiezi": "calchia",
    "calchiind": "calchia",
    "calchiindu": "calchia",
    "necalchiind": "calchia",
    "necalchiindu": "calchia",
    "nemaicalchiind": "calchia",
    "nemaicalchiindu": "calchia",
    "calchiată": "calchiat",
    "calchiate": "calchiat",
    "calchiați": "calchiat",
    "calcifiai": "calcifia",
    "calcifiam": "calcifia",
    "calcifiară": "calcifia",
    "calcifiarăm": "calcifia",
    "calcifiarăți": "calcifia",
    "calcifiase": "calcifia",
    "calcifiasem": "calcifia",
    "calcifiaseră": "calcifia",
    "calcifiaserăm": "calcifia",
    "calcifiaserăți": "calcifia",
    "calcifiaseși": "calcifia",
    "calcifiași": "calcifia",
    "calcifiat": "calcifia",
    "calcifiați": "calcifia",
    "calcifiatu": "calcifia",
    "calcifiau": "calcifia",
    "calcifiază": "calcifia",
    "calcifie": "calcifia",
    "calcifiem": "calcifia",
    "calcifiez": "calcifia",
    "calcifieze": "calcifia",
    "calcifiezi": "calcifia",
    "calcifiind": "calcifia",
    "calcifiindu": "calcifia",
    "necalcifiind": "calcifia",
    "necalcifiindu": "calcifia",
    "nemaicalcifiind": "calcifia",
    "nemaicalcifiindu": "calcifia",
    "calcifiata": "calcifiat",
    "calcifiată": "calcifiat",
    "calcifiate": "calcifiat",
    "calcifiatei": "calcifiat",
    "calcifiatele": "calcifiat",
    "calcifiatelor": "calcifiat",
    "calcifiați": "calcifiat",
    "calcifiații": "calcifiat",
    "calcifiaților": "calcifiat",
    "calcifiato": "calcifiat",
    "calcifiatul": "calcifiat",
    "calcifiatule": "calcifiat",
    "calcifiatului": "calcifiat",
    "calcific": "calcifica",
    "calcifică": "calcifica",
    "calcificai": "calcifica",
    "calcificam": "calcifica",
    "calcificăm": "calcifica",
    "calcificând": "calcifica",
    "calcificându": "calcifica",
    "calcificară": "calcifica",
    "calcificarăm": "calcifica",
    "calcificarăți": "calcifica",
    "calcificase": "calcifica",
    "calcificasem": "calcifica",
    "calcificaseră": "calcifica",
    "calcificaserăm": "calcifica",
    "calcificaserăți": "calcifica",
    "calcificaseși": "calcifica",
    "calcificași": "calcifica",
    "calcificat": "calcifica",
    "calcificați": "calcifica",
    "calcificatu": "calcifica",
    "calcificau": "calcifica",
    "calcifice": "calcifica",
    "calcifici": "calcifica",
    "necalcificând": "calcifica",
    "necalcificându": "calcifica",
    "nemaicalcificând": "calcifica",
    "nemaicalcificându": "calcifica",
    "calcificata": "calcificat",
    "calcificată": "calcificat",
    "calcificate": "calcificat",
    "calcificatei": "calcificat",
    "calcificatele": "calcificat",
    "calcificatelor": "calcificat",
    "calcificați": "calcificat",
    "calcificații": "calcificat",
    "calcificaților": "calcificat",
    "calcificato": "calcificat",
    "calcificatul": "calcificat",
    "calcificatule": "calcificat",
    "calcificatului": "calcificat",
    "calcină": "calcina",
    "calcinai": "calcina",
    "calcinam": "calcina",
    "calcinăm": "calcina",
    "calcinând": "calcina",
    "calcinându": "calcina",
    "calcinară": "calcina",
    "calcinarăm": "calcina",
    "calcinarăți": "calcina",
    "calcinase": "calcina",
    "calcinasem": "calcina",
    "calcinaseră": "calcina",
    "calcinaserăm": "calcina",
    "calcinaserăți": "calcina",
    "calcinaseși": "calcina",
    "calcinași": "calcina",
    "calcinat": "calcina",
    "calcinați": "calcina",
    "calcinatu": "calcina",
    "calcinau": "calcina",
    "calcinează": "calcina",
    "calcinez": "calcina",
    "calcineze": "calcina",
    "calcinezi": "calcina",
    "necalcinând": "calcina",
    "necalcinându": "calcina",
    "nemaicalcinând": "calcina",
    "nemaicalcinându": "calcina",
    "calcinata": "calcinat",
    "calcinată": "calcinat",
    "calcinate": "calcinat",
    "calcinatei": "calcinat",
    "calcinatele": "calcinat",
    "calcinatelor": "calcinat",
    "calcinați": "calcinat",
    "calcinații": "calcinat",
    "calcinaților": "calcinat",
    "calcinato": "calcinat",
    "calcinatul": "calcinat",
    "calcinatule": "calcinat",
    "calcinatului": "calcinat",
    "calcinatoarea": "calcinatoare",
    "calcinatoarei": "calcinatoare",
    "calcinatoarele": "calcinatoare",
    "calcinatoarelor": "calcinatoare",
    "calcinatoareo": "calcinatoare",
    "calcinatori": "calcinator",
    "calcinatorii": "calcinator",
    "calcinatorilor": "calcinator",
    "calcinatorul": "calcinator",
    "calcinatorule": "calcinator",
    "calcinatorului": "calcinator",
    "calcitul": "calcit",
    "calcitule": "calcit",
    "calcitului": "calcit",
    "Ca": "calciu",
    "calciul": "calciu",
    "calciule": "calciu",
    "calciului": "calciu",
    "calcografi": "calcograf",
    "calcografii": "calcograf",
    "calcografilor": "calcograf",
    "calcograful": "calcograf",
    "calcografule": "calcograf",
    "calcografului": "calcograf",
    "calcografia": "calcografie",
    "calcografiei": "calcografie",
    "calcografii": "calcografie",
    "calcografiile": "calcografie",
    "calcografiilor": "calcografie",
    "calcografio": "calcografie",
    "calcopirita": "calcopirită",
    "calcopirite": "calcopirită",
    "calcopiritei": "calcopirită",
    "calcopirito": "calcopirită",
    "calcule": "calcul",
    "calculele": "calcul",
    "calculelor": "calcul",
    "calculi": "calcul",
    "calculii": "calcul",
    "calculilor": "calcul",
    "calculul": "calcul",
    "calculule": "calcul",
    "calculului": "calcul",
    "calculă": "calcula",
    "calculai": "calcula",
    "calculam": "calcula",
    "calculăm": "calcula",
    "calculând": "calcula",
    "calculându": "calcula",
    "calculară": "calcula",
    "calcularăm": "calcula",
    "calcularăți": "calcula",
    "calculase": "calcula",
    "calculasem": "calcula",
    "calculaseră": "calcula",
    "calculaserăm": "calcula",
    "calculaserăți": "calcula",
    "calculaseși": "calcula",
    "calculași": "calcula",
    "calculat": "calcula",
    "calculați": "calcula",
    "calculatu": "calcula",
    "calculau": "calcula",
    "calculează": "calcula",
    "calculez": "calcula",
    "calculeze": "calcula",
    "calculezi": "calcula",
    "necalculând": "calcula",
    "necalculându": "calcula",
    "nemaicalculând": "calcula",
    "nemaicalculându": "calcula",
    "calculabila": "calculabil",
    "calculabilă": "calculabil",
    "calculabile": "calculabil",
    "calculabilei": "calculabil",
    "calculabilele": "calculabil",
    "calculabilelor": "calculabil",
    "calculabili": "calculabil",
    "calculabilii": "calculabil",
    "calculabililor": "calculabil",
    "calculabilo": "calculabil",
    "calculabilul": "calculabil",
    "calculabilule": "calculabil",
    "calculabilului": "calculabil",
    "calcularea": "calculare",
    "calculareo": "calculare",
    "calculări": "calculare",
    "calculării": "calculare",
    "calculările": "calculare",
    "calculărilor": "calculare",
    "calculata": "calculat",
    "calculată": "calculat",
    "calculate": "calculat",
    "calculatei": "calculat",
    "calculatele": "calculat",
    "calculatelor": "calculat",
    "calculați": "calculat",
    "calculații": "calculat",
    "calculaților": "calculat",
    "calculato": "calculat",
    "calculatul": "calculat",
    "calculatule": "calculat",
    "calculatului": "calculat",
    "calculația": "calculație",
    "calculației": "calculație",
    "calculații": "calculație",
    "calculațiile": "calculație",
    "calculațiilor": "calculație",
    "calculațio": "calculație",
    "calculatoarea": "calculatoare",
    "calculatoarei": "calculatoare",
    "calculatoarele": "calculatoare",
    "calculatoarelor": "calculatoare",
    "calculatoareo": "calculatoare",
    "calculatoare": "calculator",
    "calculatoarele": "calculator",
    "calculatoarelor": "calculator",
    "calculatori": "calculator",
    "calculatorii": "calculator",
    "calculatorilor": "calculator",
    "calculatorul": "calculator",
    "calculatorule": "calculator",
    "calculatorului": "calculator",
    "Calcuttă": "Calcutta",
    "Calcutte": "Calcutta",
    "Calcuttei": "Calcutta",
    "calda": "cald",
    "caldă": "cald",
    "calde": "cald",
    "caldei": "cald",
    "caldele": "cald",
    "caldelor": "cald",
    "caldo": "cald",
    "caldul": "cald",
    "caldule": "cald",
    "caldului": "cald",
    "calzi": "cald",
    "calzii": "cald",
    "calzilor": "cald",
    "caldarâmul": "caldarâm",
    "caldarâmule": "caldarâm",
    "caldarâmului": "caldarâm",
    "caldarâmuri": "caldarâm",
    "caldarâmurile": "caldarâm",
    "caldarâmurilor": "caldarâm",
    "căldărari": "căldărar",
    "căldărarii": "căldărar",
    "căldărarilor": "căldărar",
    "căldărarul": "căldărar",
    "căldărarule": "căldărar",
    "căldărarului": "căldărar",
    "căldarea": "căldare",
    "căldareo": "căldare",
    "căldări": "căldare",
    "căldării": "căldare",
    "căldările": "căldare",
    "căldărilor": "căldare",
    "căldăroaie": "căldăroi",
    "căldăroaiele": "căldăroi",
    "căldăroaielor": "căldăroi",
    "căldăroiul": "căldăroi",
    "căldăroiule": "căldăroi",
    "căldăroiului": "căldăroi",
    "căldărușa": "căldărușă",
    "căldărușe": "căldărușă",
    "căldărușei": "căldărușă",
    "căldărușele": "căldărușă",
    "căldărușelor": "căldărușă",
    "căldărușo": "căldărușă",
    "Căldărușanii": "Căldărușani",
    "Căldărușanilor": "Căldărușani",
    "Căldărușaniul": "Căldărușani",
    "Căldărușaniului": "Căldărușani",
    "căldicei": "căldicel",
    "căldiceii": "căldicel",
    "căldiceilor": "căldicel",
    "căldicele": "căldicel",
    "căldicelei": "căldicel",
    "căldicelele": "căldicel",
    "căldicelelor": "căldicel",
    "căldicelul": "căldicel",
    "căldicelule": "căldicel",
    "căldicelului": "căldicel",
    "căldicica": "căldicel",
    "căldicică": "căldicel",
    "căldicico": "căldicel",
    "căldișoara": "căldișor",
    "căldișoară": "căldișor",
    "căldișoare": "căldișor",
    "căldișoarei": "căldișor",
    "căldișoarele": "căldișor",
    "căldișoarelor": "căldișor",
    "căldișoaro": "căldișor",
    "căldișori": "căldișor",
    "căldișorii": "căldișor",
    "căldișorilor": "căldișor",
    "căldișorul": "căldișor",
    "căldișorule": "căldișor",
    "căldișorului": "căldișor",
    "căldura": "căldură",
    "călduri": "căldură",
    "căldurii": "căldură",
    "căldurile": "căldură",
    "căldurilor": "căldură",
    "călduro": "căldură",
    "căldurica": "căldurică",
    "căldurici": "căldurică",
    "călduricii": "căldurică",
    "călduricile": "căldurică",
    "călduricilor": "căldurică",
    "căldurico": "căldurică",
    "călduroasa": "călduros",
    "călduroasă": "călduros",
    "călduroase": "călduros",
    "călduroasei": "călduros",
    "călduroasele": "călduros",
    "călduroaselor": "călduros",
    "călduroaso": "călduros",
    "călduroși": "călduros",
    "călduroșii": "călduros",
    "călduroșilor": "călduros",
    "căldurosul": "călduros",
    "căldurosule": "călduros",
    "căldurosului": "călduros",
    "călduța": "călduț",
    "călduță": "călduț",
    "călduțe": "călduț",
    "călduței": "călduț",
    "călduțele": "călduț",
    "călduțelor": "călduț",
    "călduți": "călduț",
    "călduții": "călduț",
    "călduților": "călduț",
    "călduțo": "călduț",
    "călduțul": "călduț",
    "călduțule": "călduț",
    "călduțului": "călduț",
    "căi": "cale",
    "căii": "cale",
    "căile": "cale",
    "căilor": "cale",
    "calea": "cale",
    "caleo": "cale",
    "Cl.": "calea",
    "Căii_Lactee": "Calea_Lactee",
    "caleașca": "caleașcă",
    "caleașco": "caleașcă",
    "calești": "caleașcă",
    "caleștii": "caleașcă",
    "caleștile": "caleașcă",
    "caleștilor": "caleașcă",
    "caleidoscoape": "caleidoscop",
    "caleidoscoapele": "caleidoscop",
    "caleidoscoapelor": "caleidoscop",
    "caleidoscopul": "caleidoscop",
    "caleidoscopule": "caleidoscop",
    "caleidoscopului": "caleidoscop",
    "caleidoscopuri": "caleidoscop",
    "caleidoscopurile": "caleidoscop",
    "caleidoscopurilor": "caleidoscop",
    "calendare": "calendar",
    "calendarele": "calendar",
    "calendarelor": "calendar",
    "calendarul": "calendar",
    "calendarule": "calendar",
    "calendarului": "calendar",
    "calendaristica": "calendaristic",
    "calendaristică": "calendaristic",
    "calendaristice": "calendaristic",
    "calendaristicei": "calendaristic",
    "calendaristicele": "calendaristic",
    "calendaristicelor": "calendaristic",
    "calendaristici": "calendaristic",
    "calendaristicii": "calendaristic",
    "calendaristicilor": "calendaristic",
    "calendaristico": "calendaristic",
    "calendaristicul": "calendaristic",
    "calendaristicule": "calendaristic",
    "calendaristicului": "calendaristic",
    "calendele": "calende",
    "calendelor": "calende",
    "calfa": "calfă",
    "calfe": "calfă",
    "calfei": "calfă",
    "calfele": "calfă",
    "calfelor": "calfă",
    "calfo": "calfă",
    "calfată": "calfata",
    "calfatai": "calfata",
    "calfatam": "calfata",
    "calfatăm": "calfata",
    "calfatând": "calfata",
    "calfatându": "calfata",
    "calfatară": "calfata",
    "calfatarăm": "calfata",
    "calfatarăți": "calfata",
    "calfatase": "calfata",
    "calfatasem": "calfata",
    "calfataseră": "calfata",
    "calfataserăm": "calfata",
    "calfataserăți": "calfata",
    "calfataseși": "calfata",
    "calfatași": "calfata",
    "calfatat": "calfata",
    "calfatați": "calfata",
    "calfatatu": "calfata",
    "calfatau": "calfata",
    "calfatează": "calfata",
    "calfatez": "calfata",
    "calfateze": "calfata",
    "calfatezi": "calfata",
    "necalfatând": "calfata",
    "necalfatându": "calfata",
    "nemaicalfatând": "calfata",
    "nemaicalfatându": "calfata",
    "calfatată": "calfatat",
    "calfatate": "calfatat",
    "calfatați": "calfatat",
    "călea": "căli",
    "căleai": "căli",
    "căleam": "căli",
    "călească": "căli",
    "căleați": "căli",
    "căleau": "căli",
    "călesc": "căli",
    "călește": "căli",
    "călești": "căli",
    "călii": "căli",
    "călim": "căli",
    "călind": "căli",
    "călindu": "căli",
    "căliră": "căli",
    "călirăm": "căli",
    "călirăți": "căli",
    "călise": "căli",
    "călisem": "căli",
    "căliseră": "căli",
    "căliserăm": "căli",
    "căliserăți": "căli",
    "căliseși": "căli",
    "căliși": "căli",
    "călit": "căli",
    "căliți": "căli",
    "călitu": "căli",
    "necălind": "căli",
    "necălindu": "căli",
    "nemaicălind": "căli",
    "nemaicălindu": "căli",
    "calibră": "calibra",
    "calibrai": "calibra",
    "calibram": "calibra",
    "calibrăm": "calibra",
    "calibrând": "calibra",
    "calibrându": "calibra",
    "calibrară": "calibra",
    "calibrarăm": "calibra",
    "calibrarăți": "calibra",
    "calibrase": "calibra",
    "calibrasem": "calibra",
    "calibraseră": "calibra",
    "calibraserăm": "calibra",
    "calibraserăți": "calibra",
    "calibraseși": "calibra",
    "calibrași": "calibra",
    "calibrat": "calibra",
    "calibrați": "calibra",
    "calibratu": "calibra",
    "calibrau": "calibra",
    "calibrează": "calibra",
    "calibrez": "calibra",
    "calibreze": "calibra",
    "calibrezi": "calibra",
    "necalibrând": "calibra",
    "necalibrându": "calibra",
    "nemaicalibrând": "calibra",
    "nemaicalibrându": "calibra",
    "calibrarea": "calibrare",
    "calibrareo": "calibrare",
    "calibrări": "calibrare",
    "calibrării": "calibrare",
    "calibrările": "calibrare",
    "calibrărilor": "calibrare",
    "calibrată": "calibrat",
    "calibrate": "calibrat",
    "calibrați": "calibrat",
    "calibroare": "calibror",
    "calibroarea": "calibror",
    "calibroarei": "calibror",
    "calibroarele": "calibror",
    "calibroarelor": "calibror",
    "calibroareo": "calibror",
    "calibrori": "calibror",
    "calibrorii": "calibror",
    "calibrorilor": "calibror",
    "calibrorul": "calibror",
    "calibrorule": "calibror",
    "calibrorului": "calibror",
    "calibre": "calibru",
    "calibrele": "calibru",
    "calibrelor": "calibru",
    "calibrul": "calibru",
    "calibrule": "calibru",
    "calibrului": "calibru",
    "calica": "calic",
    "calică": "calic",
    "calice": "calic",
    "calicei": "calic",
    "calicele": "calic",
    "calicelor": "calic",
    "calici": "calic",
    "calicii": "calic",
    "calicilor": "calic",
    "calico": "calic",
    "calicul": "calic",
    "calicule": "calic",
    "calicului": "calic",
    "caliceasca": "calicesc",
    "calicească": "calicesc",
    "caliceasco": "calicesc",
    "calicescul": "calicesc",
    "calicescule": "calicesc",
    "calicescului": "calicesc",
    "calicești": "calicesc",
    "caliceștii": "calicesc",
    "caliceștile": "calicesc",
    "caliceștilor": "calicesc",
    "calicea": "calici",
    "caliceai": "calici",
    "caliceam": "calici",
    "calicească": "calici",
    "caliceați": "calici",
    "caliceau": "calici",
    "calicesc": "calici",
    "calicește": "calici",
    "calicești": "calici",
    "calicii": "calici",
    "calicim": "calici",
    "calicind": "calici",
    "calicindu": "calici",
    "caliciră": "calici",
    "calicirăm": "calici",
    "calicirăți": "calici",
    "calicise": "calici",
    "calicisem": "calici",
    "caliciseră": "calici",
    "caliciserăm": "calici",
    "caliciserăți": "calici",
    "caliciseși": "calici",
    "caliciși": "calici",
    "calicit": "calici",
    "caliciți": "calici",
    "calicitu": "calici",
    "necalicind": "calici",
    "necalicindu": "calici",
    "nemaicalicind": "calici",
    "nemaicalicindu": "calici",
    "calicirea": "calicire",
    "calicireo": "calicire",
    "caliciri": "calicire",
    "calicirii": "calicire",
    "calicirile": "calicire",
    "calicirilor": "calicire",
    "calicită": "calicit",
    "calicite": "calicit",
    "caliciți": "calicit",
    "calicii": "caliciu",
    "caliciile": "caliciu",
    "caliciilor": "caliciu",
    "caliciul": "caliciu",
    "caliciule": "caliciu",
    "caliciului": "caliciu",
    "califi": "calif",
    "califii": "calif",
    "califilor": "calif",
    "califul": "calif",
    "califule": "calif",
    "califului": "calif",
    "călifari": "călifar",
    "călifarii": "călifar",
    "călifarilor": "călifar",
    "călifarul": "călifar",
    "călifarule": "călifar",
    "călifarului": "călifar",
    "califate": "califat",
    "califatele": "califat",
    "califatelor": "califat",
    "califatul": "califat",
    "califatule": "califat",
    "califatului": "califat",
    "calific": "califica",
    "califică": "califica",
    "calificai": "califica",
    "calificam": "califica",
    "calificăm": "califica",
    "calificând": "califica",
    "calificându": "califica",
    "calificară": "califica",
    "calificarăm": "califica",
    "calificarăți": "califica",
    "calificase": "califica",
    "calificasem": "califica",
    "calificaseră": "califica",
    "calificaserăm": "califica",
    "calificaserăți": "califica",
    "calificaseși": "califica",
    "calificași": "califica",
    "calificat": "califica",
    "calificați": "califica",
    "calificatu": "califica",
    "calificau": "califica",
    "califice": "califica",
    "califici": "califica",
    "necalificând": "califica",
    "necalificându": "califica",
    "nemaicalificând": "califica",
    "nemaicalificându": "califica",
    "calificarea": "calificare",
    "calificareo": "calificare",
    "calificări": "calificare",
    "calificării": "calificare",
    "calificările": "calificare",
    "calificărilor": "calificare",
    "calificata": "calificat",
    "calificată": "calificat",
    "calificate": "calificat",
    "calificatei": "calificat",
    "calificatele": "calificat",
    "calificatelor": "calificat",
    "calificați": "calificat",
    "calificații": "calificat",
    "calificaților": "calificat",
    "calificato": "calificat",
    "calificatul": "calificat",
    "calificatule": "calificat",
    "calificatului": "calificat",
    "calificativa": "calificativ",
    "calificativă": "calificativ",
    "calificative": "calificativ",
    "calificativei": "calificativ",
    "calificativele": "calificativ",
    "calificativelor": "calificativ",
    "calificativi": "calificativ",
    "calificativii": "calificativ",
    "calificativilor": "calificativ",
    "calificativo": "calificativ",
    "calificativul": "calificativ",
    "calificativule": "calificativ",
    "calificativului": "calificativ",
    "Cal.": "California",
    "caligrafi": "caligraf",
    "caligrafii": "caligraf",
    "caligrafilor": "caligraf",
    "caligraful": "caligraf",
    "caligrafule": "caligraf",
    "caligrafului": "caligraf",
    "caligrafa": "caligrafă",
    "caligrafe": "caligrafă",
    "caligrafei": "caligrafă",
    "caligrafele": "caligrafă",
    "caligrafelor": "caligrafă",
    "caligrafo": "caligrafă",
    "caligrafiai": "caligrafia",
    "caligrafiam": "caligrafia",
    "caligrafiară": "caligrafia",
    "caligrafiarăm": "caligrafia",
    "caligrafiarăți": "caligrafia",
    "caligrafiase": "caligrafia",
    "caligrafiasem": "caligrafia",
    "caligrafiaseră": "caligrafia",
    "caligrafiaserăm": "caligrafia",
    "caligrafiaserăți": "caligrafia",
    "caligrafiaseși": "caligrafia",
    "caligrafiași": "caligrafia",
    "caligrafiat": "caligrafia",
    "caligrafiați": "caligrafia",
    "caligrafiatu": "caligrafia",
    "caligrafiau": "caligrafia",
    "caligrafiază": "caligrafia",
    "caligrafie": "caligrafia",
    "caligrafiem": "caligrafia",
    "caligrafiez": "caligrafia",
    "caligrafieze": "caligrafia",
    "caligrafiezi": "caligrafia",
    "caligrafiind": "caligrafia",
    "caligrafiindu": "caligrafia",
    "necaligrafiind": "caligrafia",
    "necaligrafiindu": "caligrafia",
    "nemaicaligrafiind": "caligrafia",
    "nemaicaligrafiindu": "caligrafia",
    "caligrafiată": "caligrafiat",
    "caligrafiate": "caligrafiat",
    "caligrafiați": "caligrafiat",
    "caligrafica": "caligrafic",
    "caligrafică": "caligrafic",
    "caligrafice": "caligrafic",
    "caligraficei": "caligrafic",
    "caligraficele": "caligrafic",
    "caligraficelor": "caligrafic",
    "caligrafici": "caligrafic",
    "caligraficii": "caligrafic",
    "caligraficilor": "caligrafic",
    "caligrafico": "caligrafic",
    "caligraficul": "caligrafic",
    "caligraficule": "caligrafic",
    "caligraficului": "caligrafic",
    "caligrafia": "caligrafie",
    "caligrafiei": "caligrafie",
    "caligrafii": "caligrafie",
    "caligrafiile": "caligrafie",
    "caligrafiilor": "caligrafie",
    "caligrafio": "caligrafie",
    "Călimăneștii": "Călimănești",
    "Călimăneștilor": "Călimănești",
    "Călimăneștiul": "Călimănești",
    "Călimăneștiului": "Călimănești",
    "călimara": "călimară",
    "călimări": "călimară",
    "călimării": "călimară",
    "călimările": "călimară",
    "călimărilor": "călimară",
    "călimaro": "călimară",
    "călirea": "călire",
    "călireo": "călire",
    "căliri": "călire",
    "călirii": "călire",
    "călirile": "călire",
    "călirilor": "călire",
    "călita": "călit",
    "călită": "călit",
    "călite": "călit",
    "călitei": "călit",
    "călitele": "călit",
    "călitelor": "călit",
    "căliți": "călit",
    "căliții": "călit",
    "căliților": "călit",
    "călito": "călit",
    "călitul": "călit",
    "călitule": "călit",
    "călitului": "călit",
    "calitatea": "calitate",
    "calitateo": "calitate",
    "calități": "calitate",
    "calității": "calitate",
    "calitățile": "calitate",
    "calităților": "calitate",
    "calitativa": "calitativ",
    "calitativă": "calitativ",
    "calitative": "calitativ",
    "calitativei": "calitativ",
    "calitativele": "calitativ",
    "calitativelor": "calitativ",
    "calitativi": "calitativ",
    "calitativii": "calitativ",
    "calitativilor": "calitativ",
    "calitativo": "calitativ",
    "calitativul": "calitativ",
    "calitativule": "calitativ",
    "calitativului": "calitativ",
    "calma": "calm",
    "calmă": "calm",
    "calme": "calm",
    "calmei": "calm",
    "calmele": "calm",
    "calmelor": "calm",
    "calmi": "calm",
    "calmii": "calm",
    "calmilor": "calm",
    "calmo": "calm",
    "calmul": "calm",
    "calmule": "calm",
    "calmului": "calm",
    "calmuri": "calm",
    "calmurile": "calm",
    "calmurilor": "calm",
    "calmă": "calma",
    "calmai": "calma",
    "calmam": "calma",
    "calmăm": "calma",
    "calmând": "calma",
    "calmându": "calma",
    "calmară": "calma",
    "calmarăm": "calma",
    "calmarăți": "calma",
    "calmase": "calma",
    "calmasem": "calma",
    "calmaseră": "calma",
    "calmaserăm": "calma",
    "calmaserăți": "calma",
    "calmaseși": "calma",
    "calmași": "calma",
    "calmat": "calma",
    "calmați": "calma",
    "calmatu": "calma",
    "calmau": "calma",
    "calmează": "calma",
    "calmez": "calma",
    "calmeze": "calma",
    "calmezi": "calma",
    "necalmând": "calma",
    "necalmându": "calma",
    "nemaicalmând": "calma",
    "nemaicalmându": "calma",
    "calmanta": "calmant",
    "calmantă": "calmant",
    "calmante": "calmant",
    "calmantei": "calmant",
    "calmantele": "calmant",
    "calmantelor": "calmant",
    "calmanți": "calmant",
    "calmanții": "calmant",
    "calmanților": "calmant",
    "calmanto": "calmant",
    "calmantul": "calmant",
    "calmantule": "calmant",
    "calmantului": "calmant",
    "calmarea": "calmare",
    "calmareo": "calmare",
    "calmări": "calmare",
    "calmării": "calmare",
    "calmările": "calmare",
    "calmărilor": "calmare",
    "Călmășenii": "Călmășeni",
    "Călmășenilor": "Călmășeni",
    "Călmășeniul": "Călmășeni",
    "Călmășeniului": "Călmășeni",
    "calmată": "calmat",
    "calmate": "calmat",
    "calmați": "calmat",
    "Călmățuiului": "Călmățui",
    "calomelul": "calomel",
    "calomelule": "calomel",
    "calomelului": "calomel",
    "calomfiri": "calomfir",
    "calomfirii": "calomfir",
    "calomfirilor": "calomfir",
    "calomfirul": "calomfir",
    "calomfirule": "calomfir",
    "calomfirului": "calomfir",
    "calomniai": "calomnia",
    "calomniam": "calomnia",
    "calomniară": "calomnia",
    "calomniarăm": "calomnia",
    "calomniarăți": "calomnia",
    "calomniase": "calomnia",
    "calomniasem": "calomnia",
    "calomniaseră": "calomnia",
    "calomniaserăm": "calomnia",
    "calomniaserăți": "calomnia",
    "calomniaseși": "calomnia",
    "calomniași": "calomnia",
    "calomniat": "calomnia",
    "calomniați": "calomnia",
    "calomniatu": "calomnia",
    "calomniau": "calomnia",
    "calomniază": "calomnia",
    "calomnie": "calomnia",
    "calomniem": "calomnia",
    "calomniez": "calomnia",
    "calomnieze": "calomnia",
    "calomniezi": "calomnia",
    "calomniind": "calomnia",
    "calomniindu": "calomnia",
    "necalomniind": "calomnia",
    "necalomniindu": "calomnia",
    "nemaicalomniind": "calomnia",
    "nemaicalomniindu": "calomnia",
    "calomniată": "calomniat",
    "calomniate": "calomniat",
    "calomniați": "calomniat",
    "calomniatoarea": "calomniatoare",
    "calomniatoarei": "calomniatoare",
    "calomniatoarele": "calomniatoare",
    "calomniatoarelor": "calomniatoare",
    "calomniatoareo": "calomniatoare",
    "calomniatoare": "calomniator",
    "calomniatoarea": "calomniator",
    "calomniatoarei": "calomniator",
    "calomniatoarele": "calomniator",
    "calomniatoarelor": "calomniator",
    "calomniatoareo": "calomniator",
    "calomniatori": "calomniator",
    "calomniatorii": "calomniator",
    "calomniatorilor": "calomniator",
    "calomniatorul": "calomniator",
    "calomniatorule": "calomniator",
    "calomniatorului": "calomniator",
    "calomnia": "calomnie",
    "calomniei": "calomnie",
    "calomnii": "calomnie",
    "calomniile": "calomnie",
    "calomniilor": "calomnie",
    "calomnio": "calomnie",
    "calomnierea": "calomniere",
    "calomniereo": "calomniere",
    "calomnieri": "calomniere",
    "calomnierii": "calomniere",
    "calomnierile": "calomniere",
    "calomnierilor": "calomniere",
    "calomnioasa": "calomnios",
    "calomnioasă": "calomnios",
    "calomnioase": "calomnios",
    "calomnioasei": "calomnios",
    "calomnioasele": "calomnios",
    "calomnioaselor": "calomnios",
    "calomnioaso": "calomnios",
    "calomnioși": "calomnios",
    "calomnioșii": "calomnios",
    "calomnioșilor": "calomnios",
    "calomniosul": "calomnios",
    "calomniosule": "calomnios",
    "calomniosului": "calomnios",
    "calorica": "caloric",
    "calorică": "caloric",
    "calorice": "caloric",
    "caloricei": "caloric",
    "caloricele": "caloric",
    "caloricelor": "caloric",
    "calorici": "caloric",
    "caloricii": "caloric",
    "caloricilor": "caloric",
    "calorico": "caloric",
    "caloricul": "caloric",
    "caloricule": "caloric",
    "caloricului": "caloric",
    "cal.": "calorie",
    "caloria": "calorie",
    "caloriei": "calorie",
    "calorii": "calorie",
    "caloriile": "calorie",
    "caloriilor": "calorie",
    "calorio": "calorie",
    "calorifere": "calorifer",
    "caloriferele": "calorifer",
    "caloriferelor": "calorifer",
    "caloriferul": "calorifer",
    "caloriferule": "calorifer",
    "caloriferului": "calorifer",
    "caloriferiști": "caloriferist",
    "caloriferiștii": "caloriferist",
    "caloriferiștilor": "caloriferist",
    "caloriferistul": "caloriferist",
    "caloriferistule": "caloriferist",
    "caloriferistului": "caloriferist",
    "calorifica": "calorific",
    "calorifică": "calorific",
    "calorifice": "calorific",
    "calorificei": "calorific",
    "calorificele": "calorific",
    "calorificelor": "calorific",
    "calorifici": "calorific",
    "calorificii": "calorific",
    "calorificilor": "calorific",
    "calorifico": "calorific",
    "calorificul": "calorific",
    "calorificule": "calorific",
    "calorificului": "calorific",
    "calorigena": "calorigen",
    "calorigenă": "calorigen",
    "calorigene": "calorigen",
    "calorigenei": "calorigen",
    "calorigenele": "calorigen",
    "calorigenelor": "calorigen",
    "calorigeni": "calorigen",
    "calorigenii": "calorigen",
    "calorigenilor": "calorigen",
    "calorigeno": "calorigen",
    "calorigenul": "calorigen",
    "calorigenule": "calorigen",
    "calorigenului": "calorigen",
    "calorimetrica": "calorimetric",
    "calorimetrică": "calorimetric",
    "calorimetrice": "calorimetric",
    "calorimetricei": "calorimetric",
    "calorimetricele": "calorimetric",
    "calorimetricelor": "calorimetric",
    "calorimetrici": "calorimetric",
    "calorimetricii": "calorimetric",
    "calorimetricilor": "calorimetric",
    "calorimetrico": "calorimetric",
    "calorimetricul": "calorimetric",
    "calorimetricule": "calorimetric",
    "calorimetricului": "calorimetric",
    "calorimetria": "calorimetrie",
    "calorimetriei": "calorimetrie",
    "calorimetrii": "calorimetrie",
    "calorimetriile": "calorimetrie",
    "calorimetriilor": "calorimetrie",
    "calorimetrio": "calorimetrie",
    "calorimetre": "calorimetru",
    "calorimetrele": "calorimetru",
    "calorimetrelor": "calorimetru",
    "calorimetrul": "calorimetru",
    "calorimetrule": "calorimetru",
    "calorimetrului": "calorimetru",
    "caloasa": "calos",
    "caloasă": "calos",
    "caloase": "calos",
    "caloasei": "calos",
    "caloasele": "calos",
    "caloaselor": "calos",
    "caloaso": "calos",
    "caloși": "calos",
    "caloșii": "calos",
    "caloșilor": "calos",
    "calosul": "calos",
    "calosule": "calos",
    "calosului": "calos",
    "calota": "calotă",
    "calote": "calotă",
    "calotei": "calotă",
    "calotele": "calotă",
    "calotelor": "calotă",
    "caloto": "calotă",
    "calpa": "calp",
    "calpă": "calp",
    "calpe": "calp",
    "calpei": "calp",
    "calpele": "calp",
    "calpelor": "calp",
    "calpi": "calp",
    "calpii": "calp",
    "calpilor": "calp",
    "calpo": "calp",
    "calpul": "calp",
    "calpule": "calp",
    "calpului": "calp",
    "caltaboși": "caltaboș",
    "caltaboșii": "caltaboș",
    "caltaboșilor": "caltaboș",
    "caltaboșul": "caltaboș",
    "caltaboșule": "caltaboș",
    "caltaboșului": "caltaboș",
    "câlții": "câlți",
    "câlților": "câlți",
    "câlțișorii": "câlțișori",
    "câlțișorilor": "câlțișori",
    "câlțoasa": "câlțos",
    "câlțoasă": "câlțos",
    "câlțoase": "câlțos",
    "câlțoasei": "câlțos",
    "câlțoasele": "câlțos",
    "câlțoaselor": "câlțos",
    "câlțoaso": "câlțos",
    "câlțoși": "câlțos",
    "câlțoșii": "câlțos",
    "câlțoșilor": "câlțos",
    "câlțosul": "câlțos",
    "câlțosule": "câlțos",
    "câlțosului": "câlțos",
    "călugări": "călugăr",
    "călugării": "călugăr",
    "călugărilor": "călugăr",
    "călugărul": "călugăr",
    "călugărule": "călugăr",
    "călugărului": "călugăr",
    "călugărași": "călugăraș",
    "călugărașii": "călugăraș",
    "călugărașilor": "călugăraș",
    "călugărașul": "călugăraș",
    "călugărașule": "călugăraș",
    "călugărașului": "călugăraș",
    "călugăreasca": "călugăresc",
    "călugărească": "călugăresc",
    "călugăreasco": "călugăresc",
    "călugărescul": "călugăresc",
    "călugărescule": "călugăresc",
    "călugărescului": "călugăresc",
    "călugărești": "călugăresc",
    "călugăreștii": "călugăresc",
    "călugăreștile": "călugăresc",
    "călugăreștilor": "călugăresc",
    "călugărea": "călugări",
    "călugăreai": "călugări",
    "călugăream": "călugări",
    "călugărească": "călugări",
    "călugăreați": "călugări",
    "călugăreau": "călugări",
    "călugăresc": "călugări",
    "călugărește": "călugări",
    "călugărești": "călugări",
    "călugării": "călugări",
    "călugărim": "călugări",
    "călugărind": "călugări",
    "călugărindu": "călugări",
    "călugăriră": "călugări",
    "călugărirăm": "călugări",
    "călugărirăți": "călugări",
    "călugărise": "călugări",
    "călugărisem": "călugări",
    "călugăriseră": "călugări",
    "călugăriserăm": "călugări",
    "călugăriserăți": "călugări",
    "călugăriseși": "călugări",
    "călugăriși": "călugări",
    "călugărit": "călugări",
    "călugăriți": "călugări",
    "călugăritu": "călugări",
    "necălugărind": "călugări",
    "necălugărindu": "călugări",
    "nemaicălugărind": "călugări",
    "nemaicălugărindu": "călugări",
    "călugăria": "călugărie",
    "călugăriei": "călugărie",
    "călugării": "călugărie",
    "călugăriile": "călugărie",
    "călugăriilor": "călugărie",
    "călugărio": "călugărie",
    "călugărirea": "călugărire",
    "călugărireo": "călugărire",
    "călugăriri": "călugărire",
    "călugăririi": "călugărire",
    "călugăririle": "călugărire",
    "călugăririlor": "călugărire",
    "călugărită": "călugărit",
    "călugărite": "călugărit",
    "călugăriți": "călugărit",
    "călugărița": "călugăriță",
    "călugărițe": "călugăriță",
    "călugăriței": "călugăriță",
    "călugărițele": "călugăriță",
    "călugărițelor": "călugăriță",
    "călugărițo": "călugăriță",
    "caii-dracului": "calul-dracului",
    "calupul": "calup",
    "calupule": "calup",
    "calupului": "calup",
    "calupuri": "calup",
    "calupurile": "calup",
    "calupurilor": "calup",
    "călușul": "căluș",
    "călușule": "căluș",
    "călușului": "căluș",
    "călușuri": "căluș",
    "călușurile": "căluș",
    "călușurilor": "căluș",
    "călușari": "călușar",
    "călușarii": "călușar",
    "călușarilor": "călușar",
    "călușarul": "călușar",
    "călușarule": "călușar",
    "călușarului": "călușar",
    "călușei": "călușel",
    "călușeii": "călușel",
    "călușeilor": "călușel",
    "călușelul": "călușel",
    "călușelule": "călușel",
    "călușelului": "călușel",
    "căluți": "căluț",
    "căluții": "căluț",
    "căluților": "căluț",
    "căluțul": "căluț",
    "căluțule": "căluț",
    "căluțului": "căluț",
    "calvarul": "calvar",
    "calvarule": "calvar",
    "calvarului": "calvar",
    "calvaruri": "calvar",
    "calvarurile": "calvar",
    "calvarurilor": "calvar",
    "calvina": "calvin",
    "calvină": "calvin",
    "calvine": "calvin",
    "calvinei": "calvin",
    "calvinele": "calvin",
    "calvinelor": "calvin",
    "calvini": "calvin",
    "calvinii": "calvin",
    "calvinilor": "calvin",
    "calvino": "calvin",
    "calvinul": "calvin",
    "calvinule": "calvin",
    "calvinului": "calvin",
    "calvina": "calvină",
    "calvine": "calvină",
    "calvinei": "calvină",
    "calvinele": "calvină",
    "calvinelor": "calvină",
    "calvino": "calvină",
    "calvinisme": "calvinism",
    "calvinismele": "calvinism",
    "calvinismelor": "calvinism",
    "calvinismul": "calvinism",
    "calvinismule": "calvinism",
    "calvinismului": "calvinism",
    "calvinista": "calvinist",
    "calvinistă": "calvinist",
    "calviniste": "calvinist",
    "calvinistei": "calvinist",
    "calvinistele": "calvinist",
    "calvinistelor": "calvinist",
    "calviniști": "calvinist",
    "calviniștii": "calvinist",
    "calviniștilor": "calvinist",
    "calvinisto": "calvinist",
    "calvinistul": "calvinist",
    "calvinistule": "calvinist",
    "calvinistului": "calvinist",
    "calvinista": "calvinistă",
    "calviniste": "calvinistă",
    "calvinistei": "calvinistă",
    "calvinistele": "calvinistă",
    "calvinistelor": "calvinistă",
    "calvinisto": "calvinistă",
    "calviția": "calviție",
    "calviției": "calviție",
    "calviții": "calviție",
    "calvițiile": "calviție",
    "calvițiilor": "calviție",
    "calvițio": "calviție",
    "cama": "camă",
    "came": "camă",
    "camei": "camă",
    "camele": "camă",
    "camelor": "camă",
    "camo": "camă",
    "cămara": "cămară",
    "cămări": "cămară",
    "cămării": "cămară",
    "cămările": "cămară",
    "cămărilor": "cămară",
    "cămaro": "cămară",
    "camaradul": "camarad",
    "camaradule": "camarad",
    "camaradului": "camarad",
    "camarazi": "camarad",
    "camarazii": "camarad",
    "camarazilor": "camarad",
    "camarada": "camaradă",
    "camarade": "camaradă",
    "camaradei": "camaradă",
    "camaradele": "camaradă",
    "camaradelor": "camaradă",
    "camarado": "camaradă",
    "camaradereasca": "camaraderesc",
    "camaraderească": "camaraderesc",
    "camaradereasco": "camaraderesc",
    "camaraderescul": "camaraderesc",
    "camaraderescule": "camaraderesc",
    "camaraderescului": "camaraderesc",
    "camaraderești": "camaraderesc",
    "camaradereștii": "camaraderesc",
    "camaradereștile": "camaraderesc",
    "camaradereștilor": "camaraderesc",
    "camaraderia": "camaraderie",
    "camaraderiei": "camaraderie",
    "camaraderii": "camaraderie",
    "camaraderiile": "camaraderie",
    "camaraderiilor": "camaraderie",
    "camaraderio": "camaraderie",
    "camarila": "camarilă",
    "camarile": "camarilă",
    "camarilei": "camarilă",
    "camarilele": "camarilă",
    "camarilelor": "camarilă",
    "camarilo": "camarilă",
    "cămărui": "cămăruie",
    "cămăruia": "cămăruie",
    "cămăruii": "cămăruie",
    "cămăruile": "cămăruie",
    "cămăruilor": "cămăruie",
    "cămăruio": "cămăruie",
    "cămăruța": "cămăruță",
    "cămăruțe": "cămăruță",
    "cămăruței": "cămăruță",
    "cămăruțele": "cămăruță",
    "cămăruțelor": "cămăruță",
    "cămăruțo": "cămăruță",
    "cămașa": "cămașă",
    "cămăși": "cămașă",
    "cămășii": "cămașă",
    "cămășile": "cămașă",
    "cămășilor": "cămașă",
    "cămașo": "cămașă",
    "cămășuța": "cămășuță",
    "cămășuțe": "cămășuță",
    "cămășuței": "cămășuță",
    "cămășuțele": "cămășuță",
    "cămășuțelor": "cămășuță",
    "cămășuțo": "cămășuță",
    "camăta": "camătă",
    "camăto": "camătă",
    "camete": "camătă",
    "cametei": "camătă",
    "cametele": "camătă",
    "cametelor": "camătă",
    "cămătari": "cămătar",
    "cămătarii": "cămătar",
    "cămătarilor": "cămătar",
    "cămătarul": "cămătar",
    "cămătarule": "cămătar",
    "cămătarului": "cămătar",
    "cămătăreasa": "cămătăreasă",
    "cămătăreaso": "cămătăreasă",
    "cămătărese": "cămătăreasă",
    "cămătăresei": "cămătăreasă",
    "cămătăresele": "cămătăreasă",
    "cămătăreselor": "cămătăreasă",
    "cămătăreasca": "cămătăresc",
    "cămătărească": "cămătăresc",
    "cămătăreasco": "cămătăresc",
    "cămătărescul": "cămătăresc",
    "cămătărescule": "cămătăresc",
    "cămătărescului": "cămătăresc",
    "cămătărești": "cămătăresc",
    "cămătăreștii": "cămătăresc",
    "cămătăreștile": "cămătăresc",
    "cămătăreștilor": "cămătăresc",
    "cămătăria": "cămătărie",
    "cămătăriei": "cămătărie",
    "cămătării": "cămătărie",
    "cămătăriile": "cămătărie",
    "cămătăriilor": "cămătărie",
    "cămătărio": "cămătărie",
    "cambiala": "cambial",
    "cambială": "cambial",
    "cambiale": "cambial",
    "cambialei": "cambial",
    "cambialele": "cambial",
    "cambialelor": "cambial",
    "cambiali": "cambial",
    "cambialii": "cambial",
    "cambialilor": "cambial",
    "cambialo": "cambial",
    "cambialul": "cambial",
    "cambialule": "cambial",
    "cambialului": "cambial",
    "cambia": "cambie",
    "cambiei": "cambie",
    "cambii": "cambie",
    "cambiile": "cambie",
    "cambiilor": "cambie",
    "cambio": "cambie",
    "Cambodgie": "Cambodgia",
    "Cambodgiei": "Cambodgia",
    "Cambodgii": "Cambodgia",
    "cambrianul": "cambrian",
    "cambrianule": "cambrian",
    "cambrianului": "cambrian",
    "cambuza": "cambuză",
    "cambuze": "cambuză",
    "cambuzei": "cambuză",
    "cambuzele": "cambuză",
    "cambuzelor": "cambuză",
    "cambuzo": "cambuză",
    "cameea": "camee",
    "cameei": "camee",
    "cameele": "camee",
    "cameelor": "camee",
    "cameo": "camee",
    "cameleoni": "cameleon",
    "cameleonii": "cameleon",
    "cameleonilor": "cameleon",
    "cameleonul": "cameleon",
    "cameleonule": "cameleon",
    "cameleonului": "cameleon",
    "cameleonisme": "cameleonism",
    "cameleonismele": "cameleonism",
    "cameleonismelor": "cameleonism",
    "cameleonismul": "cameleonism",
    "cameleonismule": "cameleonism",
    "cameleonismului": "cameleonism",
    "Camelie": "Camelia",
    "Cameliei": "Camelia",
    "Camelii": "Camelia",
    "camelia": "camelie",
    "cameliei": "camelie",
    "camelii": "camelie",
    "cameliile": "camelie",
    "cameliilor": "camelie",
    "camelio": "camelie",
    "camera": "cameră",
    "camere": "cameră",
    "camerei": "cameră",
    "camerele": "cameră",
    "camerelor": "cameră",
    "camero": "cameră",
    "cameramani": "cameraman",
    "cameramanii": "cameraman",
    "cameramanilor": "cameraman",
    "cameramanul": "cameraman",
    "cameramanule": "cameraman",
    "cameramanului": "cameraman",
    "camerieri": "camerier",
    "camerierii": "camerier",
    "camerierilor": "camerier",
    "camerierul": "camerier",
    "camerierule": "camerier",
    "camerierului": "camerier",
    "cameriști": "camerist",
    "cameriștii": "camerist",
    "cameriștilor": "camerist",
    "cameristul": "camerist",
    "cameristule": "camerist",
    "cameristului": "camerist",
    "camerista": "cameristă",
    "cameriste": "cameristă",
    "cameristei": "cameristă",
    "cameristele": "cameristă",
    "cameristelor": "cameristă",
    "cameristo": "cameristă",
    "camertonul": "camerton",
    "camertonule": "camerton",
    "camertonului": "camerton",
    "camertonuri": "camerton",
    "camertonurile": "camerton",
    "camertonurilor": "camerton",
    "cămeșoaie": "cămeșoi",
    "cămeșoaiele": "cămeșoi",
    "cămeșoaielor": "cămeșoi",
    "cămeșoiul": "cămeșoi",
    "cămeșoiule": "cămeșoi",
    "cămeșoiului": "cămeșoi",
    "camforul": "camfor",
    "camforule": "camfor",
    "camforului": "camfor",
    "camforata": "camforat",
    "camforată": "camforat",
    "camforate": "camforat",
    "camforatei": "camforat",
    "camforatele": "camforat",
    "camforatelor": "camforat",
    "camforați": "camforat",
    "camforații": "camforat",
    "camforaților": "camforat",
    "camforato": "camforat",
    "camforatul": "camforat",
    "camforatule": "camforat",
    "camforatului": "camforat",
    "cămila": "cămilă",
    "cămile": "cămilă",
    "cămilei": "cămilă",
    "cămilele": "cămilă",
    "cămilelor": "cămilă",
    "cămilo": "cămilă",
    "cămine": "cămin",
    "căminele": "cămin",
    "căminelor": "cămin",
    "căminul": "cămin",
    "căminule": "cămin",
    "căminului": "cămin",
    "căminuri": "cămin",
    "căminurile": "cămin",
    "căminurilor": "cămin",
    "căminista": "căminist",
    "căministă": "căminist",
    "căministe": "căminist",
    "căministei": "căminist",
    "căministele": "căminist",
    "căministelor": "căminist",
    "căminiști": "căminist",
    "căminiștii": "căminist",
    "căminiștilor": "căminist",
    "căministo": "căminist",
    "căministul": "căminist",
    "căministule": "căminist",
    "căministului": "căminist",
    "căminista": "căministă",
    "căministe": "căministă",
    "căministei": "căministă",
    "căministele": "căministă",
    "căministelor": "căministă",
    "căministo": "căministă",
    "camioane": "camion",
    "camioanele": "camion",
    "camioanelor": "camion",
    "camionul": "camion",
    "camionule": "camion",
    "camionului": "camion",
    "camionagii": "camionagiu",
    "camionagiii": "camionagiu",
    "camionagiilor": "camionagiu",
    "camionagiul": "camionagiu",
    "camionagiule": "camionagiu",
    "camionagiului": "camionagiu",
    "camioneta": "camionetă",
    "camionete": "camionetă",
    "camionetei": "camionetă",
    "camionetele": "camionetă",
    "camionetelor": "camionetă",
    "camioneto": "camionetă",
    "câmpi": "câmp",
    "câmpii": "câmp",
    "câmpilor": "câmp",
    "câmpul": "câmp",
    "câmpule": "câmp",
    "câmpului": "câmp",
    "câmpuri": "câmp",
    "câmpurile": "câmp",
    "câmpurilor": "câmp",
    "campă": "campa",
    "campai": "campa",
    "campam": "campa",
    "campăm": "campa",
    "campând": "campa",
    "campându": "campa",
    "campară": "campa",
    "camparăm": "campa",
    "camparăți": "campa",
    "campase": "campa",
    "campasem": "campa",
    "campaseră": "campa",
    "campaserăm": "campa",
    "campaserăți": "campa",
    "campaseși": "campa",
    "campași": "campa",
    "campat": "campa",
    "campați": "campa",
    "campatu": "campa",
    "campau": "campa",
    "campează": "campa",
    "campez": "campa",
    "campeze": "campa",
    "campezi": "campa",
    "necampând": "campa",
    "necampându": "campa",
    "nemaicampând": "campa",
    "nemaicampându": "campa",
    "campamente": "campament",
    "campamentele": "campament",
    "campamentelor": "campament",
    "campamentul": "campament",
    "campamentule": "campament",
    "campamentului": "campament",
    "campania": "campanie",
    "campaniei": "campanie",
    "campanii": "campanie",
    "campaniile": "campanie",
    "campaniilor": "campanie",
    "campanio": "campanie",
    "campanula": "campanulă",
    "campanule": "campanulă",
    "campanulei": "campanulă",
    "campanulele": "campanulă",
    "campanulelor": "campanulă",
    "campanulo": "campanulă",
    "campată": "campat",
    "campate": "campat",
    "campați": "campat",
    "câmpeanul": "câmpean",
    "câmpeanule": "câmpean",
    "câmpeanului": "câmpean",
    "câmpeni": "câmpean",
    "câmpenii": "câmpean",
    "câmpenilor": "câmpean",
    "câmpeanca": "câmpeancă",
    "câmpeanco": "câmpeancă",
    "câmpence": "câmpeancă",
    "câmpencei": "câmpeancă",
    "câmpencele": "câmpeancă",
    "câmpencelor": "câmpeancă",
    "câmpeneasca": "câmpenesc",
    "câmpenească": "câmpenesc",
    "câmpeneasco": "câmpenesc",
    "câmpenescul": "câmpenesc",
    "câmpenescule": "câmpenesc",
    "câmpenescului": "câmpenesc",
    "câmpenești": "câmpenesc",
    "câmpeneștii": "câmpenesc",
    "câmpeneștile": "câmpenesc",
    "câmpeneștilor": "câmpenesc",
    "Câmpiei_Turzii": "Câmpia_Turzii",
    "câmpia": "câmpie",
    "câmpiei": "câmpie",
    "câmpii": "câmpie",
    "câmpiile": "câmpie",
    "câmpiilor": "câmpie",
    "câmpio": "câmpie",
    "campioana": "campioană",
    "campioane": "campioană",
    "campioanei": "campioană",
    "campioanele": "campioană",
    "campioanelor": "campioană",
    "campioano": "campioană",
    "campioni": "campion",
    "campionii": "campion",
    "campionilor": "campion",
    "campionul": "campion",
    "campionule": "campion",
    "campionului": "campion",
    "campionate": "campionat",
    "campionatele": "campionat",
    "campionatelor": "campionat",
    "campionatul": "campionat",
    "campionatule": "campionat",
    "campionatului": "campionat",
    "CM": "Campionat_Mondial",
    "C.M.": "Campionatul_Mondial",
    "Câmpulungul": "Câmpulung",
    "Câmpulungului": "Câmpulung",
    "campusul": "campus",
    "campusule": "campus",
    "campusului": "campus",
    "campusuri": "campus",
    "campusurile": "campus",
    "campusurilor": "campus",
    "câmpușoare": "câmpușor",
    "câmpușoarele": "câmpușor",
    "câmpușoarelor": "câmpușor",
    "câmpușorul": "câmpușor",
    "câmpușorule": "câmpușor",
    "câmpușorului": "câmpușor",
    "camuflă": "camufla",
    "camuflai": "camufla",
    "camuflam": "camufla",
    "camuflăm": "camufla",
    "camuflând": "camufla",
    "camuflându": "camufla",
    "camuflară": "camufla",
    "camuflarăm": "camufla",
    "camuflarăți": "camufla",
    "camuflase": "camufla",
    "camuflasem": "camufla",
    "camuflaseră": "camufla",
    "camuflaserăm": "camufla",
    "camuflaserăți": "camufla",
    "camuflaseși": "camufla",
    "camuflași": "camufla",
    "camuflat": "camufla",
    "camuflați": "camufla",
    "camuflatu": "camufla",
    "camuflau": "camufla",
    "camuflează": "camufla",
    "camuflez": "camufla",
    "camufleze": "camufla",
    "camuflezi": "camufla",
    "necamuflând": "camufla",
    "necamuflându": "camufla",
    "nemaicamuflând": "camufla",
    "nemaicamuflându": "camufla",
    "camuflaje": "camuflaj",
    "camuflajele": "camuflaj",
    "camuflajelor": "camuflaj",
    "camuflajul": "camuflaj",
    "camuflajule": "camuflaj",
    "camuflajului": "camuflaj",
    "camuflarea": "camuflare",
    "camuflareo": "camuflare",
    "camuflări": "camuflare",
    "camuflării": "camuflare",
    "camuflările": "camuflare",
    "camuflărilor": "camuflare",
    "camuflata": "camuflat",
    "camuflată": "camuflat",
    "camuflate": "camuflat",
    "camuflatei": "camuflat",
    "camuflatele": "camuflat",
    "camuflatelor": "camuflat",
    "camuflați": "camuflat",
    "camuflații": "camuflat",
    "camuflaților": "camuflat",
    "camuflato": "camuflat",
    "camuflatul": "camuflat",
    "camuflatule": "camuflat",
    "camuflatului": "camuflat",
    "cana": "cană",
    "căni": "cană",
    "cănii": "cană",
    "cănile": "cană",
    "cănilor": "cană",
    "cano": "cană",
    "Ca.": "Canada",
    "Canadă": "Canada",
    "Canade": "Canada",
    "Canadei": "Canada",
    "canadiana": "canadian",
    "canadiană": "canadian",
    "canadiano": "canadian",
    "canadianul": "canadian",
    "canadianule": "canadian",
    "canadianului": "canadian",
    "canadiene": "canadian",
    "canadienei": "canadian",
    "canadienele": "canadian",
    "canadienelor": "canadian",
    "canadieni": "canadian",
    "canadienii": "canadian",
    "canadienilor": "canadian",
    "canadiana": "canadiană",
    "canadiene": "canadiană",
    "canadienei": "canadiană",
    "canadienele": "canadiană",
    "canadienelor": "canadiană",
    "canadianca": "canadiancă",
    "canadianco": "canadiancă",
    "canadience": "canadiancă",
    "canadiencei": "canadiancă",
    "canadiencele": "canadiancă",
    "canadiencelor": "canadiancă",
    "canale": "canal",
    "canalele": "canal",
    "canalelor": "canal",
    "canalul": "canal",
    "canalule": "canal",
    "canalului": "canal",
    "canaluri": "canal",
    "canalurile": "canal",
    "canalurilor": "canal",
    "canalia": "canalie",
    "canaliei": "canalie",
    "canalii": "canalie",
    "canaliile": "canalie",
    "canaliilor": "canalie",
    "canalio": "canalie",
    "canaliză": "canaliza",
    "canalizai": "canaliza",
    "canalizam": "canaliza",
    "canalizăm": "canaliza",
    "canalizând": "canaliza",
    "canalizându": "canaliza",
    "canalizară": "canaliza",
    "canalizarăm": "canaliza",
    "canalizarăți": "canaliza",
    "canalizase": "canaliza",
    "canalizasem": "canaliza",
    "canalizaseră": "canaliza",
    "canalizaserăm": "canaliza",
    "canalizaserăți": "canaliza",
    "canalizaseși": "canaliza",
    "canalizași": "canaliza",
    "canalizat": "canaliza",
    "canalizați": "canaliza",
    "canalizatu": "canaliza",
    "canalizau": "canaliza",
    "canalizează": "canaliza",
    "canalizez": "canaliza",
    "canalizeze": "canaliza",
    "canalizezi": "canaliza",
    "necanalizând": "canaliza",
    "necanalizându": "canaliza",
    "nemaicanalizând": "canaliza",
    "nemaicanalizându": "canaliza",
    "canalizabila": "canalizabil",
    "canalizabilă": "canalizabil",
    "canalizabile": "canalizabil",
    "canalizabilei": "canalizabil",
    "canalizabilele": "canalizabil",
    "canalizabilelor": "canalizabil",
    "canalizabili": "canalizabil",
    "canalizabilii": "canalizabil",
    "canalizabililor": "canalizabil",
    "canalizabilo": "canalizabil",
    "canalizabilul": "canalizabil",
    "canalizabilule": "canalizabil",
    "canalizabilului": "canalizabil",
    "canalizarea": "canalizare",
    "canalizareo": "canalizare",
    "canalizări": "canalizare",
    "canalizării": "canalizare",
    "canalizările": "canalizare",
    "canalizărilor": "canalizare",
    "canalizata": "canalizat",
    "canalizată": "canalizat",
    "canalizate": "canalizat",
    "canalizatei": "canalizat",
    "canalizatele": "canalizat",
    "canalizatelor": "canalizat",
    "canalizați": "canalizat",
    "canalizații": "canalizat",
    "canalizaților": "canalizat",
    "canalizato": "canalizat",
    "canalizatul": "canalizat",
    "canalizatule": "canalizat",
    "canalizatului": "canalizat",
    "canalizația": "canalizație",
    "canalizației": "canalizație",
    "canalizații": "canalizație",
    "canalizațiile": "canalizație",
    "canalizațiilor": "canalizație",
    "canalizațio": "canalizație",
    "canalizatoare": "canalizator",
    "canalizatoarea": "canalizator",
    "canalizatoarei": "canalizator",
    "canalizatoarele": "canalizator",
    "canalizatoarelor": "canalizator",
    "canalizatoareo": "canalizator",
    "canalizatori": "canalizator",
    "canalizatorii": "canalizator",
    "canalizatorilor": "canalizator",
    "canalizatorul": "canalizator",
    "canalizatorule": "canalizator",
    "canalizatorului": "canalizator",
    "canapeao": "canapea",
    "canapeaua": "canapea",
    "canapele": "canapea",
    "canapelei": "canapea",
    "canapelele": "canapea",
    "canapelelor": "canapea",
    "canapeluța": "canapeluță",
    "canapeluțe": "canapeluță",
    "canapeluței": "canapeluță",
    "canapeluțele": "canapeluță",
    "canapeluțelor": "canapeluță",
    "canapeluțo": "canapeluță",
    "canari": "canar",
    "canarii": "canar",
    "canarilor": "canar",
    "canarul": "canar",
    "canarule": "canar",
    "canarului": "canar",
    "cănărași": "cănăraș",
    "cănărașii": "cănăraș",
    "cănărașilor": "cănăraș",
    "cănărașul": "cănăraș",
    "cănărașule": "cănăraș",
    "cănărașului": "cănăraș",
    "cănărița": "cănăriță",
    "cănărițe": "cănăriță",
    "cănăriței": "cănăriță",
    "cănărițele": "cănăriță",
    "cănărițelor": "cănăriță",
    "cănărițo": "cănăriță",
    "cănăruți": "cănăruț",
    "cănăruții": "cănăruț",
    "cănăruților": "cănăruț",
    "cănăruțul": "cănăruț",
    "cănăruțule": "cănăruț",
    "cănăruțului": "cănăruț",
    "canate": "canat",
    "canatele": "canat",
    "canatelor": "canat",
    "canatul": "canat",
    "canatule": "canat",
    "canatului": "canat",
    "canaturi": "canat",
    "canaturile": "canat",
    "canaturilor": "canat",
    "canavale": "canava",
    "canavalei": "canava",
    "canavalele": "canava",
    "canavalelor": "canava",
    "canavao": "canava",
    "canavaua": "canava",
    "cancanul": "cancan",
    "cancanule": "cancan",
    "cancanului": "cancan",
    "cancanuri": "cancan",
    "cancanurile": "cancan",
    "cancanurilor": "cancan",
    "cancelari": "cancelar",
    "cancelarii": "cancelar",
    "cancelarilor": "cancelar",
    "cancelarul": "cancelar",
    "cancelarule": "cancelar",
    "cancelarului": "cancelar",
    "cancelariate": "cancelariat",
    "cancelariatele": "cancelariat",
    "cancelariatelor": "cancelariat",
    "cancelariatul": "cancelariat",
    "cancelariatule": "cancelariat",
    "cancelariatului": "cancelariat",
    "cancelaria": "cancelarie",
    "cancelariei": "cancelarie",
    "cancelarii": "cancelarie",
    "cancelariile": "cancelarie",
    "cancelariilor": "cancelarie",
    "cancelario": "cancelarie",
    "cancere": "cancer",
    "cancerele": "cancer",
    "cancerelor": "cancer",
    "cancerul": "cancer",
    "cancerule": "cancer",
    "cancerului": "cancer",
    "cancerologia": "cancerologie",
    "cancerologiei": "cancerologie",
    "cancerologii": "cancerologie",
    "cancerologio": "cancerologie",
    "canceroasa": "canceros",
    "canceroasă": "canceros",
    "canceroase": "canceros",
    "canceroasei": "canceros",
    "canceroasele": "canceros",
    "canceroaselor": "canceros",
    "canceroaso": "canceros",
    "canceroși": "canceros",
    "canceroșii": "canceros",
    "canceroșilor": "canceros",
    "cancerosul": "canceros",
    "cancerosule": "canceros",
    "cancerosului": "canceros",
    "cân'": "când",
    "candelul": "candel",
    "candelule": "candel",
    "candelului": "candel",
    "candela": "candelă",
    "candele": "candelă",
    "candelei": "candelă",
    "candelele": "candelă",
    "candelelor": "candelă",
    "candelo": "candelă",
    "cd.": "candelă",
    "candelabre": "candelabru",
    "candelabrele": "candelabru",
    "candelabrelor": "candelabru",
    "candelabrul": "candelabru",
    "candelabrule": "candelabru",
    "candelabrului": "candelabru",
    "candida": "candid",
    "candidă": "candid",
    "candide": "candid",
    "candidei": "candid",
    "candidele": "candid",
    "candidelor": "candid",
    "candido": "candid",
    "candidul": "candid",
    "candidule": "candid",
    "candidului": "candid",
    "candizi": "candid",
    "candizii": "candid",
    "candizilor": "candid",
    "candidă": "candida",
    "candidai": "candida",
    "candidam": "candida",
    "candidăm": "candida",
    "candidând": "candida",
    "candidându": "candida",
    "candidară": "candida",
    "candidarăm": "candida",
    "candidarăți": "candida",
    "candidase": "candida",
    "candidasem": "candida",
    "candidaseră": "candida",
    "candidaserăm": "candida",
    "candidaserăți": "candida",
    "candidaseși": "candida",
    "candidași": "candida",
    "candidat": "candida",
    "candidați": "candida",
    "candidatu": "candida",
    "candidau": "candida",
    "candidează": "candida",
    "candidez": "candida",
    "candideze": "candida",
    "candidezi": "candida",
    "necandidând": "candida",
    "necandidându": "candida",
    "nemaicandidând": "candida",
    "nemaicandidându": "candida",
    "candidată": "candidat",
    "candidate": "candidat",
    "candidați": "candidat",
    "candidații": "candidat",
    "candidaților": "candidat",
    "candidatul": "candidat",
    "candidatule": "candidat",
    "candidatului": "candidat",
    "candidata": "candidată",
    "candidate": "candidată",
    "candidatei": "candidată",
    "candidatele": "candidată",
    "candidatelor": "candidată",
    "candidato": "candidată",
    "candidatura": "candidatură",
    "candidaturi": "candidatură",
    "candidaturii": "candidatură",
    "candidaturile": "candidatură",
    "candidaturilor": "candidatură",
    "candidaturo": "candidatură",
    "candoarea": "candoare",
    "candoareo": "candoare",
    "candori": "candoare",
    "candorii": "candoare",
    "candorile": "candoare",
    "candorilor": "candoare",
    "candria": "candriu",
    "candrie": "candriu",
    "candriei": "candriu",
    "candrii": "candriu",
    "candriii": "candriu",
    "candriile": "candriu",
    "candriilor": "candriu",
    "candrio": "candriu",
    "candriul": "candriu",
    "candriule": "candriu",
    "candriului": "candriu",
    "caneao": "canea",
    "caneaua": "canea",
    "canele": "canea",
    "canelei": "canea",
    "canelele": "canea",
    "canelelor": "canea",
    "căneala": "căneală",
    "cănealo": "căneală",
    "căneli": "căneală",
    "cănelii": "căneală",
    "cănelile": "căneală",
    "cănelilor": "căneală",
    "canelata": "canelat",
    "canelată": "canelat",
    "canelate": "canelat",
    "canelatei": "canelat",
    "canelatele": "canelat",
    "canelatelor": "canelat",
    "canelați": "canelat",
    "canelații": "canelat",
    "canelaților": "canelat",
    "canelato": "canelat",
    "canelatul": "canelat",
    "canelatule": "canelat",
    "canelatului": "canelat",
    "canelura": "canelură",
    "caneluri": "canelură",
    "canelurii": "canelură",
    "canelurile": "canelură",
    "canelurilor": "canelură",
    "caneluro": "canelură",
    "cânepa": "cânepă",
    "cânepei": "cânepă",
    "cânepi": "cânepă",
    "cânepo": "cânepă",
    "cânepari": "cânepar",
    "câneparii": "cânepar",
    "câneparilor": "cânepar",
    "câneparul": "cânepar",
    "câneparule": "cânepar",
    "câneparului": "cânepar",
    "cânepăria": "cânepărie",
    "cânepăriei": "cânepărie",
    "cânepării": "cânepărie",
    "cânepăriile": "cânepărie",
    "cânepăriilor": "cânepărie",
    "cânepărio": "cânepărie",
    "cânepioara": "cânepioară",
    "cânepioare": "cânepioară",
    "cânepioarei": "cânepioară",
    "cânepioarele": "cânepioară",
    "cânepioarelor": "cânepioară",
    "cânepioaro": "cânepioară",
    "cânepiștea": "cânepiște",
    "cânepișteo": "cânepiște",
    "cânepiști": "cânepiște",
    "cânepiștii": "cânepiște",
    "cânepiștile": "cânepiște",
    "cânepiștilor": "cânepiște",
    "cânepie": "cânepiu",
    "cânepiei": "cânepiu",
    "cânepii": "cânepiu",
    "cangea": "cange",
    "cangeo": "cange",
    "căngi": "cange",
    "căngii": "cange",
    "căngile": "cange",
    "căngilor": "cange",
    "cangrenă": "cangrena",
    "cangrenai": "cangrena",
    "cangrenam": "cangrena",
    "cangrenăm": "cangrena",
    "cangrenând": "cangrena",
    "cangrenându": "cangrena",
    "cangrenară": "cangrena",
    "cangrenarăm": "cangrena",
    "cangrenarăți": "cangrena",
    "cangrenase": "cangrena",
    "cangrenasem": "cangrena",
    "cangrenaseră": "cangrena",
    "cangrenaserăm": "cangrena",
    "cangrenaserăți": "cangrena",
    "cangrenaseși": "cangrena",
    "cangrenași": "cangrena",
    "cangrenat": "cangrena",
    "cangrenați": "cangrena",
    "cangrenatu": "cangrena",
    "cangrenau": "cangrena",
    "cangrenează": "cangrena",
    "cangrenez": "cangrena",
    "cangreneze": "cangrena",
    "cangrenezi": "cangrena",
    "necangrenând": "cangrena",
    "necangrenându": "cangrena",
    "nemaicangrenând": "cangrena",
    "nemaicangrenându": "cangrena",
    "cangrena": "cangrenă",
    "cangrene": "cangrenă",
    "cangrenei": "cangrenă",
    "cangrenele": "cangrenă",
    "cangrenelor": "cangrenă",
    "cangreno": "cangrenă",
    "cangrenata": "cangrenat",
    "cangrenată": "cangrenat",
    "cangrenate": "cangrenat",
    "cangrenatei": "cangrenat",
    "cangrenatele": "cangrenat",
    "cangrenatelor": "cangrenat",
    "cangrenați": "cangrenat",
    "cangrenații": "cangrenat",
    "cangrenaților": "cangrenat",
    "cangrenato": "cangrenat",
    "cangrenatul": "cangrenat",
    "cangrenatule": "cangrenat",
    "cangrenatului": "cangrenat",
    "cangrenoasa": "cangrenos",
    "cangrenoasă": "cangrenos",
    "cangrenoase": "cangrenos",
    "cangrenoasei": "cangrenos",
    "cangrenoasele": "cangrenos",
    "cangrenoaselor": "cangrenos",
    "cangrenoaso": "cangrenos",
    "cangrenoși": "cangrenos",
    "cangrenoșii": "cangrenos",
    "cangrenoșilor": "cangrenos",
    "cangrenosul": "cangrenos",
    "cangrenosule": "cangrenos",
    "cangrenosului": "cangrenos",
    "canguri": "cangur",
    "cangurii": "cangur",
    "cangurilor": "cangur",
    "cangurul": "cangur",
    "cangurule": "cangur",
    "cangurului": "cangur",
    "cănea": "căni",
    "căneai": "căni",
    "căneam": "căni",
    "cănească": "căni",
    "căneați": "căni",
    "căneau": "căni",
    "cănesc": "căni",
    "cănește": "căni",
    "cănești": "căni",
    "cănii": "căni",
    "cănim": "căni",
    "cănind": "căni",
    "cănindu": "căni",
    "căniră": "căni",
    "cănirăm": "căni",
    "cănirăți": "căni",
    "cănise": "căni",
    "cănisem": "căni",
    "căniseră": "căni",
    "căniserăm": "căni",
    "căniserăți": "căni",
    "căniseși": "căni",
    "căniși": "căni",
    "cănit": "căni",
    "căniți": "căni",
    "cănitu": "căni",
    "necănind": "căni",
    "necănindu": "căni",
    "nemaicănind": "căni",
    "nemaicănindu": "căni",
    "canibali": "canibal",
    "canibalii": "canibal",
    "canibalilor": "canibal",
    "canibalul": "canibal",
    "canibalule": "canibal",
    "canibalului": "canibal",
    "canibala": "canibală",
    "canibale": "canibală",
    "canibalei": "canibală",
    "canibalele": "canibală",
    "canibalelor": "canibală",
    "canibalo": "canibală",
    "canibalica": "canibalic",
    "canibalică": "canibalic",
    "canibalice": "canibalic",
    "canibalicei": "canibalic",
    "canibalicele": "canibalic",
    "canibalicelor": "canibalic",
    "canibalici": "canibalic",
    "canibalicii": "canibalic",
    "canibalicilor": "canibalic",
    "canibalico": "canibalic",
    "canibalicul": "canibalic",
    "canibalicule": "canibalic",
    "canibalicului": "canibalic",
    "canibalismul": "canibalism",
    "canibalismule": "canibalism",
    "canibalismului": "canibalism",
    "canicula": "caniculă",
    "canicule": "caniculă",
    "caniculei": "caniculă",
    "caniculele": "caniculă",
    "caniculelor": "caniculă",
    "caniculo": "caniculă",
    "caniculara": "canicular",
    "caniculară": "canicular",
    "caniculare": "canicular",
    "canicularei": "canicular",
    "canicularele": "canicular",
    "canicularelor": "canicular",
    "caniculari": "canicular",
    "canicularii": "canicular",
    "canicularilor": "canicular",
    "canicularo": "canicular",
    "canicularul": "canicular",
    "canicularule": "canicular",
    "canicularului": "canicular",
    "canina": "canin",
    "canină": "canin",
    "canine": "canin",
    "caninei": "canin",
    "caninele": "canin",
    "caninelor": "canin",
    "canini": "canin",
    "caninii": "canin",
    "caninilor": "canin",
    "canino": "canin",
    "caninul": "canin",
    "caninule": "canin",
    "caninului": "canin",
    "cănirea": "cănire",
    "cănireo": "cănire",
    "căniri": "cănire",
    "cănirii": "cănire",
    "cănirile": "cănire",
    "cănirilor": "cănire",
    "canistra": "canistră",
    "canistre": "canistră",
    "canistrei": "canistră",
    "canistrele": "canistră",
    "canistrelor": "canistră",
    "canistro": "canistră",
    "cănită": "cănit",
    "cănite": "cănit",
    "căniți": "cănit",
    "cănița": "căniță",
    "cănițe": "căniță",
    "căniței": "căniță",
    "cănițele": "căniță",
    "cănițelor": "căniță",
    "cănițo": "căniță",
    "canoea": "canoe",
    "canoei": "canoe",
    "canoele": "canoe",
    "canoelor": "canoe",
    "canoeo": "canoe",
    "canoane": "canon",
    "canoanele": "canon",
    "canoanelor": "canon",
    "canonul": "canon",
    "canonule": "canon",
    "canonului": "canon",
    "canonada": "canonadă",
    "canonade": "canonadă",
    "canonadei": "canonadă",
    "canonadele": "canonadă",
    "canonadelor": "canonadă",
    "canonado": "canonadă",
    "canonea": "canoni",
    "canoneai": "canoni",
    "canoneam": "canoni",
    "canonească": "canoni",
    "canoneați": "canoni",
    "canoneau": "canoni",
    "canonesc": "canoni",
    "canonește": "canoni",
    "canonești": "canoni",
    "canonii": "canoni",
    "canonim": "canoni",
    "canonind": "canoni",
    "canonindu": "canoni",
    "canoniră": "canoni",
    "canonirăm": "canoni",
    "canonirăți": "canoni",
    "canonise": "canoni",
    "canonisem": "canoni",
    "canoniseră": "canoni",
    "canoniserăm": "canoni",
    "canoniserăți": "canoni",
    "canoniseși": "canoni",
    "canoniși": "canoni",
    "canonit": "canoni",
    "canoniți": "canoni",
    "canonitu": "canoni",
    "necanonind": "canoni",
    "necanonindu": "canoni",
    "nemaicanonind": "canoni",
    "nemaicanonindu": "canoni",
    "canonica": "canonic",
    "canonică": "canonic",
    "canonice": "canonic",
    "canonicei": "canonic",
    "canonicele": "canonic",
    "canonicelor": "canonic",
    "canonici": "canonic",
    "canonicii": "canonic",
    "canonicilor": "canonic",
    "canonico": "canonic",
    "canonicul": "canonic",
    "canonicule": "canonic",
    "canonicului": "canonic",
    "canonicatul": "canonicat",
    "canonicatule": "canonicat",
    "canonicatului": "canonicat",
    "canoniera": "canonieră",
    "canoniere": "canonieră",
    "canonierei": "canonieră",
    "canonierele": "canonieră",
    "canonierelor": "canonieră",
    "canoniero": "canonieră",
    "canonită": "canonit",
    "canonite": "canonit",
    "canoniți": "canonit",
    "canoniză": "canoniza",
    "canonizai": "canoniza",
    "canonizam": "canoniza",
    "canonizăm": "canoniza",
    "canonizând": "canoniza",
    "canonizându": "canoniza",
    "canonizară": "canoniza",
    "canonizarăm": "canoniza",
    "canonizarăți": "canoniza",
    "canonizase": "canoniza",
    "canonizasem": "canoniza",
    "canonizaseră": "canoniza",
    "canonizaserăm": "canoniza",
    "canonizaserăți": "canoniza",
    "canonizaseși": "canoniza",
    "canonizași": "canoniza",
    "canonizat": "canoniza",
    "canonizați": "canoniza",
    "canonizatu": "canoniza",
    "canonizau": "canoniza",
    "canonizează": "canoniza",
    "canonizez": "canoniza",
    "canonizeze": "canoniza",
    "canonizezi": "canoniza",
    "necanonizând": "canoniza",
    "necanonizându": "canoniza",
    "nemaicanonizând": "canoniza",
    "nemaicanonizându": "canoniza",
    "canonizarea": "canonizare",
    "canonizareo": "canonizare",
    "canonizări": "canonizare",
    "canonizării": "canonizare",
    "canonizările": "canonizare",
    "canonizărilor": "canonizare",
    "canonizată": "canonizat",
    "canonizate": "canonizat",
    "canonizați": "canonizat",
    "canotaje": "canotaj",
    "canotajele": "canotaj",
    "canotajelor": "canotaj",
    "canotajul": "canotaj",
    "canotajule": "canotaj",
    "canotajului": "canotaj",
    "canotiera": "canotieră",
    "canotiere": "canotieră",
    "canotierei": "canotieră",
    "canotierele": "canotieră",
    "canotierelor": "canotieră",
    "canotiero": "canotieră",
    "canotoarea": "canotoare",
    "canotoarei": "canotoare",
    "canotoarele": "canotoare",
    "canotoarelor": "canotoare",
    "canotoareo": "canotoare",
    "canotori": "canotor",
    "canotorii": "canotor",
    "canotorilor": "canotor",
    "canotorul": "canotor",
    "canotorule": "canotor",
    "canotorului": "canotor",
    "cantul": "cant",
    "cantule": "cant",
    "cantului": "cant",
    "canturi": "cant",
    "canturile": "cant",
    "canturilor": "cant",
    "cântul": "cânt",
    "cântule": "cânt",
    "cântului": "cânt",
    "cânturi": "cânt",
    "cânturile": "cânt",
    "cânturilor": "cânt",
    "cânt": "cânta",
    "cântă": "cânta",
    "cântai": "cânta",
    "cântam": "cânta",
    "cântăm": "cânta",
    "cântând": "cânta",
    "cântându": "cânta",
    "cântară": "cânta",
    "cântarăm": "cânta",
    "cântarăți": "cânta",
    "cântase": "cânta",
    "cântasem": "cânta",
    "cântaseră": "cânta",
    "cântaserăm": "cânta",
    "cântaserăți": "cânta",
    "cântaseși": "cânta",
    "cântași": "cânta",
    "cântat": "cânta",
    "cântați": "cânta",
    "cântatu": "cânta",
    "cântau": "cânta",
    "cânte": "cânta",
    "cânți": "cânta",
    "necântând": "cânta",
    "necântându": "cânta",
    "nemaicântând": "cânta",
    "nemaicântându": "cânta",
    "cantalupi": "cantalup",
    "cantalupii": "cantalup",
    "cantalupilor": "cantalup",
    "cantalupul": "cantalup",
    "cantalupule": "cantalup",
    "cantalupului": "cantalup",
    "cântare": "cântar",
    "cântarele": "cântar",
    "cântarelor": "cântar",
    "cântarul": "cântar",
    "cântarule": "cântar",
    "cântarului": "cântar",
    "cântarea": "cântare",
    "cântareo": "cântare",
    "cântări": "cântare",
    "cântării": "cântare",
    "cântările": "cântare",
    "cântărilor": "cântare",
    "cântăreala": "cântăreală",
    "cântărealo": "cântăreală",
    "cântăreli": "cântăreală",
    "cântărelii": "cântăreală",
    "cântărelile": "cântăreală",
    "cântărelilor": "cântăreală",
    "cântăreața": "cântăreață",
    "cântăreațo": "cântăreață",
    "cântărețe": "cântăreață",
    "cântăreței": "cântăreață",
    "cântărețele": "cântăreață",
    "cântărețelor": "cântăreață",
    "cântăreți": "cântăreț",
    "cântăreții": "cântăreț",
    "cântăreților": "cântăreț",
    "cântărețul": "cântăreț",
    "cântărețule": "cântăreț",
    "cântărețului": "cântăreț",
    "cântărea": "cântări",
    "cântăreai": "cântări",
    "cântăream": "cântări",
    "cântărească": "cântări",
    "cântăreați": "cântări",
    "cântăreau": "cântări",
    "cântăresc": "cântări",
    "cântărește": "cântări",
    "cântărești": "cântări",
    "cântării": "cântări",
    "cântărim": "cântări",
    "cântărind": "cântări",
    "cântărindu": "cântări",
    "cântăriră": "cântări",
    "cântărirăm": "cântări",
    "cântărirăți": "cântări",
    "cântărise": "cântări",
    "cântărisem": "cântări",
    "cântăriseră": "cântări",
    "cântăriserăm": "cântări",
    "cântăriserăți": "cântări",
    "cântăriseși": "cântări",
    "cântăriși": "cântări",
    "cântărit": "cântări",
    "cântăriți": "cântări",
    "cântăritu": "cântări",
    "necântărind": "cântări",
    "necântărindu": "cântări",
    "nemaicântărind": "cântări",
    "nemaicântărindu": "cântări",
    "cantarida": "cantaridă",
    "cantaride": "cantaridă",
    "cantaridei": "cantaridă",
    "cantaridele": "cantaridă",
    "cantaridelor": "cantaridă",
    "cantarido": "cantaridă",
    "cântărirea": "cântărire",
    "cântărireo": "cântărire",
    "cântăriri": "cântărire",
    "cântăririi": "cântărire",
    "cântăririle": "cântărire",
    "cântăririlor": "cântărire",
    "cântărita": "cântărit",
    "cântărită": "cântărit",
    "cântărite": "cântărit",
    "cântăritei": "cântărit",
    "cântăritele": "cântărit",
    "cântăritelor": "cântărit",
    "cântăriți": "cântărit",
    "cântăriții": "cântărit",
    "cântăriților": "cântărit",
    "cântărito": "cântărit",
    "cântăritul": "cântărit",
    "cântăritule": "cântărit",
    "cântăritului": "cântărit",
    "cântată": "cântat",
    "cântate": "cântat",
    "cântați": "cântat",
    "cântatul": "cântat",
    "cântatule": "cântat",
    "cântatului": "cântat",
    "cantata": "cantată",
    "cantate": "cantată",
    "cantatei": "cantată",
    "cantatele": "cantată",
    "cantatelor": "cantată",
    "cantato": "cantată",
    "cântătoare": "cântător",
    "cântătoarea": "cântător",
    "cântătoarei": "cântător",
    "cântătoarele": "cântător",
    "cântătoarelor": "cântător",
    "cântătoareo": "cântător",
    "cântători": "cântător",
    "cântătorii": "cântător",
    "cântătorilor": "cântător",
    "cântătorul": "cântător",
    "cântătorule": "cântător",
    "cântătorului": "cântător",
    "cântece": "cântec",
    "cântecele": "cântec",
    "cântecelor": "cântec",
    "cântecul": "cântec",
    "cântecule": "cântec",
    "cântecului": "cântec",
    "cânticele": "cântec",
    "cântecele": "cântecel",
    "cântecelele": "cântecel",
    "cântecelelor": "cântecel",
    "cântecelul": "cântecel",
    "cântecelule": "cântecel",
    "cântecelului": "cântecel",
    "cânticele": "cântecel",
    "cantina": "cantină",
    "cantine": "cantină",
    "cantinei": "cantină",
    "cantinele": "cantină",
    "cantinelor": "cantină",
    "cantino": "cantină",
    "cantinieri": "cantinier",
    "cantinierii": "cantinier",
    "cantinierilor": "cantinier",
    "cantinierul": "cantinier",
    "cantinierule": "cantinier",
    "cantinierului": "cantinier",
    "cantiniera": "cantinieră",
    "cantiniere": "cantinieră",
    "cantinierei": "cantinieră",
    "cantinierele": "cantinieră",
    "cantinierelor": "cantinieră",
    "cantiniero": "cantinieră",
    "cantitatea": "cantitate",
    "cantitateo": "cantitate",
    "cantități": "cantitate",
    "cantității": "cantitate",
    "cantitățile": "cantitate",
    "cantităților": "cantitate",
    "cantitativa": "cantitativ",
    "cantitativă": "cantitativ",
    "cantitative": "cantitativ",
    "cantitativei": "cantitativ",
    "cantitativele": "cantitativ",
    "cantitativelor": "cantitativ",
    "cantitativi": "cantitativ",
    "cantitativii": "cantitativ",
    "cantitativilor": "cantitativ",
    "cantitativo": "cantitativ",
    "cantitativul": "cantitativ",
    "cantitativule": "cantitativ",
    "cantitativului": "cantitativ",
    "cantoane": "canton",
    "cantoanele": "canton",
    "cantoanelor": "canton",
    "cantonul": "canton",
    "cantonule": "canton",
    "cantonului": "canton",
    "canțoneta": "canțonetă",
    "canțonete": "canțonetă",
    "canțonetei": "canțonetă",
    "canțonetele": "canțonetă",
    "canțonetelor": "canțonetă",
    "canțoneto": "canțonetă",
    "cantonieri": "cantonier",
    "cantonierii": "cantonier",
    "cantonierilor": "cantonier",
    "cantonierul": "cantonier",
    "cantonierule": "cantonier",
    "cantonierului": "cantonier",
    "cantoniera": "cantonieră",
    "cantoniere": "cantonieră",
    "cantonierei": "cantonieră",
    "cantonierele": "cantonieră",
    "cantonierelor": "cantonieră",
    "cantoniero": "cantonieră",
    "cantori": "cantor",
    "cantorii": "cantor",
    "cantorilor": "cantor",
    "cantorul": "cantor",
    "cantorule": "cantor",
    "cantorului": "cantor",
    "caol.": "caolin",
    "caolini": "caolin",
    "caolinii": "caolin",
    "caolinilor": "caolin",
    "caolinul": "caolin",
    "caolinule": "caolin",
    "caolinului": "caolin",
    "capete": "cap",
    "capetele": "cap",
    "capetelor": "cap",
    "capi": "cap",
    "capii": "cap",
    "capilor": "cap",
    "capu'": "cap",
    "capu-": "cap",
    "capul": "cap",
    "capule": "cap",
    "capului": "cap",
    "capuri": "cap",
    "capurile": "cap",
    "capurilor": "cap",
    "capa": "capă",
    "cape": "capă",
    "capei": "capă",
    "capele": "capă",
    "capelor": "capă",
    "capo": "capă",
    "capabila": "capabil",
    "capabilă": "capabil",
    "capabile": "capabil",
    "capabilei": "capabil",
    "capabilele": "capabil",
    "capabilelor": "capabil",
    "capabili": "capabil",
    "capabilii": "capabil",
    "capabililor": "capabil",
    "capabilo": "capabil",
    "capabilul": "capabil",
    "capabilule": "capabil",
    "capabilului": "capabil",
    "capace": "capac",
    "capacele": "capac",
    "capacelor": "capac",
    "capacul": "capac",
    "capacule": "capac",
    "capacului": "capac",
    "căpăcele": "căpăcel",
    "căpăcelele": "căpăcel",
    "căpăcelelor": "căpăcel",
    "căpăcelul": "căpăcel",
    "căpăcelule": "căpăcel",
    "căpăcelului": "căpăcel",
    "capacitatea": "capacitate",
    "capacitateo": "capacitate",
    "capacități": "capacitate",
    "capacității": "capacitate",
    "capacitățile": "capacitate",
    "capacităților": "capacitate",
    "căpăstrul": "căpăstru",
    "căpăstrule": "căpăstru",
    "căpăstrului": "căpăstru",
    "căpestre": "căpăstru",
    "căpestrele": "căpăstru",
    "căpestrelor": "căpăstru",
    "capătul": "capăt",
    "capătule": "capăt",
    "capătului": "capăt",
    "capete": "capăt",
    "capetele": "capăt",
    "capetelor": "capăt",
    "capăt": "căpăta",
    "capătă": "căpăta",
    "căpătă": "căpăta",
    "căpătai": "căpăta",
    "căpătam": "căpăta",
    "căpătăm": "căpăta",
    "căpătând": "căpăta",
    "căpătându": "căpăta",
    "căpătară": "căpăta",
    "căpătarăm": "căpăta",
    "căpătarăți": "căpăta",
    "căpătase": "căpăta",
    "căpătasem": "căpăta",
    "căpătaseră": "căpăta",
    "căpătaserăm": "căpăta",
    "căpătaserăți": "căpăta",
    "căpătaseși": "căpăta",
    "căpătași": "căpăta",
    "căpătat": "căpăta",
    "căpătați": "căpăta",
    "căpătatu": "căpăta",
    "căpătau": "căpăta",
    "capete": "căpăta",
    "capeți": "căpăta",
    "necăpătând": "căpăta",
    "necăpătându": "căpăta",
    "nemaicăpătând": "căpăta",
    "nemaicăpătându": "căpăta",
    "căpătâie": "căpătâi",
    "căpătâiele": "căpătâi",
    "căpătâielor": "căpătâi",
    "căpătâiul": "căpătâi",
    "căpătâiule": "căpătâi",
    "căpătâiului": "căpătâi",
    "căpățâna": "căpățână",
    "căpățâni": "căpățână",
    "căpățânii": "căpățână",
    "căpățânile": "căpățână",
    "căpățânilor": "căpățână",
    "căpățâno": "căpățână",
    "căpățânoasa": "căpățânos",
    "căpățânoasă": "căpățânos",
    "căpățânoase": "căpățânos",
    "căpățânoasei": "căpățânos",
    "căpățânoasele": "căpățânos",
    "căpățânoaselor": "căpățânos",
    "căpățânoaso": "căpățânos",
    "căpățânoși": "căpățânos",
    "căpățânoșii": "căpățânos",
    "căpățânoșilor": "căpățânos",
    "căpățânosul": "căpățânos",
    "căpățânosule": "căpățânos",
    "căpățânosului": "căpățânos",
    "căpătarea": "căpătare",
    "căpătareo": "căpătare",
    "căpătări": "căpătare",
    "căpătării": "căpătare",
    "căpătările": "căpătare",
    "căpătărilor": "căpătare",
    "căpătată": "căpătat",
    "căpătate": "căpătat",
    "căpătați": "căpătat",
    "căpătatul": "căpătat",
    "căpătatule": "căpătat",
    "căpătatului": "căpătat",
    "căpătuia": "căpătui",
    "căpătuiai": "căpătui",
    "căpătuiam": "căpătui",
    "căpătuiască": "căpătui",
    "căpătuiați": "căpătui",
    "căpătuiau": "căpătui",
    "căpătuiesc": "căpătui",
    "căpătuiește": "căpătui",
    "căpătuiești": "căpătui",
    "căpătuii": "căpătui",
    "căpătuim": "căpătui",
    "căpătuind": "căpătui",
    "căpătuindu": "căpătui",
    "căpătuiră": "căpătui",
    "căpătuirăm": "căpătui",
    "căpătuirăți": "căpătui",
    "căpătuise": "căpătui",
    "căpătuisem": "căpătui",
    "căpătuiseră": "căpătui",
    "căpătuiserăm": "căpătui",
    "căpătuiserăți": "căpătui",
    "căpătuiseși": "căpătui",
    "căpătuiși": "căpătui",
    "căpătuit": "căpătui",
    "căpătuiți": "căpătui",
    "căpătuitu": "căpătui",
    "necăpătuind": "căpătui",
    "necăpătuindu": "căpătui",
    "nemaicăpătuind": "căpătui",
    "nemaicăpătuindu": "căpătui",
    "căpătuiala": "căpătuială",
    "căpătuialo": "căpătuială",
    "căpătuieli": "căpătuială",
    "căpătuielii": "căpătuială",
    "căpătuielile": "căpătuială",
    "căpătuielilor": "căpătuială",
    "căpătuirea": "căpătuire",
    "căpătuireo": "căpătuire",
    "căpătuiri": "căpătuire",
    "căpătuirii": "căpătuire",
    "căpătuirile": "căpătuire",
    "căpătuirilor": "căpătuire",
    "căpătuita": "căpătuit",
    "căpătuită": "căpătuit",
    "căpătuite": "căpătuit",
    "căpătuitei": "căpătuit",
    "căpătuitele": "căpătuit",
    "căpătuitelor": "căpătuit",
    "căpătuiți": "căpătuit",
    "căpătuiții": "căpătuit",
    "căpătuiților": "căpătuit",
    "căpătuito": "căpătuit",
    "căpătuitul": "căpătuit",
    "căpătuitule": "căpătuit",
    "căpătuitului": "căpătuit",
    "capcana": "capcană",
    "capcane": "capcană",
    "capcanei": "capcană",
    "capcanele": "capcană",
    "capcanelor": "capcană",
    "capcano": "capcană",
    "căpcăuni": "căpcăun",
    "căpcăunii": "căpcăun",
    "căpcăunilor": "căpcăun",
    "căpcăunul": "căpcăun",
    "căpcăunule": "căpcăun",
    "căpcăunului": "căpcăun",
    "capela": "capelă",
    "capele": "capelă",
    "capelei": "capelă",
    "capelele": "capelă",
    "capelelor": "capelă",
    "capelo": "capelă",
    "capelani": "capelan",
    "capelanii": "capelan",
    "capelanilor": "capelan",
    "capelanul": "capelan",
    "capelanule": "capelan",
    "capelanului": "capelan",
    "capelmaiștri": "capelmaistru",
    "capelmaiștrii": "capelmaistru",
    "capelmaiștrilor": "capelmaistru",
    "capelmaistrul": "capelmaistru",
    "capelmaistrule": "capelmaistru",
    "capelmaistrului": "capelmaistru",
    "capeluța": "capeluță",
    "capeluțe": "capeluță",
    "capeluței": "capeluță",
    "capeluțele": "capeluță",
    "capeluțelor": "capeluță",
    "capeluțo": "capeluță",
    "căpețele": "căpețel",
    "căpețelele": "căpețel",
    "căpețelelor": "căpețel",
    "căpețelul": "căpețel",
    "căpețelule": "căpețel",
    "căpețelului": "căpețel",
    "căpetenia": "căpetenie",
    "căpeteniei": "căpetenie",
    "căpetenii": "căpetenie",
    "căpeteniile": "căpetenie",
    "căpeteniilor": "căpetenie",
    "căpetenio": "căpetenie",
    "căpiai": "căpia",
    "căpiam": "căpia",
    "căpiară": "căpia",
    "căpiarăm": "căpia",
    "căpiarăți": "căpia",
    "căpiase": "căpia",
    "căpiasem": "căpia",
    "căpiaseră": "căpia",
    "căpiaserăm": "căpia",
    "căpiaserăți": "căpia",
    "căpiaseși": "căpia",
    "căpiași": "căpia",
    "căpiat": "căpia",
    "căpiați": "căpia",
    "căpiatu": "căpia",
    "căpiau": "căpia",
    "căpiază": "căpia",
    "căpie": "căpia",
    "căpiem": "căpia",
    "căpiez": "căpia",
    "căpieze": "căpia",
    "căpiezi": "căpia",
    "căpiind": "căpia",
    "căpiindu": "căpia",
    "necăpiind": "căpia",
    "necăpiindu": "căpia",
    "nemaicăpiind": "căpia",
    "nemaicăpiindu": "căpia",
    "căpiala": "căpială",
    "căpialo": "căpială",
    "căpieli": "căpială",
    "căpielii": "căpială",
    "căpielile": "căpială",
    "căpielilor": "căpială",
    "căpiata": "căpiat",
    "căpiată": "căpiat",
    "căpiate": "căpiat",
    "căpiatei": "căpiat",
    "căpiatele": "căpiat",
    "căpiatelor": "căpiat",
    "căpiați": "căpiat",
    "căpiații": "căpiat",
    "căpiaților": "căpiat",
    "căpiato": "căpiat",
    "căpiatul": "căpiat",
    "căpiatule": "căpiat",
    "căpiatului": "căpiat",
    "căpierea": "căpiere",
    "căpiereo": "căpiere",
    "căpieri": "căpiere",
    "căpierii": "căpiere",
    "căpierile": "căpiere",
    "căpierilor": "căpiere",
    "capilara": "capilar",
    "capilară": "capilar",
    "capilare": "capilar",
    "capilarei": "capilar",
    "capilarele": "capilar",
    "capilarelor": "capilar",
    "capilari": "capilar",
    "capilarii": "capilar",
    "capilarilor": "capilar",
    "capilaro": "capilar",
    "capilarul": "capilar",
    "capilarule": "capilar",
    "capilarului": "capilar",
    "capișoane": "capișon",
    "capișoanele": "capișon",
    "capișoanelor": "capișon",
    "capișonul": "capișon",
    "capișonule": "capișon",
    "capișonului": "capișon",
    "căpița": "căpiță",
    "căpițe": "căpiță",
    "căpiței": "căpiță",
    "căpițele": "căpiță",
    "căpițelor": "căpiță",
    "căpițo": "căpiță",
    "capitala": "capital",
    "capitală": "capital",
    "capitale": "capital",
    "capitalei": "capital",
    "capitalele": "capital",
    "capitalelor": "capital",
    "capitali": "capital",
    "capitalii": "capital",
    "capitalilor": "capital",
    "capitalo": "capital",
    "capitalul": "capital",
    "capitalule": "capital",
    "capitalului": "capital",
    "capitaluri": "capital",
    "capitalurile": "capital",
    "capitalurilor": "capital",
    "capitala": "capitală",
    "capitale": "capitală",
    "capitalei": "capitală",
    "capitalele": "capitală",
    "capitalelor": "capitală",
    "capitalo": "capitală",
    "capitălașe": "capitălaș",
    "capitălașele": "capitălaș",
    "capitălașelor": "capitălaș",
    "capitălașul": "capitălaș",
    "capitălașule": "capitălaș",
    "capitălașului": "capitălaș",
    "căpitălașe": "căpitălaș",
    "căpitălașele": "căpitălaș",
    "căpitălașelor": "căpitălaș",
    "căpitălașul": "căpitălaș",
    "căpitălașule": "căpitălaș",
    "căpitălașului": "căpitălaș",
    "capitalismul": "capitalism",
    "capitalismule": "capitalism",
    "capitalismului": "capitalism",
    "capitalista": "capitalist",
    "capitalistă": "capitalist",
    "capitaliste": "capitalist",
    "capitalistei": "capitalist",
    "capitalistele": "capitalist",
    "capitalistelor": "capitalist",
    "capitaliști": "capitalist",
    "capitaliștii": "capitalist",
    "capitaliștilor": "capitalist",
    "capitalisto": "capitalist",
    "capitalistul": "capitalist",
    "capitalistule": "capitalist",
    "capitalistului": "capitalist",
    "capitalista": "capitalistă",
    "capitaliste": "capitalistă",
    "capitalistei": "capitalistă",
    "capitalistele": "capitalistă",
    "capitalistelor": "capitalistă",
    "capitalisto": "capitalistă",
    "capitaliză": "capitaliza",
    "capitalizai": "capitaliza",
    "capitalizam": "capitaliza",
    "capitalizăm": "capitaliza",
    "capitalizând": "capitaliza",
    "capitalizându": "capitaliza",
    "capitalizară": "capitaliza",
    "capitalizarăm": "capitaliza",
    "capitalizarăți": "capitaliza",
    "capitalizase": "capitaliza",
    "capitalizasem": "capitaliza",
    "capitalizaseră": "capitaliza",
    "capitalizaserăm": "capitaliza",
    "capitalizaserăți": "capitaliza",
    "capitalizaseși": "capitaliza",
    "capitalizași": "capitaliza",
    "capitalizat": "capitaliza",
    "capitalizați": "capitaliza",
    "capitalizatu": "capitaliza",
    "capitalizau": "capitaliza",
    "capitalizează": "capitaliza",
    "capitalizez": "capitaliza",
    "capitalizeze": "capitaliza",
    "capitalizezi": "capitaliza",
    "necapitalizând": "capitaliza",
    "necapitalizându": "capitaliza",
    "nemaicapitalizând": "capitaliza",
    "nemaicapitalizându": "capitaliza",
    "capitalizarea": "capitalizare",
    "capitalizareo": "capitalizare",
    "capitalizări": "capitalizare",
    "capitalizării": "capitalizare",
    "capitalizările": "capitalizare",
    "capitalizărilor": "capitalizare",
    "capitalizată": "capitalizat",
    "capitalizate": "capitalizat",
    "capitalizați": "capitalizat",
    "căpitani": "căpitan",
    "căpitanii": "căpitan",
    "căpitanilor": "căpitan",
    "căpitanul": "căpitan",
    "căpitanule": "căpitan",
    "căpitanului": "căpitan",
    "căpitănași": "căpitănaș",
    "căpitănașii": "căpitănaș",
    "căpitănașilor": "căpitănaș",
    "căpitănașul": "căpitănaș",
    "căpitănașule": "căpitănaș",
    "căpitănașului": "căpitănaș",
    "căpităneasa": "căpităneasă",
    "căpităneaso": "căpităneasă",
    "căpitănese": "căpităneasă",
    "căpitănesei": "căpităneasă",
    "căpitănesele": "căpităneasă",
    "căpităneselor": "căpităneasă",
    "căpitănia": "căpitănie",
    "căpităniei": "căpitănie",
    "căpitănii": "căpitănie",
    "căpităniile": "căpitănie",
    "căpităniilor": "căpitănie",
    "căpitănio": "căpitănie",
    "căpitani-locotenenți": "căpitan-locotenent",
    "capitelul": "capitel",
    "capitelule": "capitel",
    "capitelului": "capitel",
    "capiteluri": "capitel",
    "capitelurile": "capitel",
    "capitelurilor": "capitel",
    "cap.": "capitol",
    "capitole": "capitol",
    "capitolele": "capitol",
    "capitolelor": "capitol",
    "capitolul": "capitol",
    "capitolule": "capitol",
    "capitolului": "capitol",
    "capitonă": "capitona",
    "capitonai": "capitona",
    "capitonam": "capitona",
    "capitonăm": "capitona",
    "capitonând": "capitona",
    "capitonându": "capitona",
    "capitonară": "capitona",
    "capitonarăm": "capitona",
    "capitonarăți": "capitona",
    "capitonase": "capitona",
    "capitonasem": "capitona",
    "capitonaseră": "capitona",
    "capitonaserăm": "capitona",
    "capitonaserăți": "capitona",
    "capitonaseși": "capitona",
    "capitonași": "capitona",
    "capitonat": "capitona",
    "capitonați": "capitona",
    "capitonatu": "capitona",
    "capitonau": "capitona",
    "capitonează": "capitona",
    "capitonez": "capitona",
    "capitoneze": "capitona",
    "capitonezi": "capitona",
    "necapitonând": "capitona",
    "necapitonându": "capitona",
    "nemaicapitonând": "capitona",
    "nemaicapitonându": "capitona",
    "capitonarea": "capitonare",
    "capitonareo": "capitonare",
    "capitonări": "capitonare",
    "capitonării": "capitonare",
    "capitonările": "capitonare",
    "capitonărilor": "capitonare",
    "capitonata": "capitonat",
    "capitonată": "capitonat",
    "capitonate": "capitonat",
    "capitonatei": "capitonat",
    "capitonatele": "capitonat",
    "capitonatelor": "capitonat",
    "capitonați": "capitonat",
    "capitonații": "capitonat",
    "capitonaților": "capitonat",
    "capitonato": "capitonat",
    "capitonatul": "capitonat",
    "capitonatule": "capitonat",
    "capitonatului": "capitonat",
    "capitule": "capitul",
    "capitulele": "capitul",
    "capitulelor": "capitul",
    "capitulul": "capitul",
    "capitulule": "capitul",
    "capitulului": "capitul",
    "capitulă": "capitula",
    "capitulai": "capitula",
    "capitulam": "capitula",
    "capitulăm": "capitula",
    "capitulând": "capitula",
    "capitulându": "capitula",
    "capitulară": "capitula",
    "capitularăm": "capitula",
    "capitularăți": "capitula",
    "capitulase": "capitula",
    "capitulasem": "capitula",
    "capitulaseră": "capitula",
    "capitulaserăm": "capitula",
    "capitulaserăți": "capitula",
    "capitulaseși": "capitula",
    "capitulași": "capitula",
    "capitulat": "capitula",
    "capitulați": "capitula",
    "capitulatu": "capitula",
    "capitulau": "capitula",
    "capitulează": "capitula",
    "capitulez": "capitula",
    "capituleze": "capitula",
    "capitulezi": "capitula",
    "necapitulând": "capitula",
    "necapitulându": "capitula",
    "nemaicapitulând": "capitula",
    "nemaicapitulându": "capitula",
    "capitulanți": "capitulant",
    "capitulanții": "capitulant",
    "capitulanților": "capitulant",
    "capitulantul": "capitulant",
    "capitulantule": "capitulant",
    "capitulantului": "capitulant",
    "capitulanta": "capitulantă",
    "capitulante": "capitulantă",
    "capitulantei": "capitulantă",
    "capitulantele": "capitulantă",
    "capitulantelor": "capitulantă",
    "capitulanto": "capitulantă",
    "capitularea": "capitulare",
    "capitulareo": "capitulare",
    "capitulări": "capitulare",
    "capitulării": "capitulare",
    "capitulările": "capitulare",
    "capitulărilor": "capitulare",
    "capitulată": "capitulat",
    "capitulate": "capitulat",
    "capitulați": "capitulat",
    "capitulația": "capitulație",
    "capitulației": "capitulație",
    "capitulații": "capitulație",
    "capitulațiile": "capitulație",
    "capitulațiilor": "capitulație",
    "capitulațio": "capitulație",
    "capodopera": "capodoperă",
    "capodopere": "capodoperă",
    "capodoperei": "capodoperă",
    "capodoperele": "capodoperă",
    "capodoperelor": "capodoperă",
    "capodopero": "capodoperă",
    "cap.": "caporal",
    "caporali": "caporal",
    "caporalii": "caporal",
    "caporalilor": "caporal",
    "caporalul": "caporal",
    "caporalule": "caporal",
    "caporalului": "caporal",
    "capoate": "capot",
    "capoatele": "capot",
    "capoatelor": "capot",
    "capotul": "capot",
    "capotule": "capot",
    "capotului": "capot",
    "capotă": "capota",
    "capotai": "capota",
    "capotam": "capota",
    "capotăm": "capota",
    "capotând": "capota",
    "capotându": "capota",
    "capotară": "capota",
    "capotarăm": "capota",
    "capotarăți": "capota",
    "capotase": "capota",
    "capotasem": "capota",
    "capotaseră": "capota",
    "capotaserăm": "capota",
    "capotaserăți": "capota",
    "capotaseși": "capota",
    "capotași": "capota",
    "capotat": "capota",
    "capotați": "capota",
    "capotatu": "capota",
    "capotau": "capota",
    "capotează": "capota",
    "capotez": "capota",
    "capoteze": "capota",
    "capotezi": "capota",
    "necapotând": "capota",
    "necapotându": "capota",
    "nemaicapotând": "capota",
    "nemaicapotându": "capota",
    "capota": "capotă",
    "capote": "capotă",
    "capotei": "capotă",
    "capotele": "capotă",
    "capotelor": "capotă",
    "capoto": "capotă",
    "capotată": "capotat",
    "capotate": "capotat",
    "capotați": "capotat",
    "capoțele": "capoțel",
    "capoțelele": "capoțel",
    "capoțelelor": "capoțel",
    "capoțelul": "capoțel",
    "capoțelule": "capoțel",
    "capoțelului": "capoțel",
    "capra": "capră",
    "capre": "capră",
    "caprei": "capră",
    "caprele": "capră",
    "caprelor": "capră",
    "capro": "capră",
    "capra-neagră": "capră-neagră",
    "caprei-negre": "capră-neagră",
    "caprele-negre": "capră-neagră",
    "caprelor-negre": "capră-neagră",
    "capre-negre": "capră-neagră",
    "căprari": "căprar",
    "căprarii": "căprar",
    "căprarilor": "căprar",
    "căprarul": "căprar",
    "căprarule": "căprar",
    "căprarului": "căprar",
    "căprăria": "căprărie",
    "căprăriei": "căprărie",
    "căprării": "căprărie",
    "căprăriile": "căprărie",
    "căprăriilor": "căprărie",
    "căprărio": "căprărie",
    "căpreasca": "căpresc",
    "căprească": "căpresc",
    "căpreasco": "căpresc",
    "căprescul": "căpresc",
    "căprescule": "căpresc",
    "căprescului": "căpresc",
    "căprești": "căpresc",
    "căpreștii": "căpresc",
    "căpreștile": "căpresc",
    "căpreștilor": "căpresc",
    "capricioasa": "capricios",
    "capricioasă": "capricios",
    "capricioase": "capricios",
    "capricioasei": "capricios",
    "capricioasele": "capricios",
    "capricioaselor": "capricios",
    "capricioaso": "capricios",
    "capricioși": "capricios",
    "capricioșii": "capricios",
    "capricioșilor": "capricios",
    "capriciosul": "capricios",
    "capriciosule": "capricios",
    "capriciosului": "capricios",
    "capricii": "capriciu",
    "capriciile": "capriciu",
    "capriciilor": "capriciu",
    "capriciul": "capriciu",
    "capriciule": "capriciu",
    "capriciului": "capriciu",
    "capricorni": "capricorn",
    "capricornii": "capricorn",
    "capricornilor": "capricorn",
    "capricornul": "capricorn",
    "capricornule": "capricorn",
    "capricornului": "capricorn",
    "caprifoii": "caprifoi",
    "caprifoilor": "caprifoi",
    "caprifoiul": "caprifoi",
    "caprifoiule": "caprifoi",
    "caprifoiului": "caprifoi",
    "căprioara": "căprioară",
    "căprioare": "căprioară",
    "căprioarei": "căprioară",
    "căprioarele": "căprioară",
    "căprioarelor": "căprioară",
    "căprioaro": "căprioară",
    "căpriori": "căprior",
    "căpriorii": "căprior",
    "căpriorilor": "căprior",
    "căpriorul": "căprior",
    "căpriorule": "căprior",
    "căpriorului": "căprior",
    "căpriorași": "căprioraș",
    "căpriorașii": "căprioraș",
    "căpriorașilor": "căprioraș",
    "căpriorașul": "căprioraș",
    "căpriorașule": "căprioraș",
    "căpriorașului": "căprioraș",
    "căprișoara": "căprișoară",
    "căprișoare": "căprișoară",
    "căprișoarei": "căprișoară",
    "căprișoarele": "căprișoară",
    "căprișoarelor": "căprișoară",
    "căprișoaro": "căprișoară",
    "căprița": "căpriță",
    "căprițe": "căpriță",
    "căpriței": "căpriță",
    "căprițele": "căpriță",
    "căprițelor": "căpriță",
    "căprițo": "căpriță",
    "căprie": "căpriu",
    "căprii": "căpriu",
    "căpruie": "căprui",
    "capsă": "capsa",
    "capsai": "capsa",
    "capsam": "capsa",
    "capsăm": "capsa",
    "capsând": "capsa",
    "capsându": "capsa",
    "capsară": "capsa",
    "capsarăm": "capsa",
    "capsarăți": "capsa",
    "capsase": "capsa",
    "capsasem": "capsa",
    "capsaseră": "capsa",
    "capsaserăm": "capsa",
    "capsaserăți": "capsa",
    "capsaseși": "capsa",
    "capsași": "capsa",
    "capsat": "capsa",
    "capsați": "capsa",
    "capsatu": "capsa",
    "capsau": "capsa",
    "capsează": "capsa",
    "capsez": "capsa",
    "capseze": "capsa",
    "capsezi": "capsa",
    "necapsând": "capsa",
    "necapsându": "capsa",
    "nemaicapsând": "capsa",
    "nemaicapsându": "capsa",
    "capsa": "capsă",
    "capse": "capsă",
    "capsei": "capsă",
    "capsele": "capsă",
    "capselor": "capsă",
    "capso": "capsă",
    "capsată": "capsat",
    "capsate": "capsat",
    "capsați": "capsat",
    "capsomani": "capsoman",
    "capsomanii": "capsoman",
    "capsomanilor": "capsoman",
    "capsomanul": "capsoman",
    "capsomanule": "capsoman",
    "capsomanului": "capsoman",
    "capsomana": "capsomană",
    "capsomane": "capsomană",
    "capsomanei": "capsomană",
    "capsomanele": "capsomană",
    "capsomanelor": "capsomană",
    "capsomano": "capsomană",
    "căpșoare": "căpșor",
    "căpșoarele": "căpșor",
    "căpșoarelor": "căpșor",
    "căpșorul": "căpșor",
    "căpșorule": "căpșor",
    "căpșorului": "căpșor",
    "capsula": "capsulă",
    "capsule": "capsulă",
    "capsulei": "capsulă",
    "capsulele": "capsulă",
    "capsulelor": "capsulă",
    "capsulo": "capsulă",
    "capsulara": "capsular",
    "capsulară": "capsular",
    "capsulare": "capsular",
    "capsularei": "capsular",
    "capsularele": "capsular",
    "capsularelor": "capsular",
    "capsulari": "capsular",
    "capsularii": "capsular",
    "capsularilor": "capsular",
    "capsularo": "capsular",
    "capsularul": "capsular",
    "capsularule": "capsular",
    "capsularului": "capsular",
    "căpșuni": "căpșun",
    "căpșunii": "căpșun",
    "căpșunilor": "căpșun",
    "căpșunul": "căpșun",
    "căpșunule": "căpșun",
    "căpșunului": "căpșun",
    "căpșuna": "căpșună",
    "căpșuni": "căpșună",
    "căpșunii": "căpșună",
    "căpșunile": "căpșună",
    "căpșunilor": "căpșună",
    "căpșuno": "căpșună",
    "captă": "capta",
    "captai": "capta",
    "captam": "capta",
    "captăm": "capta",
    "captând": "capta",
    "captându": "capta",
    "captară": "capta",
    "captarăm": "capta",
    "captarăți": "capta",
    "captase": "capta",
    "captasem": "capta",
    "captaseră": "capta",
    "captaserăm": "capta",
    "captaserăți": "capta",
    "captaseși": "capta",
    "captași": "capta",
    "captat": "capta",
    "captați": "capta",
    "captatu": "capta",
    "captau": "capta",
    "captează": "capta",
    "captez": "capta",
    "capteze": "capta",
    "captezi": "capta",
    "necaptând": "capta",
    "necaptându": "capta",
    "nemaicaptând": "capta",
    "nemaicaptându": "capta",
    "captabila": "captabil",
    "captabilă": "captabil",
    "captabile": "captabil",
    "captabilei": "captabil",
    "captabilele": "captabil",
    "captabilelor": "captabil",
    "captabili": "captabil",
    "captabilii": "captabil",
    "captabililor": "captabil",
    "captabilo": "captabil",
    "captabilul": "captabil",
    "captabilule": "captabil",
    "captabilului": "captabil",
    "captarea": "captare",
    "captareo": "captare",
    "captări": "captare",
    "captării": "captare",
    "captările": "captare",
    "captărilor": "captare",
    "captată": "captat",
    "captate": "captat",
    "captați": "captat",
    "captiva": "captiv",
    "captivă": "captiv",
    "captive": "captiv",
    "captivei": "captiv",
    "captivele": "captiv",
    "captivelor": "captiv",
    "captivi": "captiv",
    "captivii": "captiv",
    "captivilor": "captiv",
    "captivo": "captiv",
    "captivul": "captiv",
    "captivule": "captiv",
    "captivului": "captiv",
    "captivă": "captiva",
    "captivai": "captiva",
    "captivam": "captiva",
    "captivăm": "captiva",
    "captivând": "captiva",
    "captivându": "captiva",
    "captivară": "captiva",
    "captivarăm": "captiva",
    "captivarăți": "captiva",
    "captivase": "captiva",
    "captivasem": "captiva",
    "captivaseră": "captiva",
    "captivaserăm": "captiva",
    "captivaserăți": "captiva",
    "captivaseși": "captiva",
    "captivași": "captiva",
    "captivat": "captiva",
    "captivați": "captiva",
    "captivatu": "captiva",
    "captivau": "captiva",
    "captivează": "captiva",
    "captivez": "captiva",
    "captiveze": "captiva",
    "captivezi": "captiva",
    "necaptivând": "captiva",
    "necaptivându": "captiva",
    "nemaicaptivând": "captiva",
    "nemaicaptivându": "captiva",
    "captiva": "captivă",
    "captive": "captivă",
    "captivei": "captivă",
    "captivele": "captivă",
    "captivelor": "captivă",
    "captivanta": "captivant",
    "captivantă": "captivant",
    "captivante": "captivant",
    "captivantei": "captivant",
    "captivantele": "captivant",
    "captivantelor": "captivant",
    "captivanți": "captivant",
    "captivanții": "captivant",
    "captivanților": "captivant",
    "captivanto": "captivant",
    "captivantul": "captivant",
    "captivantule": "captivant",
    "captivantului": "captivant",
    "captivarea": "captivare",
    "captivareo": "captivare",
    "captivări": "captivare",
    "captivării": "captivare",
    "captivările": "captivare",
    "captivărilor": "captivare",
    "captivata": "captivat",
    "captivată": "captivat",
    "captivate": "captivat",
    "captivatei": "captivat",
    "captivatele": "captivat",
    "captivatelor": "captivat",
    "captivați": "captivat",
    "captivații": "captivat",
    "captivaților": "captivat",
    "captivato": "captivat",
    "captivatul": "captivat",
    "captivatule": "captivat",
    "captivatului": "captivat",
    "captivitatea": "captivitate",
    "captivitateo": "captivitate",
    "captivități": "captivitate",
    "captivității": "captivitate",
    "captivitățile": "captivitate",
    "captivităților": "captivitate",
    "captură": "captura",
    "capturai": "captura",
    "capturam": "captura",
    "capturăm": "captura",
    "capturând": "captura",
    "capturându": "captura",
    "capturară": "captura",
    "capturarăm": "captura",
    "capturarăți": "captura",
    "capturase": "captura",
    "capturasem": "captura",
    "capturaseră": "captura",
    "capturaserăm": "captura",
    "capturaserăți": "captura",
    "capturaseși": "captura",
    "capturași": "captura",
    "capturat": "captura",
    "capturați": "captura",
    "capturatu": "captura",
    "capturau": "captura",
    "capturează": "captura",
    "capturez": "captura",
    "captureze": "captura",
    "capturezi": "captura",
    "necapturând": "captura",
    "necapturându": "captura",
    "nemaicapturând": "captura",
    "nemaicapturându": "captura",
    "captura": "captură",
    "capturi": "captură",
    "capturii": "captură",
    "capturile": "captură",
    "capturilor": "captură",
    "capturo": "captură",
    "capturarea": "capturare",
    "capturareo": "capturare",
    "capturări": "capturare",
    "capturării": "capturare",
    "capturările": "capturare",
    "capturărilor": "capturare",
    "capturată": "capturat",
    "capturate": "capturat",
    "capturați": "capturat",
    "căptușea": "căptuși",
    "căptușeai": "căptuși",
    "căptușeam": "căptuși",
    "căptușească": "căptuși",
    "căptușeați": "căptuși",
    "căptușeau": "căptuși",
    "căptușesc": "căptuși",
    "căptușește": "căptuși",
    "căptușești": "căptuși",
    "căptușii": "căptuși",
    "căptușim": "căptuși",
    "căptușind": "căptuși",
    "căptușindu": "căptuși",
    "căptușiră": "căptuși",
    "căptușirăm": "căptuși",
    "căptușirăți": "căptuși",
    "căptușise": "căptuși",
    "căptușisem": "căptuși",
    "căptușiseră": "căptuși",
    "căptușiserăm": "căptuși",
    "căptușiserăți": "căptuși",
    "căptușiseși": "căptuși",
    "căptușiși": "căptuși",
    "căptușit": "căptuși",
    "căptușiți": "căptuși",
    "căptușitu": "căptuși",
    "necăptușind": "căptuși",
    "necăptușindu": "căptuși",
    "nemaicăptușind": "căptuși",
    "nemaicăptușindu": "căptuși",
    "căptușirea": "căptușire",
    "căptușireo": "căptușire",
    "căptușiri": "căptușire",
    "căptușirii": "căptușire",
    "căptușirile": "căptușire",
    "căptușirilor": "căptușire",
    "căptușită": "căptușit",
    "căptușite": "căptușit",
    "căptușiți": "căptușit",
    "capucina": "capucin",
    "capucină": "capucin",
    "capucine": "capucin",
    "capucinei": "capucin",
    "capucinele": "capucin",
    "capucinelor": "capucin",
    "capucini": "capucin",
    "capucinii": "capucin",
    "capucinilor": "capucin",
    "capucino": "capucin",
    "capucinul": "capucin",
    "capucinule": "capucin",
    "capucinului": "capucin",
    "capucina": "capucină",
    "capucine": "capucină",
    "capucinei": "capucină",
    "capucinele": "capucină",
    "capucinelor": "capucină",
    "capucino": "capucină",
    "căpușa": "căpușă",
    "căpușe": "căpușă",
    "căpușei": "căpușă",
    "căpușele": "căpușă",
    "căpușelor": "căpușă",
    "căpușo": "căpușă",
    "căputa": "căpută",
    "căpute": "căpută",
    "căputei": "căpută",
    "căputele": "căpută",
    "căputelor": "căpută",
    "căputo": "căpută",
    "care": "car",
    "carele": "car",
    "carelor": "car",
    "cari": "car",
    "carii": "car",
    "carilor": "car",
    "carul": "car",
    "carule": "car",
    "carului": "car",
    "caruri": "car",
    "carurile": "car",
    "carurilor": "car",
    "câra": "câră",
    "cârâi": "câră",
    "cârâii": "câră",
    "câro": "câră",
    "car": "căra",
    "cară": "căra",
    "cără": "căra",
    "cărai": "căra",
    "căram": "căra",
    "cărăm": "căra",
    "cărând": "căra",
    "cărându": "căra",
    "cărară": "căra",
    "cărarăm": "căra",
    "cărarăți": "căra",
    "cărase": "căra",
    "cărasem": "căra",
    "căraseră": "căra",
    "căraserăm": "căra",
    "căraserăți": "căra",
    "căraseși": "căra",
    "cărași": "căra",
    "cărat": "căra",
    "cărați": "căra",
    "căratu": "căra",
    "cărau": "căra",
    "care": "căra",
    "cari": "căra",
    "necărând": "căra",
    "necărându": "căra",
    "nemaicărând": "căra",
    "nemaicărându": "căra",
    "cărăbănea": "cărăbăni",
    "cărăbăneai": "cărăbăni",
    "cărăbăneam": "cărăbăni",
    "cărăbănească": "cărăbăni",
    "cărăbăneați": "cărăbăni",
    "cărăbăneau": "cărăbăni",
    "cărăbănesc": "cărăbăni",
    "cărăbănește": "cărăbăni",
    "cărăbănești": "cărăbăni",
    "cărăbănii": "cărăbăni",
    "cărăbănim": "cărăbăni",
    "cărăbănind": "cărăbăni",
    "cărăbănindu": "cărăbăni",
    "cărăbăniră": "cărăbăni",
    "cărăbănirăm": "cărăbăni",
    "cărăbănirăți": "cărăbăni",
    "cărăbănise": "cărăbăni",
    "cărăbănisem": "cărăbăni",
    "cărăbăniseră": "cărăbăni",
    "cărăbăniserăm": "cărăbăni",
    "cărăbăniserăți": "cărăbăni",
    "cărăbăniseși": "cărăbăni",
    "cărăbăniși": "cărăbăni",
    "cărăbănit": "cărăbăni",
    "cărăbăniți": "cărăbăni",
    "cărăbănitu": "cărăbăni",
    "necărăbănind": "cărăbăni",
    "necărăbănindu": "cărăbăni",
    "nemaicărăbănind": "cărăbăni",
    "nemaicărăbănindu": "cărăbăni",
    "cărăbănită": "cărăbănit",
    "cărăbănite": "cărăbănit",
    "cărăbăniți": "cărăbănit",
    "carabina": "carabină",
    "carabine": "carabină",
    "carabinei": "carabină",
    "carabinele": "carabină",
    "carabinelor": "carabină",
    "carabino": "carabină",
    "carabinieri": "carabinier",
    "carabinierii": "carabinier",
    "carabinierilor": "carabinier",
    "carabinierul": "carabinier",
    "carabinierule": "carabinier",
    "carabinierului": "carabinier",
    "cărăbuși": "cărăbuș",
    "cărăbușii": "cărăbuș",
    "cărăbușilor": "cărăbuș",
    "cărăbușul": "cărăbuș",
    "cărăbușule": "cărăbuș",
    "cărăbușului": "cărăbuș",
    "caracatița": "caracatiță",
    "caracatițe": "caracatiță",
    "caracatiței": "caracatiță",
    "caracatițele": "caracatiță",
    "caracatițelor": "caracatiță",
    "caracatițo": "caracatiță",
    "caractere": "caracter",
    "caracterele": "caracter",
    "caracterelor": "caracter",
    "caracterul": "caracter",
    "caracterule": "caracter",
    "caracterului": "caracter",
    "caracteristica": "caracteristic",
    "caracteristică": "caracteristic",
    "caracteristice": "caracteristic",
    "caracteristicei": "caracteristic",
    "caracteristicele": "caracteristic",
    "caracteristicelor": "caracteristic",
    "caracteristici": "caracteristic",
    "caracteristicii": "caracteristic",
    "caracteristicilor": "caracteristic",
    "caracteristico": "caracteristic",
    "caracteristicul": "caracteristic",
    "caracteristicule": "caracteristic",
    "caracteristicului": "caracteristic",
    "caracteristica": "caracteristică",
    "caracteristicei": "caracteristică",
    "caracteristici": "caracteristică",
    "caracteristicile": "caracteristică",
    "caracteristicilor": "caracteristică",
    "caracteristico": "caracteristică",
    "caracteriză": "caracteriza",
    "caracterizai": "caracteriza",
    "caracterizam": "caracteriza",
    "caracterizăm": "caracteriza",
    "caracterizând": "caracteriza",
    "caracterizându": "caracteriza",
    "caracterizară": "caracteriza",
    "caracterizarăm": "caracteriza",
    "caracterizarăți": "caracteriza",
    "caracterizase": "caracteriza",
    "caracterizasem": "caracteriza",
    "caracterizaseră": "caracteriza",
    "caracterizaserăm": "caracteriza",
    "caracterizaserăți": "caracteriza",
    "caracterizaseși": "caracteriza",
    "caracterizași": "caracteriza",
    "caracterizat": "caracteriza",
    "caracterizați": "caracteriza",
    "caracterizatu": "caracteriza",
    "caracterizau": "caracteriza",
    "caracterizează": "caracteriza",
    "caracterizez": "caracteriza",
    "caracterizeze": "caracteriza",
    "caracterizezi": "caracteriza",
    "necaracterizând": "caracteriza",
    "necaracterizându": "caracteriza",
    "nemaicaracterizând": "caracteriza",
    "nemaicaracterizându": "caracteriza",
    "caracterizarea": "caracterizare",
    "caracterizareo": "caracterizare",
    "caracterizări": "caracterizare",
    "caracterizării": "caracterizare",
    "caracterizările": "caracterizare",
    "caracterizărilor": "caracterizare",
    "caracterizată": "caracterizat",
    "caracterizate": "caracterizat",
    "caracterizați": "caracterizat",
    "caracterizatoare": "caracterizator",
    "caracterizatoarea": "caracterizator",
    "caracterizatoarei": "caracterizator",
    "caracterizatoarele": "caracterizator",
    "caracterizatoarelor": "caracterizator",
    "caracterizatoareo": "caracterizator",
    "caracterizatori": "caracterizator",
    "caracterizatorii": "caracterizator",
    "caracterizatorilor": "caracterizator",
    "caracterizatorul": "caracterizator",
    "caracterizatorule": "caracterizator",
    "caracterizatorului": "caracterizator",
    "caracuda": "caracudă",
    "caracude": "caracudă",
    "caracudei": "caracudă",
    "caracudele": "caracudă",
    "caracudelor": "caracudă",
    "caracudo": "caracudă",
    "caraculul": "caracul",
    "caraculule": "caracul",
    "caraculului": "caracul",
    "caraculuri": "caracul",
    "caraculurile": "caracul",
    "caraculurilor": "caracul",
    "carafa": "carafă",
    "carafe": "carafă",
    "carafei": "carafă",
    "carafele": "carafă",
    "carafelor": "carafă",
    "carafo": "carafă",
    "caragața": "caragață",
    "caragațe": "caragață",
    "caragaței": "caragață",
    "caragațele": "caragață",
    "caragațelor": "caragață",
    "caragațo": "caragață",
    "caraghioasa": "caraghios",
    "caraghioasă": "caraghios",
    "caraghioase": "caraghios",
    "caraghioasei": "caraghios",
    "caraghioasele": "caraghios",
    "caraghioaselor": "caraghios",
    "caraghioaso": "caraghios",
    "caraghioși": "caraghios",
    "caraghioșii": "caraghios",
    "caraghioșilor": "caraghios",
    "caraghiosul": "caraghios",
    "caraghiosule": "caraghios",
    "caraghiosului": "caraghios",
    "caraghioslâcul": "caraghioslâc",
    "caraghioslâcule": "caraghioslâc",
    "caraghioslâcului": "caraghioslâc",
    "caraghioslâcuri": "caraghioslâc",
    "caraghioslâcurile": "caraghioslâc",
    "caraghioslâcurilor": "caraghioslâc",
    "cârâia": "cârâi",
    "cârâiai": "cârâi",
    "cârâiam": "cârâi",
    "cârâiați": "cârâi",
    "cârâiau": "cârâi",
    "cârâie": "cârâi",
    "cârâii": "cârâi",
    "cârâim": "cârâi",
    "cârâind": "cârâi",
    "cârâindu": "cârâi",
    "cârâiră": "cârâi",
    "cârâirăm": "cârâi",
    "cârâirăți": "cârâi",
    "cârâise": "cârâi",
    "cârâisem": "cârâi",
    "cârâiseră": "cârâi",
    "cârâiserăm": "cârâi",
    "cârâiserăți": "cârâi",
    "cârâiseși": "cârâi",
    "cârâiși": "cârâi",
    "cârâit": "cârâi",
    "cârâiți": "cârâi",
    "cârâitu": "cârâi",
    "necârâind": "cârâi",
    "necârâindu": "cârâi",
    "nemaicârâind": "cârâi",
    "nemaicârâindu": "cârâi",
    "cârâiala": "cârâială",
    "cârâialo": "cârâială",
    "cârâieli": "cârâială",
    "cârâielii": "cârâială",
    "cârâielile": "cârâială",
    "cârâielilor": "cârâială",
    "cârâia": "cârâie",
    "cârâiei": "cârâie",
    "cârâiele": "cârâie",
    "cârâielor": "cârâie",
    "cârâio": "cârâie",
    "cârâita": "cârâit",
    "cârâită": "cârâit",
    "cârâite": "cârâit",
    "cârâitei": "cârâit",
    "cârâitele": "cârâit",
    "cârâitelor": "cârâit",
    "cârâiți": "cârâit",
    "cârâiții": "cârâit",
    "cârâiților": "cârâit",
    "cârâito": "cârâit",
    "cârâitul": "cârâit",
    "cârâitule": "cârâit",
    "cârâitului": "cârâit",
    "cârâitoare": "cârâitor",
    "cârâitoarea": "cârâitor",
    "cârâitoarei": "cârâitor",
    "cârâitoarele": "cârâitor",
    "cârâitoarelor": "cârâitor",
    "cârâitoareo": "cârâitor",
    "cârâitori": "cârâitor",
    "cârâitorii": "cârâitor",
    "cârâitorilor": "cârâitor",
    "cârâitorul": "cârâitor",
    "cârâitorule": "cârâitor",
    "cârâitorului": "cârâitor",
    "caralii": "caraliu",
    "caraliii": "caraliu",
    "caraliilor": "caraliu",
    "caraliul": "caraliu",
    "caraliule": "caraliu",
    "caraliului": "caraliu",
    "carâmbi": "carâmb",
    "carâmbii": "carâmb",
    "carâmbilor": "carâmb",
    "carâmbul": "carâmb",
    "carâmbule": "carâmb",
    "carâmbului": "carâmb",
    "carambolul": "carambol",
    "carambolule": "carambol",
    "carambolului": "carambol",
    "caramboluri": "carambol",
    "carambolurile": "carambol",
    "carambolurilor": "carambol",
    "carambolaje": "carambolaj",
    "carambolajele": "carambolaj",
    "carambolajelor": "carambolaj",
    "carambolajul": "carambolaj",
    "carambolajule": "carambolaj",
    "carambolajului": "carambolaj",
    "caramelul": "caramel",
    "caramelule": "caramel",
    "caramelului": "caramel",
    "carameluri": "caramel",
    "caramelurile": "caramel",
    "caramelurilor": "caramel",
    "cărămida": "cărămidă",
    "cărămido": "cărămidă",
    "cărămizi": "cărămidă",
    "cărămizii": "cărămidă",
    "cărămizile": "cărămidă",
    "cărămizilor": "cărămidă",
    "cărămidari": "cărămidar",
    "cărămidarii": "cărămidar",
    "cărămidarilor": "cărămidar",
    "cărămidarul": "cărămidar",
    "cărămidarule": "cărămidar",
    "cărămidarului": "cărămidar",
    "cărămidăria": "cărămidărie",
    "cărămidăriei": "cărămidărie",
    "cărămidării": "cărămidărie",
    "cărămidăriile": "cărămidărie",
    "cărămidăriilor": "cărămidărie",
    "cărămidărio": "cărămidărie",
    "cărămizia": "cărămiziu",
    "cărămizie": "cărămiziu",
    "cărămiziei": "cărămiziu",
    "cărămizii": "cărămiziu",
    "cărămiziii": "cărămiziu",
    "cărămiziile": "cărămiziu",
    "cărămiziilor": "cărămiziu",
    "cărămizio": "cărămiziu",
    "cărămiziul": "cărămiziu",
    "cărămiziule": "cărămiziu",
    "cărămiziului": "cărămiziu",
    "carantina": "carantină",
    "carantine": "carantină",
    "carantinei": "carantină",
    "carantinele": "carantină",
    "carantinelor": "carantină",
    "carantino": "carantină",
    "carapacea": "carapace",
    "carapacei": "carapace",
    "carapacele": "carapace",
    "carapacelor": "carapace",
    "carapaceo": "carapace",
    "cărarea": "cărare",
    "cărareo": "cărare",
    "cărări": "cărare",
    "cărării": "cărare",
    "cărările": "cărare",
    "cărărilor": "cărare",
    "cărăruica": "cărăruică",
    "cărăruici": "cărăruică",
    "cărăruicii": "cărăruică",
    "cărăruicile": "cărăruică",
    "cărăruicilor": "cărăruică",
    "cărăruico": "cărăruică",
    "cărărui": "cărăruie",
    "cărăruia": "cărăruie",
    "cărăruii": "cărăruie",
    "cărăruile": "cărăruie",
    "cărăruilor": "cărăruie",
    "cărăruio": "cărăruie",
    "cărărușa": "cărărușă",
    "cărărușe": "cărărușă",
    "cărărușei": "cărărușă",
    "cărărușele": "cărărușă",
    "cărărușelor": "cărărușă",
    "cărărușo": "cărărușă",
    "carași": "caras",
    "carașii": "caras",
    "carașilor": "caras",
    "carasul": "caras",
    "carasule": "caras",
    "carasului": "caras",
    "carate": "carat",
    "caratele": "carat",
    "caratelor": "carat",
    "caratul": "carat",
    "caratule": "carat",
    "caratului": "carat",
    "cărată": "cărat",
    "cărate": "cărat",
    "cărați": "cărat",
    "căratul": "cărat",
    "căratule": "cărat",
    "căratului": "cărat",
    "caraula": "caraulă",
    "caraule": "caraulă",
    "caraulei": "caraulă",
    "caraulele": "caraulă",
    "caraulelor": "caraulă",
    "caraulo": "caraulă",
    "cărăuși": "cărăuș",
    "cărăușii": "cărăuș",
    "cărăușilor": "cărăuș",
    "cărăușul": "cărăuș",
    "cărăușule": "cărăuș",
    "cărăușului": "cărăuș",
    "cărăușea": "cărăuși",
    "cărăușeai": "cărăuși",
    "cărăușeam": "cărăuși",
    "cărăușească": "cărăuși",
    "cărăușeați": "cărăuși",
    "cărăușeau": "cărăuși",
    "cărăușesc": "cărăuși",
    "cărăușește": "cărăuși",
    "cărăușești": "cărăuși",
    "cărăușii": "cărăuși",
    "cărăușim": "cărăuși",
    "cărăușind": "cărăuși",
    "cărăușindu": "cărăuși",
    "cărăușiră": "cărăuși",
    "cărăușirăm": "cărăuși",
    "cărăușirăți": "cărăuși",
    "cărăușise": "cărăuși",
    "cărăușisem": "cărăuși",
    "cărăușiseră": "cărăuși",
    "cărăușiserăm": "cărăuși",
    "cărăușiserăți": "cărăuși",
    "cărăușiseși": "cărăuși",
    "cărăușiși": "cărăuși",
    "cărăușit": "cărăuși",
    "cărăușiți": "cărăuși",
    "cărăușitu": "cărăuși",
    "necărăușind": "cărăuși",
    "necărăușindu": "cărăuși",
    "nemaicărăușind": "cărăuși",
    "nemaicărăușindu": "cărăuși",
    "cărăușia": "cărăușie",
    "cărăușiei": "cărăușie",
    "cărăușii": "cărăușie",
    "cărăușiile": "cărăușie",
    "cărăușiilor": "cărăușie",
    "cărăușio": "cărăușie",
    "cărăușită": "cărăușit",
    "cărăușite": "cărăușit",
    "cărăușitele": "cărăușit",
    "cărăușitelor": "cărăușit",
    "cărăușiți": "cărăușit",
    "cărăușitul": "cărăușit",
    "cărăușitule": "cărăușit",
    "cărăușitului": "cărăușit",
    "caravana": "caravană",
    "caravane": "caravană",
    "caravanei": "caravană",
    "caravanele": "caravană",
    "caravanelor": "caravană",
    "caravano": "caravană",
    "caravela": "caravelă",
    "caravele": "caravelă",
    "caravelei": "caravelă",
    "caravelele": "caravelă",
    "caravelelor": "caravelă",
    "caravelo": "caravelă",
    "carbidul": "carbid",
    "carbidule": "carbid",
    "carbidului": "carbid",
    "carbonul": "carbon",
    "carbonule": "carbon",
    "carbonului": "carbon",
    "carbonari": "carbonar",
    "carbonarii": "carbonar",
    "carbonarilor": "carbonar",
    "carbonarul": "carbonar",
    "carbonarule": "carbonar",
    "carbonarului": "carbonar",
    "carbonați": "carbonat",
    "carbonații": "carbonat",
    "carbonaților": "carbonat",
    "carbonatul": "carbonat",
    "carbonatule": "carbonat",
    "carbonatului": "carbonat",
    "carbonată": "carbonata",
    "carbonatai": "carbonata",
    "carbonatam": "carbonata",
    "carbonatăm": "carbonata",
    "carbonatând": "carbonata",
    "carbonatându": "carbonata",
    "carbonatară": "carbonata",
    "carbonatarăm": "carbonata",
    "carbonatarăți": "carbonata",
    "carbonatase": "carbonata",
    "carbonatasem": "carbonata",
    "carbonataseră": "carbonata",
    "carbonataserăm": "carbonata",
    "carbonataserăți": "carbonata",
    "carbonataseși": "carbonata",
    "carbonatași": "carbonata",
    "carbonatat": "carbonata",
    "carbonatați": "carbonata",
    "carbonatatu": "carbonata",
    "carbonatau": "carbonata",
    "carbonatează": "carbonata",
    "carbonatez": "carbonata",
    "carbonateze": "carbonata",
    "carbonatezi": "carbonata",
    "necarbonatând": "carbonata",
    "necarbonatându": "carbonata",
    "nemaicarbonatând": "carbonata",
    "nemaicarbonatându": "carbonata",
    "carbonatarea": "carbonatare",
    "carbonatareo": "carbonatare",
    "carbonatări": "carbonatare",
    "carbonatării": "carbonatare",
    "carbonatările": "carbonatare",
    "carbonatărilor": "carbonatare",
    "carbonatată": "carbonatat",
    "carbonatate": "carbonatat",
    "carbonatați": "carbonatat",
    "carbonica": "carbonic",
    "carbonică": "carbonic",
    "carbonice": "carbonic",
    "carbonicei": "carbonic",
    "carbonicele": "carbonic",
    "carbonicelor": "carbonic",
    "carbonici": "carbonic",
    "carbonicii": "carbonic",
    "carbonicilor": "carbonic",
    "carbonico": "carbonic",
    "carbonicul": "carbonic",
    "carbonicule": "carbonic",
    "carbonicului": "carbonic",
    "carbonifera": "carbonifer",
    "carboniferă": "carbonifer",
    "carbonifere": "carbonifer",
    "carboniferei": "carbonifer",
    "carboniferele": "carbonifer",
    "carboniferelor": "carbonifer",
    "carboniferi": "carbonifer",
    "carboniferii": "carbonifer",
    "carboniferilor": "carbonifer",
    "carbonifero": "carbonifer",
    "carboniferul": "carbonifer",
    "carboniferule": "carbonifer",
    "carboniferului": "carbonifer",
    "carboniză": "carboniza",
    "carbonizai": "carboniza",
    "carbonizam": "carboniza",
    "carbonizăm": "carboniza",
    "carbonizând": "carboniza",
    "carbonizându": "carboniza",
    "carbonizară": "carboniza",
    "carbonizarăm": "carboniza",
    "carbonizarăți": "carboniza",
    "carbonizase": "carboniza",
    "carbonizasem": "carboniza",
    "carbonizaseră": "carboniza",
    "carbonizaserăm": "carboniza",
    "carbonizaserăți": "carboniza",
    "carbonizaseși": "carboniza",
    "carbonizași": "carboniza",
    "carbonizat": "carboniza",
    "carbonizați": "carboniza",
    "carbonizatu": "carboniza",
    "carbonizau": "carboniza",
    "carbonizează": "carboniza",
    "carbonizez": "carboniza",
    "carbonizeze": "carboniza",
    "carbonizezi": "carboniza",
    "necarbonizând": "carboniza",
    "necarbonizându": "carboniza",
    "nemaicarbonizând": "carboniza",
    "nemaicarbonizându": "carboniza",
    "carbonizarea": "carbonizare",
    "carbonizareo": "carbonizare",
    "carbonizări": "carbonizare",
    "carbonizării": "carbonizare",
    "carbonizările": "carbonizare",
    "carbonizărilor": "carbonizare",
    "carbonizată": "carbonizat",
    "carbonizate": "carbonizat",
    "carbonizați": "carbonizat",
    "cărbunari": "cărbunar",
    "cărbunarii": "cărbunar",
    "cărbunarilor": "cărbunar",
    "cărbunarul": "cărbunar",
    "cărbunarule": "cărbunar",
    "cărbunarului": "cărbunar",
    "cărbunăria": "cărbunărie",
    "cărbunăriei": "cărbunărie",
    "cărbunării": "cărbunărie",
    "cărbunăriile": "cărbunărie",
    "cărbunăriilor": "cărbunărie",
    "cărbunărio": "cărbunărie",
    "cărbunași": "cărbunaș",
    "cărbunașii": "cărbunaș",
    "cărbunașilor": "cărbunaș",
    "cărbunașul": "cărbunaș",
    "cărbunașule": "cărbunaș",
    "cărbunașului": "cărbunaș",
    "cărbunele": "cărbune",
    "cărbunelui": "cărbune",
    "cărbuni": "cărbune",
    "cărbunii": "cărbune",
    "cărbunilor": "cărbune",
    "carbură": "carbura",
    "carburai": "carbura",
    "carburam": "carbura",
    "carburăm": "carbura",
    "carburând": "carbura",
    "carburându": "carbura",
    "carburară": "carbura",
    "carburarăm": "carbura",
    "carburarăți": "carbura",
    "carburase": "carbura",
    "carburasem": "carbura",
    "carburaseră": "carbura",
    "carburaserăm": "carbura",
    "carburaserăți": "carbura",
    "carburaseși": "carbura",
    "carburași": "carbura",
    "carburat": "carbura",
    "carburați": "carbura",
    "carburatu": "carbura",
    "carburau": "carbura",
    "carburează": "carbura",
    "carburez": "carbura",
    "carbureze": "carbura",
    "carburezi": "carbura",
    "necarburând": "carbura",
    "necarburându": "carbura",
    "nemaicarburând": "carbura",
    "nemaicarburându": "carbura",
    "carburanți": "carburant",
    "carburanții": "carburant",
    "carburanților": "carburant",
    "carburantul": "carburant",
    "carburantule": "carburant",
    "carburantului": "carburant",
    "carburarea": "carburare",
    "carburareo": "carburare",
    "carburări": "carburare",
    "carburării": "carburare",
    "carburările": "carburare",
    "carburărilor": "carburare",
    "carburată": "carburat",
    "carburate": "carburat",
    "carburați": "carburat",
    "carburatoare": "carburator",
    "carburatoarele": "carburator",
    "carburatoarelor": "carburator",
    "carburatorul": "carburator",
    "carburatorule": "carburator",
    "carburatorului": "carburator",
    "cârca": "cârcă",
    "cârcâia": "cârcâi",
    "cârcâiai": "cârcâi",
    "cârcâiam": "cârcâi",
    "cârcâiați": "cârcâi",
    "cârcâiau": "cârcâi",
    "cârcâie": "cârcâi",
    "cârcâii": "cârcâi",
    "cârcâim": "cârcâi",
    "cârcâind": "cârcâi",
    "cârcâindu": "cârcâi",
    "cârcâiră": "cârcâi",
    "cârcâirăm": "cârcâi",
    "cârcâirăți": "cârcâi",
    "cârcâise": "cârcâi",
    "cârcâisem": "cârcâi",
    "cârcâiseră": "cârcâi",
    "cârcâiserăm": "cârcâi",
    "cârcâiserăți": "cârcâi",
    "cârcâiseși": "cârcâi",
    "cârcâiși": "cârcâi",
    "cârcâit": "cârcâi",
    "cârcâiți": "cârcâi",
    "cârcâitu": "cârcâi",
    "necârcâind": "cârcâi",
    "necârcâindu": "cârcâi",
    "nemaicârcâind": "cârcâi",
    "nemaicârcâindu": "cârcâi",
    "cârcăiaci": "cârcăiac",
    "cârcăiacii": "cârcăiac",
    "cârcăiacilor": "cârcăiac",
    "cârcăiacul": "cârcăiac",
    "cârcăiacule": "cârcăiac",
    "cârcăiacului": "cârcăiac",
    "cârcâirea": "cârcâire",
    "cârcâireo": "cârcâire",
    "cârcâiri": "cârcâire",
    "cârcâirii": "cârcâire",
    "cârcâirile": "cârcâire",
    "cârcâirilor": "cârcâire",
    "cârcâită": "cârcâit",
    "cârcâite": "cârcâit",
    "cârcâiți": "cârcâit",
    "cârcâitul": "cârcâit",
    "cârcâitule": "cârcâit",
    "cârcâitului": "cârcâit",
    "cârcălea": "cârcăli",
    "cârcăleai": "cârcăli",
    "cârcăleam": "cârcăli",
    "cârcălească": "cârcăli",
    "cârcăleați": "cârcăli",
    "cârcăleau": "cârcăli",
    "cârcălesc": "cârcăli",
    "cârcălește": "cârcăli",
    "cârcălești": "cârcăli",
    "cârcălii": "cârcăli",
    "cârcălim": "cârcăli",
    "cârcălind": "cârcăli",
    "cârcălindu": "cârcăli",
    "cârcăliră": "cârcăli",
    "cârcălirăm": "cârcăli",
    "cârcălirăți": "cârcăli",
    "cârcălise": "cârcăli",
    "cârcălisem": "cârcăli",
    "cârcăliseră": "cârcăli",
    "cârcăliserăm": "cârcăli",
    "cârcăliserăți": "cârcăli",
    "cârcăliseși": "cârcăli",
    "cârcăliși": "cârcăli",
    "cârcălit": "cârcăli",
    "cârcăliți": "cârcăli",
    "cârcălitu": "cârcăli",
    "necârcălind": "cârcăli",
    "necârcălindu": "cârcăli",
    "nemaicârcălind": "cârcăli",
    "nemaicârcălindu": "cârcăli",
    "cârcălită": "cârcălit",
    "cârcălite": "cârcălit",
    "cârcăliți": "cârcălit",
    "carcasa": "carcasă",
    "carcase": "carcasă",
    "carcasei": "carcasă",
    "carcasele": "carcasă",
    "carcaselor": "carcasă",
    "carcaso": "carcasă",
    "cârcei": "cârcel",
    "cârceii": "cârcel",
    "cârceilor": "cârcel",
    "cârcelul": "cârcel",
    "cârcelule": "cârcel",
    "cârcelului": "cârcel",
    "carcera": "carceră",
    "carcere": "carceră",
    "carcerei": "carceră",
    "carcerele": "carceră",
    "carcerelor": "carceră",
    "carcero": "carceră",
    "cârciogul": "cârciog",
    "cârciogule": "cârciog",
    "cârciogului": "cârciog",
    "cârcioguri": "cârciog",
    "cârciogurile": "cârciog",
    "cârciogurilor": "cârciog",
    "cârciogari": "cârciogar",
    "cârciogarii": "cârciogar",
    "cârciogarilor": "cârciogar",
    "cârciogarul": "cârciogar",
    "cârciogarule": "cârciogar",
    "cârciogarului": "cârciogar",
    "cârciuma": "cârciumă",
    "cârciumi": "cârciumă",
    "cârciumii": "cârciumă",
    "cârciumile": "cârciumă",
    "cârciumilor": "cârciumă",
    "cârciumo": "cârciumă",
    "cârciumari": "cârciumar",
    "cârciumarii": "cârciumar",
    "cârciumarilor": "cârciumar",
    "cârciumarul": "cârciumar",
    "cârciumarule": "cârciumar",
    "cârciumarului": "cârciumar",
    "cârciumăreasa": "cârciumăreasă",
    "cârciumăreaso": "cârciumăreasă",
    "cârciumărese": "cârciumăreasă",
    "cârciumăresei": "cârciumăreasă",
    "cârciumăresele": "cârciumăreasă",
    "cârciumăreselor": "cârciumăreasă",
    "cârciumăritul": "cârciumărit",
    "cârciumăritule": "cârciumărit",
    "cârciumăritului": "cârciumărit",
    "cârciumărița": "cârciumăriță",
    "cârciumărițe": "cârciumăriță",
    "cârciumăriței": "cârciumăriță",
    "cârciumărițele": "cârciumăriță",
    "cârciumărițelor": "cârciumăriță",
    "cârciumărițo": "cârciumăriță",
    "cârciumioara": "cârciumioară",
    "cârciumioare": "cârciumioară",
    "cârciumioarei": "cârciumioară",
    "cârciumioarele": "cârciumioară",
    "cârciumioarelor": "cârciumioară",
    "cârciumioaro": "cârciumioară",
    "cârcota": "cârcotă",
    "cârcote": "cârcotă",
    "cârcotei": "cârcotă",
    "cârcotele": "cârcotă",
    "cârcotelor": "cârcotă",
    "cârcoto": "cârcotă",
    "cârcotași": "cârcotaș",
    "cârcotașii": "cârcotaș",
    "cârcotașilor": "cârcotaș",
    "cârcotașul": "cârcotaș",
    "cârcotașule": "cârcotaș",
    "cârcotașului": "cârcotaș",
    "cârcotea": "cârcoti",
    "cârcoteai": "cârcoti",
    "cârcoteam": "cârcoti",
    "cârcotească": "cârcoti",
    "cârcoteați": "cârcoti",
    "cârcoteau": "cârcoti",
    "cârcotesc": "cârcoti",
    "cârcotește": "cârcoti",
    "cârcotești": "cârcoti",
    "cârcotii": "cârcoti",
    "cârcotim": "cârcoti",
    "cârcotind": "cârcoti",
    "cârcotindu": "cârcoti",
    "cârcotiră": "cârcoti",
    "cârcotirăm": "cârcoti",
    "cârcotirăți": "cârcoti",
    "cârcotise": "cârcoti",
    "cârcotisem": "cârcoti",
    "cârcotiseră": "cârcoti",
    "cârcotiserăm": "cârcoti",
    "cârcotiserăți": "cârcoti",
    "cârcotiseși": "cârcoti",
    "cârcotiși": "cârcoti",
    "cârcotit": "cârcoti",
    "cârcotiți": "cârcoti",
    "cârcotitu": "cârcoti",
    "necârcotind": "cârcoti",
    "necârcotindu": "cârcoti",
    "nemaicârcotind": "cârcoti",
    "nemaicârcotindu": "cârcoti",
    "cârcotită": "cârcotit",
    "cârcotite": "cârcotit",
    "cârcotiți": "cârcotit",
    "cârcserdari": "cârcserdar",
    "cârcserdarii": "cârcserdar",
    "cârcserdarilor": "cârcserdar",
    "cârcserdarul": "cârcserdar",
    "cârcserdarule": "cârcserdar",
    "cârcserdarului": "cârcserdar",
    "cârdul": "cârd",
    "cârdule": "cârd",
    "cârdului": "cârd",
    "cârduri": "cârd",
    "cârdurile": "cârd",
    "cârdurilor": "cârd",
    "cardanica": "cardanic",
    "cardanică": "cardanic",
    "cardanice": "cardanic",
    "cardanicei": "cardanic",
    "cardanicele": "cardanic",
    "cardanicelor": "cardanic",
    "cardanici": "cardanic",
    "cardanicii": "cardanic",
    "cardanicilor": "cardanic",
    "cardanico": "cardanic",
    "cardanicul": "cardanic",
    "cardanicule": "cardanic",
    "cardanicului": "cardanic",
    "cârdășia": "cârdășie",
    "cârdășiei": "cârdășie",
    "cârdășii": "cârdășie",
    "cârdășiile": "cârdășie",
    "cârdășiilor": "cârdășie",
    "cârdășio": "cârdășie",
    "cardiaca": "cardiac",
    "cardiacă": "cardiac",
    "cardiace": "cardiac",
    "cardiacei": "cardiac",
    "cardiacele": "cardiac",
    "cardiacelor": "cardiac",
    "cardiaci": "cardiac",
    "cardiacii": "cardiac",
    "cardiacilor": "cardiac",
    "cardiaco": "cardiac",
    "cardiacul": "cardiac",
    "cardiacule": "cardiac",
    "cardiacului": "cardiac",
    "cardinala": "cardinal",
    "cardinală": "cardinal",
    "cardinale": "cardinal",
    "cardinalei": "cardinal",
    "cardinalele": "cardinal",
    "cardinalelor": "cardinal",
    "cardinali": "cardinal",
    "cardinalii": "cardinal",
    "cardinalilor": "cardinal",
    "cardinalo": "cardinal",
    "cardinalul": "cardinal",
    "cardinalule": "cardinal",
    "cardinalului": "cardinal",
    "cardiologi": "cardiolog",
    "cardiologii": "cardiolog",
    "cardiologilor": "cardiolog",
    "cardiologul": "cardiolog",
    "cardiologule": "cardiolog",
    "cardiologului": "cardiolog",
    "cardiologia": "cardiologie",
    "cardiologiei": "cardiologie",
    "cardiologii": "cardiologie",
    "cardiologiile": "cardiologie",
    "cardiologiilor": "cardiologie",
    "cardiologio": "cardiologie",
    "cardiovasculara": "cardiovascular",
    "cardiovasculară": "cardiovascular",
    "cardiovasculare": "cardiovascular",
    "cardiovascularei": "cardiovascular",
    "cardiovascularele": "cardiovascular",
    "cardiovascularelor": "cardiovascular",
    "cardiovasculari": "cardiovascular",
    "cardiovascularii": "cardiovascular",
    "cardiovascularilor": "cardiovascular",
    "cardiovascularo": "cardiovascular",
    "cardiovascularul": "cardiovascular",
    "cardiovascularule": "cardiovascular",
    "cardiovascularului": "cardiovascular",
    "cârdișoare": "cârdișor",
    "cârdișoarele": "cârdișor",
    "cârdișoarelor": "cârdișor",
    "cârdișorul": "cârdișor",
    "cârdișorule": "cârdișor",
    "cârdișorului": "cârdișor",
    "cârduia": "cârdui",
    "cârduiai": "cârdui",
    "cârduiam": "cârdui",
    "cârduiască": "cârdui",
    "cârduiați": "cârdui",
    "cârduiau": "cârdui",
    "cârduiesc": "cârdui",
    "cârduiește": "cârdui",
    "cârduiești": "cârdui",
    "cârduii": "cârdui",
    "cârduim": "cârdui",
    "cârduind": "cârdui",
    "cârduindu": "cârdui",
    "cârduiră": "cârdui",
    "cârduirăm": "cârdui",
    "cârduirăți": "cârdui",
    "cârduise": "cârdui",
    "cârduisem": "cârdui",
    "cârduiseră": "cârdui",
    "cârduiserăm": "cârdui",
    "cârduiserăți": "cârdui",
    "cârduiseși": "cârdui",
    "cârduiși": "cârdui",
    "cârduit": "cârdui",
    "cârduiți": "cârdui",
    "cârduitu": "cârdui",
    "necârduind": "cârdui",
    "necârduindu": "cârdui",
    "nemaicârduind": "cârdui",
    "nemaicârduindu": "cârdui",
    "cârduită": "cârduit",
    "cârduite": "cârduit",
    "cârduiți": "cârduit",
    "cărei": "care",
    "căreia": "care",
    "căror": "care",
    "cărora": "care",
    "cărui": "care",
    "căruia": "care",
    "carena": "carenă",
    "carene": "carenă",
    "carenei": "carenă",
    "carenele": "carenă",
    "carenelor": "carenă",
    "careno": "carenă",
    "carența": "carență",
    "carențe": "carență",
    "carenței": "carență",
    "carențele": "carență",
    "carențelor": "carență",
    "carențo": "carență",
    "careta": "caretă",
    "carete": "caretă",
    "caretei": "caretă",
    "caretele": "caretă",
    "caretelor": "caretă",
    "careto": "caretă",
    "careul": "careu",
    "careule": "careu",
    "careului": "careu",
    "careuri": "careu",
    "careurile": "careu",
    "careurilor": "careu",
    "cargobotul": "cargobot",
    "cargobotule": "cargobot",
    "cargobotului": "cargobot",
    "cargoboturi": "cargobot",
    "cargoboturile": "cargobot",
    "cargoboturilor": "cargobot",
    "cargoul": "cargou",
    "cargoule": "cargou",
    "cargoului": "cargou",
    "cargouri": "cargou",
    "cargourile": "cargou",
    "cargourilor": "cargou",
    "cariai": "caria",
    "cariam": "caria",
    "cariară": "caria",
    "cariarăm": "caria",
    "cariarăți": "caria",
    "cariase": "caria",
    "cariasem": "caria",
    "cariaseră": "caria",
    "cariaserăm": "caria",
    "cariaserăți": "caria",
    "cariaseși": "caria",
    "cariași": "caria",
    "cariat": "caria",
    "cariați": "caria",
    "cariatu": "caria",
    "cariau": "caria",
    "cariază": "caria",
    "carie": "caria",
    "cariem": "caria",
    "cariez": "caria",
    "carieze": "caria",
    "cariezi": "caria",
    "cariind": "caria",
    "cariindu": "caria",
    "necariind": "caria",
    "necariindu": "caria",
    "nemaicariind": "caria",
    "nemaicariindu": "caria",
    "cariata": "cariat",
    "cariată": "cariat",
    "cariate": "cariat",
    "cariatei": "cariat",
    "cariatele": "cariat",
    "cariatelor": "cariat",
    "cariați": "cariat",
    "cariații": "cariat",
    "cariaților": "cariat",
    "cariato": "cariat",
    "cariatul": "cariat",
    "cariatule": "cariat",
    "cariatului": "cariat",
    "cariatida": "cariatidă",
    "cariatide": "cariatidă",
    "cariatidei": "cariatidă",
    "cariatidele": "cariatidă",
    "cariatidelor": "cariatidă",
    "cariatido": "cariatidă",
    "caricatura": "caricatură",
    "caricaturi": "caricatură",
    "caricaturii": "caricatură",
    "caricaturile": "caricatură",
    "caricaturilor": "caricatură",
    "caricaturo": "caricatură",
    "caricaturiști": "caricaturist",
    "caricaturiștii": "caricaturist",
    "caricaturiștilor": "caricaturist",
    "caricaturistul": "caricaturist",
    "caricaturistule": "caricaturist",
    "caricaturistului": "caricaturist",
    "caricaturista": "caricaturistă",
    "caricaturiste": "caricaturistă",
    "caricaturistei": "caricaturistă",
    "caricaturistele": "caricaturistă",
    "caricaturistelor": "caricaturistă",
    "caricaturisto": "caricaturistă",
    "caricaturiză": "caricaturiza",
    "caricaturizai": "caricaturiza",
    "caricaturizam": "caricaturiza",
    "caricaturizăm": "caricaturiza",
    "caricaturizând": "caricaturiza",
    "caricaturizându": "caricaturiza",
    "caricaturizară": "caricaturiza",
    "caricaturizarăm": "caricaturiza",
    "caricaturizarăți": "caricaturiza",
    "caricaturizase": "caricaturiza",
    "caricaturizasem": "caricaturiza",
    "caricaturizaseră": "caricaturiza",
    "caricaturizaserăm": "caricaturiza",
    "caricaturizaserăți": "caricaturiza",
    "caricaturizaseși": "caricaturiza",
    "caricaturizași": "caricaturiza",
    "caricaturizat": "caricaturiza",
    "caricaturizați": "caricaturiza",
    "caricaturizatu": "caricaturiza",
    "caricaturizau": "caricaturiza",
    "caricaturizează": "caricaturiza",
    "caricaturizez": "caricaturiza",
    "caricaturizeze": "caricaturiza",
    "caricaturizezi": "caricaturiza",
    "necaricaturizând": "caricaturiza",
    "necaricaturizându": "caricaturiza",
    "nemaicaricaturizând": "caricaturiza",
    "nemaicaricaturizându": "caricaturiza",
    "caricaturizarea": "caricaturizare",
    "caricaturizareo": "caricaturizare",
    "caricaturizări": "caricaturizare",
    "caricaturizării": "caricaturizare",
    "caricaturizările": "caricaturizare",
    "caricaturizărilor": "caricaturizare",
    "caricaturizată": "caricaturizat",
    "caricaturizate": "caricaturizat",
    "caricaturizați": "caricaturizat",
    "caria": "carie",
    "cariei": "carie",
    "carii": "carie",
    "cariile": "carie",
    "cariilor": "carie",
    "cario": "carie",
    "cariera": "carieră",
    "cariere": "carieră",
    "carierei": "carieră",
    "carierele": "carieră",
    "carierelor": "carieră",
    "cariero": "carieră",
    "carierisme": "carierism",
    "carierismele": "carierism",
    "carierismelor": "carierism",
    "carierismul": "carierism",
    "carierismule": "carierism",
    "carierismului": "carierism",
    "carierista": "carierist",
    "carieristă": "carierist",
    "carieriste": "carierist",
    "carieristei": "carierist",
    "carieristele": "carierist",
    "carieristelor": "carierist",
    "carieriști": "carierist",
    "carieriștii": "carierist",
    "carieriștilor": "carierist",
    "carieristo": "carierist",
    "carieristul": "carierist",
    "carieristule": "carierist",
    "carieristului": "carierist",
    "carierista": "carieristă",
    "carieriste": "carieristă",
    "carieristei": "carieristă",
    "carieristele": "carieristă",
    "carieristelor": "carieristă",
    "carieristo": "carieristă",
    "caritabila": "caritabil",
    "caritabilă": "caritabil",
    "caritabile": "caritabil",
    "caritabilei": "caritabil",
    "caritabilele": "caritabil",
    "caritabilelor": "caritabil",
    "caritabili": "caritabil",
    "caritabilii": "caritabil",
    "caritabililor": "caritabil",
    "caritabilo": "caritabil",
    "caritabilul": "caritabil",
    "caritabilule": "caritabil",
    "caritabilului": "caritabil",
    "Caritasul": "Caritas",
    "caritatea": "caritate",
    "caritateo": "caritate",
    "carități": "caritate",
    "carității": "caritate",
    "cârja": "cârjă",
    "cârje": "cârjă",
    "cârjei": "cârjă",
    "cârjele": "cârjă",
    "cârjelor": "cârjă",
    "cârjo": "cârjă",
    "cârlani": "cârlan",
    "cârlanii": "cârlan",
    "cârlanilor": "cârlan",
    "cârlanul": "cârlan",
    "cârlanule": "cârlan",
    "cârlanului": "cârlan",
    "cârlănari": "cârlănar",
    "cârlănarii": "cârlănar",
    "cârlănarilor": "cârlănar",
    "cârlănarul": "cârlănar",
    "cârlănarule": "cârlănar",
    "cârlănarului": "cârlănar",
    "cârlănași": "cârlănaș",
    "cârlănașii": "cârlănaș",
    "cârlănașilor": "cârlănaș",
    "cârlănașul": "cârlănaș",
    "cârlănașule": "cârlănaș",
    "cârlănașului": "cârlănaș",
    "cârlige": "cârlig",
    "cârligele": "cârlig",
    "cârligelor": "cârlig",
    "cârligul": "cârlig",
    "cârligule": "cârlig",
    "cârligului": "cârlig",
    "cârligașe": "cârligaș",
    "cârligașele": "cârligaș",
    "cârligașelor": "cârligaș",
    "cârligașul": "cârligaș",
    "cârligașule": "cârligaș",
    "cârligașului": "cârligaș",
    "cârligele": "cârligel",
    "cârligelele": "cârligel",
    "cârligelelor": "cârligel",
    "cârligelul": "cârligel",
    "cârligelule": "cârligel",
    "cârligelului": "cârligel",
    "carlinga": "carlingă",
    "carlingi": "carlingă",
    "carlingii": "carlingă",
    "carlingile": "carlingă",
    "carlingilor": "carlingă",
    "carlingo": "carlingă",
    "cârlionți": "cârlionț",
    "cârlionții": "cârlionț",
    "cârlionților": "cârlionț",
    "cârlionțul": "cârlionț",
    "cârlionțule": "cârlionț",
    "cârlionțului": "cârlionț",
    "cârlionță": "cârlionța",
    "cârlionțai": "cârlionța",
    "cârlionțam": "cârlionța",
    "cârlionțăm": "cârlionța",
    "cârlionțând": "cârlionța",
    "cârlionțându": "cârlionța",
    "cârlionțară": "cârlionța",
    "cârlionțarăm": "cârlionța",
    "cârlionțarăți": "cârlionța",
    "cârlionțase": "cârlionța",
    "cârlionțasem": "cârlionța",
    "cârlionțaseră": "cârlionța",
    "cârlionțaserăm": "cârlionța",
    "cârlionțaserăți": "cârlionța",
    "cârlionțaseși": "cârlionța",
    "cârlionțași": "cârlionța",
    "cârlionțat": "cârlionța",
    "cârlionțați": "cârlionța",
    "cârlionțatu": "cârlionța",
    "cârlionțau": "cârlionța",
    "cârlionțează": "cârlionța",
    "cârlionțez": "cârlionța",
    "cârlionțeze": "cârlionța",
    "cârlionțezi": "cârlionța",
    "necârlionțând": "cârlionța",
    "necârlionțându": "cârlionța",
    "nemaicârlionțând": "cârlionța",
    "nemaicârlionțându": "cârlionța",
    "cârlionțata": "cârlionțat",
    "cârlionțată": "cârlionțat",
    "cârlionțate": "cârlionțat",
    "cârlionțatei": "cârlionțat",
    "cârlionțatele": "cârlionțat",
    "cârlionțatelor": "cârlionțat",
    "cârlionțați": "cârlionțat",
    "cârlionțații": "cârlionțat",
    "cârlionțaților": "cârlionțat",
    "cârlionțato": "cârlionțat",
    "cârlionțatul": "cârlionțat",
    "cârlionțatule": "cârlionțat",
    "cârlionțatului": "cârlionțat",
    "cârma": "cârmă",
    "cârme": "cârmă",
    "cârmei": "cârmă",
    "cârmele": "cârmă",
    "cârmelor": "cârmă",
    "cârmo": "cârmă",
    "cârmacii": "cârmaci",
    "cârmacilor": "cârmaci",
    "cârmaciul": "cârmaci",
    "cârmaciule": "cârmaci",
    "cârmaciului": "cârmaci",
    "cârmeala": "cârmeală",
    "cârmealo": "cârmeală",
    "cârmeli": "cârmeală",
    "cârmelii": "cârmeală",
    "cârmelile": "cârmeală",
    "cârmelilor": "cârmeală",
    "cârmea": "cârmi",
    "cârmeai": "cârmi",
    "cârmeam": "cârmi",
    "cârmească": "cârmi",
    "cârmeați": "cârmi",
    "cârmeau": "cârmi",
    "cârmesc": "cârmi",
    "cârmește": "cârmi",
    "cârmești": "cârmi",
    "cârmii": "cârmi",
    "cârmim": "cârmi",
    "cârmind": "cârmi",
    "cârmindu": "cârmi",
    "cârmiră": "cârmi",
    "cârmirăm": "cârmi",
    "cârmirăți": "cârmi",
    "cârmise": "cârmi",
    "cârmisem": "cârmi",
    "cârmiseră": "cârmi",
    "cârmiserăm": "cârmi",
    "cârmiserăți": "cârmi",
    "cârmiseși": "cârmi",
    "cârmiși": "cârmi",
    "cârmit": "cârmi",
    "cârmiți": "cârmi",
    "cârmitu": "cârmi",
    "necârmind": "cârmi",
    "necârmindu": "cârmi",
    "nemaicârmind": "cârmi",
    "nemaicârmindu": "cârmi",
    "cârmirea": "cârmire",
    "cârmireo": "cârmire",
    "cârmiri": "cârmire",
    "cârmirii": "cârmire",
    "cârmirile": "cârmire",
    "cârmirilor": "cârmire",
    "cârmită": "cârmit",
    "cârmite": "cârmit",
    "cârmiți": "cârmit",
    "cârmuia": "cârmui",
    "cârmuiai": "cârmui",
    "cârmuiam": "cârmui",
    "cârmuiască": "cârmui",
    "cârmuiați": "cârmui",
    "cârmuiau": "cârmui",
    "cârmuiesc": "cârmui",
    "cârmuiește": "cârmui",
    "cârmuiești": "cârmui",
    "cârmuii": "cârmui",
    "cârmuim": "cârmui",
    "cârmuind": "cârmui",
    "cârmuindu": "cârmui",
    "cârmuiră": "cârmui",
    "cârmuirăm": "cârmui",
    "cârmuirăți": "cârmui",
    "cârmuise": "cârmui",
    "cârmuisem": "cârmui",
    "cârmuiseră": "cârmui",
    "cârmuiserăm": "cârmui",
    "cârmuiserăți": "cârmui",
    "cârmuiseși": "cârmui",
    "cârmuiși": "cârmui",
    "cârmuit": "cârmui",
    "cârmuiți": "cârmui",
    "cârmuitu": "cârmui",
    "necârmuind": "cârmui",
    "necârmuindu": "cârmui",
    "nemaicârmuind": "cârmui",
    "nemaicârmuindu": "cârmui",
    "cârmuirea": "cârmuire",
    "cârmuireo": "cârmuire",
    "cârmuiri": "cârmuire",
    "cârmuirii": "cârmuire",
    "cârmuirile": "cârmuire",
    "cârmuirilor": "cârmuire",
    "cârmuită": "cârmuit",
    "cârmuite": "cârmuit",
    "cârmuiți": "cârmuit",
    "cârmuitoarea": "cârmuitoare",
    "cârmuitoarei": "cârmuitoare",
    "cârmuitoarele": "cârmuitoare",
    "cârmuitoarelor": "cârmuitoare",
    "cârmuitoareo": "cârmuitoare",
    "cârmuitori": "cârmuitor",
    "cârmuitorii": "cârmuitor",
    "cârmuitorilor": "cârmuitor",
    "cârmuitorul": "cârmuitor",
    "cârmuitorule": "cârmuitor",
    "cârmuitorului": "cârmuitor",
    "cârna": "cârn",
    "cârnă": "cârn",
    "cârne": "cârn",
    "cârnei": "cârn",
    "cârnele": "cârn",
    "cârnelor": "cârn",
    "cârni": "cârn",
    "cârnii": "cârn",
    "cârnilor": "cârn",
    "cârno": "cârn",
    "cârnul": "cârn",
    "cârnule": "cârn",
    "cârnului": "cârn",
    "cârnăciori": "cârnăcior",
    "cârnăciorii": "cârnăcior",
    "cârnăciorilor": "cârnăcior",
    "cârnăciorul": "cârnăcior",
    "cârnăciorule": "cârnăcior",
    "cârnăciorului": "cârnăcior",
    "carnaje": "carnaj",
    "carnajele": "carnaj",
    "carnajelor": "carnaj",
    "carnajul": "carnaj",
    "carnajule": "carnaj",
    "carnajului": "carnaj",
    "carnala": "carnal",
    "carnală": "carnal",
    "carnale": "carnal",
    "carnalei": "carnal",
    "carnalele": "carnal",
    "carnalelor": "carnal",
    "carnali": "carnal",
    "carnalii": "carnal",
    "carnalilor": "carnal",
    "carnalo": "carnal",
    "carnalul": "carnal",
    "carnalule": "carnal",
    "carnalului": "carnal",
    "cărnăria": "cărnărie",
    "cărnăriei": "cărnărie",
    "cărnării": "cărnărie",
    "cărnăriile": "cărnărie",
    "cărnăriilor": "cărnărie",
    "cărnărio": "cărnărie",
    "carnasiera": "carnasier",
    "carnasieră": "carnasier",
    "carnasiere": "carnasier",
    "carnasierei": "carnasier",
    "carnasierele": "carnasier",
    "carnasierelor": "carnasier",
    "carnasieri": "carnasier",
    "carnasierii": "carnasier",
    "carnasierilor": "carnasier",
    "carnasiero": "carnasier",
    "carnasierul": "carnasier",
    "carnasierule": "carnasier",
    "carnasierului": "carnasier",
    "cârnați": "cârnat",
    "cârnații": "cârnat",
    "cârnaților": "cârnat",
    "cârnatul": "cârnat",
    "cârnatule": "cârnat",
    "cârnatului": "cârnat",
    "cârnațului": "cârnaț",
    "cârnățari": "cârnățar",
    "cârnățarii": "cârnățar",
    "cârnățarilor": "cârnățar",
    "cârnățarul": "cârnățar",
    "cârnățarule": "cârnățar",
    "cârnățarului": "cârnățar",
    "cârnățăreasa": "cârnățăreasă",
    "cârnățăreaso": "cârnățăreasă",
    "cârnățărese": "cârnățăreasă",
    "cârnățăresei": "cârnățăreasă",
    "cârnățăresele": "cârnățăreasă",
    "cârnățăreselor": "cârnățăreasă",
    "cârnățăria": "cârnățărie",
    "cârnățăriei": "cârnățărie",
    "cârnățării": "cârnățărie",
    "cârnățăriile": "cârnățărie",
    "cârnățăriilor": "cârnățărie",
    "cârnățărio": "cârnățărie",
    "carnavalul": "carnaval",
    "carnavalule": "carnaval",
    "carnavalului": "carnaval",
    "carnavaluri": "carnaval",
    "carnavalurile": "carnaval",
    "carnavalurilor": "carnaval",
    "carnea": "carne",
    "carneo": "carne",
    "cărni": "carne",
    "cărnii": "carne",
    "cărnuri": "carne",
    "cărnurile": "carne",
    "cărnurilor": "carne",
    "carnete": "carnet",
    "carnetele": "carnet",
    "carnetelor": "carnet",
    "carnetul": "carnet",
    "carnetule": "carnet",
    "carnetului": "carnet",
    "carnețele": "carnețel",
    "carnețelele": "carnețel",
    "carnețelelor": "carnețel",
    "carnețelul": "carnețel",
    "carnețelule": "carnețel",
    "carnețelului": "carnețel",
    "cârnea": "cârni",
    "cârneai": "cârni",
    "cârneam": "cârni",
    "cârnească": "cârni",
    "cârneați": "cârni",
    "cârneau": "cârni",
    "cârnesc": "cârni",
    "cârnește": "cârni",
    "cârnești": "cârni",
    "cârnii": "cârni",
    "cârnim": "cârni",
    "cârnind": "cârni",
    "cârnindu": "cârni",
    "cârniră": "cârni",
    "cârnirăm": "cârni",
    "cârnirăți": "cârni",
    "cârnise": "cârni",
    "cârnisem": "cârni",
    "cârniseră": "cârni",
    "cârniserăm": "cârni",
    "cârniserăți": "cârni",
    "cârniseși": "cârni",
    "cârniși": "cârni",
    "cârnit": "cârni",
    "cârniți": "cârni",
    "cârnitu": "cârni",
    "necârnind": "cârni",
    "necârnindu": "cârni",
    "nemaicârnind": "cârni",
    "nemaicârnindu": "cârni",
    "cărnicele": "cărnicică",
    "cărnicelei": "cărnicică",
    "cărnicelele": "cărnicică",
    "cărnicelelor": "cărnicică",
    "cărnicica": "cărnicică",
    "cărnicico": "cărnicică",
    "cărnișoara": "cărnișoară",
    "cărnișoare": "cărnișoară",
    "cărnișoarei": "cărnișoară",
    "cărnișoarele": "cărnișoară",
    "cărnișoarelor": "cărnișoară",
    "cărnișoaro": "cărnișoară",
    "cârnită": "cârnit",
    "cârnite": "cârnit",
    "cârniți": "cârnit",
    "cârnitul": "cârnit",
    "cârnitule": "cârnit",
    "cârnitului": "cârnit",
    "cârnituri": "cârnit",
    "cârniturile": "cârnit",
    "cârniturilor": "cârnit",
    "cărnița": "cărniță",
    "cărnițe": "cărniță",
    "cărniței": "cărniță",
    "cărnițele": "cărniță",
    "cărnițelor": "cărniță",
    "cărnițo": "cărniță",
    "carnivora": "carnivor",
    "carnivoră": "carnivor",
    "carnivore": "carnivor",
    "carnivorei": "carnivor",
    "carnivorele": "carnivor",
    "carnivorelor": "carnivor",
    "carnivori": "carnivor",
    "carnivorii": "carnivor",
    "carnivorilor": "carnivor",
    "carnivoro": "carnivor",
    "carnivorul": "carnivor",
    "carnivorule": "carnivor",
    "carnivorului": "carnivor",
    "cărnoasa": "cărnos",
    "cărnoasă": "cărnos",
    "cărnoase": "cărnos",
    "cărnoasei": "cărnos",
    "cărnoasele": "cărnos",
    "cărnoaselor": "cărnos",
    "cărnoaso": "cărnos",
    "cărnoși": "cărnos",
    "cărnoșii": "cărnos",
    "cărnoșilor": "cărnos",
    "cărnosul": "cărnos",
    "cărnosule": "cărnos",
    "cărnosului": "cărnos",
    "cărnosea": "cărnosi",
    "cărnoseai": "cărnosi",
    "cărnoseam": "cărnosi",
    "cărnosească": "cărnosi",
    "cărnoseați": "cărnosi",
    "cărnoseau": "cărnosi",
    "cărnosesc": "cărnosi",
    "cărnosește": "cărnosi",
    "cărnosești": "cărnosi",
    "cărnosii": "cărnosi",
    "cărnosim": "cărnosi",
    "cărnosind": "cărnosi",
    "cărnosindu": "cărnosi",
    "cărnosiră": "cărnosi",
    "cărnosirăm": "cărnosi",
    "cărnosirăți": "cărnosi",
    "cărnosise": "cărnosi",
    "cărnosisem": "cărnosi",
    "cărnosiseră": "cărnosi",
    "cărnosiserăm": "cărnosi",
    "cărnosiserăți": "cărnosi",
    "cărnosiseși": "cărnosi",
    "cărnosiși": "cărnosi",
    "cărnosit": "cărnosi",
    "cărnosiți": "cărnosi",
    "cărnositu": "cărnosi",
    "necărnosind": "cărnosi",
    "necărnosindu": "cărnosi",
    "nemaicărnosind": "cărnosi",
    "nemaicărnosindu": "cărnosi",
    "cărnosirea": "cărnosire",
    "cărnosireo": "cărnosire",
    "cărnosiri": "cărnosire",
    "cărnosirii": "cărnosire",
    "cărnosirile": "cărnosire",
    "cărnosirilor": "cărnosire",
    "cărnosită": "cărnosit",
    "cărnosite": "cărnosit",
    "cărnosiți": "cărnosit",
    "carale": "caro",
    "caralele": "caro",
    "caralelor": "caro",
    "caroul": "caro",
    "caroule": "caro",
    "caroului": "caro",
    "caroiaje": "caroiaj",
    "caroiajele": "caroiaj",
    "caroiajelor": "caroiaj",
    "caroiajul": "caroiaj",
    "caroiajule": "caroiaj",
    "caroiajului": "caroiaj",
    "carosabila": "carosabil",
    "carosabilă": "carosabil",
    "carosabile": "carosabil",
    "carosabilei": "carosabil",
    "carosabilele": "carosabil",
    "carosabilelor": "carosabil",
    "carosabili": "carosabil",
    "carosabilii": "carosabil",
    "carosabililor": "carosabil",
    "carosabilo": "carosabil",
    "carosabilul": "carosabil",
    "carosabilule": "carosabil",
    "carosabilului": "carosabil",
    "caroseria": "caroserie",
    "caroseriei": "caroserie",
    "caroserii": "caroserie",
    "caroseriile": "caroserie",
    "caroseriilor": "caroserie",
    "caroserio": "caroserie",
    "carotida": "carotidă",
    "carotide": "carotidă",
    "carotidei": "carotidă",
    "carotidele": "carotidă",
    "carotidelor": "carotidă",
    "carotido": "carotidă",
    "caroul": "carou",
    "caroule": "carou",
    "caroului": "carou",
    "carouri": "carou",
    "carourile": "carou",
    "carourilor": "carou",
    "cârpa": "cârpă",
    "cârpe": "cârpă",
    "cârpei": "cârpă",
    "cârpele": "cârpă",
    "cârpelor": "cârpă",
    "cârpo": "cârpă",
    "cârpăceala": "cârpăceală",
    "cârpăcealo": "cârpăceală",
    "cârpăceli": "cârpăceală",
    "cârpăcelii": "cârpăceală",
    "cârpăcelile": "cârpăceală",
    "cârpăcelilor": "cârpăceală",
    "cârpacii": "cârpaci",
    "cârpacilor": "cârpaci",
    "cârpaciul": "cârpaci",
    "cârpaciule": "cârpaci",
    "cârpaciului": "cârpaci",
    "cârpăcea": "cârpăci",
    "cârpăceai": "cârpăci",
    "cârpăceam": "cârpăci",
    "cârpăcească": "cârpăci",
    "cârpăceați": "cârpăci",
    "cârpăceau": "cârpăci",
    "cârpăcesc": "cârpăci",
    "cârpăcește": "cârpăci",
    "cârpăcești": "cârpăci",
    "cârpăcii": "cârpăci",
    "cârpăcim": "cârpăci",
    "cârpăcind": "cârpăci",
    "cârpăcindu": "cârpăci",
    "cârpăciră": "cârpăci",
    "cârpăcirăm": "cârpăci",
    "cârpăcirăți": "cârpăci",
    "cârpăcise": "cârpăci",
    "cârpăcisem": "cârpăci",
    "cârpăciseră": "cârpăci",
    "cârpăciserăm": "cârpăci",
    "cârpăciserăți": "cârpăci",
    "cârpăciseși": "cârpăci",
    "cârpăciși": "cârpăci",
    "cârpăcit": "cârpăci",
    "cârpăciți": "cârpăci",
    "cârpăcitu": "cârpăci",
    "necârpăcind": "cârpăci",
    "necârpăcindu": "cârpăci",
    "nemaicârpăcind": "cârpăci",
    "nemaicârpăcindu": "cârpăci",
    "cârpăcită": "cârpăcit",
    "cârpăcite": "cârpăcit",
    "cârpăciți": "cârpăcit",
    "cărpănoasa": "cărpănoasă",
    "cărpănoase": "cărpănoasă",
    "cărpănoasei": "cărpănoasă",
    "cărpănoasele": "cărpănoasă",
    "cărpănoaselor": "cărpănoasă",
    "cărpănoaso": "cărpănoasă",
    "cărpănoasa": "cărpănos",
    "cărpănoasă": "cărpănos",
    "cărpănoase": "cărpănos",
    "cărpănoasei": "cărpănos",
    "cărpănoasele": "cărpănos",
    "cărpănoaselor": "cărpănos",
    "cărpănoaso": "cărpănos",
    "cărpănoși": "cărpănos",
    "cărpănoșii": "cărpănos",
    "cărpănoșilor": "cărpănos",
    "cărpănosul": "cărpănos",
    "cărpănosule": "cărpănos",
    "cărpănosului": "cărpănos",
    "Carpații": "Carpați",
    "Carpaților": "Carpați",
    "Carpațiul": "Carpați",
    "Carpațiului": "Carpați",
    "Carpatinei": "Carpatina",
    "cârpeala": "cârpeală",
    "cârpealo": "cârpeală",
    "cârpeli": "cârpeală",
    "cârpelii": "cârpeală",
    "cârpelile": "cârpeală",
    "cârpelilor": "cârpeală",
    "carpeni": "carpen",
    "carpenii": "carpen",
    "carpenilor": "carpen",
    "carpenul": "carpen",
    "carpenule": "carpen",
    "carpenului": "carpen",
    "carpeta": "carpetă",
    "carpete": "carpetă",
    "carpetei": "carpetă",
    "carpetele": "carpetă",
    "carpetelor": "carpetă",
    "carpeto": "carpetă",
    "cârpea": "cârpi",
    "cârpeai": "cârpi",
    "cârpeam": "cârpi",
    "cârpească": "cârpi",
    "cârpeați": "cârpi",
    "cârpeau": "cârpi",
    "cârpesc": "cârpi",
    "cârpește": "cârpi",
    "cârpești": "cârpi",
    "cârpii": "cârpi",
    "cârpim": "cârpi",
    "cârpind": "cârpi",
    "cârpindu": "cârpi",
    "cârpiră": "cârpi",
    "cârpirăm": "cârpi",
    "cârpirăți": "cârpi",
    "cârpise": "cârpi",
    "cârpisem": "cârpi",
    "cârpiseră": "cârpi",
    "cârpiserăm": "cârpi",
    "cârpiserăți": "cârpi",
    "cârpiseși": "cârpi",
    "cârpiși": "cârpi",
    "cârpit": "cârpi",
    "cârpiți": "cârpi",
    "cârpitu": "cârpi",
    "necârpind": "cârpi",
    "necârpindu": "cârpi",
    "nemaicârpind": "cârpi",
    "nemaicârpindu": "cârpi",
    "cărpinași": "cărpinaș",
    "cărpinașii": "cărpinaș",
    "cărpinașilor": "cărpinaș",
    "cărpinașul": "cărpinaș",
    "cărpinașule": "cărpinaș",
    "cărpinașului": "cărpinaș",
    "cărpineți": "cărpinet",
    "cărpineții": "cărpinet",
    "cărpineților": "cărpinet",
    "cărpinetule": "cărpinet",
    "cărpinetului": "cărpinet",
    "cărpinișul": "cărpiniș",
    "cărpinișule": "cărpiniș",
    "cărpinișului": "cărpiniș",
    "cărpinișuri": "cărpiniș",
    "cărpinișurile": "cărpiniș",
    "cărpinișurilor": "cărpiniș",
    "cârpirea": "cârpire",
    "cârpireo": "cârpire",
    "cârpiri": "cârpire",
    "cârpirii": "cârpire",
    "cârpirile": "cârpire",
    "cârpirilor": "cârpire",
    "cârpită": "cârpit",
    "cârpite": "cârpit",
    "cârpiți": "cârpit",
    "cârpitul": "cârpit",
    "cârpitule": "cârpit",
    "cârpitului": "cârpit",
    "cârpitura": "cârpitură",
    "cârpituri": "cârpitură",
    "cârpiturii": "cârpitură",
    "cârpiturile": "cârpitură",
    "cârpiturilor": "cârpitură",
    "cârpituro": "cârpitură",
    "cârpușoara": "cârpușoară",
    "cârpușoare": "cârpușoară",
    "cârpușoarei": "cârpușoară",
    "cârpușoarele": "cârpușoară",
    "cârpușoarelor": "cârpușoară",
    "cârpușoaro": "cârpușoară",
    "cartul": "cart",
    "cartule": "cart",
    "cartului": "cart",
    "carturi": "cart",
    "carturile": "cart",
    "carturilor": "cart",
    "cartă": "carta",
    "cartai": "carta",
    "cartam": "carta",
    "cartăm": "carta",
    "cartând": "carta",
    "cartându": "carta",
    "cartară": "carta",
    "cartarăm": "carta",
    "cartarăți": "carta",
    "cartase": "carta",
    "cartasem": "carta",
    "cartaseră": "carta",
    "cartaserăm": "carta",
    "cartaserăți": "carta",
    "cartaseși": "carta",
    "cartași": "carta",
    "cartat": "carta",
    "cartați": "carta",
    "cartatu": "carta",
    "cartau": "carta",
    "cartează": "carta",
    "cartez": "carta",
    "carteze": "carta",
    "cartezi": "carta",
    "necartând": "carta",
    "necartându": "carta",
    "nemaicartând": "carta",
    "nemaicartându": "carta",
    "cartarea": "cartare",
    "cartareo": "cartare",
    "cartări": "cartare",
    "cartării": "cartare",
    "cartările": "cartare",
    "cartărilor": "cartare",
    "cartată": "cartat",
    "cartate": "cartat",
    "cartați": "cartat",
    "cartea": "carte",
    "carteo": "carte",
    "cărți": "carte",
    "cărții": "carte",
    "cărțile": "carte",
    "cărților": "carte",
    "cartea_poștală": "carte_poștală",
    "cărți_poștale": "carte_poștală",
    "cărții_poștale": "carte_poștală",
    "cărțile_poștale": "carte_poștală",
    "cărților_poștale": "carte_poștală",
    "cârteala": "cârteală",
    "cârtealo": "cârteală",
    "cârteli": "cârteală",
    "cârtelii": "cârteală",
    "cârtelile": "cârteală",
    "cârtelilor": "cârteală",
    "cartelul": "cartel",
    "cartelule": "cartel",
    "cartelului": "cartel",
    "carteluri": "cartel",
    "cartelurile": "cartel",
    "cartelurilor": "cartel",
    "Cartelul_ALFA": "Cartel_ALFA",
    "Cartelului_ALFA": "Cartel_ALFA",
    "cartelă": "cartela",
    "cartelai": "cartela",
    "cartelam": "cartela",
    "cartelăm": "cartela",
    "cartelând": "cartela",
    "cartelându": "cartela",
    "cartelară": "cartela",
    "cartelarăm": "cartela",
    "cartelarăți": "cartela",
    "cartelase": "cartela",
    "cartelasem": "cartela",
    "cartelaseră": "cartela",
    "cartelaserăm": "cartela",
    "cartelaserăți": "cartela",
    "cartelaseși": "cartela",
    "cartelași": "cartela",
    "cartelat": "cartela",
    "cartelați": "cartela",
    "cartelatu": "cartela",
    "cartelau": "cartela",
    "cartelează": "cartela",
    "cartelez": "cartela",
    "carteleze": "cartela",
    "cartelezi": "cartela",
    "necartelând": "cartela",
    "necartelându": "cartela",
    "nemaicartelând": "cartela",
    "nemaicartelându": "cartela",
    "cartela": "cartelă",
    "cartele": "cartelă",
    "cartelei": "cartelă",
    "cartelele": "cartelă",
    "cartelelor": "cartelă",
    "cartelo": "cartelă",
    "cartelarea": "cartelare",
    "cartelareo": "cartelare",
    "cartelări": "cartelare",
    "cartelării": "cartelare",
    "cartelările": "cartelare",
    "cartelărilor": "cartelare",
    "cartelată": "cartelat",
    "cartelate": "cartelat",
    "cartelați": "cartelat",
    "cartere": "carter",
    "carterele": "carter",
    "carterelor": "carter",
    "carterul": "carter",
    "carterule": "carter",
    "carterului": "carter",
    "carteziana": "cartezian",
    "carteziană": "cartezian",
    "carteziano": "cartezian",
    "cartezianul": "cartezian",
    "cartezianule": "cartezian",
    "cartezianului": "cartezian",
    "carteziene": "cartezian",
    "cartezienei": "cartezian",
    "cartezienele": "cartezian",
    "cartezienelor": "cartezian",
    "cartezieni": "cartezian",
    "cartezienii": "cartezian",
    "cartezienilor": "cartezian",
    "carteziana": "carteziană",
    "carteziano": "carteziană",
    "carteziene": "carteziană",
    "cartezienei": "carteziană",
    "cartezienele": "carteziană",
    "cartezienelor": "carteziană",
    "cartezianismul": "cartezianism",
    "cartezianismule": "cartezianism",
    "cartezianismului": "cartezianism",
    "cârtea": "cârti",
    "cârteai": "cârti",
    "cârteam": "cârti",
    "cârtească": "cârti",
    "cârteați": "cârti",
    "cârteau": "cârti",
    "cârtesc": "cârti",
    "cârtește": "cârti",
    "cârtești": "cârti",
    "cârtii": "cârti",
    "cârtim": "cârti",
    "cârtind": "cârti",
    "cârtindu": "cârti",
    "cârtiră": "cârti",
    "cârtirăm": "cârti",
    "cârtirăți": "cârti",
    "cârtise": "cârti",
    "cârtisem": "cârti",
    "cârtiseră": "cârti",
    "cârtiserăm": "cârti",
    "cârtiserăți": "cârti",
    "cârtiseși": "cârti",
    "cârtiși": "cârti",
    "cârtit": "cârti",
    "cârtiți": "cârti",
    "cârtitu": "cârti",
    "necârtind": "cârti",
    "necârtindu": "cârti",
    "nemaicârtind": "cârti",
    "nemaicârtindu": "cârti",
    "cărticeao": "cărticea",
    "cărticeaua": "cărticea",
    "cărticele": "cărticică",
    "cărticelei": "cărticică",
    "cărticelele": "cărticică",
    "cărticelelor": "cărticică",
    "cărticica": "cărticică",
    "cărticico": "cărticică",
    "cart.": "cartier",
    "cartiere": "cartier",
    "cartierele": "cartier",
    "cartierelor": "cartier",
    "cartierul": "cartier",
    "cartierule": "cartier",
    "cartierului": "cartier",
    "cartilaginoasa": "cartilaginos",
    "cartilaginoasă": "cartilaginos",
    "cartilaginoase": "cartilaginos",
    "cartilaginoasei": "cartilaginos",
    "cartilaginoasele": "cartilaginos",
    "cartilaginoaselor": "cartilaginos",
    "cartilaginoaso": "cartilaginos",
    "cartilaginoși": "cartilaginos",
    "cartilaginoșii": "cartilaginos",
    "cartilaginoșilor": "cartilaginos",
    "cartilaginosul": "cartilaginos",
    "cartilaginosule": "cartilaginos",
    "cartilaginosului": "cartilaginos",
    "cartilaje": "cartilaj",
    "cartilajele": "cartilaj",
    "cartilajelor": "cartilaj",
    "cartilajul": "cartilaj",
    "cartilajule": "cartilaj",
    "cartilajului": "cartilaj",
    "cârtirea": "cârtire",
    "cârtireo": "cârtire",
    "cârtiri": "cârtire",
    "cârtirii": "cârtire",
    "cârtirile": "cârtire",
    "cârtirilor": "cârtire",
    "cartiruirea": "cartiruire",
    "cartiruireo": "cartiruire",
    "cartiruiri": "cartiruire",
    "cartiruirii": "cartiruire",
    "cartiruirile": "cartiruire",
    "cartiruirilor": "cartiruire",
    "cărțișoara": "cărțișoară",
    "cărțișoare": "cărțișoară",
    "cărțișoarei": "cărțișoară",
    "cărțișoarele": "cărțișoară",
    "cărțișoarelor": "cărțișoară",
    "cărțișoaro": "cărțișoară",
    "cârtită": "cârtit",
    "cârtite": "cârtit",
    "cârtiți": "cârtit",
    "cârtița": "cârtiță",
    "cârtițe": "cârtiță",
    "cârtiței": "cârtiță",
    "cârtițele": "cârtiță",
    "cârtițelor": "cârtiță",
    "cârtițo": "cârtiță",
    "cârtitoare": "cârtitor",
    "cârtitoarea": "cârtitor",
    "cârtitoarei": "cârtitor",
    "cârtitoarele": "cârtitor",
    "cârtitoarelor": "cârtitor",
    "cârtitoareo": "cârtitor",
    "cârtitori": "cârtitor",
    "cârtitorii": "cârtitor",
    "cârtitorilor": "cârtitor",
    "cârtitorul": "cârtitor",
    "cârtitorule": "cârtitor",
    "cârtitorului": "cârtitor",
    "cartofi": "cartof",
    "cartofii": "cartof",
    "cartofilor": "cartof",
    "cartoful": "cartof",
    "cartofule": "cartof",
    "cartofului": "cartof",
    "cartofiori": "cartofior",
    "cartofiorii": "cartofior",
    "cartofiorilor": "cartofior",
    "cartofiorul": "cartofior",
    "cartofiorule": "cartofior",
    "cartofiorului": "cartofior",
    "cartofori": "cartofor",
    "cartoforii": "cartofor",
    "cartoforilor": "cartofor",
    "cartoforul": "cartofor",
    "cartoforule": "cartofor",
    "cartoforului": "cartofor",
    "cartofora": "cartoforă",
    "cartofore": "cartoforă",
    "cartoforei": "cartoforă",
    "cartoforele": "cartoforă",
    "cartoforelor": "cartoforă",
    "cartoforo": "cartoforă",
    "cartografi": "cartograf",
    "cartografii": "cartograf",
    "cartografilor": "cartograf",
    "cartograful": "cartograf",
    "cartografule": "cartograf",
    "cartografului": "cartograf",
    "cartografa": "cartografă",
    "cartografe": "cartografă",
    "cartografei": "cartografă",
    "cartografele": "cartografă",
    "cartografelor": "cartografă",
    "cartografo": "cartografă",
    "cartografiai": "cartografia",
    "cartografiam": "cartografia",
    "cartografiară": "cartografia",
    "cartografiarăm": "cartografia",
    "cartografiarăți": "cartografia",
    "cartografiase": "cartografia",
    "cartografiasem": "cartografia",
    "cartografiaseră": "cartografia",
    "cartografiaserăm": "cartografia",
    "cartografiaserăți": "cartografia",
    "cartografiaseși": "cartografia",
    "cartografiași": "cartografia",
    "cartografiat": "cartografia",
    "cartografiați": "cartografia",
    "cartografiatu": "cartografia",
    "cartografiau": "cartografia",
    "cartografiază": "cartografia",
    "cartografie": "cartografia",
    "cartografiem": "cartografia",
    "cartografiez": "cartografia",
    "cartografieze": "cartografia",
    "cartografiezi": "cartografia",
    "cartografiind": "cartografia",
    "cartografiindu": "cartografia",
    "necartografiind": "cartografia",
    "necartografiindu": "cartografia",
    "nemaicartografiind": "cartografia",
    "nemaicartografiindu": "cartografia",
    "cartografiată": "cartografiat",
    "cartografiate": "cartografiat",
    "cartografiați": "cartografiat",
    "cartografica": "cartografic",
    "cartografică": "cartografic",
    "cartografice": "cartografic",
    "cartograficei": "cartografic",
    "cartograficele": "cartografic",
    "cartograficelor": "cartografic",
    "cartografici": "cartografic",
    "cartograficii": "cartografic",
    "cartograficilor": "cartografic",
    "cartografico": "cartografic",
    "cartograficul": "cartografic",
    "cartograficule": "cartografic",
    "cartograficului": "cartografic",
    "cartografia": "cartografie",
    "cartografiei": "cartografie",
    "cartografii": "cartografie",
    "cartografiile": "cartografie",
    "cartografiilor": "cartografie",
    "cartografio": "cartografie",
    "cartografierea": "cartografiere",
    "cartografiereo": "cartografiere",
    "cartografieri": "cartografiere",
    "cartografierii": "cartografiere",
    "cartografierile": "cartografiere",
    "cartografierilor": "cartografiere",
    "cartograma": "cartogramă",
    "cartograme": "cartogramă",
    "cartogramei": "cartogramă",
    "cartogramele": "cartogramă",
    "cartogramelor": "cartogramă",
    "cartogramo": "cartogramă",
    "cărțoaie": "cărțoi",
    "cărțoaiele": "cărțoi",
    "cărțoaielor": "cărțoi",
    "cărțoiul": "cărțoi",
    "cărțoiule": "cărțoi",
    "cărțoiului": "cărțoi",
    "cartoane": "carton",
    "cartoanele": "carton",
    "cartoanelor": "carton",
    "cartonul": "carton",
    "cartonule": "carton",
    "cartonului": "carton",
    "cartonă": "cartona",
    "cartonai": "cartona",
    "cartonam": "cartona",
    "cartonăm": "cartona",
    "cartonând": "cartona",
    "cartonându": "cartona",
    "cartonară": "cartona",
    "cartonarăm": "cartona",
    "cartonarăți": "cartona",
    "cartonase": "cartona",
    "cartonasem": "cartona",
    "cartonaseră": "cartona",
    "cartonaserăm": "cartona",
    "cartonaserăți": "cartona",
    "cartonaseși": "cartona",
    "cartonași": "cartona",
    "cartonat": "cartona",
    "cartonați": "cartona",
    "cartonatu": "cartona",
    "cartonau": "cartona",
    "cartonează": "cartona",
    "cartonez": "cartona",
    "cartoneze": "cartona",
    "cartonezi": "cartona",
    "necartonând": "cartona",
    "necartonându": "cartona",
    "nemaicartonând": "cartona",
    "nemaicartonându": "cartona",
    "cartonaje": "cartonaj",
    "cartonajele": "cartonaj",
    "cartonajelor": "cartonaj",
    "cartonajul": "cartonaj",
    "cartonajule": "cartonaj",
    "cartonajului": "cartonaj",
    "cartonarea": "cartonare",
    "cartonareo": "cartonare",
    "cartonări": "cartonare",
    "cartonării": "cartonare",
    "cartonările": "cartonare",
    "cartonărilor": "cartonare",
    "cartonașe": "cartonaș",
    "cartonașele": "cartonaș",
    "cartonașelor": "cartonaș",
    "cartonașul": "cartonaș",
    "cartonașule": "cartonaș",
    "cartonașului": "cartonaș",
    "cartonata": "cartonat",
    "cartonată": "cartonat",
    "cartonate": "cartonat",
    "cartonatei": "cartonat",
    "cartonatele": "cartonat",
    "cartonatelor": "cartonat",
    "cartonați": "cartonat",
    "cartonații": "cartonat",
    "cartonaților": "cartonat",
    "cartonato": "cartonat",
    "cartonatul": "cartonat",
    "cartonatule": "cartonat",
    "cartonatului": "cartonat",
    "cartoteca": "cartotecă",
    "cartoteci": "cartotecă",
    "cartotecii": "cartotecă",
    "cartotecile": "cartotecă",
    "cartotecilor": "cartotecă",
    "cartoteco": "cartotecă",
    "cărțulia": "cărțulie",
    "cărțuliei": "cărțulie",
    "cărțulii": "cărțulie",
    "cărțuliile": "cărțulie",
    "cărțuliilor": "cărțulie",
    "cărțulio": "cărțulie",
    "cărturari": "cărturar",
    "cărturarii": "cărturar",
    "cărturarilor": "cărturar",
    "cărturarul": "cărturar",
    "cărturarule": "cărturar",
    "cărturarului": "cărturar",
    "cărturăreasa": "cărturăreasă",
    "cărturăreaso": "cărturăreasă",
    "cărturărese": "cărturăreasă",
    "cărturăresei": "cărturăreasă",
    "cărturăresele": "cărturăreasă",
    "cărturăreselor": "cărturăreasă",
    "cărturăreasca": "cărturăresc",
    "cărturărească": "cărturăresc",
    "cărturăreasco": "cărturăresc",
    "cărturărescul": "cărturăresc",
    "cărturărescule": "cărturăresc",
    "cărturărescului": "cărturăresc",
    "cărturărești": "cărturăresc",
    "cărturăreștii": "cărturăresc",
    "cărturăreștile": "cărturăresc",
    "cărturăreștilor": "cărturăresc",
    "cărturăria": "cărturărie",
    "cărturăriei": "cărturărie",
    "cărturării": "cărturărie",
    "cărturăriile": "cărturărie",
    "cărturăriilor": "cărturărie",
    "cărturărio": "cărturărie",
    "cartușe": "cartuș",
    "cartușele": "cartuș",
    "cartușelor": "cartuș",
    "cartușul": "cartuș",
    "cartușule": "cartuș",
    "cartușului": "cartuș",
    "cartușiera": "cartușieră",
    "cartușiere": "cartușieră",
    "cartușierei": "cartușieră",
    "cartușierele": "cartușieră",
    "cartușierelor": "cartușieră",
    "cartușiero": "cartușieră",
    "cărucioare": "cărucior",
    "cărucioarele": "cărucior",
    "cărucioarelor": "cărucior",
    "căruciorul": "cărucior",
    "căruciorule": "cărucior",
    "căruciorului": "cărucior",
    "cărunta": "cărunt",
    "căruntă": "cărunt",
    "cărunte": "cărunt",
    "căruntei": "cărunt",
    "căruntele": "cărunt",
    "căruntelor": "cărunt",
    "cărunți": "cărunt",
    "cărunții": "cărunt",
    "cărunților": "cărunt",
    "cărunto": "cărunt",
    "căruntul": "cărunt",
    "căruntule": "cărunt",
    "căruntului": "cărunt",
    "cărunțeala": "cărunțeală",
    "cărunțealo": "cărunțeală",
    "cărunțeli": "cărunțeală",
    "cărunțelii": "cărunțeală",
    "căruntețea": "căruntețe",
    "căruntețeo": "căruntețe",
    "cărunteți": "căruntețe",
    "cărunteții": "căruntețe",
    "carusele": "carusel",
    "caruselele": "carusel",
    "caruselelor": "carusel",
    "caruselul": "carusel",
    "caruselule": "carusel",
    "caruselului": "carusel",
    "căruța": "căruță",
    "căruțe": "căruță",
    "căruței": "căruță",
    "căruțele": "căruță",
    "căruțelor": "căruță",
    "căruțo": "căruță",
    "căruțăria": "căruțărie",
    "căruțăriei": "căruțărie",
    "căruțării": "căruțărie",
    "căruțăriile": "căruțărie",
    "căruțăriilor": "căruțărie",
    "căruțărio": "căruțărie",
    "căruțași": "căruțaș",
    "căruțașii": "căruțaș",
    "căruțașilor": "căruțaș",
    "căruțașul": "căruțaș",
    "căruțașule": "căruțaș",
    "căruțașului": "căruțaș",
    "cașul": "caș",
    "cașule": "caș",
    "cașului": "caș",
    "cașuri": "caș",
    "cașurile": "caș",
    "cașurilor": "caș",
    "casă": "casa",
    "casai": "casa",
    "casam": "casa",
    "casăm": "casa",
    "casând": "casa",
    "casându": "casa",
    "casară": "casa",
    "casarăm": "casa",
    "casarăți": "casa",
    "casase": "casa",
    "casasem": "casa",
    "casaseră": "casa",
    "casaserăm": "casa",
    "casaserăți": "casa",
    "casaseși": "casa",
    "casași": "casa",
    "casat": "casa",
    "casați": "casa",
    "casatu": "casa",
    "casau": "casa",
    "casează": "casa",
    "casez": "casa",
    "caseze": "casa",
    "casezi": "casa",
    "necasând": "casa",
    "necasându": "casa",
    "nemaicasând": "casa",
    "nemaicasându": "casa",
    "casa": "casă",
    "case": "casă",
    "casei": "casă",
    "casele": "casă",
    "caselor": "casă",
    "caso": "casă",
    "CEC": "Casa_de_Economii_și_Consemnațiuni",
    "casabila": "casabil",
    "casabilă": "casabil",
    "casabile": "casabil",
    "casabilei": "casabil",
    "casabilele": "casabil",
    "casabilelor": "casabil",
    "casabili": "casabil",
    "casabilii": "casabil",
    "casabililor": "casabil",
    "casabilo": "casabil",
    "casabilul": "casabil",
    "casabilule": "casabil",
    "casabilului": "casabil",
    "cașaloți": "cașalot",
    "cașaloții": "cașalot",
    "cașaloților": "cașalot",
    "cașalotul": "cașalot",
    "cașalotule": "cașalot",
    "cașalotului": "cașalot",
    "casanta": "casant",
    "casantă": "casant",
    "casante": "casant",
    "casantei": "casant",
    "casantele": "casant",
    "casantelor": "casant",
    "casanți": "casant",
    "casanții": "casant",
    "casanților": "casant",
    "casanto": "casant",
    "casantul": "casant",
    "casantule": "casant",
    "casantului": "casant",
    "casapi": "casap",
    "casapii": "casap",
    "casapilor": "casap",
    "casapul": "casap",
    "casapule": "casap",
    "casapului": "casap",
    "căsăpea": "căsăpi",
    "căsăpeai": "căsăpi",
    "căsăpeam": "căsăpi",
    "căsăpească": "căsăpi",
    "căsăpeați": "căsăpi",
    "căsăpeau": "căsăpi",
    "căsăpesc": "căsăpi",
    "căsăpește": "căsăpi",
    "căsăpești": "căsăpi",
    "căsăpii": "căsăpi",
    "căsăpim": "căsăpi",
    "căsăpind": "căsăpi",
    "căsăpindu": "căsăpi",
    "căsăpiră": "căsăpi",
    "căsăpirăm": "căsăpi",
    "căsăpirăți": "căsăpi",
    "căsăpise": "căsăpi",
    "căsăpisem": "căsăpi",
    "căsăpiseră": "căsăpi",
    "căsăpiserăm": "căsăpi",
    "căsăpiserăți": "căsăpi",
    "căsăpiseși": "căsăpi",
    "căsăpiși": "căsăpi",
    "căsăpit": "căsăpi",
    "căsăpiți": "căsăpi",
    "căsăpitu": "căsăpi",
    "necăsăpind": "căsăpi",
    "necăsăpindu": "căsăpi",
    "nemaicăsăpind": "căsăpi",
    "nemaicăsăpindu": "căsăpi",
    "căsăpirea": "căsăpire",
    "căsăpireo": "căsăpire",
    "căsăpiri": "căsăpire",
    "căsăpirii": "căsăpire",
    "căsăpirile": "căsăpire",
    "căsăpirilor": "căsăpire",
    "căsăpită": "căsăpit",
    "căsăpite": "căsăpit",
    "căsăpiți": "căsăpit",
    "casarea": "casare",
    "casareo": "casare",
    "casări": "casare",
    "casării": "casare",
    "casările": "casare",
    "casărilor": "casare",
    "casată": "casat",
    "casate": "casat",
    "casați": "casat",
    "casata": "casată",
    "casate": "casată",
    "casatei": "casată",
    "casatele": "casată",
    "casatelor": "casată",
    "casato": "casată",
    "căsătorea": "căsători",
    "căsătoreai": "căsători",
    "căsătoream": "căsători",
    "căsătorească": "căsători",
    "căsătoreați": "căsători",
    "căsătoreau": "căsători",
    "căsătoresc": "căsători",
    "căsătorește": "căsători",
    "căsătorești": "căsători",
    "căsătorii": "căsători",
    "căsătorim": "căsători",
    "căsătorind": "căsători",
    "căsătorindu": "căsători",
    "căsătoriră": "căsători",
    "căsătorirăm": "căsători",
    "căsătorirăți": "căsători",
    "căsătorise": "căsători",
    "căsătorisem": "căsători",
    "căsătoriseră": "căsători",
    "căsătoriserăm": "căsători",
    "căsătoriserăți": "căsători",
    "căsătoriseși": "căsători",
    "căsătoriși": "căsători",
    "căsătorit": "căsători",
    "căsătoriți": "căsători",
    "căsătoritu": "căsători",
    "necăsătorind": "căsători",
    "necăsătorindu": "căsători",
    "nemaicăsătorind": "căsători",
    "nemaicăsătorindu": "căsători",
    "căsătoria": "căsătorie",
    "căsătoriei": "căsătorie",
    "căsătorii": "căsătorie",
    "căsătoriile": "căsătorie",
    "căsătoriilor": "căsătorie",
    "căsătorio": "căsătorie",
    "căsătorita": "căsătorit",
    "căsătorită": "căsătorit",
    "căsătorite": "căsătorit",
    "căsătoritei": "căsătorit",
    "căsătoritele": "căsătorit",
    "căsătoritelor": "căsătorit",
    "căsătoriți": "căsătorit",
    "căsătoriții": "căsătorit",
    "căsătoriților": "căsătorit",
    "căsătorito": "căsătorit",
    "căsătoritul": "căsătorit",
    "căsătoritule": "căsătorit",
    "căsătoritului": "căsătorit",
    "casca": "cască",
    "casco": "cască",
    "căști": "cască",
    "căștii": "cască",
    "căștile": "cască",
    "căștilor": "cască",
    "casc": "căsca",
    "cască": "căsca",
    "căscă": "căsca",
    "căscai": "căsca",
    "căscam": "căsca",
    "căscăm": "căsca",
    "căscând": "căsca",
    "căscându": "căsca",
    "căscară": "căsca",
    "căscarăm": "căsca",
    "căscarăți": "căsca",
    "căscase": "căsca",
    "căscasem": "căsca",
    "căscaseră": "căsca",
    "căscaserăm": "căsca",
    "căscaserăți": "căsca",
    "căscaseși": "căsca",
    "căscași": "căsca",
    "căscat": "căsca",
    "căscați": "căsca",
    "căscatu": "căsca",
    "căscau": "căsca",
    "caște": "căsca",
    "caști": "căsca",
    "necăscând": "căsca",
    "necăscându": "căsca",
    "nemaicăscând": "căsca",
    "nemaicăscându": "căsca",
    "cascada": "cascadă",
    "cascade": "cascadă",
    "cascadei": "cascadă",
    "cascadele": "cascadă",
    "cascadelor": "cascadă",
    "cascado": "cascadă",
    "căscarea": "căscare",
    "căscareo": "căscare",
    "căscări": "căscare",
    "căscării": "căscare",
    "căscările": "căscare",
    "căscărilor": "căscare",
    "căscata": "căscat",
    "căscată": "căscat",
    "căscate": "căscat",
    "căscatei": "căscat",
    "căscatele": "căscat",
    "căscatelor": "căscat",
    "căscați": "căscat",
    "căscații": "căscat",
    "căscaților": "căscat",
    "căscato": "căscat",
    "căscatul": "căscat",
    "căscatule": "căscat",
    "căscatului": "căscat",
    "căscaturi": "căscat",
    "căscaturile": "căscat",
    "căscaturilor": "căscat",
    "cașcavalul": "cașcaval",
    "cașcavalule": "cașcaval",
    "cașcavalului": "cașcaval",
    "cașcavaluri": "cașcaval",
    "cașcavalurile": "cașcaval",
    "cașcavalurilor": "cașcaval",
    "cascheta": "caschetă",
    "caschete": "caschetă",
    "caschetei": "caschetă",
    "caschetele": "caschetă",
    "caschetelor": "caschetă",
    "cascheto": "caschetă",
    "căscioara": "căscioară",
    "căscioare": "căscioară",
    "căscioarei": "căscioară",
    "căscioarele": "căscioară",
    "căscioarelor": "căscioară",
    "căscioaro": "căscioară",
    "caseta": "casetă",
    "casete": "casetă",
    "casetei": "casetă",
    "casetele": "casetă",
    "casetelor": "casetă",
    "caseto": "casetă",
    "cașeta": "cașetă",
    "cașete": "cașetă",
    "cașetei": "cașetă",
    "cașetele": "cașetă",
    "cașetelor": "cașetă",
    "cașeto": "cașetă",
    "casieri": "casier",
    "casierii": "casier",
    "casierilor": "casier",
    "casierul": "casier",
    "casierule": "casier",
    "casierului": "casier",
    "casieria": "casierie",
    "casieriei": "casierie",
    "casierii": "casierie",
    "casieriile": "casierie",
    "casieriilor": "casierie",
    "casierio": "casierie",
    "casierița": "casieriță",
    "casierițe": "casieriță",
    "casieriței": "casieriță",
    "casierițele": "casieriță",
    "casierițelor": "casieriță",
    "casierițo": "casieriță",
    "căsișoara": "căsișoară",
    "căsișoare": "căsișoară",
    "căsișoarei": "căsișoară",
    "căsișoarele": "căsișoară",
    "căsișoarelor": "căsișoară",
    "căsișoaro": "căsișoară",
    "casnica": "casnic",
    "casnică": "casnic",
    "casnice": "casnic",
    "casnicei": "casnic",
    "casnicele": "casnic",
    "casnicelor": "casnic",
    "casnici": "casnic",
    "casnicii": "casnic",
    "casnicilor": "casnic",
    "casnico": "casnic",
    "casnicul": "casnic",
    "casnicule": "casnic",
    "casnicului": "casnic",
    "căsnicia": "căsnicie",
    "căsniciei": "căsnicie",
    "căsnicii": "căsnicie",
    "căsniciile": "căsnicie",
    "căsniciilor": "căsnicie",
    "căsoaia": "căsoaie",
    "căsoaiei": "căsoaie",
    "căsoaiele": "căsoaie",
    "căsoaielor": "căsoaie",
    "căsoaio": "căsoaie",
    "căsoiul": "căsoi",
    "căsoiule": "căsoi",
    "căsoiului": "căsoi",
    "casoleta": "casoletă",
    "casolete": "casoletă",
    "casoletei": "casoletă",
    "casoletele": "casoletă",
    "casoletelor": "casoletă",
    "casoleto": "casoletă",
    "casta": "cast",
    "castă": "cast",
    "caste": "cast",
    "castei": "cast",
    "castele": "cast",
    "castelor": "cast",
    "caști": "cast",
    "caștii": "cast",
    "caștilor": "cast",
    "casto": "cast",
    "castul": "cast",
    "castule": "cast",
    "castului": "cast",
    "casta": "castă",
    "caste": "castă",
    "castei": "castă",
    "castele": "castă",
    "castelor": "castă",
    "casto": "castă",
    "castani": "castan",
    "castanii": "castan",
    "castanilor": "castan",
    "castanul": "castan",
    "castanule": "castan",
    "castanului": "castan",
    "castana": "castană",
    "castane": "castană",
    "castanei": "castană",
    "castanele": "castană",
    "castanelor": "castană",
    "castano": "castană",
    "castanieta": "castanietă",
    "castaniete": "castanietă",
    "castanietei": "castanietă",
    "castanietele": "castanietă",
    "castanietelor": "castanietă",
    "castanieto": "castanietă",
    "castania": "castaniu",
    "castanie": "castaniu",
    "castaniei": "castaniu",
    "castanii": "castaniu",
    "castaniii": "castaniu",
    "castaniile": "castaniu",
    "castaniilor": "castaniu",
    "castanio": "castaniu",
    "castaniul": "castaniu",
    "castaniule": "castaniu",
    "castaniului": "castaniu",
    "castele": "castel",
    "castelele": "castel",
    "castelelor": "castel",
    "castelul": "castel",
    "castelule": "castel",
    "castelului": "castel",
    "câștigul": "câștig",
    "câștigule": "câștig",
    "câștigului": "câștig",
    "câștiguri": "câștig",
    "câștigurile": "câștig",
    "câștigurilor": "câștig",
    "câștig": "câștiga",
    "câștigă": "câștiga",
    "câștigai": "câștiga",
    "câștigam": "câștiga",
    "câștigăm": "câștiga",
    "câștigând": "câștiga",
    "câștigându": "câștiga",
    "câștigară": "câștiga",
    "câștigarăm": "câștiga",
    "câștigarăți": "câștiga",
    "câștigase": "câștiga",
    "câștigasem": "câștiga",
    "câștigaseră": "câștiga",
    "câștigaserăm": "câștiga",
    "câștigaserăți": "câștiga",
    "câștigaseși": "câștiga",
    "câștigași": "câștiga",
    "câștigat": "câștiga",
    "câștigați": "câștiga",
    "câștigatu": "câștiga",
    "câștigau": "câștiga",
    "câștige": "câștiga",
    "câștigi": "câștiga",
    "necâștigând": "câștiga",
    "necâștigându": "câștiga",
    "nemaicâștigând": "câștiga",
    "nemaicâștigându": "câștiga",
    "câștigarea": "câștigare",
    "câștigareo": "câștigare",
    "câștigări": "câștigare",
    "câștigării": "câștigare",
    "câștigările": "câștigare",
    "câștigărilor": "câștigare",
    "câștigata": "câștigat",
    "câștigată": "câștigat",
    "câștigate": "câștigat",
    "câștigatei": "câștigat",
    "câștigatele": "câștigat",
    "câștigatelor": "câștigat",
    "câștigați": "câștigat",
    "câștigații": "câștigat",
    "câștigaților": "câștigat",
    "câștigato": "câștigat",
    "câștigatul": "câștigat",
    "câștigatule": "câștigat",
    "câștigatului": "câștigat",
    "câștigătoarea": "câștigătoare",
    "câștigătoarei": "câștigătoare",
    "câștigătoarele": "câștigătoare",
    "câștigătoarelor": "câștigătoare",
    "câștigătoareo": "câștigătoare",
    "câștigătoare": "câștigător",
    "câștigătoarea": "câștigător",
    "câștigătoarei": "câștigător",
    "câștigătoarele": "câștigător",
    "câștigătoarelor": "câștigător",
    "câștigătoareo": "câștigător",
    "câștigători": "câștigător",
    "câștigătorii": "câștigător",
    "câștigătorilor": "câștigător",
    "câștigătorul": "câștigător",
    "câștigătorule": "câștigător",
    "câștigătorului": "câștigător",
    "castitatea": "castitate",
    "castitateo": "castitate",
    "castități": "castitate",
    "castității": "castitate",
    "castitățile": "castitate",
    "castităților": "castitate",
    "castori": "castor",
    "castorii": "castor",
    "castorilor": "castor",
    "castorul": "castor",
    "castorule": "castor",
    "castorului": "castor",
    "castră": "castra",
    "castrai": "castra",
    "castram": "castra",
    "castrăm": "castra",
    "castrând": "castra",
    "castrându": "castra",
    "castrară": "castra",
    "castrarăm": "castra",
    "castrarăți": "castra",
    "castrase": "castra",
    "castrasem": "castra",
    "castraseră": "castra",
    "castraserăm": "castra",
    "castraserăți": "castra",
    "castraseși": "castra",
    "castrași": "castra",
    "castrat": "castra",
    "castrați": "castra",
    "castratu": "castra",
    "castrau": "castra",
    "castrează": "castra",
    "castrez": "castra",
    "castreze": "castra",
    "castrezi": "castra",
    "necastrând": "castra",
    "necastrându": "castra",
    "nemaicastrând": "castra",
    "nemaicastrându": "castra",
    "castrarea": "castrare",
    "castrareo": "castrare",
    "castrări": "castrare",
    "castrării": "castrare",
    "castrările": "castrare",
    "castrărilor": "castrare",
    "castrată": "castrat",
    "castrate": "castrat",
    "castrați": "castrat",
    "castraveciori": "castravecior",
    "castraveciorii": "castravecior",
    "castraveciorilor": "castravecior",
    "castraveciorul": "castravecior",
    "castraveciorule": "castravecior",
    "castraveciorului": "castravecior",
    "castravetele": "castravete",
    "castravetelui": "castravete",
    "castraveți": "castravete",
    "castraveții": "castravete",
    "castraveților": "castravete",
    "castroane": "castron",
    "castroanele": "castron",
    "castroanelor": "castron",
    "castronul": "castron",
    "castronule": "castron",
    "castronului": "castron",
    "castronașe": "castronaș",
    "castronașele": "castronaș",
    "castronașelor": "castronaș",
    "castronașul": "castronaș",
    "castronașule": "castronaș",
    "castronașului": "castronaș",
    "castronele": "castronel",
    "castronelele": "castronel",
    "castronelelor": "castronel",
    "castronelul": "castronel",
    "castronelule": "castronel",
    "castronelului": "castronel",
    "castre": "castru",
    "castrele": "castru",
    "castrelor": "castru",
    "castrul": "castru",
    "castrule": "castru",
    "castrului": "castru",
    "cășună": "cășuna",
    "cășunai": "cășuna",
    "cășunam": "cășuna",
    "cășunăm": "cășuna",
    "cășunând": "cășuna",
    "cășunându": "cășuna",
    "cășunară": "cășuna",
    "cășunarăm": "cășuna",
    "cășunarăți": "cășuna",
    "cășunase": "cășuna",
    "cășunasem": "cășuna",
    "cășunaseră": "cășuna",
    "cășunaserăm": "cășuna",
    "cășunaserăți": "cășuna",
    "cășunaseși": "cășuna",
    "cășunași": "cășuna",
    "cășunat": "cășuna",
    "cășunați": "cășuna",
    "cășunatu": "cășuna",
    "cășunau": "cășuna",
    "cășunează": "cășuna",
    "cășunez": "cășuna",
    "cășuneze": "cășuna",
    "cășunezi": "cășuna",
    "necășunând": "cășuna",
    "necășunându": "cășuna",
    "nemaicășunând": "cășuna",
    "nemaicășunându": "cășuna",
    "cășunată": "cășunat",
    "cășunate": "cășunat",
    "cășunați": "cășunat",
    "căsuța": "căsuță",
    "căsuțe": "căsuță",
    "căsuței": "căsuță",
    "căsuțele": "căsuță",
    "căsuțelor": "căsuță",
    "căsuțo": "căsuță",
    "catul": "cat",
    "catule": "cat",
    "catului": "cat",
    "caturi": "cat",
    "caturile": "cat",
    "caturilor": "cat",
    "câtă": "cât",
    "câte": "cât",
    "câți": "cât",
    "câtor": "cât",
    "câtul": "cât",
    "câtule": "cât",
    "câtului": "cât",
    "câturi": "cât",
    "câturile": "cât",
    "câturilor": "cât",
    "cața": "cață",
    "cațe": "cață",
    "caței": "cață",
    "cațele": "cață",
    "cațelor": "cață",
    "cațo": "cață",
    "cataclisme": "cataclism",
    "cataclismele": "cataclism",
    "cataclismelor": "cataclism",
    "cataclismul": "cataclism",
    "cataclismule": "cataclism",
    "cataclismului": "cataclism",
    "catacomba": "catacombă",
    "catacombe": "catacombă",
    "catacombei": "catacombă",
    "catacombele": "catacombă",
    "catacombelor": "catacombă",
    "catacombo": "catacombă",
    "catadicsea": "catadicsi",
    "catadicseai": "catadicsi",
    "catadicseam": "catadicsi",
    "catadicsească": "catadicsi",
    "catadicseați": "catadicsi",
    "catadicseau": "catadicsi",
    "catadicsesc": "catadicsi",
    "catadicsește": "catadicsi",
    "catadicsești": "catadicsi",
    "catadicsii": "catadicsi",
    "catadicsim": "catadicsi",
    "catadicsind": "catadicsi",
    "catadicsindu": "catadicsi",
    "catadicsiră": "catadicsi",
    "catadicsirăm": "catadicsi",
    "catadicsirăți": "catadicsi",
    "catadicsise": "catadicsi",
    "catadicsisem": "catadicsi",
    "catadicsiseră": "catadicsi",
    "catadicsiserăm": "catadicsi",
    "catadicsiserăți": "catadicsi",
    "catadicsiseși": "catadicsi",
    "catadicsiși": "catadicsi",
    "catadicsit": "catadicsi",
    "catadicsiți": "catadicsi",
    "catadicsitu": "catadicsi",
    "necatadicsind": "catadicsi",
    "necatadicsindu": "catadicsi",
    "nemaicatadicsind": "catadicsi",
    "nemaicatadicsindu": "catadicsi",
    "catadicsită": "catadicsit",
    "catadicsite": "catadicsit",
    "catadicsiți": "catadicsit",
    "catafalcul": "catafalc",
    "catafalcule": "catafalc",
    "catafalcului": "catafalc",
    "catafalcuri": "catafalc",
    "catafalcurile": "catafalc",
    "catafalcurilor": "catafalc",
    "cataiful": "cataif",
    "cataifule": "cataif",
    "cataifului": "cataif",
    "cataifuri": "cataif",
    "cataifurile": "cataif",
    "cataifurilor": "cataif",
    "catalana": "catalan",
    "catalană": "catalan",
    "catalane": "catalan",
    "catalanei": "catalan",
    "catalanele": "catalan",
    "catalanelor": "catalan",
    "catalani": "catalan",
    "catalanii": "catalan",
    "catalanilor": "catalan",
    "catalano": "catalan",
    "catalanul": "catalan",
    "catalanule": "catalan",
    "catalanului": "catalan",
    "catalana": "catalană",
    "catalane": "catalană",
    "catalanei": "catalană",
    "catalanele": "catalană",
    "catalanelor": "catalană",
    "catalano": "catalană",
    "cataleptica": "cataleptic",
    "cataleptică": "cataleptic",
    "cataleptice": "cataleptic",
    "catalepticei": "cataleptic",
    "catalepticele": "cataleptic",
    "catalepticelor": "cataleptic",
    "cataleptici": "cataleptic",
    "catalepticii": "cataleptic",
    "catalepticilor": "cataleptic",
    "cataleptico": "cataleptic",
    "catalepticul": "cataleptic",
    "catalepticule": "cataleptic",
    "catalepticului": "cataleptic",
    "cataligele": "catalige",
    "cataligelor": "catalige",
    "catalitica": "catalitic",
    "catalitică": "catalitic",
    "catalitice": "catalitic",
    "cataliticei": "catalitic",
    "cataliticele": "catalitic",
    "cataliticelor": "catalitic",
    "catalitici": "catalitic",
    "cataliticii": "catalitic",
    "cataliticilor": "catalitic",
    "catalitico": "catalitic",
    "cataliticul": "catalitic",
    "cataliticule": "catalitic",
    "cataliticului": "catalitic",
    "cataliză": "cataliza",
    "catalizai": "cataliza",
    "catalizam": "cataliza",
    "catalizăm": "cataliza",
    "catalizând": "cataliza",
    "catalizându": "cataliza",
    "catalizară": "cataliza",
    "catalizarăm": "cataliza",
    "catalizarăți": "cataliza",
    "catalizase": "cataliza",
    "catalizasem": "cataliza",
    "catalizaseră": "cataliza",
    "catalizaserăm": "cataliza",
    "catalizaserăți": "cataliza",
    "catalizaseși": "cataliza",
    "catalizași": "cataliza",
    "catalizat": "cataliza",
    "catalizați": "cataliza",
    "catalizatu": "cataliza",
    "catalizau": "cataliza",
    "catalizează": "cataliza",
    "catalizez": "cataliza",
    "catalizeze": "cataliza",
    "catalizezi": "cataliza",
    "necatalizând": "cataliza",
    "necatalizându": "cataliza",
    "nemaicatalizând": "cataliza",
    "nemaicatalizându": "cataliza",
    "catalizarea": "catalizare",
    "catalizareo": "catalizare",
    "catalizări": "catalizare",
    "catalizării": "catalizare",
    "catalizările": "catalizare",
    "catalizărilor": "catalizare",
    "catalizată": "catalizat",
    "catalizate": "catalizat",
    "catalizați": "catalizat",
    "catalizatori": "catalizator",
    "catalizatorii": "catalizator",
    "catalizatorilor": "catalizator",
    "catalizatorul": "catalizator",
    "catalizatorule": "catalizator",
    "catalizatorului": "catalizator",
    "cataloage": "catalog",
    "cataloagele": "catalog",
    "cataloagelor": "catalog",
    "catalogul": "catalog",
    "catalogule": "catalog",
    "catalogului": "catalog",
    "catalogă": "cataloga",
    "catalogai": "cataloga",
    "catalogam": "cataloga",
    "catalogăm": "cataloga",
    "catalogând": "cataloga",
    "catalogându": "cataloga",
    "catalogară": "cataloga",
    "catalogarăm": "cataloga",
    "catalogarăți": "cataloga",
    "catalogase": "cataloga",
    "catalogasem": "cataloga",
    "catalogaseră": "cataloga",
    "catalogaserăm": "cataloga",
    "catalogaserăți": "cataloga",
    "catalogaseși": "cataloga",
    "catalogași": "cataloga",
    "catalogat": "cataloga",
    "catalogați": "cataloga",
    "catalogatu": "cataloga",
    "catalogau": "cataloga",
    "cataloghează": "cataloga",
    "cataloghez": "cataloga",
    "catalogheze": "cataloga",
    "cataloghezi": "cataloga",
    "necatalogând": "cataloga",
    "necatalogându": "cataloga",
    "nemaicatalogând": "cataloga",
    "nemaicatalogându": "cataloga",
    "catalogarea": "catalogare",
    "catalogareo": "catalogare",
    "catalogări": "catalogare",
    "catalogării": "catalogare",
    "catalogările": "catalogare",
    "catalogărilor": "catalogare",
    "catalogată": "catalogat",
    "catalogate": "catalogat",
    "catalogați": "catalogat",
    "cătana": "cătană",
    "cătane": "cătană",
    "cătanei": "cătană",
    "cătanele": "cătană",
    "cătanelor": "cătană",
    "cătano": "cătană",
    "cătănea": "cătăni",
    "cătăneai": "cătăni",
    "cătăneam": "cătăni",
    "cătănească": "cătăni",
    "cătăneați": "cătăni",
    "cătăneau": "cătăni",
    "cătănesc": "cătăni",
    "cătănește": "cătăni",
    "cătănești": "cătăni",
    "cătănii": "cătăni",
    "cătănim": "cătăni",
    "cătănind": "cătăni",
    "cătănindu": "cătăni",
    "cătăniră": "cătăni",
    "cătănirăm": "cătăni",
    "cătănirăți": "cătăni",
    "cătănise": "cătăni",
    "cătănisem": "cătăni",
    "cătăniseră": "cătăni",
    "cătăniserăm": "cătăni",
    "cătăniserăți": "cătăni",
    "cătăniseși": "cătăni",
    "cătăniși": "cătăni",
    "cătănit": "cătăni",
    "cătăniți": "cătăni",
    "cătănitu": "cătăni",
    "necătănind": "cătăni",
    "necătănindu": "cătăni",
    "nemaicătănind": "cătăni",
    "nemaicătănindu": "cătăni",
    "cătănia": "cătănie",
    "cătăniei": "cătănie",
    "cătănii": "cătănie",
    "cătăniile": "cătănie",
    "cătăniilor": "cătănie",
    "cătănio": "cătănie",
    "cătănită": "cătănit",
    "cătănite": "cătănit",
    "cătăniți": "cătănit",
    "catapeteasma": "catapeteasmă",
    "catapeteasme": "catapeteasmă",
    "catapeteasmei": "catapeteasmă",
    "catapeteasmele": "catapeteasmă",
    "catapeteasmelor": "catapeteasmă",
    "catapeteasmo": "catapeteasmă",
    "catapetesme": "catapeteasmă",
    "catapetesmei": "catapeteasmă",
    "catapetesmele": "catapeteasmă",
    "catapetesmelor": "catapeteasmă",
    "cataplasma": "cataplasmă",
    "cataplasme": "cataplasmă",
    "cataplasmei": "cataplasmă",
    "cataplasmele": "cataplasmă",
    "cataplasmelor": "cataplasmă",
    "cataplasmo": "cataplasmă",
    "catapulta": "catapultă",
    "catapulte": "catapultă",
    "catapultei": "catapultă",
    "catapultele": "catapultă",
    "catapultelor": "catapultă",
    "catapulto": "catapultă",
    "catâri": "catâr",
    "catârii": "catâr",
    "catârilor": "catâr",
    "catârul": "catâr",
    "catârule": "catâr",
    "catârului": "catâr",
    "cațăr": "cățăra",
    "cațără": "cățăra",
    "cățără": "cățăra",
    "cățărai": "cățăra",
    "cățăram": "cățăra",
    "cățărăm": "cățăra",
    "cățărând": "cățăra",
    "cățărându": "cățăra",
    "cățărară": "cățăra",
    "cățărarăm": "cățăra",
    "cățărarăți": "cățăra",
    "cățărase": "cățăra",
    "cățărasem": "cățăra",
    "cățăraseră": "cățăra",
    "cățăraserăm": "cățăra",
    "cățăraserăți": "cățăra",
    "cățăraseși": "cățăra",
    "cățărași": "cățăra",
    "cățărat": "cățăra",
    "cățărați": "cățăra",
    "cățăratu": "cățăra",
    "cățărau": "cățăra",
    "cațere": "cățăra",
    "cațeri": "cățăra",
    "necățărând": "cățăra",
    "necățărându": "cățăra",
    "nemaicățărând": "cățăra",
    "nemaicățărându": "cățăra",
    "cataracta": "cataractă",
    "cataracte": "cataractă",
    "cataractei": "cataractă",
    "cataractele": "cataractă",
    "cataractelor": "cataractă",
    "cataracto": "cataractă",
    "catarala": "cataral",
    "catarală": "cataral",
    "catarale": "cataral",
    "cataralei": "cataral",
    "cataralele": "cataral",
    "cataralelor": "cataral",
    "catarali": "cataral",
    "cataralii": "cataral",
    "cataralilor": "cataral",
    "cataralo": "cataral",
    "cataralul": "cataral",
    "cataralule": "cataral",
    "cataralului": "cataral",
    "catarama": "cataramă",
    "catarame": "cataramă",
    "cataramei": "cataramă",
    "cataramele": "cataramă",
    "cataramelor": "cataramă",
    "cataramo": "cataramă",
    "cătărămuța": "cătărămuță",
    "cătărămuțe": "cătărămuță",
    "cătărămuței": "cătărămuță",
    "cătărămuțele": "cătărămuță",
    "cătărămuțelor": "cătărămuță",
    "cătărămuțo": "cătărămuță",
    "cățărată": "cățărat",
    "cățărate": "cățărat",
    "cățărați": "cățărat",
    "cățărătoare": "cățărător",
    "cățărătoarea": "cățărător",
    "cățărătoarei": "cățărător",
    "cățărătoarele": "cățărător",
    "cățărătoarelor": "cățărător",
    "cățărătoareo": "cățărător",
    "cățărători": "cățărător",
    "cățărătorii": "cățărător",
    "cățărătorilor": "cățărător",
    "cățărătorul": "cățărător",
    "cățărătorule": "cățărător",
    "cățărătorului": "cățărător",
    "cătarea": "cătare",
    "cătareo": "cătare",
    "cătări": "cătare",
    "cătării": "cătare",
    "cătările": "cătare",
    "cătărilor": "cătare",
    "catarge": "catarg",
    "catargele": "catarg",
    "catargelor": "catarg",
    "catargul": "catarg",
    "catargule": "catarg",
    "catargului": "catarg",
    "catastife": "catastif",
    "catastifele": "catastif",
    "catastifelor": "catastif",
    "catastiful": "catastif",
    "catastifule": "catastif",
    "catastifului": "catastif",
    "catastrofa": "catastrofă",
    "catastrofe": "catastrofă",
    "catastrofei": "catastrofă",
    "catastrofele": "catastrofă",
    "catastrofelor": "catastrofă",
    "catastrofo": "catastrofă",
    "catastrofala": "catastrofal",
    "catastrofală": "catastrofal",
    "catastrofale": "catastrofal",
    "catastrofalei": "catastrofal",
    "catastrofalele": "catastrofal",
    "catastrofalelor": "catastrofal",
    "catastrofali": "catastrofal",
    "catastrofalii": "catastrofal",
    "catastrofalilor": "catastrofal",
    "catastrofalo": "catastrofal",
    "catastrofalul": "catastrofal",
    "catastrofalule": "catastrofal",
    "catastrofalului": "catastrofal",
    "cățeao": "cățea",
    "cățeaua": "cățea",
    "cățele": "cățea",
    "cățelei": "cățea",
    "cățelele": "cățea",
    "cățelelor": "cățea",
    "catedra": "catedră",
    "catedre": "catedră",
    "catedrei": "catedră",
    "catedrele": "catedră",
    "catedrelor": "catedră",
    "catedro": "catedră",
    "catedrala": "catedrală",
    "catedrale": "catedrală",
    "catedralei": "catedrală",
    "catedralele": "catedrală",
    "catedralelor": "catedrală",
    "catedralo": "catedrală",
    "categorica": "categoric",
    "categorică": "categoric",
    "categorice": "categoric",
    "categoricei": "categoric",
    "categoricele": "categoric",
    "categoricelor": "categoric",
    "categorici": "categoric",
    "categoricii": "categoric",
    "categoricilor": "categoric",
    "categorico": "categoric",
    "categoricul": "categoric",
    "categoricule": "categoric",
    "categoricului": "categoric",
    "categ.": "categorie",
    "categoria": "categorie",
    "categoriei": "categorie",
    "categorii": "categorie",
    "categoriile": "categorie",
    "categoriilor": "categorie",
    "categorio": "categorie",
    "categorisea": "categorisi",
    "categoriseai": "categorisi",
    "categoriseam": "categorisi",
    "categorisească": "categorisi",
    "categoriseați": "categorisi",
    "categoriseau": "categorisi",
    "categorisesc": "categorisi",
    "categorisește": "categorisi",
    "categorisești": "categorisi",
    "categorisii": "categorisi",
    "categorisim": "categorisi",
    "categorisind": "categorisi",
    "categorisindu": "categorisi",
    "categorisiră": "categorisi",
    "categorisirăm": "categorisi",
    "categorisirăți": "categorisi",
    "categorisise": "categorisi",
    "categorisisem": "categorisi",
    "categorisiseră": "categorisi",
    "categorisiserăm": "categorisi",
    "categorisiserăți": "categorisi",
    "categorisiseși": "categorisi",
    "categorisiși": "categorisi",
    "categorisit": "categorisi",
    "categorisiți": "categorisi",
    "categorisitu": "categorisi",
    "necategorisind": "categorisi",
    "necategorisindu": "categorisi",
    "nemaicategorisind": "categorisi",
    "nemaicategorisindu": "categorisi",
    "categorisirea": "categorisire",
    "categorisireo": "categorisire",
    "categorisiri": "categorisire",
    "categorisirii": "categorisire",
    "categorisirile": "categorisire",
    "categorisirilor": "categorisire",
    "categorisită": "categorisit",
    "categorisite": "categorisit",
    "categorisiți": "categorisit",
    "cateheza": "cateheză",
    "cateheze": "cateheză",
    "catehezei": "cateheză",
    "catehezele": "cateheză",
    "catehezelor": "cateheză",
    "catehezo": "cateheză",
    "catehisme": "catehism",
    "catehismele": "catehism",
    "catehismelor": "catehism",
    "catehismul": "catehism",
    "catehismule": "catehism",
    "catehismului": "catehism",
    "catehizarea": "catehizare",
    "catehizareo": "catehizare",
    "catehizări": "catehizare",
    "catehizării": "catehizare",
    "catehizările": "catehizare",
    "catehizărilor": "catehizare",
    "căței": "cățel",
    "cățeii": "cățel",
    "cățeilor": "cățel",
    "cățelul": "cățel",
    "cățelule": "cățel",
    "cățelului": "cățel",
    "cățelani": "cățelan",
    "cățelanii": "cățelan",
    "cățelanilor": "cățelan",
    "cățelanul": "cățelan",
    "cățelanule": "cățelan",
    "cățelanului": "cățelan",
    "cățelandri": "cățelandru",
    "cățelandrii": "cățelandru",
    "cățelandrilor": "cățelandru",
    "cățelandrul": "cățelandru",
    "cățelandrule": "cățelandru",
    "cățelandrului": "cățelandru",
    "câta": "câtelea",
    "cățeluși": "cățeluș",
    "cățelușii": "cățeluș",
    "cățelușilor": "cățeluș",
    "cățelușul": "cățeluș",
    "cățelușule": "cățeluș",
    "cățelușului": "cățeluș",
    "cățelușa": "cățelușă",
    "cățelușe": "cățelușă",
    "cățelușei": "cățelușă",
    "cățelușele": "cățelușă",
    "cățelușelor": "cățelușă",
    "cățelușo": "cățelușă",
    "cateta": "catetă",
    "catete": "catetă",
    "catetei": "catetă",
    "catetele": "catetă",
    "catetelor": "catetă",
    "cateto": "catetă",
    "cathartica": "cathartic",
    "cathartică": "cathartic",
    "cathartice": "cathartic",
    "catharticei": "cathartic",
    "catharticele": "cathartic",
    "catharticelor": "cathartic",
    "cathartici": "cathartic",
    "catharticii": "cathartic",
    "catharticilor": "cathartic",
    "cathartico": "cathartic",
    "catharticul": "cathartic",
    "catharticule": "cathartic",
    "catharticului": "cathartic",
    "catifeao": "catifea",
    "catifeaua": "catifea",
    "catifele": "catifea",
    "catifelei": "catifea",
    "catifelele": "catifea",
    "catifelelor": "catifea",
    "catifelata": "catifelat",
    "catifelată": "catifelat",
    "catifelate": "catifelat",
    "catifelatei": "catifelat",
    "catifelatele": "catifelat",
    "catifelatelor": "catifelat",
    "catifelați": "catifelat",
    "catifelații": "catifelat",
    "catifelaților": "catifelat",
    "catifelato": "catifelat",
    "catifelatul": "catifelat",
    "catifelatule": "catifelat",
    "catifelatului": "catifelat",
    "catihetica": "catihetic",
    "catihetică": "catihetic",
    "catihetice": "catihetic",
    "catiheticei": "catihetic",
    "catiheticele": "catihetic",
    "catiheticelor": "catihetic",
    "catihetici": "catihetic",
    "catiheticii": "catihetic",
    "catiheticilor": "catihetic",
    "catihetico": "catihetic",
    "catiheticul": "catihetic",
    "catiheticule": "catihetic",
    "catiheticului": "catihetic",
    "câtimea": "câtime",
    "câtimeo": "câtime",
    "câtimi": "câtime",
    "câtimii": "câtime",
    "câtimile": "câtime",
    "câtimilor": "câtime",
    "cătina": "cătină",
    "cătini": "cătină",
    "cătinii": "cătină",
    "cătinile": "cătină",
    "cătinilor": "cătină",
    "cătino": "cătină",
    "cationi": "cation",
    "cationii": "cation",
    "cationilor": "cation",
    "cationul": "cation",
    "cationule": "cation",
    "cationului": "cation",
    "catodul": "catod",
    "catodule": "catod",
    "catodului": "catod",
    "catozi": "catod",
    "catozii": "catod",
    "catozilor": "catod",
    "catodica": "catodic",
    "catodică": "catodic",
    "catodice": "catodic",
    "catodicei": "catodic",
    "catodicele": "catodic",
    "catodicelor": "catodic",
    "catodici": "catodic",
    "catodicii": "catodic",
    "catodicilor": "catodic",
    "catodico": "catodic",
    "catodicul": "catodic",
    "catodicule": "catodic",
    "catodicului": "catodic",
    "catolica": "catolic",
    "catolică": "catolic",
    "catolice": "catolic",
    "catolicei": "catolic",
    "catolicele": "catolic",
    "catolicelor": "catolic",
    "catolici": "catolic",
    "catolicii": "catolic",
    "catolicilor": "catolic",
    "catolico": "catolic",
    "catolicul": "catolic",
    "catolicule": "catolic",
    "catolicului": "catolic",
    "catolica": "catolică",
    "catolice": "catolică",
    "catolicei": "catolică",
    "catolicele": "catolică",
    "catolicelor": "catolică",
    "catolico": "catolică",
    "catolicisme": "catolicism",
    "catolicismele": "catolicism",
    "catolicismelor": "catolicism",
    "catolicismul": "catolicism",
    "catolicismule": "catolicism",
    "catolicismului": "catolicism",
    "catrafusele": "catrafuse",
    "catrafuselor": "catrafuse",
    "cătrăneala": "cătrăneală",
    "cătrănealo": "cătrăneală",
    "cătrăneli": "cătrăneală",
    "cătrănelii": "cătrăneală",
    "cătrănelile": "cătrăneală",
    "cătrănelilor": "cătrăneală",
    "cătrănea": "cătrăni",
    "cătrăneai": "cătrăni",
    "cătrăneam": "cătrăni",
    "cătrănească": "cătrăni",
    "cătrăneați": "cătrăni",
    "cătrăneau": "cătrăni",
    "cătrănesc": "cătrăni",
    "cătrănește": "cătrăni",
    "cătrănești": "cătrăni",
    "cătrănii": "cătrăni",
    "cătrănim": "cătrăni",
    "cătrănind": "cătrăni",
    "cătrănindu": "cătrăni",
    "cătrăniră": "cătrăni",
    "cătrănirăm": "cătrăni",
    "cătrănirăți": "cătrăni",
    "cătrănise": "cătrăni",
    "cătrănisem": "cătrăni",
    "cătrăniseră": "cătrăni",
    "cătrăniserăm": "cătrăni",
    "cătrăniserăți": "cătrăni",
    "cătrăniseși": "cătrăni",
    "cătrăniși": "cătrăni",
    "cătrănit": "cătrăni",
    "cătrăniți": "cătrăni",
    "cătrănitu": "cătrăni",
    "necătrănind": "cătrăni",
    "necătrănindu": "cătrăni",
    "nemaicătrănind": "cătrăni",
    "nemaicătrănindu": "cătrăni",
    "cătrănirea": "cătrănire",
    "cătrănireo": "cătrănire",
    "cătrăniri": "cătrănire",
    "cătrănirii": "cătrănire",
    "cătrănirile": "cătrănire",
    "cătrănirilor": "cătrănire",
    "cătrănita": "cătrănit",
    "cătrănită": "cătrănit",
    "cătrănite": "cătrănit",
    "cătrănitei": "cătrănit",
    "cătrănitele": "cătrănit",
    "cătrănitelor": "cătrănit",
    "cătrăniți": "cătrănit",
    "cătrăniții": "cătrănit",
    "cătrăniților": "cătrănit",
    "cătrănito": "cătrănit",
    "cătrănitul": "cătrănit",
    "cătrănitule": "cătrănit",
    "cătrănitului": "cătrănit",
    "cătrănitura": "cătrănitură",
    "cătrănituri": "cătrănitură",
    "cătrăniturii": "cătrănitură",
    "cătrăniturile": "cătrănitură",
    "cătrăniturilor": "cătrănitură",
    "cătrănituro": "cătrănitură",
    "catrene": "catren",
    "catrenele": "catren",
    "catrenelor": "catren",
    "catrenul": "catren",
    "catrenule": "catren",
    "catrenului": "catren",
    "catrința": "catrință",
    "catrințe": "catrință",
    "catrinței": "catrință",
    "catrințele": "catrință",
    "catrințelor": "catrință",
    "catrințo": "catrință",
    "căt.": "cătun",
    "cătune": "cătun",
    "cătunele": "cătun",
    "cătunelor": "cătun",
    "cătunul": "cătun",
    "cătunule": "cătun",
    "cătunului": "cătun",
    "cătușa": "cătușă",
    "cătușe": "cătușă",
    "cătușei": "cătușă",
    "cătușele": "cătușă",
    "cătușelor": "cătușă",
    "cătușo": "cătușă",
    "câtăva": "câtva",
    "câteva": "câtva",
    "câțiva": "câtva",
    "câtorva": "câtva",
    "cauce": "cauc",
    "caucele": "cauc",
    "caucelor": "cauc",
    "caucul": "cauc",
    "caucule": "cauc",
    "caucului": "cauc",
    "caucaziana": "caucazian",
    "caucaziană": "caucazian",
    "caucaziano": "caucazian",
    "caucazianul": "caucazian",
    "caucazianule": "caucazian",
    "caucazianului": "caucazian",
    "caucaziene": "caucazian",
    "caucazienei": "caucazian",
    "caucazienele": "caucazian",
    "caucazienelor": "caucazian",
    "caucazieni": "caucazian",
    "caucazienii": "caucazian",
    "caucazienilor": "caucazian",
    "cauciucul": "cauciuc",
    "cauciucule": "cauciuc",
    "cauciucului": "cauciuc",
    "cauciucuri": "cauciuc",
    "cauciucurile": "cauciuc",
    "cauciucurilor": "cauciuc",
    "cauciucata": "cauciucat",
    "cauciucată": "cauciucat",
    "cauciucate": "cauciucat",
    "cauciucatei": "cauciucat",
    "cauciucatele": "cauciucat",
    "cauciucatelor": "cauciucat",
    "cauciucați": "cauciucat",
    "cauciucații": "cauciucat",
    "cauciucaților": "cauciucat",
    "cauciucato": "cauciucat",
    "cauciucatul": "cauciucat",
    "cauciucatule": "cauciucat",
    "cauciucatului": "cauciucat",
    "căușe": "căuș",
    "căușele": "căuș",
    "căușelor": "căuș",
    "căușul": "căuș",
    "căușule": "căuș",
    "căușului": "căuș",
    "caustica": "caustic",
    "caustică": "caustic",
    "caustice": "caustic",
    "causticei": "caustic",
    "causticele": "caustic",
    "causticelor": "caustic",
    "caustici": "caustic",
    "causticii": "caustic",
    "causticilor": "caustic",
    "caustico": "caustic",
    "causticul": "caustic",
    "causticule": "caustic",
    "causticului": "caustic",
    "cată": "căuta",
    "caut": "căuta",
    "caută": "căuta",
    "căută": "căuta",
    "căutai": "căuta",
    "căutam": "căuta",
    "căutăm": "căuta",
    "căutând": "căuta",
    "căutându": "căuta",
    "căutară": "căuta",
    "căutarăm": "căuta",
    "căutarăți": "căuta",
    "căutase": "căuta",
    "căutasem": "căuta",
    "căutaseră": "căuta",
    "căutaserăm": "căuta",
    "căutaserăți": "căuta",
    "căutaseși": "căuta",
    "căutași": "căuta",
    "căutat": "căuta",
    "căutați": "căuta",
    "căutatu": "căuta",
    "căutau": "căuta",
    "caute": "căuta",
    "cauți": "căuta",
    "necăutând": "căuta",
    "necăutându": "căuta",
    "nemaicăutând": "căuta",
    "nemaicăutându": "căuta",
    "căutarea": "căutare",
    "căutareo": "căutare",
    "căutări": "căutare",
    "căutării": "căutare",
    "căutările": "căutare",
    "căutărilor": "căutare",
    "căutata": "căutat",
    "căutată": "căutat",
    "căutate": "căutat",
    "căutatei": "căutat",
    "căutatele": "căutat",
    "căutatelor": "căutat",
    "căutați": "căutat",
    "căutații": "căutat",
    "căutaților": "căutat",
    "căutato": "căutat",
    "căutatul": "căutat",
    "căutatule": "căutat",
    "căutatului": "căutat",
    "căutătoarea": "căutătoare",
    "căutătoarei": "căutătoare",
    "căutătoarele": "căutătoare",
    "căutătoarelor": "căutătoare",
    "căutătoareo": "căutătoare",
    "căutători": "căutător",
    "căutătorii": "căutător",
    "căutătorilor": "căutător",
    "căutătorul": "căutător",
    "căutătorule": "căutător",
    "căutătorului": "căutător",
    "căutătura": "căutătură",
    "căutături": "căutătură",
    "căutăturii": "căutătură",
    "căutăturile": "căutătură",
    "căutăturilor": "căutătură",
    "căutăturo": "căutătură",
    "cautere": "cauter",
    "cauterele": "cauter",
    "cauterelor": "cauter",
    "cauterul": "cauter",
    "cauterule": "cauter",
    "cauterului": "cauter",
    "cauteriză": "cauteriza",
    "cauterizai": "cauteriza",
    "cauterizam": "cauteriza",
    "cauterizăm": "cauteriza",
    "cauterizând": "cauteriza",
    "cauterizându": "cauteriza",
    "cauterizară": "cauteriza",
    "cauterizarăm": "cauteriza",
    "cauterizarăți": "cauteriza",
    "cauterizase": "cauteriza",
    "cauterizasem": "cauteriza",
    "cauterizaseră": "cauteriza",
    "cauterizaserăm": "cauteriza",
    "cauterizaserăți": "cauteriza",
    "cauterizaseși": "cauteriza",
    "cauterizași": "cauteriza",
    "cauterizat": "cauteriza",
    "cauterizați": "cauteriza",
    "cauterizatu": "cauteriza",
    "cauterizau": "cauteriza",
    "cauterizează": "cauteriza",
    "cauterizez": "cauteriza",
    "cauterizeze": "cauteriza",
    "cauterizezi": "cauteriza",
    "necauterizând": "cauteriza",
    "necauterizându": "cauteriza",
    "nemaicauterizând": "cauteriza",
    "nemaicauterizându": "cauteriza",
    "cauterizarea": "cauterizare",
    "cauterizareo": "cauterizare",
    "cauterizări": "cauterizare",
    "cauterizării": "cauterizare",
    "cauterizările": "cauterizare",
    "cauterizărilor": "cauterizare",
    "cauterizată": "cauterizat",
    "cauterizate": "cauterizat",
    "cauterizați": "cauterizat",
    "cauționă": "cauționa",
    "cauționai": "cauționa",
    "cauționam": "cauționa",
    "cauționăm": "cauționa",
    "cauționând": "cauționa",
    "cauționându": "cauționa",
    "cauționară": "cauționa",
    "cauționarăm": "cauționa",
    "cauționarăți": "cauționa",
    "cauționase": "cauționa",
    "cauționasem": "cauționa",
    "cauționaseră": "cauționa",
    "cauționaserăm": "cauționa",
    "cauționaserăți": "cauționa",
    "cauționaseși": "cauționa",
    "cauționași": "cauționa",
    "cauționat": "cauționa",
    "cauționați": "cauționa",
    "cauționatu": "cauționa",
    "cauționau": "cauționa",
    "cauționează": "cauționa",
    "cauționez": "cauționa",
    "cauționeze": "cauționa",
    "cauționezi": "cauționa",
    "cauționată": "cauționat",
    "cauționate": "cauționat",
    "cauționați": "cauționat",
    "cauțiunea": "cauțiune",
    "cauțiuneo": "cauțiune",
    "cauțiuni": "cauțiune",
    "cauțiunii": "cauțiune",
    "cauțiunile": "cauțiune",
    "cauțiunilor": "cauțiune",
    "cauză": "cauza",
    "cauzai": "cauza",
    "cauzam": "cauza",
    "cauzăm": "cauza",
    "cauzând": "cauza",
    "cauzându": "cauza",
    "cauzară": "cauza",
    "cauzarăm": "cauza",
    "cauzarăți": "cauza",
    "cauzase": "cauza",
    "cauzasem": "cauza",
    "cauzaseră": "cauza",
    "cauzaserăm": "cauza",
    "cauzaserăți": "cauza",
    "cauzaseși": "cauza",
    "cauzași": "cauza",
    "cauzat": "cauza",
    "cauzați": "cauza",
    "cauzatu": "cauza",
    "cauzau": "cauza",
    "cauzează": "cauza",
    "cauzez": "cauza",
    "cauzeze": "cauza",
    "cauzezi": "cauza",
    "necauzând": "cauza",
    "necauzându": "cauza",
    "nemaicauzând": "cauza",
    "nemaicauzându": "cauza",
    "cauza": "cauză",
    "cauze": "cauză",
    "cauzei": "cauză",
    "cauzele": "cauză",
    "cauzelor": "cauză",
    "cauzo": "cauză",
    "cauzala": "cauzal",
    "cauzală": "cauzal",
    "cauzale": "cauzal",
    "cauzalei": "cauzal",
    "cauzalele": "cauzal",
    "cauzalelor": "cauzal",
    "cauzali": "cauzal",
    "cauzalii": "cauzal",
    "cauzalilor": "cauzal",
    "cauzalo": "cauzal",
    "cauzalul": "cauzal",
    "cauzalule": "cauzal",
    "cauzalului": "cauzal",
    "cauzalitatea": "cauzalitate",
    "cauzalitateo": "cauzalitate",
    "cauzalități": "cauzalitate",
    "cauzalității": "cauzalitate",
    "cauzalitățile": "cauzalitate",
    "cauzalităților": "cauzalitate",
    "cauzată": "cauzat",
    "cauzate": "cauzat",
    "cauzați": "cauzat",
    "cauzativa": "cauzativ",
    "cauzativă": "cauzativ",
    "cauzative": "cauzativ",
    "cauzativei": "cauzativ",
    "cauzativele": "cauzativ",
    "cauzativelor": "cauzativ",
    "cauzativi": "cauzativ",
    "cauzativii": "cauzativ",
    "cauzativilor": "cauzativ",
    "cauzativo": "cauzativ",
    "cauzativul": "cauzativ",
    "cauzativule": "cauzativ",
    "cauzativului": "cauzativ",
    "cavale": "caval",
    "cavalele": "caval",
    "cavalelor": "caval",
    "cavalul": "caval",
    "cavalule": "caval",
    "cavalului": "caval",
    "cavaluri": "caval",
    "cavalurile": "caval",
    "cavalurilor": "caval",
    "cavalcada": "cavalcadă",
    "cavalcade": "cavalcadă",
    "cavalcadei": "cavalcadă",
    "cavalcadele": "cavalcadă",
    "cavalcadelor": "cavalcadă",
    "cavalcado": "cavalcadă",
    "cavaleri": "cavaler",
    "cavalerii": "cavaler",
    "cavalerilor": "cavaler",
    "cavalerul": "cavaler",
    "cavalerule": "cavaler",
    "cavalerului": "cavaler",
    "cavalereasca": "cavaleresc",
    "cavalerească": "cavaleresc",
    "cavalereasco": "cavaleresc",
    "cavalerescul": "cavaleresc",
    "cavalerescule": "cavaleresc",
    "cavalerescului": "cavaleresc",
    "cavalerești": "cavaleresc",
    "cavalereștii": "cavaleresc",
    "cavalereștile": "cavaleresc",
    "cavalereștilor": "cavaleresc",
    "cavaleria": "cavalerie",
    "cavaleriei": "cavalerie",
    "cavalerii": "cavalerie",
    "cavaleriile": "cavalerie",
    "cavaleriilor": "cavalerie",
    "cavalerio": "cavalerie",
    "cavalerimea": "cavalerime",
    "cavalerimeo": "cavalerime",
    "cavalerimi": "cavalerime",
    "cavalerimii": "cavalerime",
    "cavalerimile": "cavalerime",
    "cavalerimilor": "cavalerime",
    "cavalerisme": "cavalerism",
    "cavalerismele": "cavalerism",
    "cavalerismelor": "cavalerism",
    "cavalerismul": "cavalerism",
    "cavalerismule": "cavalerism",
    "cavalerismului": "cavalerism",
    "cavaleriști": "cavalerist",
    "cavaleriștii": "cavalerist",
    "cavaleriștilor": "cavalerist",
    "cavaleristul": "cavalerist",
    "cavaleristule": "cavalerist",
    "cavaleristului": "cavalerist",
    "cavatina": "cavatină",
    "cavatine": "cavatină",
    "cavatinei": "cavatină",
    "cavatinele": "cavatină",
    "cavatinelor": "cavatină",
    "cavatino": "cavatină",
    "caverna": "cavernă",
    "caverne": "cavernă",
    "cavernei": "cavernă",
    "cavernele": "cavernă",
    "cavernelor": "cavernă",
    "caverno": "cavernă",
    "caviarul": "caviar",
    "caviarule": "caviar",
    "caviarului": "caviar",
    "cavitatea": "cavitate",
    "cavitateo": "cavitate",
    "cavități": "cavitate",
    "cavității": "cavitate",
    "cavitățile": "cavitate",
    "cavităților": "cavitate",
    "cavitația": "cavitație",
    "cavitației": "cavitație",
    "cavitații": "cavitație",
    "cavitațiile": "cavitație",
    "cavitațiilor": "cavitație",
    "cavitațio": "cavitație",
    "cavoul": "cavou",
    "cavoule": "cavou",
    "cavoului": "cavou",
    "cavouri": "cavou",
    "cavourile": "cavou",
    "cavourilor": "cavou",
    "cazul": "caz",
    "cazule": "caz",
    "cazului": "caz",
    "cazuri": "caz",
    "cazurile": "caz",
    "cazurilor": "caz",
    "cază": "caza",
    "cazai": "caza",
    "cazam": "caza",
    "cazăm": "caza",
    "cazând": "caza",
    "cazându": "caza",
    "cazară": "caza",
    "cazarăm": "caza",
    "cazarăți": "caza",
    "cazase": "caza",
    "cazasem": "caza",
    "cazaseră": "caza",
    "cazaserăm": "caza",
    "cazaserăți": "caza",
    "cazaseși": "caza",
    "cazași": "caza",
    "cazat": "caza",
    "cazați": "caza",
    "cazatu": "caza",
    "cazau": "caza",
    "cazează": "caza",
    "cazez": "caza",
    "cazeze": "caza",
    "cazezi": "caza",
    "necazând": "caza",
    "necazându": "caza",
    "nemaicazând": "caza",
    "nemaicazându": "caza",
    "cazaci": "cazac",
    "cazacii": "cazac",
    "cazacilor": "cazac",
    "cazacul": "cazac",
    "cazacule": "cazac",
    "cazacului": "cazac",
    "cazaca": "cazacă",
    "cazace": "cazacă",
    "cazacei": "cazacă",
    "cazacele": "cazacă",
    "cazacelor": "cazacă",
    "cazaco": "cazacă",
    "căzăceasca": "căzăcesc",
    "căzăcească": "căzăcesc",
    "căzăceasco": "căzăcesc",
    "căzăcescul": "căzăcesc",
    "căzăcescule": "căzăcesc",
    "căzăcescului": "căzăcesc",
    "căzăcești": "căzăcesc",
    "căzăceștii": "căzăcesc",
    "căzăceștile": "căzăcesc",
    "căzăceștilor": "căzăcesc",
    "căzăcimea": "căzăcime",
    "căzăcimeo": "căzăcime",
    "căzăcimi": "căzăcime",
    "căzăcimii": "căzăcime",
    "căzăcimile": "căzăcime",
    "căzăcimilor": "căzăcime",
    "cazaciocul": "cazacioc",
    "cazaciocule": "cazacioc",
    "cazaciocului": "cazacioc",
    "cazaciocuri": "cazacioc",
    "cazaciocurile": "cazacioc",
    "cazaciocurilor": "cazacioc",
    "cazane": "cazan",
    "cazanele": "cazan",
    "cazanelor": "cazan",
    "cazanul": "cazan",
    "cazanule": "cazan",
    "cazanului": "cazan",
    "căzănele": "căzănel",
    "căzănelele": "căzănel",
    "căzănelelor": "căzănel",
    "căzănelul": "căzănel",
    "căzănelule": "căzănel",
    "căzănelului": "căzănel",
    "cazangeria": "cazangerie",
    "cazangeriei": "cazangerie",
    "cazangerii": "cazangerie",
    "cazangeriile": "cazangerie",
    "cazangeriilor": "cazangerie",
    "cazangerio": "cazangerie",
    "cazangii": "cazangiu",
    "cazangiii": "cazangiu",
    "cazangiilor": "cazangiu",
    "cazangiul": "cazangiu",
    "cazangiule": "cazangiu",
    "cazangiului": "cazangiu",
    "cazania": "cazanie",
    "cazaniei": "cazanie",
    "cazanii": "cazanie",
    "cazaniile": "cazanie",
    "cazaniilor": "cazanie",
    "cazanio": "cazanie",
    "cazarea": "cazare",
    "cazareo": "cazare",
    "cazări": "cazare",
    "cazării": "cazare",
    "cazările": "cazare",
    "cazărilor": "cazare",
    "cazarma": "cazarmă",
    "cazarme": "cazarmă",
    "cazarmei": "cazarmă",
    "cazarmele": "cazarmă",
    "cazarmelor": "cazarmă",
    "cazărmii": "cazarmă",
    "cazarmo": "cazarmă",
    "cazarmamentul": "cazarmament",
    "cazarmamentule": "cazarmament",
    "cazarmamentului": "cazarmament",
    "cazată": "cazat",
    "cazate": "cazat",
    "cazați": "cazat",
    "căzătoare": "căzător",
    "căzătoarea": "căzător",
    "căzătoarei": "căzător",
    "căzătoarele": "căzător",
    "căzătoarelor": "căzător",
    "căzătoareo": "căzător",
    "căzători": "căzător",
    "căzătorii": "căzător",
    "căzătorilor": "căzător",
    "căzătorul": "căzător",
    "căzătorule": "căzător",
    "căzătorului": "căzător",
    "căzătura": "căzătură",
    "căzături": "căzătură",
    "căzăturii": "căzătură",
    "căzăturile": "căzătură",
    "căzăturilor": "căzătură",
    "căzăturo": "căzătură",
    "cazemata": "cazemată",
    "cazemate": "cazemată",
    "cazematei": "cazemată",
    "cazematele": "cazemată",
    "cazematelor": "cazemată",
    "cazemato": "cazemată",
    "caziere": "cazier",
    "cazierele": "cazier",
    "cazierelor": "cazier",
    "cazierul": "cazier",
    "cazierule": "cazier",
    "cazierului": "cazier",
    "cazinoul": "cazinou",
    "cazinoule": "cazinou",
    "cazinoului": "cazinou",
    "cazinouri": "cazinou",
    "cazinourile": "cazinou",
    "cazinourilor": "cazinou",
    "cazmale": "cazma",
    "cazmalei": "cazma",
    "cazmalele": "cazma",
    "cazmalelor": "cazma",
    "cazmao": "cazma",
    "cazmaua": "cazma",
    "căzmăluța": "căzmăluță",
    "căzmăluțe": "căzmăluță",
    "căzmăluței": "căzmăluță",
    "căzmăluțele": "căzmăluță",
    "căzmăluțelor": "căzmăluță",
    "căzmăluțo": "căzmăluță",
    "cazna": "caznă",
    "cazne": "caznă",
    "caznei": "caznă",
    "caznele": "caznă",
    "caznelor": "caznă",
    "cazno": "caznă",
    "căznea": "căzni",
    "căzneai": "căzni",
    "căzneam": "căzni",
    "căznească": "căzni",
    "căzneați": "căzni",
    "căzneau": "căzni",
    "căznesc": "căzni",
    "căznește": "căzni",
    "căznești": "căzni",
    "căznii": "căzni",
    "căznim": "căzni",
    "căznind": "căzni",
    "căznindu": "căzni",
    "căzniră": "căzni",
    "căznirăm": "căzni",
    "căznirăți": "căzni",
    "căznise": "căzni",
    "căznisem": "căzni",
    "căzniseră": "căzni",
    "căzniserăm": "căzni",
    "căzniserăți": "căzni",
    "căzniseși": "căzni",
    "căzniși": "căzni",
    "căznit": "căzni",
    "căzniți": "căzni",
    "căznitu": "căzni",
    "necăznind": "căzni",
    "necăznindu": "căzni",
    "nemaicăznind": "căzni",
    "nemaicăznindu": "căzni",
    "căznita": "căznit",
    "căznită": "căznit",
    "căznite": "căznit",
    "căznitei": "căznit",
    "căznitele": "căznit",
    "căznitelor": "căznit",
    "căzniți": "căznit",
    "căzniții": "căznit",
    "căzniților": "căznit",
    "căznito": "căznit",
    "căznitul": "căznit",
    "căznitule": "căznit",
    "căznitului": "căznit",
    "cazona": "cazon",
    "cazonă": "cazon",
    "cazone": "cazon",
    "cazonei": "cazon",
    "cazonele": "cazon",
    "cazonelor": "cazon",
    "cazoni": "cazon",
    "cazonii": "cazon",
    "cazonilor": "cazon",
    "cazono": "cazon",
    "cazonul": "cazon",
    "cazonule": "cazon",
    "cazonului": "cazon",
    "cazuala": "cazual",
    "cazuală": "cazual",
    "cazuale": "cazual",
    "cazualei": "cazual",
    "cazualele": "cazual",
    "cazualelor": "cazual",
    "cazuali": "cazual",
    "cazualii": "cazual",
    "cazualilor": "cazual",
    "cazualo": "cazual",
    "cazualul": "cazual",
    "cazualule": "cazual",
    "cazualului": "cazual",
    "cazualismul": "cazualism",
    "cazualismule": "cazualism",
    "cazualismului": "cazualism",
    "cazualitatea": "cazualitate",
    "cazualitateo": "cazualitate",
    "cazualități": "cazualitate",
    "cazualității": "cazualitate",
    "cazualitățile": "cazualitate",
    "cazualităților": "cazualitate",
    "cazuari": "cazuar",
    "cazuarii": "cazuar",
    "cazuarilor": "cazuar",
    "cazuarul": "cazuar",
    "cazuarule": "cazuar",
    "cazuarului": "cazuar",
    "cazuiști": "cazuist",
    "cazuiștii": "cazuist",
    "cazuiștilor": "cazuist",
    "cazuistul": "cazuist",
    "cazuistule": "cazuist",
    "cazuistului": "cazuist",
    "cazuista": "cazuistă",
    "cazuiste": "cazuistă",
    "cazuistei": "cazuistă",
    "cazuistele": "cazuistă",
    "cazuistelor": "cazuistă",
    "cazuisto": "cazuistă",
    "cazuistica": "cazuistică",
    "cazuistici": "cazuistică",
    "cazuisticii": "cazuistică",
    "cazuisticile": "cazuistică",
    "cazuisticilor": "cazuistică",
    "cazuistico": "cazuistică",
    "căzuta": "căzut",
    "căzută": "căzut",
    "căzute": "căzut",
    "căzutei": "căzut",
    "căzutele": "căzut",
    "căzutelor": "căzut",
    "căzuți": "căzut",
    "căzuții": "căzut",
    "căzuților": "căzut",
    "căzutul": "căzut",
    "căzutule": "căzut",
    "căzutului": "căzut",
    "ceafa": "ceafă",
    "ceafo": "ceafă",
    "cefe": "ceafă",
    "cefei": "ceafă",
    "cefele": "ceafă",
    "cefelor": "ceafă",
    "Ceahlăul": "Ceahlău",
    "Ceahlăului": "Ceahlău",
    "ceaiul": "ceai",
    "ceaiule": "ceai",
    "ceaiului": "ceai",
    "ceaiuri": "ceai",
    "ceaiurile": "ceai",
    "ceaiurilor": "ceai",
    "ceainăria": "ceainărie",
    "ceainăriei": "ceainărie",
    "ceainării": "ceainărie",
    "ceainăriile": "ceainărie",
    "ceainăriilor": "ceainărie",
    "ceainărio": "ceainărie",
    "ceainice": "ceainic",
    "ceainicele": "ceainic",
    "ceainicelor": "ceainic",
    "ceainicul": "ceainic",
    "ceainicule": "ceainic",
    "ceainicului": "ceainic",
    "ceangăi": "ceangău",
    "ceangăii": "ceangău",
    "ceangăilor": "ceangău",
    "ceangăul": "ceangău",
    "ceangăule": "ceangău",
    "ceangăului": "ceangău",
    "ceapa": "ceapă",
    "ceapo": "ceapă",
    "cepe": "ceapă",
    "cepei": "ceapă",
    "cepele": "ceapă",
    "cepelor": "ceapă",
    "ceaprazul": "ceapraz",
    "ceaprazule": "ceapraz",
    "ceaprazului": "ceapraz",
    "ceaprazuri": "ceapraz",
    "ceaprazurile": "ceapraz",
    "ceaprazurilor": "ceapraz",
    "ceaprazari": "ceaprazar",
    "ceaprazarii": "ceaprazar",
    "ceaprazarilor": "ceaprazar",
    "ceaprazarul": "ceaprazar",
    "ceaprazarule": "ceaprazar",
    "ceaprazarului": "ceaprazar",
    "ceaprăzăria": "ceaprăzărie",
    "ceaprăzăriei": "ceaprăzărie",
    "ceaprăzării": "ceaprăzărie",
    "ceaprăzăriile": "ceaprăzărie",
    "ceaprăzăriilor": "ceaprăzărie",
    "ceaprăzărio": "ceaprăzărie",
    "ceara": "ceară",
    "cearo": "ceară",
    "ceri": "ceară",
    "cerii": "ceară",
    "cearcăne": "cearcăn",
    "cearcănele": "cearcăn",
    "cearcănelor": "cearcăn",
    "cearcănul": "cearcăn",
    "cearcănule": "cearcăn",
    "cearcănului": "cearcăn",
    "cearceaful": "cearceaf",
    "cearceafule": "cearceaf",
    "cearceafului": "cearceaf",
    "cearceafuri": "cearceaf",
    "cearceafurile": "cearceaf",
    "cearceafurilor": "cearceaf",
    "ceardace": "ceardac",
    "ceardacele": "ceardac",
    "ceardacelor": "ceardac",
    "ceardacul": "ceardac",
    "ceardacule": "ceardac",
    "ceardacului": "ceardac",
    "ceardacuri": "ceardac",
    "ceardacurile": "ceardac",
    "ceardacurilor": "ceardac",
    "ceardașul": "ceardaș",
    "ceardașule": "ceardaș",
    "ceardașului": "ceardaș",
    "ceardașuri": "ceardaș",
    "ceardașurile": "ceardaș",
    "ceardașurilor": "ceardaș",
    "cearșaful": "cearșaf",
    "cearșafule": "cearșaf",
    "cearșafului": "cearșaf",
    "cearșafuri": "cearșaf",
    "cearșafurile": "cearșaf",
    "cearșafurilor": "cearșaf",
    "cearta": "ceartă",
    "cearto": "ceartă",
    "certe": "ceartă",
    "certei": "ceartă",
    "certuri": "ceartă",
    "certurile": "ceartă",
    "certurilor": "ceartă",
    "ceasu'": "ceas",
    "ceasul": "ceas",
    "ceasule": "ceas",
    "ceasului": "ceas",
    "ceasuri": "ceas",
    "ceasurile": "ceas",
    "ceasurilor": "ceas",
    "ceașca": "ceașcă",
    "ceașco": "ceașcă",
    "cești": "ceașcă",
    "ceștii": "ceașcă",
    "ceștile": "ceașcă",
    "ceștilor": "ceașcă",
    "ceasloave": "ceaslov",
    "ceasloavele": "ceaslov",
    "ceasloavelor": "ceaslov",
    "ceaslovul": "ceaslov",
    "ceaslovule": "ceaslov",
    "ceaslovului": "ceaslov",
    "ceasornice": "ceasornic",
    "ceasornicele": "ceasornic",
    "ceasornicelor": "ceasornic",
    "ceasornicul": "ceasornic",
    "ceasornicule": "ceasornic",
    "ceasornicului": "ceasornic",
    "ceasornicari": "ceasornicar",
    "ceasornicarii": "ceasornicar",
    "ceasornicarilor": "ceasornicar",
    "ceasornicarul": "ceasornicar",
    "ceasornicarule": "ceasornicar",
    "ceasornicarului": "ceasornicar",
    "ceasornicăria": "ceasornicărie",
    "ceasornicăriei": "ceasornicărie",
    "ceasornicării": "ceasornicărie",
    "ceasornicăriile": "ceasornicărie",
    "ceasornicăriilor": "ceasornicărie",
    "ceasornicărio": "ceasornicărie",
    "ceata": "ceată",
    "ceato": "ceată",
    "cete": "ceată",
    "cetei": "ceată",
    "cetele": "ceată",
    "cetelor": "ceată",
    "ceața": "ceață",
    "ceațo": "ceață",
    "ceți": "ceață",
    "ceții": "ceață",
    "cețuri": "ceață",
    "cețurile": "ceață",
    "cețurilor": "ceață",
    "ceaune": "ceaun",
    "ceaunele": "ceaun",
    "ceaunelor": "ceaun",
    "ceaunul": "ceaun",
    "ceaunule": "ceaun",
    "ceaunului": "ceaun",
    "ceaunașe": "ceaunaș",
    "ceaunașele": "ceaunaș",
    "ceaunașelor": "ceaunaș",
    "ceaunașul": "ceaunaș",
    "ceaunașule": "ceaunaș",
    "ceaunașului": "ceaunaș",
    "ceauși": "ceauș",
    "ceaușii": "ceauș",
    "ceaușilor": "ceauș",
    "ceaușul": "ceauș",
    "ceaușule": "ceauș",
    "ceaușului": "ceauș",
    "ceaușei": "ceaușel",
    "ceaușeii": "ceaușel",
    "ceaușeilor": "ceaușel",
    "ceaușelul": "ceaușel",
    "ceaușelule": "ceaușel",
    "ceaușelului": "ceaușel",
    "ceaușista": "ceaușist",
    "ceaușistă": "ceaușist",
    "ceaușiste": "ceaușist",
    "ceaușistei": "ceaușist",
    "ceaușistele": "ceaușist",
    "ceaușistelor": "ceaușist",
    "ceaușiști": "ceaușist",
    "ceaușiștii": "ceaușist",
    "ceaușiștilor": "ceaușist",
    "ceaușisto": "ceaușist",
    "ceaușistul": "ceaușist",
    "ceaușistule": "ceaușist",
    "ceaușistului": "ceaușist",
    "ceaușista": "ceaușistă",
    "ceaușiste": "ceaușistă",
    "ceaușistei": "ceaușistă",
    "ceaușistele": "ceaușistă",
    "ceaușistelor": "ceaușistă",
    "ceaușisto": "ceaușistă",
    "cecul": "cec",
    "cecule": "cec",
    "cecului": "cec",
    "cecuri": "cec",
    "cecurile": "cec",
    "cecurilor": "cec",
    "Cecenie": "Cecenia",
    "Ceceniei": "Cecenia",
    "Cecenii": "Cecenia",
    "Cecilie": "Cecilia",
    "Ceciliei": "Cecilia",
    "Cecilii": "Cecilia",
    "cecitatea": "cecitate",
    "cecitateo": "cecitate",
    "cecități": "cecitate",
    "cecității": "cecitate",
    "cecitățile": "cecitate",
    "cecităților": "cecitate",
    "cedă": "ceda",
    "cedai": "ceda",
    "cedam": "ceda",
    "cedăm": "ceda",
    "cedând": "ceda",
    "cedându": "ceda",
    "cedară": "ceda",
    "cedarăm": "ceda",
    "cedarăți": "ceda",
    "cedase": "ceda",
    "cedasem": "ceda",
    "cedaseră": "ceda",
    "cedaserăm": "ceda",
    "cedaserăți": "ceda",
    "cedaseși": "ceda",
    "cedași": "ceda",
    "cedat": "ceda",
    "cedați": "ceda",
    "cedatu": "ceda",
    "cedau": "ceda",
    "cedează": "ceda",
    "cedez": "ceda",
    "cedeze": "ceda",
    "cedezi": "ceda",
    "necedând": "ceda",
    "necedându": "ceda",
    "nemaicedând": "ceda",
    "nemaicedându": "ceda",
    "cedarea": "cedare",
    "cedareo": "cedare",
    "cedări": "cedare",
    "cedării": "cedare",
    "cedările": "cedare",
    "cedărilor": "cedare",
    "cedată": "cedat",
    "cedate": "cedat",
    "cedați": "cedat",
    "cederistă": "cederist",
    "cedri": "cedru",
    "cedrii": "cedru",
    "cedrilor": "cedru",
    "cedrul": "cedru",
    "cedrule": "cedru",
    "cedrului": "cedru",
    "cefalica": "cefalic",
    "cefalică": "cefalic",
    "cefalice": "cefalic",
    "cefalicei": "cefalic",
    "cefalicele": "cefalic",
    "cefalicelor": "cefalic",
    "cefalici": "cefalic",
    "cefalicii": "cefalic",
    "cefalicilor": "cefalic",
    "cefalico": "cefalic",
    "cefalicul": "cefalic",
    "cefalicule": "cefalic",
    "cefalicului": "cefalic",
    "cefalopode": "cefalopod",
    "cefalopodele": "cefalopod",
    "cefalopodelor": "cefalopod",
    "cefalopodul": "cefalopod",
    "cefalopodule": "cefalopod",
    "cefalopodului": "cefalopod",
    "cefalorahidiana": "cefalorahidian",
    "cefalorahidiană": "cefalorahidian",
    "cefalorahidiano": "cefalorahidian",
    "cefalorahidianul": "cefalorahidian",
    "cefalorahidianule": "cefalorahidian",
    "cefalorahidianului": "cefalorahidian",
    "cefalorahidiene": "cefalorahidian",
    "cefalorahidienei": "cefalorahidian",
    "cefalorahidienele": "cefalorahidian",
    "cefalorahidienelor": "cefalorahidian",
    "cefalorahidieni": "cefalorahidian",
    "cefalorahidienii": "cefalorahidian",
    "cefalorahidienilor": "cefalorahidian",
    "ceferista": "ceferist",
    "ceferistă": "ceferist",
    "ceferiste": "ceferist",
    "ceferistei": "ceferist",
    "ceferistele": "ceferist",
    "ceferistelor": "ceferist",
    "ceferiști": "ceferist",
    "ceferiștii": "ceferist",
    "ceferiștilor": "ceferist",
    "ceferisto": "ceferist",
    "ceferistul": "ceferist",
    "ceferistule": "ceferist",
    "ceferistului": "ceferist",
    "ceferista": "ceferistă",
    "ceferiste": "ceferistă",
    "ceferistei": "ceferistă",
    "ceferistele": "ceferistă",
    "ceferistelor": "ceferistă",
    "ceferisto": "ceferistă",
    "cega": "cegă",
    "cegi": "cegă",
    "cegii": "cegă",
    "cegile": "cegă",
    "cegilor": "cegă",
    "cego": "cegă",
    "ceha": "ceh",
    "cehă": "ceh",
    "cehe": "ceh",
    "cehei": "ceh",
    "cehele": "ceh",
    "cehelor": "ceh",
    "cehi": "ceh",
    "cehii": "ceh",
    "cehilor": "ceh",
    "ceho": "ceh",
    "cehul": "ceh",
    "cehule": "ceh",
    "cehului": "ceh",
    "ceh.": "cehă",
    "cehoaica": "cehoaică",
    "cehoaice": "cehoaică",
    "cehoaicei": "cehoaică",
    "cehoaicele": "cehoaică",
    "cehoaicelor": "cehoaică",
    "cehoaico": "cehoaică",
    "cehoslovace": "cehoslovac",
    "Cehoslovacie": "Cehoslovacia",
    "Cehoslovaciei": "Cehoslovacia",
    "Cehoslovacii": "Cehoslovacia",
    "cea": "cel",
    "cei": "cel",
    "cele": "cel",
    "celei": "cel",
    "celor": "cel",
    "celui": "cel",
    "ăl_puțân": "cel_puțin",
    "ceea": "cela",
    "ceia": "cela",
    "cele": "cela",
    "celea": "cela",
    "celeia": "cela",
    "celora": "cela",
    "celuia": "cela",
    "cealaltă": "celălalt",
    "ceilalți": "celălalt",
    "celeilalte": "celălalt",
    "celelalte": "celălalt",
    "celorlalte": "celălalt",
    "celorlalți": "celălalt",
    "celuilalt": "celălalt",
    "celare": "celar",
    "celarele": "celar",
    "celarelor": "celar",
    "celarul": "celar",
    "celarule": "celar",
    "celarului": "celar",
    "celărele": "celărel",
    "celărelele": "celărel",
    "celărelelor": "celărel",
    "celărelul": "celărel",
    "celărelule": "celărel",
    "celărelului": "celărel",
    "celebră": "celebra",
    "celebrai": "celebra",
    "celebram": "celebra",
    "celebrăm": "celebra",
    "celebrând": "celebra",
    "celebrându": "celebra",
    "celebrară": "celebra",
    "celebrarăm": "celebra",
    "celebrarăți": "celebra",
    "celebrase": "celebra",
    "celebrasem": "celebra",
    "celebraseră": "celebra",
    "celebraserăm": "celebra",
    "celebraserăți": "celebra",
    "celebraseși": "celebra",
    "celebrași": "celebra",
    "celebrat": "celebra",
    "celebrați": "celebra",
    "celebratu": "celebra",
    "celebrau": "celebra",
    "celebrează": "celebra",
    "celebrez": "celebra",
    "celebreze": "celebra",
    "celebrezi": "celebra",
    "necelebrând": "celebra",
    "necelebrându": "celebra",
    "nemaicelebrând": "celebra",
    "nemaicelebrându": "celebra",
    "celebrată": "celebrat",
    "celebrate": "celebrat",
    "celebrați": "celebrat",
    "celebritatea": "celebritate",
    "celebritateo": "celebritate",
    "celebrități": "celebritate",
    "celebrității": "celebritate",
    "celebritățile": "celebritate",
    "celebrităților": "celebritate",
    "celebra": "celebru",
    "celebră": "celebru",
    "celebre": "celebru",
    "celebrei": "celebru",
    "celebrele": "celebru",
    "celebrelor": "celebru",
    "celebri": "celebru",
    "celebrii": "celebru",
    "celebrilor": "celebru",
    "celebro": "celebru",
    "celebrul": "celebru",
    "celebrule": "celebru",
    "celebrului": "celebru",
    "celor-ce-sunt": "cele-ce-sunt",
    "celenterate": "celenterat",
    "celenteratele": "celenterat",
    "celenteratelor": "celenterat",
    "celenteratul": "celenterat",
    "celenteratule": "celenterat",
    "celenteratului": "celenterat",
    "celeritatea": "celeritate",
    "celeritateo": "celeritate",
    "celerități": "celeritate",
    "celerității": "celeritate",
    "celeritățile": "celeritate",
    "celerităților": "celeritate",
    "celesta": "celest",
    "celestă": "celest",
    "celeste": "celest",
    "celestei": "celest",
    "celestele": "celest",
    "celestelor": "celest",
    "celești": "celest",
    "celeștii": "celest",
    "celeștilor": "celest",
    "celesto": "celest",
    "celestul": "celest",
    "celestule": "celest",
    "celestului": "celest",
    "celibatul": "celibat",
    "celibatule": "celibat",
    "celibatului": "celibat",
    "celibatari": "celibatar",
    "celibatarii": "celibatar",
    "celibatarilor": "celibatar",
    "celibatarul": "celibatar",
    "celibatarule": "celibatar",
    "celibatarului": "celibatar",
    "celofanul": "celofan",
    "celofanule": "celofan",
    "celofanului": "celofan",
    "celofibra": "celofibră",
    "celofibre": "celofibră",
    "celofibrei": "celofibră",
    "celofibro": "celofibră",
    "celolina": "celolină",
    "celolini": "celolină",
    "celolinii": "celolină",
    "celolino": "celolină",
    "celți": "celt",
    "celții": "celt",
    "celților": "celt",
    "celtul": "celt",
    "celtule": "celt",
    "celtului": "celt",
    "celta": "celtă",
    "celte": "celtă",
    "celtei": "celtă",
    "celtele": "celtă",
    "celtelor": "celtă",
    "celto": "celtă",
    "celtica": "celtic",
    "celtică": "celtic",
    "celtice": "celtic",
    "celticei": "celtic",
    "celticele": "celtic",
    "celticelor": "celtic",
    "celtici": "celtic",
    "celticii": "celtic",
    "celticilor": "celtic",
    "celtico": "celtic",
    "celticul": "celtic",
    "celticule": "celtic",
    "celticului": "celtic",
    "celula": "celulă",
    "celule": "celulă",
    "celulei": "celulă",
    "celulele": "celulă",
    "celulelor": "celulă",
    "celulo": "celulă",
    "celulara": "celular",
    "celulară": "celular",
    "celulare": "celular",
    "celularei": "celular",
    "celularele": "celular",
    "celularelor": "celular",
    "celulari": "celular",
    "celularii": "celular",
    "celularilor": "celular",
    "celularo": "celular",
    "celularul": "celular",
    "celularule": "celular",
    "celularului": "celular",
    "celuloidul": "celuloid",
    "celuloidule": "celuloid",
    "celuloidului": "celuloid",
    "celuloza": "celuloză",
    "celuloze": "celuloză",
    "celulozei": "celuloză",
    "celulozele": "celuloză",
    "celulozelor": "celuloză",
    "celulozo": "celuloză",
    "celulozica": "celulozic",
    "celulozică": "celulozic",
    "celulozice": "celulozic",
    "celulozicei": "celulozic",
    "celulozicele": "celulozic",
    "celulozicelor": "celulozic",
    "celulozici": "celulozic",
    "celulozicii": "celulozic",
    "celulozicilor": "celulozic",
    "celulozico": "celulozic",
    "celulozicul": "celulozic",
    "celulozicule": "celulozic",
    "celulozicului": "celulozic",
    "cementul": "cement",
    "cementule": "cement",
    "cementului": "cement",
    "cementuri": "cement",
    "cementurile": "cement",
    "cementurilor": "cement",
    "cementă": "cementa",
    "cementai": "cementa",
    "cementam": "cementa",
    "cementăm": "cementa",
    "cementând": "cementa",
    "cementându": "cementa",
    "cementară": "cementa",
    "cementarăm": "cementa",
    "cementarăți": "cementa",
    "cementase": "cementa",
    "cementasem": "cementa",
    "cementaseră": "cementa",
    "cementaserăm": "cementa",
    "cementaserăți": "cementa",
    "cementaseși": "cementa",
    "cementași": "cementa",
    "cementat": "cementa",
    "cementați": "cementa",
    "cementatu": "cementa",
    "cementau": "cementa",
    "cementează": "cementa",
    "cementez": "cementa",
    "cementeze": "cementa",
    "cementezi": "cementa",
    "necementând": "cementa",
    "necementându": "cementa",
    "nemaicementând": "cementa",
    "nemaicementându": "cementa",
    "cementată": "cementat",
    "cementate": "cementat",
    "cementați": "cementat",
    "cenaclul": "cenaclu",
    "cenaclule": "cenaclu",
    "cenaclului": "cenaclu",
    "cenacluri": "cenaclu",
    "cenaclurile": "cenaclu",
    "cenaclurilor": "cenaclu",
    "cenobiți": "cenobit",
    "cenobiții": "cenobit",
    "cenobiților": "cenobit",
    "cenobitul": "cenobit",
    "cenobitule": "cenobit",
    "cenobitului": "cenobit",
    "censul": "cens",
    "censule": "cens",
    "censului": "cens",
    "censuri": "cens",
    "censurile": "cens",
    "censurilor": "cens",
    "cenți": "cent",
    "cenții": "cent",
    "cenților": "cent",
    "centul": "cent",
    "centule": "cent",
    "centului": "cent",
    "centauri": "centaur",
    "centaurii": "centaur",
    "centaurilor": "centaur",
    "centaurul": "centaur",
    "centaurule": "centaur",
    "centaurului": "centaur",
    "centenare": "centenar",
    "centenarele": "centenar",
    "centenarelor": "centenar",
    "centenarul": "centenar",
    "centenarule": "centenar",
    "centenarului": "centenar",
    "centezimala": "centezimal",
    "centezimală": "centezimal",
    "centezimale": "centezimal",
    "centezimalei": "centezimal",
    "centezimalele": "centezimal",
    "centezimalelor": "centezimal",
    "centezimali": "centezimal",
    "centezimalii": "centezimal",
    "centezimalilor": "centezimal",
    "centezimalo": "centezimal",
    "centezimalul": "centezimal",
    "centezimalule": "centezimal",
    "centezimalului": "centezimal",
    "centiari": "centiar",
    "centiarii": "centiar",
    "centiarilor": "centiar",
    "centiarul": "centiar",
    "centiarule": "centiar",
    "centiarului": "centiar",
    "centigrade": "centigrad",
    "centigradele": "centigrad",
    "centigradelor": "centigrad",
    "centigradul": "centigrad",
    "centigradule": "centigrad",
    "centigradului": "centigrad",
    "centigrame": "centigram",
    "centigramele": "centigram",
    "centigramelor": "centigram",
    "centigramul": "centigram",
    "centigramule": "centigram",
    "centigramului": "centigram",
    "cg.": "centigram",
    "cl": "centilitri",
    "centilitri": "centilitru",
    "centilitrii": "centilitru",
    "centilitrilor": "centilitru",
    "centilitrul": "centilitru",
    "centilitrule": "centilitru",
    "centilitrului": "centilitru",
    "centima": "centimă",
    "centime": "centimă",
    "centimei": "centimă",
    "centimele": "centimă",
    "centimelor": "centimă",
    "centimo": "centimă",
    "centimetri": "centimetru",
    "centimetrii": "centimetru",
    "centimetrilor": "centimetru",
    "centimetrul": "centimetru",
    "centimetrule": "centimetru",
    "centimetrului": "centimetru",
    "cm": "centimetru",
    "centiroane": "centiron",
    "centiroanele": "centiron",
    "centiroanelor": "centiron",
    "centironul": "centiron",
    "centironule": "centiron",
    "centironului": "centiron",
    "centră": "centra",
    "centrai": "centra",
    "centram": "centra",
    "centrăm": "centra",
    "centrând": "centra",
    "centrându": "centra",
    "centrară": "centra",
    "centrarăm": "centra",
    "centrarăți": "centra",
    "centrase": "centra",
    "centrasem": "centra",
    "centraseră": "centra",
    "centraserăm": "centra",
    "centraserăți": "centra",
    "centraseși": "centra",
    "centrași": "centra",
    "centrat": "centra",
    "centrați": "centra",
    "centratu": "centra",
    "centrau": "centra",
    "centrează": "centra",
    "centrez": "centra",
    "centreze": "centra",
    "centrezi": "centra",
    "necentrând": "centra",
    "necentrându": "centra",
    "nemaicentrând": "centra",
    "nemaicentrându": "centra",
    "centrala": "central",
    "centrală": "central",
    "centrale": "central",
    "centralei": "central",
    "centralele": "central",
    "centralelor": "central",
    "centrali": "central",
    "centralii": "central",
    "centralilor": "central",
    "centralul": "central",
    "centralule": "central",
    "centralului": "central",
    "centrala": "centrală",
    "centrale": "centrală",
    "centralei": "centrală",
    "centralele": "centrală",
    "centralelor": "centrală",
    "CET": "Centrala_Electrotermică",
    "centralismul": "centralism",
    "centralismule": "centralism",
    "centralismului": "centralism",
    "centralista": "centralist",
    "centralistă": "centralist",
    "centraliste": "centralist",
    "centralistei": "centralist",
    "centralistele": "centralist",
    "centralistelor": "centralist",
    "centraliști": "centralist",
    "centraliștii": "centralist",
    "centraliștilor": "centralist",
    "centralisto": "centralist",
    "centralistul": "centralist",
    "centralistule": "centralist",
    "centralistului": "centralist",
    "centraliză": "centraliza",
    "centralizai": "centraliza",
    "centralizam": "centraliza",
    "centralizăm": "centraliza",
    "centralizând": "centraliza",
    "centralizându": "centraliza",
    "centralizară": "centraliza",
    "centralizarăm": "centraliza",
    "centralizarăți": "centraliza",
    "centralizase": "centraliza",
    "centralizasem": "centraliza",
    "centralizaseră": "centraliza",
    "centralizaserăm": "centraliza",
    "centralizaserăți": "centraliza",
    "centralizaseși": "centraliza",
    "centralizași": "centraliza",
    "centralizat": "centraliza",
    "centralizați": "centraliza",
    "centralizatu": "centraliza",
    "centralizau": "centraliza",
    "centralizează": "centraliza",
    "centralizez": "centraliza",
    "centralizeze": "centraliza",
    "centralizezi": "centraliza",
    "necentralizând": "centraliza",
    "necentralizându": "centraliza",
    "nemaicentralizând": "centraliza",
    "nemaicentralizându": "centraliza",
    "centralizarea": "centralizare",
    "centralizareo": "centralizare",
    "centralizări": "centralizare",
    "centralizării": "centralizare",
    "centralizările": "centralizare",
    "centralizărilor": "centralizare",
    "centralizată": "centralizat",
    "centralizate": "centralizat",
    "centralizați": "centralizat",
    "centralizatoare": "centralizator",
    "centralizatoarea": "centralizator",
    "centralizatoarei": "centralizator",
    "centralizatoarele": "centralizator",
    "centralizatoarelor": "centralizator",
    "centralizatori": "centralizator",
    "centralizatorii": "centralizator",
    "centralizatorilor": "centralizator",
    "centralizatorul": "centralizator",
    "centralizatorule": "centralizator",
    "centralizatorului": "centralizator",
    "centrarea": "centrare",
    "centrareo": "centrare",
    "centrări": "centrare",
    "centrării": "centrare",
    "centrările": "centrare",
    "centrărilor": "centrare",
    "centrata": "centrat",
    "centrată": "centrat",
    "centrate": "centrat",
    "centratei": "centrat",
    "centratele": "centrat",
    "centratelor": "centrat",
    "centrați": "centrat",
    "centrații": "centrat",
    "centraților": "centrat",
    "centrato": "centrat",
    "centratul": "centrat",
    "centratule": "centrat",
    "centratului": "centrat",
    "centrifuga": "centrifug",
    "centrifugă": "centrifug",
    "centrifuge": "centrifug",
    "centrifugei": "centrifug",
    "centrifugele": "centrifug",
    "centrifugelor": "centrifug",
    "centrifugi": "centrifug",
    "centrifugii": "centrifug",
    "centrifugilor": "centrifug",
    "centrifugo": "centrifug",
    "centrifugul": "centrifug",
    "centrifugule": "centrifug",
    "centrifugului": "centrifug",
    "centrifugă": "centrifuga",
    "centrifugai": "centrifuga",
    "centrifugam": "centrifuga",
    "centrifugăm": "centrifuga",
    "centrifugând": "centrifuga",
    "centrifugându": "centrifuga",
    "centrifugară": "centrifuga",
    "centrifugarăm": "centrifuga",
    "centrifugarăți": "centrifuga",
    "centrifugase": "centrifuga",
    "centrifugasem": "centrifuga",
    "centrifugaseră": "centrifuga",
    "centrifugaserăm": "centrifuga",
    "centrifugaserăți": "centrifuga",
    "centrifugaseși": "centrifuga",
    "centrifugași": "centrifuga",
    "centrifugat": "centrifuga",
    "centrifugați": "centrifuga",
    "centrifugatu": "centrifuga",
    "centrifugau": "centrifuga",
    "centrifughează": "centrifuga",
    "centrifughez": "centrifuga",
    "centrifugheze": "centrifuga",
    "centrifughezi": "centrifuga",
    "necentrifugând": "centrifuga",
    "necentrifugându": "centrifuga",
    "nemaicentrifugând": "centrifuga",
    "nemaicentrifugându": "centrifuga",
    "centrifuga": "centrifugă",
    "centrifuge": "centrifugă",
    "centrifugei": "centrifugă",
    "centrifugele": "centrifugă",
    "centrifugelor": "centrifugă",
    "centrifugo": "centrifugă",
    "centrifugala": "centrifugal",
    "centrifugală": "centrifugal",
    "centrifugale": "centrifugal",
    "centrifugalei": "centrifugal",
    "centrifugalele": "centrifugal",
    "centrifugalelor": "centrifugal",
    "centrifugali": "centrifugal",
    "centrifugalii": "centrifugal",
    "centrifugalilor": "centrifugal",
    "centrifugalo": "centrifugal",
    "centrifugalul": "centrifugal",
    "centrifugalule": "centrifugal",
    "centrifugalului": "centrifugal",
    "centrifugarea": "centrifugare",
    "centrifugareo": "centrifugare",
    "centrifugări": "centrifugare",
    "centrifugării": "centrifugare",
    "centrifugările": "centrifugare",
    "centrifugărilor": "centrifugare",
    "centrifugată": "centrifugat",
    "centrifugate": "centrifugat",
    "centrifugați": "centrifugat",
    "centripeta": "centripet",
    "centripetă": "centripet",
    "centripete": "centripet",
    "centripetei": "centripet",
    "centripetele": "centripet",
    "centripetelor": "centripet",
    "centripeți": "centripet",
    "centripeții": "centripet",
    "centripeților": "centripet",
    "centripeto": "centripet",
    "centripetul": "centripet",
    "centripetule": "centripet",
    "centripetului": "centripet",
    "centripetala": "centripetal",
    "centripetală": "centripetal",
    "centripetale": "centripetal",
    "centripetalei": "centripetal",
    "centripetalele": "centripetal",
    "centripetalelor": "centripetal",
    "centripetali": "centripetal",
    "centripetalii": "centripetal",
    "centripetalilor": "centripetal",
    "centripetalo": "centripetal",
    "centripetalul": "centripetal",
    "centripetalule": "centripetal",
    "centripetalului": "centripetal",
    "centrismul": "centrism",
    "centrismule": "centrism",
    "centrismului": "centrism",
    "centrista": "centrist",
    "centristă": "centrist",
    "centriste": "centrist",
    "centristei": "centrist",
    "centristele": "centrist",
    "centristelor": "centrist",
    "centriști": "centrist",
    "centriștii": "centrist",
    "centriștilor": "centrist",
    "centristo": "centrist",
    "centristul": "centrist",
    "centristule": "centrist",
    "centristului": "centrist",
    "centro-americana": "centro-american",
    "centro-americană": "centro-american",
    "centro-americanca": "centro-american",
    "centro-americancă": "centro-american",
    "centro-americance": "centro-american",
    "centro-americancei": "centro-american",
    "centro-americancele": "centro-american",
    "centro-americancelor": "centro-american",
    "centro-americanco": "centro-american",
    "centro-americane": "centro-american",
    "centro-americanei": "centro-american",
    "centro-americanele": "centro-american",
    "centro-americanelor": "centro-american",
    "centro-americani": "centro-american",
    "centro-americanii": "centro-american",
    "centro-americanilor": "centro-american",
    "centro-americano": "centro-american",
    "centro-americanul": "centro-american",
    "centro-americanule": "centro-american",
    "centro-americanului": "centro-american",
    "centre": "centru",
    "centrele": "centru",
    "centrelor": "centru",
    "centri": "centru",
    "centrii": "centru",
    "centrilor": "centru",
    "centrul": "centru",
    "centrule": "centru",
    "centrului": "centru",
    "centura": "centură",
    "centuri": "centură",
    "centurii": "centură",
    "centurile": "centură",
    "centurilor": "centură",
    "centuro": "centură",
    "centuria": "centurie",
    "centuriei": "centurie",
    "centurii": "centurie",
    "centuriile": "centurie",
    "centuriilor": "centurie",
    "centurio": "centurie",
    "centurioni": "centurion",
    "centurionii": "centurion",
    "centurionilor": "centurion",
    "centurionul": "centurion",
    "centurionule": "centurion",
    "centurionului": "centurion",
    "cenușa": "cenușă",
    "cenuși": "cenușă",
    "cenușii": "cenușă",
    "cenușile": "cenușă",
    "cenușilor": "cenușă",
    "cenușo": "cenușă",
    "cenușia": "cenușiu",
    "cenușie": "cenușiu",
    "cenușiei": "cenușiu",
    "cenușii": "cenușiu",
    "cenușiii": "cenușiu",
    "cenușiile": "cenușiu",
    "cenușiilor": "cenușiu",
    "cenușio": "cenușiu",
    "cenușiul": "cenușiu",
    "cenușiule": "cenușiu",
    "cenușiului": "cenușiu",
    "cenușiu-roșiatica": "cenușiu-roșiatic",
    "cenușiu-roșiatică": "cenușiu-roșiatic",
    "cenușiu-roșiatice": "cenușiu-roșiatic",
    "cenușiu-roșiaticei": "cenușiu-roșiatic",
    "cenușiu-roșiaticele": "cenușiu-roșiatic",
    "cenușiu-roșiaticelor": "cenușiu-roșiatic",
    "cenușiu-roșiatici": "cenușiu-roșiatic",
    "cenușiu-roșiaticii": "cenușiu-roșiatic",
    "cenușiu-roșiaticilor": "cenușiu-roșiatic",
    "cenușiu-roșiatico": "cenușiu-roșiatic",
    "cenușiu-roșiaticul": "cenușiu-roșiatic",
    "cenușiu-roșiaticule": "cenușiu-roșiatic",
    "cenușiu-roșiaticului": "cenușiu-roșiatic",
    "cenzitara": "cenzitar",
    "cenzitară": "cenzitar",
    "cenzitare": "cenzitar",
    "cenzitarei": "cenzitar",
    "cenzitarele": "cenzitar",
    "cenzitarelor": "cenzitar",
    "cenzitari": "cenzitar",
    "cenzitarii": "cenzitar",
    "cenzitarilor": "cenzitar",
    "cenzitaro": "cenzitar",
    "cenzitarul": "cenzitar",
    "cenzitarule": "cenzitar",
    "cenzitarului": "cenzitar",
    "cenzori": "cenzor",
    "cenzorii": "cenzor",
    "cenzorilor": "cenzor",
    "cenzorul": "cenzor",
    "cenzorule": "cenzor",
    "cenzorului": "cenzor",
    "cenzură": "cenzura",
    "cenzurai": "cenzura",
    "cenzuram": "cenzura",
    "cenzurăm": "cenzura",
    "cenzurând": "cenzura",
    "cenzurându": "cenzura",
    "cenzurară": "cenzura",
    "cenzurarăm": "cenzura",
    "cenzurarăți": "cenzura",
    "cenzurase": "cenzura",
    "cenzurasem": "cenzura",
    "cenzuraseră": "cenzura",
    "cenzuraserăm": "cenzura",
    "cenzuraserăți": "cenzura",
    "cenzuraseși": "cenzura",
    "cenzurași": "cenzura",
    "cenzurat": "cenzura",
    "cenzurați": "cenzura",
    "cenzuratu": "cenzura",
    "cenzurau": "cenzura",
    "cenzurează": "cenzura",
    "cenzurez": "cenzura",
    "cenzureze": "cenzura",
    "cenzurezi": "cenzura",
    "necenzurând": "cenzura",
    "necenzurându": "cenzura",
    "nemaicenzurând": "cenzura",
    "nemaicenzurându": "cenzura",
    "cenzura": "cenzură",
    "cenzuri": "cenzură",
    "cenzurii": "cenzură",
    "cenzurile": "cenzură",
    "cenzurilor": "cenzură",
    "cenzuro": "cenzură",
    "cenzurarea": "cenzurare",
    "cenzurareo": "cenzurare",
    "cenzurări": "cenzurare",
    "cenzurării": "cenzurare",
    "cenzurările": "cenzurare",
    "cenzurărilor": "cenzurare",
    "cenzurata": "cenzurat",
    "cenzurată": "cenzurat",
    "cenzurate": "cenzurat",
    "cenzuratei": "cenzurat",
    "cenzuratele": "cenzurat",
    "cenzuratelor": "cenzurat",
    "cenzurați": "cenzurat",
    "cenzurații": "cenzurat",
    "cenzuraților": "cenzurat",
    "cenzurato": "cenzurat",
    "cenzuratul": "cenzurat",
    "cenzuratule": "cenzurat",
    "cenzuratului": "cenzurat",
    "cepul": "cep",
    "cepule": "cep",
    "cepului": "cep",
    "cepuri": "cep",
    "cepurile": "cep",
    "cepurilor": "cep",
    "cepișoara": "cepișoară",
    "cepișoare": "cepișoară",
    "cepișoarei": "cepișoară",
    "cepișoarele": "cepișoară",
    "cepișoarelor": "cepișoară",
    "cepișoaro": "cepișoară",
    "cepșoara": "cepșoară",
    "cepșoare": "cepșoară",
    "cepșoarei": "cepșoară",
    "cepșoarele": "cepșoară",
    "cepșoarelor": "cepșoară",
    "cepșoaro": "cepșoară",
    "cepușoara": "cepușoară",
    "cepușoare": "cepușoară",
    "cepușoarei": "cepușoară",
    "cepușoarele": "cepușoară",
    "cepușoarelor": "cepușoară",
    "cepușoaro": "cepușoară",
    "cepușoare": "cepușor",
    "cepușoarele": "cepușor",
    "cepușoarelor": "cepușor",
    "cepușorul": "cepușor",
    "cepușorule": "cepușor",
    "cepușorului": "cepușor",
    "ceri": "cer",
    "cerii": "cer",
    "cerilor": "cer",
    "cerul": "cer",
    "cerule": "cer",
    "cerului": "cer",
    "ceruri": "cer",
    "cerurile": "cer",
    "cerurilor": "cer",
    "ceramica": "ceramică",
    "ceramici": "ceramică",
    "ceramicii": "ceramică",
    "ceramicile": "ceramică",
    "ceramicilor": "ceramică",
    "ceramico": "ceramică",
    "ceramiști": "ceramist",
    "ceramiștii": "ceramist",
    "ceramiștilor": "ceramist",
    "ceramistul": "ceramist",
    "ceramistule": "ceramist",
    "ceramistului": "ceramist",
    "ceramista": "ceramistă",
    "ceramiste": "ceramistă",
    "ceramistei": "ceramistă",
    "ceramistele": "ceramistă",
    "ceramistelor": "ceramistă",
    "ceramisto": "ceramistă",
    "cerata": "cerat",
    "cerată": "cerat",
    "cerate": "cerat",
    "ceratei": "cerat",
    "ceratele": "cerat",
    "ceratelor": "cerat",
    "cerați": "cerat",
    "cerații": "cerat",
    "ceraților": "cerat",
    "cerato": "cerat",
    "ceratul": "cerat",
    "ceratule": "cerat",
    "ceratului": "cerat",
    "cerbi": "cerb",
    "cerbii": "cerb",
    "cerbilor": "cerb",
    "cerbul": "cerb",
    "cerbule": "cerb",
    "cerbului": "cerb",
    "cerbăria": "cerbărie",
    "cerbăriei": "cerbărie",
    "cerbării": "cerbărie",
    "cerbăriile": "cerbărie",
    "cerbăriilor": "cerbărie",
    "cerbărio": "cerbărie",
    "cerberi": "cerber",
    "cerberii": "cerber",
    "cerberilor": "cerber",
    "cerberul": "cerber",
    "cerberule": "cerber",
    "cerberului": "cerber",
    "cerbicia": "cerbicie",
    "cerbiciei": "cerbicie",
    "cerbicii": "cerbicie",
    "cerbiciile": "cerbicie",
    "cerbiciilor": "cerbicie",
    "cerbicio": "cerbicie",
    "cerboaica": "cerboaică",
    "cerboaice": "cerboaică",
    "cerboaicei": "cerboaică",
    "cerboaicele": "cerboaică",
    "cerboaicelor": "cerboaică",
    "cerboaico": "cerboaică",
    "cercul": "cerc",
    "cercule": "cerc",
    "cercului": "cerc",
    "cercuri": "cerc",
    "cercurile": "cerc",
    "cercurilor": "cerc",
    "cearcă": "cerca",
    "cerc": "cerca",
    "cercă": "cerca",
    "cercai": "cerca",
    "cercam": "cerca",
    "cercăm": "cerca",
    "cercând": "cerca",
    "cercându": "cerca",
    "cercară": "cerca",
    "cercarăm": "cerca",
    "cercarăți": "cerca",
    "cercase": "cerca",
    "cercasem": "cerca",
    "cercaseră": "cerca",
    "cercaserăm": "cerca",
    "cercaserăți": "cerca",
    "cercaseși": "cerca",
    "cercași": "cerca",
    "cercat": "cerca",
    "cercați": "cerca",
    "cercatu": "cerca",
    "cercau": "cerca",
    "cerce": "cerca",
    "cerci": "cerca",
    "necercând": "cerca",
    "necercându": "cerca",
    "nemaicercând": "cerca",
    "nemaicercându": "cerca",
    "cercănata": "cercănat",
    "cercănată": "cercănat",
    "cercănate": "cercănat",
    "cercănatei": "cercănat",
    "cercănatele": "cercănat",
    "cercănatelor": "cercănat",
    "cercănați": "cercănat",
    "cercănații": "cercănat",
    "cercănaților": "cercănat",
    "cercănato": "cercănat",
    "cercănatul": "cercănat",
    "cercănatule": "cercănat",
    "cercănatului": "cercănat",
    "cercănele": "cercănel",
    "cercănelele": "cercănel",
    "cercănelelor": "cercănel",
    "cercănelul": "cercănel",
    "cercănelule": "cercănel",
    "cercănelului": "cercănel",
    "cercarea": "cercare",
    "cercareo": "cercare",
    "cercări": "cercare",
    "cercării": "cercare",
    "cercările": "cercare",
    "cercărilor": "cercare",
    "cercata": "cercat",
    "cercată": "cercat",
    "cercate": "cercat",
    "cercatei": "cercat",
    "cercatele": "cercat",
    "cercatelor": "cercat",
    "cercați": "cercat",
    "cercații": "cercat",
    "cercaților": "cercat",
    "cercato": "cercat",
    "cercatul": "cercat",
    "cercatule": "cercat",
    "cercatului": "cercat",
    "cercei": "cercel",
    "cerceii": "cercel",
    "cerceilor": "cercel",
    "cercelul": "cercel",
    "cercelule": "cercel",
    "cercelului": "cercel",
    "cerceloii": "cerceloi",
    "cerceloilor": "cerceloi",
    "cerceloiul": "cerceloi",
    "cerceloiule": "cerceloi",
    "cerceloiului": "cerceloi",
    "cerceluși": "cerceluș",
    "cercelușii": "cerceluș",
    "cercelușilor": "cerceluș",
    "cercelușul": "cerceluș",
    "cercelușule": "cerceluș",
    "cercelușului": "cerceluș",
    "cercetă": "cerceta",
    "cercetai": "cerceta",
    "cercetam": "cerceta",
    "cercetăm": "cerceta",
    "cercetând": "cerceta",
    "cercetându": "cerceta",
    "cercetară": "cerceta",
    "cercetarăm": "cerceta",
    "cercetarăți": "cerceta",
    "cercetase": "cerceta",
    "cercetasem": "cerceta",
    "cercetaseră": "cerceta",
    "cercetaserăm": "cerceta",
    "cercetaserăți": "cerceta",
    "cercetaseși": "cerceta",
    "cercetași": "cerceta",
    "cercetat": "cerceta",
    "cercetați": "cerceta",
    "cercetatu": "cerceta",
    "cercetau": "cerceta",
    "cerceteaz": "cerceta",
    "cercetează": "cerceta",
    "cercetez": "cerceta",
    "cerceteze": "cerceta",
    "cercetezi": "cerceta",
    "necercetând": "cerceta",
    "necercetându": "cerceta",
    "nemaicercetând": "cerceta",
    "nemaicercetându": "cerceta",
    "cercetarea": "cercetare",
    "cercetareo": "cercetare",
    "cercetări": "cercetare",
    "cercetării": "cercetare",
    "cercetările": "cercetare",
    "cercetărilor": "cercetare",
    "cercetași": "cercetaș",
    "cercetașii": "cercetaș",
    "cercetașilor": "cercetaș",
    "cercetașul": "cercetaș",
    "cercetașule": "cercetaș",
    "cercetașului": "cercetaș",
    "cercetașa": "cercetașă",
    "cercetașe": "cercetașă",
    "cercetașei": "cercetașă",
    "cercetașele": "cercetașă",
    "cercetașelor": "cercetașă",
    "cercetașo": "cercetașă",
    "cercetășia": "cercetășie",
    "cercetășiei": "cercetășie",
    "cercetășii": "cercetășie",
    "cercetășiile": "cercetășie",
    "cercetășiilor": "cercetășie",
    "cercetășio": "cercetășie",
    "cercetată": "cercetat",
    "cercetate": "cercetat",
    "cercetați": "cercetat",
    "cercetătoarea": "cercetătoare",
    "cercetătoarei": "cercetătoare",
    "cercetătoarele": "cercetătoare",
    "cercetătoarelor": "cercetătoare",
    "cercetătoareo": "cercetătoare",
    "cercetătoare": "cercetător",
    "cercetători": "cercetător",
    "cercetătorii": "cercetător",
    "cercetătorilor": "cercetător",
    "cercetătorul": "cercetător",
    "cercetătorule": "cercetător",
    "cercetătorului": "cercetător",
    "cerceveao": "cercevea",
    "cerceveaua": "cercevea",
    "cercevele": "cercevea",
    "cercevelei": "cercevea",
    "cercevelele": "cercevea",
    "cercevelelor": "cercevea",
    "cercuiala": "cercuială",
    "cercuialo": "cercuială",
    "cercuieli": "cercuială",
    "cercuielii": "cercuială",
    "cercuielile": "cercuială",
    "cercuielilor": "cercuială",
    "cercuitul": "cercuit",
    "cercuitule": "cercuit",
    "cercuitului": "cercuit",
    "cerculețe": "cerculeț",
    "cerculețele": "cerculeț",
    "cerculețelor": "cerculeț",
    "cerculețul": "cerculeț",
    "cerculețule": "cerculeț",
    "cerculețului": "cerculeț",
    "cercușoare": "cercușor",
    "cercușoarele": "cercușor",
    "cercușoarelor": "cercușor",
    "cercușorul": "cercușor",
    "cercușorule": "cercușor",
    "cercușorului": "cercușor",
    "cerdace": "cerdac",
    "cerdacele": "cerdac",
    "cerdacelor": "cerdac",
    "cerdacul": "cerdac",
    "cerdacule": "cerdac",
    "cerdacului": "cerdac",
    "cerdacuri": "cerdac",
    "cerdacurile": "cerdac",
    "cerdacurilor": "cerdac",
    "cerdăcele": "cerdăcel",
    "cerdăcelele": "cerdăcel",
    "cerdăcelelor": "cerdăcel",
    "cerdăcelul": "cerdăcel",
    "cerdăcelule": "cerdăcel",
    "cerdăcelului": "cerdăcel",
    "cerdăcuțe": "cerdăcuț",
    "cerdăcuțele": "cerdăcuț",
    "cerdăcuțelor": "cerdăcuț",
    "cerdăcuțul": "cerdăcuț",
    "cerdăcuțule": "cerdăcuț",
    "cerdăcuțului": "cerdăcuț",
    "ceară": "cere",
    "cer": "cere",
    "cerând": "cere",
    "cerându": "cere",
    "cerea": "cere",
    "cereai": "cere",
    "ceream": "cere",
    "cereați": "cere",
    "cereau": "cere",
    "cerem": "cere",
    "cereți": "cere",
    "ceri": "cere",
    "ceru": "cere",
    "cerui": "cere",
    "cerură": "cere",
    "cerurăm": "cere",
    "cerurăți": "cere",
    "ceruse": "cere",
    "cerusem": "cere",
    "ceruseră": "cere",
    "ceruserăm": "cere",
    "ceruserăți": "cere",
    "ceruseși": "cere",
    "ceruși": "cere",
    "cerut": "cere",
    "cerutu": "cere",
    "necerând": "cere",
    "necerându": "cere",
    "nemaicerând": "cere",
    "nemaicerându": "cere",
    "cereala": "cereală",
    "cereale": "cereală",
    "cerealei": "cereală",
    "cerealele": "cereală",
    "cerealelor": "cereală",
    "cerealo": "cereală",
    "cerealiera": "cerealier",
    "cerealieră": "cerealier",
    "cerealiere": "cerealier",
    "cerealierei": "cerealier",
    "cerealierele": "cerealier",
    "cerealierelor": "cerealier",
    "cerealieri": "cerealier",
    "cerealierii": "cerealier",
    "cerealierilor": "cerealier",
    "cerealiero": "cerealier",
    "cerealierul": "cerealier",
    "cerealierule": "cerealier",
    "cerealierului": "cerealier",
    "cerebele": "cerebel",
    "cerebelele": "cerebel",
    "cerebelelor": "cerebel",
    "cerebelul": "cerebel",
    "cerebelule": "cerebel",
    "cerebelului": "cerebel",
    "cerebeluri": "cerebel",
    "cerebelurile": "cerebel",
    "cerebelurilor": "cerebel",
    "cerebrala": "cerebral",
    "cerebrală": "cerebral",
    "cerebrale": "cerebral",
    "cerebralei": "cerebral",
    "cerebralele": "cerebral",
    "cerebralelor": "cerebral",
    "cerebrali": "cerebral",
    "cerebralii": "cerebral",
    "cerebralilor": "cerebral",
    "cerebralo": "cerebral",
    "cerebralul": "cerebral",
    "cerebralule": "cerebral",
    "cerebralului": "cerebral",
    "cerebrospinala": "cerebrospinal",
    "cerebrospinală": "cerebrospinal",
    "cerebrospinale": "cerebrospinal",
    "cerebrospinalei": "cerebrospinal",
    "cerebrospinalele": "cerebrospinal",
    "cerebrospinalelor": "cerebrospinal",
    "cerebrospinali": "cerebrospinal",
    "cerebrospinalii": "cerebrospinal",
    "cerebrospinalilor": "cerebrospinal",
    "cerebrospinalo": "cerebrospinal",
    "cerebrospinalul": "cerebrospinal",
    "cerebrospinalule": "cerebrospinal",
    "cerebrospinalului": "cerebrospinal",
    "ceremoniale": "ceremonial",
    "ceremonialele": "ceremonial",
    "ceremonialelor": "ceremonial",
    "ceremonialul": "ceremonial",
    "ceremonialule": "ceremonial",
    "ceremonialului": "ceremonial",
    "ceremonialuri": "ceremonial",
    "ceremonialurile": "ceremonial",
    "ceremonialurilor": "ceremonial",
    "ceremonia": "ceremonie",
    "ceremoniei": "ceremonie",
    "ceremonii": "ceremonie",
    "ceremoniile": "ceremonie",
    "ceremoniilor": "ceremonie",
    "ceremonio": "ceremonie",
    "ceremonioasa": "ceremonios",
    "ceremonioasă": "ceremonios",
    "ceremonioase": "ceremonios",
    "ceremonioasei": "ceremonios",
    "ceremonioasele": "ceremonios",
    "ceremonioaselor": "ceremonios",
    "ceremonioaso": "ceremonios",
    "ceremonioși": "ceremonios",
    "ceremonioșii": "ceremonios",
    "ceremonioșilor": "ceremonios",
    "ceremoniosul": "ceremonios",
    "ceremoniosule": "ceremonios",
    "ceremoniosului": "ceremonios",
    "cererea": "cerere",
    "cerereo": "cerere",
    "cereri": "cerere",
    "cererii": "cerere",
    "cererile": "cerere",
    "cererilor": "cerere",
    "cereasca": "ceresc",
    "cerească": "ceresc",
    "cereasco": "ceresc",
    "cerescul": "ceresc",
    "cerescule": "ceresc",
    "cerescului": "ceresc",
    "cerești": "ceresc",
    "cereștii": "ceresc",
    "cereștile": "ceresc",
    "cereștilor": "ceresc",
    "cerezina": "cerezină",
    "cerezine": "cerezină",
    "cerezinei": "cerezină",
    "cerezinele": "cerezină",
    "cerezinelor": "cerezină",
    "cerezino": "cerezină",
    "cerga": "cergă",
    "cergi": "cergă",
    "cergii": "cergă",
    "cergile": "cergă",
    "cergilor": "cergă",
    "cergo": "cergă",
    "cerința": "cerință",
    "cerințe": "cerință",
    "cerinței": "cerință",
    "cerințele": "cerință",
    "cerințelor": "cerință",
    "cerințo": "cerință",
    "ceriul": "ceriu",
    "ceriule": "ceriu",
    "ceriului": "ceriu",
    "Cernă": "Cerna",
    "Cerne": "Cerna",
    "Cernei": "Cerna",
    "Cernăuțiul": "Cernăuți",
    "Cernăuțiului": "Cernăuți",
    "cearnă": "cerne",
    "cern": "cerne",
    "cernând": "cerne",
    "cernându": "cerne",
    "cernea": "cerne",
    "cerneai": "cerne",
    "cerneam": "cerne",
    "cerneați": "cerne",
    "cerneau": "cerne",
    "cernem": "cerne",
    "cerneți": "cerne",
    "cerni": "cerne",
    "cernu": "cerne",
    "cernui": "cerne",
    "cernură": "cerne",
    "cernurăm": "cerne",
    "cernurăți": "cerne",
    "cernuse": "cerne",
    "cernusem": "cerne",
    "cernuseră": "cerne",
    "cernuserăm": "cerne",
    "cernuserăți": "cerne",
    "cernuseși": "cerne",
    "cernuși": "cerne",
    "cernut": "cerne",
    "cernutu": "cerne",
    "necernând": "cerne",
    "necernându": "cerne",
    "nemaicernând": "cerne",
    "nemaicernându": "cerne",
    "cerneala": "cerneală",
    "cernealo": "cerneală",
    "cerneli": "cerneală",
    "cernelii": "cerneală",
    "cernelile": "cerneală",
    "cernelilor": "cerneală",
    "cerneluri": "cerneală",
    "cernelurile": "cerneală",
    "cernelurilor": "cerneală",
    "cernerea": "cernere",
    "cernereo": "cernere",
    "cerneri": "cernere",
    "cernerii": "cernere",
    "cernerile": "cernere",
    "cernerilor": "cernere",
    "cernea": "cerni",
    "cerneai": "cerni",
    "cerneam": "cerni",
    "cernească": "cerni",
    "cerneați": "cerni",
    "cerneau": "cerni",
    "cernesc": "cerni",
    "cernește": "cerni",
    "cernești": "cerni",
    "cernii": "cerni",
    "cernim": "cerni",
    "cernind": "cerni",
    "cernindu": "cerni",
    "cerniră": "cerni",
    "cernirăm": "cerni",
    "cernirăți": "cerni",
    "cernise": "cerni",
    "cernisem": "cerni",
    "cerniseră": "cerni",
    "cerniserăm": "cerni",
    "cerniserăți": "cerni",
    "cerniseși": "cerni",
    "cerniși": "cerni",
    "cernit": "cerni",
    "cerniți": "cerni",
    "cernitu": "cerni",
    "necernind": "cerni",
    "necernindu": "cerni",
    "nemaicernind": "cerni",
    "nemaicernindu": "cerni",
    "Cernicei": "Cernica",
    "cernirea": "cernire",
    "cernireo": "cernire",
    "cerniri": "cernire",
    "cernirii": "cernire",
    "cernirile": "cernire",
    "cernirilor": "cernire",
    "cernita": "cernit",
    "cernită": "cernit",
    "cernite": "cernit",
    "cernitei": "cernit",
    "cernitele": "cernit",
    "cernitelor": "cernit",
    "cerniți": "cernit",
    "cerniții": "cernit",
    "cerniților": "cernit",
    "cernito": "cernit",
    "cernitul": "cernit",
    "cernitule": "cernit",
    "cernitului": "cernit",
    "Cernobâlul": "Cernobâl",
    "Cernobâlului": "Cernobâl",
    "cernoziomul": "cernoziom",
    "cernoziomule": "cernoziom",
    "cernoziomului": "cernoziom",
    "cernoziomuri": "cernoziom",
    "cernoziomurile": "cernoziom",
    "cernoziomurilor": "cernoziom",
    "cernuta": "cernut",
    "cernută": "cernut",
    "cernute": "cernut",
    "cernutei": "cernut",
    "cernutele": "cernut",
    "cernutelor": "cernut",
    "cernuți": "cernut",
    "cernuții": "cernut",
    "cernuților": "cernut",
    "cernuto": "cernut",
    "cernutul": "cernut",
    "cernutule": "cernut",
    "cernutului": "cernut",
    "ceroplastica": "ceroplastică",
    "ceroplastici": "ceroplastică",
    "ceroplasticii": "ceroplastică",
    "ceroplasticile": "ceroplastică",
    "ceroplasticilor": "ceroplastică",
    "ceroplastico": "ceroplastică",
    "ceroasa": "ceros",
    "ceroasă": "ceros",
    "ceroase": "ceros",
    "ceroasei": "ceros",
    "ceroasele": "ceros",
    "ceroaselor": "ceros",
    "ceroaso": "ceros",
    "ceroși": "ceros",
    "ceroșii": "ceros",
    "ceroșilor": "ceros",
    "cerosul": "ceros",
    "cerosule": "ceros",
    "cerosului": "ceros",
    "cerșetoarea": "cerșetoare",
    "cerșetoarei": "cerșetoare",
    "cerșetoarele": "cerșetoare",
    "cerșetoarelor": "cerșetoare",
    "cerșetoareo": "cerșetoare",
    "cerșetori": "cerșetor",
    "cerșetorii": "cerșetor",
    "cerșetorilor": "cerșetor",
    "cerșetorul": "cerșetor",
    "cerșetorule": "cerșetor",
    "cerșetorului": "cerșetor",
    "cerșetoreasca": "cerșetoresc",
    "cerșetorească": "cerșetoresc",
    "cerșetoreasco": "cerșetoresc",
    "cerșetorescul": "cerșetoresc",
    "cerșetorescule": "cerșetoresc",
    "cerșetorescului": "cerșetoresc",
    "cerșetorești": "cerșetoresc",
    "cerșetoreștii": "cerșetoresc",
    "cerșetoreștile": "cerșetoresc",
    "cerșetoreștilor": "cerșetoresc",
    "cerșetorea": "cerșetori",
    "cerșetoreai": "cerșetori",
    "cerșetoream": "cerșetori",
    "cerșetorească": "cerșetori",
    "cerșetoreați": "cerșetori",
    "cerșetoreau": "cerșetori",
    "cerșetoresc": "cerșetori",
    "cerșetorește": "cerșetori",
    "cerșetorești": "cerșetori",
    "cerșetorii": "cerșetori",
    "cerșetorim": "cerșetori",
    "cerșetorind": "cerșetori",
    "cerșetorindu": "cerșetori",
    "cerșetoriră": "cerșetori",
    "cerșetorirăm": "cerșetori",
    "cerșetorirăți": "cerșetori",
    "cerșetorise": "cerșetori",
    "cerșetorisem": "cerșetori",
    "cerșetoriseră": "cerșetori",
    "cerșetoriserăm": "cerșetori",
    "cerșetoriserăți": "cerșetori",
    "cerșetoriseși": "cerșetori",
    "cerșetoriși": "cerșetori",
    "cerșetorit": "cerșetori",
    "cerșetoriți": "cerșetori",
    "cerșetoritu": "cerșetori",
    "necerșetorind": "cerșetori",
    "necerșetorindu": "cerșetori",
    "nemaicerșetorind": "cerșetori",
    "nemaicerșetorindu": "cerșetori",
    "cerșetoria": "cerșetorie",
    "cerșetoriei": "cerșetorie",
    "cerșetorii": "cerșetorie",
    "cerșetoriile": "cerșetorie",
    "cerșetoriilor": "cerșetorie",
    "cerșetorio": "cerșetorie",
    "cerșetorimea": "cerșetorime",
    "cerșetorimeo": "cerșetorime",
    "cerșetorimi": "cerșetorime",
    "cerșetorimii": "cerșetorime",
    "cerșetorimile": "cerșetorime",
    "cerșetorimilor": "cerșetorime",
    "cerșetorită": "cerșetorit",
    "cerșetorite": "cerșetorit",
    "cerșetoriți": "cerșetorit",
    "cerșea": "cerși",
    "cerșeai": "cerși",
    "cerșeam": "cerși",
    "cerșească": "cerși",
    "cerșeați": "cerși",
    "cerșeau": "cerși",
    "cerșesc": "cerși",
    "cerșește": "cerși",
    "cerșești": "cerși",
    "cerșii": "cerși",
    "cerșim": "cerși",
    "cerșind": "cerși",
    "cerșindu": "cerși",
    "cerșiră": "cerși",
    "cerșirăm": "cerși",
    "cerșirăți": "cerși",
    "cerșise": "cerși",
    "cerșisem": "cerși",
    "cerșiseră": "cerși",
    "cerșiserăm": "cerși",
    "cerșiserăți": "cerși",
    "cerșiseși": "cerși",
    "cerșiși": "cerși",
    "cerșit": "cerși",
    "cerșiți": "cerși",
    "cerșitu": "cerși",
    "necerșind": "cerși",
    "necerșindu": "cerși",
    "nemaicerșind": "cerși",
    "nemaicerșindu": "cerși",
    "cerșită": "cerșit",
    "cerșite": "cerșit",
    "cerșiți": "cerșit",
    "cerșitul": "cerșit",
    "cerșitule": "cerșit",
    "cerșitului": "cerșit",
    "certa": "cert",
    "certă": "cert",
    "certe": "cert",
    "certei": "cert",
    "certele": "cert",
    "certelor": "cert",
    "cerți": "cert",
    "cerții": "cert",
    "cerților": "cert",
    "certo": "cert",
    "certul": "cert",
    "certule": "cert",
    "certului": "cert",
    "ceartă": "certa",
    "cert": "certa",
    "certă": "certa",
    "certai": "certa",
    "certam": "certa",
    "certăm": "certa",
    "certând": "certa",
    "certându": "certa",
    "certară": "certa",
    "certarăm": "certa",
    "certarăți": "certa",
    "certase": "certa",
    "certasem": "certa",
    "certaseră": "certa",
    "certaserăm": "certa",
    "certaserăți": "certa",
    "certaseși": "certa",
    "certași": "certa",
    "certat": "certa",
    "certați": "certa",
    "certatu": "certa",
    "certau": "certa",
    "certe": "certa",
    "cerți": "certa",
    "necertând": "certa",
    "necertându": "certa",
    "nemaicertând": "certa",
    "nemaicertându": "certa",
    "certarea": "certare",
    "certareo": "certare",
    "certări": "certare",
    "certării": "certare",
    "certările": "certare",
    "certărilor": "certare",
    "certăreața": "certăreț",
    "certăreață": "certăreț",
    "certăreațo": "certăreț",
    "certărețe": "certăreț",
    "certăreței": "certăreț",
    "certărețele": "certăreț",
    "certărețelor": "certăreț",
    "certăreți": "certăreț",
    "certăreții": "certăreț",
    "certăreților": "certăreț",
    "certărețul": "certăreț",
    "certărețule": "certăreț",
    "certărețului": "certăreț",
    "certata": "certat",
    "certată": "certat",
    "certate": "certat",
    "certatei": "certat",
    "certatele": "certat",
    "certatelor": "certat",
    "certați": "certat",
    "certații": "certat",
    "certaților": "certat",
    "certato": "certat",
    "certatul": "certat",
    "certatule": "certat",
    "certatului": "certat",
    "certific": "certifica",
    "certifică": "certifica",
    "certificai": "certifica",
    "certificam": "certifica",
    "certificăm": "certifica",
    "certificând": "certifica",
    "certificându": "certifica",
    "certificară": "certifica",
    "certificarăm": "certifica",
    "certificarăți": "certifica",
    "certificase": "certifica",
    "certificasem": "certifica",
    "certificaseră": "certifica",
    "certificaserăm": "certifica",
    "certificaserăți": "certifica",
    "certificaseși": "certifica",
    "certificași": "certifica",
    "certificat": "certifica",
    "certificați": "certifica",
    "certificatu": "certifica",
    "certificau": "certifica",
    "certifice": "certifica",
    "certifici": "certifica",
    "necertificând": "certifica",
    "necertificându": "certifica",
    "nemaicertificând": "certifica",
    "nemaicertificându": "certifica",
    "certificarea": "certificare",
    "certificareo": "certificare",
    "certificări": "certificare",
    "certificării": "certificare",
    "certificările": "certificare",
    "certificărilor": "certificare",
    "certificată": "certificat",
    "certificate": "certificat",
    "certificatele": "certificat",
    "certificatelor": "certificat",
    "certificați": "certificat",
    "certificatul": "certificat",
    "certificatule": "certificat",
    "certificatului": "certificat",
    "certitudinea": "certitudine",
    "certitudineo": "certitudine",
    "certitudini": "certitudine",
    "certitudinii": "certitudine",
    "certitudinile": "certitudine",
    "certitudinilor": "certitudine",
    "ceruia": "cerui",
    "ceruiai": "cerui",
    "ceruiam": "cerui",
    "ceruiască": "cerui",
    "ceruiați": "cerui",
    "ceruiau": "cerui",
    "ceruiesc": "cerui",
    "ceruiește": "cerui",
    "ceruiești": "cerui",
    "ceruii": "cerui",
    "ceruim": "cerui",
    "ceruind": "cerui",
    "ceruindu": "cerui",
    "ceruiră": "cerui",
    "ceruirăm": "cerui",
    "ceruirăți": "cerui",
    "ceruise": "cerui",
    "ceruisem": "cerui",
    "ceruiseră": "cerui",
    "ceruiserăm": "cerui",
    "ceruiserăți": "cerui",
    "ceruiseși": "cerui",
    "ceruiși": "cerui",
    "ceruit": "cerui",
    "ceruiți": "cerui",
    "ceruitu": "cerui",
    "neceruind": "cerui",
    "neceruindu": "cerui",
    "nemaiceruind": "cerui",
    "nemaiceruindu": "cerui",
    "ceruiala": "ceruială",
    "ceruialo": "ceruială",
    "ceruieli": "ceruială",
    "ceruielii": "ceruială",
    "ceruielile": "ceruială",
    "ceruielilor": "ceruială",
    "ceruirea": "ceruire",
    "ceruireo": "ceruire",
    "ceruiri": "ceruire",
    "ceruirii": "ceruire",
    "ceruirile": "ceruire",
    "ceruirilor": "ceruire",
    "ceruită": "ceruit",
    "ceruite": "ceruit",
    "ceruiți": "ceruit",
    "ceruitul": "ceruit",
    "ceruitule": "ceruit",
    "ceruitului": "ceruit",
    "ceruituri": "ceruit",
    "ceruiturile": "ceruit",
    "ceruiturilor": "ceruit",
    "cerumenul": "cerumen",
    "cerumenule": "cerumen",
    "cerumenului": "cerumen",
    "cerută": "cerut",
    "cerute": "cerut",
    "ceruți": "cerut",
    "cerutul": "cerut",
    "cerutule": "cerut",
    "cerutului": "cerut",
    "cervicala": "cervical",
    "cervicală": "cervical",
    "cervicale": "cervical",
    "cervicalei": "cervical",
    "cervicalele": "cervical",
    "cervicalelor": "cervical",
    "cervicali": "cervical",
    "cervicalii": "cervical",
    "cervicalilor": "cervical",
    "cervicalo": "cervical",
    "cervicalul": "cervical",
    "cervicalule": "cervical",
    "cervicalului": "cervical",
    "ceșculița": "ceșculiță",
    "ceșculițe": "ceșculiță",
    "ceșculiței": "ceșculiță",
    "ceșculițele": "ceșculiță",
    "ceșculițelor": "ceșculiță",
    "ceșculițo": "ceșculiță",
    "ceșcuța": "ceșcuță",
    "ceșcuțe": "ceșcuță",
    "ceșcuței": "ceșcuță",
    "ceșcuțele": "ceșcuță",
    "ceșcuțelor": "ceșcuță",
    "ceșcuțo": "ceșcuță",
    "cesionă": "cesiona",
    "cesionai": "cesiona",
    "cesionam": "cesiona",
    "cesionăm": "cesiona",
    "cesionând": "cesiona",
    "cesionându": "cesiona",
    "cesionară": "cesiona",
    "cesionarăm": "cesiona",
    "cesionarăți": "cesiona",
    "cesionase": "cesiona",
    "cesionasem": "cesiona",
    "cesionaseră": "cesiona",
    "cesionaserăm": "cesiona",
    "cesionaserăți": "cesiona",
    "cesionaseși": "cesiona",
    "cesionași": "cesiona",
    "cesionat": "cesiona",
    "cesionați": "cesiona",
    "cesionatu": "cesiona",
    "cesionau": "cesiona",
    "cesionează": "cesiona",
    "cesionez": "cesiona",
    "cesioneze": "cesiona",
    "cesionezi": "cesiona",
    "necesionând": "cesiona",
    "necesionându": "cesiona",
    "nemaicesionând": "cesiona",
    "nemaicesionându": "cesiona",
    "cesionari": "cesionar",
    "cesionarii": "cesionar",
    "cesionarilor": "cesionar",
    "cesionarul": "cesionar",
    "cesionarule": "cesionar",
    "cesionarului": "cesionar",
    "cesionara": "cesionară",
    "cesionare": "cesionară",
    "cesionarea": "cesionară",
    "cesionarei": "cesionară",
    "cesionarele": "cesionară",
    "cesionarelor": "cesionară",
    "cesionaro": "cesionară",
    "cesionată": "cesionat",
    "cesionate": "cesionat",
    "cesionați": "cesionat",
    "cesiul": "cesiu",
    "cesiule": "cesiu",
    "cesiului": "cesiu",
    "cesiunea": "cesiune",
    "cesiuneo": "cesiune",
    "cesiuni": "cesiune",
    "cesiunii": "cesiune",
    "cesiunile": "cesiune",
    "cesiunilor": "cesiune",
    "ceastălaltă": "cestălalt",
    "cesteilalte": "cestălalt",
    "cestelalte": "cestălalt",
    "ceștilalți": "cestălalt",
    "cestorlalte": "cestălalt",
    "cestorlalți": "cestălalt",
    "cestuilalt": "cestălalt",
    "cesulețe": "cesuleț",
    "cesulețele": "cesuleț",
    "cesulețelor": "cesuleț",
    "cesulețul": "cesuleț",
    "cesulețule": "cesuleț",
    "cesulețului": "cesuleț",
    "cetacee": "cetaceu",
    "cetaceele": "cetaceu",
    "cetaceelor": "cetaceu",
    "cetaceul": "cetaceu",
    "cetaceule": "cetaceu",
    "cetaceului": "cetaceu",
    "cetași": "cetaș",
    "cetașii": "cetaș",
    "cetașilor": "cetaș",
    "cetașul": "cetaș",
    "cetașule": "cetaș",
    "cetașului": "cetaș",
    "cetatea": "cetate",
    "cetateo": "cetate",
    "cetăți": "cetate",
    "cetății": "cetate",
    "cetățile": "cetate",
    "cetăților": "cetate",
    "cetățeanul": "cetățean",
    "cetățeanule": "cetățean",
    "cetățeanului": "cetățean",
    "cetățeni": "cetățean",
    "cetățenii": "cetățean",
    "cetățenilor": "cetățean",
    "cetățeana": "cetățeană",
    "cetățeano": "cetățeană",
    "cetățene": "cetățeană",
    "cetățenei": "cetățeană",
    "cetățenele": "cetățeană",
    "cetățenelor": "cetățeană",
    "cetățeneasca": "cetățenesc",
    "cetățenească": "cetățenesc",
    "cetățeneasco": "cetățenesc",
    "cetățenescul": "cetățenesc",
    "cetățenescule": "cetățenesc",
    "cetățenescului": "cetățenesc",
    "cetățenești": "cetățenesc",
    "cetățeneștii": "cetățenesc",
    "cetățeneștile": "cetățenesc",
    "cetățeneștilor": "cetățenesc",
    "cetățenia": "cetățenie",
    "cetățeniei": "cetățenie",
    "cetățenii": "cetățenie",
    "cetățeniile": "cetățenie",
    "cetățeniilor": "cetățenie",
    "cetățenio": "cetățenie",
    "cetățui": "cetățuie",
    "cetățuia": "cetățuie",
    "cetățuii": "cetățuie",
    "cetățuile": "cetățuie",
    "cetățuilor": "cetățuie",
    "cetățuio": "cetățuie",
    "cetera": "ceteră",
    "ceteri": "ceteră",
    "ceterii": "ceteră",
    "ceterile": "ceteră",
    "ceterilor": "ceteră",
    "cetero": "ceteră",
    "ceterași": "ceteraș",
    "ceterașii": "ceteraș",
    "ceterașilor": "ceteraș",
    "ceterașul": "ceteraș",
    "ceterașule": "ceteraș",
    "ceterașului": "ceteraș",
    "cetina": "cetină",
    "cetini": "cetină",
    "cetinii": "cetină",
    "cetinile": "cetină",
    "cetinilor": "cetină",
    "cetino": "cetină",
    "cetinița": "cetiniță",
    "cetinițe": "cetiniță",
    "cetiniței": "cetiniță",
    "cetinițele": "cetiniță",
    "cetinițelor": "cetiniță",
    "cetinițo": "cetiniță",
    "cetioara": "cetioară",
    "cetioare": "cetioară",
    "cetioarei": "cetioară",
    "cetioarele": "cetioară",
    "cetioarelor": "cetioară",
    "cetioaro": "cetioară",
    "cetitoarea": "cetitoare",
    "cetitoarei": "cetitoare",
    "cetitoarele": "cetitoare",
    "cetitoarelor": "cetitoare",
    "cetitoareo": "cetitoare",
    "cetitori": "cetitor",
    "cetitorii": "cetitor",
    "cetitorilor": "cetitor",
    "cetitorul": "cetitor",
    "cetitorule": "cetitor",
    "cetitorului": "cetitor",
    "cetluia": "cetlui",
    "cetluiai": "cetlui",
    "cetluiam": "cetlui",
    "cetluiască": "cetlui",
    "cetluiați": "cetlui",
    "cetluiau": "cetlui",
    "cetluiesc": "cetlui",
    "cetluiește": "cetlui",
    "cetluiești": "cetlui",
    "cetluii": "cetlui",
    "cetluim": "cetlui",
    "cetluind": "cetlui",
    "cetluindu": "cetlui",
    "cetluiră": "cetlui",
    "cetluirăm": "cetlui",
    "cetluirăți": "cetlui",
    "cetluise": "cetlui",
    "cetluisem": "cetlui",
    "cetluiseră": "cetlui",
    "cetluiserăm": "cetlui",
    "cetluiserăți": "cetlui",
    "cetluiseși": "cetlui",
    "cetluiși": "cetlui",
    "cetluit": "cetlui",
    "cetluiți": "cetlui",
    "cetluitu": "cetlui",
    "necetluind": "cetlui",
    "necetluindu": "cetlui",
    "nemaicetluind": "cetlui",
    "nemaicetluindu": "cetlui",
    "cetluită": "cetluit",
    "cetluite": "cetluit",
    "cetluiți": "cetluit",
    "cetona": "cetonă",
    "cetone": "cetonă",
    "cetonei": "cetonă",
    "cetonele": "cetonă",
    "cetonelor": "cetonă",
    "cetono": "cetonă",
    "cețoasa": "cețos",
    "cețoasă": "cețos",
    "cețoase": "cețos",
    "cețoasei": "cețos",
    "cețoasele": "cețos",
    "cețoaselor": "cețos",
    "cețoaso": "cețos",
    "cețoși": "cețos",
    "cețoșii": "cețos",
    "cețoșilor": "cețos",
    "cețosul": "cețos",
    "cețosule": "cețos",
    "cețosului": "cețos",
    "Ceylonul": "Ceylon",
    "cezari": "cezar",
    "cezarii": "cezar",
    "cezarilor": "cezar",
    "cezarul": "cezar",
    "cezarule": "cezar",
    "cezarului": "cezar",
    "cezariana": "cezarian",
    "cezariană": "cezarian",
    "cezariano": "cezarian",
    "cezarianul": "cezarian",
    "cezarianule": "cezarian",
    "cezarianului": "cezarian",
    "cezariene": "cezarian",
    "cezarienei": "cezarian",
    "cezarienele": "cezarian",
    "cezarienelor": "cezarian",
    "cezarieni": "cezarian",
    "cezarienii": "cezarian",
    "cezarienilor": "cezarian",
    "cezariana": "cezariană",
    "cezariane": "cezariană",
    "cezarianei": "cezariană",
    "cezarianele": "cezariană",
    "cezarianelor": "cezariană",
    "cezariano": "cezariană",
    "cezura": "cezură",
    "cezuri": "cezură",
    "cezurii": "cezură",
    "cezurile": "cezură",
    "cezurilor": "cezură",
    "cezuro": "cezură",
    "Ch.": "Charles",
    "cheagul": "cheag",
    "cheagule": "cheag",
    "cheagului": "cheag",
    "cheaguri": "cheag",
    "cheagurile": "cheag",
    "cheagurilor": "cheag",
    "chebapul": "chebap",
    "chebapule": "chebap",
    "chebapului": "chebap",
    "chebapuri": "chebap",
    "chebapurile": "chebap",
    "chebapurilor": "chebap",
    "cheful": "chef",
    "chefule": "chef",
    "chefului": "chef",
    "chefuri": "chef",
    "chefurile": "chef",
    "chefurilor": "chef",
    "chefali": "chefal",
    "chefalii": "chefal",
    "chefalilor": "chefal",
    "chefalul": "chefal",
    "chefalule": "chefal",
    "chefalului": "chefal",
    "cheflia": "chefliu",
    "cheflie": "chefliu",
    "chefliei": "chefliu",
    "cheflii": "chefliu",
    "chefliii": "chefliu",
    "chefliile": "chefliu",
    "chefliilor": "chefliu",
    "cheflio": "chefliu",
    "chefliul": "chefliu",
    "chefliule": "chefliu",
    "chefliului": "chefliu",
    "chefuia": "chefui",
    "chefuiai": "chefui",
    "chefuiam": "chefui",
    "chefuiască": "chefui",
    "chefuiați": "chefui",
    "chefuiau": "chefui",
    "chefuiesc": "chefui",
    "chefuiește": "chefui",
    "chefuiești": "chefui",
    "chefuii": "chefui",
    "chefuim": "chefui",
    "chefuind": "chefui",
    "chefuindu": "chefui",
    "chefuiră": "chefui",
    "chefuirăm": "chefui",
    "chefuirăți": "chefui",
    "chefuise": "chefui",
    "chefuisem": "chefui",
    "chefuiseră": "chefui",
    "chefuiserăm": "chefui",
    "chefuiserăți": "chefui",
    "chefuiseși": "chefui",
    "chefuiși": "chefui",
    "chefuit": "chefui",
    "chefuiți": "chefui",
    "chefuitu": "chefui",
    "nechefuind": "chefui",
    "nechefuindu": "chefui",
    "nemaichefuind": "chefui",
    "nemaichefuindu": "chefui",
    "chefuită": "chefuit",
    "chefuite": "chefuit",
    "chefuiți": "chefuit",
    "cheiul": "chei",
    "cheiule": "chei",
    "cheiului": "chei",
    "cheiuri": "chei",
    "cheiurile": "chei",
    "cheiurilor": "chei",
    "Cheiei": "Cheia",
    "Cheii": "Cheia",
    "chei": "cheie",
    "cheia": "cheie",
    "cheii": "cheie",
    "cheile": "cheie",
    "cheilor": "cheie",
    "cheio": "cheie",
    "cheița": "cheiță",
    "cheițe": "cheiță",
    "cheiței": "cheiță",
    "cheițele": "cheiță",
    "cheițelor": "cheiță",
    "cheițo": "cheiță",
    "cheala": "chel",
    "cheală": "chel",
    "chealo": "chel",
    "chei": "chel",
    "cheii": "chel",
    "cheilor": "chel",
    "chele": "chel",
    "chelei": "chel",
    "chelele": "chel",
    "chelelor": "chel",
    "chelul": "chel",
    "chelule": "chel",
    "chelului": "chel",
    "chelălăia": "chelălăi",
    "chelălăiai": "chelălăi",
    "chelălăiam": "chelălăi",
    "chelălăiați": "chelălăi",
    "chelălăiau": "chelălăi",
    "chelălăie": "chelălăi",
    "chelălăii": "chelălăi",
    "chelălăim": "chelălăi",
    "chelălăind": "chelălăi",
    "chelălăindu": "chelălăi",
    "chelălăiră": "chelălăi",
    "chelălăirăm": "chelălăi",
    "chelălăirăți": "chelălăi",
    "chelălăise": "chelălăi",
    "chelălăisem": "chelălăi",
    "chelălăiseră": "chelălăi",
    "chelălăiserăm": "chelălăi",
    "chelălăiserăți": "chelălăi",
    "chelălăiseși": "chelălăi",
    "chelălăiși": "chelălăi",
    "chelălăit": "chelălăi",
    "chelălăiți": "chelălăi",
    "chelălăitu": "chelălăi",
    "nechelălăind": "chelălăi",
    "nechelălăindu": "chelălăi",
    "nemaichelălăind": "chelălăi",
    "nemaichelălăindu": "chelălăi",
    "chelălăita": "chelălăit",
    "chelălăită": "chelălăit",
    "chelălăite": "chelălăit",
    "chelălăitei": "chelălăit",
    "chelălăitele": "chelălăit",
    "chelălăitelor": "chelălăit",
    "chelălăiți": "chelălăit",
    "chelălăiții": "chelălăit",
    "chelălăiților": "chelălăit",
    "chelălăito": "chelălăit",
    "chelălăitul": "chelălăit",
    "chelălăitule": "chelălăit",
    "chelălăitului": "chelălăit",
    "chelălăitura": "chelălăitură",
    "chelălăituri": "chelălăitură",
    "chelălăiturii": "chelălăitură",
    "chelălăiturile": "chelălăitură",
    "chelălăiturilor": "chelălăitură",
    "chelălăituro": "chelălăitură",
    "chelari": "chelar",
    "chelarii": "chelar",
    "chelarilor": "chelar",
    "chelarul": "chelar",
    "chelarule": "chelar",
    "chelarului": "chelar",
    "chelăreasa": "chelăreasă",
    "chelăreaso": "chelăreasă",
    "chelărese": "chelăreasă",
    "chelăresei": "chelăreasă",
    "chelăresele": "chelăreasă",
    "chelăreselor": "chelăreasă",
    "chelărița": "chelăriță",
    "chelărițe": "chelăriță",
    "chelăriței": "chelăriță",
    "chelărițele": "chelăriță",
    "chelărițelor": "chelăriță",
    "chelărițo": "chelăriță",
    "chelfăneala": "chelfăneală",
    "chelfănealo": "chelfăneală",
    "chelfăneli": "chelfăneală",
    "chelfănelii": "chelfăneală",
    "chelfănelile": "chelfăneală",
    "chelfănelilor": "chelfăneală",
    "chelfănea": "chelfăni",
    "chelfăneai": "chelfăni",
    "chelfăneam": "chelfăni",
    "chelfănească": "chelfăni",
    "chelfăneați": "chelfăni",
    "chelfăneau": "chelfăni",
    "chelfănesc": "chelfăni",
    "chelfănește": "chelfăni",
    "chelfănești": "chelfăni",
    "chelfănii": "chelfăni",
    "chelfănim": "chelfăni",
    "chelfănind": "chelfăni",
    "chelfănindu": "chelfăni",
    "chelfăniră": "chelfăni",
    "chelfănirăm": "chelfăni",
    "chelfănirăți": "chelfăni",
    "chelfănise": "chelfăni",
    "chelfănisem": "chelfăni",
    "chelfăniseră": "chelfăni",
    "chelfăniserăm": "chelfăni",
    "chelfăniserăți": "chelfăni",
    "chelfăniseși": "chelfăni",
    "chelfăniși": "chelfăni",
    "chelfănit": "chelfăni",
    "chelfăniți": "chelfăni",
    "chelfănitu": "chelfăni",
    "nechelfănind": "chelfăni",
    "nechelfănindu": "chelfăni",
    "nemaichelfănind": "chelfăni",
    "nemaichelfănindu": "chelfăni",
    "chelfănită": "chelfănit",
    "chelfănite": "chelfănit",
    "chelfăniți": "chelfănit",
    "chelea": "cheli",
    "cheleai": "cheli",
    "cheleam": "cheli",
    "chelească": "cheli",
    "cheleați": "cheli",
    "cheleau": "cheli",
    "chelesc": "cheli",
    "chelește": "cheli",
    "chelești": "cheli",
    "chelii": "cheli",
    "chelim": "cheli",
    "chelind": "cheli",
    "chelindu": "cheli",
    "cheliră": "cheli",
    "chelirăm": "cheli",
    "chelirăți": "cheli",
    "chelise": "cheli",
    "chelisem": "cheli",
    "cheliseră": "cheli",
    "cheliserăm": "cheli",
    "cheliserăți": "cheli",
    "cheliseși": "cheli",
    "cheliși": "cheli",
    "chelit": "cheli",
    "cheliți": "cheli",
    "chelitu": "cheli",
    "nechelind": "cheli",
    "nechelindu": "cheli",
    "nemaichelind": "cheli",
    "nemaichelindu": "cheli",
    "chelia": "chelie",
    "cheliei": "chelie",
    "chelii": "chelie",
    "cheliile": "chelie",
    "cheliilor": "chelie",
    "chelio": "chelie",
    "chelită": "chelit",
    "chelite": "chelit",
    "cheliți": "chelit",
    "chelnăr": "chelner",
    "chelneri": "chelner",
    "chelnerii": "chelner",
    "chelnerilor": "chelner",
    "chelnerul": "chelner",
    "chelnerule": "chelner",
    "chelnerului": "chelner",
    "chelnerița": "chelneriță",
    "chelnerițe": "chelneriță",
    "chelneriței": "chelneriță",
    "chelnerițele": "chelneriță",
    "chelnerițelor": "chelneriță",
    "chelnerițo": "chelneriță",
    "chelonianul": "chelonian",
    "chelonianule": "chelonian",
    "chelonianului": "chelonian",
    "chelonieni": "chelonian",
    "chelonienii": "chelonian",
    "chelonienilor": "chelonian",
    "cheltuia": "cheltui",
    "cheltuiai": "cheltui",
    "cheltuiam": "cheltui",
    "cheltuiască": "cheltui",
    "cheltuiați": "cheltui",
    "cheltuiau": "cheltui",
    "cheltuie": "cheltui",
    "cheltuiesc": "cheltui",
    "cheltuiește": "cheltui",
    "cheltuiești": "cheltui",
    "cheltuii": "cheltui",
    "cheltuim": "cheltui",
    "cheltuind": "cheltui",
    "cheltuindu": "cheltui",
    "cheltuiră": "cheltui",
    "cheltuirăm": "cheltui",
    "cheltuirăți": "cheltui",
    "cheltuise": "cheltui",
    "cheltuisem": "cheltui",
    "cheltuiseră": "cheltui",
    "cheltuiserăm": "cheltui",
    "cheltuiserăți": "cheltui",
    "cheltuiseși": "cheltui",
    "cheltuiși": "cheltui",
    "cheltuit": "cheltui",
    "cheltuiți": "cheltui",
    "cheltuitu": "cheltui",
    "necheltuind": "cheltui",
    "necheltuindu": "cheltui",
    "nemaicheltuind": "cheltui",
    "nemaicheltuindu": "cheltui",
    "cheltuiala": "cheltuială",
    "cheltuialo": "cheltuială",
    "cheltuieli": "cheltuială",
    "cheltuielii": "cheltuială",
    "cheltuielile": "cheltuială",
    "cheltuielilor": "cheltuială",
    "cheltuirea": "cheltuire",
    "cheltuireo": "cheltuire",
    "cheltuiri": "cheltuire",
    "cheltuirii": "cheltuire",
    "cheltuirile": "cheltuire",
    "cheltuirilor": "cheltuire",
    "cheltuită": "cheltuit",
    "cheltuite": "cheltuit",
    "cheltuiți": "cheltuit",
    "cheltuitoare": "cheltuitor",
    "cheltuitoarea": "cheltuitor",
    "cheltuitoarei": "cheltuitor",
    "cheltuitoarele": "cheltuitor",
    "cheltuitoarelor": "cheltuitor",
    "cheltuitori": "cheltuitor",
    "cheltuitorii": "cheltuitor",
    "cheltuitorilor": "cheltuitor",
    "cheltuitorul": "cheltuitor",
    "cheltuitorului": "cheltuitor",
    "cheamă": "chema",
    "chem": "chema",
    "chemă": "chema",
    "chemai": "chema",
    "chemam": "chema",
    "chemăm": "chema",
    "chemând": "chema",
    "chemându": "chema",
    "chemară": "chema",
    "chemarăm": "chema",
    "chemarăți": "chema",
    "chemase": "chema",
    "chemasem": "chema",
    "chemaseră": "chema",
    "chemaserăm": "chema",
    "chemaserăți": "chema",
    "chemaseși": "chema",
    "chemași": "chema",
    "chemat": "chema",
    "chemați": "chema",
    "chematu": "chema",
    "chemau": "chema",
    "cheme": "chema",
    "chemi": "chema",
    "nechemând": "chema",
    "nechemându": "chema",
    "nemaichemând": "chema",
    "nemaichemându": "chema",
    "chemarea": "chemare",
    "chemareo": "chemare",
    "chemări": "chemare",
    "chemării": "chemare",
    "chemările": "chemare",
    "chemărilor": "chemare",
    "chemata": "chemat",
    "chemată": "chemat",
    "chemate": "chemat",
    "chematei": "chemat",
    "chematele": "chemat",
    "chematelor": "chemat",
    "chemați": "chemat",
    "chemații": "chemat",
    "chemaților": "chemat",
    "chemato": "chemat",
    "chematul": "chemat",
    "chematule": "chemat",
    "chematului": "chemat",
    "chemătoare": "chemător",
    "chemătoarea": "chemător",
    "chemătoarei": "chemător",
    "chemătoarele": "chemător",
    "chemătoarelor": "chemător",
    "chemătoareo": "chemător",
    "chemători": "chemător",
    "chemătorii": "chemător",
    "chemătorilor": "chemător",
    "chemătorul": "chemător",
    "chemătorule": "chemător",
    "chemătorului": "chemător",
    "chemoluminiscența": "chemoluminiscență",
    "chemoluminiscențe": "chemoluminiscență",
    "chemoluminiscenței": "chemoluminiscență",
    "chemoluminiscențele": "chemoluminiscență",
    "chemoluminiscențelor": "chemoluminiscență",
    "chemoluminiscențo": "chemoluminiscență",
    "chemoterapia": "chemoterapie",
    "chemoterapiei": "chemoterapie",
    "chemoterapii": "chemoterapie",
    "chemoterapiile": "chemoterapie",
    "chemoterapiilor": "chemoterapie",
    "chemoterapio": "chemoterapie",
    "chenare": "chenar",
    "chenarele": "chenar",
    "chenarelor": "chenar",
    "chenarul": "chenar",
    "chenarule": "chenar",
    "chenarului": "chenar",
    "chenărașe": "chenăraș",
    "chenărașele": "chenăraș",
    "chenărașelor": "chenăraș",
    "chenărașul": "chenăraș",
    "chenărașule": "chenăraș",
    "chenărașului": "chenăraș",
    "chenzina": "chenzină",
    "chenzine": "chenzină",
    "chenzinei": "chenzină",
    "chenzinele": "chenzină",
    "chenzinelor": "chenzină",
    "chenzino": "chenzină",
    "cheotoarea": "cheotoare",
    "cheotoareo": "cheotoare",
    "cheotori": "cheotoare",
    "cheotorii": "cheotoare",
    "cheotorile": "cheotoare",
    "cheotorilor": "cheotoare",
    "chepengul": "chepeng",
    "chepengule": "chepeng",
    "chepengului": "chepeng",
    "chepenguri": "chepeng",
    "chepengurile": "chepeng",
    "chepengurilor": "chepeng",
    "cheratina": "cheratină",
    "cheratine": "cheratină",
    "cheratinei": "cheratină",
    "cheratinele": "cheratină",
    "cheratinelor": "cheratină",
    "cheratino": "cheratină",
    "cherchelita": "cherchelit",
    "cherchelită": "cherchelit",
    "cherchelite": "cherchelit",
    "cherchelitei": "cherchelit",
    "cherchelitele": "cherchelit",
    "cherchelitelor": "cherchelit",
    "chercheliți": "cherchelit",
    "chercheliții": "cherchelit",
    "chercheliților": "cherchelit",
    "cherchelito": "cherchelit",
    "cherchelitul": "cherchelit",
    "cherchelitule": "cherchelit",
    "cherchelitului": "cherchelit",
    "cheremul": "cherem",
    "cheremule": "cherem",
    "cheremului": "cherem",
    "cheresteao": "cherestea",
    "cheresteaua": "cherestea",
    "cherestele": "cherestea",
    "cherestelei": "cherestea",
    "cherestelele": "cherestea",
    "cherestelelor": "cherestea",
    "cherhanale": "cherhana",
    "cherhanalei": "cherhana",
    "cherhanalele": "cherhana",
    "cherhanalelor": "cherhana",
    "cherhanao": "cherhana",
    "cherhanaua": "cherhana",
    "chermesa": "chermesă",
    "chermese": "chermesă",
    "chermesei": "chermesă",
    "chermesele": "chermesă",
    "chermeselor": "chermesă",
    "chermeso": "chermesă",
    "cherpedine": "cherpedin",
    "cherpedinele": "cherpedin",
    "cherpedinelor": "cherpedin",
    "cherpedinul": "cherpedin",
    "cherpedinule": "cherpedin",
    "cherpedinului": "cherpedin",
    "chervane": "chervan",
    "chervanele": "chervan",
    "chervanelor": "chervan",
    "chervanul": "chervan",
    "chervanule": "chervan",
    "chervanului": "chervan",
    "cheseao": "chesea",
    "cheseaua": "chesea",
    "chesele": "chesea",
    "cheselei": "chesea",
    "cheselele": "chesea",
    "cheselelor": "chesea",
    "chesoane": "cheson",
    "chesoanele": "cheson",
    "chesoanelor": "cheson",
    "chesonul": "cheson",
    "chesonule": "cheson",
    "chesonului": "cheson",
    "chesonieri": "chesonier",
    "chesonierii": "chesonier",
    "chesonierilor": "chesonier",
    "chesonierul": "chesonier",
    "chesonierule": "chesonier",
    "chesonierului": "chesonier",
    "chesoniera": "chesonieră",
    "chesoniere": "chesonieră",
    "chesonierei": "chesonieră",
    "chesonierele": "chesonieră",
    "chesonierelor": "chesonieră",
    "chesoniero": "chesonieră",
    "chestia": "chestie",
    "chestiei": "chestie",
    "chestii": "chestie",
    "chestiile": "chestie",
    "chestiilor": "chestie",
    "chestio": "chestie",
    "chestionă": "chestiona",
    "chestionai": "chestiona",
    "chestionam": "chestiona",
    "chestionăm": "chestiona",
    "chestionând": "chestiona",
    "chestionându": "chestiona",
    "chestionară": "chestiona",
    "chestionarăm": "chestiona",
    "chestionarăți": "chestiona",
    "chestionase": "chestiona",
    "chestionasem": "chestiona",
    "chestionaseră": "chestiona",
    "chestionaserăm": "chestiona",
    "chestionaserăți": "chestiona",
    "chestionaseși": "chestiona",
    "chestionași": "chestiona",
    "chestionat": "chestiona",
    "chestionați": "chestiona",
    "chestionatu": "chestiona",
    "chestionau": "chestiona",
    "chestionează": "chestiona",
    "chestionez": "chestiona",
    "chestioneze": "chestiona",
    "chestionezi": "chestiona",
    "nechestionând": "chestiona",
    "nechestionându": "chestiona",
    "nemaichestionând": "chestiona",
    "nemaichestionându": "chestiona",
    "chestionare": "chestionar",
    "chestionarele": "chestionar",
    "chestionarelor": "chestionar",
    "chestionarul": "chestionar",
    "chestionarule": "chestionar",
    "chestionarului": "chestionar",
    "chestionarea": "chestionare",
    "chestionareo": "chestionare",
    "chestionări": "chestionare",
    "chestionării": "chestionare",
    "chestionările": "chestionare",
    "chestionărilor": "chestionare",
    "chestionată": "chestionat",
    "chestionate": "chestionat",
    "chestionați": "chestionat",
    "chestiunea": "chestiune",
    "chestiuneo": "chestiune",
    "chestiuni": "chestiune",
    "chestiunii": "chestiune",
    "chestiunile": "chestiune",
    "chestiunilor": "chestiune",
    "chestori": "chestor",
    "chestorii": "chestor",
    "chestorilor": "chestor",
    "chestorul": "chestor",
    "chestorule": "chestor",
    "chestorului": "chestor",
    "chestura": "chestură",
    "chesturi": "chestură",
    "chesturii": "chestură",
    "chesturile": "chestură",
    "chesturilor": "chestură",
    "chesturo": "chestură",
    "cheta": "chetă",
    "chete": "chetă",
    "chetei": "chetă",
    "chetele": "chetă",
    "chetelor": "chetă",
    "cheto": "chetă",
    "cheutoarea": "cheutoare",
    "cheutoareo": "cheutoare",
    "cheutori": "cheutoare",
    "cheutorii": "cheutoare",
    "cheutorile": "cheutoare",
    "cheutorilor": "cheutoare",
    "chezași": "chezaș",
    "chezașii": "chezaș",
    "chezașilor": "chezaș",
    "chezașul": "chezaș",
    "chezașule": "chezaș",
    "chezașului": "chezaș",
    "chezașa": "chezașă",
    "chezașe": "chezașă",
    "chezașei": "chezașă",
    "chezașele": "chezașă",
    "chezașelor": "chezașă",
    "chezașo": "chezașă",
    "chezășia": "chezășie",
    "chezășiei": "chezășie",
    "chezășii": "chezășie",
    "chezășiile": "chezășie",
    "chezășiilor": "chezășie",
    "chezășio": "chezășie",
    "chezășuia": "chezășui",
    "chezășuiai": "chezășui",
    "chezășuiam": "chezășui",
    "chezășuiască": "chezășui",
    "chezășuiați": "chezășui",
    "chezășuiau": "chezășui",
    "chezășuiesc": "chezășui",
    "chezășuiește": "chezășui",
    "chezășuiești": "chezășui",
    "chezășuii": "chezășui",
    "chezășuim": "chezășui",
    "chezășuind": "chezășui",
    "chezășuindu": "chezășui",
    "chezășuiră": "chezășui",
    "chezășuirăm": "chezășui",
    "chezășuirăți": "chezășui",
    "chezășuise": "chezășui",
    "chezășuisem": "chezășui",
    "chezășuiseră": "chezășui",
    "chezășuiserăm": "chezășui",
    "chezășuiserăți": "chezășui",
    "chezășuiseși": "chezășui",
    "chezășuiși": "chezășui",
    "chezășuit": "chezășui",
    "chezășuiți": "chezășui",
    "chezășuitu": "chezășui",
    "nechezășuind": "chezășui",
    "nechezășuindu": "chezășui",
    "nemaichezășuind": "chezășui",
    "nemaichezășuindu": "chezășui",
    "chezășuirea": "chezășuire",
    "chezășuireo": "chezășuire",
    "chezășuiri": "chezășuire",
    "chezășuirii": "chezășuire",
    "chezășuirile": "chezășuire",
    "chezășuirilor": "chezășuire",
    "chezășuită": "chezășuit",
    "chezășuite": "chezășuit",
    "chezășuiți": "chezășuit",
    "chiaburi": "chiabur",
    "chiaburii": "chiabur",
    "chiaburilor": "chiabur",
    "chiaburul": "chiabur",
    "chiaburule": "chiabur",
    "chiaburului": "chiabur",
    "chiaburași": "chiaburaș",
    "chiaburașii": "chiaburaș",
    "chiaburașilor": "chiaburaș",
    "chiaburașul": "chiaburaș",
    "chiaburașule": "chiaburaș",
    "chiaburașului": "chiaburaș",
    "chiabureasca": "chiaburesc",
    "chiaburească": "chiaburesc",
    "chiabureasco": "chiaburesc",
    "chiaburescul": "chiaburesc",
    "chiaburescule": "chiaburesc",
    "chiaburescului": "chiaburesc",
    "chiaburești": "chiaburesc",
    "chiabureștii": "chiaburesc",
    "chiabureștile": "chiaburesc",
    "chiabureștilor": "chiaburesc",
    "chiaburea": "chiaburi",
    "chiabureai": "chiaburi",
    "chiabuream": "chiaburi",
    "chiaburească": "chiaburi",
    "chiabureați": "chiaburi",
    "chiabureau": "chiaburi",
    "chiaburesc": "chiaburi",
    "chiaburește": "chiaburi",
    "chiaburești": "chiaburi",
    "chiaburii": "chiaburi",
    "chiaburim": "chiaburi",
    "chiaburind": "chiaburi",
    "chiaburindu": "chiaburi",
    "chiaburiră": "chiaburi",
    "chiaburirăm": "chiaburi",
    "chiaburirăți": "chiaburi",
    "chiaburise": "chiaburi",
    "chiaburisem": "chiaburi",
    "chiaburiseră": "chiaburi",
    "chiaburiserăm": "chiaburi",
    "chiaburiserăți": "chiaburi",
    "chiaburiseși": "chiaburi",
    "chiaburit": "chiaburi",
    "chiaburiți": "chiaburi",
    "chiaburitu": "chiaburi",
    "nechiaburind": "chiaburi",
    "nechiaburindu": "chiaburi",
    "nemaichiaburind": "chiaburi",
    "nemaichiaburindu": "chiaburi",
    "chiaburimea": "chiaburime",
    "chiaburimeo": "chiaburime",
    "chiaburimi": "chiaburime",
    "chiaburimii": "chiaburime",
    "chiaburimile": "chiaburime",
    "chiaburimilor": "chiaburime",
    "chiaburită": "chiaburit",
    "chiaburite": "chiaburit",
    "chiaburiți": "chiaburit",
    "chiaburoaica": "chiaburoaică",
    "chiaburoaice": "chiaburoaică",
    "chiaburoaicei": "chiaburoaică",
    "chiaburoaicele": "chiaburoaică",
    "chiaburoaicelor": "chiaburoaică",
    "chiaburoaico": "chiaburoaică",
    "chiaburoii": "chiaburoi",
    "chiaburoilor": "chiaburoi",
    "chiaburoiul": "chiaburoi",
    "chiaburoiule": "chiaburoi",
    "chiaburoiului": "chiaburoi",
    "chibiți": "chibiț",
    "chibiții": "chibiț",
    "chibiților": "chibiț",
    "chibițul": "chibiț",
    "chibițule": "chibiț",
    "chibițului": "chibiț",
    "chibrite": "chibrit",
    "chibritele": "chibrit",
    "chibritelor": "chibrit",
    "chibritul": "chibrit",
    "chibritule": "chibrit",
    "chibritului": "chibrit",
    "chibrituri": "chibrit",
    "chibriturile": "chibrit",
    "chibriturilor": "chibrit",
    "chibzuia": "chibzui",
    "chibzuiai": "chibzui",
    "chibzuiam": "chibzui",
    "chibzuiască": "chibzui",
    "chibzuiați": "chibzui",
    "chibzuiau": "chibzui",
    "chibzuiesc": "chibzui",
    "chibzuiește": "chibzui",
    "chibzuiești": "chibzui",
    "chibzuii": "chibzui",
    "chibzuim": "chibzui",
    "chibzuind": "chibzui",
    "chibzuindu": "chibzui",
    "chibzuiră": "chibzui",
    "chibzuirăm": "chibzui",
    "chibzuirăți": "chibzui",
    "chibzuise": "chibzui",
    "chibzuisem": "chibzui",
    "chibzuiseră": "chibzui",
    "chibzuiserăm": "chibzui",
    "chibzuiserăți": "chibzui",
    "chibzuiseși": "chibzui",
    "chibzuiși": "chibzui",
    "chibzuit": "chibzui",
    "chibzuiți": "chibzui",
    "chibzuitu": "chibzui",
    "nechibzuind": "chibzui",
    "nechibzuindu": "chibzui",
    "nemaichibzuind": "chibzui",
    "nemaichibzuindu": "chibzui",
    "chibzuiala": "chibzuială",
    "chibzuialo": "chibzuială",
    "chibzuieli": "chibzuială",
    "chibzuielii": "chibzuială",
    "chibzuielile": "chibzuială",
    "chibzuielilor": "chibzuială",
    "chibzuința": "chibzuință",
    "chibzuințe": "chibzuință",
    "chibzuinței": "chibzuință",
    "chibzuințele": "chibzuință",
    "chibzuințelor": "chibzuință",
    "chibzuințo": "chibzuință",
    "chibzuirea": "chibzuire",
    "chibzuireo": "chibzuire",
    "chibzuiri": "chibzuire",
    "chibzuirii": "chibzuire",
    "chibzuirile": "chibzuire",
    "chibzuirilor": "chibzuire",
    "chibzuita": "chibzuit",
    "chibzuită": "chibzuit",
    "chibzuite": "chibzuit",
    "chibzuitei": "chibzuit",
    "chibzuitele": "chibzuit",
    "chibzuitelor": "chibzuit",
    "chibzuiți": "chibzuit",
    "chibzuiții": "chibzuit",
    "chibzuiților": "chibzuit",
    "chibzuito": "chibzuit",
    "chibzuitul": "chibzuit",
    "chibzuitule": "chibzuit",
    "chibzuitului": "chibzuit",
    "chica": "chică",
    "chici": "chică",
    "chicii": "chică",
    "chicile": "chică",
    "chicilor": "chică",
    "chico": "chică",
    "chichineața": "chichineață",
    "chichineațo": "chichineață",
    "chichinețe": "chichineață",
    "chichineței": "chichineață",
    "chichinețele": "chichineață",
    "chichinețelor": "chichineață",
    "chichirezul": "chichirez",
    "chichirezule": "chichirez",
    "chichirezului": "chichirez",
    "chichirezuri": "chichirez",
    "chichirezurile": "chichirez",
    "chichirezurilor": "chichirez",
    "chichița": "chichiță",
    "chichițe": "chichiță",
    "chichiței": "chichiță",
    "chichițele": "chichiță",
    "chichițelor": "chichiță",
    "chichițo": "chichiță",
    "chicineta": "chicinetă",
    "chicinete": "chicinetă",
    "chicinetei": "chicinetă",
    "chicinetele": "chicinetă",
    "chicinetelor": "chicinetă",
    "chicineto": "chicinetă",
    "chiciura": "chiciură",
    "chiciuri": "chiciură",
    "chiciurii": "chiciură",
    "chiciurile": "chiciură",
    "chiciurilor": "chiciură",
    "chiciuro": "chiciură",
    "chicote": "chicot",
    "chicotele": "chicot",
    "chicotelor": "chicot",
    "chicotul": "chicot",
    "chicotule": "chicot",
    "chicotului": "chicot",
    "chicoteala": "chicoteală",
    "chicotealo": "chicoteală",
    "chicoteli": "chicoteală",
    "chicotelii": "chicoteală",
    "chicotelile": "chicoteală",
    "chicotelilor": "chicoteală",
    "chicotea": "chicoti",
    "chicoteai": "chicoti",
    "chicoteam": "chicoti",
    "chicotească": "chicoti",
    "chicoteați": "chicoti",
    "chicoteau": "chicoti",
    "chicotesc": "chicoti",
    "chicotește": "chicoti",
    "chicotești": "chicoti",
    "chicotii": "chicoti",
    "chicotim": "chicoti",
    "chicotind": "chicoti",
    "chicotindu": "chicoti",
    "chicotiră": "chicoti",
    "chicotirăm": "chicoti",
    "chicotirăți": "chicoti",
    "chicotise": "chicoti",
    "chicotisem": "chicoti",
    "chicotiseră": "chicoti",
    "chicotiserăm": "chicoti",
    "chicotiserăți": "chicoti",
    "chicotiseși": "chicoti",
    "chicotiși": "chicoti",
    "chicotit": "chicoti",
    "chicotiți": "chicoti",
    "chicotitu": "chicoti",
    "nechicotind": "chicoti",
    "nechicotindu": "chicoti",
    "nemaichicotind": "chicoti",
    "nemaichicotindu": "chicoti",
    "chicotită": "chicotit",
    "chicotite": "chicotit",
    "chicotiți": "chicotit",
    "chicotitul": "chicotit",
    "chicotitule": "chicotit",
    "chicotitului": "chicotit",
    "chicotituri": "chicotit",
    "chicotiturile": "chicotit",
    "chicotiturilor": "chicotit",
    "chiculița": "chiculiță",
    "chiculițe": "chiculiță",
    "chiculiței": "chiculiță",
    "chiculițele": "chiculiță",
    "chiculițelor": "chiculiță",
    "chiculițo": "chiculiță",
    "chicuța": "chicuță",
    "chicuțe": "chicuță",
    "chicuței": "chicuță",
    "chicuțele": "chicuță",
    "chicuțelor": "chicuță",
    "chicuțo": "chicuță",
    "chifla": "chiflă",
    "chifle": "chiflă",
    "chiflei": "chiflă",
    "chiflele": "chiflă",
    "chiflelor": "chiflă",
    "chiflo": "chiflă",
    "chifteao": "chiftea",
    "chifteaua": "chiftea",
    "chiftele": "chiftea",
    "chiftelei": "chiftea",
    "chiftelele": "chiftea",
    "chiftelelor": "chiftea",
    "chifteluța": "chifteluță",
    "chifteluțe": "chifteluță",
    "chifteluței": "chifteluță",
    "chifteluțele": "chifteluță",
    "chifteluțelor": "chifteluță",
    "chifteluțo": "chifteluță",
    "chiftea": "chifti",
    "chifteai": "chifti",
    "chifteam": "chifti",
    "chiftească": "chifti",
    "chifteați": "chifti",
    "chifteau": "chifti",
    "chiftesc": "chifti",
    "chiftește": "chifti",
    "chiftești": "chifti",
    "chiftii": "chifti",
    "chiftim": "chifti",
    "chiftind": "chifti",
    "chiftindu": "chifti",
    "chiftiră": "chifti",
    "chiftirăm": "chifti",
    "chiftirăți": "chifti",
    "chiftise": "chifti",
    "chiftisem": "chifti",
    "chiftiseră": "chifti",
    "chiftiserăm": "chifti",
    "chiftiserăți": "chifti",
    "chiftiseși": "chifti",
    "chiftiși": "chifti",
    "chiftit": "chifti",
    "chiftiți": "chifti",
    "chiftitu": "chifti",
    "nechiftind": "chifti",
    "nechiftindu": "chifti",
    "nemaichiftind": "chifti",
    "nemaichiftindu": "chifti",
    "chiftită": "chiftit",
    "chiftite": "chiftit",
    "chiftiți": "chiftit",
    "chihăia": "chihăi",
    "chihăiai": "chihăi",
    "chihăiam": "chihăi",
    "chihăiască": "chihăi",
    "chihăiați": "chihăi",
    "chihăiau": "chihăi",
    "chihăiesc": "chihăi",
    "chihăiește": "chihăi",
    "chihăiești": "chihăi",
    "chihăii": "chihăi",
    "chihăim": "chihăi",
    "chihăind": "chihăi",
    "chihăindu": "chihăi",
    "chihăiră": "chihăi",
    "chihăirăm": "chihăi",
    "chihăirăți": "chihăi",
    "chihăise": "chihăi",
    "chihăisem": "chihăi",
    "chihăiseră": "chihăi",
    "chihăiserăm": "chihăi",
    "chihăiserăți": "chihăi",
    "chihăiseși": "chihăi",
    "chihăiși": "chihăi",
    "chihăit": "chihăi",
    "chihăiți": "chihăi",
    "chihăitu": "chihăi",
    "nechihăind": "chihăi",
    "nechihăindu": "chihăi",
    "nemaichihăind": "chihăi",
    "nemaichihăindu": "chihăi",
    "chihăită": "chihăit",
    "chihăite": "chihăit",
    "chihăiți": "chihăit",
    "chihlimbare": "chihlimbar",
    "chihlimbarele": "chihlimbar",
    "chihlimbarelor": "chihlimbar",
    "chihlimbarul": "chihlimbar",
    "chihlimbarule": "chihlimbar",
    "chihlimbarului": "chihlimbar",
    "chihlimbaruri": "chihlimbar",
    "chihlimbarurile": "chihlimbar",
    "chihlimbarurilor": "chihlimbar",
    "chihlimbaria": "chihlimbariu",
    "chihlimbarie": "chihlimbariu",
    "chihlimbariei": "chihlimbariu",
    "chihlimbarii": "chihlimbariu",
    "chihlimbariii": "chihlimbariu",
    "chihlimbariile": "chihlimbariu",
    "chihlimbariilor": "chihlimbariu",
    "chihlimbario": "chihlimbariu",
    "chihlimbariul": "chihlimbariu",
    "chihlimbariule": "chihlimbariu",
    "chihlimbariului": "chihlimbariu",
    "chile": "chil",
    "chilele": "chil",
    "chilelor": "chil",
    "chilul": "chil",
    "chilule": "chil",
    "chilului": "chil",
    "chila": "chilă",
    "chile": "chilă",
    "chilei": "chilă",
    "chilele": "chilă",
    "chilelor": "chilă",
    "chilo": "chilă",
    "Chilie": "Chilia",
    "Chiliei": "Chilia",
    "Chilii": "Chilia",
    "chiliana": "chilian",
    "chiliană": "chilian",
    "chiliano": "chilian",
    "chilianul": "chilian",
    "chilianule": "chilian",
    "chilianului": "chilian",
    "chiliene": "chilian",
    "chilienei": "chilian",
    "chilienele": "chilian",
    "chilienelor": "chilian",
    "chilieni": "chilian",
    "chilienii": "chilian",
    "chilienilor": "chilian",
    "chilia": "chilie",
    "chiliei": "chilie",
    "chilii": "chilie",
    "chiliile": "chilie",
    "chiliilor": "chilie",
    "chilio": "chilie",
    "chilimul": "chilim",
    "chilimule": "chilim",
    "chilimului": "chilim",
    "chilimuri": "chilim",
    "chilimurile": "chilim",
    "chilimurilor": "chilim",
    "chilipirul": "chilipir",
    "chilipirule": "chilipir",
    "chilipirului": "chilipir",
    "chilipiruri": "chilipir",
    "chilipirurile": "chilipir",
    "chilipirurilor": "chilipir",
    "chiliuța": "chiliuță",
    "chiliuțe": "chiliuță",
    "chiliuței": "chiliuță",
    "chiliuțele": "chiliuță",
    "chiliuțelor": "chiliuță",
    "chiliuțo": "chiliuță",
    "chilotul": "chilot",
    "chilotule": "chilot",
    "chilotului": "chilot",
    "chiloții": "chiloți",
    "chiloților": "chiloți",
    "chimenul": "chimen",
    "chimenule": "chimen",
    "chimenului": "chimen",
    "chimica": "chimic",
    "chimică": "chimic",
    "chimice": "chimic",
    "chimicei": "chimic",
    "chimicele": "chimic",
    "chimicelor": "chimic",
    "chimici": "chimic",
    "chimicii": "chimic",
    "chimicilor": "chimic",
    "chimico": "chimic",
    "chimicul": "chimic",
    "chimicule": "chimic",
    "chimicului": "chimic",
    "chimicalele": "chimicale",
    "chimicalelor": "chimicale",
    "chim.": "chimie",
    "chimia": "chimie",
    "chimiei": "chimie",
    "chimii": "chimie",
    "chimio": "chimie",
    "chimiluminescența": "chimiluminescență",
    "chimiluminescențe": "chimiluminescență",
    "chimiluminescenței": "chimiluminescență",
    "chimiluminescențele": "chimiluminescență",
    "chimiluminescențelor": "chimiluminescență",
    "chimiluminescențo": "chimiluminescență",
    "chimionul": "chimion",
    "chimionule": "chimion",
    "chimionului": "chimion",
    "chimioterapia": "chimioterapie",
    "chimioterapiei": "chimioterapie",
    "chimioterapii": "chimioterapie",
    "chimioterapiile": "chimioterapie",
    "chimioterapiilor": "chimioterapie",
    "chimioterapio": "chimioterapie",
    "chimire": "chimir",
    "chimirele": "chimir",
    "chimirelor": "chimir",
    "chimirul": "chimir",
    "chimirule": "chimir",
    "chimirului": "chimir",
    "chimirașe": "chimiraș",
    "chimirașele": "chimiraș",
    "chimirașelor": "chimiraș",
    "chimirașul": "chimiraș",
    "chimirașule": "chimiraș",
    "chimirașului": "chimiraș",
    "chimiști": "chimist",
    "chimiștii": "chimist",
    "chimiștilor": "chimist",
    "chimistul": "chimist",
    "chimistule": "chimist",
    "chimistului": "chimist",
    "chimista": "chimistă",
    "chimiste": "chimistă",
    "chimistei": "chimistă",
    "chimistele": "chimistă",
    "chimistelor": "chimistă",
    "chimisto": "chimistă",
    "chimiză": "chimiza",
    "chimizai": "chimiza",
    "chimizam": "chimiza",
    "chimizăm": "chimiza",
    "chimizând": "chimiza",
    "chimizându": "chimiza",
    "chimizară": "chimiza",
    "chimizarăm": "chimiza",
    "chimizarăți": "chimiza",
    "chimizase": "chimiza",
    "chimizasem": "chimiza",
    "chimizaseră": "chimiza",
    "chimizaserăm": "chimiza",
    "chimizaserăți": "chimiza",
    "chimizaseși": "chimiza",
    "chimizași": "chimiza",
    "chimizat": "chimiza",
    "chimizați": "chimiza",
    "chimizatu": "chimiza",
    "chimizau": "chimiza",
    "chimizează": "chimiza",
    "chimizez": "chimiza",
    "chimizeze": "chimiza",
    "chimizezi": "chimiza",
    "nechimizând": "chimiza",
    "nechimizându": "chimiza",
    "nemaichimizând": "chimiza",
    "nemaichimizându": "chimiza",
    "chimizarea": "chimizare",
    "chimizareo": "chimizare",
    "chimizări": "chimizare",
    "chimizării": "chimizare",
    "chimizările": "chimizare",
    "chimizărilor": "chimizare",
    "chimizată": "chimizat",
    "chimizate": "chimizat",
    "chimizați": "chimizat",
    "chimonoul": "chimonou",
    "chimonoule": "chimonou",
    "chimonoului": "chimonou",
    "chimonouri": "chimonou",
    "chimonourile": "chimonou",
    "chimonourilor": "chimonou",
    "chimvale": "chimval",
    "chimvalele": "chimval",
    "chimvalelor": "chimval",
    "chimvalul": "chimval",
    "chimvalule": "chimval",
    "chimvalului": "chimval",
    "chinul": "chin",
    "chinule": "chin",
    "chinului": "chin",
    "chinuri": "chin",
    "chinurile": "chin",
    "chinurilor": "chin",
    "Chină": "China",
    "Chine": "China",
    "Chinei": "China",
    "chindia": "chindie",
    "chindiei": "chindie",
    "chindii": "chindie",
    "chindiile": "chindie",
    "chindiilor": "chindie",
    "chindio": "chindie",
    "chineza": "chinez",
    "chineză": "chinez",
    "chineze": "chinez",
    "chinezei": "chinez",
    "chinezele": "chinez",
    "chinezelor": "chinez",
    "chinezi": "chinez",
    "chinezii": "chinez",
    "chinezilor": "chinez",
    "chinezo": "chinez",
    "chinezul": "chinez",
    "chinezule": "chinez",
    "chinezului": "chinez",
    "chinezăria": "chinezărie",
    "chinezăriei": "chinezărie",
    "chinezării": "chinezărie",
    "chinezăriile": "chinezărie",
    "chinezăriilor": "chinezărie",
    "chinezărio": "chinezărie",
    "chinezeasca": "chinezesc",
    "chinezească": "chinezesc",
    "chinezeasco": "chinezesc",
    "chinezescul": "chinezesc",
    "chinezescule": "chinezesc",
    "chinezescului": "chinezesc",
    "chinezești": "chinezesc",
    "chinezeștii": "chinezesc",
    "chinezeștile": "chinezesc",
    "chinezeștilor": "chinezesc",
    "chinezoaica": "chinezoaică",
    "chinezoaice": "chinezoaică",
    "chinezoaicei": "chinezoaică",
    "chinezoaicele": "chinezoaică",
    "chinezoaicelor": "chinezoaică",
    "chinezoaico": "chinezoaică",
    "chinga": "chingă",
    "chingi": "chingă",
    "chingii": "chingă",
    "chingile": "chingă",
    "chingilor": "chingă",
    "chingo": "chingă",
    "chingulița": "chinguliță",
    "chingulițe": "chinguliță",
    "chinguliței": "chinguliță",
    "chingulițele": "chinguliță",
    "chingulițelor": "chinguliță",
    "chingulițo": "chinguliță",
    "chinguța": "chinguță",
    "chinguțe": "chinguță",
    "chinguței": "chinguță",
    "chinguțele": "chinguță",
    "chinguțelor": "chinguță",
    "chinguțo": "chinguță",
    "chinina": "chinină",
    "chinine": "chinină",
    "chininei": "chinină",
    "chininele": "chinină",
    "chininelor": "chinină",
    "chinino": "chinină",
    "chinologia": "chinologie",
    "chinologiei": "chinologie",
    "chinologii": "chinologie",
    "chinologio": "chinologie",
    "chinotehnia": "chinotehnie",
    "chinotehniei": "chinotehnie",
    "chinotehnii": "chinotehnie",
    "chinotehnio": "chinotehnie",
    "chinovia": "chinovie",
    "chinoviei": "chinovie",
    "chinovii": "chinovie",
    "chinoviile": "chinovie",
    "chinoviilor": "chinovie",
    "chinovio": "chinovie",
    "chintale": "chintal",
    "chintalele": "chintal",
    "chintalelor": "chintal",
    "chintalul": "chintal",
    "chintalule": "chintal",
    "chintalului": "chintal",
    "chintesența": "chintesență",
    "chintesențe": "chintesență",
    "chintesenței": "chintesență",
    "chintesențele": "chintesență",
    "chintesențelor": "chintesență",
    "chintesențo": "chintesență",
    "chinuia": "chinui",
    "chinuiai": "chinui",
    "chinuiam": "chinui",
    "chinuiască": "chinui",
    "chinuiați": "chinui",
    "chinuiau": "chinui",
    "chinuie": "chinui",
    "chinuiesc": "chinui",
    "chinuiește": "chinui",
    "chinuiești": "chinui",
    "chinuii": "chinui",
    "chinuim": "chinui",
    "chinuind": "chinui",
    "chinuindu": "chinui",
    "chinuiră": "chinui",
    "chinuirăm": "chinui",
    "chinuirăți": "chinui",
    "chinuise": "chinui",
    "chinuisem": "chinui",
    "chinuiseră": "chinui",
    "chinuiserăm": "chinui",
    "chinuiserăți": "chinui",
    "chinuiseși": "chinui",
    "chinuiși": "chinui",
    "chinuit": "chinui",
    "chinuiți": "chinui",
    "chinuitu": "chinui",
    "nechinuind": "chinui",
    "nechinuindu": "chinui",
    "nemaichinuind": "chinui",
    "nemaichinuindu": "chinui",
    "chinuiala": "chinuială",
    "chinuialo": "chinuială",
    "chinuieli": "chinuială",
    "chinuielii": "chinuială",
    "chinuielile": "chinuială",
    "chinuielilor": "chinuială",
    "chinuirea": "chinuire",
    "chinuireo": "chinuire",
    "chinuiri": "chinuire",
    "chinuirii": "chinuire",
    "chinuirile": "chinuire",
    "chinuirilor": "chinuire",
    "chinuita": "chinuit",
    "chinuită": "chinuit",
    "chinuite": "chinuit",
    "chinuitei": "chinuit",
    "chinuitele": "chinuit",
    "chinuitelor": "chinuit",
    "chinuiți": "chinuit",
    "chinuiții": "chinuit",
    "chinuiților": "chinuit",
    "chinuito": "chinuit",
    "chinuitul": "chinuit",
    "chinuitule": "chinuit",
    "chinuitului": "chinuit",
    "chinuitoare": "chinuitor",
    "chinuitoarea": "chinuitor",
    "chinuitoarei": "chinuitor",
    "chinuitoarele": "chinuitor",
    "chinuitoarelor": "chinuitor",
    "chinuitoareo": "chinuitor",
    "chinuitori": "chinuitor",
    "chinuitorii": "chinuitor",
    "chinuitorilor": "chinuitor",
    "chinuitorul": "chinuitor",
    "chinuitorule": "chinuitor",
    "chinuitorului": "chinuitor",
    "chiolhanul": "chiolhan",
    "chiolhanule": "chiolhan",
    "chiolhanului": "chiolhan",
    "chiolhanuri": "chiolhan",
    "chiolhanurile": "chiolhan",
    "chiolhanurilor": "chiolhan",
    "chioara": "chior",
    "chioară": "chior",
    "chioare": "chior",
    "chioarei": "chior",
    "chioarele": "chior",
    "chioarelor": "chior",
    "chioaro": "chior",
    "chiori": "chior",
    "chiorii": "chior",
    "chiorilor": "chior",
    "chiorul": "chior",
    "chiorule": "chior",
    "chiorului": "chior",
    "chiorăia": "chiorăi",
    "chiorăiai": "chiorăi",
    "chiorăiam": "chiorăi",
    "chiorăiați": "chiorăi",
    "chiorăiau": "chiorăi",
    "chiorăie": "chiorăi",
    "chiorăii": "chiorăi",
    "chiorăim": "chiorăi",
    "chiorăind": "chiorăi",
    "chiorăindu": "chiorăi",
    "chiorăiră": "chiorăi",
    "chiorăirăm": "chiorăi",
    "chiorăirăți": "chiorăi",
    "chiorăise": "chiorăi",
    "chiorăisem": "chiorăi",
    "chiorăiseră": "chiorăi",
    "chiorăiserăm": "chiorăi",
    "chiorăiserăți": "chiorăi",
    "chiorăiseși": "chiorăi",
    "chiorăiși": "chiorăi",
    "chiorăit": "chiorăi",
    "chiorăiți": "chiorăi",
    "chiorăitu": "chiorăi",
    "nechiorăind": "chiorăi",
    "nechiorăindu": "chiorăi",
    "nemaichiorăind": "chiorăi",
    "nemaichiorăindu": "chiorăi",
    "chiorăiala": "chiorăială",
    "chiorăialo": "chiorăială",
    "chiorăieli": "chiorăială",
    "chiorăielii": "chiorăială",
    "chiorăielile": "chiorăială",
    "chiorăielilor": "chiorăială",
    "chiorăită": "chiorăit",
    "chiorăite": "chiorăit",
    "chiorăiți": "chiorăit",
    "chiorăitura": "chiorăitură",
    "chiorăituri": "chiorăitură",
    "chiorăiturii": "chiorăitură",
    "chiorăiturile": "chiorăitură",
    "chiorăiturilor": "chiorăitură",
    "chiorăituro": "chiorăitură",
    "chiorâșa": "chiorâș",
    "chiorâșă": "chiorâș",
    "chiorâșe": "chiorâș",
    "chiorâșei": "chiorâș",
    "chiorâșele": "chiorâș",
    "chiorâșelor": "chiorâș",
    "chiorâși": "chiorâș",
    "chiorâșii": "chiorâș",
    "chiorâșilor": "chiorâș",
    "chiorâșo": "chiorâș",
    "chiorâșul": "chiorâș",
    "chiorâșule": "chiorâș",
    "chiorâșului": "chiorâș",
    "chiorâtă": "chiorât",
    "chiorâte": "chiorât",
    "chiorâți": "chiorât",
    "chiora": "chiorî",
    "chiorai": "chiorî",
    "chiorâi": "chiorî",
    "chioram": "chiorî",
    "chiorâm": "chiorî",
    "chiorând": "chiorî",
    "chiorându": "chiorî",
    "chiorâră": "chiorî",
    "chiorârăm": "chiorî",
    "chiorârăți": "chiorî",
    "chiorăsc": "chiorî",
    "chiorască": "chiorî",
    "chiorâse": "chiorî",
    "chiorâsem": "chiorî",
    "chiorâseră": "chiorî",
    "chiorâserăm": "chiorî",
    "chiorâserăți": "chiorî",
    "chiorâseși": "chiorî",
    "chiorâși": "chiorî",
    "chiorăște": "chiorî",
    "chiorăști": "chiorî",
    "chiorât": "chiorî",
    "chiorați": "chiorî",
    "chiorâți": "chiorî",
    "chiorâtu": "chiorî",
    "chiorau": "chiorî",
    "nechiorând": "chiorî",
    "nechiorându": "chiorî",
    "nemaichiorând": "chiorî",
    "nemaichiorându": "chiorî",
    "chioșcul": "chioșc",
    "chioșcule": "chioșc",
    "chioșcului": "chioșc",
    "chioșcuri": "chioșc",
    "chioșcurile": "chioșc",
    "chioșcurilor": "chioșc",
    "chiote": "chiot",
    "chiotele": "chiot",
    "chiotelor": "chiot",
    "chiotul": "chiot",
    "chiotule": "chiot",
    "chiotului": "chiot",
    "chiotoarea": "chiotoare",
    "chiotoareo": "chiotoare",
    "chiotori": "chiotoare",
    "chiotorii": "chiotoare",
    "chiotorile": "chiotoare",
    "chiotorilor": "chiotoare",
    "chipu": "chip",
    "chipul": "chip",
    "chipule": "chip",
    "chipului": "chip",
    "chipuri": "chip",
    "chipurile": "chip",
    "chipurilor": "chip",
    "chiparoși": "chiparos",
    "chiparoșii": "chiparos",
    "chiparoșilor": "chiparos",
    "chiparosul": "chiparos",
    "chiparosule": "chiparos",
    "chiparosului": "chiparos",
    "chipeșa": "chipeș",
    "chipeșă": "chipeș",
    "chipeșe": "chipeș",
    "chipeșei": "chipeș",
    "chipeșele": "chipeș",
    "chipeșelor": "chipeș",
    "chipeși": "chipeș",
    "chipeșii": "chipeș",
    "chipeșilor": "chipeș",
    "chipeșo": "chipeș",
    "chipeșul": "chipeș",
    "chipeșule": "chipeș",
    "chipeșului": "chipeș",
    "chipie": "chipiu",
    "chipiele": "chipiu",
    "chipielor": "chipiu",
    "chipiul": "chipiu",
    "chipiule": "chipiu",
    "chipiului": "chipiu",
    "chipiuri": "chipiu",
    "chipiurile": "chipiu",
    "chipiurilor": "chipiu",
    "chirăia": "chirăi",
    "chirăiai": "chirăi",
    "chirăiam": "chirăi",
    "chirăiați": "chirăi",
    "chirăiau": "chirăi",
    "chirăie": "chirăi",
    "chirăii": "chirăi",
    "chirăim": "chirăi",
    "chirăind": "chirăi",
    "chirăindu": "chirăi",
    "chirăiră": "chirăi",
    "chirăirăm": "chirăi",
    "chirăirăți": "chirăi",
    "chirăise": "chirăi",
    "chirăisem": "chirăi",
    "chirăiseră": "chirăi",
    "chirăiserăm": "chirăi",
    "chirăiserăți": "chirăi",
    "chirăiseși": "chirăi",
    "chirăiși": "chirăi",
    "chirăit": "chirăi",
    "chirăiți": "chirăi",
    "chirăitu": "chirăi",
    "nechirăind": "chirăi",
    "nechirăindu": "chirăi",
    "nemaichirăind": "chirăi",
    "nemaichirăindu": "chirăi",
    "chirăită": "chirăit",
    "chirăite": "chirăit",
    "chirăiți": "chirăit",
    "chirăitul": "chirăit",
    "chirăitule": "chirăit",
    "chirăitului": "chirăit",
    "chirăituri": "chirăit",
    "chirăiturile": "chirăit",
    "chirăiturilor": "chirăit",
    "chircea": "chirci",
    "chirceai": "chirci",
    "chirceam": "chirci",
    "chircească": "chirci",
    "chirceați": "chirci",
    "chirceau": "chirci",
    "chircesc": "chirci",
    "chircește": "chirci",
    "chircești": "chirci",
    "chircii": "chirci",
    "chircim": "chirci",
    "chircind": "chirci",
    "chircindu": "chirci",
    "chirciră": "chirci",
    "chircirăm": "chirci",
    "chircirăți": "chirci",
    "chircise": "chirci",
    "chircisem": "chirci",
    "chirciseră": "chirci",
    "chirciserăm": "chirci",
    "chirciserăți": "chirci",
    "chirciseși": "chirci",
    "chirciși": "chirci",
    "chircit": "chirci",
    "chirciți": "chirci",
    "chircitu": "chirci",
    "nechircind": "chirci",
    "nechircindu": "chirci",
    "nemaichircind": "chirci",
    "nemaichircindu": "chirci",
    "chircita": "chircit",
    "chircită": "chircit",
    "chircite": "chircit",
    "chircitei": "chircit",
    "chircitele": "chircit",
    "chircitelor": "chircit",
    "chirciți": "chircit",
    "chirciții": "chircit",
    "chirciților": "chircit",
    "chircito": "chircit",
    "chircitul": "chircit",
    "chircitule": "chircit",
    "chircitului": "chircit",
    "chircitura": "chircitură",
    "chircituri": "chircitură",
    "chirciturii": "chircitură",
    "chirciturile": "chircitură",
    "chirciturilor": "chircitură",
    "chircituro": "chircitură",
    "chiriași": "chiriaș",
    "chiriașii": "chiriaș",
    "chiriașilor": "chiriaș",
    "chiriașul": "chiriaș",
    "chiriașule": "chiriaș",
    "chiriașului": "chiriaș",
    "chiriașa": "chiriașă",
    "chiriașe": "chiriașă",
    "chiriașei": "chiriașă",
    "chiriașele": "chiriașă",
    "chiriașelor": "chiriașă",
    "chiriașo": "chiriașă",
    "chiria": "chirie",
    "chiriei": "chirie",
    "chirii": "chirie",
    "chiriile": "chirie",
    "chiriilor": "chirie",
    "chirio": "chirie",
    "chirigii": "chirigiu",
    "chirigiii": "chirigiu",
    "chirigiilor": "chirigiu",
    "chirigiul": "chirigiu",
    "chirigiule": "chirigiu",
    "chirigiului": "chirigiu",
    "chirilica": "chirilic",
    "chirilică": "chirilic",
    "chirilice": "chirilic",
    "chirilicei": "chirilic",
    "chirilicele": "chirilic",
    "chirilicelor": "chirilic",
    "chirilici": "chirilic",
    "chirilicii": "chirilic",
    "chirilicilor": "chirilic",
    "chirilico": "chirilic",
    "chirilicul": "chirilic",
    "chirilicule": "chirilic",
    "chirilicului": "chirilic",
    "chiromanți": "chiromant",
    "chiromanții": "chiromant",
    "chiromanților": "chiromant",
    "chiromantul": "chiromant",
    "chiromantule": "chiromant",
    "chiromantului": "chiromant",
    "chiromanția": "chiromanție",
    "chiromanției": "chiromanție",
    "chiromanții": "chiromanție",
    "chiromanțio": "chiromanție",
    "chirpiciul": "chirpici",
    "chirpiciule": "chirpici",
    "chirpiciului": "chirpici",
    "chirurgi": "chirurg",
    "chirurgii": "chirurg",
    "chirurgilor": "chirurg",
    "chirurgul": "chirurg",
    "chirurgule": "chirurg",
    "chirurgului": "chirurg",
    "chirurgicala": "chirurgical",
    "chirurgicală": "chirurgical",
    "chirurgicale": "chirurgical",
    "chirurgicalei": "chirurgical",
    "chirurgicalele": "chirurgical",
    "chirurgicalelor": "chirurgical",
    "chirurgicali": "chirurgical",
    "chirurgicalii": "chirurgical",
    "chirurgicalilor": "chirurgical",
    "chirurgicalo": "chirurgical",
    "chirurgicalul": "chirurgical",
    "chirurgicalule": "chirurgical",
    "chirurgicalului": "chirurgical",
    "chirurgia": "chirurgie",
    "chirurgiei": "chirurgie",
    "chirurgii": "chirurgie",
    "chirurgiile": "chirurgie",
    "chirurgiilor": "chirurgie",
    "chirurgio": "chirurgie",
    "chiseao": "chisea",
    "chiseaua": "chisea",
    "chisele": "chisea",
    "chiselei": "chisea",
    "chiselele": "chisea",
    "chiselelor": "chisea",
    "chiselița": "chiseliță",
    "chiselițe": "chiseliță",
    "chiseliței": "chiseliță",
    "chiselițele": "chiseliță",
    "chiselițelor": "chiseliță",
    "chiselițo": "chiseliță",
    "Chișinăul": "Chișinău",
    "Chișinăului": "Chișinău",
    "chișița": "chișiță",
    "chișițe": "chișiță",
    "chișiței": "chișiță",
    "chișițele": "chișiță",
    "chișițelor": "chișiță",
    "chișițo": "chișiță",
    "chișleagul": "chișleag",
    "chișleagule": "chișleag",
    "chișleagului": "chișleag",
    "chistul": "chist",
    "chistule": "chist",
    "chistului": "chist",
    "chisturi": "chist",
    "chisturile": "chist",
    "chisturilor": "chist",
    "chiștoace": "chiștoc",
    "chiștoacele": "chiștoc",
    "chiștoacelor": "chiștoc",
    "chiștocul": "chiștoc",
    "chiștocule": "chiștoc",
    "chiștocului": "chiștoc",
    "chitul": "chit",
    "chitule": "chit",
    "chitului": "chit",
    "chituri": "chit",
    "chiturile": "chit",
    "chiturilor": "chit",
    "chițăia": "chițăi",
    "chițăiai": "chițăi",
    "chițăiam": "chițăi",
    "chițăiați": "chițăi",
    "chițăiau": "chițăi",
    "chițăie": "chițăi",
    "chițăii": "chițăi",
    "chițăim": "chițăi",
    "chițăind": "chițăi",
    "chițăindu": "chițăi",
    "chițăiră": "chițăi",
    "chițăirăm": "chițăi",
    "chițăirăți": "chițăi",
    "chițăise": "chițăi",
    "chițăisem": "chițăi",
    "chițăiseră": "chițăi",
    "chițăiserăm": "chițăi",
    "chițăiserăți": "chițăi",
    "chițăiseși": "chițăi",
    "chițăiși": "chițăi",
    "chițăit": "chițăi",
    "chițăiți": "chițăi",
    "chițăitu": "chițăi",
    "nechițăind": "chițăi",
    "nechițăindu": "chițăi",
    "nemaichițăind": "chițăi",
    "nemaichițăindu": "chițăi",
    "chițăită": "chițăit",
    "chițăite": "chițăit",
    "chițăiți": "chițăit",
    "chițăitul": "chițăit",
    "chițăitule": "chițăit",
    "chițăitului": "chițăit",
    "chitanța": "chitanță",
    "chitanțe": "chitanță",
    "chitanței": "chitanță",
    "chitanțele": "chitanță",
    "chitanțelor": "chitanță",
    "chitanțo": "chitanță",
    "chitanțiere": "chitanțier",
    "chitanțierele": "chitanțier",
    "chitanțierelor": "chitanțier",
    "chitanțierul": "chitanțier",
    "chitanțierule": "chitanțier",
    "chitanțierului": "chitanțier",
    "chitara": "chitară",
    "chitare": "chitară",
    "chitarei": "chitară",
    "chitarele": "chitară",
    "chitarelor": "chitară",
    "chitaro": "chitară",
    "chitariști": "chitarist",
    "chitariștii": "chitarist",
    "chitariștilor": "chitarist",
    "chitaristul": "chitarist",
    "chitaristule": "chitarist",
    "chitaristului": "chitarist",
    "chitarista": "chitaristă",
    "chitariste": "chitaristă",
    "chitaristei": "chitaristă",
    "chitaristele": "chitaristă",
    "chitaristelor": "chitaristă",
    "chitaristo": "chitaristă",
    "chițcăia": "chițcăi",
    "chițcăiai": "chițcăi",
    "chițcăiam": "chițcăi",
    "chițcăiați": "chițcăi",
    "chițcăiau": "chițcăi",
    "chițcăie": "chițcăi",
    "chițcăii": "chițcăi",
    "chițcăim": "chițcăi",
    "chițcăind": "chițcăi",
    "chițcăindu": "chițcăi",
    "chițcăiră": "chițcăi",
    "chițcăirăm": "chițcăi",
    "chițcăirăți": "chițcăi",
    "chițcăise": "chițcăi",
    "chițcăisem": "chițcăi",
    "chițcăiseră": "chițcăi",
    "chițcăiserăm": "chițcăi",
    "chițcăiserăți": "chițcăi",
    "chițcăiseși": "chițcăi",
    "chițcăiși": "chițcăi",
    "chițcăit": "chițcăi",
    "chițcăiți": "chițcăi",
    "chițcăitu": "chițcăi",
    "nechițcăind": "chițcăi",
    "nechițcăindu": "chițcăi",
    "nemaichițcăind": "chițcăi",
    "nemaichițcăindu": "chițcăi",
    "chițcăiala": "chițcăială",
    "chițcăialo": "chițcăială",
    "chițcăieli": "chițcăială",
    "chițcăielii": "chițcăială",
    "chițcăielile": "chițcăială",
    "chițcăielilor": "chițcăială",
    "chițcăită": "chițcăit",
    "chițcăite": "chițcăit",
    "chițcăiți": "chițcăit",
    "chițcani": "chițcan",
    "chițcanii": "chițcan",
    "chițcanilor": "chițcan",
    "chițcanul": "chițcan",
    "chițcanule": "chițcan",
    "chițcanului": "chițcan",
    "chiteala": "chiteală",
    "chitealo": "chiteală",
    "chiteli": "chiteală",
    "chitelii": "chiteală",
    "chitelile": "chiteală",
    "chitelilor": "chiteală",
    "chitea": "chiti",
    "chiteai": "chiti",
    "chiteam": "chiti",
    "chitească": "chiti",
    "chiteați": "chiti",
    "chiteau": "chiti",
    "chitesc": "chiti",
    "chitește": "chiti",
    "chitești": "chiti",
    "chitii": "chiti",
    "chitim": "chiti",
    "chitind": "chiti",
    "chitindu": "chiti",
    "chitiră": "chiti",
    "chitirăm": "chiti",
    "chitirăți": "chiti",
    "chitise": "chiti",
    "chitisem": "chiti",
    "chitiseră": "chiti",
    "chitiserăm": "chiti",
    "chitiserăți": "chiti",
    "chitiseși": "chiti",
    "chitiși": "chiti",
    "chitit": "chiti",
    "chitiți": "chiti",
    "chititu": "chiti",
    "nechitind": "chiti",
    "nechitindu": "chiti",
    "nemaichitind": "chiti",
    "nemaichitindu": "chiti",
    "chițibușul": "chițibuș",
    "chițibușule": "chițibuș",
    "chițibușului": "chițibuș",
    "chițibușuri": "chițibuș",
    "chițibușurile": "chițibuș",
    "chițibușurilor": "chițibuș",
    "chițibușari": "chițibușar",
    "chițibușarii": "chițibușar",
    "chițibușarilor": "chițibușar",
    "chițibușarul": "chițibușar",
    "chițibușarule": "chițibușar",
    "chițibușarului": "chițibușar",
    "chițibușara": "chițibușară",
    "chițibușare": "chițibușară",
    "chițibușarei": "chițibușară",
    "chițibușarele": "chițibușară",
    "chițibușarelor": "chițibușară",
    "chițibușaro": "chițibușară",
    "chițibușăria": "chițibușărie",
    "chițibușăriei": "chițibușărie",
    "chițibușării": "chițibușărie",
    "chițibușăriile": "chițibușărie",
    "chițibușăriilor": "chițibușărie",
    "chițibușărio": "chițibușărie",
    "chitici": "chitic",
    "chiticii": "chitic",
    "chiticilor": "chitic",
    "chiticul": "chitic",
    "chiticule": "chitic",
    "chiticului": "chitic",
    "chitina": "chitină",
    "chitine": "chitină",
    "chitinei": "chitină",
    "chitino": "chitină",
    "chitinoasa": "chitinos",
    "chitinoasă": "chitinos",
    "chitinoase": "chitinos",
    "chitinoasei": "chitinos",
    "chitinoasele": "chitinos",
    "chitinoaselor": "chitinos",
    "chitinoaso": "chitinos",
    "chitinoși": "chitinos",
    "chitinoșii": "chitinos",
    "chitinoșilor": "chitinos",
    "chitinosul": "chitinos",
    "chitinosule": "chitinos",
    "chitinosului": "chitinos",
    "chitita": "chitit",
    "chitită": "chitit",
    "chitite": "chitit",
    "chititei": "chitit",
    "chititele": "chitit",
    "chititelor": "chitit",
    "chitiți": "chitit",
    "chitiții": "chitit",
    "chitiților": "chitit",
    "chitito": "chitit",
    "chititul": "chitit",
    "chititule": "chitit",
    "chititului": "chitit",
    "chituia": "chitui",
    "chituiai": "chitui",
    "chituiam": "chitui",
    "chituiască": "chitui",
    "chituiați": "chitui",
    "chituiau": "chitui",
    "chituiesc": "chitui",
    "chituiește": "chitui",
    "chituiești": "chitui",
    "chituii": "chitui",
    "chituim": "chitui",
    "chituind": "chitui",
    "chituindu": "chitui",
    "chituiră": "chitui",
    "chituirăm": "chitui",
    "chituirăți": "chitui",
    "chituise": "chitui",
    "chituisem": "chitui",
    "chituiseră": "chitui",
    "chituiserăm": "chitui",
    "chituiserăți": "chitui",
    "chituiseși": "chitui",
    "chituiși": "chitui",
    "chituit": "chitui",
    "chituiți": "chitui",
    "chituitu": "chitui",
    "nechituind": "chitui",
    "nechituindu": "chitui",
    "nemaichituind": "chitui",
    "nemaichituindu": "chitui",
    "chituită": "chituit",
    "chituite": "chituit",
    "chituiți": "chituit",
    "chiul": "chiu",
    "chiule": "chiu",
    "chiului": "chiu",
    "chiuia": "chiui",
    "chiuiai": "chiui",
    "chiuiam": "chiui",
    "chiuiați": "chiui",
    "chiuiau": "chiui",
    "chiuie": "chiui",
    "chiuii": "chiui",
    "chiuim": "chiui",
    "chiuind": "chiui",
    "chiuindu": "chiui",
    "chiuiră": "chiui",
    "chiuirăm": "chiui",
    "chiuirăți": "chiui",
    "chiuise": "chiui",
    "chiuisem": "chiui",
    "chiuiseră": "chiui",
    "chiuiserăm": "chiui",
    "chiuiserăți": "chiui",
    "chiuiseși": "chiui",
    "chiuiși": "chiui",
    "chiuit": "chiui",
    "chiuiți": "chiui",
    "chiuitu": "chiui",
    "nechiuind": "chiui",
    "nechiuindu": "chiui",
    "nemaichiuind": "chiui",
    "nemaichiuindu": "chiui",
    "chiuită": "chiuit",
    "chiuite": "chiuit",
    "chiuiți": "chiuit",
    "chiuitul": "chiuit",
    "chiuitule": "chiuit",
    "chiuitului": "chiuit",
    "chiuituri": "chiuit",
    "chiuiturile": "chiuit",
    "chiuiturilor": "chiuit",
    "chiuitura": "chiuitură",
    "chiuituri": "chiuitură",
    "chiuiturii": "chiuitură",
    "chiuiturile": "chiuitură",
    "chiuiturilor": "chiuitură",
    "chiuituro": "chiuitură",
    "chiulul": "chiul",
    "chiulule": "chiul",
    "chiulului": "chiul",
    "chiuluri": "chiul",
    "chiulurile": "chiul",
    "chiulurilor": "chiul",
    "chiulangia": "chiulangie",
    "chiulangiei": "chiulangie",
    "chiulangii": "chiulangie",
    "chiulangiile": "chiulangie",
    "chiulangiilor": "chiulangie",
    "chiulangio": "chiulangie",
    "chiulangii": "chiulangiu",
    "chiulangiii": "chiulangiu",
    "chiulangiilor": "chiulangiu",
    "chiulangiul": "chiulangiu",
    "chiulangiule": "chiulangiu",
    "chiulangiului": "chiulangiu",
    "chiulasa": "chiulasă",
    "chiulase": "chiulasă",
    "chiulasei": "chiulasă",
    "chiulasele": "chiulasă",
    "chiulaselor": "chiulasă",
    "chiulaso": "chiulasă",
    "chiulea": "chiuli",
    "chiuleai": "chiuli",
    "chiuleam": "chiuli",
    "chiulească": "chiuli",
    "chiuleați": "chiuli",
    "chiuleau": "chiuli",
    "chiulesc": "chiuli",
    "chiulește": "chiuli",
    "chiulești": "chiuli",
    "chiulii": "chiuli",
    "chiulim": "chiuli",
    "chiulind": "chiuli",
    "chiulindu": "chiuli",
    "chiuliră": "chiuli",
    "chiulirăm": "chiuli",
    "chiulirăți": "chiuli",
    "chiulise": "chiuli",
    "chiulisem": "chiuli",
    "chiuliseră": "chiuli",
    "chiuliserăm": "chiuli",
    "chiuliserăți": "chiuli",
    "chiuliseși": "chiuli",
    "chiuliși": "chiuli",
    "chiulit": "chiuli",
    "chiuliți": "chiuli",
    "chiulitu": "chiuli",
    "nechiulind": "chiuli",
    "nechiulindu": "chiuli",
    "nemaichiulind": "chiuli",
    "nemaichiulindu": "chiuli",
    "chiulită": "chiulit",
    "chiulite": "chiulit",
    "chiuliți": "chiulit",
    "chiupul": "chiup",
    "chiupule": "chiup",
    "chiupului": "chiup",
    "chiupuri": "chiup",
    "chiupurile": "chiup",
    "chiupurilor": "chiup",
    "chiuretă": "chiureta",
    "chiuretai": "chiureta",
    "chiuretam": "chiureta",
    "chiuretăm": "chiureta",
    "chiuretând": "chiureta",
    "chiuretându": "chiureta",
    "chiuretară": "chiureta",
    "chiuretarăm": "chiureta",
    "chiuretarăți": "chiureta",
    "chiuretase": "chiureta",
    "chiuretasem": "chiureta",
    "chiuretaseră": "chiureta",
    "chiuretaserăm": "chiureta",
    "chiuretaserăți": "chiureta",
    "chiuretaseși": "chiureta",
    "chiuretași": "chiureta",
    "chiuretat": "chiureta",
    "chiuretați": "chiureta",
    "chiuretatu": "chiureta",
    "chiuretau": "chiureta",
    "chiuretează": "chiureta",
    "chiuretez": "chiureta",
    "chiureteze": "chiureta",
    "chiuretezi": "chiureta",
    "nechiuretând": "chiureta",
    "nechiuretându": "chiureta",
    "nemaichiuretând": "chiureta",
    "nemaichiuretându": "chiureta",
    "chiureta": "chiuretă",
    "chiurete": "chiuretă",
    "chiuretei": "chiuretă",
    "chiuretele": "chiuretă",
    "chiuretelor": "chiuretă",
    "chiureto": "chiuretă",
    "chiuretaje": "chiuretaj",
    "chiuretajele": "chiuretaj",
    "chiuretajelor": "chiuretaj",
    "chiuretajul": "chiuretaj",
    "chiuretajule": "chiuretaj",
    "chiuretajului": "chiuretaj",
    "chiuretată": "chiuretat",
    "chiuretate": "chiuretat",
    "chiuretați": "chiuretat",
    "chiuveta": "chiuvetă",
    "chiuvete": "chiuvetă",
    "chiuvetei": "chiuvetă",
    "chiuvetele": "chiuvetă",
    "chiuvetelor": "chiuvetă",
    "chiuveto": "chiuvetă",
    "chivăra": "chivără",
    "chivăro": "chivără",
    "chivere": "chivără",
    "chiverei": "chivără",
    "chiverele": "chivără",
    "chiverelor": "chivără",
    "chiverniseala": "chiverniseală",
    "chivernisealo": "chiverniseală",
    "chiverniseli": "chiverniseală",
    "chiverniselii": "chiverniseală",
    "chiverniselile": "chiverniseală",
    "chiverniselilor": "chiverniseală",
    "chivernisea": "chivernisi",
    "chiverniseai": "chivernisi",
    "chiverniseam": "chivernisi",
    "chivernisească": "chivernisi",
    "chiverniseați": "chivernisi",
    "chiverniseau": "chivernisi",
    "chivernisesc": "chivernisi",
    "chivernisește": "chivernisi",
    "chivernisești": "chivernisi",
    "chivernisii": "chivernisi",
    "chivernisim": "chivernisi",
    "chivernisind": "chivernisi",
    "chivernisindu": "chivernisi",
    "chivernisiră": "chivernisi",
    "chivernisirăm": "chivernisi",
    "chivernisirăți": "chivernisi",
    "chivernisise": "chivernisi",
    "chivernisisem": "chivernisi",
    "chivernisiseră": "chivernisi",
    "chivernisiserăm": "chivernisi",
    "chivernisiserăți": "chivernisi",
    "chivernisiseși": "chivernisi",
    "chivernisiși": "chivernisi",
    "chivernisit": "chivernisi",
    "chivernisiți": "chivernisi",
    "chivernisitu": "chivernisi",
    "nechivernisind": "chivernisi",
    "nechivernisindu": "chivernisi",
    "nemaichivernisind": "chivernisi",
    "nemaichivernisindu": "chivernisi",
    "chivernisirea": "chivernisire",
    "chivernisireo": "chivernisire",
    "chivernisiri": "chivernisire",
    "chivernisirii": "chivernisire",
    "chivernisirile": "chivernisire",
    "chivernisirilor": "chivernisire",
    "chivernisita": "chivernisit",
    "chivernisită": "chivernisit",
    "chivernisite": "chivernisit",
    "chivernisitei": "chivernisit",
    "chivernisitele": "chivernisit",
    "chivernisitelor": "chivernisit",
    "chivernisiți": "chivernisit",
    "chivernisiții": "chivernisit",
    "chivernisiților": "chivernisit",
    "chivernisito": "chivernisit",
    "chivernisitul": "chivernisit",
    "chivernisitule": "chivernisit",
    "chivernisitului": "chivernisit",
    "chivote": "chivot",
    "chivotele": "chivot",
    "chivotelor": "chivot",
    "chivotul": "chivot",
    "chivotule": "chivot",
    "chivotului": "chivot",
    "chivoturi": "chivot",
    "chivoturile": "chivot",
    "chivoturilor": "chivot",
    "chixul": "chix",
    "chixule": "chix",
    "chixului": "chix",
    "chixuri": "chix",
    "chixurile": "chix",
    "chixurilor": "chix",
    "Christoase": "Christos",
    "Christosul": "Christos",
    "Christosului": "Christos",
    "cianul": "cian",
    "cianule": "cian",
    "cianului": "cian",
    "ciangăi": "ciangău",
    "ciangăii": "ciangău",
    "ciangăilor": "ciangău",
    "ciangăul": "ciangău",
    "ciangăule": "ciangău",
    "ciangăului": "ciangău",
    "cianhidrici": "cianhidric",
    "cianhidricii": "cianhidric",
    "cianhidricilor": "cianhidric",
    "cianhidricul": "cianhidric",
    "cianhidricule": "cianhidric",
    "cianhidricului": "cianhidric",
    "cianhidrizarea": "cianhidrizare",
    "cianhidrizareo": "cianhidrizare",
    "cianhidrizări": "cianhidrizare",
    "cianhidrizării": "cianhidrizare",
    "cianhidrizările": "cianhidrizare",
    "cianhidrizărilor": "cianhidrizare",
    "cianizarea": "cianizare",
    "cianizareo": "cianizare",
    "cianizări": "cianizare",
    "cianizării": "cianizare",
    "cianizările": "cianizare",
    "cianizărilor": "cianizare",
    "cianura": "cianură",
    "cianuri": "cianură",
    "cianurii": "cianură",
    "cianurile": "cianură",
    "cianurilor": "cianură",
    "cianuro": "cianură",
    "cianurarea": "cianurare",
    "cianurareo": "cianurare",
    "cianurări": "cianurare",
    "cianurării": "cianurare",
    "cianurările": "cianurare",
    "cianurărilor": "cianurare",
    "cibernetica": "cibernetică",
    "cibernetici": "cibernetică",
    "ciberneticii": "cibernetică",
    "ciberneticile": "cibernetică",
    "ciberneticilor": "cibernetică",
    "cic": "cică",
    "cicăleala": "cicăleală",
    "cicălealo": "cicăleală",
    "cicăleli": "cicăleală",
    "cicălelii": "cicăleală",
    "cicălelile": "cicăleală",
    "cicălelilor": "cicăleală",
    "cicălea": "cicăli",
    "cicăleai": "cicăli",
    "cicăleam": "cicăli",
    "cicălească": "cicăli",
    "cicăleați": "cicăli",
    "cicăleau": "cicăli",
    "cicălesc": "cicăli",
    "cicălește": "cicăli",
    "cicălești": "cicăli",
    "cicălii": "cicăli",
    "cicălim": "cicăli",
    "cicălind": "cicăli",
    "cicălindu": "cicăli",
    "cicăliră": "cicăli",
    "cicălirăm": "cicăli",
    "cicălirăți": "cicăli",
    "cicălise": "cicăli",
    "cicălisem": "cicăli",
    "cicăliseră": "cicăli",
    "cicăliserăm": "cicăli",
    "cicăliserăți": "cicăli",
    "cicăliseși": "cicăli",
    "cicăliși": "cicăli",
    "cicălit": "cicăli",
    "cicăliți": "cicăli",
    "cicălitu": "cicăli",
    "necicălind": "cicăli",
    "necicălindu": "cicăli",
    "nemaicicălind": "cicăli",
    "nemaicicălindu": "cicăli",
    "cicălirea": "cicălire",
    "cicălireo": "cicălire",
    "cicăliri": "cicălire",
    "cicălirii": "cicălire",
    "cicălirile": "cicălire",
    "cicălirilor": "cicălire",
    "cicălită": "cicălit",
    "cicălite": "cicălit",
    "cicăliți": "cicălit",
    "cicălitoare": "cicălitor",
    "cicălitoarea": "cicălitor",
    "cicălitoarei": "cicălitor",
    "cicălitoarele": "cicălitor",
    "cicălitoarelor": "cicălitor",
    "cicălitoareo": "cicălitor",
    "cicălitori": "cicălitor",
    "cicălitorii": "cicălitor",
    "cicălitorilor": "cicălitor",
    "cicălitorul": "cicălitor",
    "cicălitorule": "cicălitor",
    "cicălitorului": "cicălitor",
    "cicatricea": "cicatrice",
    "cicatricei": "cicatrice",
    "cicatricele": "cicatrice",
    "cicatricelor": "cicatrice",
    "cicatriceo": "cicatrice",
    "cicatricile": "cicatrice",
    "cicatriză": "cicatriza",
    "cicatrizai": "cicatriza",
    "cicatrizam": "cicatriza",
    "cicatrizăm": "cicatriza",
    "cicatrizând": "cicatriza",
    "cicatrizându": "cicatriza",
    "cicatrizară": "cicatriza",
    "cicatrizarăm": "cicatriza",
    "cicatrizarăți": "cicatriza",
    "cicatrizase": "cicatriza",
    "cicatrizasem": "cicatriza",
    "cicatrizaseră": "cicatriza",
    "cicatrizaserăm": "cicatriza",
    "cicatrizaserăți": "cicatriza",
    "cicatrizaseși": "cicatriza",
    "cicatrizași": "cicatriza",
    "cicatrizat": "cicatriza",
    "cicatrizați": "cicatriza",
    "cicatrizatu": "cicatriza",
    "cicatrizau": "cicatriza",
    "cicatrizează": "cicatriza",
    "cicatrizez": "cicatriza",
    "cicatrizeze": "cicatriza",
    "cicatrizezi": "cicatriza",
    "necicatrizând": "cicatriza",
    "necicatrizându": "cicatriza",
    "nemaicicatrizând": "cicatriza",
    "nemaicicatrizându": "cicatriza",
    "cicatrizarea": "cicatrizare",
    "cicatrizareo": "cicatrizare",
    "cicatrizări": "cicatrizare",
    "cicatrizării": "cicatrizare",
    "cicatrizările": "cicatrizare",
    "cicatrizărilor": "cicatrizare",
    "cicatrizată": "cicatrizat",
    "cicatrizate": "cicatrizat",
    "cicatrizați": "cicatrizat",
    "ciclama": "ciclamă",
    "ciclame": "ciclamă",
    "ciclamei": "ciclamă",
    "ciclamele": "ciclamă",
    "ciclamelor": "ciclamă",
    "ciclamo": "ciclamă",
    "ciclica": "ciclic",
    "ciclică": "ciclic",
    "ciclice": "ciclic",
    "ciclicei": "ciclic",
    "ciclicele": "ciclic",
    "ciclicelor": "ciclic",
    "ciclici": "ciclic",
    "ciclicii": "ciclic",
    "ciclicilor": "ciclic",
    "ciclico": "ciclic",
    "ciclicul": "ciclic",
    "ciclicule": "ciclic",
    "ciclicului": "ciclic",
    "ciclismul": "ciclism",
    "ciclismule": "ciclism",
    "ciclismului": "ciclism",
    "cicliști": "ciclist",
    "cicliștii": "ciclist",
    "cicliștilor": "ciclist",
    "ciclistul": "ciclist",
    "ciclistule": "ciclist",
    "ciclistului": "ciclist",
    "ciclista": "ciclistă",
    "cicliste": "ciclistă",
    "ciclistei": "ciclistă",
    "ciclistele": "ciclistă",
    "ciclistelor": "ciclistă",
    "ciclisto": "ciclistă",
    "ciclizarea": "ciclizare",
    "ciclizareo": "ciclizare",
    "ciclizări": "ciclizare",
    "ciclizării": "ciclizare",
    "ciclizările": "ciclizare",
    "ciclizărilor": "ciclizare",
    "ciclocrosul": "ciclocros",
    "ciclocrosule": "ciclocros",
    "ciclocrosului": "ciclocros",
    "ciclocrosuri": "ciclocros",
    "ciclocrosurile": "ciclocros",
    "ciclocrosurilor": "ciclocros",
    "ciclohexanul": "ciclohexan",
    "ciclohexanule": "ciclohexan",
    "ciclohexanului": "ciclohexan",
    "cicloida": "cicloidă",
    "cicloide": "cicloidă",
    "cicloidei": "cicloidă",
    "cicloidele": "cicloidă",
    "cicloidelor": "cicloidă",
    "cicloido": "cicloidă",
    "cicloidala": "cicloidal",
    "cicloidală": "cicloidal",
    "cicloidale": "cicloidal",
    "cicloidalei": "cicloidal",
    "cicloidalele": "cicloidal",
    "cicloidalelor": "cicloidal",
    "cicloidali": "cicloidal",
    "cicloidalii": "cicloidal",
    "cicloidalilor": "cicloidal",
    "cicloidalo": "cicloidal",
    "cicloidalul": "cicloidal",
    "cicloidalule": "cicloidal",
    "cicloidalului": "cicloidal",
    "cicloane": "ciclon",
    "cicloanele": "ciclon",
    "cicloanelor": "ciclon",
    "ciclonul": "ciclon",
    "ciclonule": "ciclon",
    "ciclonului": "ciclon",
    "ciclopi": "ciclop",
    "ciclopii": "ciclop",
    "ciclopilor": "ciclop",
    "ciclopul": "ciclop",
    "ciclopule": "ciclop",
    "ciclopului": "ciclop",
    "ciclopentanul": "ciclopentan",
    "ciclopentanule": "ciclopentan",
    "ciclopentanului": "ciclopentan",
    "ciclotroane": "ciclotron",
    "ciclotroanele": "ciclotron",
    "ciclotroanelor": "ciclotron",
    "ciclotronul": "ciclotron",
    "ciclotronule": "ciclotron",
    "ciclotronului": "ciclotron",
    "ciclul": "ciclu",
    "ciclule": "ciclu",
    "ciclului": "ciclu",
    "cicluri": "ciclu",
    "ciclurile": "ciclu",
    "ciclurilor": "ciclu",
    "cicoarea": "cicoare",
    "cicoareo": "cicoare",
    "cicori": "cicoare",
    "cicorii": "cicoare",
    "cicorile": "cicoare",
    "cicorilor": "cicoare",
    "cidrul": "cidru",
    "cidrule": "cidru",
    "cidrului": "cidru",
    "cifră": "cifra",
    "cifrai": "cifra",
    "cifram": "cifra",
    "cifrăm": "cifra",
    "cifrând": "cifra",
    "cifrându": "cifra",
    "cifrară": "cifra",
    "cifrarăm": "cifra",
    "cifrarăți": "cifra",
    "cifrase": "cifra",
    "cifrasem": "cifra",
    "cifraseră": "cifra",
    "cifraserăm": "cifra",
    "cifraserăți": "cifra",
    "cifraseși": "cifra",
    "cifrași": "cifra",
    "cifrat": "cifra",
    "cifrați": "cifra",
    "cifratu": "cifra",
    "cifrau": "cifra",
    "cifrează": "cifra",
    "cifrez": "cifra",
    "cifreze": "cifra",
    "cifrezi": "cifra",
    "necifrând": "cifra",
    "necifrându": "cifra",
    "nemaicifrând": "cifra",
    "nemaicifrându": "cifra",
    "cifra": "cifră",
    "cifre": "cifră",
    "cifrei": "cifră",
    "cifrele": "cifră",
    "cifrelor": "cifră",
    "cifro": "cifră",
    "cifrărăi": "cifrăraie",
    "cifrăraia": "cifrăraie",
    "cifrărăii": "cifrăraie",
    "cifrăraio": "cifrăraie",
    "cifrata": "cifrat",
    "cifrată": "cifrat",
    "cifrate": "cifrat",
    "cifratei": "cifrat",
    "cifratele": "cifrat",
    "cifratelor": "cifrat",
    "cifrați": "cifrat",
    "cifrații": "cifrat",
    "cifraților": "cifrat",
    "cifrato": "cifrat",
    "cifratul": "cifrat",
    "cifratule": "cifrat",
    "cifratului": "cifrat",
    "cifrica": "cifric",
    "cifrică": "cifric",
    "cifrice": "cifric",
    "cifricei": "cifric",
    "cifricele": "cifric",
    "cifricelor": "cifric",
    "cifrici": "cifric",
    "cifricii": "cifric",
    "cifricilor": "cifric",
    "cifrico": "cifric",
    "cifricul": "cifric",
    "cifricule": "cifric",
    "cifricului": "cifric",
    "cifrul": "cifru",
    "cifrule": "cifru",
    "cifrului": "cifru",
    "cifruri": "cifru",
    "cifrurile": "cifru",
    "cifrurilor": "cifru",
    "cihăia": "cihăi",
    "cihăiai": "cihăi",
    "cihăiam": "cihăi",
    "cihăiască": "cihăi",
    "cihăiați": "cihăi",
    "cihăiau": "cihăi",
    "cihăiesc": "cihăi",
    "cihăiește": "cihăi",
    "cihăiești": "cihăi",
    "cihăii": "cihăi",
    "cihăim": "cihăi",
    "cihăind": "cihăi",
    "cihăindu": "cihăi",
    "cihăiră": "cihăi",
    "cihăirăm": "cihăi",
    "cihăirăți": "cihăi",
    "cihăise": "cihăi",
    "cihăisem": "cihăi",
    "cihăiseră": "cihăi",
    "cihăiserăm": "cihăi",
    "cihăiserăți": "cihăi",
    "cihăiseși": "cihăi",
    "cihăiși": "cihăi",
    "cihăit": "cihăi",
    "cihăiți": "cihăi",
    "cihăitu": "cihăi",
    "necihăind": "cihăi",
    "necihăindu": "cihăi",
    "nemaicihăind": "cihăi",
    "nemaicihăindu": "cihăi",
    "cihăită": "cihăit",
    "cihăite": "cihăit",
    "cihăiți": "cihăit",
    "cili": "cil",
    "cilii": "cil",
    "cililor": "cil",
    "cilul": "cil",
    "cilule": "cil",
    "cilului": "cil",
    "ciliara": "ciliar",
    "ciliară": "ciliar",
    "ciliare": "ciliar",
    "ciliarei": "ciliar",
    "ciliarele": "ciliar",
    "ciliarelor": "ciliar",
    "ciliari": "ciliar",
    "ciliarii": "ciliar",
    "ciliarilor": "ciliar",
    "ciliaro": "ciliar",
    "ciliarul": "ciliar",
    "ciliarule": "ciliar",
    "ciliarului": "ciliar",
    "cilindrica": "cilindric",
    "cilindrică": "cilindric",
    "cilindrice": "cilindric",
    "cilindricei": "cilindric",
    "cilindricele": "cilindric",
    "cilindricelor": "cilindric",
    "cilindrici": "cilindric",
    "cilindricii": "cilindric",
    "cilindricilor": "cilindric",
    "cilindrico": "cilindric",
    "cilindricul": "cilindric",
    "cilindricule": "cilindric",
    "cilindricului": "cilindric",
    "cilindre": "cilindru",
    "cilindrele": "cilindru",
    "cilindrelor": "cilindru",
    "cilindri": "cilindru",
    "cilindrii": "cilindru",
    "cilindrilor": "cilindru",
    "cilindrul": "cilindru",
    "cilindrule": "cilindru",
    "cilindrului": "cilindru",
    "cimbale": "cimbal",
    "cimbalele": "cimbal",
    "cimbalelor": "cimbal",
    "cimbalul": "cimbal",
    "cimbalule": "cimbal",
    "cimbalului": "cimbal",
    "cimbrișorul": "cimbrișor",
    "cimbrișorule": "cimbrișor",
    "cimbrișorului": "cimbrișor",
    "cimbrul": "cimbru",
    "cimbrule": "cimbru",
    "cimbrului": "cimbru",
    "cimentul": "ciment",
    "cimentule": "ciment",
    "cimentului": "ciment",
    "cimenturi": "ciment",
    "cimenturile": "ciment",
    "cimenturilor": "ciment",
    "cimentă": "cimenta",
    "cimentai": "cimenta",
    "cimentam": "cimenta",
    "cimentăm": "cimenta",
    "cimentând": "cimenta",
    "cimentându": "cimenta",
    "cimentară": "cimenta",
    "cimentarăm": "cimenta",
    "cimentarăți": "cimenta",
    "cimentase": "cimenta",
    "cimentasem": "cimenta",
    "cimentaseră": "cimenta",
    "cimentaserăm": "cimenta",
    "cimentaserăți": "cimenta",
    "cimentaseși": "cimenta",
    "cimentași": "cimenta",
    "cimentat": "cimenta",
    "cimentați": "cimenta",
    "cimentatu": "cimenta",
    "cimentau": "cimenta",
    "cimentează": "cimenta",
    "cimentez": "cimenta",
    "cimenteze": "cimenta",
    "cimentezi": "cimenta",
    "necimentând": "cimenta",
    "necimentându": "cimenta",
    "nemaicimentând": "cimenta",
    "nemaicimentându": "cimenta",
    "cimentarea": "cimentare",
    "cimentareo": "cimentare",
    "cimentări": "cimentare",
    "cimentării": "cimentare",
    "cimentările": "cimentare",
    "cimentărilor": "cimentare",
    "cimentată": "cimentat",
    "cimentate": "cimentat",
    "cimentați": "cimentat",
    "cimilea": "cimili",
    "cimileai": "cimili",
    "cimileam": "cimili",
    "cimilească": "cimili",
    "cimileați": "cimili",
    "cimileau": "cimili",
    "cimilesc": "cimili",
    "cimilește": "cimili",
    "cimilești": "cimili",
    "cimilii": "cimili",
    "cimilim": "cimili",
    "cimilind": "cimili",
    "cimilindu": "cimili",
    "cimiliră": "cimili",
    "cimilirăm": "cimili",
    "cimilirăți": "cimili",
    "cimilise": "cimili",
    "cimilisem": "cimili",
    "cimiliseră": "cimili",
    "cimiliserăm": "cimili",
    "cimiliserăți": "cimili",
    "cimiliseși": "cimili",
    "cimiliși": "cimili",
    "cimilit": "cimili",
    "cimiliți": "cimili",
    "cimilitu": "cimili",
    "necimilind": "cimili",
    "necimilindu": "cimili",
    "nemaicimilind": "cimili",
    "nemaicimilindu": "cimili",
    "cimilită": "cimilit",
    "cimilite": "cimilit",
    "cimiliți": "cimilit",
    "cimilitura": "cimilitură",
    "cimilituri": "cimilitură",
    "cimiliturii": "cimilitură",
    "cimiliturile": "cimilitură",
    "cimiliturilor": "cimilitură",
    "cimilituro": "cimilitură",
    "cim.": "cimitir",
    "cimitire": "cimitir",
    "cimitirele": "cimitir",
    "cimitirelor": "cimitir",
    "cimitirul": "cimitir",
    "cimitirule": "cimitir",
    "cimitirului": "cimitir",
    "cimpanzei": "cimpanzeu",
    "cimpanzeii": "cimpanzeu",
    "cimpanzeilor": "cimpanzeu",
    "cimpanzeul": "cimpanzeu",
    "cimpanzeule": "cimpanzeu",
    "cimpanzeului": "cimpanzeu",
    "cimpoaie": "cimpoi",
    "cimpoaiele": "cimpoi",
    "cimpoaielor": "cimpoi",
    "cimpoiul": "cimpoi",
    "cimpoiule": "cimpoi",
    "cimpoiului": "cimpoi",
    "cimpoiași": "cimpoiaș",
    "cimpoiașii": "cimpoiaș",
    "cimpoiașilor": "cimpoiaș",
    "cimpoiașul": "cimpoiaș",
    "cimpoiașule": "cimpoiaș",
    "cimpoiașului": "cimpoiaș",
    "cimpoieri": "cimpoier",
    "cimpoierii": "cimpoier",
    "cimpoierilor": "cimpoier",
    "cimpoierul": "cimpoier",
    "cimpoierule": "cimpoier",
    "cimpoierului": "cimpoier",
    "cinul": "cin",
    "cinule": "cin",
    "cinului": "cin",
    "cinuri": "cin",
    "cinurile": "cin",
    "cinurilor": "cin",
    "cină": "cina",
    "cinai": "cina",
    "cinam": "cina",
    "cinăm": "cina",
    "cinând": "cina",
    "cinându": "cina",
    "cinară": "cina",
    "cinarăm": "cina",
    "cinarăți": "cina",
    "cinase": "cina",
    "cinasem": "cina",
    "cinaseră": "cina",
    "cinaserăm": "cina",
    "cinaserăți": "cina",
    "cinaseși": "cina",
    "cinași": "cina",
    "cinat": "cina",
    "cinați": "cina",
    "cinatu": "cina",
    "cinau": "cina",
    "cinează": "cina",
    "cinez": "cina",
    "cineze": "cina",
    "cinezi": "cina",
    "necinând": "cina",
    "necinându": "cina",
    "nemaicinând": "cina",
    "nemaicinându": "cina",
    "cina": "cină",
    "cine": "cină",
    "cinei": "cină",
    "cinele": "cină",
    "cinelor": "cină",
    "cino": "cină",
    "cinată": "cinat",
    "cinate": "cinat",
    "cinați": "cinat",
    "cincea": "cinci",
    "cincilea": "cinci",
    "cinciul": "cinci",
    "cinciului": "cinci",
    "V": "cinci",
    "cincimea": "cincime",
    "cincimi": "cincime",
    "cincimii": "cincime",
    "cincimile": "cincime",
    "cincimilor": "cincime",
    "cincinale": "cincinal",
    "cincinalele": "cincinal",
    "cincinalelor": "cincinal",
    "cincinalul": "cincinal",
    "cincinalule": "cincinal",
    "cincinalului": "cincinal",
    "cincisprezecea": "cincisprezece",
    "cincisprezecelea": "cincisprezece",
    "cinșpe": "cincisprezece",
    "cinșpea": "cincisprezece",
    "cinșpelea": "cincisprezece",
    "cinsprezece": "cincisprezece",
    "XV": "cincisprezece",
    "cincisprezecimea": "cincisprezecime",
    "cincisprezecimi": "cincisprezecime",
    "cincisprezecimii": "cincisprezecime",
    "cincisprezecimile": "cincisprezecime",
    "cincisprezecimilor": "cincisprezecime",
    "cincizecea": "cincizeci",
    "cincizecilea": "cincizeci",
    "L": "cincizeci",
    "cui": "cine",
    "cine_știe_cărui": "cine_știe_care",
    "cine_știe_câte": "cine_știe_cât",
    "cineaști": "cineast",
    "cineaștii": "cineast",
    "cineaștilor": "cineast",
    "cineastul": "cineast",
    "cineastule": "cineast",
    "cineastului": "cineast",
    "cineasta": "cineastă",
    "cineaste": "cineastă",
    "cineastei": "cineastă",
    "cineastele": "cineastă",
    "cineastelor": "cineastă",
    "cineasto": "cineastă",
    "cinefili": "cinefil",
    "cinefilii": "cinefil",
    "cinefililor": "cinefil",
    "cinefilul": "cinefil",
    "cinefilule": "cinefil",
    "cinefilului": "cinefil",
    "cinefila": "cinefilă",
    "cinefile": "cinefilă",
    "cinefilei": "cinefilă",
    "cinefilele": "cinefilă",
    "cinefilelor": "cinefilă",
    "cinefilo": "cinefilă",
    "cinegetica": "cinegetic",
    "cinegetică": "cinegetic",
    "cinegetice": "cinegetic",
    "cinegeticei": "cinegetic",
    "cinegeticele": "cinegetic",
    "cinegeticelor": "cinegetic",
    "cinegetici": "cinegetic",
    "cinegeticii": "cinegetic",
    "cinegeticilor": "cinegetic",
    "cinegetico": "cinegetic",
    "cinegeticul": "cinegetic",
    "cinegeticule": "cinegetic",
    "cinegeticului": "cinegetic",
    "cinematica": "cinematică",
    "cinematice": "cinematică",
    "cinematicei": "cinematică",
    "cinematico": "cinematică",
    "cinematografe": "cinematograf",
    "cinematografele": "cinematograf",
    "cinematografelor": "cinematograf",
    "cinematograful": "cinematograf",
    "cinematografule": "cinematograf",
    "cinematografului": "cinematograf",
    "cinematografiai": "cinematografia",
    "cinematografiam": "cinematografia",
    "cinematografiară": "cinematografia",
    "cinematografiarăm": "cinematografia",
    "cinematografiarăți": "cinematografia",
    "cinematografiase": "cinematografia",
    "cinematografiasem": "cinematografia",
    "cinematografiaseră": "cinematografia",
    "cinematografiaserăm": "cinematografia",
    "cinematografiaserăți": "cinematografia",
    "cinematografiaseși": "cinematografia",
    "cinematografiași": "cinematografia",
    "cinematografiat": "cinematografia",
    "cinematografiați": "cinematografia",
    "cinematografiatu": "cinematografia",
    "cinematografiau": "cinematografia",
    "cinematografiază": "cinematografia",
    "cinematografie": "cinematografia",
    "cinematografiem": "cinematografia",
    "cinematografiez": "cinematografia",
    "cinematografieze": "cinematografia",
    "cinematografiezi": "cinematografia",
    "cinematografiind": "cinematografia",
    "cinematografiindu": "cinematografia",
    "necinematografiind": "cinematografia",
    "necinematografiindu": "cinematografia",
    "nemaicinematografiind": "cinematografia",
    "nemaicinematografiindu": "cinematografia",
    "cinematografiată": "cinematografiat",
    "cinematografiate": "cinematografiat",
    "cinematografiați": "cinematografiat",
    "cinematografica": "cinematografic",
    "cinematografică": "cinematografic",
    "cinematografice": "cinematografic",
    "cinematograficei": "cinematografic",
    "cinematograficele": "cinematografic",
    "cinematograficelor": "cinematografic",
    "cinematografici": "cinematografic",
    "cinematograficii": "cinematografic",
    "cinematograficilor": "cinematografic",
    "cinematografico": "cinematografic",
    "cinematograficul": "cinematografic",
    "cinematograficule": "cinematografic",
    "cinematograficului": "cinematografic",
    "cinematografia": "cinematografie",
    "cinematografiei": "cinematografie",
    "cinematografii": "cinematografie",
    "cinematografiile": "cinematografie",
    "cinematografiilor": "cinematografie",
    "cinematografio": "cinematografie",
    "cinetica": "cinetic",
    "cinetică": "cinetic",
    "cinetice": "cinetic",
    "cineticei": "cinetic",
    "cineticele": "cinetic",
    "cineticelor": "cinetic",
    "cinetici": "cinetic",
    "cineticii": "cinetic",
    "cineticilor": "cinetic",
    "cinetico": "cinetic",
    "cineticul": "cinetic",
    "cineticule": "cinetic",
    "cineticului": "cinetic",
    "cinetica": "cinetică",
    "cinetice": "cinetică",
    "cineticei": "cinetică",
    "cinetico": "cinetică",
    "cuiva": "cineva",
    "cingătoarea": "cingătoare",
    "cingătoareo": "cingătoare",
    "cingători": "cingătoare",
    "cingătorii": "cingătoare",
    "cingătorile": "cingătoare",
    "cingătorilor": "cingătoare",
    "cinica": "cinic",
    "cinică": "cinic",
    "cinice": "cinic",
    "cinicei": "cinic",
    "cinicele": "cinic",
    "cinicelor": "cinic",
    "cinici": "cinic",
    "cinicii": "cinic",
    "cinicilor": "cinic",
    "cinico": "cinic",
    "cinicul": "cinic",
    "cinicule": "cinic",
    "cinicului": "cinic",
    "cinica": "cinică",
    "cinice": "cinică",
    "cinicei": "cinică",
    "cinicele": "cinică",
    "cinicelor": "cinică",
    "cinico": "cinică",
    "cinisme": "cinism",
    "cinismele": "cinism",
    "cinismelor": "cinism",
    "cinismul": "cinism",
    "cinismule": "cinism",
    "cinismului": "cinism",
    "cinocefali": "cinocefal",
    "cinocefalii": "cinocefal",
    "cinocefalilor": "cinocefal",
    "cinocefalul": "cinocefal",
    "cinocefalule": "cinocefal",
    "cinocefalului": "cinocefal",
    "cinstea": "cinste",
    "cinstei": "cinste",
    "cinsteo": "cinste",
    "cinstea": "cinsti",
    "cinsteai": "cinsti",
    "cinsteam": "cinsti",
    "cinstească": "cinsti",
    "cinsteați": "cinsti",
    "cinsteau": "cinsti",
    "cinstesc": "cinsti",
    "cinstește": "cinsti",
    "cinstești": "cinsti",
    "cinstii": "cinsti",
    "cinstim": "cinsti",
    "cinstind": "cinsti",
    "cinstindu": "cinsti",
    "cinstiră": "cinsti",
    "cinstirăm": "cinsti",
    "cinstirăți": "cinsti",
    "cinstise": "cinsti",
    "cinstisem": "cinsti",
    "cinstiseră": "cinsti",
    "cinstiserăm": "cinsti",
    "cinstiserăți": "cinsti",
    "cinstiseși": "cinsti",
    "cinstiși": "cinsti",
    "cinstit": "cinsti",
    "cinstiți": "cinsti",
    "cinstitu": "cinsti",
    "nemaicinstind": "cinsti",
    "nemaicinstindu": "cinsti",
    "cinstirea": "cinstire",
    "cinstireo": "cinstire",
    "cinstiri": "cinstire",
    "cinstirii": "cinstire",
    "cinstirile": "cinstire",
    "cinstirilor": "cinstire",
    "cinstita": "cinstit",
    "cinstită": "cinstit",
    "cinstite": "cinstit",
    "cinstitei": "cinstit",
    "cinstitele": "cinstit",
    "cinstitelor": "cinstit",
    "cinstiți": "cinstit",
    "cinstiții": "cinstit",
    "cinstiților": "cinstit",
    "cinstito": "cinstit",
    "cinstitul": "cinstit",
    "cinstitule": "cinstit",
    "cinstitului": "cinstit",
    "cinteza": "cinteză",
    "cinteze": "cinteză",
    "cintezei": "cinteză",
    "cintezele": "cinteză",
    "cintezelor": "cinteză",
    "cintezoii": "cintezoi",
    "cintezoilor": "cintezoi",
    "cintezoiul": "cintezoi",
    "cintezoiule": "cintezoi",
    "cintezoiului": "cintezoi",
    "cintre": "cintru",
    "cintrele": "cintru",
    "cintrelor": "cintru",
    "cintrul": "cintru",
    "cintrule": "cintru",
    "cintrului": "cintru",
    "cinzeaca": "cinzeacă",
    "cinzeaco": "cinzeacă",
    "cinzeci": "cinzeacă",
    "cinzecii": "cinzeacă",
    "cinzecile": "cinzeacă",
    "cinzecilor": "cinzeacă",
    "cioara": "cioară",
    "cioaro": "cioară",
    "ciori": "cioară",
    "ciorii": "cioară",
    "ciorile": "cioară",
    "ciorilor": "cioară",
    "cioarecii": "cioareci",
    "cioarecilor": "cioareci",
    "cioarsa": "cioarsă",
    "cioarse": "cioarsă",
    "cioarsei": "cioarsă",
    "cioarsele": "cioarsă",
    "cioarselor": "cioarsă",
    "cioarso": "cioarsă",
    "cioata": "cioată",
    "cioate": "cioată",
    "cioatei": "cioată",
    "cioatele": "cioată",
    "cioatelor": "cioată",
    "cioato": "cioată",
    "cioatca": "cioatcă",
    "cioatce": "cioatcă",
    "cioatcei": "cioatcă",
    "cioatcele": "cioatcă",
    "cioatcelor": "cioatcă",
    "cioatco": "cioatcă",
    "ciobul": "ciob",
    "ciobule": "ciob",
    "ciobului": "ciob",
    "cioburi": "ciob",
    "cioburile": "ciob",
    "cioburilor": "ciob",
    "ciobani": "cioban",
    "ciobanii": "cioban",
    "ciobanilor": "cioban",
    "ciobanul": "cioban",
    "ciobanule": "cioban",
    "ciobanului": "cioban",
    "ciobănași": "ciobănaș",
    "ciobănașii": "ciobănaș",
    "ciobănașilor": "ciobănaș",
    "ciobănașul": "ciobănaș",
    "ciobănașule": "ciobănaș",
    "ciobănașului": "ciobănaș",
    "ciobănei": "ciobănel",
    "ciobăneii": "ciobănel",
    "ciobăneilor": "ciobănel",
    "ciobănelul": "ciobănel",
    "ciobănelule": "ciobănel",
    "ciobănelului": "ciobănel",
    "ciobăneasca": "ciobănesc",
    "ciobănească": "ciobănesc",
    "ciobăneasco": "ciobănesc",
    "ciobănescul": "ciobănesc",
    "ciobănescule": "ciobănesc",
    "ciobănescului": "ciobănesc",
    "ciobănești": "ciobănesc",
    "ciobăneștii": "ciobănesc",
    "ciobăneștile": "ciobănesc",
    "ciobăneștilor": "ciobănesc",
    "ciobănea": "ciobăni",
    "ciobăneai": "ciobăni",
    "ciobăneam": "ciobăni",
    "ciobănească": "ciobăni",
    "ciobăneați": "ciobăni",
    "ciobăneau": "ciobăni",
    "ciobănesc": "ciobăni",
    "ciobănește": "ciobăni",
    "ciobănești": "ciobăni",
    "ciobănii": "ciobăni",
    "ciobănim": "ciobăni",
    "ciobănind": "ciobăni",
    "ciobănindu": "ciobăni",
    "ciobăniră": "ciobăni",
    "ciobănirăm": "ciobăni",
    "ciobănirăți": "ciobăni",
    "ciobănise": "ciobăni",
    "ciobănisem": "ciobăni",
    "ciobăniseră": "ciobăni",
    "ciobăniserăm": "ciobăni",
    "ciobăniserăți": "ciobăni",
    "ciobăniseși": "ciobăni",
    "ciobăniși": "ciobăni",
    "ciobănit": "ciobăni",
    "ciobăniți": "ciobăni",
    "ciobănitu": "ciobăni",
    "neciobănind": "ciobăni",
    "neciobănindu": "ciobăni",
    "nemaiciobănind": "ciobăni",
    "nemaiciobănindu": "ciobăni",
    "ciobănia": "ciobănie",
    "ciobăniei": "ciobănie",
    "ciobănii": "ciobănie",
    "ciobăniile": "ciobănie",
    "ciobăniilor": "ciobănie",
    "ciobănio": "ciobănie",
    "ciobănită": "ciobănit",
    "ciobănite": "ciobănit",
    "ciobăniți": "ciobănit",
    "ciobănița": "ciobăniță",
    "ciobănițe": "ciobăniță",
    "ciobăniței": "ciobăniță",
    "ciobănițele": "ciobăniță",
    "ciobănițelor": "ciobăniță",
    "ciobănițo": "ciobăniță",
    "ciobea": "ciobi",
    "ciobeai": "ciobi",
    "ciobeam": "ciobi",
    "ciobească": "ciobi",
    "ciobeați": "ciobi",
    "ciobeau": "ciobi",
    "ciobesc": "ciobi",
    "ciobește": "ciobi",
    "ciobești": "ciobi",
    "ciobii": "ciobi",
    "ciobim": "ciobi",
    "ciobind": "ciobi",
    "ciobindu": "ciobi",
    "ciobiră": "ciobi",
    "ciobirăm": "ciobi",
    "ciobirăți": "ciobi",
    "ciobise": "ciobi",
    "ciobisem": "ciobi",
    "ciobiseră": "ciobi",
    "ciobiserăm": "ciobi",
    "ciobiserăți": "ciobi",
    "ciobiseși": "ciobi",
    "ciobiși": "ciobi",
    "ciobit": "ciobi",
    "ciobiți": "ciobi",
    "ciobitu": "ciobi",
    "neciobind": "ciobi",
    "neciobindu": "ciobi",
    "nemaiciobind": "ciobi",
    "nemaiciobindu": "ciobi",
    "ciobită": "ciobit",
    "ciobite": "ciobit",
    "ciobiți": "ciobit",
    "ciobitura": "ciobitură",
    "ciobituri": "ciobitură",
    "ciobiturii": "ciobitură",
    "ciobiturile": "ciobitură",
    "ciobiturilor": "ciobitură",
    "ciocul": "cioc",
    "ciocule": "cioc",
    "ciocului": "cioc",
    "ciocuri": "cioc",
    "ciocurile": "cioc",
    "ciocurilor": "cioc",
    "ciocălăi": "ciocălău",
    "ciocălăii": "ciocălău",
    "ciocălăilor": "ciocălău",
    "ciocălăul": "ciocălău",
    "ciocălăule": "ciocălău",
    "ciocălăului": "ciocălău",
    "ciocane": "ciocan",
    "ciocanele": "ciocan",
    "ciocanelor": "ciocan",
    "ciocanul": "ciocan",
    "ciocanule": "ciocan",
    "ciocanului": "ciocan",
    "ciocănașe": "ciocănaș",
    "ciocănașele": "ciocănaș",
    "ciocănașelor": "ciocănaș",
    "ciocănașul": "ciocănaș",
    "ciocănașule": "ciocănaș",
    "ciocănașului": "ciocănaș",
    "ciocănele": "ciocănel",
    "ciocănelele": "ciocănel",
    "ciocănelelor": "ciocănel",
    "ciocănelul": "ciocănel",
    "ciocănelule": "ciocănel",
    "ciocănelului": "ciocănel",
    "ciocănea": "ciocăni",
    "ciocăneai": "ciocăni",
    "ciocăneam": "ciocăni",
    "ciocănească": "ciocăni",
    "ciocăneați": "ciocăni",
    "ciocăneau": "ciocăni",
    "ciocănesc": "ciocăni",
    "ciocănește": "ciocăni",
    "ciocănești": "ciocăni",
    "ciocănii": "ciocăni",
    "ciocănim": "ciocăni",
    "ciocănind": "ciocăni",
    "ciocănindu": "ciocăni",
    "ciocăniră": "ciocăni",
    "ciocănirăm": "ciocăni",
    "ciocănirăți": "ciocăni",
    "ciocănise": "ciocăni",
    "ciocănisem": "ciocăni",
    "ciocăniseră": "ciocăni",
    "ciocăniserăm": "ciocăni",
    "ciocăniserăți": "ciocăni",
    "ciocăniseși": "ciocăni",
    "ciocăniși": "ciocăni",
    "ciocănit": "ciocăni",
    "ciocăniți": "ciocăni",
    "ciocănitu": "ciocăni",
    "neciocănind": "ciocăni",
    "neciocănindu": "ciocăni",
    "nemaiciocănind": "ciocăni",
    "nemaiciocănindu": "ciocăni",
    "ciocănirea": "ciocănire",
    "ciocănireo": "ciocănire",
    "ciocăniri": "ciocănire",
    "ciocănirii": "ciocănire",
    "ciocănirile": "ciocănire",
    "ciocănirilor": "ciocănire",
    "ciocănită": "ciocănit",
    "ciocănite": "ciocănit",
    "ciocăniți": "ciocănit",
    "ciocănitul": "ciocănit",
    "ciocănitule": "ciocănit",
    "ciocănitului": "ciocănit",
    "ciocănituri": "ciocănit",
    "ciocăniturile": "ciocănit",
    "ciocăniturilor": "ciocănit",
    "ciocănitoarea": "ciocănitoare",
    "ciocănitoareo": "ciocănitoare",
    "ciocănitori": "ciocănitoare",
    "ciocănitorii": "ciocănitoare",
    "ciocănitorile": "ciocănitoare",
    "ciocănitorilor": "ciocănitoare",
    "ciocănitura": "ciocănitură",
    "ciocănituri": "ciocănitură",
    "ciocăniturii": "ciocănitură",
    "ciocăniturile": "ciocănitură",
    "ciocăniturilor": "ciocănitură",
    "ciocănituro": "ciocănitură",
    "ciocârlani": "ciocârlan",
    "ciocârlanii": "ciocârlan",
    "ciocârlanilor": "ciocârlan",
    "ciocârlanul": "ciocârlan",
    "ciocârlanule": "ciocârlan",
    "ciocârlanului": "ciocârlan",
    "ciocârlia": "ciocârlie",
    "ciocârliei": "ciocârlie",
    "ciocârlii": "ciocârlie",
    "ciocârliile": "ciocârlie",
    "ciocârliilor": "ciocârlie",
    "ciocârlio": "ciocârlie",
    "ciocârtea": "ciocârti",
    "ciocârteai": "ciocârti",
    "ciocârteam": "ciocârti",
    "ciocârtească": "ciocârti",
    "ciocârteați": "ciocârti",
    "ciocârteau": "ciocârti",
    "ciocârtesc": "ciocârti",
    "ciocârtește": "ciocârti",
    "ciocârtești": "ciocârti",
    "ciocârtii": "ciocârti",
    "ciocârtim": "ciocârti",
    "ciocârtind": "ciocârti",
    "ciocârtindu": "ciocârti",
    "ciocârtiră": "ciocârti",
    "ciocârtirăm": "ciocârti",
    "ciocârtirăți": "ciocârti",
    "ciocârtise": "ciocârti",
    "ciocârtisem": "ciocârti",
    "ciocârtiseră": "ciocârti",
    "ciocârtiserăm": "ciocârti",
    "ciocârtiserăți": "ciocârti",
    "ciocârtiseși": "ciocârti",
    "ciocârtiși": "ciocârti",
    "ciocârtit": "ciocârti",
    "ciocârtiți": "ciocârti",
    "ciocârtitu": "ciocârti",
    "neciocârtind": "ciocârti",
    "neciocârtindu": "ciocârti",
    "nemaiciocârtind": "ciocârti",
    "nemaiciocârtindu": "ciocârti",
    "ciocârtită": "ciocârtit",
    "ciocârtite": "ciocârtit",
    "ciocârtiți": "ciocârtit",
    "cioclovina": "cioclovină",
    "cioclovine": "cioclovină",
    "cioclovinei": "cioclovină",
    "cioclovinele": "cioclovină",
    "cioclovinelor": "cioclovină",
    "cioclovino": "cioclovină",
    "ciocli": "cioclu",
    "cioclii": "cioclu",
    "cioclilor": "cioclu",
    "cioclul": "cioclu",
    "cioclule": "cioclu",
    "cioclului": "cioclu",
    "ciocneala": "ciocneală",
    "ciocnealo": "ciocneală",
    "ciocneli": "ciocneală",
    "ciocnelii": "ciocneală",
    "ciocnelile": "ciocneală",
    "ciocnelilor": "ciocneală",
    "ciocnete": "ciocnet",
    "ciocnetele": "ciocnet",
    "ciocnetelor": "ciocnet",
    "ciocnetul": "ciocnet",
    "ciocnetule": "ciocnet",
    "ciocnetului": "ciocnet",
    "ciocnea": "ciocni",
    "ciocneai": "ciocni",
    "ciocneam": "ciocni",
    "ciocnească": "ciocni",
    "ciocneați": "ciocni",
    "ciocneau": "ciocni",
    "ciocnesc": "ciocni",
    "ciocnește": "ciocni",
    "ciocnești": "ciocni",
    "ciocnii": "ciocni",
    "ciocnim": "ciocni",
    "ciocnind": "ciocni",
    "ciocnindu": "ciocni",
    "ciocniră": "ciocni",
    "ciocnirăm": "ciocni",
    "ciocnirăți": "ciocni",
    "ciocnise": "ciocni",
    "ciocnisem": "ciocni",
    "ciocniseră": "ciocni",
    "ciocniserăm": "ciocni",
    "ciocniserăți": "ciocni",
    "ciocniseși": "ciocni",
    "ciocniși": "ciocni",
    "ciocnit": "ciocni",
    "ciocniți": "ciocni",
    "ciocnitu": "ciocni",
    "neciocnind": "ciocni",
    "neciocnindu": "ciocni",
    "nemaiciocnind": "ciocni",
    "nemaiciocnindu": "ciocni",
    "ciocnirea": "ciocnire",
    "ciocnireo": "ciocnire",
    "ciocniri": "ciocnire",
    "ciocnirii": "ciocnire",
    "ciocnirile": "ciocnire",
    "ciocnirilor": "ciocnire",
    "ciocnita": "ciocnit",
    "ciocnită": "ciocnit",
    "ciocnite": "ciocnit",
    "ciocnitei": "ciocnit",
    "ciocnitele": "ciocnit",
    "ciocnitelor": "ciocnit",
    "ciocniți": "ciocnit",
    "ciocniții": "ciocnit",
    "ciocniților": "ciocnit",
    "ciocnito": "ciocnit",
    "ciocnitul": "ciocnit",
    "ciocnitule": "ciocnit",
    "ciocnitului": "ciocnit",
    "ciocoaica": "ciocoaică",
    "ciocoaice": "ciocoaică",
    "ciocoaicei": "ciocoaică",
    "ciocoaicele": "ciocoaică",
    "ciocoaicelor": "ciocoaică",
    "ciocoaico": "ciocoaică",
    "ciocofleandura": "ciocofleandură",
    "ciocofleanduro": "ciocofleandură",
    "ciocoflendure": "ciocofleandură",
    "ciocoflendurei": "ciocofleandură",
    "ciocoflendurele": "ciocofleandură",
    "ciocoflendurelor": "ciocofleandură",
    "ciocoia": "ciocoi",
    "ciocoiai": "ciocoi",
    "ciocoiam": "ciocoi",
    "ciocoiască": "ciocoi",
    "ciocoiați": "ciocoi",
    "ciocoiau": "ciocoi",
    "ciocoiesc": "ciocoi",
    "ciocoiește": "ciocoi",
    "ciocoiești": "ciocoi",
    "ciocoii": "ciocoi",
    "ciocoilor": "ciocoi",
    "ciocoim": "ciocoi",
    "ciocoind": "ciocoi",
    "ciocoindu": "ciocoi",
    "ciocoiră": "ciocoi",
    "ciocoirăm": "ciocoi",
    "ciocoirăți": "ciocoi",
    "ciocoise": "ciocoi",
    "ciocoisem": "ciocoi",
    "ciocoiseră": "ciocoi",
    "ciocoiserăm": "ciocoi",
    "ciocoiserăți": "ciocoi",
    "ciocoiseși": "ciocoi",
    "ciocoiși": "ciocoi",
    "ciocoit": "ciocoi",
    "ciocoiți": "ciocoi",
    "ciocoitu": "ciocoi",
    "ciocoiul": "ciocoi",
    "ciocoiule": "ciocoi",
    "ciocoiului": "ciocoi",
    "neciocoind": "ciocoi",
    "neciocoindu": "ciocoi",
    "nemaiciocoind": "ciocoi",
    "nemaiciocoindu": "ciocoi",
    "ciocoiași": "ciocoiaș",
    "ciocoiașii": "ciocoiaș",
    "ciocoiașilor": "ciocoiaș",
    "ciocoiașul": "ciocoiaș",
    "ciocoiașule": "ciocoiaș",
    "ciocoiașului": "ciocoiaș",
    "ciocoieasca": "ciocoiesc",
    "ciocoiească": "ciocoiesc",
    "ciocoieasco": "ciocoiesc",
    "ciocoiescul": "ciocoiesc",
    "ciocoiescule": "ciocoiesc",
    "ciocoiescului": "ciocoiesc",
    "ciocoiești": "ciocoiesc",
    "ciocoieștii": "ciocoiesc",
    "ciocoieștile": "ciocoiesc",
    "ciocoieștilor": "ciocoiesc",
    "ciocoimea": "ciocoime",
    "ciocoimeo": "ciocoime",
    "ciocoimi": "ciocoime",
    "ciocoimii": "ciocoime",
    "ciocoimile": "ciocoime",
    "ciocoimilor": "ciocoime",
    "ciocoisme": "ciocoism",
    "ciocoismele": "ciocoism",
    "ciocoismelor": "ciocoism",
    "ciocoismul": "ciocoism",
    "ciocoismule": "ciocoism",
    "ciocoismului": "ciocoism",
    "ciocoită": "ciocoit",
    "ciocoite": "ciocoit",
    "ciocoiți": "ciocoit",
    "ciocolata": "ciocolată",
    "ciocolate": "ciocolată",
    "ciocolatei": "ciocolată",
    "ciocolatele": "ciocolată",
    "ciocolatelor": "ciocolată",
    "ciocolato": "ciocolată",
    "cioculețe": "cioculeț",
    "cioculețele": "cioculeț",
    "cioculețelor": "cioculeț",
    "cioculețul": "cioculeț",
    "cioculețule": "cioculeț",
    "cioculețului": "cioculeț",
    "cioflingari": "cioflingar",
    "cioflingarii": "cioflingar",
    "cioflingarilor": "cioflingar",
    "cioflingarul": "cioflingar",
    "cioflingarule": "cioflingar",
    "cioflingarului": "cioflingar",
    "ciolane": "ciolan",
    "ciolanele": "ciolan",
    "ciolanelor": "ciolan",
    "ciolanul": "ciolan",
    "ciolanule": "ciolan",
    "ciolanului": "ciolan",
    "ciolănași": "ciolănaș",
    "ciolănașii": "ciolănaș",
    "ciolănașilor": "ciolănaș",
    "ciolănașul": "ciolănaș",
    "ciolănașule": "ciolănaș",
    "ciolănașului": "ciolănaș",
    "ciolănei": "ciolănel",
    "ciolăneii": "ciolănel",
    "ciolăneilor": "ciolănel",
    "ciolănelul": "ciolănel",
    "ciolănelule": "ciolănel",
    "ciolănelului": "ciolănel",
    "ciolănoasa": "ciolănos",
    "ciolănoasă": "ciolănos",
    "ciolănoase": "ciolănos",
    "ciolănoasei": "ciolănos",
    "ciolănoasele": "ciolănos",
    "ciolănoaselor": "ciolănos",
    "ciolănoaso": "ciolănos",
    "ciolănoși": "ciolănos",
    "ciolănoșii": "ciolănos",
    "ciolănoșilor": "ciolănos",
    "ciolănosul": "ciolănos",
    "ciolănosule": "ciolănos",
    "ciolănosului": "ciolănos",
    "ciolpani": "ciolpan",
    "ciolpanii": "ciolpan",
    "ciolpanilor": "ciolpan",
    "ciolpanul": "ciolpan",
    "ciolpanule": "ciolpan",
    "ciolpanului": "ciolpan",
    "ciomagul": "ciomag",
    "ciomagule": "ciomag",
    "ciomagului": "ciomag",
    "ciomege": "ciomag",
    "ciomegele": "ciomag",
    "ciomegelor": "ciomag",
    "ciomăgari": "ciomăgar",
    "ciomăgarii": "ciomăgar",
    "ciomăgarilor": "ciomăgar",
    "ciomăgarul": "ciomăgar",
    "ciomăgarule": "ciomăgar",
    "ciomăgarului": "ciomăgar",
    "ciomăgași": "ciomăgaș",
    "ciomăgașii": "ciomăgaș",
    "ciomăgașilor": "ciomăgaș",
    "ciomăgașul": "ciomăgaș",
    "ciomăgașule": "ciomăgaș",
    "ciomăgașului": "ciomăgaș",
    "ciomăgeala": "ciomăgeală",
    "ciomăgealo": "ciomăgeală",
    "ciomăgeli": "ciomăgeală",
    "ciomăgelii": "ciomăgeală",
    "ciomăgelile": "ciomăgeală",
    "ciomăgelilor": "ciomăgeală",
    "ciomăgele": "ciomăgel",
    "ciomăgelele": "ciomăgel",
    "ciomăgelelor": "ciomăgel",
    "ciomăgelul": "ciomăgel",
    "ciomăgelule": "ciomăgel",
    "ciomăgelului": "ciomăgel",
    "ciomăgea": "ciomăgi",
    "ciomăgeai": "ciomăgi",
    "ciomăgeam": "ciomăgi",
    "ciomăgească": "ciomăgi",
    "ciomăgeați": "ciomăgi",
    "ciomăgeau": "ciomăgi",
    "ciomăgesc": "ciomăgi",
    "ciomăgește": "ciomăgi",
    "ciomăgești": "ciomăgi",
    "ciomăgii": "ciomăgi",
    "ciomăgim": "ciomăgi",
    "ciomăgind": "ciomăgi",
    "ciomăgindu": "ciomăgi",
    "ciomăgiră": "ciomăgi",
    "ciomăgirăm": "ciomăgi",
    "ciomăgirăți": "ciomăgi",
    "ciomăgise": "ciomăgi",
    "ciomăgisem": "ciomăgi",
    "ciomăgiseră": "ciomăgi",
    "ciomăgiserăm": "ciomăgi",
    "ciomăgiserăți": "ciomăgi",
    "ciomăgiseși": "ciomăgi",
    "ciomăgiși": "ciomăgi",
    "ciomăgit": "ciomăgi",
    "ciomăgiți": "ciomăgi",
    "ciomăgitu": "ciomăgi",
    "neciomăgind": "ciomăgi",
    "neciomăgindu": "ciomăgi",
    "nemaiciomăgind": "ciomăgi",
    "nemaiciomăgindu": "ciomăgi",
    "ciomăgită": "ciomăgit",
    "ciomăgite": "ciomăgit",
    "ciomăgiți": "ciomăgit",
    "ciompul": "ciomp",
    "ciompule": "ciomp",
    "ciompului": "ciomp",
    "ciompuri": "ciomp",
    "ciompurile": "ciomp",
    "ciompurilor": "ciomp",
    "ciondăneala": "ciondăneală",
    "ciondănealo": "ciondăneală",
    "ciondăneli": "ciondăneală",
    "ciondănelii": "ciondăneală",
    "ciondănelile": "ciondăneală",
    "ciondănelilor": "ciondăneală",
    "ciondănea": "ciondăni",
    "ciondăneai": "ciondăni",
    "ciondăneam": "ciondăni",
    "ciondănească": "ciondăni",
    "ciondăneați": "ciondăni",
    "ciondăneau": "ciondăni",
    "ciondănesc": "ciondăni",
    "ciondănește": "ciondăni",
    "ciondănești": "ciondăni",
    "ciondănii": "ciondăni",
    "ciondănim": "ciondăni",
    "ciondănind": "ciondăni",
    "ciondănindu": "ciondăni",
    "ciondăniră": "ciondăni",
    "ciondănirăm": "ciondăni",
    "ciondănirăți": "ciondăni",
    "ciondănise": "ciondăni",
    "ciondănisem": "ciondăni",
    "ciondăniseră": "ciondăni",
    "ciondăniserăm": "ciondăni",
    "ciondăniserăți": "ciondăni",
    "ciondăniseși": "ciondăni",
    "ciondăniși": "ciondăni",
    "ciondănit": "ciondăni",
    "ciondăniți": "ciondăni",
    "ciondănitu": "ciondăni",
    "neciondănind": "ciondăni",
    "neciondănindu": "ciondăni",
    "nemaiciondănind": "ciondăni",
    "nemaiciondănindu": "ciondăni",
    "ciondănită": "ciondănit",
    "ciondănite": "ciondănit",
    "ciondăniți": "ciondănit",
    "ciopârțeala": "ciopârțeală",
    "ciopârțealo": "ciopârțeală",
    "ciopârțeli": "ciopârțeală",
    "ciopârțelii": "ciopârțeală",
    "ciopârțelile": "ciopârțeală",
    "ciopârțelilor": "ciopârțeală",
    "ciopârțea": "ciopârți",
    "ciopârțeai": "ciopârți",
    "ciopârțeam": "ciopârți",
    "ciopârțească": "ciopârți",
    "ciopârțeați": "ciopârți",
    "ciopârțeau": "ciopârți",
    "ciopârțesc": "ciopârți",
    "ciopârțește": "ciopârți",
    "ciopârțești": "ciopârți",
    "ciopârții": "ciopârți",
    "ciopârțim": "ciopârți",
    "ciopârțind": "ciopârți",
    "ciopârțindu": "ciopârți",
    "ciopârțiră": "ciopârți",
    "ciopârțirăm": "ciopârți",
    "ciopârțirăți": "ciopârți",
    "ciopârțise": "ciopârți",
    "ciopârțisem": "ciopârți",
    "ciopârțiseră": "ciopârți",
    "ciopârțiserăm": "ciopârți",
    "ciopârțiserăți": "ciopârți",
    "ciopârțiseși": "ciopârți",
    "ciopârțiși": "ciopârți",
    "ciopârțit": "ciopârți",
    "ciopârțiți": "ciopârți",
    "ciopârțitu": "ciopârți",
    "neciopârțind": "ciopârți",
    "neciopârțindu": "ciopârți",
    "nemaiciopârțind": "ciopârți",
    "nemaiciopârțindu": "ciopârți",
    "ciopârțirea": "ciopârțire",
    "ciopârțireo": "ciopârțire",
    "ciopârțiri": "ciopârțire",
    "ciopârțirii": "ciopârțire",
    "ciopârțirile": "ciopârțire",
    "ciopârțirilor": "ciopârțire",
    "ciopârțită": "ciopârțit",
    "ciopârțite": "ciopârțit",
    "ciopârțiți": "ciopârțit",
    "ciopleala": "ciopleală",
    "cioplealo": "ciopleală",
    "ciopleli": "ciopleală",
    "cioplelii": "ciopleală",
    "cioplelile": "ciopleală",
    "cioplelilor": "ciopleală",
    "cioplea": "ciopli",
    "ciopleai": "ciopli",
    "ciopleam": "ciopli",
    "cioplească": "ciopli",
    "ciopleați": "ciopli",
    "ciopleau": "ciopli",
    "cioplesc": "ciopli",
    "cioplește": "ciopli",
    "cioplești": "ciopli",
    "cioplii": "ciopli",
    "cioplim": "ciopli",
    "cioplind": "ciopli",
    "cioplindu": "ciopli",
    "ciopliră": "ciopli",
    "cioplirăm": "ciopli",
    "cioplirăți": "ciopli",
    "cioplise": "ciopli",
    "cioplisem": "ciopli",
    "ciopliseră": "ciopli",
    "ciopliserăm": "ciopli",
    "ciopliserăți": "ciopli",
    "ciopliseși": "ciopli",
    "ciopliși": "ciopli",
    "cioplit": "ciopli",
    "ciopliți": "ciopli",
    "cioplitu": "ciopli",
    "necioplind": "ciopli",
    "necioplindu": "ciopli",
    "nemaicioplind": "ciopli",
    "nemaicioplindu": "ciopli",
    "cioplirea": "cioplire",
    "cioplireo": "cioplire",
    "ciopliri": "cioplire",
    "cioplirii": "cioplire",
    "cioplirile": "cioplire",
    "cioplirilor": "cioplire",
    "cioplită": "cioplit",
    "cioplite": "cioplit",
    "ciopliți": "cioplit",
    "cioplitoarea": "cioplitoare",
    "cioplitoarei": "cioplitoare",
    "cioplitoarele": "cioplitoare",
    "cioplitoarelor": "cioplitoare",
    "cioplitoareo": "cioplitoare",
    "cioplitori": "cioplitor",
    "cioplitorii": "cioplitor",
    "cioplitorilor": "cioplitor",
    "cioplitorul": "cioplitor",
    "cioplitorule": "cioplitor",
    "cioplitorului": "cioplitor",
    "cioplitura": "cioplitură",
    "cioplituri": "cioplitură",
    "ciopliturii": "cioplitură",
    "ciopliturile": "cioplitură",
    "ciopliturilor": "cioplitură",
    "cioplituro": "cioplitură",
    "ciopoare": "ciopor",
    "ciopoarele": "ciopor",
    "ciopoarelor": "ciopor",
    "cioporul": "ciopor",
    "cioporule": "ciopor",
    "cioporului": "ciopor",
    "ciorapi": "ciorap",
    "ciorapii": "ciorap",
    "ciorapilor": "ciorap",
    "ciorapul": "ciorap",
    "ciorapule": "ciorap",
    "ciorapului": "ciorap",
    "ciorăpăria": "ciorăpărie",
    "ciorăpăriei": "ciorăpărie",
    "ciorăpării": "ciorăpărie",
    "ciorăpăriile": "ciorăpărie",
    "ciorăpăriilor": "ciorăpărie",
    "ciorăpărio": "ciorăpărie",
    "ciorba": "ciorbă",
    "ciorbe": "ciorbă",
    "ciorbei": "ciorbă",
    "ciorbele": "ciorbă",
    "ciorbelor": "ciorbă",
    "ciorbo": "ciorbă",
    "ciorchinele": "ciorchine",
    "ciorchinelui": "ciorchine",
    "ciorchini": "ciorchine",
    "ciorchinii": "ciorchine",
    "ciorchinilor": "ciorchine",
    "ciordeala": "ciordeală",
    "ciordealo": "ciordeală",
    "ciordeli": "ciordeală",
    "ciordelii": "ciordeală",
    "ciordelile": "ciordeală",
    "ciordelilor": "ciordeală",
    "ciordea": "ciordi",
    "ciordeai": "ciordi",
    "ciordeam": "ciordi",
    "ciordească": "ciordi",
    "ciordeați": "ciordi",
    "ciordeau": "ciordi",
    "ciordesc": "ciordi",
    "ciordește": "ciordi",
    "ciordești": "ciordi",
    "ciordii": "ciordi",
    "ciordim": "ciordi",
    "ciordind": "ciordi",
    "ciordindu": "ciordi",
    "ciordiră": "ciordi",
    "ciordirăm": "ciordi",
    "ciordirăți": "ciordi",
    "ciordise": "ciordi",
    "ciordisem": "ciordi",
    "ciordiseră": "ciordi",
    "ciordiserăm": "ciordi",
    "ciordiserăți": "ciordi",
    "ciordiseși": "ciordi",
    "ciordiși": "ciordi",
    "ciordit": "ciordi",
    "ciordiți": "ciordi",
    "ciorditu": "ciordi",
    "neciordind": "ciordi",
    "neciordindu": "ciordi",
    "nemaiciordind": "ciordi",
    "nemaiciordindu": "ciordi",
    "ciordită": "ciordit",
    "ciordite": "ciordit",
    "ciordiți": "ciordit",
    "ciorna": "ciornă",
    "ciorne": "ciornă",
    "ciornei": "ciornă",
    "ciornele": "ciornă",
    "ciornelor": "ciornă",
    "ciorno": "ciornă",
    "cioroii": "cioroi",
    "cioroilor": "cioroi",
    "cioroiul": "cioroi",
    "cioroiule": "cioroi",
    "cioroiului": "cioroi",
    "ciorovăia": "ciorovăi",
    "ciorovăiai": "ciorovăi",
    "ciorovăiam": "ciorovăi",
    "ciorovăiască": "ciorovăi",
    "ciorovăiați": "ciorovăi",
    "ciorovăiau": "ciorovăi",
    "ciorovăiesc": "ciorovăi",
    "ciorovăiește": "ciorovăi",
    "ciorovăiești": "ciorovăi",
    "ciorovăii": "ciorovăi",
    "ciorovăim": "ciorovăi",
    "ciorovăind": "ciorovăi",
    "ciorovăindu": "ciorovăi",
    "ciorovăiră": "ciorovăi",
    "ciorovăirăm": "ciorovăi",
    "ciorovăirăți": "ciorovăi",
    "ciorovăise": "ciorovăi",
    "ciorovăisem": "ciorovăi",
    "ciorovăiseră": "ciorovăi",
    "ciorovăiserăm": "ciorovăi",
    "ciorovăiserăți": "ciorovăi",
    "ciorovăiseși": "ciorovăi",
    "ciorovăiși": "ciorovăi",
    "ciorovăit": "ciorovăi",
    "ciorovăiți": "ciorovăi",
    "ciorovăitu": "ciorovăi",
    "neciorovăind": "ciorovăi",
    "neciorovăindu": "ciorovăi",
    "nemaiciorovăind": "ciorovăi",
    "nemaiciorovăindu": "ciorovăi",
    "ciorovăiala": "ciorovăială",
    "ciorovăialo": "ciorovăială",
    "ciorovăieli": "ciorovăială",
    "ciorovăielii": "ciorovăială",
    "ciorovăielile": "ciorovăială",
    "ciorovăielilor": "ciorovăială",
    "ciorovăirea": "ciorovăire",
    "ciorovăireo": "ciorovăire",
    "ciorovăiri": "ciorovăire",
    "ciorovăirii": "ciorovăire",
    "ciorovăirile": "ciorovăire",
    "ciorovăirilor": "ciorovăire",
    "ciorovăită": "ciorovăit",
    "ciorovăite": "ciorovăit",
    "ciorovăiți": "ciorovăit",
    "ciorovăitul": "ciorovăit",
    "ciorovăitule": "ciorovăit",
    "ciorovăitului": "ciorovăit",
    "ciotul": "ciot",
    "ciotule": "ciot",
    "ciotului": "ciot",
    "cioturi": "ciot",
    "cioturile": "ciot",
    "cioturilor": "ciot",
    "cioturoasa": "cioturos",
    "cioturoasă": "cioturos",
    "cioturoase": "cioturos",
    "cioturoasei": "cioturos",
    "cioturoasele": "cioturos",
    "cioturoaselor": "cioturos",
    "cioturoaso": "cioturos",
    "cioturoși": "cioturos",
    "cioturoșii": "cioturos",
    "cioturoșilor": "cioturos",
    "cioturosul": "cioturos",
    "cioturosule": "cioturos",
    "cioturosului": "cioturos",
    "ciovica": "ciovică",
    "ciovici": "ciovică",
    "ciovicii": "ciovică",
    "ciovicile": "ciovică",
    "ciovicilor": "ciovică",
    "ciovico": "ciovică",
    "ciozvârta": "ciozvârtă",
    "ciozvârte": "ciozvârtă",
    "ciozvârtei": "ciozvârtă",
    "ciozvârtele": "ciozvârtă",
    "ciozvârtelor": "ciozvârtă",
    "ciozvârto": "ciozvârtă",
    "cipici": "cipic",
    "cipicii": "cipic",
    "cipicilor": "cipic",
    "cipicul": "cipic",
    "cipicule": "cipic",
    "cipicului": "cipic",
    "cipilica": "cipilică",
    "cipilici": "cipilică",
    "cipilicii": "cipilică",
    "cipilicile": "cipilică",
    "cipilicilor": "cipilică",
    "ciraci": "cirac",
    "ciracii": "cirac",
    "ciracilor": "cirac",
    "ciracul": "cirac",
    "ciracule": "cirac",
    "ciracului": "cirac",
    "circul": "circ",
    "circule": "circ",
    "circului": "circ",
    "circuri": "circ",
    "circurile": "circ",
    "circurilor": "circ",
    "cca": "circa",
    "circa": "circă",
    "circe": "circă",
    "circei": "circă",
    "circo": "circă",
    "circuite": "circuit",
    "circuitele": "circuit",
    "circuitelor": "circuit",
    "circuitul": "circuit",
    "circuitule": "circuit",
    "circuitului": "circuit",
    "circul": "circula",
    "circulă": "circula",
    "circulai": "circula",
    "circulam": "circula",
    "circulăm": "circula",
    "circulând": "circula",
    "circulându": "circula",
    "circulară": "circula",
    "circularăm": "circula",
    "circularăți": "circula",
    "circulase": "circula",
    "circulasem": "circula",
    "circulaseră": "circula",
    "circulaserăm": "circula",
    "circulaserăți": "circula",
    "circulaseși": "circula",
    "circulași": "circula",
    "circulat": "circula",
    "circulați": "circula",
    "circulatu": "circula",
    "circulau": "circula",
    "circule": "circula",
    "circuli": "circula",
    "necirculând": "circula",
    "necirculându": "circula",
    "nemaicirculând": "circula",
    "nemaicirculându": "circula",
    "circulanta": "circulant",
    "circulantă": "circulant",
    "circulante": "circulant",
    "circulantei": "circulant",
    "circulantele": "circulant",
    "circulantelor": "circulant",
    "circulanți": "circulant",
    "circulanții": "circulant",
    "circulanților": "circulant",
    "circulanto": "circulant",
    "circulantul": "circulant",
    "circulantule": "circulant",
    "circulantului": "circulant",
    "circulara": "circular",
    "circulară": "circular",
    "circulare": "circular",
    "circularei": "circular",
    "circularele": "circular",
    "circularelor": "circular",
    "circulari": "circular",
    "circularii": "circular",
    "circularilor": "circular",
    "circularo": "circular",
    "circularul": "circular",
    "circularule": "circular",
    "circularului": "circular",
    "circulara": "circulară",
    "circulare": "circulară",
    "circularei": "circulară",
    "circularele": "circulară",
    "circularelor": "circulară",
    "circularo": "circulară",
    "circularitatea": "circularitate",
    "circularități": "circularitate",
    "circularității": "circularitate",
    "circulată": "circulat",
    "circulate": "circulat",
    "circulați": "circulat",
    "circulația": "circulație",
    "circulației": "circulație",
    "circulații": "circulație",
    "circulațiile": "circulație",
    "circulațiilor": "circulație",
    "circulațio": "circulație",
    "circulatoare": "circulator",
    "circulatoarea": "circulator",
    "circulatoarei": "circulator",
    "circulatoarele": "circulator",
    "circulatoarelor": "circulator",
    "circulatoareo": "circulator",
    "circulatori": "circulator",
    "circulatorii": "circulator",
    "circulatorilor": "circulator",
    "circulatorul": "circulator",
    "circulatorule": "circulator",
    "circulatorului": "circulator",
    "circumferința": "circumferință",
    "circumferințe": "circumferință",
    "circumferinței": "circumferință",
    "circumferințele": "circumferință",
    "circumferințelor": "circumferință",
    "circumferințo": "circumferință",
    "circumflexe": "circumflex",
    "circumflexele": "circumflex",
    "circumflexelor": "circumflex",
    "circumflexul": "circumflex",
    "circumflexule": "circumflex",
    "circumflexului": "circumflex",
    "circumscria": "circumscrie",
    "circumscriai": "circumscrie",
    "circumscriam": "circumscrie",
    "circumscriați": "circumscrie",
    "circumscriau": "circumscrie",
    "circumscriem": "circumscrie",
    "circumscrieți": "circumscrie",
    "circumscrii": "circumscrie",
    "circumscriind": "circumscrie",
    "circumscriindu": "circumscrie",
    "circumscris": "circumscrie",
    "circumscrise": "circumscrie",
    "circumscrisei": "circumscrie",
    "circumscriseră": "circumscrie",
    "circumscriserăm": "circumscrie",
    "circumscriserăți": "circumscrie",
    "circumscrisese": "circumscrie",
    "circumscrisesem": "circumscrie",
    "circumscriseseră": "circumscrie",
    "circumscriseserăm": "circumscrie",
    "circumscriseserăți": "circumscrie",
    "circumscriseseși": "circumscrie",
    "circumscriseși": "circumscrie",
    "circumscrisu": "circumscrie",
    "circumscriu": "circumscrie",
    "necircumscriind": "circumscrie",
    "necircumscriindu": "circumscrie",
    "nemaicircumscriind": "circumscrie",
    "nemaicircumscriindu": "circumscrie",
    "circumscrierea": "circumscriere",
    "circumscriereo": "circumscriere",
    "circumscrieri": "circumscriere",
    "circumscrierii": "circumscriere",
    "circumscrierile": "circumscriere",
    "circumscrierilor": "circumscriere",
    "circumscripția": "circumscripție",
    "circumscripției": "circumscripție",
    "circumscripții": "circumscripție",
    "circumscripțiile": "circumscripție",
    "circumscripțiilor": "circumscripție",
    "circumscripțio": "circumscripție",
    "circumscrisa": "circumscris",
    "circumscrisă": "circumscris",
    "circumscrise": "circumscris",
    "circumscrisei": "circumscris",
    "circumscrisele": "circumscris",
    "circumscriselor": "circumscris",
    "circumscriși": "circumscris",
    "circumscrișii": "circumscris",
    "circumscrișilor": "circumscris",
    "circumscriso": "circumscris",
    "circumscrisul": "circumscris",
    "circumscrisule": "circumscris",
    "circumscrisului": "circumscris",
    "circumspecta": "circumspect",
    "circumspectă": "circumspect",
    "circumspecte": "circumspect",
    "circumspectei": "circumspect",
    "circumspectele": "circumspect",
    "circumspectelor": "circumspect",
    "circumspecți": "circumspect",
    "circumspecții": "circumspect",
    "circumspecților": "circumspect",
    "circumspecto": "circumspect",
    "circumspectul": "circumspect",
    "circumspectule": "circumspect",
    "circumspectului": "circumspect",
    "circumspecția": "circumspecție",
    "circumspecției": "circumspecție",
    "circumspecții": "circumspecție",
    "circumspecțiile": "circumspecție",
    "circumspecțiilor": "circumspecție",
    "circumspecțio": "circumspecție",
    "circumstanța": "circumstanță",
    "circumstanțe": "circumstanță",
    "circumstanței": "circumstanță",
    "circumstanțele": "circumstanță",
    "circumstanțelor": "circumstanță",
    "circumstanțo": "circumstanță",
    "circumvoluția": "circumvoluție",
    "circumvoluției": "circumvoluție",
    "circumvoluții": "circumvoluție",
    "circumvoluțiile": "circumvoluție",
    "circumvoluțiilor": "circumvoluție",
    "circumvoluțio": "circumvoluție",
    "circumvoluțiunea": "circumvoluțiune",
    "circumvoluțiuneo": "circumvoluțiune",
    "circumvoluțiuni": "circumvoluțiune",
    "circumvoluțiunii": "circumvoluțiune",
    "circumvoluțiunile": "circumvoluțiune",
    "circumvoluțiunilor": "circumvoluțiune",
    "cireada": "cireadă",
    "cireado": "cireadă",
    "cirezi": "cireadă",
    "cirezii": "cireadă",
    "cirezile": "cireadă",
    "cirezilor": "cireadă",
    "cireașa": "cireașă",
    "cireașo": "cireașă",
    "cireșe": "cireașă",
    "cireșei": "cireașă",
    "cireșele": "cireașă",
    "cireșelor": "cireașă",
    "cireși": "cireș",
    "cireșii": "cireș",
    "cireșilor": "cireș",
    "cireșul": "cireș",
    "cireșule": "cireș",
    "cireșului": "cireș",
    "cireșari": "cireșar",
    "cireșarii": "cireșar",
    "cireșarilor": "cireșar",
    "cireșarul": "cireșar",
    "cireșarule": "cireșar",
    "cireșarului": "cireșar",
    "cireșia": "cireșiu",
    "cireșie": "cireșiu",
    "cireșiei": "cireșiu",
    "cireșii": "cireșiu",
    "cireșiii": "cireșiu",
    "cireșiile": "cireșiu",
    "cireșiilor": "cireșiu",
    "cireșio": "cireșiu",
    "cireșiul": "cireșiu",
    "cireșiule": "cireșiu",
    "cireșiului": "cireșiu",
    "ciripeala": "ciripeală",
    "ciripealo": "ciripeală",
    "ciripeli": "ciripeală",
    "ciripelii": "ciripeală",
    "ciripelile": "ciripeală",
    "ciripelilor": "ciripeală",
    "ciripea": "ciripi",
    "ciripeai": "ciripi",
    "ciripeam": "ciripi",
    "ciripească": "ciripi",
    "ciripeați": "ciripi",
    "ciripeau": "ciripi",
    "ciripesc": "ciripi",
    "ciripește": "ciripi",
    "ciripești": "ciripi",
    "ciripii": "ciripi",
    "ciripim": "ciripi",
    "ciripind": "ciripi",
    "ciripindu": "ciripi",
    "ciripiră": "ciripi",
    "ciripirăm": "ciripi",
    "ciripirăți": "ciripi",
    "ciripise": "ciripi",
    "ciripisem": "ciripi",
    "ciripiseră": "ciripi",
    "ciripiserăm": "ciripi",
    "ciripiserăți": "ciripi",
    "ciripiseși": "ciripi",
    "ciripiși": "ciripi",
    "ciripit": "ciripi",
    "ciripiți": "ciripi",
    "ciripitu": "ciripi",
    "neciripind": "ciripi",
    "neciripindu": "ciripi",
    "nemaiciripind": "ciripi",
    "nemaiciripindu": "ciripi",
    "ciripirea": "ciripire",
    "ciripireo": "ciripire",
    "ciripiri": "ciripire",
    "ciripirii": "ciripire",
    "ciripirile": "ciripire",
    "ciripirilor": "ciripire",
    "ciripită": "ciripit",
    "ciripite": "ciripit",
    "ciripiți": "ciripit",
    "ciripitul": "ciripit",
    "ciripitule": "ciripit",
    "ciripitului": "ciripit",
    "ciripituri": "ciripit",
    "ciripiturile": "ciripit",
    "ciripiturilor": "ciripit",
    "ciripitoare": "ciripitor",
    "ciripitoarea": "ciripitor",
    "ciripitoarei": "ciripitor",
    "ciripitoarele": "ciripitor",
    "ciripitoarelor": "ciripitor",
    "ciripitoareo": "ciripitor",
    "ciripitori": "ciripitor",
    "ciripitorii": "ciripitor",
    "ciripitorilor": "ciripitor",
    "ciripitorul": "ciripitor",
    "ciripitorule": "ciripitor",
    "ciripitorului": "ciripitor",
    "ciroza": "ciroză",
    "ciroze": "ciroză",
    "cirozei": "ciroză",
    "cirozele": "ciroză",
    "cirozelor": "ciroză",
    "cirozo": "ciroză",
    "cisluia": "cislui",
    "cisluiai": "cislui",
    "cisluiam": "cislui",
    "cisluiască": "cislui",
    "cisluiați": "cislui",
    "cisluiau": "cislui",
    "cisluiesc": "cislui",
    "cisluiește": "cislui",
    "cisluiești": "cislui",
    "cisluii": "cislui",
    "cisluim": "cislui",
    "cisluind": "cislui",
    "cisluindu": "cislui",
    "cisluiră": "cislui",
    "cisluirăm": "cislui",
    "cisluirăți": "cislui",
    "cisluise": "cislui",
    "cisluisem": "cislui",
    "cisluiseră": "cislui",
    "cisluiserăm": "cislui",
    "cisluiserăți": "cislui",
    "cisluiseși": "cislui",
    "cisluiși": "cislui",
    "cisluit": "cislui",
    "cisluiți": "cislui",
    "cisluitu": "cislui",
    "necisluind": "cislui",
    "necisluindu": "cislui",
    "nemaicisluind": "cislui",
    "nemaicisluindu": "cislui",
    "cisluită": "cisluit",
    "cisluite": "cisluit",
    "cisluiți": "cisluit",
    "cișmeao": "cișmea",
    "cișmeaua": "cișmea",
    "cișmele": "cișmea",
    "cișmelei": "cișmea",
    "cișmelele": "cișmea",
    "cișmelelor": "cișmea",
    "Cișmigiul": "Cișmigiu",
    "Cișmigiului": "Cișmigiu",
    "cisterna": "cisternă",
    "cisterne": "cisternă",
    "cisternei": "cisternă",
    "cisternele": "cisternă",
    "cisternelor": "cisternă",
    "cisterno": "cisternă",
    "cisticerci": "cisticerc",
    "cisticercii": "cisticerc",
    "cisticercilor": "cisticerc",
    "cisticercul": "cisticerc",
    "cisticercule": "cisticerc",
    "cisticercului": "cisticerc",
    "cisticercoza": "cisticercoză",
    "cisticercoze": "cisticercoză",
    "cisticercozei": "cisticercoză",
    "cisticercozele": "cisticercoză",
    "cisticercozelor": "cisticercoză",
    "cisticercozo": "cisticercoză",
    "cistita": "cistită",
    "cistite": "cistită",
    "cistitei": "cistită",
    "cistitele": "cistită",
    "cistitelor": "cistită",
    "cistito": "cistită",
    "cistoscopul": "cistoscop",
    "cistoscopule": "cistoscop",
    "cistoscopului": "cistoscop",
    "cistoscopuri": "cistoscop",
    "cistoscopurile": "cistoscop",
    "cistoscopurilor": "cistoscop",
    "cistoscopia": "cistoscopie",
    "cistoscopiei": "cistoscopie",
    "cistoscopii": "cistoscopie",
    "cistoscopiile": "cistoscopie",
    "cistoscopiilor": "cistoscopie",
    "cistoscopio": "cistoscopie",
    "cită": "cita",
    "citai": "cita",
    "citam": "cita",
    "cităm": "cita",
    "citând": "cita",
    "citându": "cita",
    "citară": "cita",
    "citarăm": "cita",
    "citarăți": "cita",
    "citase": "cita",
    "citasem": "cita",
    "citaseră": "cita",
    "citaserăm": "cita",
    "citaserăți": "cita",
    "citaseși": "cita",
    "citași": "cita",
    "citat": "cita",
    "citați": "cita",
    "citatu": "cita",
    "citau": "cita",
    "citează": "cita",
    "citez": "cita",
    "citeze": "cita",
    "citezi": "cita",
    "necitând": "cita",
    "necitându": "cita",
    "nemaicitând": "cita",
    "nemaicitându": "cita",
    "citadela": "citadelă",
    "citadele": "citadelă",
    "citadelei": "citadelă",
    "citadelele": "citadelă",
    "citadelelor": "citadelă",
    "citadelo": "citadelă",
    "citadina": "citadin",
    "citadină": "citadin",
    "citadine": "citadin",
    "citadinei": "citadin",
    "citadinele": "citadin",
    "citadinelor": "citadin",
    "citadini": "citadin",
    "citadinii": "citadin",
    "citadinilor": "citadin",
    "citadino": "citadin",
    "citadinul": "citadin",
    "citadinule": "citadin",
    "citadinului": "citadin",
    "citarea": "citare",
    "citareo": "citare",
    "citări": "citare",
    "citării": "citare",
    "citările": "citare",
    "citărilor": "citare",
    "citată": "citat",
    "citate": "citat",
    "citatele": "citat",
    "citatelor": "citat",
    "citați": "citat",
    "citatul": "citat",
    "citatule": "citat",
    "citatului": "citat",
    "citația": "citație",
    "citației": "citație",
    "citații": "citație",
    "citațiile": "citație",
    "citațiilor": "citație",
    "citațio": "citație",
    "cit.": "citește",
    "citeața": "citeț",
    "citeață": "citeț",
    "citeațo": "citeț",
    "citețe": "citeț",
    "citeței": "citeț",
    "citețele": "citeț",
    "citețelor": "citeț",
    "citeți": "citeț",
    "citeții": "citeț",
    "citeților": "citeț",
    "citețul": "citeț",
    "citețule": "citeț",
    "citețului": "citeț",
    "citea": "citi",
    "citeai": "citi",
    "citeam": "citi",
    "citească": "citi",
    "citeați": "citi",
    "citeau": "citi",
    "citesc": "citi",
    "citește": "citi",
    "citești": "citi",
    "citii": "citi",
    "citim": "citi",
    "citind": "citi",
    "citindu": "citi",
    "citiră": "citi",
    "citirăm": "citi",
    "citirăți": "citi",
    "citise": "citi",
    "citisem": "citi",
    "citiseră": "citi",
    "citiserăm": "citi",
    "citiserăți": "citi",
    "citiseși": "citi",
    "citiși": "citi",
    "citit": "citi",
    "citiți": "citi",
    "cititu": "citi",
    "necitind": "citi",
    "necitindu": "citi",
    "nemaicitind": "citi",
    "nemaicitindu": "citi",
    "citirea": "citire",
    "citireo": "citire",
    "citiri": "citire",
    "citirii": "citire",
    "citirile": "citire",
    "citirilor": "citire",
    "citita": "citit",
    "citită": "citit",
    "citite": "citit",
    "cititei": "citit",
    "cititele": "citit",
    "cititelor": "citit",
    "citiți": "citit",
    "citiții": "citit",
    "citiților": "citit",
    "citito": "citit",
    "cititul": "citit",
    "cititule": "citit",
    "cititului": "citit",
    "cititoarea": "cititoare",
    "cititoarei": "cititoare",
    "cititoarele": "cititoare",
    "cititoarelor": "cititoare",
    "cititoareo": "cititoare",
    "cititori": "cititor",
    "cititorii": "cititor",
    "cititorilor": "cititor",
    "cititorul": "cititor",
    "cititorule": "cititor",
    "cititorului": "cititor",
    "citostatica": "citostatic",
    "citostatică": "citostatic",
    "citostatice": "citostatic",
    "citostaticei": "citostatic",
    "citostaticele": "citostatic",
    "citostaticelor": "citostatic",
    "citostatici": "citostatic",
    "citostaticii": "citostatic",
    "citostaticilor": "citostatic",
    "citostatico": "citostatic",
    "citostaticul": "citostatic",
    "citostaticule": "citostatic",
    "citostaticului": "citostatic",
    "citrați": "citrat",
    "citrații": "citrat",
    "citraților": "citrat",
    "citratul": "citrat",
    "citratule": "citrat",
    "citratului": "citrat",
    "citrica": "citric",
    "citrică": "citric",
    "citrice": "citric",
    "citricei": "citric",
    "citricele": "citric",
    "citricelor": "citric",
    "citrici": "citric",
    "citricii": "citric",
    "citricilor": "citric",
    "citrico": "citric",
    "citricul": "citric",
    "citricule": "citric",
    "citricului": "citric",
    "citronada": "citronadă",
    "citronade": "citronadă",
    "citronadei": "citronadă",
    "citronadele": "citronadă",
    "citronadelor": "citronadă",
    "citronado": "citronadă",
    "ciubăre": "ciubăr",
    "ciubărele": "ciubăr",
    "ciubărelor": "ciubăr",
    "ciubărul": "ciubăr",
    "ciubărule": "ciubăr",
    "ciubărului": "ciubăr",
    "ciubărașe": "ciubăraș",
    "ciubărașele": "ciubăraș",
    "ciubărașelor": "ciubăraș",
    "ciubărașul": "ciubăraș",
    "ciubărașule": "ciubăraș",
    "ciubărașului": "ciubăraș",
    "ciubota": "ciubotă",
    "ciubote": "ciubotă",
    "ciubotei": "ciubotă",
    "ciubotele": "ciubotă",
    "ciubotelor": "ciubotă",
    "ciuboto": "ciubotă",
    "ciubotari": "ciubotar",
    "ciubotarii": "ciubotar",
    "ciubotarilor": "ciubotar",
    "ciubotarul": "ciubotar",
    "ciubotarule": "ciubotar",
    "ciubotarului": "ciubotar",
    "ciubotăreasca": "ciubotăresc",
    "ciubotărească": "ciubotăresc",
    "ciubotăreasco": "ciubotăresc",
    "ciubotărescul": "ciubotăresc",
    "ciubotărescule": "ciubotăresc",
    "ciubotărescului": "ciubotăresc",
    "ciubotărești": "ciubotăresc",
    "ciubotăreștii": "ciubotăresc",
    "ciubotăreștile": "ciubotăresc",
    "ciubotăreștilor": "ciubotăresc",
    "ciubotăria": "ciubotărie",
    "ciubotăriei": "ciubotărie",
    "ciubotării": "ciubotărie",
    "ciubotăriile": "ciubotărie",
    "ciubotăriilor": "ciubotărie",
    "ciubotărio": "ciubotărie",
    "ciuboțele": "ciuboțică",
    "ciuboțelei": "ciuboțică",
    "ciuboțelele": "ciuboțică",
    "ciuboțelelor": "ciuboțică",
    "ciuboțica": "ciuboțică",
    "ciuboțico": "ciuboțică",
    "ciubuce": "ciubuc",
    "ciubucele": "ciubuc",
    "ciubucelor": "ciubuc",
    "ciubucul": "ciubuc",
    "ciubucule": "ciubuc",
    "ciubucului": "ciubuc",
    "ciubucari": "ciubucar",
    "ciubucarii": "ciubucar",
    "ciubucarilor": "ciubucar",
    "ciubucarul": "ciubucar",
    "ciubucarule": "ciubucar",
    "ciubucarului": "ciubucar",
    "Ciucașul": "Ciucaș",
    "Ciucașului": "Ciucaș",
    "ciuciuletele": "ciuciulete",
    "ciuciuletelui": "ciuciulete",
    "ciuciuleți": "ciuciulete",
    "ciuciuleții": "ciuciulete",
    "ciuciuleților": "ciuciulete",
    "ciucurul": "ciucur",
    "ciucurule": "ciucur",
    "ciucurului": "ciucur",
    "ciucurași": "ciucuraș",
    "ciucurașii": "ciucuraș",
    "ciucurașilor": "ciucuraș",
    "ciucurașul": "ciucuraș",
    "ciucurașule": "ciucuraș",
    "ciucurașului": "ciucuraș",
    "ciucurele": "ciucure",
    "ciucurelui": "ciucure",
    "ciucuri": "ciucure",
    "ciucurii": "ciucure",
    "ciucurilor": "ciucure",
    "ciucurei": "ciucurel",
    "ciucureii": "ciucurel",
    "ciucureilor": "ciucurel",
    "ciucurelul": "ciucurel",
    "ciucurelule": "ciucurel",
    "ciucurelului": "ciucurel",
    "ciuda": "ciudă",
    "ciude": "ciudă",
    "ciudei": "ciudă",
    "ciudele": "ciudă",
    "ciudelor": "ciudă",
    "ciudo": "ciudă",
    "ciuda'": "ciudat",
    "ciudata": "ciudat",
    "ciudată": "ciudat",
    "ciudate": "ciudat",
    "ciudatei": "ciudat",
    "ciudatele": "ciudat",
    "ciudatelor": "ciudat",
    "ciudați": "ciudat",
    "ciudații": "ciudat",
    "ciudaților": "ciudat",
    "ciudato": "ciudat",
    "ciudatul": "ciudat",
    "ciudatule": "ciudat",
    "ciudatului": "ciudat",
    "ciudățenia": "ciudățenie",
    "ciudățeniei": "ciudățenie",
    "ciudățenii": "ciudățenie",
    "ciudățeniile": "ciudățenie",
    "ciudățeniilor": "ciudățenie",
    "ciudățenio": "ciudățenie",
    "ciufi": "ciuf",
    "ciufii": "ciuf",
    "ciufilor": "ciuf",
    "ciuful": "ciuf",
    "ciufule": "ciuf",
    "ciufului": "ciuf",
    "ciufuri": "ciuf",
    "ciufurile": "ciuf",
    "ciufurilor": "ciuf",
    "ciufulea": "ciufuli",
    "ciufuleai": "ciufuli",
    "ciufuleam": "ciufuli",
    "ciufulească": "ciufuli",
    "ciufuleați": "ciufuli",
    "ciufuleau": "ciufuli",
    "ciufulesc": "ciufuli",
    "ciufulește": "ciufuli",
    "ciufulești": "ciufuli",
    "ciufulii": "ciufuli",
    "ciufulim": "ciufuli",
    "ciufulind": "ciufuli",
    "ciufulindu": "ciufuli",
    "ciufuliră": "ciufuli",
    "ciufulirăm": "ciufuli",
    "ciufulirăți": "ciufuli",
    "ciufulise": "ciufuli",
    "ciufulisem": "ciufuli",
    "ciufuliseră": "ciufuli",
    "ciufuliserăm": "ciufuli",
    "ciufuliserăți": "ciufuli",
    "ciufuliseși": "ciufuli",
    "ciufuliși": "ciufuli",
    "ciufulit": "ciufuli",
    "ciufuliți": "ciufuli",
    "ciufulitu": "ciufuli",
    "neciufulind": "ciufuli",
    "neciufulindu": "ciufuli",
    "nemaiciufulind": "ciufuli",
    "nemaiciufulindu": "ciufuli",
    "ciufulita": "ciufulit",
    "ciufulită": "ciufulit",
    "ciufulite": "ciufulit",
    "ciufulitei": "ciufulit",
    "ciufulitele": "ciufulit",
    "ciufulitelor": "ciufulit",
    "ciufuliți": "ciufulit",
    "ciufuliții": "ciufulit",
    "ciufuliților": "ciufulit",
    "ciufulito": "ciufulit",
    "ciufulitul": "ciufulit",
    "ciufulitule": "ciufulit",
    "ciufulitului": "ciufulit",
    "ciufuta": "ciufut",
    "ciufută": "ciufut",
    "ciufute": "ciufut",
    "ciufutei": "ciufut",
    "ciufutele": "ciufut",
    "ciufutelor": "ciufut",
    "ciufuți": "ciufut",
    "ciufuții": "ciufut",
    "ciufuților": "ciufut",
    "ciufuto": "ciufut",
    "ciufutul": "ciufut",
    "ciufutule": "ciufut",
    "ciufutului": "ciufut",
    "ciuguleala": "ciuguleală",
    "ciugulealo": "ciuguleală",
    "ciuguleli": "ciuguleală",
    "ciugulelii": "ciuguleală",
    "ciugulelile": "ciuguleală",
    "ciugulelilor": "ciuguleală",
    "ciugulea": "ciuguli",
    "ciuguleai": "ciuguli",
    "ciuguleam": "ciuguli",
    "ciugulească": "ciuguli",
    "ciuguleați": "ciuguli",
    "ciuguleau": "ciuguli",
    "ciugulesc": "ciuguli",
    "ciugulește": "ciuguli",
    "ciugulești": "ciuguli",
    "ciugulii": "ciuguli",
    "ciugulim": "ciuguli",
    "ciugulind": "ciuguli",
    "ciugulindu": "ciuguli",
    "ciuguliră": "ciuguli",
    "ciugulirăm": "ciuguli",
    "ciugulirăți": "ciuguli",
    "ciugulise": "ciuguli",
    "ciugulisem": "ciuguli",
    "ciuguliseră": "ciuguli",
    "ciuguliserăm": "ciuguli",
    "ciuguliserăți": "ciuguli",
    "ciuguliseși": "ciuguli",
    "ciuguliși": "ciuguli",
    "ciugulit": "ciuguli",
    "ciuguliți": "ciuguli",
    "ciugulitu": "ciuguli",
    "neciugulind": "ciuguli",
    "neciugulindu": "ciuguli",
    "nemaiciugulind": "ciuguli",
    "nemaiciugulindu": "ciuguli",
    "ciugulită": "ciugulit",
    "ciugulite": "ciugulit",
    "ciuguliți": "ciugulit",
    "ciulamale": "ciulama",
    "ciulamalei": "ciulama",
    "ciulamalele": "ciulama",
    "ciulamalelor": "ciulama",
    "ciulamao": "ciulama",
    "ciulamaua": "ciulama",
    "ciuleandra": "ciuleandră",
    "ciuleandro": "ciuleandră",
    "ciulendre": "ciuleandră",
    "ciulendrei": "ciuleandră",
    "ciulendrele": "ciuleandră",
    "ciulendrelor": "ciuleandră",
    "ciuleii": "ciulei",
    "ciuleilor": "ciulei",
    "ciuleiul": "ciulei",
    "ciuleiule": "ciulei",
    "ciuleiului": "ciulei",
    "ciulea": "ciuli",
    "ciuleai": "ciuli",
    "ciuleam": "ciuli",
    "ciulească": "ciuli",
    "ciuleați": "ciuli",
    "ciuleau": "ciuli",
    "ciulesc": "ciuli",
    "ciulește": "ciuli",
    "ciulești": "ciuli",
    "ciulii": "ciuli",
    "ciulim": "ciuli",
    "ciulind": "ciuli",
    "ciulindu": "ciuli",
    "ciuliră": "ciuli",
    "ciulirăm": "ciuli",
    "ciulirăți": "ciuli",
    "ciulise": "ciuli",
    "ciulisem": "ciuli",
    "ciuliseră": "ciuli",
    "ciuliserăm": "ciuli",
    "ciuliserăți": "ciuli",
    "ciuliseși": "ciuli",
    "ciuliși": "ciuli",
    "ciulit": "ciuli",
    "ciuliți": "ciuli",
    "ciulitu": "ciuli",
    "neciulind": "ciuli",
    "neciulindu": "ciuli",
    "nemaiciulind": "ciuli",
    "nemaiciulindu": "ciuli",
    "ciulini": "ciulin",
    "ciulinii": "ciulin",
    "ciulinilor": "ciulin",
    "ciulinul": "ciulin",
    "ciulinule": "ciulin",
    "ciulinului": "ciulin",
    "ciulită": "ciulit",
    "ciulite": "ciulit",
    "ciuliți": "ciulit",
    "ciuma": "ciumă",
    "ciume": "ciumă",
    "ciumei": "ciumă",
    "ciumele": "ciumă",
    "ciumelor": "ciumă",
    "ciumo": "ciumă",
    "ciumăfăi": "ciumăfaie",
    "ciumăfaia": "ciumăfaie",
    "ciumăfăii": "ciumăfaie",
    "ciumăfăile": "ciumăfaie",
    "ciumăfăilor": "ciumăfaie",
    "ciumăfaio": "ciumăfaie",
    "ciumata": "ciumat",
    "ciumată": "ciumat",
    "ciumate": "ciumat",
    "ciumatei": "ciumat",
    "ciumatele": "ciumat",
    "ciumatelor": "ciumat",
    "ciumați": "ciumat",
    "ciumații": "ciumat",
    "ciumaților": "ciumat",
    "ciumato": "ciumat",
    "ciumatul": "ciumat",
    "ciumatule": "ciumat",
    "ciumatului": "ciumat",
    "ciumpăvea": "ciumpăvi",
    "ciumpăveai": "ciumpăvi",
    "ciumpăveam": "ciumpăvi",
    "ciumpăvească": "ciumpăvi",
    "ciumpăveați": "ciumpăvi",
    "ciumpăveau": "ciumpăvi",
    "ciumpăvesc": "ciumpăvi",
    "ciumpăvește": "ciumpăvi",
    "ciumpăvești": "ciumpăvi",
    "ciumpăvii": "ciumpăvi",
    "ciumpăvim": "ciumpăvi",
    "ciumpăvind": "ciumpăvi",
    "ciumpăvindu": "ciumpăvi",
    "ciumpăviră": "ciumpăvi",
    "ciumpăvirăm": "ciumpăvi",
    "ciumpăvirăți": "ciumpăvi",
    "ciumpăvise": "ciumpăvi",
    "ciumpăvisem": "ciumpăvi",
    "ciumpăviseră": "ciumpăvi",
    "ciumpăviserăm": "ciumpăvi",
    "ciumpăviserăți": "ciumpăvi",
    "ciumpăviseși": "ciumpăvi",
    "ciumpăviși": "ciumpăvi",
    "ciumpăvit": "ciumpăvi",
    "ciumpăviți": "ciumpăvi",
    "ciumpăvitu": "ciumpăvi",
    "neciumpăvind": "ciumpăvi",
    "neciumpăvindu": "ciumpăvi",
    "nemaiciumpăvind": "ciumpăvi",
    "nemaiciumpăvindu": "ciumpăvi",
    "ciumpăvită": "ciumpăvit",
    "ciumpăvite": "ciumpăvit",
    "ciumpăviți": "ciumpăvit",
    "ciunga": "ciung",
    "ciungă": "ciung",
    "ciunge": "ciung",
    "ciungei": "ciung",
    "ciungele": "ciung",
    "ciungelor": "ciung",
    "ciungi": "ciung",
    "ciungii": "ciung",
    "ciungilor": "ciung",
    "ciungo": "ciung",
    "ciungul": "ciung",
    "ciungule": "ciung",
    "ciungului": "ciung",
    "ciungea": "ciungi",
    "ciungeai": "ciungi",
    "ciungeam": "ciungi",
    "ciungească": "ciungi",
    "ciungeați": "ciungi",
    "ciungeau": "ciungi",
    "ciungesc": "ciungi",
    "ciungește": "ciungi",
    "ciungești": "ciungi",
    "ciungii": "ciungi",
    "ciungim": "ciungi",
    "ciungind": "ciungi",
    "ciungindu": "ciungi",
    "ciungiră": "ciungi",
    "ciungirăm": "ciungi",
    "ciungirăți": "ciungi",
    "ciungise": "ciungi",
    "ciungisem": "ciungi",
    "ciungiseră": "ciungi",
    "ciungiserăm": "ciungi",
    "ciungiserăți": "ciungi",
    "ciungiseși": "ciungi",
    "ciungiși": "ciungi",
    "ciungit": "ciungi",
    "ciungiți": "ciungi",
    "ciungitu": "ciungi",
    "neciungind": "ciungi",
    "neciungindu": "ciungi",
    "nemaiciungind": "ciungi",
    "nemaiciungindu": "ciungi",
    "ciungită": "ciungit",
    "ciungite": "ciungit",
    "ciungiți": "ciungit",
    "ciuntea": "ciunti",
    "ciunteai": "ciunti",
    "ciunteam": "ciunti",
    "ciuntească": "ciunti",
    "ciunteați": "ciunti",
    "ciunteau": "ciunti",
    "ciuntesc": "ciunti",
    "ciuntește": "ciunti",
    "ciuntești": "ciunti",
    "ciuntii": "ciunti",
    "ciuntim": "ciunti",
    "ciuntind": "ciunti",
    "ciuntindu": "ciunti",
    "ciuntiră": "ciunti",
    "ciuntirăm": "ciunti",
    "ciuntirăți": "ciunti",
    "ciuntise": "ciunti",
    "ciuntisem": "ciunti",
    "ciuntiseră": "ciunti",
    "ciuntiserăm": "ciunti",
    "ciuntiserăți": "ciunti",
    "ciuntiseși": "ciunti",
    "ciuntiși": "ciunti",
    "ciuntit": "ciunti",
    "ciuntiți": "ciunti",
    "ciuntitu": "ciunti",
    "neciuntind": "ciunti",
    "neciuntindu": "ciunti",
    "nemaiciuntind": "ciunti",
    "nemaiciuntindu": "ciunti",
    "ciuntirea": "ciuntire",
    "ciuntireo": "ciuntire",
    "ciuntiri": "ciuntire",
    "ciuntirii": "ciuntire",
    "ciuntirile": "ciuntire",
    "ciuntirilor": "ciuntire",
    "ciuntită": "ciuntit",
    "ciuntite": "ciuntit",
    "ciuntiți": "ciuntit",
    "ciuntitura": "ciuntitură",
    "ciuntituri": "ciuntitură",
    "ciuntiturii": "ciuntitură",
    "ciuntiturile": "ciuntitură",
    "ciuntiturilor": "ciuntitură",
    "ciuntituro": "ciuntitură",
    "ciupeala": "ciupeală",
    "ciupealo": "ciupeală",
    "ciupeli": "ciupeală",
    "ciupelii": "ciupeală",
    "ciupelile": "ciupeală",
    "ciupelilor": "ciupeală",
    "ciuperca": "ciupercă",
    "ciuperci": "ciupercă",
    "ciupercii": "ciupercă",
    "ciupercile": "ciupercă",
    "ciupercilor": "ciupercă",
    "ciuperco": "ciupercă",
    "ciupea": "ciupi",
    "ciupeai": "ciupi",
    "ciupeam": "ciupi",
    "ciupească": "ciupi",
    "ciupeați": "ciupi",
    "ciupeau": "ciupi",
    "ciupesc": "ciupi",
    "ciupește": "ciupi",
    "ciupești": "ciupi",
    "ciupii": "ciupi",
    "ciupim": "ciupi",
    "ciupind": "ciupi",
    "ciupindu": "ciupi",
    "ciupiră": "ciupi",
    "ciupirăm": "ciupi",
    "ciupirăți": "ciupi",
    "ciupise": "ciupi",
    "ciupisem": "ciupi",
    "ciupiseră": "ciupi",
    "ciupiserăm": "ciupi",
    "ciupiserăți": "ciupi",
    "ciupiseși": "ciupi",
    "ciupiși": "ciupi",
    "ciupit": "ciupi",
    "ciupiți": "ciupi",
    "ciupitu": "ciupi",
    "neciupind": "ciupi",
    "neciupindu": "ciupi",
    "nemaiciupind": "ciupi",
    "nemaiciupindu": "ciupi",
    "ciupita": "ciupit",
    "ciupită": "ciupit",
    "ciupite": "ciupit",
    "ciupitei": "ciupit",
    "ciupitele": "ciupit",
    "ciupitelor": "ciupit",
    "ciupiți": "ciupit",
    "ciupiții": "ciupit",
    "ciupiților": "ciupit",
    "ciupito": "ciupit",
    "ciupitul": "ciupit",
    "ciupitule": "ciupit",
    "ciupitului": "ciupit",
    "ciupitura": "ciupitură",
    "ciupituri": "ciupitură",
    "ciupiturii": "ciupitură",
    "ciupiturile": "ciupitură",
    "ciupiturilor": "ciupitură",
    "ciupituro": "ciupitură",
    "ciurul": "ciur",
    "ciurule": "ciur",
    "ciurului": "ciur",
    "ciururi": "ciur",
    "ciururile": "ciur",
    "ciururilor": "ciur",
    "ciurari": "ciurar",
    "ciurarii": "ciurar",
    "ciurarilor": "ciurar",
    "ciurarul": "ciurar",
    "ciurarule": "ciurar",
    "ciurarului": "ciurar",
    "ciurda": "ciurdă",
    "ciurde": "ciurdă",
    "ciurdei": "ciurdă",
    "ciurdele": "ciurdă",
    "ciurdelor": "ciurdă",
    "ciurdo": "ciurdă",
    "ciurdari": "ciurdar",
    "ciurdarii": "ciurdar",
    "ciurdarilor": "ciurdar",
    "ciurdarul": "ciurdar",
    "ciurdarule": "ciurdar",
    "ciurdarului": "ciurdar",
    "ciurele": "ciurel",
    "ciurelele": "ciurel",
    "ciurelelor": "ciurel",
    "ciurelul": "ciurel",
    "ciurelule": "ciurel",
    "ciurelului": "ciurel",
    "ciurucul": "ciuruc",
    "ciurucule": "ciuruc",
    "ciurucului": "ciuruc",
    "ciurucuri": "ciuruc",
    "ciurucurile": "ciuruc",
    "ciurucurilor": "ciuruc",
    "ciuruia": "ciurui",
    "ciuruiai": "ciurui",
    "ciuruiam": "ciurui",
    "ciuruiască": "ciurui",
    "ciuruiați": "ciurui",
    "ciuruiau": "ciurui",
    "ciuruiesc": "ciurui",
    "ciuruiește": "ciurui",
    "ciuruiești": "ciurui",
    "ciuruii": "ciurui",
    "ciuruim": "ciurui",
    "ciuruind": "ciurui",
    "ciuruindu": "ciurui",
    "ciuruiră": "ciurui",
    "ciuruirăm": "ciurui",
    "ciuruirăți": "ciurui",
    "ciuruise": "ciurui",
    "ciuruisem": "ciurui",
    "ciuruiseră": "ciurui",
    "ciuruiserăm": "ciurui",
    "ciuruiserăți": "ciurui",
    "ciuruiseși": "ciurui",
    "ciuruiși": "ciurui",
    "ciuruit": "ciurui",
    "ciuruiți": "ciurui",
    "ciuruitu": "ciurui",
    "neciuruind": "ciurui",
    "neciuruindu": "ciurui",
    "nemaiciuruind": "ciurui",
    "nemaiciuruindu": "ciurui",
    "ciuruiala": "ciuruială",
    "ciuruialo": "ciuruială",
    "ciuruieli": "ciuruială",
    "ciuruielii": "ciuruială",
    "ciuruielile": "ciuruială",
    "ciuruielilor": "ciuruială",
    "ciuruirea": "ciuruire",
    "ciuruireo": "ciuruire",
    "ciuruiri": "ciuruire",
    "ciuruirii": "ciuruire",
    "ciuruirile": "ciuruire",
    "ciuruirilor": "ciuruire",
    "ciuruită": "ciuruit",
    "ciuruite": "ciuruit",
    "ciuruiți": "ciuruit",
    "ciuruitoare": "ciuruitor",
    "ciuruitoarea": "ciuruitor",
    "ciuruitoarei": "ciuruitor",
    "ciuruitoarele": "ciuruitor",
    "ciuruitoarelor": "ciuruitor",
    "ciuruitoareo": "ciuruitor",
    "ciuruitori": "ciuruitor",
    "ciuruitorii": "ciuruitor",
    "ciuruitorilor": "ciuruitor",
    "ciuruitorul": "ciuruitor",
    "ciuruitorule": "ciuruitor",
    "ciuruitorului": "ciuruitor",
    "ciuta": "ciută",
    "ciute": "ciută",
    "ciutei": "ciută",
    "ciutele": "ciută",
    "ciutelor": "ciută",
    "ciuto": "ciută",
    "ciutura": "ciutură",
    "ciuturi": "ciutură",
    "ciuturii": "ciutură",
    "ciuturile": "ciutură",
    "ciuturilor": "ciutură",
    "ciuturo": "ciutură",
    "civica": "civic",
    "civică": "civic",
    "civice": "civic",
    "civicei": "civic",
    "civicele": "civic",
    "civicelor": "civic",
    "civici": "civic",
    "civicii": "civic",
    "civicilor": "civic",
    "civico": "civic",
    "civicul": "civic",
    "civicule": "civic",
    "civicului": "civic",
    "civila": "civil",
    "civilă": "civil",
    "civile": "civil",
    "civilei": "civil",
    "civilele": "civil",
    "civilelor": "civil",
    "civili": "civil",
    "civilii": "civil",
    "civililor": "civil",
    "civilo": "civil",
    "civilul": "civil",
    "civilule": "civil",
    "civilului": "civil",
    "civiliză": "civiliza",
    "civilizai": "civiliza",
    "civilizam": "civiliza",
    "civilizăm": "civiliza",
    "civilizând": "civiliza",
    "civilizându": "civiliza",
    "civilizară": "civiliza",
    "civilizarăm": "civiliza",
    "civilizarăți": "civiliza",
    "civilizase": "civiliza",
    "civilizasem": "civiliza",
    "civilizaseră": "civiliza",
    "civilizaserăm": "civiliza",
    "civilizaserăți": "civiliza",
    "civilizaseși": "civiliza",
    "civilizași": "civiliza",
    "civilizat": "civiliza",
    "civilizați": "civiliza",
    "civilizatu": "civiliza",
    "civilizau": "civiliza",
    "civilizează": "civiliza",
    "civilizez": "civiliza",
    "civilizeze": "civiliza",
    "civilizezi": "civiliza",
    "necivilizând": "civiliza",
    "necivilizându": "civiliza",
    "nemaicivilizând": "civiliza",
    "nemaicivilizându": "civiliza",
    "civilizarea": "civilizare",
    "civilizareo": "civilizare",
    "civilizări": "civilizare",
    "civilizării": "civilizare",
    "civilizările": "civilizare",
    "civilizărilor": "civilizare",
    "civilizata": "civilizat",
    "civilizată": "civilizat",
    "civilizate": "civilizat",
    "civilizatei": "civilizat",
    "civilizatele": "civilizat",
    "civilizatelor": "civilizat",
    "civilizați": "civilizat",
    "civilizații": "civilizat",
    "civilizaților": "civilizat",
    "civilizato": "civilizat",
    "civilizatul": "civilizat",
    "civilizatule": "civilizat",
    "civilizatului": "civilizat",
    "civilizația": "civilizație",
    "civilizației": "civilizație",
    "civilizații": "civilizație",
    "civilizațiile": "civilizație",
    "civilizațiilor": "civilizație",
    "civilizațio": "civilizație",
    "civilizatoare": "civilizator",
    "civilizatoarea": "civilizator",
    "civilizatoarei": "civilizator",
    "civilizatoarele": "civilizator",
    "civilizatoarelor": "civilizator",
    "civilizatoareo": "civilizator",
    "civilizatori": "civilizator",
    "civilizatorii": "civilizator",
    "civilizatorilor": "civilizator",
    "civilizatorul": "civilizator",
    "civilizatorule": "civilizator",
    "civilizatorului": "civilizator",
    "civismul": "civism",
    "civismule": "civism",
    "civismului": "civism",
    "cizelă": "cizela",
    "cizelai": "cizela",
    "cizelam": "cizela",
    "cizelăm": "cizela",
    "cizelând": "cizela",
    "cizelându": "cizela",
    "cizelară": "cizela",
    "cizelarăm": "cizela",
    "cizelarăți": "cizela",
    "cizelase": "cizela",
    "cizelasem": "cizela",
    "cizelaseră": "cizela",
    "cizelaserăm": "cizela",
    "cizelaserăți": "cizela",
    "cizelaseși": "cizela",
    "cizelași": "cizela",
    "cizelat": "cizela",
    "cizelați": "cizela",
    "cizelatu": "cizela",
    "cizelau": "cizela",
    "cizelează": "cizela",
    "cizelez": "cizela",
    "cizeleze": "cizela",
    "cizelezi": "cizela",
    "necizelând": "cizela",
    "necizelându": "cizela",
    "nemaicizelând": "cizela",
    "nemaicizelându": "cizela",
    "cizelarea": "cizelare",
    "cizelareo": "cizelare",
    "cizelări": "cizelare",
    "cizelării": "cizelare",
    "cizelările": "cizelare",
    "cizelărilor": "cizelare",
    "cizelata": "cizelat",
    "cizelată": "cizelat",
    "cizelate": "cizelat",
    "cizelatei": "cizelat",
    "cizelatele": "cizelat",
    "cizelatelor": "cizelat",
    "cizelați": "cizelat",
    "cizelații": "cizelat",
    "cizelaților": "cizelat",
    "cizelato": "cizelat",
    "cizelatul": "cizelat",
    "cizelatule": "cizelat",
    "cizelatului": "cizelat",
    "cizelura": "cizelură",
    "cizeluri": "cizelură",
    "cizelurii": "cizelură",
    "cizelurile": "cizelură",
    "cizelurilor": "cizelură",
    "cizeluro": "cizelură",
    "cizma": "cizmă",
    "cizme": "cizmă",
    "cizmei": "cizmă",
    "cizmele": "cizmă",
    "cizmelor": "cizmă",
    "cizmo": "cizmă",
    "cizmari": "cizmar",
    "cizmarii": "cizmar",
    "cizmarilor": "cizmar",
    "cizmarul": "cizmar",
    "cizmarule": "cizmar",
    "cizmarului": "cizmar",
    "cizmăreasa": "cizmăreasă",
    "cizmăreaso": "cizmăreasă",
    "cizmărese": "cizmăreasă",
    "cizmăresei": "cizmăreasă",
    "cizmăresele": "cizmăreasă",
    "cizmăreselor": "cizmăreasă",
    "cizmăreasca": "cizmăresc",
    "cizmărească": "cizmăresc",
    "cizmăreasco": "cizmăresc",
    "cizmărescul": "cizmăresc",
    "cizmărescule": "cizmăresc",
    "cizmărescului": "cizmăresc",
    "cizmărești": "cizmăresc",
    "cizmăreștii": "cizmăresc",
    "cizmăreștile": "cizmăresc",
    "cizmăreștilor": "cizmăresc",
    "cizmăria": "cizmărie",
    "cizmăriei": "cizmărie",
    "cizmării": "cizmărie",
    "cizmăriile": "cizmărie",
    "cizmăriilor": "cizmărie",
    "cizmărio": "cizmărie",
    "cizmulița": "cizmuliță",
    "cizmulițe": "cizmuliță",
    "cizmuliței": "cizmuliță",
    "cizmulițele": "cizmuliță",
    "cizmulițelor": "cizmuliță",
    "cizmulițo": "cizmuliță",
    "clăbuci": "clăbuc",
    "clăbucii": "clăbuc",
    "clăbucilor": "clăbuc",
    "clăbucul": "clăbuc",
    "clăbucule": "clăbuc",
    "clăbucului": "clăbuc",
    "clăbucea": "clăbuci",
    "clăbuceai": "clăbuci",
    "clăbuceam": "clăbuci",
    "clăbucească": "clăbuci",
    "clăbuceați": "clăbuci",
    "clăbuceau": "clăbuci",
    "clăbucesc": "clăbuci",
    "clăbucește": "clăbuci",
    "clăbucești": "clăbuci",
    "clăbucii": "clăbuci",
    "clăbucim": "clăbuci",
    "clăbucind": "clăbuci",
    "clăbucindu": "clăbuci",
    "clăbuciră": "clăbuci",
    "clăbucirăm": "clăbuci",
    "clăbucirăți": "clăbuci",
    "clăbucise": "clăbuci",
    "clăbucisem": "clăbuci",
    "clăbuciseră": "clăbuci",
    "clăbuciserăm": "clăbuci",
    "clăbuciserăți": "clăbuci",
    "clăbuciseși": "clăbuci",
    "clăbuciși": "clăbuci",
    "clăbucit": "clăbuci",
    "clăbuciți": "clăbuci",
    "clăbucitu": "clăbuci",
    "neclăbucind": "clăbuci",
    "neclăbucindu": "clăbuci",
    "nemaiclăbucind": "clăbuci",
    "nemaiclăbucindu": "clăbuci",
    "clăbucită": "clăbucit",
    "clăbucite": "clăbucit",
    "clăbuciți": "clăbucit",
    "clacă": "claca",
    "clacai": "claca",
    "clacam": "claca",
    "clacăm": "claca",
    "clacând": "claca",
    "clacându": "claca",
    "clacară": "claca",
    "clacarăm": "claca",
    "clacarăți": "claca",
    "clacase": "claca",
    "clacasem": "claca",
    "clacaseră": "claca",
    "clacaserăm": "claca",
    "clacaserăți": "claca",
    "clacaseși": "claca",
    "clacași": "claca",
    "clacat": "claca",
    "clacați": "claca",
    "clacatu": "claca",
    "clacau": "claca",
    "clachează": "claca",
    "clachez": "claca",
    "clacheze": "claca",
    "clachezi": "claca",
    "claca": "clacă",
    "clăci": "clacă",
    "clăcii": "clacă",
    "clăcile": "clacă",
    "clăcilor": "clacă",
    "claco": "clacă",
    "clăcași": "clăcaș",
    "clăcașii": "clăcaș",
    "clăcașilor": "clăcaș",
    "clăcașul": "clăcaș",
    "clăcașule": "clăcaș",
    "clăcașului": "clăcaș",
    "clacată": "clacat",
    "clacate": "clacat",
    "clacați": "clacat",
    "clădea": "clădi",
    "clădeai": "clădi",
    "clădeam": "clădi",
    "clădească": "clădi",
    "clădeați": "clădi",
    "clădeau": "clădi",
    "clădesc": "clădi",
    "clădește": "clădi",
    "clădești": "clădi",
    "clădii": "clădi",
    "clădim": "clădi",
    "clădind": "clădi",
    "clădindu": "clădi",
    "clădiră": "clădi",
    "clădirăm": "clădi",
    "clădirăți": "clădi",
    "clădise": "clădi",
    "clădisem": "clădi",
    "clădiseră": "clădi",
    "clădiserăm": "clădi",
    "clădiserăți": "clădi",
    "clădiseși": "clădi",
    "clădiși": "clădi",
    "clădit": "clădi",
    "clădiți": "clădi",
    "clăditu": "clădi",
    "neclădind": "clădi",
    "neclădindu": "clădi",
    "nemaiclădind": "clădi",
    "nemaiclădindu": "clădi",
    "clădirea": "clădire",
    "clădireo": "clădire",
    "clădiri": "clădire",
    "clădirii": "clădire",
    "clădirile": "clădire",
    "clădirilor": "clădire",
    "clădită": "clădit",
    "clădite": "clădit",
    "clădiți": "clădit",
    "clăditul": "clădit",
    "clăditule": "clădit",
    "clăditului": "clădit",
    "clăditoare": "clăditor",
    "clăditoarea": "clăditor",
    "clăditoarei": "clăditor",
    "clăditoarele": "clăditor",
    "clăditoarelor": "clăditor",
    "clăditoareo": "clăditor",
    "clăditori": "clăditor",
    "clăditorii": "clăditor",
    "clăditorilor": "clăditor",
    "clăditorul": "clăditor",
    "clăditorule": "clăditor",
    "clăditorului": "clăditor",
    "clăi": "claie",
    "claia": "claie",
    "clăii": "claie",
    "clăile": "claie",
    "clăilor": "claie",
    "claio": "claie",
    "clăița": "clăiță",
    "clăițe": "clăiță",
    "clăiței": "clăiță",
    "clăițele": "clăiță",
    "clăițelor": "clăiță",
    "clăițo": "clăiță",
    "clama": "clamă",
    "clame": "clamă",
    "clamei": "clamă",
    "clamele": "clamă",
    "clamelor": "clamă",
    "clamo": "clamă",
    "clamata": "clamat",
    "clamată": "clamat",
    "clamate": "clamat",
    "clamatei": "clamat",
    "clamatele": "clamat",
    "clamatelor": "clamat",
    "clamați": "clamat",
    "clamații": "clamat",
    "clamaților": "clamat",
    "clamato": "clamat",
    "clamatul": "clamat",
    "clamatule": "clamat",
    "clamatului": "clamat",
    "clămpăneala": "clămpăneală",
    "clămpănealo": "clămpăneală",
    "clămpăneli": "clămpăneală",
    "clămpănelii": "clămpăneală",
    "clămpănelile": "clămpăneală",
    "clămpănelilor": "clămpăneală",
    "clămpănea": "clămpăni",
    "clămpăneai": "clămpăni",
    "clămpăneam": "clămpăni",
    "clămpănească": "clămpăni",
    "clămpăneați": "clămpăni",
    "clămpăneau": "clămpăni",
    "clămpănesc": "clămpăni",
    "clămpănește": "clămpăni",
    "clămpănești": "clămpăni",
    "clămpănii": "clămpăni",
    "clămpănim": "clămpăni",
    "clămpănind": "clămpăni",
    "clămpănindu": "clămpăni",
    "clămpăniră": "clămpăni",
    "clămpănirăm": "clămpăni",
    "clămpănirăți": "clămpăni",
    "clămpănise": "clămpăni",
    "clămpănisem": "clămpăni",
    "clămpăniseră": "clămpăni",
    "clămpăniserăm": "clămpăni",
    "clămpăniserăți": "clămpăni",
    "clămpăniseși": "clămpăni",
    "clămpăniși": "clămpăni",
    "clămpănit": "clămpăni",
    "clămpăniți": "clămpăni",
    "clămpănitu": "clămpăni",
    "neclămpănind": "clămpăni",
    "neclămpănindu": "clămpăni",
    "nemaiclămpănind": "clămpăni",
    "nemaiclămpănindu": "clămpăni",
    "clămpănirea": "clămpănire",
    "clămpănireo": "clămpănire",
    "clămpăniri": "clămpănire",
    "clămpănirii": "clămpănire",
    "clămpănirile": "clămpănire",
    "clămpănirilor": "clămpănire",
    "clămpănită": "clămpănit",
    "clămpănite": "clămpănit",
    "clămpăniți": "clămpănit",
    "clămpănitul": "clămpănit",
    "clămpănitule": "clămpănit",
    "clămpănitului": "clămpănit",
    "clămpănitura": "clămpănitură",
    "clămpănituri": "clămpănitură",
    "clămpăniturii": "clămpănitură",
    "clămpăniturile": "clămpănitură",
    "clămpăniturilor": "clămpănitură",
    "clămpănituro": "clămpănitură",
    "clanul": "clan",
    "clanule": "clan",
    "clanului": "clan",
    "clanuri": "clan",
    "clanurile": "clan",
    "clanurilor": "clan",
    "clandestina": "clandestin",
    "clandestină": "clandestin",
    "clandestine": "clandestin",
    "clandestinei": "clandestin",
    "clandestinele": "clandestin",
    "clandestinelor": "clandestin",
    "clandestini": "clandestin",
    "clandestinii": "clandestin",
    "clandestinilor": "clandestin",
    "clandestino": "clandestin",
    "clandestinul": "clandestin",
    "clandestinule": "clandestin",
    "clandestinului": "clandestin",
    "clandestinitatea": "clandestinitate",
    "clandestinitateo": "clandestinitate",
    "clandestinități": "clandestinitate",
    "clandestinității": "clandestinitate",
    "clandestinitățile": "clandestinitate",
    "clandestinităților": "clandestinitate",
    "clanțul": "clanț",
    "clanțule": "clanț",
    "clanțului": "clanț",
    "clanțuri": "clanț",
    "clanțurile": "clanț",
    "clanțurilor": "clanț",
    "clanța": "clanță",
    "clanțe": "clanță",
    "clanței": "clanță",
    "clanțele": "clanță",
    "clanțelor": "clanță",
    "clanțo": "clanță",
    "clănțăneala": "clănțăneală",
    "clănțănealo": "clănțăneală",
    "clănțăneli": "clănțăneală",
    "clănțănelii": "clănțăneală",
    "clănțănelile": "clănțăneală",
    "clănțănelilor": "clănțăneală",
    "clănțăn": "clănțăni",
    "clănțăne": "clănțăni",
    "clănțănea": "clănțăni",
    "clănțăneai": "clănțăni",
    "clănțăneam": "clănțăni",
    "clănțănească": "clănțăni",
    "clănțăneați": "clănțăni",
    "clănțăneau": "clănțăni",
    "clănțănesc": "clănțăni",
    "clănțănește": "clănțăni",
    "clănțănești": "clănțăni",
    "clănțănii": "clănțăni",
    "clănțănim": "clănțăni",
    "clănțănind": "clănțăni",
    "clănțănindu": "clănțăni",
    "clănțăniră": "clănțăni",
    "clănțănirăm": "clănțăni",
    "clănțănirăți": "clănțăni",
    "clănțănise": "clănțăni",
    "clănțănisem": "clănțăni",
    "clănțăniseră": "clănțăni",
    "clănțăniserăm": "clănțăni",
    "clănțăniserăți": "clănțăni",
    "clănțăniseși": "clănțăni",
    "clănțăniși": "clănțăni",
    "clănțănit": "clănțăni",
    "clănțăniți": "clănțăni",
    "clănțănitu": "clănțăni",
    "neclănțănind": "clănțăni",
    "neclănțănindu": "clănțăni",
    "nemaiclănțănind": "clănțăni",
    "nemaiclănțănindu": "clănțăni",
    "clănțănirea": "clănțănire",
    "clănțănireo": "clănțănire",
    "clănțăniri": "clănțănire",
    "clănțănirii": "clănțănire",
    "clănțănirile": "clănțănire",
    "clănțănirilor": "clănțănire",
    "clănțănită": "clănțănit",
    "clănțănite": "clănțănit",
    "clănțăniți": "clănțănit",
    "clănțănitul": "clănțănit",
    "clănțănitule": "clănțănit",
    "clănțănitului": "clănțănit",
    "clănțănitura": "clănțănitură",
    "clănțănituri": "clănțănitură",
    "clănțăniturii": "clănțănitură",
    "clănțăniturile": "clănțănitură",
    "clănțăniturilor": "clănțănitură",
    "clănțănituro": "clănțănitură",
    "clănțăi": "clănțău",
    "clănțăii": "clănțău",
    "clănțăilor": "clănțău",
    "clănțăul": "clănțău",
    "clănțăule": "clănțău",
    "clănțăului": "clănțău",
    "clapa": "clapă",
    "clape": "clapă",
    "clapei": "clapă",
    "clapele": "clapă",
    "clapelor": "clapă",
    "clapo": "clapă",
    "clăpăuga": "clăpăug",
    "clăpăugă": "clăpăug",
    "clăpăuge": "clăpăug",
    "clăpăugei": "clăpăug",
    "clăpăugele": "clăpăug",
    "clăpăugelor": "clăpăug",
    "clăpăugi": "clăpăug",
    "clăpăugii": "clăpăug",
    "clăpăugilor": "clăpăug",
    "clăpăugo": "clăpăug",
    "clăpăugul": "clăpăug",
    "clăpăugule": "clăpăug",
    "clăpăugului": "clăpăug",
    "claponi": "clapon",
    "claponii": "clapon",
    "claponilor": "clapon",
    "claponul": "clapon",
    "claponule": "clapon",
    "claponului": "clapon",
    "claponași": "claponaș",
    "claponașii": "claponaș",
    "claponașilor": "claponaș",
    "claponașul": "claponaș",
    "claponașule": "claponaș",
    "claponașului": "claponaș",
    "clara": "clar",
    "clară": "clar",
    "clare": "clar",
    "clarei": "clar",
    "clarele": "clar",
    "clarelor": "clar",
    "clari": "clar",
    "clarii": "clar",
    "clarilor": "clar",
    "claro": "clar",
    "clarul": "clar",
    "clarule": "clar",
    "clarului": "clar",
    "clarific": "clarifica",
    "clarifică": "clarifica",
    "clarificai": "clarifica",
    "clarificam": "clarifica",
    "clarificăm": "clarifica",
    "clarificând": "clarifica",
    "clarificându": "clarifica",
    "clarificară": "clarifica",
    "clarificarăm": "clarifica",
    "clarificarăți": "clarifica",
    "clarificase": "clarifica",
    "clarificasem": "clarifica",
    "clarificaseră": "clarifica",
    "clarificaserăm": "clarifica",
    "clarificaserăți": "clarifica",
    "clarificaseși": "clarifica",
    "clarificași": "clarifica",
    "clarificat": "clarifica",
    "clarificați": "clarifica",
    "clarificatu": "clarifica",
    "clarificau": "clarifica",
    "clarifice": "clarifica",
    "clarifici": "clarifica",
    "neclarificând": "clarifica",
    "neclarificându": "clarifica",
    "nemaiclarificând": "clarifica",
    "nemaiclarificându": "clarifica",
    "clarificarea": "clarificare",
    "clarificareo": "clarificare",
    "clarificări": "clarificare",
    "clarificării": "clarificare",
    "clarificările": "clarificare",
    "clarificărilor": "clarificare",
    "clarificată": "clarificat",
    "clarificate": "clarificat",
    "clarificați": "clarificat",
    "clarificatoare": "clarificator",
    "clarificatoarea": "clarificator",
    "clarificatoarei": "clarificator",
    "clarificatoarele": "clarificator",
    "clarificatoarelor": "clarificator",
    "clarificatoareo": "clarificator",
    "clarificatori": "clarificator",
    "clarificatorii": "clarificator",
    "clarificatorilor": "clarificator",
    "clarificatorul": "clarificator",
    "clarificatorule": "clarificator",
    "clarificatorului": "clarificator",
    "clarinete": "clarinet",
    "clarinetele": "clarinet",
    "clarinetelor": "clarinet",
    "clarinetul": "clarinet",
    "clarinetule": "clarinet",
    "clarinetului": "clarinet",
    "clarinetiști": "clarinetist",
    "clarinetiștii": "clarinetist",
    "clarinetiștilor": "clarinetist",
    "clarinetistul": "clarinetist",
    "clarinetistule": "clarinetist",
    "clarinetistului": "clarinetist",
    "clarinetista": "clarinetistă",
    "clarinetiste": "clarinetistă",
    "clarinetistei": "clarinetistă",
    "clarinetistele": "clarinetistă",
    "clarinetistelor": "clarinetistă",
    "clarinetisto": "clarinetistă",
    "claritatea": "claritate",
    "claritateo": "claritate",
    "clarități": "claritate",
    "clarității": "claritate",
    "claritățile": "claritate",
    "clarităților": "claritate",
    "clarobscurul": "clarobscur",
    "clarobscurule": "clarobscur",
    "clarobscurului": "clarobscur",
    "clar-obscurul": "clar-obscur",
    "clar-obscurului": "clar-obscur",
    "clarvăzătoare": "clarvăzător",
    "clarvăzătoarea": "clarvăzător",
    "clarvăzătoarei": "clarvăzător",
    "clarvăzătoarele": "clarvăzător",
    "clarvăzătoarelor": "clarvăzător",
    "clarvăzătoareo": "clarvăzător",
    "clarvăzători": "clarvăzător",
    "clarvăzătorii": "clarvăzător",
    "clarvăzătorilor": "clarvăzător",
    "clarvăzătorul": "clarvăzător",
    "clarvăzătorule": "clarvăzător",
    "clarvăzătorului": "clarvăzător",
    "clarviziunea": "clarviziune",
    "clarviziuneo": "clarviziune",
    "clarviziuni": "clarviziune",
    "clarviziunii": "clarviziune",
    "clarviziunile": "clarviziune",
    "clarviziunilor": "clarviziune",
    "clasă": "clasa",
    "clasai": "clasa",
    "clasam": "clasa",
    "clasăm": "clasa",
    "clasând": "clasa",
    "clasându": "clasa",
    "clasară": "clasa",
    "clasarăm": "clasa",
    "clasarăți": "clasa",
    "clasase": "clasa",
    "clasasem": "clasa",
    "clasaseră": "clasa",
    "clasaserăm": "clasa",
    "clasaserăți": "clasa",
    "clasaseși": "clasa",
    "clasași": "clasa",
    "clasat": "clasa",
    "clasați": "clasa",
    "clasatu": "clasa",
    "clasau": "clasa",
    "clasează": "clasa",
    "clasez": "clasa",
    "claseze": "clasa",
    "clasezi": "clasa",
    "neclasând": "clasa",
    "neclasându": "clasa",
    "nemaiclasând": "clasa",
    "nemaiclasându": "clasa",
    "clasa": "clasă",
    "clase": "clasă",
    "clasei": "clasă",
    "clasele": "clasă",
    "claselor": "clasă",
    "claso": "clasă",
    "clasabila": "clasabil",
    "clasabilă": "clasabil",
    "clasabile": "clasabil",
    "clasabilei": "clasabil",
    "clasabilele": "clasabil",
    "clasabilelor": "clasabil",
    "clasabili": "clasabil",
    "clasabilii": "clasabil",
    "clasabililor": "clasabil",
    "clasabilo": "clasabil",
    "clasabilul": "clasabil",
    "clasabilule": "clasabil",
    "clasabilului": "clasabil",
    "clasamente": "clasament",
    "clasamentele": "clasament",
    "clasamentelor": "clasament",
    "clasamentul": "clasament",
    "clasamentule": "clasament",
    "clasamentului": "clasament",
    "clasarea": "clasare",
    "clasareo": "clasare",
    "clasări": "clasare",
    "clasării": "clasare",
    "clasările": "clasare",
    "clasărilor": "clasare",
    "clasată": "clasat",
    "clasate": "clasat",
    "clasați": "clasat",
    "clasica": "clasic",
    "clasică": "clasic",
    "clasice": "clasic",
    "clasicei": "clasic",
    "clasicele": "clasic",
    "clasicelor": "clasic",
    "clasici": "clasic",
    "clasicii": "clasic",
    "clasicilor": "clasic",
    "clasico": "clasic",
    "clasicul": "clasic",
    "clasicule": "clasic",
    "clasicului": "clasic",
    "clasicismul": "clasicism",
    "clasicismule": "clasicism",
    "clasicismului": "clasicism",
    "clasific": "clasifica",
    "clasifică": "clasifica",
    "clasificai": "clasifica",
    "clasificam": "clasifica",
    "clasificăm": "clasifica",
    "clasificând": "clasifica",
    "clasificându": "clasifica",
    "clasificară": "clasifica",
    "clasificarăm": "clasifica",
    "clasificarăți": "clasifica",
    "clasificase": "clasifica",
    "clasificasem": "clasifica",
    "clasificaseră": "clasifica",
    "clasificaserăm": "clasifica",
    "clasificaserăți": "clasifica",
    "clasificaseși": "clasifica",
    "clasificași": "clasifica",
    "clasificat": "clasifica",
    "clasificați": "clasifica",
    "clasificatu": "clasifica",
    "clasificau": "clasifica",
    "clasifice": "clasifica",
    "clasifici": "clasifica",
    "neclasificând": "clasifica",
    "neclasificându": "clasifica",
    "nemaiclasificând": "clasifica",
    "nemaiclasificându": "clasifica",
    "clasificarea": "clasificare",
    "clasificareo": "clasificare",
    "clasificări": "clasificare",
    "clasificării": "clasificare",
    "clasificările": "clasificare",
    "clasificărilor": "clasificare",
    "clasificată": "clasificat",
    "clasificate": "clasificat",
    "clasificați": "clasificat",
    "clasificatoarea": "clasificatoare",
    "clasificatoarei": "clasificatoare",
    "clasificatoarele": "clasificatoare",
    "clasificatoarelor": "clasificatoare",
    "clasificatoareo": "clasificatoare",
    "clasificatori": "clasificator",
    "clasificatorii": "clasificator",
    "clasificatorilor": "clasificator",
    "clasificatorul": "clasificator",
    "clasificatorule": "clasificator",
    "clasificatorului": "clasificator",
    "clasoare": "clasor",
    "clasoarele": "clasor",
    "clasoarelor": "clasor",
    "clasorul": "clasor",
    "clasorule": "clasor",
    "clasorului": "clasor",
    "clătea": "clăti",
    "clăteai": "clăti",
    "clăteam": "clăti",
    "clătească": "clăti",
    "clăteați": "clăti",
    "clăteau": "clăti",
    "clătesc": "clăti",
    "clătește": "clăti",
    "clătești": "clăti",
    "clătii": "clăti",
    "clătim": "clăti",
    "clătind": "clăti",
    "clătindu": "clăti",
    "clătiră": "clăti",
    "clătirăm": "clăti",
    "clătirăți": "clăti",
    "clătise": "clăti",
    "clătisem": "clăti",
    "clătiseră": "clăti",
    "clătiserăm": "clăti",
    "clătiserăți": "clăti",
    "clătiseși": "clăti",
    "clătiși": "clăti",
    "clătit": "clăti",
    "clătiți": "clăti",
    "clătitu": "clăti",
    "neclătind": "clăti",
    "neclătindu": "clăti",
    "nemaiclătind": "clăti",
    "nemaiclătindu": "clăti",
    "clatin": "clătina",
    "clatină": "clătina",
    "clătină": "clătina",
    "clătinai": "clătina",
    "clătinam": "clătina",
    "clătinăm": "clătina",
    "clătinând": "clătina",
    "clătinându": "clătina",
    "clătinară": "clătina",
    "clătinarăm": "clătina",
    "clătinarăți": "clătina",
    "clătinase": "clătina",
    "clătinasem": "clătina",
    "clătinaseră": "clătina",
    "clătinaserăm": "clătina",
    "clătinaserăți": "clătina",
    "clătinaseși": "clătina",
    "clătinași": "clătina",
    "clătinat": "clătina",
    "clătinați": "clătina",
    "clătinatu": "clătina",
    "clătinau": "clătina",
    "clatine": "clătina",
    "clatini": "clătina",
    "neclătinând": "clătina",
    "neclătinându": "clătina",
    "nemaiclătinând": "clătina",
    "nemaiclătinându": "clătina",
    "clătinarea": "clătinare",
    "clătinareo": "clătinare",
    "clătinări": "clătinare",
    "clătinării": "clătinare",
    "clătinările": "clătinare",
    "clătinărilor": "clătinare",
    "clătinată": "clătinat",
    "clătinate": "clătinat",
    "clătinați": "clătinat",
    "clătinătura": "clătinătură",
    "clătinături": "clătinătură",
    "clătinăturii": "clătinătură",
    "clătinăturile": "clătinătură",
    "clătinăturilor": "clătinătură",
    "clătinăturo": "clătinătură",
    "clătirea": "clătire",
    "clătireo": "clătire",
    "clătiri": "clătire",
    "clătirii": "clătire",
    "clătirile": "clătire",
    "clătirilor": "clătire",
    "clătită": "clătit",
    "clătite": "clătit",
    "clătiți": "clătit",
    "clătitul": "clătit",
    "clătitule": "clătit",
    "clătitului": "clătit",
    "Claudie": "Claudia",
    "Claudiei": "Claudia",
    "Claudii": "Claudia",
    "Cl.": "Claudiu",
    "claustră": "claustra",
    "claustrai": "claustra",
    "claustram": "claustra",
    "claustrăm": "claustra",
    "claustrând": "claustra",
    "claustrându": "claustra",
    "claustrară": "claustra",
    "claustrarăm": "claustra",
    "claustrarăți": "claustra",
    "claustrase": "claustra",
    "claustrasem": "claustra",
    "claustraseră": "claustra",
    "claustraserăm": "claustra",
    "claustraserăți": "claustra",
    "claustraseși": "claustra",
    "claustrași": "claustra",
    "claustrat": "claustra",
    "claustrați": "claustra",
    "claustratu": "claustra",
    "claustrau": "claustra",
    "claustrează": "claustra",
    "claustrez": "claustra",
    "claustreze": "claustra",
    "claustrezi": "claustra",
    "neclaustrând": "claustra",
    "neclaustrându": "claustra",
    "nemaiclaustrând": "claustra",
    "nemaiclaustrându": "claustra",
    "claustrala": "claustral",
    "claustrală": "claustral",
    "claustrale": "claustral",
    "claustralei": "claustral",
    "claustralele": "claustral",
    "claustralelor": "claustral",
    "claustrali": "claustral",
    "claustralii": "claustral",
    "claustralilor": "claustral",
    "claustralo": "claustral",
    "claustralul": "claustral",
    "claustralule": "claustral",
    "claustralului": "claustral",
    "claustrarea": "claustrare",
    "claustrareo": "claustrare",
    "claustrări": "claustrare",
    "claustrării": "claustrare",
    "claustrările": "claustrare",
    "claustrărilor": "claustrare",
    "claustrată": "claustrat",
    "claustrate": "claustrat",
    "claustrați": "claustrat",
    "clauza": "clauză",
    "clauze": "clauză",
    "clauzei": "clauză",
    "clauzele": "clauză",
    "clauzelor": "clauză",
    "clauzo": "clauză",
    "clavecine": "clavecin",
    "clavecinele": "clavecin",
    "clavecinelor": "clavecin",
    "clavecinul": "clavecin",
    "clavecinule": "clavecin",
    "clavecinului": "clavecin",
    "claviatura": "claviatură",
    "claviaturi": "claviatură",
    "claviaturii": "claviatură",
    "claviaturile": "claviatură",
    "claviaturilor": "claviatură",
    "claviaturo": "claviatură",
    "clavicula": "claviculă",
    "clavicule": "claviculă",
    "claviculei": "claviculă",
    "claviculele": "claviculă",
    "claviculelor": "claviculă",
    "claviculo": "claviculă",
    "clavire": "clavir",
    "clavirele": "clavir",
    "clavirelor": "clavir",
    "clavirul": "clavir",
    "clavirule": "clavir",
    "clavirului": "clavir",
    "clavirașe": "claviraș",
    "clavirașele": "claviraș",
    "clavirașelor": "claviraș",
    "clavirașul": "claviraș",
    "clavirașule": "claviraș",
    "clavirașului": "claviraș",
    "claxoane": "claxon",
    "claxoanele": "claxon",
    "claxoanelor": "claxon",
    "claxonul": "claxon",
    "claxonule": "claxon",
    "claxonului": "claxon",
    "claxonă": "claxona",
    "claxonai": "claxona",
    "claxonam": "claxona",
    "claxonăm": "claxona",
    "claxonând": "claxona",
    "claxonându": "claxona",
    "claxonară": "claxona",
    "claxonarăm": "claxona",
    "claxonarăți": "claxona",
    "claxonase": "claxona",
    "claxonasem": "claxona",
    "claxonaseră": "claxona",
    "claxonaserăm": "claxona",
    "claxonaserăți": "claxona",
    "claxonaseși": "claxona",
    "claxonași": "claxona",
    "claxonat": "claxona",
    "claxonați": "claxona",
    "claxonatu": "claxona",
    "claxonau": "claxona",
    "claxonează": "claxona",
    "claxonez": "claxona",
    "claxoneze": "claxona",
    "claxonezi": "claxona",
    "neclaxonând": "claxona",
    "neclaxonându": "claxona",
    "nemaiclaxonând": "claxona",
    "nemaiclaxonându": "claxona",
    "claxonată": "claxonat",
    "claxonate": "claxonat",
    "claxonați": "claxonat",
    "cleanul": "clean",
    "cleanule": "clean",
    "cleanului": "clean",
    "cleni": "clean",
    "clenii": "clean",
    "clenilor": "clean",
    "clefăia": "clefăi",
    "clefăiai": "clefăi",
    "clefăiam": "clefăi",
    "clefăiați": "clefăi",
    "clefăiau": "clefăi",
    "clefăie": "clefăi",
    "clefăii": "clefăi",
    "clefăim": "clefăi",
    "clefăind": "clefăi",
    "clefăindu": "clefăi",
    "clefăiră": "clefăi",
    "clefăirăm": "clefăi",
    "clefăirăți": "clefăi",
    "clefăise": "clefăi",
    "clefăisem": "clefăi",
    "clefăiseră": "clefăi",
    "clefăiserăm": "clefăi",
    "clefăiserăți": "clefăi",
    "clefăiseși": "clefăi",
    "clefăiși": "clefăi",
    "clefăit": "clefăi",
    "clefăiți": "clefăi",
    "clefăitu": "clefăi",
    "neclefăind": "clefăi",
    "neclefăindu": "clefăi",
    "nemaiclefăind": "clefăi",
    "nemaiclefăindu": "clefăi",
    "clefăită": "clefăit",
    "clefăite": "clefăit",
    "clefăiți": "clefăit",
    "clefăitul": "clefăit",
    "clefăitule": "clefăit",
    "clefăitului": "clefăit",
    "cleiul": "clei",
    "cleiule": "clei",
    "cleiului": "clei",
    "cleiuri": "clei",
    "cleiurile": "clei",
    "cleiurilor": "clei",
    "cleioasa": "cleios",
    "cleioasă": "cleios",
    "cleioase": "cleios",
    "cleioasei": "cleios",
    "cleioasele": "cleios",
    "cleioaselor": "cleios",
    "cleioaso": "cleios",
    "cleioși": "cleios",
    "cleioșii": "cleios",
    "cleioșilor": "cleios",
    "cleiosul": "cleios",
    "cleiosule": "cleios",
    "cleiosului": "cleios",
    "clema": "clemă",
    "cleme": "clemă",
    "clemei": "clemă",
    "clemele": "clemă",
    "clemelor": "clemă",
    "clemo": "clemă",
    "clementa": "clement",
    "clementă": "clement",
    "clemente": "clement",
    "clementei": "clement",
    "clementele": "clement",
    "clementelor": "clement",
    "clemenți": "clement",
    "clemenții": "clement",
    "clemenților": "clement",
    "clemento": "clement",
    "clementul": "clement",
    "clementule": "clement",
    "clementului": "clement",
    "clemența": "clemență",
    "clemențe": "clemență",
    "clemenței": "clemență",
    "clemențele": "clemență",
    "clemențelor": "clemență",
    "clemențo": "clemență",
    "clenciul": "clenci",
    "clenciule": "clenci",
    "clenciului": "clenci",
    "clenciuri": "clenci",
    "clenciurile": "clenci",
    "clenciurilor": "clenci",
    "clepsidra": "clepsidră",
    "clepsidre": "clepsidră",
    "clepsidrei": "clepsidră",
    "clepsidrele": "clepsidră",
    "clepsidrelor": "clepsidră",
    "clepsidro": "clepsidră",
    "cleptomani": "cleptoman",
    "cleptomanii": "cleptoman",
    "cleptomanilor": "cleptoman",
    "cleptomanul": "cleptoman",
    "cleptomanule": "cleptoman",
    "cleptomanului": "cleptoman",
    "cleptomana": "cleptomană",
    "cleptomane": "cleptomană",
    "cleptomanei": "cleptomană",
    "cleptomanele": "cleptomană",
    "cleptomanelor": "cleptomană",
    "cleptomano": "cleptomană",
    "cleptomania": "cleptomanie",
    "cleptomaniei": "cleptomanie",
    "cleptomanii": "cleptomanie",
    "cleptomaniile": "cleptomanie",
    "cleptomaniilor": "cleptomanie",
    "clerul": "cler",
    "clerule": "cler",
    "clerului": "cler",
    "cleruri": "cler",
    "clerurile": "cler",
    "clerurilor": "cler",
    "clerici": "cleric",
    "clericii": "cleric",
    "clericilor": "cleric",
    "clericul": "cleric",
    "clericule": "cleric",
    "clericului": "cleric",
    "clericala": "clerical",
    "clericală": "clerical",
    "clericale": "clerical",
    "clericalei": "clerical",
    "clericalele": "clerical",
    "clericalelor": "clerical",
    "clericali": "clerical",
    "clericalii": "clerical",
    "clericalilor": "clerical",
    "clericalo": "clerical",
    "clericalul": "clerical",
    "clericalule": "clerical",
    "clericalului": "clerical",
    "cleștare": "cleștar",
    "cleștarele": "cleștar",
    "cleștarelor": "cleștar",
    "cleștarul": "cleștar",
    "cleștarule": "cleștar",
    "cleștarului": "cleștar",
    "cleștele": "clește",
    "cleștelui": "clește",
    "clești": "clește",
    "cleștii": "clește",
    "cleștilor": "clește",
    "cleștișori": "cleștișor",
    "cleștișorii": "cleștișor",
    "cleștișorilor": "cleștișor",
    "cleștișorul": "cleștișor",
    "cleștișorule": "cleștișor",
    "cleștișorului": "cleștișor",
    "cleveteala": "cleveteală",
    "clevetealo": "cleveteală",
    "cleveteli": "cleveteală",
    "clevetelii": "cleveteală",
    "clevetelile": "cleveteală",
    "clevetelilor": "cleveteală",
    "clevetea": "cleveti",
    "cleveteai": "cleveti",
    "cleveteam": "cleveti",
    "clevetească": "cleveti",
    "cleveteați": "cleveti",
    "cleveteau": "cleveti",
    "clevetesc": "cleveti",
    "clevetește": "cleveti",
    "clevetești": "cleveti",
    "clevetii": "cleveti",
    "clevetim": "cleveti",
    "clevetind": "cleveti",
    "clevetindu": "cleveti",
    "clevetiră": "cleveti",
    "clevetirăm": "cleveti",
    "clevetirăți": "cleveti",
    "clevetise": "cleveti",
    "clevetisem": "cleveti",
    "clevetiseră": "cleveti",
    "clevetiserăm": "cleveti",
    "clevetiserăți": "cleveti",
    "clevetiseși": "cleveti",
    "clevetiși": "cleveti",
    "clevetit": "cleveti",
    "clevetiți": "cleveti",
    "clevetitu": "cleveti",
    "neclevetind": "cleveti",
    "neclevetindu": "cleveti",
    "nemaiclevetind": "cleveti",
    "nemaiclevetindu": "cleveti",
    "clevetirea": "clevetire",
    "clevetireo": "clevetire",
    "clevetiri": "clevetire",
    "clevetirii": "clevetire",
    "clevetirile": "clevetire",
    "clevetirilor": "clevetire",
    "clevetită": "clevetit",
    "clevetite": "clevetit",
    "clevetiți": "clevetit",
    "clevetitoarea": "clevetitoare",
    "clevetitoarei": "clevetitoare",
    "clevetitoarele": "clevetitoare",
    "clevetitoarelor": "clevetitoare",
    "clevetitoareo": "clevetitoare",
    "clevetitori": "clevetitor",
    "clevetitorii": "clevetitor",
    "clevetitorilor": "clevetitor",
    "clevetitorul": "clevetitor",
    "clevetitorule": "clevetitor",
    "clevetitorului": "clevetitor",
    "clica": "clică",
    "clici": "clică",
    "clicii": "clică",
    "clicile": "clică",
    "clicilor": "clică",
    "clico": "clică",
    "clienți": "client",
    "clienții": "client",
    "clienților": "client",
    "clientul": "client",
    "clientule": "client",
    "clientului": "client",
    "clienta": "clientă",
    "cliente": "clientă",
    "clientei": "clientă",
    "clientele": "clientă",
    "clientelor": "clientă",
    "cliento": "clientă",
    "clientela": "clientelă",
    "clientele": "clientelă",
    "clientelei": "clientelă",
    "clientelele": "clientelă",
    "clientelelor": "clientelă",
    "clientelo": "clientelă",
    "clienții-întreprindere": "client-întreprindere",
    "clima": "climă",
    "clime": "climă",
    "climei": "climă",
    "climele": "climă",
    "climelor": "climă",
    "climo": "climă",
    "climatul": "climat",
    "climatule": "climat",
    "climatului": "climat",
    "climaturi": "climat",
    "climaturile": "climat",
    "climaturilor": "climat",
    "climaterica": "climateric",
    "climaterică": "climateric",
    "climaterice": "climateric",
    "climatericei": "climateric",
    "climatericele": "climateric",
    "climatericelor": "climateric",
    "climaterici": "climateric",
    "climatericii": "climateric",
    "climatericilor": "climateric",
    "climaterico": "climateric",
    "climatericul": "climateric",
    "climatericule": "climateric",
    "climatericului": "climateric",
    "climatica": "climatic",
    "climatică": "climatic",
    "climatice": "climatic",
    "climaticei": "climatic",
    "climaticele": "climatic",
    "climaticelor": "climatic",
    "climatici": "climatic",
    "climaticii": "climatic",
    "climaticilor": "climatic",
    "climatico": "climatic",
    "climaticul": "climatic",
    "climaticule": "climatic",
    "climaticului": "climatic",
    "climatologica": "climatologic",
    "climatologică": "climatologic",
    "climatologice": "climatologic",
    "climatologicei": "climatologic",
    "climatologicele": "climatologic",
    "climatologicelor": "climatologic",
    "climatologici": "climatologic",
    "climatologicii": "climatologic",
    "climatologicilor": "climatologic",
    "climatologico": "climatologic",
    "climatologicul": "climatologic",
    "climatologicule": "climatologic",
    "climatologicului": "climatologic",
    "climatologia": "climatologie",
    "climatologiei": "climatologie",
    "climatologii": "climatologie",
    "climatologiile": "climatologie",
    "climatologiilor": "climatologie",
    "climatologio": "climatologie",
    "clini": "clin",
    "clinii": "clin",
    "clinilor": "clin",
    "clinul": "clin",
    "clinule": "clin",
    "clinului": "clin",
    "clinuri": "clin",
    "clinurile": "clin",
    "clinurilor": "clin",
    "clina": "clină",
    "cline": "clină",
    "clinei": "clină",
    "clinele": "clină",
    "clinelor": "clină",
    "clino": "clină",
    "clincăitul": "clincăit",
    "clincăitule": "clincăit",
    "clincăitului": "clincăit",
    "clincăituri": "clincăit",
    "clincăiturile": "clincăit",
    "clincăiturilor": "clincăit",
    "clincănea": "clincăni",
    "clincăneai": "clincăni",
    "clincăneam": "clincăni",
    "clincănească": "clincăni",
    "clincăneați": "clincăni",
    "clincăneau": "clincăni",
    "clincănesc": "clincăni",
    "clincănește": "clincăni",
    "clincănești": "clincăni",
    "clincănii": "clincăni",
    "clincănim": "clincăni",
    "clincănind": "clincăni",
    "clincănindu": "clincăni",
    "clincăniră": "clincăni",
    "clincănirăm": "clincăni",
    "clincănirăți": "clincăni",
    "clincănise": "clincăni",
    "clincănisem": "clincăni",
    "clincăniseră": "clincăni",
    "clincăniserăm": "clincăni",
    "clincăniserăți": "clincăni",
    "clincăniseși": "clincăni",
    "clincăniși": "clincăni",
    "clincănit": "clincăni",
    "clincăniți": "clincăni",
    "clincănitu": "clincăni",
    "neclincănind": "clincăni",
    "neclincănindu": "clincăni",
    "nemaiclincănind": "clincăni",
    "nemaiclincănindu": "clincăni",
    "clincănită": "clincănit",
    "clincănite": "clincănit",
    "clincăniți": "clincănit",
    "clinchete": "clinchet",
    "clinchetele": "clinchet",
    "clinchetelor": "clinchet",
    "clinchetul": "clinchet",
    "clinchetule": "clinchet",
    "clinchetului": "clinchet",
    "clinica": "clinic",
    "clinică": "clinic",
    "clinice": "clinic",
    "clinicei": "clinic",
    "clinicele": "clinic",
    "clinicelor": "clinic",
    "clinici": "clinic",
    "clinicii": "clinic",
    "clinicilor": "clinic",
    "clinico": "clinic",
    "clinicul": "clinic",
    "clinicule": "clinic",
    "clinicului": "clinic",
    "clinica": "clinică",
    "clinici": "clinică",
    "clinicii": "clinică",
    "clinicile": "clinică",
    "clinicilor": "clinică",
    "clinico": "clinică",
    "clinicianul": "clinician",
    "clinicianule": "clinician",
    "clinicianului": "clinician",
    "clinicieni": "clinician",
    "clinicienii": "clinician",
    "clinicienilor": "clinician",
    "cliniciana": "cliniciană",
    "cliniciano": "cliniciană",
    "cliniciene": "cliniciană",
    "clinicienei": "cliniciană",
    "clinicienele": "cliniciană",
    "clinicienelor": "cliniciană",
    "clinometre": "clinometru",
    "clinometrele": "clinometru",
    "clinometrelor": "clinometru",
    "clinometrul": "clinometru",
    "clinometrule": "clinometru",
    "clinometrului": "clinometru",
    "clintea": "clinti",
    "clinteai": "clinti",
    "clinteam": "clinti",
    "clintească": "clinti",
    "clinteați": "clinti",
    "clinteau": "clinti",
    "clintesc": "clinti",
    "clintește": "clinti",
    "clintești": "clinti",
    "clintii": "clinti",
    "clintim": "clinti",
    "clintind": "clinti",
    "clintindu": "clinti",
    "clintiră": "clinti",
    "clintirăm": "clinti",
    "clintirăți": "clinti",
    "clintise": "clinti",
    "clintisem": "clinti",
    "clintiseră": "clinti",
    "clintiserăm": "clinti",
    "clintiserăți": "clinti",
    "clintiseși": "clinti",
    "clintiși": "clinti",
    "clintit": "clinti",
    "clintiți": "clinti",
    "clintitu": "clinti",
    "neclintind": "clinti",
    "neclintindu": "clinti",
    "neclintit": "clinti",
    "nemaiclintind": "clinti",
    "nemaiclintindu": "clinti",
    "clintită": "clintit",
    "clintite": "clintit",
    "clintiți": "clintit",
    "clipa": "clipă",
    "clipe": "clipă",
    "clipei": "clipă",
    "clipele": "clipă",
    "clipelor": "clipă",
    "clipo": "clipă",
    "clipeala": "clipeală",
    "clipealo": "clipeală",
    "clipeli": "clipeală",
    "clipelii": "clipeală",
    "clipelile": "clipeală",
    "clipelilor": "clipeală",
    "clipea": "clipi",
    "clipeai": "clipi",
    "clipeam": "clipi",
    "clipească": "clipi",
    "clipeați": "clipi",
    "clipeau": "clipi",
    "clipesc": "clipi",
    "clipește": "clipi",
    "clipești": "clipi",
    "clipii": "clipi",
    "clipim": "clipi",
    "clipind": "clipi",
    "clipindu": "clipi",
    "clipiră": "clipi",
    "clipirăm": "clipi",
    "clipirăți": "clipi",
    "clipise": "clipi",
    "clipisem": "clipi",
    "clipiseră": "clipi",
    "clipiserăm": "clipi",
    "clipiserăți": "clipi",
    "clipiseși": "clipi",
    "clipiși": "clipi",
    "clipit": "clipi",
    "clipiți": "clipi",
    "clipitu": "clipi",
    "neclipind": "clipi",
    "neclipindu": "clipi",
    "nemaiclipind": "clipi",
    "nemaiclipindu": "clipi",
    "clipirea": "clipire",
    "clipireo": "clipire",
    "clipiri": "clipire",
    "clipirii": "clipire",
    "clipirile": "clipire",
    "clipirilor": "clipire",
    "clipită": "clipit",
    "clipite": "clipit",
    "clipiți": "clipit",
    "clipitul": "clipit",
    "clipitule": "clipit",
    "clipitului": "clipit",
    "clipita": "clipită",
    "clipite": "clipită",
    "clipitei": "clipită",
    "clipitele": "clipită",
    "clipitelor": "clipită",
    "clipito": "clipită",
    "clipoceala": "clipoceală",
    "clipocealo": "clipoceală",
    "clipoceli": "clipoceală",
    "clipocelii": "clipoceală",
    "clipocelile": "clipoceală",
    "clipocelilor": "clipoceală",
    "clipocea": "clipoci",
    "clipoceai": "clipoci",
    "clipoceam": "clipoci",
    "clipocească": "clipoci",
    "clipoceați": "clipoci",
    "clipoceau": "clipoci",
    "clipocesc": "clipoci",
    "clipocește": "clipoci",
    "clipocești": "clipoci",
    "clipocii": "clipoci",
    "clipocim": "clipoci",
    "clipocind": "clipoci",
    "clipocindu": "clipoci",
    "clipociră": "clipoci",
    "clipocirăm": "clipoci",
    "clipocirăți": "clipoci",
    "clipocise": "clipoci",
    "clipocisem": "clipoci",
    "clipociseră": "clipoci",
    "clipociserăm": "clipoci",
    "clipociserăți": "clipoci",
    "clipociseși": "clipoci",
    "clipociși": "clipoci",
    "clipocit": "clipoci",
    "clipociți": "clipoci",
    "clipocitu": "clipoci",
    "neclipocind": "clipoci",
    "neclipocindu": "clipoci",
    "nemaiclipocind": "clipoci",
    "nemaiclipocindu": "clipoci",
    "clipocirea": "clipocire",
    "clipocireo": "clipocire",
    "clipociri": "clipocire",
    "clipocirii": "clipocire",
    "clipocirile": "clipocire",
    "clipocirilor": "clipocire",
    "clipocită": "clipocit",
    "clipocite": "clipocit",
    "clipociți": "clipocit",
    "clipocitul": "clipocit",
    "clipocitule": "clipocit",
    "clipocitului": "clipocit",
    "cliringul": "cliring",
    "cliringule": "cliring",
    "cliringului": "cliring",
    "clisa": "clisă",
    "clise": "clisă",
    "clisei": "clisă",
    "clisele": "clisă",
    "cliselor": "clisă",
    "clișee": "clișeu",
    "clișeele": "clișeu",
    "clișeelor": "clișeu",
    "clișeul": "clișeu",
    "clișeule": "clișeu",
    "clișeului": "clișeu",
    "clisma": "clismă",
    "clisme": "clismă",
    "clismei": "clismă",
    "clismele": "clismă",
    "clismelor": "clismă",
    "clismo": "clismă",
    "clisoasa": "clisos",
    "clisoasă": "clisos",
    "clisoase": "clisos",
    "clisoasei": "clisos",
    "clisoasele": "clisos",
    "clisoaselor": "clisos",
    "clisoaso": "clisos",
    "clisoși": "clisos",
    "clisoșii": "clisos",
    "clisoșilor": "clisos",
    "clisosul": "clisos",
    "clisosule": "clisos",
    "clisosului": "clisos",
    "clistire": "clistir",
    "clistirele": "clistir",
    "clistirelor": "clistir",
    "clistirul": "clistir",
    "clistirule": "clistir",
    "clistirului": "clistir",
    "clisura": "clisură",
    "clisuri": "clisură",
    "clisurii": "clisură",
    "clisurile": "clisură",
    "clisurilor": "clisură",
    "clisuro": "clisură",
    "clivă": "cliva",
    "clivai": "cliva",
    "clivam": "cliva",
    "clivăm": "cliva",
    "clivând": "cliva",
    "clivându": "cliva",
    "clivară": "cliva",
    "clivarăm": "cliva",
    "clivarăți": "cliva",
    "clivase": "cliva",
    "clivasem": "cliva",
    "clivaseră": "cliva",
    "clivaserăm": "cliva",
    "clivaserăți": "cliva",
    "clivaseși": "cliva",
    "clivași": "cliva",
    "clivat": "cliva",
    "clivați": "cliva",
    "clivatu": "cliva",
    "clivau": "cliva",
    "clivează": "cliva",
    "clivez": "cliva",
    "cliveze": "cliva",
    "clivezi": "cliva",
    "neclivând": "cliva",
    "neclivându": "cliva",
    "nemaiclivând": "cliva",
    "nemaiclivându": "cliva",
    "clivaje": "clivaj",
    "clivajele": "clivaj",
    "clivajelor": "clivaj",
    "clivajul": "clivaj",
    "clivajule": "clivaj",
    "clivajului": "clivaj",
    "clivarea": "clivare",
    "clivareo": "clivare",
    "clivări": "clivare",
    "clivării": "clivare",
    "clivările": "clivare",
    "clivărilor": "clivare",
    "clivată": "clivat",
    "clivate": "clivat",
    "clivați": "clivat",
    "cloaca": "cloacă",
    "cloace": "cloacă",
    "cloacei": "cloacă",
    "cloacele": "cloacă",
    "cloacelor": "cloacă",
    "cloaco": "cloacă",
    "cloanța": "cloanță",
    "cloanțe": "cloanță",
    "cloanței": "cloanță",
    "cloanțele": "cloanță",
    "cloanțelor": "cloanță",
    "cloanțo": "cloanță",
    "cloceala": "cloceală",
    "clocealo": "cloceală",
    "cloceli": "cloceală",
    "clocelii": "cloceală",
    "clocelile": "cloceală",
    "clocelilor": "cloceală",
    "clocea": "cloci",
    "cloceai": "cloci",
    "cloceam": "cloci",
    "clocească": "cloci",
    "cloceați": "cloci",
    "cloceau": "cloci",
    "clocesc": "cloci",
    "clocește": "cloci",
    "clocești": "cloci",
    "clocii": "cloci",
    "clocim": "cloci",
    "clocind": "cloci",
    "clocindu": "cloci",
    "clociră": "cloci",
    "clocirăm": "cloci",
    "clocirăți": "cloci",
    "clocise": "cloci",
    "clocisem": "cloci",
    "clociseră": "cloci",
    "clociserăm": "cloci",
    "clociserăți": "cloci",
    "clociseși": "cloci",
    "clociși": "cloci",
    "clocit": "cloci",
    "clociți": "cloci",
    "clocitu": "cloci",
    "neclocind": "cloci",
    "neclocindu": "cloci",
    "nemaiclocind": "cloci",
    "nemaiclocindu": "cloci",
    "clocita": "clocit",
    "clocită": "clocit",
    "clocite": "clocit",
    "clocitei": "clocit",
    "clocitele": "clocit",
    "clocitelor": "clocit",
    "clociți": "clocit",
    "clociții": "clocit",
    "clociților": "clocit",
    "clocito": "clocit",
    "clocitul": "clocit",
    "clocitule": "clocit",
    "clocitului": "clocit",
    "clocitoarea": "clocitoare",
    "clocitoarei": "clocitoare",
    "clocitoarele": "clocitoare",
    "clocitoarelor": "clocitoare",
    "clocitoareo": "clocitoare",
    "clocitura": "clocitură",
    "clocituri": "clocitură",
    "clociturii": "clocitură",
    "clociturile": "clocitură",
    "clociturilor": "clocitură",
    "clocituro": "clocitură",
    "clocote": "clocot",
    "clocotele": "clocot",
    "clocotelor": "clocot",
    "clocotul": "clocot",
    "clocotule": "clocot",
    "clocotului": "clocot",
    "clocotea": "clocoti",
    "clocoteai": "clocoti",
    "clocoteam": "clocoti",
    "clocotească": "clocoti",
    "clocoteați": "clocoti",
    "clocoteau": "clocoti",
    "clocotesc": "clocoti",
    "clocotește": "clocoti",
    "clocotești": "clocoti",
    "clocotii": "clocoti",
    "clocotim": "clocoti",
    "clocotind": "clocoti",
    "clocotindu": "clocoti",
    "clocotiră": "clocoti",
    "clocotirăm": "clocoti",
    "clocotirăți": "clocoti",
    "clocotise": "clocoti",
    "clocotisem": "clocoti",
    "clocotiseră": "clocoti",
    "clocotiserăm": "clocoti",
    "clocotiserăți": "clocoti",
    "clocotiseși": "clocoti",
    "clocotiși": "clocoti",
    "clocotit": "clocoti",
    "clocotiți": "clocoti",
    "clocotitu": "clocoti",
    "neclocotind": "clocoti",
    "neclocotindu": "clocoti",
    "nemaiclocotind": "clocoti",
    "nemaiclocotindu": "clocoti",
    "clocotirea": "clocotire",
    "clocotireo": "clocotire",
    "clocotiri": "clocotire",
    "clocotirii": "clocotire",
    "clocotirile": "clocotire",
    "clocotirilor": "clocotire",
    "clocotita": "clocotit",
    "clocotită": "clocotit",
    "clocotite": "clocotit",
    "clocotitei": "clocotit",
    "clocotitele": "clocotit",
    "clocotitelor": "clocotit",
    "clocotiți": "clocotit",
    "clocotiții": "clocotit",
    "clocotiților": "clocotit",
    "clocotito": "clocotit",
    "clocotitul": "clocotit",
    "clocotitule": "clocotit",
    "clocotitului": "clocotit",
    "cloncani": "cloncan",
    "cloncanii": "cloncan",
    "cloncanilor": "cloncan",
    "cloncanul": "cloncan",
    "cloncanule": "cloncan",
    "cloncanului": "cloncan",
    "cloncănea": "cloncăni",
    "cloncăneai": "cloncăni",
    "cloncăneam": "cloncăni",
    "cloncănească": "cloncăni",
    "cloncăneați": "cloncăni",
    "cloncăneau": "cloncăni",
    "cloncănesc": "cloncăni",
    "cloncănește": "cloncăni",
    "cloncănești": "cloncăni",
    "cloncănii": "cloncăni",
    "cloncănim": "cloncăni",
    "cloncănind": "cloncăni",
    "cloncănindu": "cloncăni",
    "cloncăniră": "cloncăni",
    "cloncănirăm": "cloncăni",
    "cloncănirăți": "cloncăni",
    "cloncănise": "cloncăni",
    "cloncănisem": "cloncăni",
    "cloncăniseră": "cloncăni",
    "cloncăniserăm": "cloncăni",
    "cloncăniserăți": "cloncăni",
    "cloncăniseși": "cloncăni",
    "cloncăniși": "cloncăni",
    "cloncănit": "cloncăni",
    "cloncăniți": "cloncăni",
    "cloncănitu": "cloncăni",
    "necloncănind": "cloncăni",
    "necloncănindu": "cloncăni",
    "nemaicloncănind": "cloncăni",
    "nemaicloncănindu": "cloncăni",
    "cloncănirea": "cloncănire",
    "cloncănireo": "cloncănire",
    "cloncăniri": "cloncănire",
    "cloncănirii": "cloncănire",
    "cloncănirile": "cloncănire",
    "cloncănirilor": "cloncănire",
    "cloncănită": "cloncănit",
    "cloncănite": "cloncănit",
    "cloncăniți": "cloncănit",
    "cloncănitul": "cloncănit",
    "cloncănitule": "cloncănit",
    "cloncănitului": "cloncănit",
    "clondire": "clondir",
    "clondirele": "clondir",
    "clondirelor": "clondir",
    "clondirul": "clondir",
    "clondirule": "clondir",
    "clondirului": "clondir",
    "clonțul": "clonț",
    "clonțule": "clonț",
    "clonțului": "clonț",
    "clonțuri": "clonț",
    "clonțurile": "clonț",
    "clonțurilor": "clonț",
    "clonțoasa": "clonțos",
    "clonțoasă": "clonțos",
    "clonțoase": "clonțos",
    "clonțoasei": "clonțos",
    "clonțoasele": "clonțos",
    "clonțoaselor": "clonțos",
    "clonțoaso": "clonțos",
    "clonțoși": "clonțos",
    "clonțoșii": "clonțos",
    "clonțoșilor": "clonțos",
    "clonțosul": "clonțos",
    "clonțosule": "clonțos",
    "clonțosului": "clonțos",
    "clopul": "clop",
    "clopule": "clop",
    "clopului": "clop",
    "clopuri": "clop",
    "clopurile": "clop",
    "clopurilor": "clop",
    "clopote": "clopot",
    "clopotele": "clopot",
    "clopotelor": "clopot",
    "clopotul": "clopot",
    "clopotule": "clopot",
    "clopotului": "clopot",
    "clopotari": "clopotar",
    "clopotarii": "clopotar",
    "clopotarilor": "clopotar",
    "clopotarul": "clopotar",
    "clopotarule": "clopotar",
    "clopotarului": "clopotar",
    "clopoței": "clopoțel",
    "clopoțeii": "clopoțel",
    "clopoțeilor": "clopoțel",
    "clopoțelul": "clopoțel",
    "clopoțelule": "clopoțel",
    "clopoțelului": "clopoțel",
    "clopoțea": "clopoți",
    "clopoțeai": "clopoți",
    "clopoțeam": "clopoți",
    "clopoțească": "clopoți",
    "clopoțeați": "clopoți",
    "clopoțeau": "clopoți",
    "clopoțesc": "clopoți",
    "clopoțește": "clopoți",
    "clopoțești": "clopoți",
    "clopoții": "clopoți",
    "clopoțim": "clopoți",
    "clopoțind": "clopoți",
    "clopoțindu": "clopoți",
    "clopoțiră": "clopoți",
    "clopoțirăm": "clopoți",
    "clopoțirăți": "clopoți",
    "clopoțise": "clopoți",
    "clopoțisem": "clopoți",
    "clopoțiseră": "clopoți",
    "clopoțiserăm": "clopoți",
    "clopoțiserăți": "clopoți",
    "clopoțiseși": "clopoți",
    "clopoțiși": "clopoți",
    "clopoțit": "clopoți",
    "clopoțiți": "clopoți",
    "clopoțitu": "clopoți",
    "neclopoțind": "clopoți",
    "neclopoțindu": "clopoți",
    "nemaiclopoțind": "clopoți",
    "nemaiclopoțindu": "clopoți",
    "clopoțită": "clopoțit",
    "clopoțite": "clopoțit",
    "clopoțiți": "clopoțit",
    "clopotnița": "clopotniță",
    "clopotnițe": "clopotniță",
    "clopotniței": "clopotniță",
    "clopotnițele": "clopotniță",
    "clopotnițelor": "clopotniță",
    "clopotnițo": "clopotniță",
    "Cl": "clor",
    "clorul": "clor",
    "clorule": "clor",
    "clorului": "clor",
    "clorați": "clorat",
    "clorații": "clorat",
    "cloraților": "clorat",
    "cloratul": "clorat",
    "cloratule": "clorat",
    "cloratului": "clorat",
    "clorhidricul": "clorhidric",
    "clorhidricule": "clorhidric",
    "clorhidricului": "clorhidric",
    "clorizarea": "clorizare",
    "clorizareo": "clorizare",
    "clorizări": "clorizare",
    "clorizării": "clorizare",
    "clorizările": "clorizare",
    "clorizărilor": "clorizare",
    "clorofila": "clorofilă",
    "clorofile": "clorofilă",
    "clorofilei": "clorofilă",
    "clorofilele": "clorofilă",
    "clorofilelor": "clorofilă",
    "clorofilo": "clorofilă",
    "clorofiliana": "clorofilian",
    "clorofiliană": "clorofilian",
    "clorofiliano": "clorofilian",
    "clorofilianul": "clorofilian",
    "clorofilianule": "clorofilian",
    "clorofilianului": "clorofilian",
    "clorofiliene": "clorofilian",
    "clorofilienei": "clorofilian",
    "clorofilienele": "clorofilian",
    "clorofilienelor": "clorofilian",
    "clorofilieni": "clorofilian",
    "clorofilienii": "clorofilian",
    "clorofilienilor": "clorofilian",
    "cloroformul": "cloroform",
    "cloroformule": "cloroform",
    "cloroformului": "cloroform",
    "cloroformiză": "cloroformiza",
    "cloroformizai": "cloroformiza",
    "cloroformizam": "cloroformiza",
    "cloroformizăm": "cloroformiza",
    "cloroformizând": "cloroformiza",
    "cloroformizându": "cloroformiza",
    "cloroformizară": "cloroformiza",
    "cloroformizarăm": "cloroformiza",
    "cloroformizarăți": "cloroformiza",
    "cloroformizase": "cloroformiza",
    "cloroformizasem": "cloroformiza",
    "cloroformizaseră": "cloroformiza",
    "cloroformizaserăm": "cloroformiza",
    "cloroformizaserăți": "cloroformiza",
    "cloroformizaseși": "cloroformiza",
    "cloroformizași": "cloroformiza",
    "cloroformizat": "cloroformiza",
    "cloroformizați": "cloroformiza",
    "cloroformizatu": "cloroformiza",
    "cloroformizau": "cloroformiza",
    "cloroformizează": "cloroformiza",
    "cloroformizez": "cloroformiza",
    "cloroformizeze": "cloroformiza",
    "cloroformizezi": "cloroformiza",
    "necloroformizând": "cloroformiza",
    "necloroformizându": "cloroformiza",
    "nemaicloroformizând": "cloroformiza",
    "nemaicloroformizându": "cloroformiza",
    "cloroformizată": "cloroformizat",
    "cloroformizate": "cloroformizat",
    "cloroformizați": "cloroformizat",
    "cloroza": "cloroză",
    "cloroze": "cloroză",
    "clorozei": "cloroză",
    "clorozele": "cloroză",
    "clorozelor": "cloroză",
    "clorozo": "cloroză",
    "clorura": "clorură",
    "cloruri": "clorură",
    "clorurii": "clorură",
    "clorurile": "clorură",
    "clorurilor": "clorură",
    "cloruro": "clorură",
    "cloșul": "cloș",
    "cloșule": "cloș",
    "cloșului": "cloș",
    "cloșuri": "cloș",
    "cloșurile": "cloș",
    "cloșurilor": "cloș",
    "cloșca": "cloșcă",
    "cloșco": "cloșcă",
    "cloști": "cloșcă",
    "cloștii": "cloșcă",
    "cloștile": "cloșcă",
    "cloștilor": "cloșcă",
    "closete": "closet",
    "closetele": "closet",
    "closetelor": "closet",
    "closetul": "closet",
    "closetule": "closet",
    "closetului": "closet",
    "cloța": "cloță",
    "cloțe": "cloță",
    "cloței": "cloță",
    "cloțele": "cloță",
    "cloțelor": "cloță",
    "cloțo": "cloță",
    "cloțani": "cloțan",
    "cloțanii": "cloțan",
    "cloțanilor": "cloțan",
    "cloțanul": "cloțan",
    "cloțanule": "cloțan",
    "cloțanului": "cloțan",
    "clovni": "clovn",
    "clovnii": "clovn",
    "clovnilor": "clovn",
    "clovnul": "clovn",
    "clovnule": "clovn",
    "clovnului": "clovn",
    "clovneria": "clovnerie",
    "clovneriei": "clovnerie",
    "clovnerii": "clovnerie",
    "clovneriile": "clovnerie",
    "clovneriilor": "clovnerie",
    "clovnerio": "clovnerie",
    "clownilor": "clown",
    "clubul": "club",
    "clubule": "club",
    "clubului": "club",
    "cluburi": "club",
    "cluburile": "club",
    "cluburilor": "club",
    "CF": "Clubul_de_Fotbal",
    "cluceri": "clucer",
    "clucerii": "clucer",
    "clucerilor": "clucer",
    "clucerul": "clucer",
    "clucerule": "clucer",
    "clucerului": "clucer",
    "clucereasa": "clucereasă",
    "clucereaso": "clucereasă",
    "clucerese": "clucereasă",
    "cluceresei": "clucereasă",
    "cluceresele": "clucereasă",
    "clucereselor": "clucereasă",
    "Clujul": "Cluj",
    "Clujului": "Cluj",
    "clujeana": "clujean",
    "clujeană": "clujean",
    "clujeano": "clujean",
    "clujeanul": "clujean",
    "clujeanule": "clujean",
    "clujeanului": "clujean",
    "clujene": "clujean",
    "clujenei": "clujean",
    "clujenele": "clujean",
    "clujenelor": "clujean",
    "clujeni": "clujean",
    "clujenii": "clujean",
    "clujenilor": "clujean",
    "clujeanca": "clujeancă",
    "clujeanco": "clujeancă",
    "clujence": "clujeancă",
    "clujencei": "clujeancă",
    "clujencele": "clujeancă",
    "clujencelor": "clujeancă",
    "clupa": "clupă",
    "clupe": "clupă",
    "clupei": "clupă",
    "clupele": "clupă",
    "clupelor": "clupă",
    "clupo": "clupă",
    "cneazul": "cneaz",
    "cneazule": "cneaz",
    "cneazului": "cneaz",
    "cneji": "cneaz",
    "cnejii": "cneaz",
    "cnejilor": "cneaz",
    "cnezate": "cnezat",
    "cnezatele": "cnezat",
    "cnezatelor": "cnezat",
    "cnezatul": "cnezat",
    "cnezatule": "cnezat",
    "cnezatului": "cnezat",
    "cnocautul": "cnocaut",
    "cnocautule": "cnocaut",
    "cnocautului": "cnocaut",
    "cnocauturi": "cnocaut",
    "cnocauturile": "cnocaut",
    "cnocauturilor": "cnocaut",
    "cnutul": "cnut",
    "cnutule": "cnut",
    "cnutului": "cnut",
    "cnuturi": "cnut",
    "cnuturile": "cnut",
    "cnuturilor": "cnut",
    "coabită": "coabita",
    "coabitai": "coabita",
    "coabitam": "coabita",
    "coabităm": "coabita",
    "coabitând": "coabita",
    "coabitându": "coabita",
    "coabitară": "coabita",
    "coabitarăm": "coabita",
    "coabitarăți": "coabita",
    "coabitase": "coabita",
    "coabitasem": "coabita",
    "coabitaseră": "coabita",
    "coabitaserăm": "coabita",
    "coabitaserăți": "coabita",
    "coabitaseși": "coabita",
    "coabitași": "coabita",
    "coabitat": "coabita",
    "coabitați": "coabita",
    "coabitatu": "coabita",
    "coabitau": "coabita",
    "coabitează": "coabita",
    "coabitez": "coabita",
    "coabiteze": "coabita",
    "coabitezi": "coabita",
    "necoabitând": "coabita",
    "necoabitându": "coabita",
    "nemaicoabitând": "coabita",
    "nemaicoabitându": "coabita",
    "coabitarea": "coabitare",
    "coabitareo": "coabitare",
    "coabitări": "coabitare",
    "coabitării": "coabitare",
    "coabitările": "coabitare",
    "coabitărilor": "coabitare",
    "coabitată": "coabitat",
    "coabitate": "coabitat",
    "coabitați": "coabitat",
    "coacăzi": "coacăz",
    "coacăzii": "coacăz",
    "coacăzilor": "coacăz",
    "coacăzul": "coacăz",
    "coacăzule": "coacăz",
    "coacăzului": "coacăz",
    "coacăza": "coacăză",
    "coacăze": "coacăză",
    "coacăzei": "coacăză",
    "coacăzele": "coacăză",
    "coacăzelor": "coacăză",
    "coacăzo": "coacăză",
    "coacă": "coace",
    "coacem": "coace",
    "coaceți": "coace",
    "coc": "coace",
    "cocând": "coace",
    "cocându": "coace",
    "cocea": "coace",
    "coceai": "coace",
    "coceam": "coace",
    "coceați": "coace",
    "coceau": "coace",
    "coci": "coace",
    "copse": "coace",
    "copsei": "coace",
    "copseră": "coace",
    "copserăm": "coace",
    "copserăți": "coace",
    "copsese": "coace",
    "copsesem": "coace",
    "copseseră": "coace",
    "copseserăm": "coace",
    "copseserăți": "coace",
    "copseseși": "coace",
    "copseși": "coace",
    "copt": "coace",
    "coptu": "coace",
    "necocând": "coace",
    "necocându": "coace",
    "nemaicocând": "coace",
    "nemaicocându": "coace",
    "coacerea": "coacere",
    "coacereo": "coacere",
    "coaceri": "coacere",
    "coacerii": "coacere",
    "coacerile": "coacere",
    "coacerilor": "coacere",
    "coada": "coadă",
    "coado": "coadă",
    "cozi": "coadă",
    "cozii": "coadă",
    "cozile": "coadă",
    "cozilor": "coadă",
    "coafă": "coafa",
    "coafai": "coafa",
    "coafam": "coafa",
    "coafăm": "coafa",
    "coafând": "coafa",
    "coafându": "coafa",
    "coafară": "coafa",
    "coafarăm": "coafa",
    "coafarăți": "coafa",
    "coafase": "coafa",
    "coafasem": "coafa",
    "coafaseră": "coafa",
    "coafaserăm": "coafa",
    "coafaserăți": "coafa",
    "coafaseși": "coafa",
    "coafași": "coafa",
    "coafat": "coafa",
    "coafați": "coafa",
    "coafatu": "coafa",
    "coafau": "coafa",
    "coafează": "coafa",
    "coafez": "coafa",
    "coafeze": "coafa",
    "coafezi": "coafa",
    "necoafând": "coafa",
    "necoafându": "coafa",
    "nemaicoafând": "coafa",
    "nemaicoafându": "coafa",
    "coafata": "coafat",
    "coafată": "coafat",
    "coafate": "coafat",
    "coafatei": "coafat",
    "coafatele": "coafat",
    "coafatelor": "coafat",
    "coafați": "coafat",
    "coafații": "coafat",
    "coafaților": "coafat",
    "coafato": "coafat",
    "coafatul": "coafat",
    "coafatule": "coafat",
    "coafatului": "coafat",
    "coafeza": "coafeză",
    "coafeze": "coafeză",
    "coafezei": "coafeză",
    "coafezele": "coafeză",
    "coafezelor": "coafeză",
    "coafezo": "coafeză",
    "coafori": "coafor",
    "coaforii": "coafor",
    "coaforilor": "coafor",
    "coaforul": "coafor",
    "coaforule": "coafor",
    "coaforului": "coafor",
    "coafura": "coafură",
    "coafuri": "coafură",
    "coafurii": "coafură",
    "coafurile": "coafură",
    "coafurilor": "coafură",
    "coafuro": "coafură",
    "coagulă": "coagula",
    "coagulai": "coagula",
    "coagulam": "coagula",
    "coagulăm": "coagula",
    "coagulând": "coagula",
    "coagulându": "coagula",
    "coagulară": "coagula",
    "coagularăm": "coagula",
    "coagularăți": "coagula",
    "coagulase": "coagula",
    "coagulasem": "coagula",
    "coagulaseră": "coagula",
    "coagulaserăm": "coagula",
    "coagulaserăți": "coagula",
    "coagulaseși": "coagula",
    "coagulași": "coagula",
    "coagulat": "coagula",
    "coagulați": "coagula",
    "coagulatu": "coagula",
    "coagulau": "coagula",
    "coagulează": "coagula",
    "coagulez": "coagula",
    "coaguleze": "coagula",
    "coagulezi": "coagula",
    "necoagulând": "coagula",
    "necoagulându": "coagula",
    "nemaicoagulând": "coagula",
    "nemaicoagulându": "coagula",
    "coagularea": "coagulare",
    "coagulareo": "coagulare",
    "coagulări": "coagulare",
    "coagulării": "coagulare",
    "coagulările": "coagulare",
    "coagulărilor": "coagulare",
    "coagulata": "coagulat",
    "coagulată": "coagulat",
    "coagulate": "coagulat",
    "coagulatei": "coagulat",
    "coagulatele": "coagulat",
    "coagulatelor": "coagulat",
    "coagulați": "coagulat",
    "coagulații": "coagulat",
    "coagulaților": "coagulat",
    "coagulato": "coagulat",
    "coagulatul": "coagulat",
    "coagulatule": "coagulat",
    "coagulatului": "coagulat",
    "coaja": "coajă",
    "coajo": "coajă",
    "coji": "coajă",
    "cojii": "coajă",
    "cojile": "coajă",
    "cojilor": "coajă",
    "coala": "coală",
    "coalo": "coală",
    "coli": "coală",
    "colii": "coală",
    "colile": "coală",
    "colilor": "coală",
    "coaliția": "coaliție",
    "coaliției": "coaliție",
    "coaliții": "coaliție",
    "coalițiile": "coaliție",
    "coalițiilor": "coaliție",
    "coalițio": "coaliție",
    "coaliză": "coaliza",
    "coalizai": "coaliza",
    "coalizam": "coaliza",
    "coalizăm": "coaliza",
    "coalizând": "coaliza",
    "coalizându": "coaliza",
    "coalizară": "coaliza",
    "coalizarăm": "coaliza",
    "coalizarăți": "coaliza",
    "coalizase": "coaliza",
    "coalizasem": "coaliza",
    "coalizaseră": "coaliza",
    "coalizaserăm": "coaliza",
    "coalizaserăți": "coaliza",
    "coalizaseși": "coaliza",
    "coalizași": "coaliza",
    "coalizat": "coaliza",
    "coalizați": "coaliza",
    "coalizatu": "coaliza",
    "coalizau": "coaliza",
    "coalizează": "coaliza",
    "coalizez": "coaliza",
    "coalizeze": "coaliza",
    "coalizezi": "coaliza",
    "necoalizând": "coaliza",
    "necoalizându": "coaliza",
    "nemaicoalizând": "coaliza",
    "nemaicoalizându": "coaliza",
    "coalizarea": "coalizare",
    "coalizareo": "coalizare",
    "coalizări": "coalizare",
    "coalizării": "coalizare",
    "coalizările": "coalizare",
    "coalizărilor": "coalizare",
    "coalizată": "coalizat",
    "coalizate": "coalizat",
    "coalizați": "coalizat",
    "coama": "coamă",
    "coame": "coamă",
    "coamei": "coamă",
    "coamele": "coamă",
    "coamelor": "coamă",
    "coamo": "coamă",
    "coapsa": "coapsă",
    "coapse": "coapsă",
    "coapsei": "coapsă",
    "coapsele": "coapsă",
    "coapselor": "coapsă",
    "coapso": "coapsă",
    "coarba": "coarbă",
    "coarbe": "coarbă",
    "coarbei": "coarbă",
    "coarbele": "coarbă",
    "coarbelor": "coarbă",
    "coarbo": "coarbă",
    "coarda": "coardă",
    "coarde": "coardă",
    "coardei": "coardă",
    "coardele": "coardă",
    "coardelor": "coardă",
    "coardo": "coardă",
    "corzi": "coardă",
    "corzii": "coardă",
    "corzile": "coardă",
    "corzilor": "coardă",
    "coarna": "coarnă",
    "coarne": "coarnă",
    "coarnei": "coarnă",
    "coarnele": "coarnă",
    "coarnelor": "coarnă",
    "coarno": "coarnă",
    "coasa": "coasă",
    "coase": "coasă",
    "coasei": "coasă",
    "coasele": "coasă",
    "coaselor": "coasă",
    "coaso": "coasă",
    "coasă": "coase",
    "coasem": "coase",
    "coaseți": "coase",
    "cos": "coase",
    "cosând": "coase",
    "cosându": "coase",
    "cosea": "coase",
    "coseai": "coase",
    "coseam": "coase",
    "coseați": "coase",
    "coseau": "coase",
    "coși": "coase",
    "cusu": "coase",
    "cusui": "coase",
    "cusură": "coase",
    "cusurăm": "coase",
    "cusurăți": "coase",
    "cususe": "coase",
    "cususem": "coase",
    "cususeră": "coase",
    "cususerăm": "coase",
    "cususerăți": "coase",
    "cususeși": "coase",
    "cusuși": "coase",
    "cusut": "coase",
    "cusutu": "coase",
    "necosând": "coase",
    "necosându": "coase",
    "nemaicosând": "coase",
    "nemaicosându": "coase",
    "coasta": "coastă",
    "coaste": "coastă",
    "coastei": "coastă",
    "coastele": "coastă",
    "coastelor": "coastă",
    "coasto": "coastă",
    "cobaii": "cobai",
    "cobailor": "cobai",
    "cobaiul": "cobai",
    "cobaiule": "cobai",
    "cobaiului": "cobai",
    "Co": "cobalt",
    "cobaltul": "cobalt",
    "cobaltule": "cobalt",
    "cobaltului": "cobalt",
    "cobea": "cobe",
    "cobei": "cobe",
    "cobele": "cobe",
    "cobelor": "cobe",
    "cobeo": "cobe",
    "cobeala": "cobeală",
    "cobealo": "cobeală",
    "cobeli": "cobeală",
    "cobelii": "cobeală",
    "cobelile": "cobeală",
    "cobelilor": "cobeală",
    "cobea": "cobi",
    "cobeai": "cobi",
    "cobeam": "cobi",
    "cobească": "cobi",
    "cobeați": "cobi",
    "cobeau": "cobi",
    "cobesc": "cobi",
    "cobește": "cobi",
    "cobești": "cobi",
    "cobii": "cobi",
    "cobim": "cobi",
    "cobind": "cobi",
    "cobindu": "cobi",
    "cobiră": "cobi",
    "cobirăm": "cobi",
    "cobirăți": "cobi",
    "cobise": "cobi",
    "cobisem": "cobi",
    "cobiseră": "cobi",
    "cobiserăm": "cobi",
    "cobiserăți": "cobi",
    "cobiseși": "cobi",
    "cobiși": "cobi",
    "cobit": "cobi",
    "cobiți": "cobi",
    "cobitu": "cobi",
    "necobind": "cobi",
    "necobindu": "cobi",
    "nemaicobind": "cobi",
    "nemaicobindu": "cobi",
    "cobilița": "cobiliță",
    "cobilițe": "cobiliță",
    "cobiliței": "cobiliță",
    "cobilițele": "cobiliță",
    "cobilițelor": "cobiliță",
    "cobilițo": "cobiliță",
    "cobită": "cobit",
    "cobite": "cobit",
    "cobiți": "cobit",
    "cobitoare": "cobitor",
    "cobitoarea": "cobitor",
    "cobitoarei": "cobitor",
    "cobitoarele": "cobitor",
    "cobitoarelor": "cobitor",
    "cobitoareo": "cobitor",
    "cobitori": "cobitor",
    "cobitorii": "cobitor",
    "cobitorilor": "cobitor",
    "cobitorul": "cobitor",
    "cobitorule": "cobitor",
    "cobitorului": "cobitor",
    "coborârea": "coborâre",
    "coborâreo": "coborâre",
    "coborâri": "coborâre",
    "coborârii": "coborâre",
    "coborârile": "coborâre",
    "coborârilor": "coborâre",
    "coborâșul": "coborâș",
    "coborâșule": "coborâș",
    "coborâșului": "coborâș",
    "coborâșuri": "coborâș",
    "coborâșurile": "coborâș",
    "coborâșurilor": "coborâș",
    "coborâtă": "coborât",
    "coborâte": "coborât",
    "coborâți": "coborât",
    "coborâtul": "coborât",
    "coborâtului": "coborât",
    "coborâtoare": "coborâtor",
    "coborâtoarea": "coborâtor",
    "coborâtoarei": "coborâtor",
    "coborâtoarele": "coborâtor",
    "coborâtoarelor": "coborâtor",
    "coborâtoareo": "coborâtor",
    "coborâtori": "coborâtor",
    "coborâtorii": "coborâtor",
    "coborâtorilor": "coborâtor",
    "coborâtorul": "coborâtor",
    "coborâtorule": "coborâtor",
    "coborâtorului": "coborâtor",
    "coboară": "coborî",
    "coboare": "coborî",
    "cobor": "coborî",
    "cobora": "coborî",
    "coborai": "coborî",
    "coborâi": "coborî",
    "coboram": "coborî",
    "coborâm": "coborî",
    "coborând": "coborî",
    "coborându": "coborî",
    "coborâră": "coborî",
    "coborârăm": "coborî",
    "coborârăți": "coborî",
    "coborâse": "coborî",
    "coborâsem": "coborî",
    "coborâseră": "coborî",
    "coborâserăm": "coborî",
    "coborâserăți": "coborî",
    "coborâseși": "coborî",
    "coborâși": "coborî",
    "coborât": "coborî",
    "coborați": "coborî",
    "coborâți": "coborî",
    "coborâtu": "coborî",
    "coborau": "coborî",
    "cobori": "coborî",
    "necoborând": "coborî",
    "necoborându": "coborî",
    "nemaicoborând": "coborî",
    "nemaicoborându": "coborî",
    "cobra": "cobră",
    "cobre": "cobră",
    "cobrei": "cobră",
    "cobrele": "cobră",
    "cobrelor": "cobră",
    "cobro": "cobră",
    "cobza": "cobză",
    "cobze": "cobză",
    "cobzei": "cobză",
    "cobzele": "cobză",
    "cobzelor": "cobză",
    "cobzo": "cobză",
    "cobzișoara": "cobzișoară",
    "cobzișoare": "cobzișoară",
    "cobzișoarei": "cobzișoară",
    "cobzișoarele": "cobzișoară",
    "cobzișoarelor": "cobzișoară",
    "cobzișoaro": "cobzișoară",
    "coci": "coc",
    "cocii": "coc",
    "cocilor": "coc",
    "cocul": "coc",
    "cocule": "coc",
    "cocului": "coc",
    "cocuri": "coc",
    "cocurile": "coc",
    "cocurilor": "coc",
    "coca": "cocă",
    "cocăi": "cocă",
    "coci": "cocă",
    "cocii": "cocă",
    "cocile": "cocă",
    "cocilor": "cocă",
    "coco": "cocă",
    "cocaina": "cocaină",
    "cocaine": "cocaină",
    "cocainei": "cocaină",
    "cocainele": "cocaină",
    "cocainelor": "cocaină",
    "cocaino": "cocaină",
    "cocainomani": "cocainoman",
    "cocainomanii": "cocainoman",
    "cocainomanilor": "cocainoman",
    "cocainomanul": "cocainoman",
    "cocainomanule": "cocainoman",
    "cocainomanului": "cocainoman",
    "cocainomana": "cocainomană",
    "cocainomane": "cocainomană",
    "cocainomanei": "cocainomană",
    "cocainomanele": "cocainomană",
    "cocainomanelor": "cocainomană",
    "cocainomano": "cocainomană",
    "cocarda": "cocardă",
    "cocarde": "cocardă",
    "cocardei": "cocardă",
    "cocardele": "cocardă",
    "cocardelor": "cocardă",
    "cocardo": "cocardă",
    "cocârjă": "cocârja",
    "cocârjai": "cocârja",
    "cocârjam": "cocârja",
    "cocârjăm": "cocârja",
    "cocârjând": "cocârja",
    "cocârjându": "cocârja",
    "cocârjară": "cocârja",
    "cocârjarăm": "cocârja",
    "cocârjarăți": "cocârja",
    "cocârjase": "cocârja",
    "cocârjasem": "cocârja",
    "cocârjaseră": "cocârja",
    "cocârjaserăm": "cocârja",
    "cocârjaserăți": "cocârja",
    "cocârjaseși": "cocârja",
    "cocârjași": "cocârja",
    "cocârjat": "cocârja",
    "cocârjați": "cocârja",
    "cocârjatu": "cocârja",
    "cocârjau": "cocârja",
    "cocârjează": "cocârja",
    "cocârjez": "cocârja",
    "cocârjeze": "cocârja",
    "cocârjezi": "cocârja",
    "necocârjând": "cocârja",
    "necocârjându": "cocârja",
    "nemaicocârjând": "cocârja",
    "nemaicocârjându": "cocârja",
    "cocârjarea": "cocârjare",
    "cocârjareo": "cocârjare",
    "cocârjări": "cocârjare",
    "cocârjării": "cocârjare",
    "cocârjările": "cocârjare",
    "cocârjărilor": "cocârjare",
    "cocârjata": "cocârjat",
    "cocârjată": "cocârjat",
    "cocârjate": "cocârjat",
    "cocârjatei": "cocârjat",
    "cocârjatele": "cocârjat",
    "cocârjatelor": "cocârjat",
    "cocârjați": "cocârjat",
    "cocârjații": "cocârjat",
    "cocârjaților": "cocârjat",
    "cocârjato": "cocârjat",
    "cocârjatul": "cocârjat",
    "cocârjatule": "cocârjat",
    "cocârjatului": "cocârjat",
    "cocârjea": "cocârji",
    "cocârjeai": "cocârji",
    "cocârjeam": "cocârji",
    "cocârjească": "cocârji",
    "cocârjeați": "cocârji",
    "cocârjeau": "cocârji",
    "cocârjesc": "cocârji",
    "cocârjește": "cocârji",
    "cocârjești": "cocârji",
    "cocârjii": "cocârji",
    "cocârjim": "cocârji",
    "cocârjind": "cocârji",
    "cocârjindu": "cocârji",
    "cocârjiră": "cocârji",
    "cocârjirăm": "cocârji",
    "cocârjirăți": "cocârji",
    "cocârjise": "cocârji",
    "cocârjisem": "cocârji",
    "cocârjiseră": "cocârji",
    "cocârjiserăm": "cocârji",
    "cocârjiserăți": "cocârji",
    "cocârjiseși": "cocârji",
    "cocârjiși": "cocârji",
    "cocârjit": "cocârji",
    "cocârjiți": "cocârji",
    "cocârjitu": "cocârji",
    "necocârjind": "cocârji",
    "necocârjindu": "cocârji",
    "nemaicocârjind": "cocârji",
    "nemaicocârjindu": "cocârji",
    "cocârjita": "cocârjit",
    "cocârjită": "cocârjit",
    "cocârjite": "cocârjit",
    "cocârjitei": "cocârjit",
    "cocârjitele": "cocârjit",
    "cocârjitelor": "cocârjit",
    "cocârjiți": "cocârjit",
    "cocârjiții": "cocârjit",
    "cocârjiților": "cocârjit",
    "cocârjito": "cocârjit",
    "cocârjitul": "cocârjit",
    "cocârjitule": "cocârjit",
    "cocârjitului": "cocârjit",
    "cocârla": "cocârlă",
    "cocârle": "cocârlă",
    "cocârlei": "cocârlă",
    "cocârlele": "cocârlă",
    "cocârlelor": "cocârlă",
    "cocârlo": "cocârlă",
    "coccisul": "coccis",
    "coccisule": "coccis",
    "coccisului": "coccis",
    "coccisuri": "coccis",
    "coccisurile": "coccis",
    "coccisurilor": "coccis",
    "coceanul": "cocean",
    "coceanule": "cocean",
    "coceanului": "cocean",
    "coceni": "cocean",
    "cocenii": "cocean",
    "cocenilor": "cocean",
    "cocheta": "cochet",
    "cochetă": "cochet",
    "cochete": "cochet",
    "cochetei": "cochet",
    "cochetele": "cochet",
    "cochetelor": "cochet",
    "cocheți": "cochet",
    "cocheții": "cochet",
    "cocheților": "cochet",
    "cocheto": "cochet",
    "cochetul": "cochet",
    "cochetule": "cochet",
    "cochetului": "cochet",
    "cochetă": "cocheta",
    "cochetai": "cocheta",
    "cochetam": "cocheta",
    "cochetăm": "cocheta",
    "cochetând": "cocheta",
    "cochetându": "cocheta",
    "cochetară": "cocheta",
    "cochetarăm": "cocheta",
    "cochetarăți": "cocheta",
    "cochetase": "cocheta",
    "cochetasem": "cocheta",
    "cochetaseră": "cocheta",
    "cochetaserăm": "cocheta",
    "cochetaserăți": "cocheta",
    "cochetaseși": "cocheta",
    "cochetași": "cocheta",
    "cochetat": "cocheta",
    "cochetați": "cocheta",
    "cochetatu": "cocheta",
    "cochetau": "cocheta",
    "cochetează": "cocheta",
    "cochetez": "cocheta",
    "cocheteze": "cocheta",
    "cochetezi": "cocheta",
    "necochetând": "cocheta",
    "necochetându": "cocheta",
    "nemaicochetând": "cocheta",
    "nemaicochetându": "cocheta",
    "cochetată": "cochetat",
    "cochetate": "cochetat",
    "cochetați": "cochetat",
    "cochilia": "cochilie",
    "cochiliei": "cochilie",
    "cochilii": "cochilie",
    "cochiliile": "cochilie",
    "cochiliilor": "cochilie",
    "cochilio": "cochilie",
    "cocina": "cocină",
    "cocini": "cocină",
    "cocinii": "cocină",
    "cocinile": "cocină",
    "cocinilor": "cocină",
    "cocino": "cocină",
    "cocioaba": "cocioabă",
    "cocioabe": "cocioabă",
    "cocioabei": "cocioabă",
    "cocioabele": "cocioabă",
    "cocioabelor": "cocioabă",
    "cocioabo": "cocioabă",
    "coclaurile": "coclauri",
    "coclaurilor": "coclauri",
    "cocleala": "cocleală",
    "cocleli": "cocleală",
    "coclelii": "cocleală",
    "coclelile": "cocleală",
    "coclelilor": "cocleală",
    "coclețe": "cocleț",
    "coclețele": "cocleț",
    "coclețelor": "cocleț",
    "cocleți": "cocleț",
    "cocleții": "cocleț",
    "cocleților": "cocleț",
    "coclețul": "cocleț",
    "coclețule": "cocleț",
    "coclețului": "cocleț",
    "coclea": "cocli",
    "cocleai": "cocli",
    "cocleam": "cocli",
    "coclească": "cocli",
    "cocleați": "cocli",
    "cocleau": "cocli",
    "coclesc": "cocli",
    "coclește": "cocli",
    "coclești": "cocli",
    "coclii": "cocli",
    "coclim": "cocli",
    "coclind": "cocli",
    "coclindu": "cocli",
    "cocliră": "cocli",
    "coclirăm": "cocli",
    "coclirăți": "cocli",
    "coclise": "cocli",
    "coclisem": "cocli",
    "cocliseră": "cocli",
    "cocliserăm": "cocli",
    "cocliserăți": "cocli",
    "cocliseși": "cocli",
    "cocliși": "cocli",
    "coclit": "cocli",
    "cocliți": "cocli",
    "coclitu": "cocli",
    "necoclind": "cocli",
    "necoclindu": "cocli",
    "nemaicoclind": "cocli",
    "nemaicoclindu": "cocli",
    "coclirea": "coclire",
    "coclireo": "coclire",
    "cocliri": "coclire",
    "coclirii": "coclire",
    "coclirile": "coclire",
    "coclirilor": "coclire",
    "coclita": "coclit",
    "coclită": "coclit",
    "coclite": "coclit",
    "coclitei": "coclit",
    "coclitele": "coclit",
    "coclitelor": "coclit",
    "cocliți": "coclit",
    "cocliții": "coclit",
    "cocliților": "coclit",
    "coclito": "coclit",
    "coclitul": "coclit",
    "coclitule": "coclit",
    "coclitului": "coclit",
    "cocoașa": "cocoașă",
    "cocoașe": "cocoașă",
    "cocoașei": "cocoașă",
    "cocoașele": "cocoașă",
    "cocoașelor": "cocoașă",
    "cocoașo": "cocoașă",
    "cocoloașe": "cocoloș",
    "cocoloașele": "cocoloș",
    "cocoloașelor": "cocoloș",
    "cocoloși": "cocoloș",
    "cocoloșii": "cocoloș",
    "cocoloșilor": "cocoloș",
    "cocoloșul": "cocoloș",
    "cocoloșule": "cocoloș",
    "cocoloșului": "cocoloș",
    "cocoloșeala": "cocoloșeală",
    "cocoloșealo": "cocoloșeală",
    "cocoloșeli": "cocoloșeală",
    "cocoloșelii": "cocoloșeală",
    "cocoloșelile": "cocoloșeală",
    "cocoloșelilor": "cocoloșeală",
    "cocoloșea": "cocoloși",
    "cocoloșeai": "cocoloși",
    "cocoloșeam": "cocoloși",
    "cocoloșească": "cocoloși",
    "cocoloșeați": "cocoloși",
    "cocoloșeau": "cocoloși",
    "cocoloșesc": "cocoloși",
    "cocoloșește": "cocoloși",
    "cocoloșești": "cocoloși",
    "cocoloșii": "cocoloși",
    "cocoloșim": "cocoloși",
    "cocoloșind": "cocoloși",
    "cocoloșindu": "cocoloși",
    "cocoloșiră": "cocoloși",
    "cocoloșirăm": "cocoloși",
    "cocoloșirăți": "cocoloși",
    "cocoloșise": "cocoloși",
    "cocoloșisem": "cocoloși",
    "cocoloșiseră": "cocoloși",
    "cocoloșiserăm": "cocoloși",
    "cocoloșiserăți": "cocoloși",
    "cocoloșiseși": "cocoloși",
    "cocoloșiși": "cocoloși",
    "cocoloșit": "cocoloși",
    "cocoloșiți": "cocoloși",
    "cocoloșitu": "cocoloși",
    "necocoloșind": "cocoloși",
    "necocoloșindu": "cocoloși",
    "nemaicocoloșind": "cocoloși",
    "nemaicocoloșindu": "cocoloși",
    "cocoloșirea": "cocoloșire",
    "cocoloșireo": "cocoloșire",
    "cocoloșiri": "cocoloșire",
    "cocoloșirii": "cocoloșire",
    "cocoloșirile": "cocoloșire",
    "cocoloșirilor": "cocoloșire",
    "cocoloșită": "cocoloșit",
    "cocoloșite": "cocoloșit",
    "cocoloșiți": "cocoloșit",
    "coconi": "cocon",
    "coconii": "cocon",
    "coconilor": "cocon",
    "coconul": "cocon",
    "coconule": "cocon",
    "coconului": "cocon",
    "cocori": "cocor",
    "cocorii": "cocor",
    "cocorilor": "cocor",
    "cocorul": "cocor",
    "cocorule": "cocor",
    "cocorului": "cocor",
    "cocosul": "cocos",
    "cocosule": "cocos",
    "cocosului": "cocos",
    "cocoașe": "cocoș",
    "cocoașele": "cocoș",
    "cocoașelor": "cocoș",
    "cocoși": "cocoș",
    "cocoșii": "cocoș",
    "cocoșilor": "cocoș",
    "cocoșul": "cocoș",
    "cocoșule": "cocoș",
    "cocoșului": "cocoș",
    "cocoșă": "cocoșa",
    "cocoșai": "cocoșa",
    "cocoșam": "cocoșa",
    "cocoșăm": "cocoșa",
    "cocoșând": "cocoșa",
    "cocoșându": "cocoșa",
    "cocoșară": "cocoșa",
    "cocoșarăm": "cocoșa",
    "cocoșarăți": "cocoșa",
    "cocoșase": "cocoșa",
    "cocoșasem": "cocoșa",
    "cocoșaseră": "cocoșa",
    "cocoșaserăm": "cocoșa",
    "cocoșaserăți": "cocoșa",
    "cocoșaseși": "cocoșa",
    "cocoșași": "cocoșa",
    "cocoșat": "cocoșa",
    "cocoșați": "cocoșa",
    "cocoșatu": "cocoșa",
    "cocoșau": "cocoșa",
    "cocoșează": "cocoșa",
    "cocoșez": "cocoșa",
    "cocoșeze": "cocoșa",
    "cocoșezi": "cocoșa",
    "necocoșând": "cocoșa",
    "necocoșându": "cocoșa",
    "nemaicocoșând": "cocoșa",
    "nemaicocoșându": "cocoșa",
    "cocoșari": "cocoșar",
    "cocoșarii": "cocoșar",
    "cocoșarilor": "cocoșar",
    "cocoșarul": "cocoșar",
    "cocoșarule": "cocoșar",
    "cocoșarului": "cocoșar",
    "cocoșata": "cocoșat",
    "cocoșată": "cocoșat",
    "cocoșate": "cocoșat",
    "cocoșatei": "cocoșat",
    "cocoșatele": "cocoșat",
    "cocoșatelor": "cocoșat",
    "cocoșați": "cocoșat",
    "cocoșații": "cocoșat",
    "cocoșaților": "cocoșat",
    "cocoșato": "cocoșat",
    "cocoșatul": "cocoșat",
    "cocoșatule": "cocoșat",
    "cocoșatului": "cocoșat",
    "cocoșata": "cocoșată",
    "cocoșate": "cocoșată",
    "cocoșatei": "cocoșată",
    "cocoșatele": "cocoșată",
    "cocoșatelor": "cocoșată",
    "cocoșato": "cocoșată",
    "cocoși-de-mesteacăn": "cocoș-de-mesteacăn",
    "cocoși-de-munte": "cocoș-de-munte",
    "cocoșii-de-munte": "cocoș-de-munte",
    "cocoșilor-de-munte": "cocoș-de-munte",
    "cocoșul-de-munte": "cocoș-de-munte",
    "cocoșului-de-munte": "cocoș-de-munte",
    "cocoșei": "cocoșel",
    "cocoșeii": "cocoșel",
    "cocoșeilor": "cocoșel",
    "cocoșelul": "cocoșel",
    "cocoșelule": "cocoșel",
    "cocoșelului": "cocoșel",
    "cocoșei-de-câmp": "cocoșel-de-câmp",
    "cocoșeii-de-câmp": "cocoșel-de-câmp",
    "cocoșeilor-de-câmp": "cocoșel-de-câmp",
    "cocoșelul-de-câmp": "cocoșel-de-câmp",
    "cocoșelului-de-câmp": "cocoșel-de-câmp",
    "cocostârci": "cocostârc",
    "cocostârcii": "cocostârc",
    "cocostârcilor": "cocostârc",
    "cocostârcul": "cocostârc",
    "cocostârcule": "cocostârc",
    "cocostârcului": "cocostârc",
    "cocoață": "cocoța",
    "cocoațe": "cocoța",
    "cocoț": "cocoța",
    "cocoță": "cocoța",
    "cocoțai": "cocoța",
    "cocoțam": "cocoța",
    "cocoțăm": "cocoța",
    "cocoțând": "cocoța",
    "cocoțându": "cocoța",
    "cocoțară": "cocoța",
    "cocoțarăm": "cocoța",
    "cocoțarăți": "cocoța",
    "cocoțase": "cocoța",
    "cocoțasem": "cocoța",
    "cocoțaseră": "cocoța",
    "cocoțaserăm": "cocoța",
    "cocoțaserăți": "cocoța",
    "cocoțaseși": "cocoța",
    "cocoțași": "cocoța",
    "cocoțat": "cocoța",
    "cocoțați": "cocoța",
    "cocoțatu": "cocoța",
    "cocoțau": "cocoța",
    "cocoți": "cocoța",
    "necocoțând": "cocoța",
    "necocoțându": "cocoța",
    "nemaicocoțând": "cocoța",
    "nemaicocoțându": "cocoța",
    "cocoțarea": "cocoțare",
    "cocoțareo": "cocoțare",
    "cocoțări": "cocoțare",
    "cocoțării": "cocoțare",
    "cocoțările": "cocoțare",
    "cocoțărilor": "cocoțare",
    "cocoțată": "cocoțat",
    "cocoțate": "cocoțat",
    "cocoțați": "cocoțat",
    "cocotieri": "cocotier",
    "cocotierii": "cocotier",
    "cocotierilor": "cocotier",
    "cocotierul": "cocotier",
    "cocotierule": "cocotier",
    "cocotierului": "cocotier",
    "cocsul": "cocs",
    "cocsule": "cocs",
    "cocsului": "cocs",
    "cocsuri": "cocs",
    "cocsurile": "cocs",
    "cocsurilor": "cocs",
    "cocseria": "cocserie",
    "cocseriei": "cocserie",
    "cocserii": "cocserie",
    "cocseriile": "cocserie",
    "cocseriilor": "cocserie",
    "cocserio": "cocserie",
    "cocsific": "cocsifica",
    "cocsifică": "cocsifica",
    "cocsificai": "cocsifica",
    "cocsificam": "cocsifica",
    "cocsificăm": "cocsifica",
    "cocsificând": "cocsifica",
    "cocsificându": "cocsifica",
    "cocsificară": "cocsifica",
    "cocsificarăm": "cocsifica",
    "cocsificarăți": "cocsifica",
    "cocsificase": "cocsifica",
    "cocsificasem": "cocsifica",
    "cocsificaseră": "cocsifica",
    "cocsificaserăm": "cocsifica",
    "cocsificaserăți": "cocsifica",
    "cocsificaseși": "cocsifica",
    "cocsificași": "cocsifica",
    "cocsificat": "cocsifica",
    "cocsificați": "cocsifica",
    "cocsificatu": "cocsifica",
    "cocsificau": "cocsifica",
    "cocsifice": "cocsifica",
    "cocsifici": "cocsifica",
    "necocsificând": "cocsifica",
    "necocsificându": "cocsifica",
    "nemaicocsificând": "cocsifica",
    "nemaicocsificându": "cocsifica",
    "cocsificarea": "cocsificare",
    "cocsificareo": "cocsificare",
    "cocsificări": "cocsificare",
    "cocsificării": "cocsificare",
    "cocsificările": "cocsificare",
    "cocsificărilor": "cocsificare",
    "cocsificată": "cocsificat",
    "cocsificate": "cocsificat",
    "cocsificați": "cocsificat",
    "cocteilul": "cocteil",
    "cocteilule": "cocteil",
    "cocteilului": "cocteil",
    "cocteiluri": "cocteil",
    "cocteilurile": "cocteil",
    "cocteilurilor": "cocteil",
    "cocuța": "cocuță",
    "cocuțe": "cocuță",
    "cocuței": "cocuță",
    "cocuțele": "cocuță",
    "cocuțelor": "cocuță",
    "cocuțo": "cocuță",
    "Cocytul": "Cocyt",
    "Cocytului": "Cocyt",
    "codul": "cod",
    "codule": "cod",
    "codului": "cod",
    "coduri": "cod",
    "codurile": "cod",
    "codurilor": "cod",
    "codata": "codat",
    "codată": "codat",
    "codate": "codat",
    "codatei": "codat",
    "codatele": "codat",
    "codatelor": "codat",
    "codați": "codat",
    "codații": "codat",
    "codaților": "codat",
    "codato": "codat",
    "codatul": "codat",
    "codatule": "codat",
    "codatului": "codat",
    "codeala": "codeală",
    "codealo": "codeală",
    "codeli": "codeală",
    "codelii": "codeală",
    "codelile": "codeală",
    "codelilor": "codeală",
    "codeina": "codeină",
    "codeine": "codeină",
    "codeinei": "codeină",
    "codeinele": "codeină",
    "codeinelor": "codeină",
    "codeino": "codeină",
    "codexul": "codex",
    "codexule": "codex",
    "codexului": "codex",
    "codexuri": "codex",
    "codexurile": "codex",
    "codexurilor": "codex",
    "codea": "codi",
    "codeai": "codi",
    "codeam": "codi",
    "codească": "codi",
    "codeați": "codi",
    "codeau": "codi",
    "codesc": "codi",
    "codește": "codi",
    "codești": "codi",
    "codii": "codi",
    "codim": "codi",
    "codind": "codi",
    "codindu": "codi",
    "codiră": "codi",
    "codirăm": "codi",
    "codirăți": "codi",
    "codise": "codi",
    "codisem": "codi",
    "codiseră": "codi",
    "codiserăm": "codi",
    "codiserăți": "codi",
    "codiseși": "codi",
    "codiși": "codi",
    "codit": "codi",
    "codiți": "codi",
    "coditu": "codi",
    "necodind": "codi",
    "necodindu": "codi",
    "nemaicodind": "codi",
    "nemaicodindu": "codi",
    "codicele": "codice",
    "codicelor": "codice",
    "codicelui": "codice",
    "codicilul": "codicil",
    "codicilule": "codicil",
    "codicilului": "codicil",
    "codiciluri": "codicil",
    "codicilurile": "codicil",
    "codicilurilor": "codicil",
    "codific": "codifica",
    "codifică": "codifica",
    "codificai": "codifica",
    "codificam": "codifica",
    "codificăm": "codifica",
    "codificând": "codifica",
    "codificându": "codifica",
    "codificară": "codifica",
    "codificarăm": "codifica",
    "codificarăți": "codifica",
    "codificase": "codifica",
    "codificasem": "codifica",
    "codificaseră": "codifica",
    "codificaserăm": "codifica",
    "codificaserăți": "codifica",
    "codificaseși": "codifica",
    "codificași": "codifica",
    "codificat": "codifica",
    "codificați": "codifica",
    "codificatu": "codifica",
    "codificau": "codifica",
    "codifice": "codifica",
    "codifici": "codifica",
    "necodificând": "codifica",
    "necodificându": "codifica",
    "nemaicodificând": "codifica",
    "nemaicodificându": "codifica",
    "codificarea": "codificare",
    "codificareo": "codificare",
    "codificări": "codificare",
    "codificării": "codificare",
    "codificările": "codificare",
    "codificărilor": "codificare",
    "codificată": "codificat",
    "codificate": "codificat",
    "codificați": "codificat",
    "codirea": "codire",
    "codireo": "codire",
    "codiri": "codire",
    "codirii": "codire",
    "codirile": "codire",
    "codirilor": "codire",
    "codită": "codit",
    "codite": "codit",
    "codiți": "codit",
    "codița": "codiță",
    "codițe": "codiță",
    "codiței": "codiță",
    "codițele": "codiță",
    "codițelor": "codiță",
    "codițo": "codiță",
    "codoașa": "codoașă",
    "codoașe": "codoașă",
    "codoașei": "codoașă",
    "codoașele": "codoașă",
    "codoașelor": "codoașă",
    "codoașo": "codoașă",
    "codobatura": "codobatură",
    "codobaturi": "codobatură",
    "codobaturii": "codobatură",
    "codobaturile": "codobatură",
    "codobaturilor": "codobatură",
    "codobaturo": "codobatură",
    "codobelci": "codobelc",
    "codobelcii": "codobelc",
    "codobelcilor": "codobelc",
    "codobelcul": "codobelc",
    "codobelcule": "codobelc",
    "codobelcului": "codobelc",
    "codoși": "codoș",
    "codoșii": "codoș",
    "codoșilor": "codoș",
    "codoșul": "codoș",
    "codoșule": "codoș",
    "codoșului": "codoș",
    "codreana": "codrean",
    "codreană": "codrean",
    "codreanca": "codrean",
    "codreancă": "codrean",
    "codreanco": "codrean",
    "codreano": "codrean",
    "codreanul": "codrean",
    "codreanule": "codrean",
    "codreanului": "codrean",
    "codrence": "codrean",
    "codrencei": "codrean",
    "codrencele": "codrean",
    "codrencelor": "codrean",
    "codrene": "codrean",
    "codrenei": "codrean",
    "codrenele": "codrean",
    "codrenelor": "codrean",
    "codreni": "codrean",
    "codrenii": "codrean",
    "codrenilor": "codrean",
    "codreasca": "codresc",
    "codrească": "codresc",
    "codreasco": "codresc",
    "codrescul": "codresc",
    "codrescule": "codresc",
    "codrescului": "codresc",
    "codrești": "codresc",
    "codreștii": "codresc",
    "codreștile": "codresc",
    "codreștilor": "codresc",
    "codri": "codru",
    "codrii": "codru",
    "codrilor": "codru",
    "codrul": "codru",
    "codrule": "codru",
    "codrului": "codru",
    "codrulețe": "codruleț",
    "codrulețele": "codruleț",
    "codrulețelor": "codruleț",
    "codrulețul": "codruleț",
    "codrulețule": "codruleț",
    "codrulețului": "codruleț",
    "codruți": "codruț",
    "codruții": "codruț",
    "codruților": "codruț",
    "codruțul": "codruț",
    "codruțule": "codruț",
    "codruțului": "codruț",
    "coechipieri": "coechipier",
    "coechipierii": "coechipier",
    "coechipierilor": "coechipier",
    "coechipierul": "coechipier",
    "coechipierule": "coechipier",
    "coechipierului": "coechipier",
    "coechipiera": "coechipieră",
    "coechipiere": "coechipieră",
    "coechipierei": "coechipieră",
    "coechipierele": "coechipieră",
    "coechipierelor": "coechipieră",
    "coechipiero": "coechipieră",
    "coeficienți": "coeficient",
    "coeficienții": "coeficient",
    "coeficienților": "coeficient",
    "coeficientul": "coeficient",
    "coeficientule": "coeficient",
    "coeficientului": "coeficient",
    "coerciția": "coerciție",
    "coerciției": "coerciție",
    "coerciții": "coerciție",
    "coercițiile": "coerciție",
    "coercițiilor": "coerciție",
    "coercițio": "coerciție",
    "coercitiva": "coercitiv",
    "coercitivă": "coercitiv",
    "coercitive": "coercitiv",
    "coercitivei": "coercitiv",
    "coercitivele": "coercitiv",
    "coercitivelor": "coercitiv",
    "coercitivi": "coercitiv",
    "coercitivii": "coercitiv",
    "coercitivilor": "coercitiv",
    "coercitivo": "coercitiv",
    "coercitivul": "coercitiv",
    "coercitivule": "coercitiv",
    "coercitivului": "coercitiv",
    "coerenta": "coerent",
    "coerentă": "coerent",
    "coerente": "coerent",
    "coerentei": "coerent",
    "coerentele": "coerent",
    "coerentelor": "coerent",
    "coerenți": "coerent",
    "coerenții": "coerent",
    "coerenților": "coerent",
    "coerento": "coerent",
    "coerentul": "coerent",
    "coerentule": "coerent",
    "coerentului": "coerent",
    "coerența": "coerență",
    "coerențe": "coerență",
    "coerenței": "coerență",
    "coerențele": "coerență",
    "coerențelor": "coerență",
    "coerențo": "coerență",
    "coeziunea": "coeziune",
    "coeziuneo": "coeziune",
    "coeziuni": "coeziune",
    "coeziunii": "coeziune",
    "coeziunile": "coeziune",
    "coeziunilor": "coeziune",
    "cofa": "cofă",
    "cofe": "cofă",
    "cofei": "cofă",
    "cofele": "cofă",
    "cofelor": "cofă",
    "cofo": "cofă",
    "cofeina": "cofeină",
    "cofeine": "cofeină",
    "cofeinei": "cofeină",
    "cofeino": "cofeină",
    "cofetari": "cofetar",
    "cofetarii": "cofetar",
    "cofetarilor": "cofetar",
    "cofetarul": "cofetar",
    "cofetarule": "cofetar",
    "cofetarului": "cofetar",
    "cofetara": "cofetară",
    "cofetare": "cofetară",
    "cofetarei": "cofetară",
    "cofetarele": "cofetară",
    "cofetarelor": "cofetară",
    "cofetaro": "cofetară",
    "cofet.": "cofetărie",
    "cofetăria": "cofetărie",
    "cofetăriei": "cofetărie",
    "cofetării": "cofetărie",
    "cofetăriile": "cofetărie",
    "cofetăriilor": "cofetărie",
    "cofetărio": "cofetărie",
    "cofeturile": "cofeturi",
    "cofeturilor": "cofeturi",
    "cofița": "cofiță",
    "cofițe": "cofiță",
    "cofiței": "cofiță",
    "cofițele": "cofiță",
    "cofițelor": "cofiță",
    "cofițo": "cofiță",
    "cofleșea": "cofleși",
    "cofleșeai": "cofleși",
    "cofleșeam": "cofleși",
    "cofleșească": "cofleși",
    "cofleșeați": "cofleși",
    "cofleșeau": "cofleși",
    "cofleșesc": "cofleși",
    "cofleșește": "cofleși",
    "cofleșești": "cofleși",
    "cofleșii": "cofleși",
    "cofleșim": "cofleși",
    "cofleșind": "cofleși",
    "cofleșindu": "cofleși",
    "cofleșiră": "cofleși",
    "cofleșirăm": "cofleși",
    "cofleșirăți": "cofleși",
    "cofleșise": "cofleși",
    "cofleșisem": "cofleși",
    "cofleșiseră": "cofleși",
    "cofleșiserăm": "cofleși",
    "cofleșiserăți": "cofleși",
    "cofleșiseși": "cofleși",
    "cofleșiși": "cofleși",
    "cofleșit": "cofleși",
    "cofleșiți": "cofleși",
    "cofleșitu": "cofleși",
    "necofleșind": "cofleși",
    "necofleșindu": "cofleși",
    "nemaicofleșind": "cofleși",
    "nemaicofleșindu": "cofleși",
    "cofleșită": "cofleșit",
    "cofleșite": "cofleșit",
    "cofleșiți": "cofleșit",
    "cofondatoarea": "cofondatoare",
    "cofondatoarei": "cofondatoare",
    "cofondatoarele": "cofondatoare",
    "cofondatoarelor": "cofondatoare",
    "cofondatoareo": "cofondatoare",
    "cofondatoare": "cofondator",
    "cofondatoarea": "cofondator",
    "cofondatoarei": "cofondator",
    "cofondatoarele": "cofondator",
    "cofondatoarelor": "cofondator",
    "cofondatoareo": "cofondator",
    "cofondatori": "cofondator",
    "cofondatorii": "cofondator",
    "cofondatorilor": "cofondator",
    "cofondatorul": "cofondator",
    "cofondatorule": "cofondator",
    "cofondatorului": "cofondator",
    "cofraje": "cofraj",
    "cofrajele": "cofraj",
    "cofrajelor": "cofraj",
    "cofrajul": "cofraj",
    "cofrajule": "cofraj",
    "cofrajului": "cofraj",
    "cognoscibila": "cognoscibil",
    "cognoscibilă": "cognoscibil",
    "cognoscibile": "cognoscibil",
    "cognoscibilei": "cognoscibil",
    "cognoscibilele": "cognoscibil",
    "cognoscibilelor": "cognoscibil",
    "cognoscibili": "cognoscibil",
    "cognoscibilii": "cognoscibil",
    "cognoscibililor": "cognoscibil",
    "cognoscibilo": "cognoscibil",
    "cognoscibilul": "cognoscibil",
    "cognoscibilule": "cognoscibil",
    "cognoscibilului": "cognoscibil",
    "cohorta": "cohortă",
    "cohorte": "cohortă",
    "cohortei": "cohortă",
    "cohortele": "cohortă",
    "cohortelor": "cohortă",
    "cohorto": "cohortă",
    "coiful": "coif",
    "coifule": "coif",
    "coifului": "coif",
    "coifuri": "coif",
    "coifurile": "coif",
    "coifurilor": "coif",
    "coincid": "coincide",
    "coincidă": "coincide",
    "coincidea": "coincide",
    "coincideai": "coincide",
    "coincideam": "coincide",
    "coincideați": "coincide",
    "coincideau": "coincide",
    "coincidem": "coincide",
    "coincideți": "coincide",
    "coincis": "coincide",
    "coincise": "coincide",
    "coincisei": "coincide",
    "coinciseră": "coincide",
    "coinciserăm": "coincide",
    "coinciserăți": "coincide",
    "coincisese": "coincide",
    "coincisesem": "coincide",
    "coinciseseră": "coincide",
    "coinciseserăm": "coincide",
    "coinciseserăți": "coincide",
    "coinciseseși": "coincide",
    "coinciseși": "coincide",
    "coincisu": "coincide",
    "coincizând": "coincide",
    "coincizându": "coincide",
    "coincizi": "coincide",
    "necoincizând": "coincide",
    "necoincizându": "coincide",
    "nemaicoincizând": "coincide",
    "nemaicoincizându": "coincide",
    "coincidența": "coincidență",
    "coincidențe": "coincidență",
    "coincidenței": "coincidență",
    "coincidențele": "coincidență",
    "coincidențelor": "coincidență",
    "coincidențo": "coincidență",
    "coincisă": "coincis",
    "coincise": "coincis",
    "coinciși": "coincis",
    "coitul": "coit",
    "coitule": "coit",
    "coitului": "coit",
    "coituri": "coit",
    "coiturile": "coit",
    "coiturilor": "coit",
    "cojeala": "cojeală",
    "cojealo": "cojeală",
    "cojeli": "cojeală",
    "cojelii": "cojeală",
    "cojelile": "cojeală",
    "cojelilor": "cojeală",
    "cojea": "coji",
    "cojeai": "coji",
    "cojeam": "coji",
    "cojească": "coji",
    "cojeați": "coji",
    "cojeau": "coji",
    "cojesc": "coji",
    "cojește": "coji",
    "cojești": "coji",
    "cojii": "coji",
    "cojim": "coji",
    "cojind": "coji",
    "cojindu": "coji",
    "cojiră": "coji",
    "cojirăm": "coji",
    "cojirăți": "coji",
    "cojise": "coji",
    "cojisem": "coji",
    "cojiseră": "coji",
    "cojiserăm": "coji",
    "cojiserăți": "coji",
    "cojiseși": "coji",
    "cojiși": "coji",
    "cojit": "coji",
    "cojiți": "coji",
    "cojitu": "coji",
    "necojind": "coji",
    "necojindu": "coji",
    "nemaicojind": "coji",
    "nemaicojindu": "coji",
    "cojirea": "cojire",
    "cojireo": "cojire",
    "cojiri": "cojire",
    "cojirii": "cojire",
    "cojirile": "cojire",
    "cojirilor": "cojire",
    "cojita": "cojit",
    "cojită": "cojit",
    "cojite": "cojit",
    "cojitei": "cojit",
    "cojitele": "cojit",
    "cojitelor": "cojit",
    "cojiți": "cojit",
    "cojiții": "cojit",
    "cojiților": "cojit",
    "cojito": "cojit",
    "cojitul": "cojit",
    "cojitule": "cojit",
    "cojitului": "cojit",
    "cojoace": "cojoc",
    "cojoacele": "cojoc",
    "cojoacelor": "cojoc",
    "cojocul": "cojoc",
    "cojocule": "cojoc",
    "cojocului": "cojoc",
    "cojocele": "cojocel",
    "cojocelele": "cojocel",
    "cojocelelor": "cojocel",
    "cojocelul": "cojocel",
    "cojocelule": "cojocel",
    "cojocelului": "cojocel",
    "colaboră": "colabora",
    "colaborai": "colabora",
    "colaboram": "colabora",
    "colaborăm": "colabora",
    "colaborând": "colabora",
    "colaborându": "colabora",
    "colaborară": "colabora",
    "colaborarăm": "colabora",
    "colaborarăți": "colabora",
    "colaborase": "colabora",
    "colaborasem": "colabora",
    "colaboraseră": "colabora",
    "colaboraserăm": "colabora",
    "colaboraserăți": "colabora",
    "colaboraseși": "colabora",
    "colaborași": "colabora",
    "colaborat": "colabora",
    "colaborați": "colabora",
    "colaboratu": "colabora",
    "colaborau": "colabora",
    "colaborează": "colabora",
    "colaborez": "colabora",
    "colaboreze": "colabora",
    "colaborezi": "colabora",
    "necolaborând": "colabora",
    "necolaborându": "colabora",
    "nemaicolaborând": "colabora",
    "nemaicolaborându": "colabora",
    "colaborarea": "colaborare",
    "colaborareo": "colaborare",
    "colaborări": "colaborare",
    "colaborării": "colaborare",
    "colaborările": "colaborare",
    "colaborărilor": "colaborare",
    "colaborată": "colaborat",
    "colaborate": "colaborat",
    "colaborați": "colaborat",
    "colaboraționismul": "colaboraționism",
    "colaboraționismului": "colaboraționism",
    "colaboraționiști": "colaboraționist",
    "colaboraționiștii": "colaboraționist",
    "colaboraționiștilor": "colaboraționist",
    "colaboraționistul": "colaboraționist",
    "colaboraționistule": "colaboraționist",
    "colaboraționistului": "colaboraționist",
    "colaboraționista": "colaboraționistă",
    "colaboraționiste": "colaboraționistă",
    "colaboraționistei": "colaboraționistă",
    "colaboraționistele": "colaboraționistă",
    "colaboraționistelor": "colaboraționistă",
    "colaboraționisto": "colaboraționistă",
    "colaboratoarea": "colaboratoare",
    "colaboratoarei": "colaboratoare",
    "colaboratoarele": "colaboratoare",
    "colaboratoarelor": "colaboratoare",
    "colaboratoareo": "colaboratoare",
    "colaboratori": "colaborator",
    "colaboratorii": "colaborator",
    "colaboratorilor": "colaborator",
    "colaboratorul": "colaborator",
    "colaboratorule": "colaborator",
    "colaboratorului": "colaborator",
    "colaci": "colac",
    "colacii": "colac",
    "colacilor": "colac",
    "colacul": "colac",
    "colacule": "colac",
    "colacului": "colac",
    "colăcei": "colăcel",
    "colăceii": "colăcel",
    "colăceilor": "colăcel",
    "colăcelul": "colăcel",
    "colăcelule": "colăcel",
    "colăcelului": "colăcel",
    "colane": "colan",
    "colanele": "colan",
    "colanelor": "colan",
    "colanul": "colan",
    "colanule": "colan",
    "colanului": "colan",
    "colapsul": "colaps",
    "colapsule": "colaps",
    "colapsului": "colaps",
    "colapsuri": "colaps",
    "colapsurile": "colaps",
    "colapsurilor": "colaps",
    "colaterala": "colateral",
    "colaterală": "colateral",
    "colaterale": "colateral",
    "colateralei": "colateral",
    "colateralele": "colateral",
    "colateralelor": "colateral",
    "colaterali": "colateral",
    "colateralii": "colateral",
    "colateralilor": "colateral",
    "colateralo": "colateral",
    "colateralul": "colateral",
    "colateralule": "colateral",
    "colateralului": "colateral",
    "colaționă": "colaționa",
    "colaționai": "colaționa",
    "colaționam": "colaționa",
    "colaționăm": "colaționa",
    "colaționând": "colaționa",
    "colaționându": "colaționa",
    "colaționară": "colaționa",
    "colaționarăm": "colaționa",
    "colaționarăți": "colaționa",
    "colaționase": "colaționa",
    "colaționasem": "colaționa",
    "colaționaseră": "colaționa",
    "colaționaserăm": "colaționa",
    "colaționaserăți": "colaționa",
    "colaționaseși": "colaționa",
    "colaționași": "colaționa",
    "colaționat": "colaționa",
    "colaționați": "colaționa",
    "colaționatu": "colaționa",
    "colaționau": "colaționa",
    "colaționează": "colaționa",
    "colaționez": "colaționa",
    "colaționeze": "colaționa",
    "colaționezi": "colaționa",
    "necolaționând": "colaționa",
    "necolaționându": "colaționa",
    "nemaicolaționând": "colaționa",
    "nemaicolaționându": "colaționa",
    "colaționarea": "colaționare",
    "colaționareo": "colaționare",
    "colaționări": "colaționare",
    "colaționării": "colaționare",
    "colaționările": "colaționare",
    "colaționărilor": "colaționare",
    "colaționată": "colaționat",
    "colaționate": "colaționat",
    "colaționați": "colaționat",
    "colațiunea": "colațiune",
    "colațiuneo": "colațiune",
    "colațiuni": "colațiune",
    "colațiunii": "colațiune",
    "colațiunile": "colațiune",
    "colațiunilor": "colațiune",
    "colbul": "colb",
    "colbule": "colb",
    "colbului": "colb",
    "colburi": "colb",
    "colburile": "colb",
    "colburilor": "colb",
    "colbăia": "colbăi",
    "colbăiai": "colbăi",
    "colbăiam": "colbăi",
    "colbăiască": "colbăi",
    "colbăiați": "colbăi",
    "colbăiau": "colbăi",
    "colbăiesc": "colbăi",
    "colbăiește": "colbăi",
    "colbăiești": "colbăi",
    "colbăii": "colbăi",
    "colbăim": "colbăi",
    "colbăind": "colbăi",
    "colbăindu": "colbăi",
    "colbăiră": "colbăi",
    "colbăirăm": "colbăi",
    "colbăirăți": "colbăi",
    "colbăise": "colbăi",
    "colbăisem": "colbăi",
    "colbăiseră": "colbăi",
    "colbăiserăm": "colbăi",
    "colbăiserăți": "colbăi",
    "colbăiseși": "colbăi",
    "colbăiși": "colbăi",
    "colbăit": "colbăi",
    "colbăiți": "colbăi",
    "colbăitu": "colbăi",
    "necolbăind": "colbăi",
    "necolbăindu": "colbăi",
    "nemaicolbăind": "colbăi",
    "nemaicolbăindu": "colbăi",
    "colbăita": "colbăit",
    "colbăită": "colbăit",
    "colbăite": "colbăit",
    "colbăitei": "colbăit",
    "colbăitele": "colbăit",
    "colbăitelor": "colbăit",
    "colbăiți": "colbăit",
    "colbăiții": "colbăit",
    "colbăiților": "colbăit",
    "colbăito": "colbăit",
    "colbăitul": "colbăit",
    "colbăitule": "colbăit",
    "colbăitului": "colbăit",
    "colbăria": "colbărie",
    "colbăriei": "colbărie",
    "colbării": "colbărie",
    "colbăriile": "colbărie",
    "colbăriilor": "colbărie",
    "colbărio": "colbărie",
    "colbuita": "colbuit",
    "colbuită": "colbuit",
    "colbuite": "colbuit",
    "colbuitei": "colbuit",
    "colbuitele": "colbuit",
    "colbuitelor": "colbuit",
    "colbuiți": "colbuit",
    "colbuiții": "colbuit",
    "colbuiților": "colbuit",
    "colbuito": "colbuit",
    "colbuitul": "colbuit",
    "colbuitule": "colbuit",
    "colbuitului": "colbuit",
    "colcăia": "colcăi",
    "colcăiai": "colcăi",
    "colcăiam": "colcăi",
    "colcăiați": "colcăi",
    "colcăiau": "colcăi",
    "colcăie": "colcăi",
    "colcăii": "colcăi",
    "colcăim": "colcăi",
    "colcăind": "colcăi",
    "colcăindu": "colcăi",
    "colcăiră": "colcăi",
    "colcăirăm": "colcăi",
    "colcăirăți": "colcăi",
    "colcăise": "colcăi",
    "colcăisem": "colcăi",
    "colcăiseră": "colcăi",
    "colcăiserăm": "colcăi",
    "colcăiserăți": "colcăi",
    "colcăiseși": "colcăi",
    "colcăiși": "colcăi",
    "colcăit": "colcăi",
    "colcăiți": "colcăi",
    "colcăitu": "colcăi",
    "necolcăind": "colcăi",
    "necolcăindu": "colcăi",
    "nemaicolcăind": "colcăi",
    "nemaicolcăindu": "colcăi",
    "colcăiala": "colcăială",
    "colcăialo": "colcăială",
    "colcăieli": "colcăială",
    "colcăielii": "colcăială",
    "colcăielile": "colcăială",
    "colcăielilor": "colcăială",
    "colcăită": "colcăit",
    "colcăite": "colcăit",
    "colcăiți": "colcăit",
    "colectă": "colecta",
    "colectai": "colecta",
    "colectam": "colecta",
    "colectăm": "colecta",
    "colectând": "colecta",
    "colectându": "colecta",
    "colectară": "colecta",
    "colectarăm": "colecta",
    "colectarăți": "colecta",
    "colectase": "colecta",
    "colectasem": "colecta",
    "colectaseră": "colecta",
    "colectaserăm": "colecta",
    "colectaserăți": "colecta",
    "colectaseși": "colecta",
    "colectași": "colecta",
    "colectat": "colecta",
    "colectați": "colecta",
    "colectatu": "colecta",
    "colectau": "colecta",
    "colectează": "colecta",
    "colectez": "colecta",
    "colecteze": "colecta",
    "colectezi": "colecta",
    "necolectând": "colecta",
    "necolectându": "colecta",
    "nemaicolectând": "colecta",
    "nemaicolectându": "colecta",
    "colecta": "colectă",
    "colecte": "colectă",
    "colectei": "colectă",
    "colectele": "colectă",
    "colectelor": "colectă",
    "colecto": "colectă",
    "colectarea": "colectare",
    "colectareo": "colectare",
    "colectări": "colectare",
    "colectării": "colectare",
    "colectările": "colectare",
    "colectărilor": "colectare",
    "colectată": "colectat",
    "colectate": "colectat",
    "colectați": "colectat",
    "col.": "colecție",
    "colecția": "colecție",
    "colecției": "colecție",
    "colecții": "colecție",
    "colecțiile": "colecție",
    "colecțiilor": "colecție",
    "colecțio": "colecție",
    "colecționă": "colecționa",
    "colecționai": "colecționa",
    "colecționam": "colecționa",
    "colecționăm": "colecționa",
    "colecționând": "colecționa",
    "colecționându": "colecționa",
    "colecționară": "colecționa",
    "colecționarăm": "colecționa",
    "colecționarăți": "colecționa",
    "colecționase": "colecționa",
    "colecționasem": "colecționa",
    "colecționaseră": "colecționa",
    "colecționaserăm": "colecționa",
    "colecționaserăți": "colecționa",
    "colecționaseși": "colecționa",
    "colecționași": "colecționa",
    "colecționat": "colecționa",
    "colecționați": "colecționa",
    "colecționatu": "colecționa",
    "colecționau": "colecționa",
    "colecționează": "colecționa",
    "colecționez": "colecționa",
    "colecționeze": "colecționa",
    "colecționezi": "colecționa",
    "necolecționând": "colecționa",
    "necolecționându": "colecționa",
    "nemaicolecționând": "colecționa",
    "nemaicolecționându": "colecționa",
    "colecționari": "colecționar",
    "colecționarii": "colecționar",
    "colecționarilor": "colecționar",
    "colecționarul": "colecționar",
    "colecționarule": "colecționar",
    "colecționarului": "colecționar",
    "colecționara": "colecționară",
    "colecționare": "colecționară",
    "colecționarei": "colecționară",
    "colecționarele": "colecționară",
    "colecționarelor": "colecționară",
    "colecționaro": "colecționară",
    "colecționarea": "colecționare",
    "colecționareo": "colecționare",
    "colecționări": "colecționare",
    "colecționării": "colecționare",
    "colecționările": "colecționare",
    "colecționărilor": "colecționare",
    "colecționată": "colecționat",
    "colecționate": "colecționat",
    "colecționați": "colecționat",
    "colectiva": "colectiv",
    "colectivă": "colectiv",
    "colective": "colectiv",
    "colectivei": "colectiv",
    "colectivele": "colectiv",
    "colectivelor": "colectiv",
    "colectivi": "colectiv",
    "colectivii": "colectiv",
    "colectivilor": "colectiv",
    "colectivo": "colectiv",
    "colectivul": "colectiv",
    "colectivule": "colectiv",
    "colectivului": "colectiv",
    "colectivisme": "colectivism",
    "colectivismele": "colectivism",
    "colectivismelor": "colectivism",
    "colectivismul": "colectivism",
    "colectivismule": "colectivism",
    "colectivismului": "colectivism",
    "colectivista": "colectivist",
    "colectivistă": "colectivist",
    "colectiviste": "colectivist",
    "colectivistei": "colectivist",
    "colectivistele": "colectivist",
    "colectivistelor": "colectivist",
    "colectiviști": "colectivist",
    "colectiviștii": "colectivist",
    "colectiviștilor": "colectivist",
    "colectivisto": "colectivist",
    "colectivistul": "colectivist",
    "colectivistule": "colectivist",
    "colectivistului": "colectivist",
    "colectiviză": "colectiviza",
    "colectivizai": "colectiviza",
    "colectivizam": "colectiviza",
    "colectivizăm": "colectiviza",
    "colectivizând": "colectiviza",
    "colectivizându": "colectiviza",
    "colectivizară": "colectiviza",
    "colectivizarăm": "colectiviza",
    "colectivizarăți": "colectiviza",
    "colectivizase": "colectiviza",
    "colectivizasem": "colectiviza",
    "colectivizaseră": "colectiviza",
    "colectivizaserăm": "colectiviza",
    "colectivizaserăți": "colectiviza",
    "colectivizaseși": "colectiviza",
    "colectivizași": "colectiviza",
    "colectivizat": "colectiviza",
    "colectivizați": "colectiviza",
    "colectivizatu": "colectiviza",
    "colectivizau": "colectiviza",
    "colectivizează": "colectiviza",
    "colectivizez": "colectiviza",
    "colectivizeze": "colectiviza",
    "colectivizezi": "colectiviza",
    "necolectivizând": "colectiviza",
    "necolectivizându": "colectiviza",
    "nemaicolectivizând": "colectiviza",
    "nemaicolectivizându": "colectiviza",
    "colectivizarea": "colectivizare",
    "colectivizareo": "colectivizare",
    "colectivizări": "colectivizare",
    "colectivizării": "colectivizare",
    "colectivizările": "colectivizare",
    "colectivizărilor": "colectivizare",
    "colectivizată": "colectivizat",
    "colectivizate": "colectivizat",
    "colectivizați": "colectivizat",
    "colectoare": "colector",
    "colectoarea": "colector",
    "colectoarei": "colector",
    "colectoarele": "colector",
    "colectoarelor": "colector",
    "colectoareo": "colector",
    "colectori": "colector",
    "colectorii": "colector",
    "colectorilor": "colector",
    "colectorul": "colector",
    "colectorule": "colector",
    "colectorului": "colector",
    "colegi": "coleg",
    "colegii": "coleg",
    "colegilor": "coleg",
    "colegul": "coleg",
    "colegule": "coleg",
    "colegului": "coleg",
    "colega": "colegă",
    "colege": "colegă",
    "colegei": "colegă",
    "colegele": "colegă",
    "colegelor": "colegă",
    "colego": "colegă",
    "colegatari": "colegatar",
    "colegatarii": "colegatar",
    "colegatarilor": "colegatar",
    "colegatarul": "colegatar",
    "colegatarule": "colegatar",
    "colegatarului": "colegatar",
    "colegatara": "colegatară",
    "colegatare": "colegatară",
    "colegatarei": "colegatară",
    "colegatarele": "colegatară",
    "colegatarelor": "colegatară",
    "colegataro": "colegatară",
    "colegiala": "colegial",
    "colegială": "colegial",
    "colegiale": "colegial",
    "colegialele": "colegial",
    "colegialelor": "colegial",
    "colegiali": "colegial",
    "colegialii": "colegial",
    "colegialilor": "colegial",
    "colegialul": "colegial",
    "colegialului": "colegial",
    "Col.": "colegiu",
    "colegii": "colegiu",
    "colegiile": "colegiu",
    "colegiilor": "colegiu",
    "colegiul": "colegiu",
    "colegiule": "colegiu",
    "colegiului": "colegiu",
    "coleoptere": "coleopter",
    "coleopterele": "coleopter",
    "coleopterelor": "coleopter",
    "coleopterul": "coleopter",
    "coleopterule": "coleopter",
    "coleopterului": "coleopter",
    "colerica": "coleric",
    "colerică": "coleric",
    "colerice": "coleric",
    "colericei": "coleric",
    "colericele": "coleric",
    "colericelor": "coleric",
    "colerici": "coleric",
    "colericii": "coleric",
    "colericilor": "coleric",
    "colerico": "coleric",
    "colericul": "coleric",
    "colericule": "coleric",
    "colericului": "coleric",
    "colesterolul": "colesterol",
    "colesterolule": "colesterol",
    "colesterolului": "colesterol",
    "colete": "colet",
    "coletele": "colet",
    "coletelor": "colet",
    "coletul": "colet",
    "coletule": "colet",
    "coletului": "colet",
    "coletăria": "coletărie",
    "coletăriei": "coletărie",
    "coletării": "coletărie",
    "coletăriile": "coletărie",
    "coletăriilor": "coletărie",
    "coletărio": "coletărie",
    "colhozul": "colhoz",
    "colhozule": "colhoz",
    "colhozului": "colhoz",
    "colhozuri": "colhoz",
    "colhozurile": "colhoz",
    "colhozurilor": "colhoz",
    "colhoznica": "colhoznic",
    "colhoznică": "colhoznic",
    "colhoznice": "colhoznic",
    "colhoznicei": "colhoznic",
    "colhoznicele": "colhoznic",
    "colhoznicelor": "colhoznic",
    "colhoznici": "colhoznic",
    "colhoznicii": "colhoznic",
    "colhoznicilor": "colhoznic",
    "colhoznico": "colhoznic",
    "colhoznicul": "colhoznic",
    "colhoznicule": "colhoznic",
    "colhoznicului": "colhoznic",
    "colhoznica": "colhoznică",
    "colhoznice": "colhoznică",
    "colhoznicei": "colhoznică",
    "colhoznicele": "colhoznică",
    "colhoznicelor": "colhoznică",
    "colhoznico": "colhoznică",
    "coliba": "colibă",
    "colibe": "colibă",
    "colibei": "colibă",
    "colibele": "colibă",
    "colibelor": "colibă",
    "colibo": "colibă",
    "colibacili": "colibacil",
    "colibacilii": "colibacil",
    "colibacililor": "colibacil",
    "colibacilul": "colibacil",
    "colibacilule": "colibacil",
    "colibacilului": "colibacil",
    "colica": "colică",
    "colici": "colică",
    "colicii": "colică",
    "colicile": "colică",
    "colicilor": "colică",
    "colico": "colică",
    "coliere": "colier",
    "colierele": "colier",
    "colierelor": "colier",
    "colierul": "colier",
    "colierule": "colier",
    "colierului": "colier",
    "colimatoare": "colimator",
    "colimatoarele": "colimator",
    "colimatoarelor": "colimator",
    "colimatorul": "colimator",
    "colimatorule": "colimator",
    "colimatorului": "colimator",
    "colina": "colină",
    "coline": "colină",
    "colinei": "colină",
    "colinele": "colină",
    "colinelor": "colină",
    "colino": "colină",
    "colinde": "colind",
    "colindele": "colind",
    "colindelor": "colind",
    "colindul": "colind",
    "colindule": "colind",
    "colindului": "colind",
    "colind": "colinda",
    "colindă": "colinda",
    "colindai": "colinda",
    "colindam": "colinda",
    "colindăm": "colinda",
    "colindând": "colinda",
    "colindându": "colinda",
    "colindară": "colinda",
    "colindarăm": "colinda",
    "colindarăți": "colinda",
    "colindase": "colinda",
    "colindasem": "colinda",
    "colindaseră": "colinda",
    "colindaserăm": "colinda",
    "colindaserăți": "colinda",
    "colindaseși": "colinda",
    "colindași": "colinda",
    "colindat": "colinda",
    "colindați": "colinda",
    "colindatu": "colinda",
    "colindau": "colinda",
    "colinde": "colinda",
    "colinzi": "colinda",
    "necolindând": "colinda",
    "necolindându": "colinda",
    "nemaicolindând": "colinda",
    "nemaicolindându": "colinda",
    "colinda": "colindă",
    "colindo": "colindă",
    "colinzi": "colindă",
    "colinzii": "colindă",
    "colinzile": "colindă",
    "colinzilor": "colindă",
    "colindarea": "colindare",
    "colindareo": "colindare",
    "colindări": "colindare",
    "colindării": "colindare",
    "colindările": "colindare",
    "colindărilor": "colindare",
    "colindată": "colindat",
    "colindate": "colindat",
    "colindați": "colindat",
    "colindatul": "colindat",
    "colindatule": "colindat",
    "colindatului": "colindat",
    "colindătoarea": "colindătoare",
    "colindătoarei": "colindătoare",
    "colindătoarele": "colindătoare",
    "colindătoarelor": "colindătoare",
    "colindătoareo": "colindătoare",
    "colindători": "colindător",
    "colindătorii": "colindător",
    "colindătorilor": "colindător",
    "colindătorul": "colindător",
    "colindătorule": "colindător",
    "colindătorului": "colindător",
    "colirul": "colir",
    "colirule": "colir",
    "colirului": "colir",
    "colita": "colită",
    "colite": "colită",
    "colitei": "colită",
    "colitele": "colită",
    "colitelor": "colită",
    "colito": "colită",
    "coliva": "colivă",
    "colive": "colivă",
    "colivei": "colivă",
    "colivele": "colivă",
    "colivelor": "colivă",
    "colivo": "colivă",
    "colivia": "colivie",
    "coliviei": "colivie",
    "colivii": "colivie",
    "coliviile": "colivie",
    "coliviilor": "colivie",
    "colivio": "colivie",
    "coliziunea": "coliziune",
    "coliziuneo": "coliziune",
    "coliziuni": "coliziune",
    "coliziunii": "coliziune",
    "coliziunile": "coliziune",
    "coliziunilor": "coliziune",
    "colmatarea": "colmatare",
    "colmatareo": "colmatare",
    "colmatări": "colmatare",
    "colmatării": "colmatare",
    "colmatările": "colmatare",
    "colmatărilor": "colmatare",
    "colnice": "colnic",
    "colnicele": "colnic",
    "colnicelor": "colnic",
    "colnicul": "colnic",
    "colnicule": "colnic",
    "colnicului": "colnic",
    "colnicele": "colnicel",
    "colnicelele": "colnicel",
    "colnicelelor": "colnicel",
    "colnicelul": "colnicel",
    "colnicelule": "colnicel",
    "colnicelului": "colnicel",
    "coloana": "coloană",
    "coloane": "coloană",
    "coloanei": "coloană",
    "coloanele": "coloană",
    "coloanelor": "coloană",
    "coloano": "coloană",
    "colocatari": "colocatar",
    "colocatarii": "colocatar",
    "colocatarilor": "colocatar",
    "colocatarul": "colocatar",
    "colocatarule": "colocatar",
    "colocatarului": "colocatar",
    "colocvii": "colocviu",
    "colocviile": "colocviu",
    "colocviilor": "colocviu",
    "colocviul": "colocviu",
    "colocviule": "colocviu",
    "colocviului": "colocviu",
    "colodiul": "colodiu",
    "colodiule": "colodiu",
    "colodiului": "colodiu",
    "colofoniul": "colofoniu",
    "colofoniule": "colofoniu",
    "colofoniului": "colofoniu",
    "coloidala": "coloidal",
    "coloidală": "coloidal",
    "coloidale": "coloidal",
    "coloidalei": "coloidal",
    "coloidalele": "coloidal",
    "coloidalelor": "coloidal",
    "coloidali": "coloidal",
    "coloidalii": "coloidal",
    "coloidalilor": "coloidal",
    "coloidalo": "coloidal",
    "coloidalul": "coloidal",
    "coloidalule": "coloidal",
    "coloidalului": "coloidal",
    "coloni": "colon",
    "colonii": "colon",
    "colonilor": "colon",
    "colonul": "colon",
    "colonule": "colon",
    "colonului": "colon",
    "colonuri": "colon",
    "colonurile": "colon",
    "colonurilor": "colon",
    "colonada": "colonadă",
    "colonade": "colonadă",
    "colonadei": "colonadă",
    "colonadele": "colonadă",
    "colonadelor": "colonadă",
    "colonado": "colonadă",
    "col.": "colonel",
    "colonei": "colonel",
    "coloneii": "colonel",
    "coloneilor": "colonel",
    "colonelul": "colonel",
    "colonelule": "colonel",
    "colonelului": "colonel",
    "coloneleasa": "coloneleasă",
    "coloneleaso": "coloneleasă",
    "colonelese": "coloneleasă",
    "colonelesei": "coloneleasă",
    "colonelesele": "coloneleasă",
    "coloneleselor": "coloneleasă",
    "coloniala": "colonial",
    "colonială": "colonial",
    "coloniale": "colonial",
    "colonialei": "colonial",
    "colonialele": "colonial",
    "colonialelor": "colonial",
    "coloniali": "colonial",
    "colonialii": "colonial",
    "colonialilor": "colonial",
    "colonialo": "colonial",
    "colonialul": "colonial",
    "colonialule": "colonial",
    "colonialului": "colonial",
    "col.": "colonie",
    "colonia": "colonie",
    "coloniei": "colonie",
    "colonii": "colonie",
    "coloniile": "colonie",
    "coloniilor": "colonie",
    "colonio": "colonie",
    "coloniști": "colonist",
    "coloniștii": "colonist",
    "coloniștilor": "colonist",
    "colonistul": "colonist",
    "colonistule": "colonist",
    "colonistului": "colonist",
    "colonista": "colonistă",
    "coloniste": "colonistă",
    "colonistei": "colonistă",
    "colonistele": "colonistă",
    "colonistelor": "colonistă",
    "colonisto": "colonistă",
    "coloniză": "coloniza",
    "colonizai": "coloniza",
    "colonizam": "coloniza",
    "colonizăm": "coloniza",
    "colonizând": "coloniza",
    "colonizându": "coloniza",
    "colonizară": "coloniza",
    "colonizarăm": "coloniza",
    "colonizarăți": "coloniza",
    "colonizase": "coloniza",
    "colonizasem": "coloniza",
    "colonizaseră": "coloniza",
    "colonizaserăm": "coloniza",
    "colonizaserăți": "coloniza",
    "colonizaseși": "coloniza",
    "colonizași": "coloniza",
    "colonizat": "coloniza",
    "colonizați": "coloniza",
    "colonizatu": "coloniza",
    "colonizau": "coloniza",
    "colonizează": "coloniza",
    "colonizez": "coloniza",
    "colonizeze": "coloniza",
    "colonizezi": "coloniza",
    "necolonizând": "coloniza",
    "necolonizându": "coloniza",
    "nemaicolonizând": "coloniza",
    "nemaicolonizându": "coloniza",
    "colonizarea": "colonizare",
    "colonizareo": "colonizare",
    "colonizări": "colonizare",
    "colonizării": "colonizare",
    "colonizările": "colonizare",
    "colonizărilor": "colonizare",
    "colonizată": "colonizat",
    "colonizate": "colonizat",
    "colonizați": "colonizat",
    "colonizatoarea": "colonizatoare",
    "colonizatoarei": "colonizatoare",
    "colonizatoarele": "colonizatoare",
    "colonizatoarelor": "colonizatoare",
    "colonizatoareo": "colonizatoare",
    "colonizatoare": "colonizator",
    "colonizatoarea": "colonizator",
    "colonizatoarei": "colonizator",
    "colonizatoarele": "colonizator",
    "colonizatoarelor": "colonizator",
    "colonizatoareo": "colonizator",
    "colonizatori": "colonizator",
    "colonizatorii": "colonizator",
    "colonizatorilor": "colonizator",
    "colonizatorul": "colonizator",
    "colonizatorule": "colonizator",
    "colonizatorului": "colonizator",
    "colora": "color",
    "coloră": "color",
    "colore": "color",
    "colorei": "color",
    "colorele": "color",
    "colorelor": "color",
    "colori": "color",
    "colorii": "color",
    "colorilor": "color",
    "coloro": "color",
    "colorul": "color",
    "colorule": "color",
    "colorului": "color",
    "coloră": "colora",
    "colorai": "colora",
    "coloram": "colora",
    "colorăm": "colora",
    "colorând": "colora",
    "colorându": "colora",
    "colorară": "colora",
    "colorarăm": "colora",
    "colorarăți": "colora",
    "colorase": "colora",
    "colorasem": "colora",
    "coloraseră": "colora",
    "coloraserăm": "colora",
    "coloraserăți": "colora",
    "coloraseși": "colora",
    "colorași": "colora",
    "colorat": "colora",
    "colorați": "colora",
    "coloratu": "colora",
    "colorau": "colora",
    "colorează": "colora",
    "colorez": "colora",
    "coloreze": "colora",
    "colorezi": "colora",
    "necolorând": "colora",
    "necolorându": "colora",
    "nemaicolorând": "colora",
    "nemaicolorându": "colora",
    "colorarea": "colorare",
    "colorareo": "colorare",
    "colorări": "colorare",
    "colorării": "colorare",
    "colorările": "colorare",
    "colorărilor": "colorare",
    "colorata": "colorat",
    "colorată": "colorat",
    "colorate": "colorat",
    "coloratei": "colorat",
    "coloratele": "colorat",
    "coloratelor": "colorat",
    "colorați": "colorat",
    "colorații": "colorat",
    "coloraților": "colorat",
    "colorato": "colorat",
    "coloratul": "colorat",
    "coloratule": "colorat",
    "coloratului": "colorat",
    "coloratura": "coloratură",
    "coloraturi": "coloratură",
    "coloraturii": "coloratură",
    "coloraturile": "coloratură",
    "coloraturilor": "coloratură",
    "coloraturo": "coloratură",
    "colorimetre": "colorimetru",
    "colorimetrele": "colorimetru",
    "colorimetrelor": "colorimetru",
    "colorimetrul": "colorimetru",
    "colorimetrule": "colorimetru",
    "colorimetrului": "colorimetru",
    "coloriști": "colorist",
    "coloriștii": "colorist",
    "coloriștilor": "colorist",
    "coloristul": "colorist",
    "coloristule": "colorist",
    "coloristului": "colorist",
    "colorista": "coloristă",
    "coloriste": "coloristă",
    "coloristei": "coloristă",
    "coloristele": "coloristă",
    "coloristelor": "coloristă",
    "coloristo": "coloristă",
    "coloritul": "colorit",
    "coloritule": "colorit",
    "coloritului": "colorit",
    "colorituri": "colorit",
    "coloriturile": "colorit",
    "coloriturilor": "colorit",
    "coloși": "colos",
    "coloșii": "colos",
    "coloșilor": "colos",
    "colosul": "colos",
    "colosule": "colos",
    "colosului": "colos",
    "colosala": "colosal",
    "colosală": "colosal",
    "colosale": "colosal",
    "colosalei": "colosal",
    "colosalele": "colosal",
    "colosalelor": "colosal",
    "colosali": "colosal",
    "colosalii": "colosal",
    "colosalilor": "colosal",
    "colosalo": "colosal",
    "colosalul": "colosal",
    "colosalule": "colosal",
    "colosalului": "colosal",
    "colportă": "colporta",
    "colportai": "colporta",
    "colportam": "colporta",
    "colportăm": "colporta",
    "colportând": "colporta",
    "colportându": "colporta",
    "colportară": "colporta",
    "colportarăm": "colporta",
    "colportarăți": "colporta",
    "colportase": "colporta",
    "colportasem": "colporta",
    "colportaseră": "colporta",
    "colportaserăm": "colporta",
    "colportaserăți": "colporta",
    "colportaseși": "colporta",
    "colportași": "colporta",
    "colportat": "colporta",
    "colportați": "colporta",
    "colportatu": "colporta",
    "colportau": "colporta",
    "colportează": "colporta",
    "colportez": "colporta",
    "colporteze": "colporta",
    "colportezi": "colporta",
    "necolportând": "colporta",
    "necolportându": "colporta",
    "nemaicolportând": "colporta",
    "nemaicolportându": "colporta",
    "colportaje": "colportaj",
    "colportajele": "colportaj",
    "colportajelor": "colportaj",
    "colportajul": "colportaj",
    "colportajule": "colportaj",
    "colportajului": "colportaj",
    "colportată": "colportat",
    "colportate": "colportat",
    "colportați": "colportat",
    "colportori": "colportor",
    "colportorii": "colportor",
    "colportorilor": "colportor",
    "colportorul": "colportor",
    "colportorule": "colportor",
    "colportorului": "colportor",
    "colți": "colț",
    "colții": "colț",
    "colților": "colț",
    "colțul": "colț",
    "colțule": "colț",
    "colțului": "colț",
    "colțuri": "colț",
    "colțurile": "colț",
    "colțurilor": "colț",
    "colțare": "colțar",
    "colțarele": "colțar",
    "colțarelor": "colțar",
    "colțari": "colțar",
    "colțarii": "colțar",
    "colțarilor": "colțar",
    "colțarul": "colțar",
    "colțarule": "colțar",
    "colțarului": "colțar",
    "colțata": "colțat",
    "colțată": "colțat",
    "colțate": "colțat",
    "colțatei": "colțat",
    "colțatele": "colțat",
    "colțatelor": "colțat",
    "colțați": "colțat",
    "colțații": "colțat",
    "colțaților": "colțat",
    "colțato": "colțat",
    "colțatul": "colțat",
    "colțatule": "colțat",
    "colțatului": "colțat",
    "colțoasa": "colțat",
    "colțoasă": "colțat",
    "colțoase": "colțat",
    "colțoasei": "colțat",
    "colțoasele": "colțat",
    "colțoaselor": "colțat",
    "colțoaso": "colțat",
    "colțos": "colțat",
    "colțoși": "colțat",
    "colțoșii": "colțat",
    "colțoșilor": "colțat",
    "colțosul": "colțat",
    "colțosule": "colțat",
    "colțosului": "colțat",
    "Colțeei": "Colțea",
    "colțișoare": "colțișor",
    "colțișoarele": "colțișor",
    "colțișoarelor": "colțișor",
    "colțișorul": "colțișor",
    "colțișorule": "colțișor",
    "colțișorului": "colțișor",
    "coltuce": "coltuc",
    "coltucele": "coltuc",
    "coltucelor": "coltuc",
    "coltucul": "coltuc",
    "coltucule": "coltuc",
    "coltucului": "coltuc",
    "coltucele": "coltucel",
    "coltucelele": "coltucel",
    "coltucelelor": "coltucel",
    "coltucelul": "coltucel",
    "coltucelule": "coltucel",
    "coltucelului": "coltucel",
    "colții-babei": "colțul-babei",
    "colțulețe": "colțuleț",
    "colțulețele": "colțuleț",
    "colțulețelor": "colțuleț",
    "colțulețul": "colțuleț",
    "colțulețule": "colțuleț",
    "colțulețului": "colțuleț",
    "colțuni": "colțun",
    "colțunii": "colțun",
    "colțunilor": "colțun",
    "colțunul": "colțun",
    "colțunule": "colțun",
    "colțunului": "colțun",
    "colțunași": "colțunaș",
    "colțunașii": "colțunaș",
    "colțunașilor": "colțunaș",
    "colțunașul": "colțunaș",
    "colțunașule": "colțunaș",
    "colțunașului": "colțunaș",
    "colțunii-popii": "colțunul-popii",
    "colțurata": "colțurat",
    "colțurată": "colțurat",
    "colțurate": "colțurat",
    "colțuratei": "colțurat",
    "colțuratele": "colțurat",
    "colțuratelor": "colțurat",
    "colțurați": "colțurat",
    "colțurații": "colțurat",
    "colțuraților": "colțurat",
    "colțurato": "colțurat",
    "colțuratul": "colțurat",
    "colțuratule": "colțurat",
    "colțuratului": "colțurat",
    "colțuroasa": "colțuros",
    "colțuroasă": "colțuros",
    "colțuroase": "colțuros",
    "colțuroasei": "colțuros",
    "colțuroasele": "colțuros",
    "colțuroaselor": "colțuros",
    "colțuroaso": "colțuros",
    "colțuroși": "colțuros",
    "colțuroșii": "colțuros",
    "colțuroșilor": "colțuros",
    "colțurosul": "colțuros",
    "colțurosule": "colțuros",
    "colțurosului": "colțuros",
    "columba": "columbă",
    "columbe": "columbă",
    "columbei": "columbă",
    "columbele": "columbă",
    "columbelor": "columbă",
    "columbo": "columbă",
    "columbare": "columbar",
    "columbarele": "columbar",
    "columbarelor": "columbar",
    "columbarul": "columbar",
    "columbarule": "columbar",
    "columbarului": "columbar",
    "Columbie": "Columbia",
    "Columbiei": "Columbia",
    "Columbii": "Columbia",
    "columna": "columnă",
    "columne": "columnă",
    "columnei": "columnă",
    "columnele": "columnă",
    "columnelor": "columnă",
    "columno": "columnă",
    "coma": "comă",
    "come": "comă",
    "comei": "comă",
    "comele": "comă",
    "comelor": "comă",
    "como": "comă",
    "comănace": "comănac",
    "comănacele": "comănac",
    "comănacelor": "comănac",
    "comănaci": "comănac",
    "comănacii": "comănac",
    "comănacilor": "comănac",
    "comănacul": "comănac",
    "comănacule": "comănac",
    "comănacului": "comănac",
    "comand": "comanda",
    "comandă": "comanda",
    "comandai": "comanda",
    "comandam": "comanda",
    "comandăm": "comanda",
    "comandând": "comanda",
    "comandându": "comanda",
    "comandară": "comanda",
    "comandarăm": "comanda",
    "comandarăți": "comanda",
    "comandase": "comanda",
    "comandasem": "comanda",
    "comandaseră": "comanda",
    "comandaserăm": "comanda",
    "comandaserăți": "comanda",
    "comandaseși": "comanda",
    "comandași": "comanda",
    "comandat": "comanda",
    "comandați": "comanda",
    "comandatu": "comanda",
    "comandau": "comanda",
    "comande": "comanda",
    "comanzi": "comanda",
    "necomandând": "comanda",
    "necomandându": "comanda",
    "nemaicomandând": "comanda",
    "nemaicomandându": "comanda",
    "comanda": "comandă",
    "comando": "comandă",
    "comenzi": "comandă",
    "comenzii": "comandă",
    "comenzile": "comandă",
    "comenzilor": "comandă",
    "comandamente": "comandament",
    "comandamentele": "comandament",
    "comandamentelor": "comandament",
    "comandamentul": "comandament",
    "comandamentule": "comandament",
    "comandamentului": "comandament",
    "Cdt.": "comandant",
    "comandanți": "comandant",
    "comandanții": "comandant",
    "comandanților": "comandant",
    "comandantul": "comandant",
    "comandantule": "comandant",
    "comandantului": "comandant",
    "comandanta": "comandantă",
    "comandante": "comandantă",
    "comandantei": "comandantă",
    "comandantele": "comandantă",
    "comandantelor": "comandantă",
    "comandanto": "comandantă",
    "comandarea": "comandare",
    "comandareo": "comandare",
    "comandări": "comandare",
    "comandării": "comandare",
    "comandările": "comandare",
    "comandărilor": "comandare",
    "comandată": "comandat",
    "comandate": "comandat",
    "comandați": "comandat",
    "comandatura": "comandatură",
    "comandaturi": "comandatură",
    "comandaturii": "comandatură",
    "comandaturile": "comandatură",
    "comandaturilor": "comandatură",
    "comandaturo": "comandatură",
    "comandită": "comandita",
    "comanditai": "comandita",
    "comanditam": "comandita",
    "comandităm": "comandita",
    "comanditând": "comandita",
    "comanditându": "comandita",
    "comanditară": "comandita",
    "comanditarăm": "comandita",
    "comanditarăți": "comandita",
    "comanditase": "comandita",
    "comanditasem": "comandita",
    "comanditaseră": "comandita",
    "comanditaserăm": "comandita",
    "comanditaserăți": "comandita",
    "comanditaseși": "comandita",
    "comanditași": "comandita",
    "comanditat": "comandita",
    "comanditați": "comandita",
    "comanditatu": "comandita",
    "comanditau": "comandita",
    "comanditează": "comandita",
    "comanditez": "comandita",
    "comanditeze": "comandita",
    "comanditezi": "comandita",
    "necomanditând": "comandita",
    "necomanditându": "comandita",
    "nemaicomanditând": "comandita",
    "nemaicomanditându": "comandita",
    "comandita": "comandită",
    "comandite": "comandită",
    "comanditei": "comandită",
    "comanditele": "comandită",
    "comanditelor": "comandită",
    "comandito": "comandită",
    "comanditari": "comanditar",
    "comanditarii": "comanditar",
    "comanditarilor": "comanditar",
    "comanditarul": "comanditar",
    "comanditarule": "comanditar",
    "comanditarului": "comanditar",
    "comanditara": "comanditară",
    "comanditare": "comanditară",
    "comanditarei": "comanditară",
    "comanditarele": "comanditară",
    "comanditarelor": "comanditară",
    "comanditaro": "comanditară",
    "comanditată": "comanditat",
    "comanditate": "comanditat",
    "comanditați": "comanditat",
    "comanditații": "comanditat",
    "comanditaților": "comanditat",
    "comanditatul": "comanditat",
    "comanditatule": "comanditat",
    "comanditatului": "comanditat",
    "comanditata": "comanditată",
    "comanditate": "comanditată",
    "comanditatei": "comanditată",
    "comanditatele": "comanditată",
    "comanditatelor": "comanditată",
    "comanditato": "comanditată",
    "comandori": "comandor",
    "comandorii": "comandor",
    "comandorilor": "comandor",
    "comandorul": "comandor",
    "comandorule": "comandor",
    "comandorului": "comandor",
    "comarnice": "comarnic",
    "comarnicele": "comarnic",
    "comarnicelor": "comarnic",
    "comarnicul": "comarnic",
    "comarnicule": "comarnic",
    "comarnicului": "comarnic",
    "comasă": "comasa",
    "comasai": "comasa",
    "comasam": "comasa",
    "comasăm": "comasa",
    "comasând": "comasa",
    "comasându": "comasa",
    "comasară": "comasa",
    "comasarăm": "comasa",
    "comasarăți": "comasa",
    "comasase": "comasa",
    "comasasem": "comasa",
    "comasaseră": "comasa",
    "comasaserăm": "comasa",
    "comasaserăți": "comasa",
    "comasaseși": "comasa",
    "comasași": "comasa",
    "comasat": "comasa",
    "comasați": "comasa",
    "comasatu": "comasa",
    "comasau": "comasa",
    "comasează": "comasa",
    "comasez": "comasa",
    "comaseze": "comasa",
    "comasezi": "comasa",
    "necomasând": "comasa",
    "necomasându": "comasa",
    "nemaicomasând": "comasa",
    "nemaicomasându": "comasa",
    "comasarea": "comasare",
    "comasareo": "comasare",
    "comasări": "comasare",
    "comasării": "comasare",
    "comasările": "comasare",
    "comasărilor": "comasare",
    "comasată": "comasat",
    "comasate": "comasat",
    "comasați": "comasat",
    "combatanți": "combatant",
    "combatanții": "combatant",
    "combatanților": "combatant",
    "combatantul": "combatant",
    "combatantule": "combatant",
    "combatantului": "combatant",
    "combat": "combate",
    "combată": "combate",
    "combătând": "combate",
    "combătându": "combate",
    "combătea": "combate",
    "combăteai": "combate",
    "combăteam": "combate",
    "combăteați": "combate",
    "combăteau": "combate",
    "combatem": "combate",
    "combateți": "combate",
    "combați": "combate",
    "combătu": "combate",
    "combătui": "combate",
    "combătură": "combate",
    "combăturăm": "combate",
    "combăturăți": "combate",
    "combătuse": "combate",
    "combătusem": "combate",
    "combătuseră": "combate",
    "combătuserăm": "combate",
    "combătuserăți": "combate",
    "combătuseși": "combate",
    "combătuși": "combate",
    "combătut": "combate",
    "combătutu": "combate",
    "necombătând": "combate",
    "necombătându": "combate",
    "nemaicombătând": "combate",
    "nemaicombătându": "combate",
    "combaterea": "combatere",
    "combatereo": "combatere",
    "combateri": "combatere",
    "combaterii": "combatere",
    "combaterile": "combatere",
    "combaterilor": "combatere",
    "combativa": "combativ",
    "combativă": "combativ",
    "combative": "combativ",
    "combativei": "combativ",
    "combativele": "combativ",
    "combativelor": "combativ",
    "combativi": "combativ",
    "combativii": "combativ",
    "combativilor": "combativ",
    "combativo": "combativ",
    "combativul": "combativ",
    "combativule": "combativ",
    "combativului": "combativ",
    "combătută": "combătut",
    "combătute": "combătut",
    "combătuți": "combătut",
    "combin": "combina",
    "combină": "combina",
    "combinai": "combina",
    "combinam": "combina",
    "combinăm": "combina",
    "combinând": "combina",
    "combinându": "combina",
    "combinară": "combina",
    "combinarăm": "combina",
    "combinarăți": "combina",
    "combinase": "combina",
    "combinasem": "combina",
    "combinaseră": "combina",
    "combinaserăm": "combina",
    "combinaserăți": "combina",
    "combinaseși": "combina",
    "combinași": "combina",
    "combinat": "combina",
    "combinați": "combina",
    "combinatu": "combina",
    "combinau": "combina",
    "combine": "combina",
    "combini": "combina",
    "necombinând": "combina",
    "necombinându": "combina",
    "nemaicombinând": "combina",
    "nemaicombinându": "combina",
    "combina": "combină",
    "combine": "combină",
    "combinei": "combină",
    "combinele": "combină",
    "combinelor": "combină",
    "combino": "combină",
    "combinarea": "combinare",
    "combinareo": "combinare",
    "combinări": "combinare",
    "combinării": "combinare",
    "combinările": "combinare",
    "combinărilor": "combinare",
    "Comb.": "combinat",
    "combinată": "combinat",
    "combinate": "combinat",
    "combinatele": "combinat",
    "combinatelor": "combinat",
    "combinați": "combinat",
    "combinatul": "combinat",
    "combinatule": "combinat",
    "combinatului": "combinat",
    "combinația": "combinație",
    "combinației": "combinație",
    "combinații": "combinație",
    "combinațiile": "combinație",
    "combinațiilor": "combinație",
    "combinațio": "combinație",
    "combinezoane": "combinezon",
    "combinezoanele": "combinezon",
    "combinezoanelor": "combinezon",
    "combinezonul": "combinezon",
    "combinezonule": "combinezon",
    "combinezonului": "combinezon",
    "combustibili": "combustibil",
    "combustibilii": "combustibil",
    "combustibililor": "combustibil",
    "combustibilul": "combustibil",
    "combustibilule": "combustibil",
    "combustibilului": "combustibil",
    "combustia": "combustie",
    "combustiei": "combustie",
    "combustii": "combustie",
    "combustiile": "combustie",
    "combustiilor": "combustie",
    "combustio": "combustie",
    "comcerealuri": "comcereal",
    "comedianți": "comediant",
    "comedianții": "comediant",
    "comedianților": "comediant",
    "comediantul": "comediant",
    "comediantule": "comediant",
    "comediantului": "comediant",
    "comedianta": "comediantă",
    "comediante": "comediantă",
    "comediantei": "comediantă",
    "comediantele": "comediantă",
    "comediantelor": "comediantă",
    "comedianto": "comediantă",
    "comedia": "comedie",
    "comediei": "comedie",
    "comedii": "comedie",
    "comediile": "comedie",
    "comediilor": "comedie",
    "comedio": "comedie",
    "comedioara": "comedioară",
    "comedioare": "comedioară",
    "comedioarei": "comedioară",
    "comedioarele": "comedioară",
    "comedioarelor": "comedioară",
    "comedioaro": "comedioară",
    "comemoră": "comemora",
    "comemorai": "comemora",
    "comemoram": "comemora",
    "comemorăm": "comemora",
    "comemorând": "comemora",
    "comemorându": "comemora",
    "comemorară": "comemora",
    "comemorarăm": "comemora",
    "comemorarăți": "comemora",
    "comemorase": "comemora",
    "comemorasem": "comemora",
    "comemoraseră": "comemora",
    "comemoraserăm": "comemora",
    "comemoraserăți": "comemora",
    "comemoraseși": "comemora",
    "comemorași": "comemora",
    "comemorat": "comemora",
    "comemorați": "comemora",
    "comemoratu": "comemora",
    "comemorau": "comemora",
    "comemorează": "comemora",
    "comemorez": "comemora",
    "comemoreze": "comemora",
    "comemorezi": "comemora",
    "necomemorând": "comemora",
    "necomemorându": "comemora",
    "nemaicomemorând": "comemora",
    "nemaicomemorându": "comemora",
    "comemorabila": "comemorabil",
    "comemorabilă": "comemorabil",
    "comemorabile": "comemorabil",
    "comemorabilei": "comemorabil",
    "comemorabilele": "comemorabil",
    "comemorabilelor": "comemorabil",
    "comemorabili": "comemorabil",
    "comemorabilii": "comemorabil",
    "comemorabililor": "comemorabil",
    "comemorabilo": "comemorabil",
    "comemorabilul": "comemorabil",
    "comemorabilule": "comemorabil",
    "comemorabilului": "comemorabil",
    "comemorarea": "comemorare",
    "comemorareo": "comemorare",
    "comemorări": "comemorare",
    "comemorării": "comemorare",
    "comemorările": "comemorare",
    "comemorărilor": "comemorare",
    "comemorată": "comemorat",
    "comemorate": "comemorat",
    "comemorați": "comemorat",
    "comemorativa": "comemorativ",
    "comemorativă": "comemorativ",
    "comemorative": "comemorativ",
    "comemorativei": "comemorativ",
    "comemorativele": "comemorativ",
    "comemorativelor": "comemorativ",
    "comemorativi": "comemorativ",
    "comemorativii": "comemorativ",
    "comemorativilor": "comemorativ",
    "comemorativo": "comemorativ",
    "comemorativul": "comemorativ",
    "comemorativule": "comemorativ",
    "comemorativului": "comemorativ",
    "comenduirea": "comenduire",
    "comenduireo": "comenduire",
    "comenduiri": "comenduire",
    "comenduirii": "comenduire",
    "comenduirile": "comenduire",
    "comenduirilor": "comenduire",
    "comensurabila": "comensurabil",
    "comensurabilă": "comensurabil",
    "comensurabile": "comensurabil",
    "comensurabilei": "comensurabil",
    "comensurabilele": "comensurabil",
    "comensurabilelor": "comensurabil",
    "comensurabili": "comensurabil",
    "comensurabilii": "comensurabil",
    "comensurabililor": "comensurabil",
    "comensurabilo": "comensurabil",
    "comensurabilul": "comensurabil",
    "comensurabilule": "comensurabil",
    "comensurabilului": "comensurabil",
    "comentă": "comenta",
    "comentai": "comenta",
    "comentam": "comenta",
    "comentăm": "comenta",
    "comentând": "comenta",
    "comentându": "comenta",
    "comentară": "comenta",
    "comentarăm": "comenta",
    "comentarăți": "comenta",
    "comentase": "comenta",
    "comentasem": "comenta",
    "comentaseră": "comenta",
    "comentaserăm": "comenta",
    "comentaserăți": "comenta",
    "comentaseși": "comenta",
    "comentași": "comenta",
    "comentat": "comenta",
    "comentați": "comenta",
    "comentatu": "comenta",
    "comentau": "comenta",
    "comentează": "comenta",
    "comentez": "comenta",
    "comenteze": "comenta",
    "comentezi": "comenta",
    "necomentând": "comenta",
    "necomentându": "comenta",
    "nemaicomentând": "comenta",
    "nemaicomentându": "comenta",
    "comentarea": "comentare",
    "comentareo": "comentare",
    "comentări": "comentare",
    "comentării": "comentare",
    "comentările": "comentare",
    "comentărilor": "comentare",
    "comentarii": "comentariu",
    "comentariile": "comentariu",
    "comentariilor": "comentariu",
    "comentariul": "comentariu",
    "comentariule": "comentariu",
    "comentariului": "comentariu",
    "comentată": "comentat",
    "comentate": "comentat",
    "comentați": "comentat",
    "comentatoarea": "comentatoare",
    "comentatoarei": "comentatoare",
    "comentatoarele": "comentatoare",
    "comentatoarelor": "comentatoare",
    "comentatoareo": "comentatoare",
    "comentatori": "comentator",
    "comentatorii": "comentator",
    "comentatorilor": "comentator",
    "comentatorul": "comentator",
    "comentatorule": "comentator",
    "comentatorului": "comentator",
    "comerc.": "comercial",
    "comerciala": "comercial",
    "comercială": "comercial",
    "comerciale": "comercial",
    "comercialei": "comercial",
    "comercialele": "comercial",
    "comercialelor": "comercial",
    "comerciali": "comercial",
    "comercialii": "comercial",
    "comercialilor": "comercial",
    "comercialo": "comercial",
    "comercialul": "comercial",
    "comercialule": "comercial",
    "comercialului": "comercial",
    "comercializă": "comercializa",
    "comercializai": "comercializa",
    "comercializam": "comercializa",
    "comercializăm": "comercializa",
    "comercializând": "comercializa",
    "comercializându": "comercializa",
    "comercializară": "comercializa",
    "comercializarăm": "comercializa",
    "comercializarăți": "comercializa",
    "comercializase": "comercializa",
    "comercializasem": "comercializa",
    "comercializaseră": "comercializa",
    "comercializaserăm": "comercializa",
    "comercializaserăți": "comercializa",
    "comercializaseși": "comercializa",
    "comercializași": "comercializa",
    "comercializat": "comercializa",
    "comercializați": "comercializa",
    "comercializatu": "comercializa",
    "comercializau": "comercializa",
    "comercializează": "comercializa",
    "comercializez": "comercializa",
    "comercializeze": "comercializa",
    "comercializezi": "comercializa",
    "necomercializând": "comercializa",
    "necomercializându": "comercializa",
    "nemaicomercializând": "comercializa",
    "nemaicomercializându": "comercializa",
    "comercializarea": "comercializare",
    "comercializareo": "comercializare",
    "comercializări": "comercializare",
    "comercializării": "comercializare",
    "comercializările": "comercializare",
    "comercializărilor": "comercializare",
    "comercializată": "comercializat",
    "comercializate": "comercializat",
    "comercializați": "comercializat",
    "comercianți": "comerciant",
    "comercianții": "comerciant",
    "comercianților": "comerciant",
    "comerciantul": "comerciant",
    "comerciantule": "comerciant",
    "comerciantului": "comerciant",
    "comercianta": "comerciantă",
    "comerciante": "comerciantă",
    "comerciantei": "comerciantă",
    "comerciantele": "comerciantă",
    "comerciantelor": "comerciantă",
    "comercianto": "comerciantă",
    "comerțul": "comerț",
    "comerțule": "comerț",
    "comerțului": "comerț",
    "comerțuri": "comerț",
    "comerțurile": "comerț",
    "comerțurilor": "comerț",
    "comeseanul": "comesean",
    "comeseanule": "comesean",
    "comeseanului": "comesean",
    "comeseni": "comesean",
    "comesenii": "comesean",
    "comesenilor": "comesean",
    "comeseana": "comeseană",
    "comeseano": "comeseană",
    "comesene": "comeseană",
    "comesenei": "comeseană",
    "comesenele": "comeseană",
    "comesenelor": "comeseană",
    "comestibila": "comestibil",
    "comestibilă": "comestibil",
    "comestibile": "comestibil",
    "comestibilei": "comestibil",
    "comestibilele": "comestibil",
    "comestibilelor": "comestibil",
    "comestibili": "comestibil",
    "comestibilii": "comestibil",
    "comestibililor": "comestibil",
    "comestibilo": "comestibil",
    "comestibilul": "comestibil",
    "comestibilule": "comestibil",
    "comestibilului": "comestibil",
    "cometa": "cometă",
    "comete": "cometă",
    "cometei": "cometă",
    "cometele": "cometă",
    "cometelor": "cometă",
    "cometo": "cometă",
    "comica": "comic",
    "comică": "comic",
    "comice": "comic",
    "comicei": "comic",
    "comicele": "comic",
    "comicelor": "comic",
    "comici": "comic",
    "comicii": "comic",
    "comicilor": "comic",
    "comico": "comic",
    "comicul": "comic",
    "comicule": "comic",
    "comicului": "comic",
    "comicăria": "comicărie",
    "comicăriei": "comicărie",
    "comicării": "comicărie",
    "comicăriile": "comicărie",
    "comicăriilor": "comicărie",
    "comina": "comină",
    "comine": "comină",
    "cominei": "comină",
    "cominele": "comină",
    "cominelor": "comină",
    "comino": "comină",
    "cominatoria": "cominatoriu",
    "cominatorie": "cominatoriu",
    "cominatoriei": "cominatoriu",
    "cominatorii": "cominatoriu",
    "cominatoriii": "cominatoriu",
    "cominatoriile": "cominatoriu",
    "cominatoriilor": "cominatoriu",
    "cominatorio": "cominatoriu",
    "cominatoriul": "cominatoriu",
    "cominatoriule": "cominatoriu",
    "cominatoriului": "cominatoriu",
    "comisă": "comis",
    "comise": "comis",
    "comiși": "comis",
    "comișii": "comis",
    "comișilor": "comis",
    "comisul": "comis",
    "comisule": "comis",
    "comisului": "comis",
    "comisari": "comisar",
    "comisarii": "comisar",
    "comisarilor": "comisar",
    "comisarul": "comisar",
    "comisarule": "comisar",
    "comisarului": "comisar",
    "comisariate": "comisariat",
    "comisariatele": "comisariat",
    "comisariatelor": "comisariat",
    "comisariatul": "comisariat",
    "comisariatule": "comisariat",
    "comisariatului": "comisariat",
    "comișei": "comișel",
    "comișeii": "comișel",
    "comișeilor": "comișel",
    "comișelul": "comișel",
    "comișelule": "comișel",
    "comișelului": "comișel",
    "C.N.E.A.A.": "Comisia_Națională_de_Evaluare_și_Acreditare_Academică",
    "comisia": "comisie",
    "comisiei": "comisie",
    "comisii": "comisie",
    "comisiile": "comisie",
    "comisiilor": "comisie",
    "comisio": "comisie",
    "comisioane": "comision",
    "comisioanele": "comision",
    "comisioanelor": "comision",
    "comisionul": "comision",
    "comisionule": "comision",
    "comisionului": "comision",
    "comisionari": "comisionar",
    "comisionarii": "comisionar",
    "comisionarilor": "comisionar",
    "comisionarul": "comisionar",
    "comisionarule": "comisionar",
    "comisionarului": "comisionar",
    "comisura": "comisură",
    "comisuri": "comisură",
    "comisurii": "comisură",
    "comisurile": "comisură",
    "comisurilor": "comisură",
    "comis-voiajori": "comis-voiajor",
    "comis-voiajorilor": "comis-voiajor",
    "comis-voiajorul": "comis-voiajor",
    "comis-voiajorului": "comis-voiajor",
    "comitate": "comitat",
    "comitatele": "comitat",
    "comitatelor": "comitat",
    "comitatul": "comitat",
    "comitatule": "comitat",
    "comitatului": "comitat",
    "comis": "comite",
    "comise": "comite",
    "comisei": "comite",
    "comiseră": "comite",
    "comiserăm": "comite",
    "comiserăți": "comite",
    "comisese": "comite",
    "comisesem": "comite",
    "comiseseră": "comite",
    "comiseserăm": "comite",
    "comiseserăți": "comite",
    "comiseseși": "comite",
    "comiseși": "comite",
    "comisu": "comite",
    "comit": "comite",
    "comită": "comite",
    "comițând": "comite",
    "comițându": "comite",
    "comitea": "comite",
    "comiteai": "comite",
    "comiteam": "comite",
    "comiteați": "comite",
    "comiteau": "comite",
    "comitele": "comite",
    "comitelui": "comite",
    "comitem": "comite",
    "comiteți": "comite",
    "comiți": "comite",
    "comiții": "comite",
    "comiților": "comite",
    "necomițând": "comite",
    "necomițându": "comite",
    "nemaicomițând": "comite",
    "nemaicomițându": "comite",
    "comitenți": "comitent",
    "comitenții": "comitent",
    "comitenților": "comitent",
    "comitentul": "comitent",
    "comitentule": "comitent",
    "comitentului": "comitent",
    "comiterea": "comitere",
    "comiteri": "comitere",
    "comiterii": "comitere",
    "comiterile": "comitere",
    "comiterilor": "comitere",
    "comitete": "comitet",
    "comitetele": "comitet",
    "comitetelor": "comitet",
    "comitetul": "comitet",
    "comitetule": "comitet",
    "comitetului": "comitet",
    "C.C.": "Comitetul_Central",
    "C.C.P.C.R.": "Comitetul_Central_al_Partidului_Comunist_Român",
    "comițiala": "comițial",
    "comițială": "comițial",
    "comițiale": "comițial",
    "comițialei": "comițial",
    "comițialele": "comițial",
    "comițialelor": "comițial",
    "comițiali": "comițial",
    "comițialii": "comițial",
    "comițialilor": "comițial",
    "comițialo": "comițial",
    "comițialul": "comițial",
    "comițialule": "comițial",
    "comițialului": "comițial",
    "comițiile": "comiții",
    "comițiilor": "comiții",
    "comoara": "comoară",
    "comoaro": "comoară",
    "comori": "comoară",
    "comorii": "comoară",
    "comorile": "comoară",
    "comorilor": "comoară",
    "comoda": "comod",
    "comodă": "comod",
    "comode": "comod",
    "comodei": "comod",
    "comodele": "comod",
    "comodelor": "comod",
    "comodo": "comod",
    "comodul": "comod",
    "comodule": "comod",
    "comodului": "comod",
    "comozi": "comod",
    "comozii": "comod",
    "comozilor": "comod",
    "comoda": "comodă",
    "comode": "comodă",
    "comodei": "comodă",
    "comodele": "comodă",
    "comodelor": "comodă",
    "comodo": "comodă",
    "comoditatea": "comoditate",
    "comoditateo": "comoditate",
    "comodități": "comoditate",
    "comodității": "comoditate",
    "comoditățile": "comoditate",
    "comodităților": "comoditate",
    "comoția": "comoție",
    "comoției": "comoție",
    "comoții": "comoție",
    "comoțiile": "comoție",
    "comoțiilor": "comoție",
    "comoțio": "comoție",
    "compacta": "compact",
    "compactă": "compact",
    "compacte": "compact",
    "compactei": "compact",
    "compactele": "compact",
    "compactelor": "compact",
    "compacți": "compact",
    "compacții": "compact",
    "compacților": "compact",
    "compacto": "compact",
    "compactul": "compact",
    "compactule": "compact",
    "compactului": "compact",
    "compactă": "compacta",
    "compactai": "compacta",
    "compactam": "compacta",
    "compactăm": "compacta",
    "compactând": "compacta",
    "compactându": "compacta",
    "compactară": "compacta",
    "compactarăm": "compacta",
    "compactarăți": "compacta",
    "compactase": "compacta",
    "compactasem": "compacta",
    "compactaseră": "compacta",
    "compactaserăm": "compacta",
    "compactaserăți": "compacta",
    "compactaseși": "compacta",
    "compactași": "compacta",
    "compactat": "compacta",
    "compactați": "compacta",
    "compactatu": "compacta",
    "compactau": "compacta",
    "compactează": "compacta",
    "compactez": "compacta",
    "compacteze": "compacta",
    "compactezi": "compacta",
    "necompactând": "compacta",
    "necompactându": "compacta",
    "nemaicompactând": "compacta",
    "nemaicompactându": "compacta",
    "compactată": "compactat",
    "compactate": "compactat",
    "compactați": "compactat",
    "Co.": "Companie",
    "Comp.": "Companie",
    "compania": "companie",
    "companiei": "companie",
    "companii": "companie",
    "companiile": "companie",
    "companiilor": "companie",
    "companio": "companie",
    "companioana": "companioană",
    "companioane": "companioană",
    "companioanei": "companioană",
    "companioanele": "companioană",
    "companioanelor": "companioană",
    "companioano": "companioană",
    "companioni": "companion",
    "companionii": "companion",
    "companionilor": "companion",
    "companionul": "companion",
    "companionule": "companion",
    "companionului": "companion",
    "Co.": "Company",
    "compar": "compara",
    "compară": "compara",
    "comparai": "compara",
    "comparam": "compara",
    "comparăm": "compara",
    "comparând": "compara",
    "comparându": "compara",
    "comparară": "compara",
    "compararăm": "compara",
    "compararăți": "compara",
    "comparase": "compara",
    "comparasem": "compara",
    "comparaseră": "compara",
    "comparaserăm": "compara",
    "comparaserăți": "compara",
    "comparaseși": "compara",
    "comparași": "compara",
    "comparat": "compara",
    "comparați": "compara",
    "comparatu": "compara",
    "comparau": "compara",
    "compare": "compara",
    "compari": "compara",
    "necomparând": "compara",
    "necomparându": "compara",
    "nemaicomparând": "compara",
    "nemaicomparându": "compara",
    "comparabila": "comparabil",
    "comparabilă": "comparabil",
    "comparabile": "comparabil",
    "comparabilei": "comparabil",
    "comparabilele": "comparabil",
    "comparabilelor": "comparabil",
    "comparabili": "comparabil",
    "comparabilii": "comparabil",
    "comparabililor": "comparabil",
    "comparabilo": "comparabil",
    "comparabilul": "comparabil",
    "comparabilule": "comparabil",
    "comparabilului": "comparabil",
    "compararea": "comparare",
    "comparareo": "comparare",
    "comparări": "comparare",
    "comparării": "comparare",
    "comparările": "comparare",
    "comparărilor": "comparare",
    "comparata": "comparat",
    "comparată": "comparat",
    "comparate": "comparat",
    "comparatei": "comparat",
    "comparatele": "comparat",
    "comparatelor": "comparat",
    "comparați": "comparat",
    "comparații": "comparat",
    "comparaților": "comparat",
    "comparato": "comparat",
    "comparatul": "comparat",
    "comparatule": "comparat",
    "comparatului": "comparat",
    "comparația": "comparație",
    "comparației": "comparație",
    "comparații": "comparație",
    "comparațiile": "comparație",
    "comparațiilor": "comparație",
    "comparațio": "comparație",
    "comparativa": "comparativ",
    "comparativă": "comparativ",
    "comparative": "comparativ",
    "comparativei": "comparativ",
    "comparativele": "comparativ",
    "comparativelor": "comparativ",
    "comparativi": "comparativ",
    "comparativii": "comparativ",
    "comparativilor": "comparativ",
    "comparativo": "comparativ",
    "comparativul": "comparativ",
    "comparativule": "comparativ",
    "comparativului": "comparativ",
    "comparatoare": "comparator",
    "comparatoarele": "comparator",
    "comparatoarelor": "comparator",
    "comparatorul": "comparator",
    "comparatorule": "comparator",
    "comparatorului": "comparator",
    "compar": "compărea",
    "compară": "compărea",
    "compărând": "compărea",
    "compărându": "compărea",
    "compare": "compărea",
    "compăreai": "compărea",
    "compăream": "compărea",
    "compăreați": "compărea",
    "compăreau": "compărea",
    "compărem": "compărea",
    "compăreți": "compărea",
    "compari": "compărea",
    "compăru": "compărea",
    "compărui": "compărea",
    "compărură": "compărea",
    "compărurăm": "compărea",
    "compărurăți": "compărea",
    "compăruse": "compărea",
    "compărusem": "compărea",
    "compăruseră": "compărea",
    "compăruserăm": "compărea",
    "compăruserăți": "compărea",
    "compăruseși": "compărea",
    "compăruși": "compărea",
    "compărut": "compărea",
    "compărutu": "compărea",
    "necompărând": "compărea",
    "necompărându": "compărea",
    "nemaicompărând": "compărea",
    "nemaicompărându": "compărea",
    "compartimente": "compartiment",
    "compartimentele": "compartiment",
    "compartimentelor": "compartiment",
    "compartimentul": "compartiment",
    "compartimentule": "compartiment",
    "compartimentului": "compartiment",
    "compartimentă": "compartimenta",
    "compartimentai": "compartimenta",
    "compartimentam": "compartimenta",
    "compartimentăm": "compartimenta",
    "compartimentând": "compartimenta",
    "compartimentându": "compartimenta",
    "compartimentară": "compartimenta",
    "compartimentarăm": "compartimenta",
    "compartimentarăți": "compartimenta",
    "compartimentase": "compartimenta",
    "compartimentasem": "compartimenta",
    "compartimentaseră": "compartimenta",
    "compartimentaserăm": "compartimenta",
    "compartimentaserăți": "compartimenta",
    "compartimentaseși": "compartimenta",
    "compartimentași": "compartimenta",
    "compartimentat": "compartimenta",
    "compartimentați": "compartimenta",
    "compartimentatu": "compartimenta",
    "compartimentau": "compartimenta",
    "compartimentează": "compartimenta",
    "compartimentez": "compartimenta",
    "compartimenteze": "compartimenta",
    "compartimentezi": "compartimenta",
    "necompartimentând": "compartimenta",
    "necompartimentându": "compartimenta",
    "nemaicompartimentând": "compartimenta",
    "nemaicompartimentându": "compartimenta",
    "compartimentata": "compartimentat",
    "compartimentată": "compartimentat",
    "compartimentate": "compartimentat",
    "compartimentatei": "compartimentat",
    "compartimentatele": "compartimentat",
    "compartimentatelor": "compartimentat",
    "compartimentați": "compartimentat",
    "compartimentații": "compartimentat",
    "compartimentaților": "compartimentat",
    "compartimentato": "compartimentat",
    "compartimentatul": "compartimentat",
    "compartimentatule": "compartimentat",
    "compartimentatului": "compartimentat",
    "compărută": "compărut",
    "compărute": "compărut",
    "compăruți": "compărut",
    "compasul": "compas",
    "compasule": "compas",
    "compasului": "compas",
    "compasuri": "compas",
    "compasurile": "compas",
    "compasurilor": "compas",
    "compasiunea": "compasiune",
    "compasiuneo": "compasiune",
    "compasiuni": "compasiune",
    "compasiunii": "compasiune",
    "compasiunile": "compasiune",
    "compasiunilor": "compasiune",
    "compatibila": "compatibil",
    "compatibilă": "compatibil",
    "compatibile": "compatibil",
    "compatibilei": "compatibil",
    "compatibilele": "compatibil",
    "compatibilelor": "compatibil",
    "compatibili": "compatibil",
    "compatibilii": "compatibil",
    "compatibililor": "compatibil",
    "compatibilo": "compatibil",
    "compatibilul": "compatibil",
    "compatibilule": "compatibil",
    "compatibilului": "compatibil",
    "compătimea": "compătimi",
    "compătimeai": "compătimi",
    "compătimeam": "compătimi",
    "compătimească": "compătimi",
    "compătimeați": "compătimi",
    "compătimeau": "compătimi",
    "compătimesc": "compătimi",
    "compătimește": "compătimi",
    "compătimești": "compătimi",
    "compătimii": "compătimi",
    "compătimim": "compătimi",
    "compătimind": "compătimi",
    "compătimindu": "compătimi",
    "compătimiră": "compătimi",
    "compătimirăm": "compătimi",
    "compătimirăți": "compătimi",
    "compătimise": "compătimi",
    "compătimisem": "compătimi",
    "compătimiseră": "compătimi",
    "compătimiserăm": "compătimi",
    "compătimiserăți": "compătimi",
    "compătimiseși": "compătimi",
    "compătimiși": "compătimi",
    "compătimit": "compătimi",
    "compătimiți": "compătimi",
    "compătimitu": "compătimi",
    "compătimirea": "compătimire",
    "compătimireo": "compătimire",
    "compătimiri": "compătimire",
    "compătimirii": "compătimire",
    "compătimirile": "compătimire",
    "compătimirilor": "compătimire",
    "compătimită": "compătimit",
    "compătimite": "compătimit",
    "compătimiți": "compătimit",
    "compatrioata": "compatrioată",
    "compatrioate": "compatrioată",
    "compatrioatei": "compatrioată",
    "compatrioatele": "compatrioată",
    "compatrioatelor": "compatrioată",
    "compatrioato": "compatrioată",
    "compatrioți": "compatriot",
    "compatrioții": "compatriot",
    "compatrioților": "compatriot",
    "compatriotul": "compatriot",
    "compatriotule": "compatriot",
    "compatriotului": "compatriot",
    "compendii": "compendiu",
    "compendiile": "compendiu",
    "compendiilor": "compendiu",
    "compendiul": "compendiu",
    "compendiule": "compendiu",
    "compendiului": "compendiu",
    "compensă": "compensa",
    "compensai": "compensa",
    "compensam": "compensa",
    "compensăm": "compensa",
    "compensând": "compensa",
    "compensându": "compensa",
    "compensară": "compensa",
    "compensarăm": "compensa",
    "compensarăți": "compensa",
    "compensase": "compensa",
    "compensasem": "compensa",
    "compensaseră": "compensa",
    "compensaserăm": "compensa",
    "compensaserăți": "compensa",
    "compensaseși": "compensa",
    "compensași": "compensa",
    "compensat": "compensa",
    "compensați": "compensa",
    "compensatu": "compensa",
    "compensau": "compensa",
    "compensează": "compensa",
    "compensez": "compensa",
    "compenseze": "compensa",
    "compensezi": "compensa",
    "necompensând": "compensa",
    "necompensându": "compensa",
    "nemaicompensând": "compensa",
    "nemaicompensându": "compensa",
    "compensabila": "compensabil",
    "compensabilă": "compensabil",
    "compensabile": "compensabil",
    "compensabilei": "compensabil",
    "compensabilele": "compensabil",
    "compensabilelor": "compensabil",
    "compensabili": "compensabil",
    "compensabilii": "compensabil",
    "compensabililor": "compensabil",
    "compensabilo": "compensabil",
    "compensabilul": "compensabil",
    "compensabilule": "compensabil",
    "compensabilului": "compensabil",
    "compensarea": "compensare",
    "compensareo": "compensare",
    "compensări": "compensare",
    "compensării": "compensare",
    "compensările": "compensare",
    "compensărilor": "compensare",
    "compensată": "compensat",
    "compensate": "compensat",
    "compensați": "compensat",
    "compensația": "compensație",
    "compensației": "compensație",
    "compensații": "compensație",
    "compensațiile": "compensație",
    "compensațiilor": "compensație",
    "compensațio": "compensație",
    "compensatoare": "compensator",
    "compensatoarea": "compensator",
    "compensatoarei": "compensator",
    "compensatoarele": "compensator",
    "compensatoarelor": "compensator",
    "compensatoareo": "compensator",
    "compensatori": "compensator",
    "compensatorii": "compensator",
    "compensatorilor": "compensator",
    "compensatorul": "compensator",
    "compensatorule": "compensator",
    "compensatorului": "compensator",
    "compensatoria": "compensatoriu",
    "compensatorie": "compensatoriu",
    "compensatoriei": "compensatoriu",
    "compensatorii": "compensatoriu",
    "compensatoriii": "compensatoriu",
    "compensatoriile": "compensatoriu",
    "compensatoriilor": "compensatoriu",
    "compensatoriul": "compensatoriu",
    "compensatoriului": "compensatoriu",
    "competenta": "competent",
    "competentă": "competent",
    "competente": "competent",
    "competentei": "competent",
    "competentele": "competent",
    "competentelor": "competent",
    "competenți": "competent",
    "competenții": "competent",
    "competenților": "competent",
    "competento": "competent",
    "competentul": "competent",
    "competentule": "competent",
    "competentului": "competent",
    "competența": "competență",
    "competențe": "competență",
    "competenței": "competență",
    "competențele": "competență",
    "competențelor": "competență",
    "competențo": "competență",
    "competiția": "competiție",
    "competiției": "competiție",
    "competiții": "competiție",
    "competițiile": "competiție",
    "competițiilor": "competiție",
    "competițio": "competiție",
    "competiționala": "competițional",
    "competițională": "competițional",
    "competiționale": "competițional",
    "competiționalei": "competițional",
    "competiționalele": "competițional",
    "competiționalelor": "competițional",
    "competiționali": "competițional",
    "competiționalii": "competițional",
    "competiționalilor": "competițional",
    "competiționalo": "competițional",
    "competiționalul": "competițional",
    "competiționalule": "competițional",
    "competiționalului": "competițional",
    "competitiva": "competitiv",
    "competitivă": "competitiv",
    "competitive": "competitiv",
    "competitivei": "competitiv",
    "competitivele": "competitiv",
    "competitivelor": "competitiv",
    "competitivi": "competitiv",
    "competitivii": "competitiv",
    "competitivilor": "competitiv",
    "competitivo": "competitiv",
    "competitivul": "competitiv",
    "competitivule": "competitiv",
    "competitivului": "competitiv",
    "competitivitatea": "competitivitate",
    "competitivități": "competitivitate",
    "competitivității": "competitivitate",
    "competitivitățile": "competitivitate",
    "competitivităților": "competitivitate",
    "competitoarea": "competitoare",
    "competitoarei": "competitoare",
    "competitoarele": "competitoare",
    "competitoarelor": "competitoare",
    "competitoareo": "competitoare",
    "competitori": "competitor",
    "competitorii": "competitor",
    "competitorilor": "competitor",
    "competitorul": "competitor",
    "competitorule": "competitor",
    "competitorului": "competitor",
    "compilă": "compila",
    "compilai": "compila",
    "compilam": "compila",
    "compilăm": "compila",
    "compilând": "compila",
    "compilându": "compila",
    "compilară": "compila",
    "compilarăm": "compila",
    "compilarăți": "compila",
    "compilase": "compila",
    "compilasem": "compila",
    "compilaseră": "compila",
    "compilaserăm": "compila",
    "compilaserăți": "compila",
    "compilaseși": "compila",
    "compilași": "compila",
    "compilat": "compila",
    "compilați": "compila",
    "compilatu": "compila",
    "compilau": "compila",
    "compilează": "compila",
    "compilez": "compila",
    "compileze": "compila",
    "compilezi": "compila",
    "necompilând": "compila",
    "necompilându": "compila",
    "nemaicompilând": "compila",
    "nemaicompilându": "compila",
    "compilarea": "compilare",
    "compilareo": "compilare",
    "compilări": "compilare",
    "compilării": "compilare",
    "compilările": "compilare",
    "compilărilor": "compilare",
    "compilată": "compilat",
    "compilate": "compilat",
    "compilați": "compilat",
    "compilatoarea": "compilatoare",
    "compilatoarei": "compilatoare",
    "compilatoarele": "compilatoare",
    "compilatoarelor": "compilatoare",
    "compilatoareo": "compilatoare",
    "compilatoare": "compilator",
    "compilatoarele": "compilator",
    "compilatoarelor": "compilator",
    "compilatori": "compilator",
    "compilatorii": "compilator",
    "compilatorilor": "compilator",
    "compilatorul": "compilator",
    "compilatorule": "compilator",
    "compilatorului": "compilator",
    "complac": "complăcea",
    "complacă": "complăcea",
    "complăcând": "complăcea",
    "complăcându": "complăcea",
    "complace": "complăcea",
    "complăceai": "complăcea",
    "complăceam": "complăcea",
    "complăceați": "complăcea",
    "complăceau": "complăcea",
    "complăcem": "complăcea",
    "complăceți": "complăcea",
    "complaci": "complăcea",
    "complăcu": "complăcea",
    "complăcui": "complăcea",
    "complăcură": "complăcea",
    "complăcurăm": "complăcea",
    "complăcurăți": "complăcea",
    "complăcuse": "complăcea",
    "complăcusem": "complăcea",
    "complăcuseră": "complăcea",
    "complăcuserăm": "complăcea",
    "complăcuserăți": "complăcea",
    "complăcuseși": "complăcea",
    "complăcuși": "complăcea",
    "complăcut": "complăcea",
    "complăcutu": "complăcea",
    "complăcută": "complăcut",
    "complăcute": "complăcut",
    "complăcuți": "complăcut",
    "complecta": "complect",
    "complectă": "complect",
    "complecte": "complect",
    "complectei": "complect",
    "complectele": "complect",
    "complectelor": "complect",
    "complecți": "complect",
    "complecții": "complect",
    "complecților": "complect",
    "complecto": "complect",
    "complectul": "complect",
    "complectule": "complect",
    "complectului": "complect",
    "complectă": "complecta",
    "complectai": "complecta",
    "complectam": "complecta",
    "complectăm": "complecta",
    "complectând": "complecta",
    "complectându": "complecta",
    "complectară": "complecta",
    "complectarăm": "complecta",
    "complectarăți": "complecta",
    "complectase": "complecta",
    "complectasem": "complecta",
    "complectaseră": "complecta",
    "complectaserăm": "complecta",
    "complectaserăți": "complecta",
    "complectaseși": "complecta",
    "complectași": "complecta",
    "complectat": "complecta",
    "complectați": "complecta",
    "complectatu": "complecta",
    "complectau": "complecta",
    "complectează": "complecta",
    "complectez": "complecta",
    "complecteze": "complecta",
    "complectezi": "complecta",
    "necomplectând": "complecta",
    "necomplectându": "complecta",
    "nemaicomplectând": "complecta",
    "nemaicomplectându": "complecta",
    "complectarea": "complectare",
    "complectareo": "complectare",
    "complectări": "complectare",
    "complectării": "complectare",
    "complectările": "complectare",
    "complectărilor": "complectare",
    "complectată": "complectat",
    "complectate": "complectat",
    "complectați": "complectat",
    "complemente": "complement",
    "complementele": "complement",
    "complementelor": "complement",
    "complementul": "complement",
    "complementule": "complement",
    "complementului": "complement",
    "completa": "complet",
    "completă": "complet",
    "complete": "complet",
    "completei": "complet",
    "completele": "complet",
    "completelor": "complet",
    "compleți": "complet",
    "compleții": "complet",
    "compleților": "complet",
    "completo": "complet",
    "completul": "complet",
    "completule": "complet",
    "completului": "complet",
    "completuri": "complet",
    "completurile": "complet",
    "completurilor": "complet",
    "completă": "completa",
    "completai": "completa",
    "completam": "completa",
    "completăm": "completa",
    "completând": "completa",
    "completându": "completa",
    "completară": "completa",
    "completarăm": "completa",
    "completarăți": "completa",
    "completase": "completa",
    "completasem": "completa",
    "completaseră": "completa",
    "completaserăm": "completa",
    "completaserăți": "completa",
    "completaseși": "completa",
    "completași": "completa",
    "completat": "completa",
    "completați": "completa",
    "completatu": "completa",
    "completau": "completa",
    "completează": "completa",
    "completez": "completa",
    "completeze": "completa",
    "completezi": "completa",
    "necompletând": "completa",
    "necompletându": "completa",
    "nemaicompletând": "completa",
    "nemaicompletându": "completa",
    "completarea": "completare",
    "completareo": "completare",
    "completări": "completare",
    "completării": "completare",
    "completările": "completare",
    "completărilor": "completare",
    "completată": "completat",
    "completate": "completat",
    "completați": "completat",
    "completiva": "completiv",
    "completivă": "completiv",
    "completive": "completiv",
    "completivei": "completiv",
    "completivele": "completiv",
    "completivelor": "completiv",
    "completivi": "completiv",
    "completivii": "completiv",
    "completivilor": "completiv",
    "completivo": "completiv",
    "completivul": "completiv",
    "completivule": "completiv",
    "completivului": "completiv",
    "complecși": "complex",
    "complecșii": "complex",
    "complecșilor": "complex",
    "complexa": "complex",
    "complexă": "complex",
    "complexe": "complex",
    "complexei": "complex",
    "complexele": "complex",
    "complexelor": "complex",
    "complexo": "complex",
    "complexul": "complex",
    "complexule": "complex",
    "complexului": "complex",
    "complexitatea": "complexitate",
    "complexitateo": "complexitate",
    "complexități": "complexitate",
    "complexității": "complexitate",
    "complexitățile": "complexitate",
    "complexităților": "complexitate",
    "complezenta": "complezent",
    "complezentă": "complezent",
    "complezente": "complezent",
    "complezentei": "complezent",
    "complezentele": "complezent",
    "complezentelor": "complezent",
    "complezenți": "complezent",
    "complezenții": "complezent",
    "complezenților": "complezent",
    "complezento": "complezent",
    "complezentul": "complezent",
    "complezentule": "complezent",
    "complezentului": "complezent",
    "complezența": "complezență",
    "complezențe": "complezență",
    "complezenței": "complezență",
    "complezențele": "complezență",
    "complezențelor": "complezență",
    "complezențo": "complezență",
    "complic": "complica",
    "complică": "complica",
    "complicai": "complica",
    "complicam": "complica",
    "complicăm": "complica",
    "complicând": "complica",
    "complicându": "complica",
    "complicară": "complica",
    "complicarăm": "complica",
    "complicarăți": "complica",
    "complicase": "complica",
    "complicasem": "complica",
    "complicaseră": "complica",
    "complicaserăm": "complica",
    "complicaserăți": "complica",
    "complicaseși": "complica",
    "complicași": "complica",
    "complicat": "complica",
    "complicați": "complica",
    "complicatu": "complica",
    "complicau": "complica",
    "complice": "complica",
    "complici": "complica",
    "necomplicând": "complica",
    "necomplicându": "complica",
    "nemaicomplicând": "complica",
    "nemaicomplicându": "complica",
    "complicarea": "complicare",
    "complicareo": "complicare",
    "complicări": "complicare",
    "complicării": "complicare",
    "complicările": "complicare",
    "complicărilor": "complicare",
    "complicata": "complicat",
    "complicată": "complicat",
    "complicate": "complicat",
    "complicatei": "complicat",
    "complicatele": "complicat",
    "complicatelor": "complicat",
    "complicați": "complicat",
    "complicații": "complicat",
    "complicaților": "complicat",
    "complicato": "complicat",
    "complicatul": "complicat",
    "complicatule": "complicat",
    "complicatului": "complicat",
    "complicația": "complicație",
    "complicației": "complicație",
    "complicații": "complicație",
    "complicațiile": "complicație",
    "complicațiilor": "complicație",
    "complicațio": "complicație",
    "complicea": "complice",
    "complicei": "complice",
    "complicele": "complice",
    "complicelor": "complice",
    "complicelui": "complice",
    "compliceo": "complice",
    "complici": "complice",
    "complicii": "complice",
    "complicilor": "complice",
    "complicitatea": "complicitate",
    "complicitateo": "complicitate",
    "complicități": "complicitate",
    "complicității": "complicitate",
    "complicitățile": "complicitate",
    "complicităților": "complicitate",
    "complimente": "compliment",
    "complimentele": "compliment",
    "complimentelor": "compliment",
    "complimentul": "compliment",
    "complimentule": "compliment",
    "complimentului": "compliment",
    "complimentă": "complimenta",
    "complimentai": "complimenta",
    "complimentam": "complimenta",
    "complimentăm": "complimenta",
    "complimentând": "complimenta",
    "complimentându": "complimenta",
    "complimentară": "complimenta",
    "complimentarăm": "complimenta",
    "complimentarăți": "complimenta",
    "complimentase": "complimenta",
    "complimentasem": "complimenta",
    "complimentaseră": "complimenta",
    "complimentaserăm": "complimenta",
    "complimentaserăți": "complimenta",
    "complimentaseși": "complimenta",
    "complimentași": "complimenta",
    "complimentat": "complimenta",
    "complimentați": "complimenta",
    "complimentatu": "complimenta",
    "complimentau": "complimenta",
    "complimentează": "complimenta",
    "complimentez": "complimenta",
    "complimenteze": "complimenta",
    "complimentezi": "complimenta",
    "necomplimentând": "complimenta",
    "necomplimentându": "complimenta",
    "nemaicomplimentând": "complimenta",
    "nemaicomplimentându": "complimenta",
    "complimentată": "complimentat",
    "complimentate": "complimentat",
    "complimentați": "complimentat",
    "complinea": "complini",
    "complineai": "complini",
    "complineam": "complini",
    "complinească": "complini",
    "complineați": "complini",
    "complineau": "complini",
    "complinesc": "complini",
    "complinește": "complini",
    "complinești": "complini",
    "complinii": "complini",
    "complinim": "complini",
    "complinind": "complini",
    "complinindu": "complini",
    "compliniră": "complini",
    "complinirăm": "complini",
    "complinirăți": "complini",
    "complinise": "complini",
    "complinisem": "complini",
    "compliniseră": "complini",
    "compliniserăm": "complini",
    "compliniserăți": "complini",
    "compliniseși": "complini",
    "compliniși": "complini",
    "complinit": "complini",
    "compliniți": "complini",
    "complinitu": "complini",
    "necomplinind": "complini",
    "necomplinindu": "complini",
    "nemaicomplinind": "complini",
    "nemaicomplinindu": "complini",
    "complinirea": "complinire",
    "complinireo": "complinire",
    "compliniri": "complinire",
    "complinirii": "complinire",
    "complinirile": "complinire",
    "complinirilor": "complinire",
    "complinită": "complinit",
    "complinite": "complinit",
    "compliniți": "complinit",
    "complinitoare": "complinitor",
    "complinitoarea": "complinitor",
    "complinitoarei": "complinitor",
    "complinitoarele": "complinitor",
    "complinitoarelor": "complinitor",
    "complinitoareo": "complinitor",
    "complinitori": "complinitor",
    "complinitorii": "complinitor",
    "complinitorilor": "complinitor",
    "complinitorul": "complinitor",
    "complinitorule": "complinitor",
    "complinitorului": "complinitor",
    "complotul": "complot",
    "complotule": "complot",
    "complotului": "complot",
    "comploturi": "complot",
    "comploturile": "complot",
    "comploturilor": "complot",
    "complotă": "complota",
    "complotai": "complota",
    "complotam": "complota",
    "complotăm": "complota",
    "complotând": "complota",
    "complotându": "complota",
    "complotară": "complota",
    "complotarăm": "complota",
    "complotarăți": "complota",
    "complotase": "complota",
    "complotasem": "complota",
    "complotaseră": "complota",
    "complotaserăm": "complota",
    "complotaserăți": "complota",
    "complotaseși": "complota",
    "complotași": "complota",
    "complotat": "complota",
    "complotați": "complota",
    "complotatu": "complota",
    "complotau": "complota",
    "complotează": "complota",
    "complotez": "complota",
    "comploteze": "complota",
    "complotezi": "complota",
    "necomplotând": "complota",
    "necomplotându": "complota",
    "nemaicomplotând": "complota",
    "nemaicomplotându": "complota",
    "complotată": "complotat",
    "complotate": "complotat",
    "complotați": "complotat",
    "complotiști": "complotist",
    "complotiștii": "complotist",
    "complotiștilor": "complotist",
    "complotistul": "complotist",
    "complotistule": "complotist",
    "complotistului": "complotist",
    "complotista": "complotistă",
    "complotiste": "complotistă",
    "complotistei": "complotistă",
    "complotistele": "complotistă",
    "complotistelor": "complotistă",
    "complotisto": "complotistă",
    "componenta": "component",
    "componentă": "component",
    "componente": "component",
    "componentei": "component",
    "componentele": "component",
    "componentelor": "component",
    "componenți": "component",
    "componenții": "component",
    "componenților": "component",
    "componento": "component",
    "componentul": "component",
    "componentule": "component",
    "componentului": "component",
    "componenta": "componentă",
    "componente": "componentă",
    "componentei": "componentă",
    "componentele": "componentă",
    "componentelor": "componentă",
    "componento": "componentă",
    "componența": "componență",
    "componențe": "componență",
    "componenței": "componență",
    "componențele": "componență",
    "componențelor": "componență",
    "componențo": "componență",
    "componentele": "componente",
    "componentelor": "componente",
    "componiști": "componist",
    "componiștii": "componist",
    "componiștilor": "componist",
    "componistul": "componist",
    "componistule": "componist",
    "componistului": "componist",
    "componista": "componistă",
    "componiste": "componistă",
    "componistei": "componistă",
    "componistele": "componistă",
    "componistelor": "componistă",
    "componisto": "componistă",
    "componistica": "componistic",
    "componistică": "componistic",
    "componistice": "componistic",
    "componisticei": "componistic",
    "componisticele": "componistic",
    "componisticelor": "componistic",
    "componistici": "componistic",
    "componisticii": "componistic",
    "componisticilor": "componistic",
    "componistico": "componistic",
    "componisticul": "componistic",
    "componisticule": "componistic",
    "componisticului": "componistic",
    "comport": "comporta",
    "comportă": "comporta",
    "comportai": "comporta",
    "comportam": "comporta",
    "comportăm": "comporta",
    "comportând": "comporta",
    "comportându": "comporta",
    "comportară": "comporta",
    "comportarăm": "comporta",
    "comportarăți": "comporta",
    "comportase": "comporta",
    "comportasem": "comporta",
    "comportaseră": "comporta",
    "comportaserăm": "comporta",
    "comportaserăți": "comporta",
    "comportaseși": "comporta",
    "comportași": "comporta",
    "comportat": "comporta",
    "comportați": "comporta",
    "comportatu": "comporta",
    "comportau": "comporta",
    "comporte": "comporta",
    "comporți": "comporta",
    "necomportând": "comporta",
    "necomportându": "comporta",
    "nemaicomportând": "comporta",
    "nemaicomportându": "comporta",
    "comportamente": "comportament",
    "comportamentele": "comportament",
    "comportamentelor": "comportament",
    "comportamentul": "comportament",
    "comportamentule": "comportament",
    "comportamentului": "comportament",
    "comportarea": "comportare",
    "comportareo": "comportare",
    "comportări": "comportare",
    "comportării": "comportare",
    "comportările": "comportare",
    "comportărilor": "comportare",
    "comportată": "comportat",
    "comportate": "comportat",
    "comportați": "comportat",
    "compostă": "composta",
    "compostai": "composta",
    "compostam": "composta",
    "compostăm": "composta",
    "compostând": "composta",
    "compostându": "composta",
    "compostară": "composta",
    "compostarăm": "composta",
    "compostarăți": "composta",
    "compostase": "composta",
    "compostasem": "composta",
    "compostaseră": "composta",
    "compostaserăm": "composta",
    "compostaserăți": "composta",
    "compostaseși": "composta",
    "compostași": "composta",
    "compostat": "composta",
    "compostați": "composta",
    "compostatu": "composta",
    "compostau": "composta",
    "compostează": "composta",
    "compostez": "composta",
    "composteze": "composta",
    "compostezi": "composta",
    "necompostând": "composta",
    "necompostându": "composta",
    "nemaicompostând": "composta",
    "nemaicompostându": "composta",
    "compostată": "compostat",
    "compostate": "compostat",
    "compostați": "compostat",
    "compostoare": "compostor",
    "compostoarele": "compostor",
    "compostoarelor": "compostor",
    "compostorul": "compostor",
    "compostorule": "compostor",
    "compostorului": "compostor",
    "compotul": "compot",
    "compotule": "compot",
    "compotului": "compot",
    "compoturi": "compot",
    "compoturile": "compot",
    "compoturilor": "compot",
    "compozita": "compozit",
    "compozită": "compozit",
    "compozite": "compozit",
    "compozitei": "compozit",
    "compozitele": "compozit",
    "compozitelor": "compozit",
    "compoziți": "compozit",
    "compoziții": "compozit",
    "compoziților": "compozit",
    "compozito": "compozit",
    "compozitul": "compozit",
    "compozitule": "compozit",
    "compozitului": "compozit",
    "compoziția": "compoziție",
    "compoziției": "compoziție",
    "compoziții": "compoziție",
    "compozițiile": "compoziție",
    "compozițiilor": "compoziție",
    "compozițio": "compoziție",
    "compoziționala": "compozițional",
    "compozițională": "compozițional",
    "compoziționale": "compozițional",
    "compoziționalei": "compozițional",
    "compoziționalele": "compozițional",
    "compoziționalelor": "compozițional",
    "compoziționali": "compozițional",
    "compoziționalii": "compozițional",
    "compoziționalilor": "compozițional",
    "compoziționalo": "compozițional",
    "compoziționalul": "compozițional",
    "compoziționalule": "compozițional",
    "compoziționalului": "compozițional",
    "compozitoarea": "compozitoare",
    "compozitoarei": "compozitoare",
    "compozitoarele": "compozitoare",
    "compozitoarelor": "compozitoare",
    "compozitoareo": "compozitoare",
    "compozitori": "compozitor",
    "compozitorii": "compozitor",
    "compozitorilor": "compozitor",
    "compozitorul": "compozitor",
    "compozitorule": "compozitor",
    "compozitorului": "compozitor",
    "comprehensibila": "comprehensibil",
    "comprehensibilă": "comprehensibil",
    "comprehensibile": "comprehensibil",
    "comprehensibilei": "comprehensibil",
    "comprehensibilele": "comprehensibil",
    "comprehensibilelor": "comprehensibil",
    "comprehensibili": "comprehensibil",
    "comprehensibilii": "comprehensibil",
    "comprehensibililor": "comprehensibil",
    "comprehensibilo": "comprehensibil",
    "comprehensibilul": "comprehensibil",
    "comprehensibilule": "comprehensibil",
    "comprehensibilului": "comprehensibil",
    "comprehensiunea": "comprehensiune",
    "comprehensiuneo": "comprehensiune",
    "comprehensiuni": "comprehensiune",
    "comprehensiunii": "comprehensiune",
    "comprehensiunile": "comprehensiune",
    "comprehensiunilor": "comprehensiune",
    "comprehensiva": "comprehensiv",
    "comprehensivă": "comprehensiv",
    "comprehensive": "comprehensiv",
    "comprehensivei": "comprehensiv",
    "comprehensivele": "comprehensiv",
    "comprehensivelor": "comprehensiv",
    "comprehensivi": "comprehensiv",
    "comprehensivii": "comprehensiv",
    "comprehensivilor": "comprehensiv",
    "comprehensivo": "comprehensiv",
    "comprehensivul": "comprehensiv",
    "comprehensivule": "comprehensiv",
    "comprehensivului": "comprehensiv",
    "compresa": "compresă",
    "comprese": "compresă",
    "compresei": "compresă",
    "compresele": "compresă",
    "compreselor": "compresă",
    "compreso": "compresă",
    "compresibila": "compresibil",
    "compresibilă": "compresibil",
    "compresibile": "compresibil",
    "compresibilei": "compresibil",
    "compresibilele": "compresibil",
    "compresibilelor": "compresibil",
    "compresibili": "compresibil",
    "compresibilii": "compresibil",
    "compresibililor": "compresibil",
    "compresibilo": "compresibil",
    "compresibilul": "compresibil",
    "compresibilule": "compresibil",
    "compresibilului": "compresibil",
    "compresoare": "compresor",
    "compresoarele": "compresor",
    "compresoarelor": "compresor",
    "compresorul": "compresor",
    "compresorule": "compresor",
    "compresorului": "compresor",
    "comprim": "comprima",
    "comprimă": "comprima",
    "comprimai": "comprima",
    "comprimam": "comprima",
    "comprimăm": "comprima",
    "comprimând": "comprima",
    "comprimându": "comprima",
    "comprimară": "comprima",
    "comprimarăm": "comprima",
    "comprimarăți": "comprima",
    "comprimase": "comprima",
    "comprimasem": "comprima",
    "comprimaseră": "comprima",
    "comprimaserăm": "comprima",
    "comprimaserăți": "comprima",
    "comprimaseși": "comprima",
    "comprimași": "comprima",
    "comprimat": "comprima",
    "comprimați": "comprima",
    "comprimatu": "comprima",
    "comprimau": "comprima",
    "comprime": "comprima",
    "comprimi": "comprima",
    "necomprimând": "comprima",
    "necomprimându": "comprima",
    "nemaicomprimând": "comprima",
    "nemaicomprimându": "comprima",
    "comprimabila": "comprimabil",
    "comprimabilă": "comprimabil",
    "comprimabile": "comprimabil",
    "comprimabilei": "comprimabil",
    "comprimabilele": "comprimabil",
    "comprimabilelor": "comprimabil",
    "comprimabili": "comprimabil",
    "comprimabilii": "comprimabil",
    "comprimabililor": "comprimabil",
    "comprimabilo": "comprimabil",
    "comprimabilul": "comprimabil",
    "comprimabilule": "comprimabil",
    "comprimabilului": "comprimabil",
    "comprimarea": "comprimare",
    "comprimareo": "comprimare",
    "comprimări": "comprimare",
    "comprimării": "comprimare",
    "comprimările": "comprimare",
    "comprimărilor": "comprimare",
    "comprimata": "comprimat",
    "comprimată": "comprimat",
    "comprimate": "comprimat",
    "comprimatei": "comprimat",
    "comprimatele": "comprimat",
    "comprimatelor": "comprimat",
    "comprimați": "comprimat",
    "comprimații": "comprimat",
    "comprimaților": "comprimat",
    "comprimato": "comprimat",
    "comprimatul": "comprimat",
    "comprimatule": "comprimat",
    "comprimatului": "comprimat",
    "compromisa": "compromis",
    "compromisă": "compromis",
    "compromise": "compromis",
    "compromisei": "compromis",
    "compromisele": "compromis",
    "compromiselor": "compromis",
    "compromiși": "compromis",
    "compromișii": "compromis",
    "compromișilor": "compromis",
    "compromiso": "compromis",
    "compromisul": "compromis",
    "compromisule": "compromis",
    "compromisului": "compromis",
    "compromisuri": "compromis",
    "compromisurile": "compromis",
    "compromisurilor": "compromis",
    "compromițătoare": "compromițător",
    "compromițătoarea": "compromițător",
    "compromițătoarei": "compromițător",
    "compromițătoarele": "compromițător",
    "compromițătoarelor": "compromițător",
    "compromițătoareo": "compromițător",
    "compromițători": "compromițător",
    "compromițătorii": "compromițător",
    "compromițătorilor": "compromițător",
    "compromițătorul": "compromițător",
    "compromițătorule": "compromițător",
    "compromițătorului": "compromițător",
    "compromis": "compromite",
    "compromise": "compromite",
    "compromisei": "compromite",
    "compromiseră": "compromite",
    "compromiserăm": "compromite",
    "compromiserăți": "compromite",
    "compromisese": "compromite",
    "compromisesem": "compromite",
    "compromiseseră": "compromite",
    "compromiseserăm": "compromite",
    "compromiseserăți": "compromite",
    "compromiseseși": "compromite",
    "compromiseși": "compromite",
    "compromisu": "compromite",
    "compromit": "compromite",
    "compromită": "compromite",
    "compromițând": "compromite",
    "compromițându": "compromite",
    "compromitea": "compromite",
    "compromiteai": "compromite",
    "compromiteam": "compromite",
    "compromiteați": "compromite",
    "compromiteau": "compromite",
    "compromitem": "compromite",
    "compromiteți": "compromite",
    "compromiți": "compromite",
    "necompromițând": "compromite",
    "necompromițându": "compromite",
    "nemaicompromițând": "compromite",
    "nemaicompromițându": "compromite",
    "compromiterea": "compromitere",
    "compromitereo": "compromitere",
    "compromiteri": "compromitere",
    "compromiterii": "compromitere",
    "compromiterile": "compromitere",
    "compromiterilor": "compromitere",
    "compui": "compune",
    "compun": "compune",
    "compună": "compune",
    "compunând": "compune",
    "compunându": "compune",
    "compunea": "compune",
    "compuneai": "compune",
    "compuneam": "compune",
    "compuneați": "compune",
    "compuneau": "compune",
    "compunem": "compune",
    "compuneți": "compune",
    "compus": "compune",
    "compuse": "compune",
    "compusei": "compune",
    "compuseră": "compune",
    "compuserăm": "compune",
    "compuserăți": "compune",
    "compusese": "compune",
    "compusesem": "compune",
    "compuseseră": "compune",
    "compuseserăm": "compune",
    "compuseserăți": "compune",
    "compuseseși": "compune",
    "compuseși": "compune",
    "compusu": "compune",
    "necompunând": "compune",
    "necompunându": "compune",
    "nemaicompunând": "compune",
    "nemaicompunându": "compune",
    "compunerea": "compunere",
    "compunereo": "compunere",
    "compuneri": "compunere",
    "compunerii": "compunere",
    "compunerile": "compunere",
    "compunerilor": "compunere",
    "compusa": "compus",
    "compusă": "compus",
    "compuse": "compus",
    "compusei": "compus",
    "compusele": "compus",
    "compuselor": "compus",
    "compuși": "compus",
    "compușii": "compus",
    "compușilor": "compus",
    "compuso": "compus",
    "compusul": "compus",
    "compusule": "compus",
    "compusului": "compus",
    "computere": "computer",
    "computerele": "computer",
    "computerelor": "computer",
    "computerul": "computer",
    "computerule": "computer",
    "computerului": "computer",
    "computerizata": "computerizat",
    "computerizată": "computerizat",
    "computerizate": "computerizat",
    "computerizatei": "computerizat",
    "computerizatele": "computerizat",
    "computerizatelor": "computerizat",
    "computerizați": "computerizat",
    "computerizații": "computerizat",
    "computerizaților": "computerizat",
    "computerizato": "computerizat",
    "computerizatul": "computerizat",
    "computerizatule": "computerizat",
    "computerizatului": "computerizat",
    "comuna": "comun",
    "comună": "comun",
    "comune": "comun",
    "comunei": "comun",
    "comunele": "comun",
    "comunelor": "comun",
    "comuni": "comun",
    "comunii": "comun",
    "comunilor": "comun",
    "comuno": "comun",
    "comunul": "comun",
    "comunule": "comun",
    "comunului": "comun",
    "com.": "comuna",
    "comuna": "comună",
    "comune": "comună",
    "comunei": "comună",
    "comunele": "comună",
    "comunelor": "comună",
    "comuno": "comună",
    "comunala": "comunal",
    "comunală": "comunal",
    "comunale": "comunal",
    "comunalei": "comunal",
    "comunalele": "comunal",
    "comunalelor": "comunal",
    "comunali": "comunal",
    "comunalii": "comunal",
    "comunalilor": "comunal",
    "comunalo": "comunal",
    "comunalul": "comunal",
    "comunalule": "comunal",
    "comunalului": "comunal",
    "comunic": "comunica",
    "comunică": "comunica",
    "comunicai": "comunica",
    "comunicam": "comunica",
    "comunicăm": "comunica",
    "comunicând": "comunica",
    "comunicându": "comunica",
    "comunicară": "comunica",
    "comunicarăm": "comunica",
    "comunicarăți": "comunica",
    "comunicase": "comunica",
    "comunicasem": "comunica",
    "comunicaseră": "comunica",
    "comunicaserăm": "comunica",
    "comunicaserăți": "comunica",
    "comunicaseși": "comunica",
    "comunicași": "comunica",
    "comunicat": "comunica",
    "comunicați": "comunica",
    "comunicatu": "comunica",
    "comunicau": "comunica",
    "comunice": "comunica",
    "comunici": "comunica",
    "necomunicând": "comunica",
    "necomunicându": "comunica",
    "nemaicomunicând": "comunica",
    "nemaicomunicându": "comunica",
    "comunicante": "comunicant",
    "comunicantele": "comunicant",
    "comunicantelor": "comunicant",
    "comunicantul": "comunicant",
    "comunicantule": "comunicant",
    "comunicantului": "comunicant",
    "comunicarea": "comunicare",
    "comunicareo": "comunicare",
    "comunicări": "comunicare",
    "comunicării": "comunicare",
    "comunicările": "comunicare",
    "comunicărilor": "comunicare",
    "comunicată": "comunicat",
    "comunicate": "comunicat",
    "comunicatele": "comunicat",
    "comunicatelor": "comunicat",
    "comunicați": "comunicat",
    "comunicatul": "comunicat",
    "comunicatule": "comunicat",
    "comunicatului": "comunicat",
    "comunicația": "comunicație",
    "comunicației": "comunicație",
    "comunicații": "comunicație",
    "comunicațiile": "comunicație",
    "comunicațiilor": "comunicație",
    "comunicațio": "comunicație",
    "comunicativa": "comunicativ",
    "comunicativă": "comunicativ",
    "comunicative": "comunicativ",
    "comunicativei": "comunicativ",
    "comunicativele": "comunicativ",
    "comunicativelor": "comunicativ",
    "comunicativi": "comunicativ",
    "comunicativii": "comunicativ",
    "comunicativilor": "comunicativ",
    "comunicativo": "comunicativ",
    "comunicativul": "comunicativ",
    "comunicativule": "comunicativ",
    "comunicativului": "comunicativ",
    "comunismul": "comunism",
    "comunismule": "comunism",
    "comunismului": "comunism",
    "comuniste": "comunist",
    "comuniști": "comunist",
    "comuniștii": "comunist",
    "comuniștilor": "comunist",
    "comunistul": "comunist",
    "comunistule": "comunist",
    "comunistului": "comunist",
    "comunista": "comunistă",
    "comuniste": "comunistă",
    "comunistei": "comunistă",
    "comunistele": "comunistă",
    "comunistelor": "comunistă",
    "comunisto": "comunistă",
    "comunitara": "comunitar",
    "comunitară": "comunitar",
    "comunitare": "comunitar",
    "comunitarei": "comunitar",
    "comunitarele": "comunitar",
    "comunitarelor": "comunitar",
    "comunitari": "comunitar",
    "comunitarii": "comunitar",
    "comunitarilor": "comunitar",
    "comunitaro": "comunitar",
    "comunitarul": "comunitar",
    "comunitarule": "comunitar",
    "comunitarului": "comunitar",
    "comunitatea": "comunitate",
    "comunitateo": "comunitate",
    "comunități": "comunitate",
    "comunității": "comunitate",
    "comunitățile": "comunitate",
    "comunităților": "comunitate",
    "comuniunea": "comuniune",
    "comuniuneo": "comuniune",
    "comuniuni": "comuniune",
    "comuniunii": "comuniune",
    "comuniunile": "comuniune",
    "comuniunilor": "comuniune",
    "comut": "comuta",
    "comută": "comuta",
    "comutai": "comuta",
    "comutam": "comuta",
    "comutăm": "comuta",
    "comutând": "comuta",
    "comutându": "comuta",
    "comutară": "comuta",
    "comutarăm": "comuta",
    "comutarăți": "comuta",
    "comutase": "comuta",
    "comutasem": "comuta",
    "comutaseră": "comuta",
    "comutaserăm": "comuta",
    "comutaserăți": "comuta",
    "comutaseși": "comuta",
    "comutași": "comuta",
    "comutat": "comuta",
    "comutați": "comuta",
    "comutatu": "comuta",
    "comutau": "comuta",
    "comute": "comuta",
    "comuți": "comuta",
    "necomutând": "comuta",
    "necomutându": "comuta",
    "nemaicomutând": "comuta",
    "nemaicomutându": "comuta",
    "comutabila": "comutabil",
    "comutabilă": "comutabil",
    "comutabile": "comutabil",
    "comutabilei": "comutabil",
    "comutabilele": "comutabil",
    "comutabilelor": "comutabil",
    "comutabili": "comutabil",
    "comutabilii": "comutabil",
    "comutabililor": "comutabil",
    "comutabilo": "comutabil",
    "comutabilul": "comutabil",
    "comutabilule": "comutabil",
    "comutabilului": "comutabil",
    "comutarea": "comutare",
    "comutareo": "comutare",
    "comutări": "comutare",
    "comutării": "comutare",
    "comutările": "comutare",
    "comutărilor": "comutare",
    "comutată": "comutat",
    "comutate": "comutat",
    "comutați": "comutat",
    "comutatoare": "comutator",
    "comutatoarele": "comutator",
    "comutatoarelor": "comutator",
    "comutatorul": "comutator",
    "comutatorule": "comutator",
    "comutatorului": "comutator",
    "conul": "con",
    "conule": "con",
    "conului": "con",
    "conuri": "con",
    "conurile": "con",
    "conurilor": "con",
    "conace": "conac",
    "conacele": "conac",
    "conacelor": "conac",
    "conacul": "conac",
    "conacule": "conac",
    "conacului": "conac",
    "conaționali": "conațional",
    "conaționalii": "conațional",
    "conaționalilor": "conațional",
    "conaționalul": "conațional",
    "conaționalului": "conațional",
    "concasă": "concasa",
    "concasai": "concasa",
    "concasam": "concasa",
    "concasăm": "concasa",
    "concasând": "concasa",
    "concasându": "concasa",
    "concasară": "concasa",
    "concasarăm": "concasa",
    "concasarăți": "concasa",
    "concasase": "concasa",
    "concasasem": "concasa",
    "concasaseră": "concasa",
    "concasaserăm": "concasa",
    "concasaserăți": "concasa",
    "concasaseși": "concasa",
    "concasași": "concasa",
    "concasat": "concasa",
    "concasați": "concasa",
    "concasatu": "concasa",
    "concasau": "concasa",
    "concasează": "concasa",
    "concasez": "concasa",
    "concaseze": "concasa",
    "concasezi": "concasa",
    "neconcasând": "concasa",
    "neconcasându": "concasa",
    "nemaiconcasând": "concasa",
    "nemaiconcasându": "concasa",
    "concasarea": "concasare",
    "concasareo": "concasare",
    "concasări": "concasare",
    "concasării": "concasare",
    "concasările": "concasare",
    "concasărilor": "concasare",
    "concasată": "concasat",
    "concasate": "concasat",
    "concasați": "concasat",
    "concasoare": "concasor",
    "concasoarele": "concasor",
    "concasoarelor": "concasor",
    "concasorul": "concasor",
    "concasorule": "concasor",
    "concasorului": "concasor",
    "concava": "concav",
    "concavă": "concav",
    "concave": "concav",
    "concavei": "concav",
    "concavele": "concav",
    "concavelor": "concav",
    "concavi": "concav",
    "concavii": "concav",
    "concavilor": "concav",
    "concavo": "concav",
    "concavul": "concav",
    "concavule": "concav",
    "concavului": "concav",
    "concavitatea": "concavitate",
    "concavitateo": "concavitate",
    "concavități": "concavitate",
    "concavității": "concavitate",
    "concavitățile": "concavitate",
    "concavităților": "concavitate",
    "conceadă": "concede",
    "conced": "concede",
    "concedând": "concede",
    "concedându": "concede",
    "concedea": "concede",
    "concedeai": "concede",
    "concedeam": "concede",
    "concedeați": "concede",
    "concedeau": "concede",
    "concedem": "concede",
    "concedeți": "concede",
    "conceze": "concede",
    "concezi": "concede",
    "neconcedând": "concede",
    "neconcedându": "concede",
    "nemaiconcedând": "concede",
    "nemaiconcedându": "concede",
    "concediai": "concedia",
    "concediam": "concedia",
    "concediară": "concedia",
    "concediarăm": "concedia",
    "concediarăți": "concedia",
    "concediase": "concedia",
    "concediasem": "concedia",
    "concediaseră": "concedia",
    "concediaserăm": "concedia",
    "concediaserăți": "concedia",
    "concediaseși": "concedia",
    "concediași": "concedia",
    "concediat": "concedia",
    "concediați": "concedia",
    "concediatu": "concedia",
    "concediau": "concedia",
    "concediază": "concedia",
    "concedie": "concedia",
    "concediem": "concedia",
    "concediez": "concedia",
    "concedieze": "concedia",
    "concediezi": "concedia",
    "concediind": "concedia",
    "concediindu": "concedia",
    "neconcediind": "concedia",
    "neconcediindu": "concedia",
    "nemaiconcediind": "concedia",
    "nemaiconcediindu": "concedia",
    "concediată": "concediat",
    "concediate": "concediat",
    "concediați": "concediat",
    "concedierea": "concediere",
    "concediereo": "concediere",
    "concedieri": "concediere",
    "concedierii": "concediere",
    "concedierile": "concediere",
    "concedierilor": "concediere",
    "concedii": "concediu",
    "concediile": "concediu",
    "concediilor": "concediu",
    "concediul": "concediu",
    "concediule": "concediu",
    "concediului": "concediu",
    "concentră": "concentra",
    "concentrai": "concentra",
    "concentram": "concentra",
    "concentrăm": "concentra",
    "concentrând": "concentra",
    "concentrându": "concentra",
    "concentrară": "concentra",
    "concentrarăm": "concentra",
    "concentrarăți": "concentra",
    "concentrase": "concentra",
    "concentrasem": "concentra",
    "concentraseră": "concentra",
    "concentraserăm": "concentra",
    "concentraserăți": "concentra",
    "concentraseși": "concentra",
    "concentrași": "concentra",
    "concentrat": "concentra",
    "concentrați": "concentra",
    "concentratu": "concentra",
    "concentrau": "concentra",
    "concentrează": "concentra",
    "concentrez": "concentra",
    "concentreze": "concentra",
    "concentrezi": "concentra",
    "neconcentrând": "concentra",
    "neconcentrându": "concentra",
    "nemaiconcentrând": "concentra",
    "nemaiconcentrându": "concentra",
    "concentrarea": "concentrare",
    "concentrareo": "concentrare",
    "concentrări": "concentrare",
    "concentrării": "concentrare",
    "concentrările": "concentrare",
    "concentrărilor": "concentrare",
    "concentrata": "concentrat",
    "concentrată": "concentrat",
    "concentrate": "concentrat",
    "concentratei": "concentrat",
    "concentratele": "concentrat",
    "concentratelor": "concentrat",
    "concentrați": "concentrat",
    "concentrații": "concentrat",
    "concentraților": "concentrat",
    "concentrato": "concentrat",
    "concentratul": "concentrat",
    "concentratule": "concentrat",
    "concentratului": "concentrat",
    "concentrația": "concentrație",
    "concentrației": "concentrație",
    "concentrații": "concentrație",
    "concentrațiile": "concentrație",
    "concentrațiilor": "concentrație",
    "concentrațio": "concentrație",
    "concentraționara": "concentraționar",
    "concentraționară": "concentraționar",
    "concentraționare": "concentraționar",
    "concentraționarei": "concentraționar",
    "concentraționarele": "concentraționar",
    "concentraționarelor": "concentraționar",
    "concentraționari": "concentraționar",
    "concentraționarii": "concentraționar",
    "concentraționarilor": "concentraționar",
    "concentraționaro": "concentraționar",
    "concentraționarul": "concentraționar",
    "concentraționarule": "concentraționar",
    "concentraționarului": "concentraționar",
    "concentrica": "concentric",
    "concentrică": "concentric",
    "concentrice": "concentric",
    "concentricei": "concentric",
    "concentricele": "concentric",
    "concentricelor": "concentric",
    "concentrici": "concentric",
    "concentricii": "concentric",
    "concentricilor": "concentric",
    "concentrico": "concentric",
    "concentricul": "concentric",
    "concentricule": "concentric",
    "concentricului": "concentric",
    "conceapă": "concepe",
    "concep": "concepe",
    "concepând": "concepe",
    "concepându": "concepe",
    "concepea": "concepe",
    "concepeai": "concepe",
    "concepeam": "concepe",
    "concepeați": "concepe",
    "concepeau": "concepe",
    "concepem": "concepe",
    "concepeți": "concepe",
    "concepi": "concepe",
    "concepu": "concepe",
    "concepui": "concepe",
    "concepură": "concepe",
    "concepurăm": "concepe",
    "concepurăți": "concepe",
    "concepuse": "concepe",
    "concepusem": "concepe",
    "concepuseră": "concepe",
    "concepuserăm": "concepe",
    "concepuserăți": "concepe",
    "concepuseși": "concepe",
    "concepuși": "concepe",
    "conceput": "concepe",
    "conceputu": "concepe",
    "neconcepând": "concepe",
    "neconcepându": "concepe",
    "neconceput": "concepe",
    "nemaiconcepând": "concepe",
    "nemaiconcepându": "concepe",
    "conceperea": "concepere",
    "concepereo": "concepere",
    "conceperi": "concepere",
    "conceperii": "concepere",
    "conceperile": "concepere",
    "conceperilor": "concepere",
    "concepte": "concept",
    "conceptele": "concept",
    "conceptelor": "concept",
    "conceptul": "concept",
    "conceptule": "concept",
    "conceptului": "concept",
    "concepția": "concepție",
    "concepției": "concepție",
    "concepții": "concepție",
    "concepțiile": "concepție",
    "concepțiilor": "concepție",
    "concepțio": "concepție",
    "conceptuala": "conceptual",
    "conceptuală": "conceptual",
    "conceptuale": "conceptual",
    "conceptualei": "conceptual",
    "conceptualele": "conceptual",
    "conceptualelor": "conceptual",
    "conceptuali": "conceptual",
    "conceptualii": "conceptual",
    "conceptualilor": "conceptual",
    "conceptualo": "conceptual",
    "conceptualul": "conceptual",
    "conceptualule": "conceptual",
    "conceptualului": "conceptual",
    "concepută": "conceput",
    "concepute": "conceput",
    "concepuți": "conceput",
    "concerne": "concern",
    "concernele": "concern",
    "concernelor": "concern",
    "concernul": "concern",
    "concernule": "concern",
    "concernului": "concern",
    "concerte": "concert",
    "concertele": "concert",
    "concertelor": "concert",
    "concertul": "concert",
    "concertule": "concert",
    "concertului": "concert",
    "concertă": "concerta",
    "concertai": "concerta",
    "concertam": "concerta",
    "concertăm": "concerta",
    "concertând": "concerta",
    "concertându": "concerta",
    "concertară": "concerta",
    "concertarăm": "concerta",
    "concertarăți": "concerta",
    "concertase": "concerta",
    "concertasem": "concerta",
    "concertaseră": "concerta",
    "concertaserăm": "concerta",
    "concertaserăți": "concerta",
    "concertaseși": "concerta",
    "concertași": "concerta",
    "concertat": "concerta",
    "concertați": "concerta",
    "concertatu": "concerta",
    "concertau": "concerta",
    "concertează": "concerta",
    "concertez": "concerta",
    "concerteze": "concerta",
    "concertezi": "concerta",
    "neconcertând": "concerta",
    "neconcertându": "concerta",
    "nemaiconcertând": "concerta",
    "nemaiconcertându": "concerta",
    "concertanta": "concertant",
    "concertantă": "concertant",
    "concertante": "concertant",
    "concertantei": "concertant",
    "concertantele": "concertant",
    "concertantelor": "concertant",
    "concertanți": "concertant",
    "concertanții": "concertant",
    "concertanților": "concertant",
    "concertanto": "concertant",
    "concertantul": "concertant",
    "concertantule": "concertant",
    "concertantului": "concertant",
    "concertată": "concertat",
    "concertate": "concertat",
    "concertați": "concertat",
    "concertiști": "concertist",
    "concertiștii": "concertist",
    "concertiștilor": "concertist",
    "concertistul": "concertist",
    "concertistule": "concertist",
    "concertistului": "concertist",
    "concertista": "concertistă",
    "concertiste": "concertistă",
    "concertistei": "concertistă",
    "concertistele": "concertistă",
    "concertistelor": "concertistă",
    "concertisto": "concertistă",
    "concertmaiștri": "concertmaistru",
    "concertmaiștrii": "concertmaistru",
    "concertmaiștrilor": "concertmaistru",
    "concertmaistrul": "concertmaistru",
    "concertmaistrule": "concertmaistru",
    "concertmaistrului": "concertmaistru",
    "concesia": "concesie",
    "concesiei": "concesie",
    "concesii": "concesie",
    "concesiile": "concesie",
    "concesiilor": "concesie",
    "concesio": "concesie",
    "concesionă": "concesiona",
    "concesionai": "concesiona",
    "concesionam": "concesiona",
    "concesionăm": "concesiona",
    "concesionând": "concesiona",
    "concesionându": "concesiona",
    "concesionară": "concesiona",
    "concesionarăm": "concesiona",
    "concesionarăți": "concesiona",
    "concesionase": "concesiona",
    "concesionasem": "concesiona",
    "concesionaseră": "concesiona",
    "concesionaserăm": "concesiona",
    "concesionaserăți": "concesiona",
    "concesionaseși": "concesiona",
    "concesionași": "concesiona",
    "concesionat": "concesiona",
    "concesionați": "concesiona",
    "concesionatu": "concesiona",
    "concesionau": "concesiona",
    "concesionează": "concesiona",
    "concesionez": "concesiona",
    "concesioneze": "concesiona",
    "concesionezi": "concesiona",
    "neconcesionând": "concesiona",
    "neconcesionându": "concesiona",
    "nemaiconcesionând": "concesiona",
    "nemaiconcesionându": "concesiona",
    "concesionari": "concesionar",
    "concesionarii": "concesionar",
    "concesionarilor": "concesionar",
    "concesionarul": "concesionar",
    "concesionarule": "concesionar",
    "concesionarului": "concesionar",
    "concesionarea": "concesionare",
    "concesionareo": "concesionare",
    "concesionări": "concesionare",
    "concesionării": "concesionare",
    "concesionările": "concesionare",
    "concesionărilor": "concesionare",
    "concesionată": "concesionat",
    "concesionate": "concesionat",
    "concesionați": "concesionat",
    "concesiunea": "concesiune",
    "concesiuneo": "concesiune",
    "concesiuni": "concesiune",
    "concesiunii": "concesiune",
    "concesiunile": "concesiune",
    "concesiunilor": "concesiune",
    "concesiva": "concesiv",
    "concesivă": "concesiv",
    "concesive": "concesiv",
    "concesivei": "concesiv",
    "concesivele": "concesiv",
    "concesivelor": "concesiv",
    "concesivi": "concesiv",
    "concesivii": "concesiv",
    "concesivilor": "concesiv",
    "concesivo": "concesiv",
    "concesivul": "concesiv",
    "concesivule": "concesiv",
    "concesivului": "concesiv",
    "concetățeanul": "concetățean",
    "concetățeanule": "concetățean",
    "concetățeanului": "concetățean",
    "concetățeni": "concetățean",
    "concetățenii": "concetățean",
    "concetățenilor": "concetățean",
    "concetățeana": "concetățeană",
    "concetățeano": "concetățeană",
    "concetățene": "concetățeană",
    "concetățenei": "concetățeană",
    "concetățenele": "concetățeană",
    "concetățenelor": "concetățeană",
    "conchid": "conchide",
    "conchidă": "conchide",
    "conchidea": "conchide",
    "conchideai": "conchide",
    "conchideam": "conchide",
    "conchideați": "conchide",
    "conchideau": "conchide",
    "conchidem": "conchide",
    "conchideți": "conchide",
    "conchis": "conchide",
    "conchise": "conchide",
    "conchisei": "conchide",
    "conchiseră": "conchide",
    "conchiserăm": "conchide",
    "conchiserăți": "conchide",
    "conchisese": "conchide",
    "conchisesem": "conchide",
    "conchiseseră": "conchide",
    "conchiseserăm": "conchide",
    "conchiseserăți": "conchide",
    "conchiseseși": "conchide",
    "conchiseși": "conchide",
    "conchisu": "conchide",
    "conchizând": "conchide",
    "conchizându": "conchide",
    "conchizi": "conchide",
    "neconchizând": "conchide",
    "neconchizându": "conchide",
    "nemaiconchizând": "conchide",
    "nemaiconchizându": "conchide",
    "conchisă": "conchis",
    "conchise": "conchis",
    "conchiși": "conchis",
    "conchista": "conchistă",
    "conchiste": "conchistă",
    "conchistei": "conchistă",
    "conchistele": "conchistă",
    "conchistelor": "conchistă",
    "conchisto": "conchistă",
    "conchistadori": "conchistador",
    "conchistadorii": "conchistador",
    "conchistadorilor": "conchistador",
    "conchistadorul": "conchistador",
    "conchistadorule": "conchistador",
    "conchistadorului": "conchistador",
    "conciul": "conci",
    "conciule": "conci",
    "conciului": "conci",
    "conciuri": "conci",
    "conciurile": "conci",
    "conciurilor": "conci",
    "conciliai": "concilia",
    "conciliam": "concilia",
    "conciliară": "concilia",
    "conciliarăm": "concilia",
    "conciliarăți": "concilia",
    "conciliase": "concilia",
    "conciliasem": "concilia",
    "conciliaseră": "concilia",
    "conciliaserăm": "concilia",
    "conciliaserăți": "concilia",
    "conciliaseși": "concilia",
    "conciliași": "concilia",
    "conciliat": "concilia",
    "conciliați": "concilia",
    "conciliatu": "concilia",
    "conciliau": "concilia",
    "conciliază": "concilia",
    "concilie": "concilia",
    "conciliem": "concilia",
    "conciliez": "concilia",
    "concilieze": "concilia",
    "conciliezi": "concilia",
    "conciliind": "concilia",
    "conciliindu": "concilia",
    "neconciliind": "concilia",
    "neconciliindu": "concilia",
    "nemaiconciliind": "concilia",
    "nemaiconciliindu": "concilia",
    "conciliabule": "conciliabul",
    "conciliabulele": "conciliabul",
    "conciliabulelor": "conciliabul",
    "conciliabulul": "conciliabul",
    "conciliabulule": "conciliabul",
    "conciliabulului": "conciliabul",
    "concilianta": "conciliant",
    "conciliantă": "conciliant",
    "conciliante": "conciliant",
    "conciliantei": "conciliant",
    "conciliantele": "conciliant",
    "conciliantelor": "conciliant",
    "concilianți": "conciliant",
    "concilianții": "conciliant",
    "concilianților": "conciliant",
    "concilianto": "conciliant",
    "conciliantul": "conciliant",
    "conciliantule": "conciliant",
    "conciliantului": "conciliant",
    "conciliată": "conciliat",
    "conciliate": "conciliat",
    "conciliați": "conciliat",
    "conciliația": "conciliație",
    "conciliației": "conciliație",
    "conciliații": "conciliație",
    "conciliațiile": "conciliație",
    "conciliațiilor": "conciliație",
    "conciliațio": "conciliație",
    "conciliatoare": "conciliator",
    "conciliatoarea": "conciliator",
    "conciliatoarei": "conciliator",
    "conciliatoarele": "conciliator",
    "conciliatoarelor": "conciliator",
    "conciliatoareo": "conciliator",
    "conciliatori": "conciliator",
    "conciliatorii": "conciliator",
    "conciliatorilor": "conciliator",
    "conciliatorul": "conciliator",
    "conciliatorule": "conciliator",
    "conciliatorului": "conciliator",
    "concilierea": "conciliere",
    "conciliereo": "conciliere",
    "concilieri": "conciliere",
    "concilierii": "conciliere",
    "concilierile": "conciliere",
    "concilierilor": "conciliere",
    "concilii": "conciliu",
    "conciliile": "conciliu",
    "conciliilor": "conciliu",
    "conciliul": "conciliu",
    "conciliule": "conciliu",
    "conciliului": "conciliu",
    "concisa": "concis",
    "concisă": "concis",
    "concise": "concis",
    "concisei": "concis",
    "concisele": "concis",
    "conciselor": "concis",
    "conciși": "concis",
    "concișii": "concis",
    "concișilor": "concis",
    "conciso": "concis",
    "concisul": "concis",
    "concisule": "concis",
    "concisului": "concis",
    "concitadina": "concitadin",
    "concitadină": "concitadin",
    "concitadine": "concitadin",
    "concitadinei": "concitadin",
    "concitadinele": "concitadin",
    "concitadinelor": "concitadin",
    "concitadini": "concitadin",
    "concitadinii": "concitadin",
    "concitadinilor": "concitadin",
    "concitadino": "concitadin",
    "concitadinul": "concitadin",
    "concitadinule": "concitadin",
    "concitadinului": "concitadin",
    "concitadina": "concitadină",
    "concitadine": "concitadină",
    "concitadinei": "concitadină",
    "concitadinele": "concitadină",
    "concitadinelor": "concitadină",
    "concitadino": "concitadină",
    "concizia": "concizie",
    "conciziei": "concizie",
    "concizii": "concizie",
    "conclave": "conclav",
    "conclavele": "conclav",
    "conclavelor": "conclav",
    "conclavul": "conclav",
    "conclavule": "conclav",
    "conclavului": "conclav",
    "concludenta": "concludent",
    "concludentă": "concludent",
    "concludente": "concludent",
    "concludentei": "concludent",
    "concludentele": "concludent",
    "concludentelor": "concludent",
    "concludenți": "concludent",
    "concludenții": "concludent",
    "concludenților": "concludent",
    "concludento": "concludent",
    "concludentul": "concludent",
    "concludentule": "concludent",
    "concludentului": "concludent",
    "conclusiva": "conclusiv",
    "conclusivă": "conclusiv",
    "conclusive": "conclusiv",
    "conclusivei": "conclusiv",
    "conclusivele": "conclusiv",
    "conclusivelor": "conclusiv",
    "conclusivi": "conclusiv",
    "conclusivii": "conclusiv",
    "conclusivilor": "conclusiv",
    "conclusivo": "conclusiv",
    "conclusivul": "conclusiv",
    "conclusivule": "conclusiv",
    "conclusivului": "conclusiv",
    "concluzia": "concluzie",
    "concluziei": "concluzie",
    "concluzii": "concluzie",
    "concluziile": "concluzie",
    "concluziilor": "concluzie",
    "concluzio": "concluzie",
    "concluzionă": "concluziona",
    "concluzionai": "concluziona",
    "concluzionam": "concluziona",
    "concluzionăm": "concluziona",
    "concluzionând": "concluziona",
    "concluzionându": "concluziona",
    "concluzionară": "concluziona",
    "concluzionarăm": "concluziona",
    "concluzionarăți": "concluziona",
    "concluzionase": "concluziona",
    "concluzionasem": "concluziona",
    "concluzionaseră": "concluziona",
    "concluzionaserăm": "concluziona",
    "concluzionaserăți": "concluziona",
    "concluzionaseși": "concluziona",
    "concluzionași": "concluziona",
    "concluzionat": "concluziona",
    "concluzionați": "concluziona",
    "concluzionatu": "concluziona",
    "concluzionau": "concluziona",
    "concluzionează": "concluziona",
    "concluzionez": "concluziona",
    "concluzioneze": "concluziona",
    "concluzionezi": "concluziona",
    "concluzionată": "concluzionat",
    "concluzionate": "concluzionat",
    "concluzionați": "concluzionat",
    "concluziunea": "concluziune",
    "concluziuneo": "concluziune",
    "concluziuni": "concluziune",
    "concluziunii": "concluziune",
    "concluziunile": "concluziune",
    "concluziunilor": "concluziune",
    "concomitenta": "concomitent",
    "concomitentă": "concomitent",
    "concomitente": "concomitent",
    "concomitentei": "concomitent",
    "concomitentele": "concomitent",
    "concomitentelor": "concomitent",
    "concomitenți": "concomitent",
    "concomitenții": "concomitent",
    "concomitenților": "concomitent",
    "concomitento": "concomitent",
    "concomitentul": "concomitent",
    "concomitentule": "concomitent",
    "concomitentului": "concomitent",
    "concord": "concorda",
    "concordă": "concorda",
    "concordai": "concorda",
    "concordam": "concorda",
    "concordăm": "concorda",
    "concordând": "concorda",
    "concordându": "concorda",
    "concordară": "concorda",
    "concordarăm": "concorda",
    "concordarăți": "concorda",
    "concordase": "concorda",
    "concordasem": "concorda",
    "concordaseră": "concorda",
    "concordaserăm": "concorda",
    "concordaserăți": "concorda",
    "concordaseși": "concorda",
    "concordași": "concorda",
    "concordat": "concorda",
    "concordați": "concorda",
    "concordatu": "concorda",
    "concordau": "concorda",
    "concorde": "concorda",
    "concorzi": "concorda",
    "neconcordând": "concorda",
    "neconcordându": "concorda",
    "nemaiconcordând": "concorda",
    "nemaiconcordându": "concorda",
    "concordanța": "concordanță",
    "concordanțe": "concordanță",
    "concordanței": "concordanță",
    "concordanțele": "concordanță",
    "concordanțelor": "concordanță",
    "concordanțo": "concordanță",
    "concordată": "concordat",
    "concordate": "concordat",
    "concordatele": "concordat",
    "concordatelor": "concordat",
    "concordați": "concordat",
    "concordatul": "concordat",
    "concordatule": "concordat",
    "concordatului": "concordat",
    "concordia": "concordie",
    "concordiei": "concordie",
    "concordii": "concordie",
    "concordiile": "concordie",
    "concordiilor": "concordie",
    "concordio": "concordie",
    "concr.": "concret",
    "concreta": "concret",
    "concretă": "concret",
    "concrete": "concret",
    "concretei": "concret",
    "concretele": "concret",
    "concretelor": "concret",
    "concreți": "concret",
    "concreții": "concret",
    "concreților": "concret",
    "concreto": "concret",
    "concretul": "concret",
    "concretule": "concret",
    "concretului": "concret",
    "concretețea": "concretețe",
    "concretețeo": "concretețe",
    "concreteți": "concretețe",
    "concreteții": "concretețe",
    "concreționarea": "concreționare",
    "concreționareo": "concreționare",
    "concreționări": "concreționare",
    "concreționării": "concreționare",
    "concreționările": "concreționare",
    "concreționărilor": "concreționare",
    "concrețiunea": "concrețiune",
    "concrețiuneo": "concrețiune",
    "concrețiuni": "concrețiune",
    "concrețiunii": "concrețiune",
    "concrețiunile": "concrețiune",
    "concrețiunilor": "concrețiune",
    "concretiză": "concretiza",
    "concretizai": "concretiza",
    "concretizam": "concretiza",
    "concretizăm": "concretiza",
    "concretizând": "concretiza",
    "concretizându": "concretiza",
    "concretizară": "concretiza",
    "concretizarăm": "concretiza",
    "concretizarăți": "concretiza",
    "concretizase": "concretiza",
    "concretizasem": "concretiza",
    "concretizaseră": "concretiza",
    "concretizaserăm": "concretiza",
    "concretizaserăți": "concretiza",
    "concretizaseși": "concretiza",
    "concretizași": "concretiza",
    "concretizat": "concretiza",
    "concretizați": "concretiza",
    "concretizatu": "concretiza",
    "concretizau": "concretiza",
    "concretizează": "concretiza",
    "concretizez": "concretiza",
    "concretizeze": "concretiza",
    "concretizezi": "concretiza",
    "neconcretizând": "concretiza",
    "neconcretizându": "concretiza",
    "nemaiconcretizând": "concretiza",
    "nemaiconcretizându": "concretiza",
    "concretizarea": "concretizare",
    "concretizareo": "concretizare",
    "concretizări": "concretizare",
    "concretizării": "concretizare",
    "concretizările": "concretizare",
    "concretizărilor": "concretizare",
    "concretizată": "concretizat",
    "concretizate": "concretizat",
    "concretizați": "concretizat",
    "concubini": "concubin",
    "concubinii": "concubin",
    "concubinilor": "concubin",
    "concubinul": "concubin",
    "concubinule": "concubin",
    "concubinului": "concubin",
    "concubina": "concubină",
    "concubine": "concubină",
    "concubinei": "concubină",
    "concubinele": "concubină",
    "concubinelor": "concubină",
    "concubino": "concubină",
    "concubinaje": "concubinaj",
    "concubinajele": "concubinaj",
    "concubinajelor": "concubinaj",
    "concubinajul": "concubinaj",
    "concubinajule": "concubinaj",
    "concubinajului": "concubinaj",
    "concupiscența": "concupiscență",
    "concupiscențe": "concupiscență",
    "concupiscenței": "concupiscență",
    "concură": "concura",
    "concurai": "concura",
    "concuram": "concura",
    "concurăm": "concura",
    "concurând": "concura",
    "concurându": "concura",
    "concurară": "concura",
    "concurarăm": "concura",
    "concurarăți": "concura",
    "concurase": "concura",
    "concurasem": "concura",
    "concuraseră": "concura",
    "concuraserăm": "concura",
    "concuraserăți": "concura",
    "concuraseși": "concura",
    "concurași": "concura",
    "concurat": "concura",
    "concurați": "concura",
    "concuratu": "concura",
    "concurau": "concura",
    "concurează": "concura",
    "concurez": "concura",
    "concureze": "concura",
    "concurezi": "concura",
    "neconcurând": "concura",
    "neconcurându": "concura",
    "nemaiconcurând": "concura",
    "nemaiconcurându": "concura",
    "concurată": "concurat",
    "concurate": "concurat",
    "concurați": "concurat",
    "concurenți": "concurent",
    "concurenții": "concurent",
    "concurenților": "concurent",
    "concurentul": "concurent",
    "concurentului": "concurent",
    "concurența": "concurență",
    "concurențe": "concurență",
    "concurenței": "concurență",
    "concurențele": "concurență",
    "concurențelor": "concurență",
    "concurențo": "concurență",
    "concurențiala": "concurențial",
    "concurențială": "concurențial",
    "concurențiale": "concurențial",
    "concurențialei": "concurențial",
    "concurențialele": "concurențial",
    "concurențialelor": "concurențial",
    "concurențiali": "concurențial",
    "concurențialii": "concurențial",
    "concurențialilor": "concurențial",
    "concurențialo": "concurențial",
    "concurențialul": "concurențial",
    "concurențialule": "concurențial",
    "concurențialului": "concurențial",
    "concursul": "concurs",
    "concursule": "concurs",
    "concursului": "concurs",
    "concursuri": "concurs",
    "concursurile": "concurs",
    "concursurilor": "concurs",
    "condamn": "condamna",
    "condamnă": "condamna",
    "condamnai": "condamna",
    "condamnam": "condamna",
    "condamnăm": "condamna",
    "condamnând": "condamna",
    "condamnându": "condamna",
    "condamnară": "condamna",
    "condamnarăm": "condamna",
    "condamnarăți": "condamna",
    "condamnase": "condamna",
    "condamnasem": "condamna",
    "condamnaseră": "condamna",
    "condamnaserăm": "condamna",
    "condamnaserăți": "condamna",
    "condamnaseși": "condamna",
    "condamnași": "condamna",
    "condamnat": "condamna",
    "condamnați": "condamna",
    "condamnatu": "condamna",
    "condamnau": "condamna",
    "condamne": "condamna",
    "condamni": "condamna",
    "necondamnând": "condamna",
    "necondamnându": "condamna",
    "nemaicondamnând": "condamna",
    "nemaicondamnându": "condamna",
    "condamnabila": "condamnabil",
    "condamnabilă": "condamnabil",
    "condamnabile": "condamnabil",
    "condamnabilei": "condamnabil",
    "condamnabilele": "condamnabil",
    "condamnabilelor": "condamnabil",
    "condamnabili": "condamnabil",
    "condamnabilii": "condamnabil",
    "condamnabililor": "condamnabil",
    "condamnabilo": "condamnabil",
    "condamnabilul": "condamnabil",
    "condamnabilule": "condamnabil",
    "condamnabilului": "condamnabil",
    "condamnarea": "condamnare",
    "condamnareo": "condamnare",
    "condamnări": "condamnare",
    "condamnării": "condamnare",
    "condamnările": "condamnare",
    "condamnărilor": "condamnare",
    "condamnată": "condamnat",
    "condamnate": "condamnat",
    "condamnați": "condamnat",
    "condamnații": "condamnat",
    "condamnaților": "condamnat",
    "condamnatul": "condamnat",
    "condamnatule": "condamnat",
    "condamnatului": "condamnat",
    "condamnata": "condamnată",
    "condamnate": "condamnată",
    "condamnatei": "condamnată",
    "condamnatele": "condamnată",
    "condamnatelor": "condamnată",
    "condamnato": "condamnată",
    "condeie": "condei",
    "condeiele": "condei",
    "condeielor": "condei",
    "condeiul": "condei",
    "condeiule": "condei",
    "condeiului": "condei",
    "condeiașe": "condeiaș",
    "condeiașele": "condeiaș",
    "condeiașelor": "condeiaș",
    "condeiașul": "condeiaș",
    "condeiașule": "condeiaș",
    "condeiașului": "condeiaș",
    "condeieri": "condeier",
    "condeierii": "condeier",
    "condeierilor": "condeier",
    "condeierul": "condeier",
    "condeierule": "condeier",
    "condeierului": "condeier",
    "condensă": "condensa",
    "condensai": "condensa",
    "condensam": "condensa",
    "condensăm": "condensa",
    "condensând": "condensa",
    "condensându": "condensa",
    "condensară": "condensa",
    "condensarăm": "condensa",
    "condensarăți": "condensa",
    "condensase": "condensa",
    "condensasem": "condensa",
    "condensaseră": "condensa",
    "condensaserăm": "condensa",
    "condensaserăți": "condensa",
    "condensaseși": "condensa",
    "condensași": "condensa",
    "condensat": "condensa",
    "condensați": "condensa",
    "condensatu": "condensa",
    "condensau": "condensa",
    "condensează": "condensa",
    "condensez": "condensa",
    "condenseze": "condensa",
    "condensezi": "condensa",
    "necondensând": "condensa",
    "necondensându": "condensa",
    "nemaicondensând": "condensa",
    "nemaicondensându": "condensa",
    "condensabila": "condensabil",
    "condensabilă": "condensabil",
    "condensabile": "condensabil",
    "condensabilei": "condensabil",
    "condensabilele": "condensabil",
    "condensabilelor": "condensabil",
    "condensabili": "condensabil",
    "condensabilii": "condensabil",
    "condensabililor": "condensabil",
    "condensabilo": "condensabil",
    "condensabilul": "condensabil",
    "condensabilule": "condensabil",
    "condensabilului": "condensabil",
    "condensarea": "condensare",
    "condensareo": "condensare",
    "condensări": "condensare",
    "condensării": "condensare",
    "condensările": "condensare",
    "condensărilor": "condensare",
    "condensata": "condensat",
    "condensată": "condensat",
    "condensate": "condensat",
    "condensatei": "condensat",
    "condensatele": "condensat",
    "condensatelor": "condensat",
    "condensați": "condensat",
    "condensații": "condensat",
    "condensaților": "condensat",
    "condensato": "condensat",
    "condensatul": "condensat",
    "condensatule": "condensat",
    "condensatului": "condensat",
    "condensatoare": "condensator",
    "condensatoarele": "condensator",
    "condensatoarelor": "condensator",
    "condensatorul": "condensator",
    "condensatorule": "condensator",
    "condensatorului": "condensator",
    "condensoare": "condensor",
    "condensoarele": "condensor",
    "condensoarelor": "condensor",
    "condensorul": "condensor",
    "condensorule": "condensor",
    "condensorului": "condensor",
    "condescendenta": "condescendent",
    "condescendentă": "condescendent",
    "condescendente": "condescendent",
    "condescendentei": "condescendent",
    "condescendentele": "condescendent",
    "condescendentelor": "condescendent",
    "condescendenți": "condescendent",
    "condescendenții": "condescendent",
    "condescendenților": "condescendent",
    "condescendento": "condescendent",
    "condescendentul": "condescendent",
    "condescendentule": "condescendent",
    "condescendentului": "condescendent",
    "condescendența": "condescendență",
    "condescendențe": "condescendență",
    "condescendenței": "condescendență",
    "condescendențele": "condescendență",
    "condescendențelor": "condescendență",
    "condescendențo": "condescendență",
    "condica": "condică",
    "condici": "condică",
    "condicii": "condică",
    "condicile": "condică",
    "condicilor": "condică",
    "condico": "condică",
    "condicuța": "condicuță",
    "condicuțe": "condicuță",
    "condicuței": "condicuță",
    "condicuțele": "condicuță",
    "condicuțelor": "condicuță",
    "condicuțo": "condicuță",
    "condimente": "condiment",
    "condimentele": "condiment",
    "condimentelor": "condiment",
    "condimentul": "condiment",
    "condimentule": "condiment",
    "condimentului": "condiment",
    "condimentă": "condimenta",
    "condimentai": "condimenta",
    "condimentam": "condimenta",
    "condimentăm": "condimenta",
    "condimentând": "condimenta",
    "condimentându": "condimenta",
    "condimentară": "condimenta",
    "condimentarăm": "condimenta",
    "condimentarăți": "condimenta",
    "condimentase": "condimenta",
    "condimentasem": "condimenta",
    "condimentaseră": "condimenta",
    "condimentaserăm": "condimenta",
    "condimentaserăți": "condimenta",
    "condimentaseși": "condimenta",
    "condimentași": "condimenta",
    "condimentat": "condimenta",
    "condimentați": "condimenta",
    "condimentatu": "condimenta",
    "condimentau": "condimenta",
    "condimentează": "condimenta",
    "condimentez": "condimenta",
    "condimenteze": "condimenta",
    "condimentezi": "condimenta",
    "necondimentând": "condimenta",
    "necondimentându": "condimenta",
    "nemaicondimentând": "condimenta",
    "nemaicondimentându": "condimenta",
    "condimentată": "condimentat",
    "condimentate": "condimentat",
    "condimentați": "condimentat",
    "condiția": "condiție",
    "condiției": "condiție",
    "condiții": "condiție",
    "condițiile": "condiție",
    "condițiilor": "condiție",
    "condițio": "condiție",
    "condiționă": "condiționa",
    "condiționai": "condiționa",
    "condiționam": "condiționa",
    "condiționăm": "condiționa",
    "condiționând": "condiționa",
    "condiționându": "condiționa",
    "condiționară": "condiționa",
    "condiționarăm": "condiționa",
    "condiționarăți": "condiționa",
    "condiționase": "condiționa",
    "condiționasem": "condiționa",
    "condiționaseră": "condiționa",
    "condiționaserăm": "condiționa",
    "condiționaserăți": "condiționa",
    "condiționaseși": "condiționa",
    "condiționași": "condiționa",
    "condiționat": "condiționa",
    "condiționați": "condiționa",
    "condiționatu": "condiționa",
    "condiționau": "condiționa",
    "condiționează": "condiționa",
    "condiționez": "condiționa",
    "condiționeze": "condiționa",
    "condiționezi": "condiționa",
    "necondiționând": "condiționa",
    "necondiționându": "condiționa",
    "nemaicondiționând": "condiționa",
    "nemaicondiționându": "condiționa",
    "condiționala": "condițional",
    "condițională": "condițional",
    "condiționale": "condițional",
    "condiționalei": "condițional",
    "condiționalele": "condițional",
    "condiționalelor": "condițional",
    "condiționali": "condițional",
    "condiționalii": "condițional",
    "condiționalilor": "condițional",
    "condiționalo": "condițional",
    "condiționalul": "condițional",
    "condiționalule": "condițional",
    "condiționalului": "condițional",
    "condiționarea": "condiționare",
    "condiționareo": "condiționare",
    "condiționări": "condiționare",
    "condiționării": "condiționare",
    "condiționările": "condiționare",
    "condiționărilor": "condiționare",
    "condiționata": "condiționat",
    "condiționată": "condiționat",
    "condiționate": "condiționat",
    "condiționatei": "condiționat",
    "condiționatele": "condiționat",
    "condiționatelor": "condiționat",
    "condiționați": "condiționat",
    "condiționații": "condiționat",
    "condiționaților": "condiționat",
    "condiționato": "condiționat",
    "condiționatul": "condiționat",
    "condiționatule": "condiționat",
    "condiționatului": "condiționat",
    "condițiunea": "condițiune",
    "condițiuneo": "condițiune",
    "condițiuni": "condițiune",
    "condițiunii": "condițiune",
    "condițiunile": "condițiune",
    "condițiunilor": "condițiune",
    "condoleanțele": "condoleanțe",
    "condoleanțelor": "condoleanțe",
    "condori": "condor",
    "condorii": "condor",
    "condorilor": "condor",
    "condorul": "condor",
    "condorule": "condor",
    "condorului": "condor",
    "condotieri": "condotier",
    "condotierii": "condotier",
    "condotierilor": "condotier",
    "condotierul": "condotier",
    "condotierule": "condotier",
    "condotierului": "condotier",
    "conducătoarea": "conducătoare",
    "conducătoarei": "conducătoare",
    "conducătoarele": "conducătoare",
    "conducătoarelor": "conducătoare",
    "conducătoareo": "conducătoare",
    "conducătoare": "conducător",
    "conducătoarea": "conducător",
    "conducătoarei": "conducător",
    "conducătoarele": "conducător",
    "conducătoarelor": "conducător",
    "conducătoareo": "conducător",
    "conducători": "conducător",
    "conducătorii": "conducător",
    "conducătorilor": "conducător",
    "conducătorul": "conducător",
    "conducătorule": "conducător",
    "conducătorului": "conducător",
    "condu": "conduce",
    "conduc": "conduce",
    "conducă": "conduce",
    "conducând": "conduce",
    "conducându": "conduce",
    "conducea": "conduce",
    "conduceai": "conduce",
    "conduceam": "conduce",
    "conduceați": "conduce",
    "conduceau": "conduce",
    "conducem": "conduce",
    "conduceți": "conduce",
    "conduci": "conduce",
    "condus": "conduce",
    "conduse": "conduce",
    "condusei": "conduce",
    "conduseră": "conduce",
    "conduserăm": "conduce",
    "conduserăți": "conduce",
    "condusese": "conduce",
    "condusesem": "conduce",
    "conduseseră": "conduce",
    "conduseserăm": "conduce",
    "conduseserăți": "conduce",
    "conduseseși": "conduce",
    "conduseși": "conduce",
    "condusu": "conduce",
    "neconducând": "conduce",
    "neconducându": "conduce",
    "nemaiconducând": "conduce",
    "nemaiconducându": "conduce",
    "conducerea": "conducere",
    "conducereo": "conducere",
    "conduceri": "conducere",
    "conducerii": "conducere",
    "conducerile": "conducere",
    "conducerilor": "conducere",
    "conducta": "conductă",
    "conducte": "conductă",
    "conductei": "conductă",
    "conductele": "conductă",
    "conductelor": "conductă",
    "conducto": "conductă",
    "conductibila": "conductibil",
    "conductibilă": "conductibil",
    "conductibile": "conductibil",
    "conductibilei": "conductibil",
    "conductibilele": "conductibil",
    "conductibilelor": "conductibil",
    "conductibili": "conductibil",
    "conductibilii": "conductibil",
    "conductibililor": "conductibil",
    "conductibilo": "conductibil",
    "conductibilul": "conductibil",
    "conductibilule": "conductibil",
    "conductibilului": "conductibil",
    "conductibilitatea": "conductibilitate",
    "conductibilități": "conductibilitate",
    "conductibilității": "conductibilitate",
    "conductivitatea": "conductivitate",
    "conductivitateo": "conductivitate",
    "conductivități": "conductivitate",
    "conductivității": "conductivitate",
    "conductivitățile": "conductivitate",
    "conductivităților": "conductivitate",
    "conductoarea": "conductoare",
    "conductoarei": "conductoare",
    "conductoarele": "conductoare",
    "conductoarelor": "conductoare",
    "conductoareo": "conductoare",
    "conductoare": "conductor",
    "conductoarea": "conductor",
    "conductoarei": "conductor",
    "conductoarele": "conductor",
    "conductoarelor": "conductor",
    "conductori": "conductor",
    "conductorii": "conductor",
    "conductorilor": "conductor",
    "conductorul": "conductor",
    "conductorule": "conductor",
    "conductorului": "conductor",
    "conduita": "conduită",
    "conduite": "conduită",
    "conduitei": "conduită",
    "conduitele": "conduită",
    "conduitelor": "conduită",
    "conduito": "conduită",
    "conduri": "condur",
    "condurii": "condur",
    "condurilor": "condur",
    "condurul": "condur",
    "condurule": "condur",
    "condurului": "condur",
    "condusă": "condus",
    "conduse": "condus",
    "conduși": "condus",
    "conectă": "conecta",
    "conectai": "conecta",
    "conectam": "conecta",
    "conectăm": "conecta",
    "conectând": "conecta",
    "conectându": "conecta",
    "conectară": "conecta",
    "conectarăm": "conecta",
    "conectarăți": "conecta",
    "conectase": "conecta",
    "conectasem": "conecta",
    "conectaseră": "conecta",
    "conectaserăm": "conecta",
    "conectaserăți": "conecta",
    "conectaseși": "conecta",
    "conectași": "conecta",
    "conectat": "conecta",
    "conectați": "conecta",
    "conectatu": "conecta",
    "conectau": "conecta",
    "conectează": "conecta",
    "conectez": "conecta",
    "conecteze": "conecta",
    "conectezi": "conecta",
    "neconectând": "conecta",
    "neconectându": "conecta",
    "nemaiconectând": "conecta",
    "nemaiconectându": "conecta",
    "conectarea": "conectare",
    "conectareo": "conectare",
    "conectări": "conectare",
    "conectării": "conectare",
    "conectările": "conectare",
    "conectărilor": "conectare",
    "conectată": "conectat",
    "conectate": "conectat",
    "conectați": "conectat",
    "conectoare": "conector",
    "conectoarea": "conector",
    "conectoarei": "conector",
    "conectoarele": "conector",
    "conectoarelor": "conector",
    "conectoareo": "conector",
    "conectori": "conector",
    "conectorii": "conector",
    "conectorilor": "conector",
    "conectorul": "conector",
    "conectorule": "conector",
    "conectorului": "conector",
    "conecși": "conex",
    "conecșii": "conex",
    "conecșilor": "conex",
    "conexa": "conex",
    "conexă": "conex",
    "conexe": "conex",
    "conexei": "conex",
    "conexele": "conex",
    "conexelor": "conex",
    "conexo": "conex",
    "conexul": "conex",
    "conexule": "conex",
    "conexului": "conex",
    "conexă": "conexa",
    "conexai": "conexa",
    "conexam": "conexa",
    "conexăm": "conexa",
    "conexând": "conexa",
    "conexându": "conexa",
    "conexară": "conexa",
    "conexarăm": "conexa",
    "conexarăți": "conexa",
    "conexase": "conexa",
    "conexasem": "conexa",
    "conexaseră": "conexa",
    "conexaserăm": "conexa",
    "conexaserăți": "conexa",
    "conexaseși": "conexa",
    "conexași": "conexa",
    "conexat": "conexa",
    "conexați": "conexa",
    "conexatu": "conexa",
    "conexau": "conexa",
    "conexează": "conexa",
    "conexez": "conexa",
    "conexeze": "conexa",
    "conexezi": "conexa",
    "neconexând": "conexa",
    "neconexându": "conexa",
    "nemaiconexând": "conexa",
    "nemaiconexându": "conexa",
    "conexarea": "conexare",
    "conexareo": "conexare",
    "conexări": "conexare",
    "conexării": "conexare",
    "conexările": "conexare",
    "conexărilor": "conexare",
    "conexată": "conexat",
    "conexate": "conexat",
    "conexați": "conexat",
    "conexitatea": "conexitate",
    "conexitateo": "conexitate",
    "conexități": "conexitate",
    "conexității": "conexitate",
    "conexitățile": "conexitate",
    "conexităților": "conexitate",
    "conexiunea": "conexiune",
    "conexiuni": "conexiune",
    "conexiunii": "conexiune",
    "conexiunile": "conexiune",
    "conexiunilor": "conexiune",
    "confecția": "confecție",
    "confecției": "confecție",
    "confecții": "confecție",
    "confecțiile": "confecție",
    "confecțiilor": "confecție",
    "confecțio": "confecție",
    "conf.": "confecții",
    "confecționă": "confecționa",
    "confecționai": "confecționa",
    "confecționam": "confecționa",
    "confecționăm": "confecționa",
    "confecționând": "confecționa",
    "confecționându": "confecționa",
    "confecționară": "confecționa",
    "confecționarăm": "confecționa",
    "confecționarăți": "confecționa",
    "confecționase": "confecționa",
    "confecționasem": "confecționa",
    "confecționaseră": "confecționa",
    "confecționaserăm": "confecționa",
    "confecționaserăți": "confecționa",
    "confecționaseși": "confecționa",
    "confecționași": "confecționa",
    "confecționat": "confecționa",
    "confecționați": "confecționa",
    "confecționatu": "confecționa",
    "confecționau": "confecționa",
    "confecționează": "confecționa",
    "confecționez": "confecționa",
    "confecționeze": "confecționa",
    "confecționezi": "confecționa",
    "neconfecționând": "confecționa",
    "neconfecționându": "confecționa",
    "nemaiconfecționând": "confecționa",
    "nemaiconfecționându": "confecționa",
    "confecționarea": "confecționare",
    "confecționareo": "confecționare",
    "confecționări": "confecționare",
    "confecționării": "confecționare",
    "confecționările": "confecționare",
    "confecționărilor": "confecționare",
    "confecționată": "confecționat",
    "confecționate": "confecționat",
    "confecționați": "confecționat",
    "CISL": "Confederația_Sindicatelor_Libere",
    "confederația": "confederație",
    "confederației": "confederație",
    "confederații": "confederație",
    "confederațiile": "confederație",
    "confederațiilor": "confederație",
    "confederațio": "confederație",
    "confederativa": "confederativ",
    "confederativă": "confederativ",
    "confederative": "confederativ",
    "confederativei": "confederativ",
    "confederativele": "confederativ",
    "confederativelor": "confederativ",
    "confederativi": "confederativ",
    "confederativii": "confederativ",
    "confederativilor": "confederativ",
    "confederativo": "confederativ",
    "confederativul": "confederativ",
    "confederativule": "confederativ",
    "confederativului": "confederativ",
    "conferențiai": "conferenția",
    "conferențiam": "conferenția",
    "conferențiară": "conferenția",
    "conferențiarăm": "conferenția",
    "conferențiarăți": "conferenția",
    "conferențiase": "conferenția",
    "conferențiasem": "conferenția",
    "conferențiaseră": "conferenția",
    "conferențiaserăm": "conferenția",
    "conferențiaserăți": "conferenția",
    "conferențiaseși": "conferenția",
    "conferențiași": "conferenția",
    "conferențiat": "conferenția",
    "conferențiați": "conferenția",
    "conferențiatu": "conferenția",
    "conferențiau": "conferenția",
    "conferențiază": "conferenția",
    "conferenție": "conferenția",
    "conferențiem": "conferenția",
    "conferențiez": "conferenția",
    "conferențieze": "conferenția",
    "conferențiezi": "conferenția",
    "conferențiind": "conferenția",
    "conferențiindu": "conferenția",
    "neconferențiind": "conferenția",
    "neconferențiindu": "conferenția",
    "nemaiconferențiind": "conferenția",
    "nemaiconferențiindu": "conferenția",
    "conf.": "conferențiar",
    "conferențiari": "conferențiar",
    "conferențiarii": "conferențiar",
    "conferențiarilor": "conferențiar",
    "conferențiarul": "conferențiar",
    "conferențiarule": "conferențiar",
    "conferențiarului": "conferențiar",
    "conferențiara": "conferențiară",
    "conferențiare": "conferențiară",
    "conferențiarei": "conferențiară",
    "conferențiarele": "conferențiară",
    "conferențiarelor": "conferențiară",
    "conferențiaro": "conferențiară",
    "conferențiată": "conferențiat",
    "conferențiate": "conferențiat",
    "conferențiați": "conferențiat",
    "confer": "conferi",
    "conferă": "conferi",
    "confere": "conferi",
    "conferea": "conferi",
    "confereai": "conferi",
    "confeream": "conferi",
    "confereați": "conferi",
    "confereau": "conferi",
    "conferii": "conferi",
    "conferim": "conferi",
    "conferind": "conferi",
    "conferindu": "conferi",
    "conferiră": "conferi",
    "conferirăm": "conferi",
    "conferirăți": "conferi",
    "conferise": "conferi",
    "conferisem": "conferi",
    "conferiseră": "conferi",
    "conferiserăm": "conferi",
    "conferiserăți": "conferi",
    "conferiseși": "conferi",
    "conferiși": "conferi",
    "conferit": "conferi",
    "conferiți": "conferi",
    "conferitu": "conferi",
    "neconferind": "conferi",
    "neconferindu": "conferi",
    "nemaiconferind": "conferi",
    "nemaiconferindu": "conferi",
    "conferința": "conferință",
    "conferințe": "conferință",
    "conferinței": "conferință",
    "conferințele": "conferință",
    "conferințelor": "conferință",
    "conferințo": "conferință",
    "conferirea": "conferire",
    "conferireo": "conferire",
    "conferiri": "conferire",
    "conferirii": "conferire",
    "conferirile": "conferire",
    "conferirilor": "conferire",
    "conferită": "conferit",
    "conferite": "conferit",
    "conferiți": "conferit",
    "confesă": "confesa",
    "confesai": "confesa",
    "confesam": "confesa",
    "confesăm": "confesa",
    "confesând": "confesa",
    "confesându": "confesa",
    "confesară": "confesa",
    "confesarăm": "confesa",
    "confesarăți": "confesa",
    "confesase": "confesa",
    "confesasem": "confesa",
    "confesaseră": "confesa",
    "confesaserăm": "confesa",
    "confesaserăți": "confesa",
    "confesaseși": "confesa",
    "confesași": "confesa",
    "confesat": "confesa",
    "confesați": "confesa",
    "confesatu": "confesa",
    "confesau": "confesa",
    "confesează": "confesa",
    "confesez": "confesa",
    "confeseze": "confesa",
    "confesezi": "confesa",
    "neconfesând": "confesa",
    "neconfesându": "confesa",
    "nemaiconfesând": "confesa",
    "nemaiconfesându": "confesa",
    "confesată": "confesat",
    "confesate": "confesat",
    "confesați": "confesat",
    "confesionala": "confesional",
    "confesională": "confesional",
    "confesionale": "confesional",
    "confesionalei": "confesional",
    "confesionalele": "confesional",
    "confesionalelor": "confesional",
    "confesionali": "confesional",
    "confesionalii": "confesional",
    "confesionalilor": "confesional",
    "confesionalo": "confesional",
    "confesionalul": "confesional",
    "confesionalule": "confesional",
    "confesionalului": "confesional",
    "confesiunea": "confesiune",
    "confesiuneo": "confesiune",
    "confesiuni": "confesiune",
    "confesiunii": "confesiune",
    "confesiunile": "confesiune",
    "confesiunilor": "confesiune",
    "confesiva": "confesiv",
    "confesivă": "confesiv",
    "confesive": "confesiv",
    "confesivei": "confesiv",
    "confesivele": "confesiv",
    "confesivelor": "confesiv",
    "confesivi": "confesiv",
    "confesivii": "confesiv",
    "confesivilor": "confesiv",
    "confesivo": "confesiv",
    "confesivul": "confesiv",
    "confesivule": "confesiv",
    "confesivului": "confesiv",
    "confesori": "confesor",
    "confesorii": "confesor",
    "confesorilor": "confesor",
    "confesorul": "confesor",
    "confesorule": "confesor",
    "confesorului": "confesor",
    "confiai": "confia",
    "confiam": "confia",
    "confiară": "confia",
    "confiarăm": "confia",
    "confiarăți": "confia",
    "confiase": "confia",
    "confiasem": "confia",
    "confiaseră": "confia",
    "confiaserăm": "confia",
    "confiaserăți": "confia",
    "confiaseși": "confia",
    "confiași": "confia",
    "confiat": "confia",
    "confiați": "confia",
    "confiatu": "confia",
    "confiau": "confia",
    "confiază": "confia",
    "confie": "confia",
    "confiem": "confia",
    "confiez": "confia",
    "confieze": "confia",
    "confiezi": "confia",
    "confiind": "confia",
    "confiindu": "confia",
    "neconfiind": "confia",
    "neconfiindu": "confia",
    "nemaiconfiind": "confia",
    "nemaiconfiindu": "confia",
    "confiată": "confiat",
    "confiate": "confiat",
    "confiați": "confiat",
    "confidenți": "confident",
    "confidenții": "confident",
    "confidenților": "confident",
    "confidentul": "confident",
    "confidentule": "confident",
    "confidentului": "confident",
    "confidenta": "confidentă",
    "confidente": "confidentă",
    "confidentei": "confidentă",
    "confidentele": "confidentă",
    "confidentelor": "confidentă",
    "confidento": "confidentă",
    "confidența": "confidență",
    "confidențe": "confidență",
    "confidenței": "confidență",
    "confidențele": "confidență",
    "confidențelor": "confidență",
    "confidențo": "confidență",
    "confidențiala": "confidențial",
    "confidențială": "confidențial",
    "confidențiale": "confidențial",
    "confidențialei": "confidențial",
    "confidențialele": "confidențial",
    "confidențialelor": "confidențial",
    "confidențiali": "confidențial",
    "confidențialii": "confidențial",
    "confidențialilor": "confidențial",
    "confidențialo": "confidențial",
    "confidențialul": "confidențial",
    "confidențialule": "confidențial",
    "confidențialului": "confidențial",
    "configură": "configura",
    "configurai": "configura",
    "configuram": "configura",
    "configurăm": "configura",
    "configurând": "configura",
    "configurându": "configura",
    "configurară": "configura",
    "configurarăm": "configura",
    "configurarăți": "configura",
    "configurase": "configura",
    "configurasem": "configura",
    "configuraseră": "configura",
    "configuraserăm": "configura",
    "configuraserăți": "configura",
    "configuraseși": "configura",
    "configurași": "configura",
    "configurat": "configura",
    "configurați": "configura",
    "configuratu": "configura",
    "configurau": "configura",
    "configurează": "configura",
    "configurez": "configura",
    "configureze": "configura",
    "configurezi": "configura",
    "neconfigurând": "configura",
    "neconfigurându": "configura",
    "nemaiconfigurând": "configura",
    "nemaiconfigurându": "configura",
    "configurată": "configurat",
    "configurate": "configurat",
    "configurați": "configurat",
    "configurația": "configurație",
    "configurației": "configurație",
    "configurații": "configurație",
    "configurațiile": "configurație",
    "configurațiilor": "configurație",
    "configurațio": "configurație",
    "confirm": "confirma",
    "confirmă": "confirma",
    "confirmai": "confirma",
    "confirmam": "confirma",
    "confirmăm": "confirma",
    "confirmând": "confirma",
    "confirmându": "confirma",
    "confirmară": "confirma",
    "confirmarăm": "confirma",
    "confirmarăți": "confirma",
    "confirmase": "confirma",
    "confirmasem": "confirma",
    "confirmaseră": "confirma",
    "confirmaserăm": "confirma",
    "confirmaserăți": "confirma",
    "confirmaseși": "confirma",
    "confirmași": "confirma",
    "confirmat": "confirma",
    "confirmați": "confirma",
    "confirmatu": "confirma",
    "confirmau": "confirma",
    "confirme": "confirma",
    "confirmi": "confirma",
    "neconfirmând": "confirma",
    "neconfirmându": "confirma",
    "nemaiconfirmând": "confirma",
    "nemaiconfirmându": "confirma",
    "confirmarea": "confirmare",
    "confirmareo": "confirmare",
    "confirmări": "confirmare",
    "confirmării": "confirmare",
    "confirmările": "confirmare",
    "confirmărilor": "confirmare",
    "confirmată": "confirmat",
    "confirmate": "confirmat",
    "confirmați": "confirmat",
    "confisc": "confisca",
    "confiscă": "confisca",
    "confiscai": "confisca",
    "confiscam": "confisca",
    "confiscăm": "confisca",
    "confiscând": "confisca",
    "confiscându": "confisca",
    "confiscară": "confisca",
    "confiscarăm": "confisca",
    "confiscarăți": "confisca",
    "confiscase": "confisca",
    "confiscasem": "confisca",
    "confiscaseră": "confisca",
    "confiscaserăm": "confisca",
    "confiscaserăți": "confisca",
    "confiscaseși": "confisca",
    "confiscași": "confisca",
    "confiscat": "confisca",
    "confiscați": "confisca",
    "confiscatu": "confisca",
    "confiscau": "confisca",
    "confiște": "confisca",
    "confiști": "confisca",
    "neconfiscând": "confisca",
    "neconfiscându": "confisca",
    "nemaiconfiscând": "confisca",
    "nemaiconfiscându": "confisca",
    "confiscarea": "confiscare",
    "confiscareo": "confiscare",
    "confiscări": "confiscare",
    "confiscării": "confiscare",
    "confiscările": "confiscare",
    "confiscărilor": "confiscare",
    "confiscată": "confiscat",
    "confiscate": "confiscat",
    "confiscați": "confiscat",
    "conflagrația": "conflagrație",
    "conflagrației": "conflagrație",
    "conflagrații": "conflagrație",
    "conflagrațiile": "conflagrație",
    "conflagrațiilor": "conflagrație",
    "conflagrațio": "conflagrație",
    "conflicte": "conflict",
    "conflictele": "conflict",
    "conflictelor": "conflict",
    "conflictul": "conflict",
    "conflictule": "conflict",
    "conflictului": "conflict",
    "conflictuala": "conflictual",
    "conflictuală": "conflictual",
    "conflictuale": "conflictual",
    "conflictualei": "conflictual",
    "conflictualele": "conflictual",
    "conflictualelor": "conflictual",
    "conflictuali": "conflictual",
    "conflictualii": "conflictual",
    "conflictualilor": "conflictual",
    "conflictualo": "conflictual",
    "conflictualul": "conflictual",
    "conflictualule": "conflictual",
    "conflictualului": "conflictual",
    "confluenta": "confluent",
    "confluentă": "confluent",
    "confluente": "confluent",
    "confluentei": "confluent",
    "confluentele": "confluent",
    "confluentelor": "confluent",
    "confluenți": "confluent",
    "confluenții": "confluent",
    "confluenților": "confluent",
    "confluento": "confluent",
    "confluentul": "confluent",
    "confluentule": "confluent",
    "confluentului": "confluent",
    "confluența": "confluență",
    "confluențe": "confluență",
    "confluenței": "confluență",
    "confluențele": "confluență",
    "confluențelor": "confluență",
    "confluențo": "confluență",
    "conforma": "conform",
    "conformă": "conform",
    "conforme": "conform",
    "conformei": "conform",
    "conformele": "conform",
    "conformelor": "conform",
    "conformi": "conform",
    "conformii": "conform",
    "conformilor": "conform",
    "conformo": "conform",
    "conformul": "conform",
    "conformule": "conform",
    "conformului": "conform",
    "conformă": "conforma",
    "conformai": "conforma",
    "conformam": "conforma",
    "conformăm": "conforma",
    "conformând": "conforma",
    "conformându": "conforma",
    "conformară": "conforma",
    "conformarăm": "conforma",
    "conformarăți": "conforma",
    "conformase": "conforma",
    "conformasem": "conforma",
    "conformaseră": "conforma",
    "conformaserăm": "conforma",
    "conformaserăți": "conforma",
    "conformaseși": "conforma",
    "conformași": "conforma",
    "conformat": "conforma",
    "conformați": "conforma",
    "conformatu": "conforma",
    "conformau": "conforma",
    "conformează": "conforma",
    "conformez": "conforma",
    "conformeze": "conforma",
    "conformezi": "conforma",
    "neconformând": "conforma",
    "neconformându": "conforma",
    "nemaiconformând": "conforma",
    "nemaiconformându": "conforma",
    "conformarea": "conformare",
    "conformareo": "conformare",
    "conformări": "conformare",
    "conformării": "conformare",
    "conformările": "conformare",
    "conformărilor": "conformare",
    "conformata": "conformat",
    "conformată": "conformat",
    "conformate": "conformat",
    "conformatei": "conformat",
    "conformatele": "conformat",
    "conformatelor": "conformat",
    "conformați": "conformat",
    "conformații": "conformat",
    "conformaților": "conformat",
    "conformato": "conformat",
    "conformatul": "conformat",
    "conformatule": "conformat",
    "conformatului": "conformat",
    "conformația": "conformație",
    "conformației": "conformație",
    "conformații": "conformație",
    "conformațiile": "conformație",
    "conformațiilor": "conformație",
    "conformațio": "conformație",
    "conformismul": "conformism",
    "conformismule": "conformism",
    "conformismului": "conformism",
    "conformiști": "conformist",
    "conformiștii": "conformist",
    "conformiștilor": "conformist",
    "conformistul": "conformist",
    "conformistule": "conformist",
    "conformistului": "conformist",
    "conformista": "conformistă",
    "conformiste": "conformistă",
    "conformistei": "conformistă",
    "conformistele": "conformistă",
    "conformistelor": "conformistă",
    "conformisto": "conformistă",
    "conformitatea": "conformitate",
    "conformitateo": "conformitate",
    "conformități": "conformitate",
    "conformității": "conformitate",
    "conformitățile": "conformitate",
    "conformităților": "conformitate",
    "confortul": "confort",
    "confortule": "confort",
    "confortului": "confort",
    "conforturi": "confort",
    "conforturile": "confort",
    "conforturilor": "confort",
    "confortabila": "confortabil",
    "confortabilă": "confortabil",
    "confortabile": "confortabil",
    "confortabilei": "confortabil",
    "confortabilele": "confortabil",
    "confortabilelor": "confortabil",
    "confortabili": "confortabil",
    "confortabilii": "confortabil",
    "confortabililor": "confortabil",
    "confortabilo": "confortabil",
    "confortabilul": "confortabil",
    "confortabilule": "confortabil",
    "confortabilului": "confortabil",
    "confratele": "confrate",
    "confratelui": "confrate",
    "confrați": "confrate",
    "confrații": "confrate",
    "confraților": "confrate",
    "confraterna": "confratern",
    "confraternă": "confratern",
    "confraterne": "confratern",
    "confraternei": "confratern",
    "confraternele": "confratern",
    "confraternelor": "confratern",
    "confraterni": "confratern",
    "confraternii": "confratern",
    "confraternilor": "confratern",
    "confraterno": "confratern",
    "confraternul": "confratern",
    "confraternule": "confratern",
    "confraternului": "confratern",
    "confreria": "confrerie",
    "confreriei": "confrerie",
    "confrerii": "confrerie",
    "confreriile": "confrerie",
    "confreriilor": "confrerie",
    "confrerio": "confrerie",
    "confrunt": "confrunta",
    "confruntă": "confrunta",
    "confruntai": "confrunta",
    "confruntam": "confrunta",
    "confruntăm": "confrunta",
    "confruntând": "confrunta",
    "confruntându": "confrunta",
    "confruntară": "confrunta",
    "confruntarăm": "confrunta",
    "confruntarăți": "confrunta",
    "confruntase": "confrunta",
    "confruntasem": "confrunta",
    "confruntaseră": "confrunta",
    "confruntaserăm": "confrunta",
    "confruntaserăți": "confrunta",
    "confruntaseși": "confrunta",
    "confruntași": "confrunta",
    "confruntat": "confrunta",
    "confruntați": "confrunta",
    "confruntatu": "confrunta",
    "confruntau": "confrunta",
    "confrunte": "confrunta",
    "confrunți": "confrunta",
    "neconfruntând": "confrunta",
    "neconfruntându": "confrunta",
    "nemaiconfruntând": "confrunta",
    "nemaiconfruntându": "confrunta",
    "confruntarea": "confruntare",
    "confruntareo": "confruntare",
    "confruntări": "confruntare",
    "confruntării": "confruntare",
    "confruntările": "confruntare",
    "confruntărilor": "confruntare",
    "confruntată": "confruntat",
    "confruntate": "confruntat",
    "confruntați": "confruntat",
    "confund": "confunda",
    "confundă": "confunda",
    "confundai": "confunda",
    "confundam": "confunda",
    "confundăm": "confunda",
    "confundând": "confunda",
    "confundându": "confunda",
    "confundară": "confunda",
    "confundarăm": "confunda",
    "confundarăți": "confunda",
    "confundase": "confunda",
    "confundasem": "confunda",
    "confundaseră": "confunda",
    "confundaserăm": "confunda",
    "confundaserăți": "confunda",
    "confundaseși": "confunda",
    "confundași": "confunda",
    "confundat": "confunda",
    "confundați": "confunda",
    "confundatu": "confunda",
    "confundau": "confunda",
    "confunde": "confunda",
    "confunzi": "confunda",
    "neconfundând": "confunda",
    "neconfundându": "confunda",
    "neconfundat": "confunda",
    "nemaiconfundând": "confunda",
    "nemaiconfundându": "confunda",
    "confundarea": "confundare",
    "confundareo": "confundare",
    "confundări": "confundare",
    "confundării": "confundare",
    "confundările": "confundare",
    "confundărilor": "confundare",
    "confundată": "confundat",
    "confundate": "confundat",
    "confundați": "confundat",
    "confuza": "confuz",
    "confuză": "confuz",
    "confuze": "confuz",
    "confuzei": "confuz",
    "confuzele": "confuz",
    "confuzelor": "confuz",
    "confuzi": "confuz",
    "confuzii": "confuz",
    "confuzilor": "confuz",
    "confuzo": "confuz",
    "confuzul": "confuz",
    "confuzule": "confuz",
    "confuzului": "confuz",
    "confuzia": "confuzie",
    "confuziei": "confuzie",
    "confuzii": "confuzie",
    "confuziile": "confuzie",
    "confuziilor": "confuzie",
    "confuzio": "confuzie",
    "congelă": "congela",
    "congelai": "congela",
    "congelam": "congela",
    "congelăm": "congela",
    "congelând": "congela",
    "congelându": "congela",
    "congelară": "congela",
    "congelarăm": "congela",
    "congelarăți": "congela",
    "congelase": "congela",
    "congelasem": "congela",
    "congelaseră": "congela",
    "congelaserăm": "congela",
    "congelaserăți": "congela",
    "congelaseși": "congela",
    "congelași": "congela",
    "congelat": "congela",
    "congelați": "congela",
    "congelatu": "congela",
    "congelau": "congela",
    "congelează": "congela",
    "congelez": "congela",
    "congeleze": "congela",
    "congelezi": "congela",
    "necongelând": "congela",
    "necongelându": "congela",
    "nemaicongelând": "congela",
    "nemaicongelându": "congela",
    "congelarea": "congelare",
    "congelareo": "congelare",
    "congelări": "congelare",
    "congelării": "congelare",
    "congelările": "congelare",
    "congelărilor": "congelare",
    "congelata": "congelat",
    "congelată": "congelat",
    "congelate": "congelat",
    "congelatei": "congelat",
    "congelatele": "congelat",
    "congelatelor": "congelat",
    "congelați": "congelat",
    "congelații": "congelat",
    "congelaților": "congelat",
    "congelato": "congelat",
    "congelatul": "congelat",
    "congelatule": "congelat",
    "congelatului": "congelat",
    "congelatoare": "congelator",
    "congelatoarele": "congelator",
    "congelatoarelor": "congelator",
    "congelatorul": "congelator",
    "congelatorule": "congelator",
    "congelatorului": "congelator",
    "congenitala": "congenital",
    "congenitală": "congenital",
    "congenitale": "congenital",
    "congenitalei": "congenital",
    "congenitalele": "congenital",
    "congenitalelor": "congenital",
    "congenitali": "congenital",
    "congenitalii": "congenital",
    "congenitalilor": "congenital",
    "congenitalo": "congenital",
    "congenitalul": "congenital",
    "congenitalule": "congenital",
    "congenitalului": "congenital",
    "congestia": "congestie",
    "congestiei": "congestie",
    "congestii": "congestie",
    "congestiile": "congestie",
    "congestiilor": "congestie",
    "congestio": "congestie",
    "congestionă": "congestiona",
    "congestionai": "congestiona",
    "congestionam": "congestiona",
    "congestionăm": "congestiona",
    "congestionând": "congestiona",
    "congestionându": "congestiona",
    "congestionară": "congestiona",
    "congestionarăm": "congestiona",
    "congestionarăți": "congestiona",
    "congestionase": "congestiona",
    "congestionasem": "congestiona",
    "congestionaseră": "congestiona",
    "congestionaserăm": "congestiona",
    "congestionaserăți": "congestiona",
    "congestionaseși": "congestiona",
    "congestionași": "congestiona",
    "congestionat": "congestiona",
    "congestionați": "congestiona",
    "congestionatu": "congestiona",
    "congestionau": "congestiona",
    "congestionează": "congestiona",
    "congestionez": "congestiona",
    "congestioneze": "congestiona",
    "congestionezi": "congestiona",
    "necongestionând": "congestiona",
    "necongestionându": "congestiona",
    "nemaicongestionând": "congestiona",
    "nemaicongestionându": "congestiona",
    "congestionarea": "congestionare",
    "congestionareo": "congestionare",
    "congestionări": "congestionare",
    "congestionării": "congestionare",
    "congestionările": "congestionare",
    "congestionărilor": "congestionare",
    "congestionata": "congestionat",
    "congestionată": "congestionat",
    "congestionate": "congestionat",
    "congestionatei": "congestionat",
    "congestionatele": "congestionat",
    "congestionatelor": "congestionat",
    "congestionați": "congestionat",
    "congestionații": "congestionat",
    "congestionaților": "congestionat",
    "congestionato": "congestionat",
    "congestionatul": "congestionat",
    "congestionatule": "congestionat",
    "congestionatului": "congestionat",
    "conglomerate": "conglomerat",
    "conglomeratele": "conglomerat",
    "conglomeratelor": "conglomerat",
    "conglomeratul": "conglomerat",
    "conglomeratule": "conglomerat",
    "conglomeratului": "conglomerat",
    "congregația": "congregație",
    "congregației": "congregație",
    "congregații": "congregație",
    "congregațiile": "congregație",
    "congregațiilor": "congregație",
    "congregațio": "congregație",
    "congrese": "congres",
    "congresele": "congres",
    "congreselor": "congres",
    "congresul": "congres",
    "congresule": "congres",
    "congresului": "congres",
    "congresiști": "congresist",
    "congresiștii": "congresist",
    "congresiștilor": "congresist",
    "congresistul": "congresist",
    "congresistule": "congresist",
    "congresistului": "congresist",
    "congresista": "congresistă",
    "congresiste": "congresistă",
    "congresistei": "congresistă",
    "congresistele": "congresistă",
    "congresistelor": "congresistă",
    "congresisto": "congresistă",
    "congruenta": "congruent",
    "congruentă": "congruent",
    "congruente": "congruent",
    "congruentei": "congruent",
    "congruentele": "congruent",
    "congruentelor": "congruent",
    "congruenți": "congruent",
    "congruenții": "congruent",
    "congruenților": "congruent",
    "congruento": "congruent",
    "congruentul": "congruent",
    "congruentule": "congruent",
    "congruentului": "congruent",
    "congruența": "congruență",
    "congruențe": "congruență",
    "congruenței": "congruență",
    "congruențele": "congruență",
    "congruențelor": "congruență",
    "congruențo": "congruență",
    "coniacul": "coniac",
    "coniacule": "coniac",
    "coniacului": "coniac",
    "coniacuri": "coniac",
    "coniacurile": "coniac",
    "coniacurilor": "coniac",
    "conica": "conic",
    "conică": "conic",
    "conice": "conic",
    "conicei": "conic",
    "conicele": "conic",
    "conicelor": "conic",
    "conici": "conic",
    "conicii": "conic",
    "conicilor": "conic",
    "conico": "conic",
    "conicul": "conic",
    "conicule": "conic",
    "conicului": "conic",
    "conifere": "conifer",
    "coniferele": "conifer",
    "coniferelor": "conifer",
    "coniferul": "conifer",
    "coniferule": "conifer",
    "coniferului": "conifer",
    "conivența": "conivență",
    "conivențe": "conivență",
    "conivenței": "conivență",
    "conivențele": "conivență",
    "conivențelor": "conivență",
    "conivențo": "conivență",
    "conjectura": "conjectură",
    "conjecturi": "conjectură",
    "conjecturii": "conjectură",
    "conjecturile": "conjectură",
    "conjecturilor": "conjectură",
    "conjecturo": "conjectură",
    "conjug": "conjuga",
    "conjugă": "conjuga",
    "conjugai": "conjuga",
    "conjugam": "conjuga",
    "conjugăm": "conjuga",
    "conjugând": "conjuga",
    "conjugându": "conjuga",
    "conjugară": "conjuga",
    "conjugarăm": "conjuga",
    "conjugarăți": "conjuga",
    "conjugase": "conjuga",
    "conjugasem": "conjuga",
    "conjugaseră": "conjuga",
    "conjugaserăm": "conjuga",
    "conjugaserăți": "conjuga",
    "conjugaseși": "conjuga",
    "conjugași": "conjuga",
    "conjugat": "conjuga",
    "conjugați": "conjuga",
    "conjugatu": "conjuga",
    "conjugau": "conjuga",
    "conjuge": "conjuga",
    "conjugi": "conjuga",
    "neconjugând": "conjuga",
    "neconjugându": "conjuga",
    "nemaiconjugând": "conjuga",
    "nemaiconjugându": "conjuga",
    "conjugala": "conjugal",
    "conjugală": "conjugal",
    "conjugale": "conjugal",
    "conjugalei": "conjugal",
    "conjugalele": "conjugal",
    "conjugalelor": "conjugal",
    "conjugali": "conjugal",
    "conjugalii": "conjugal",
    "conjugalilor": "conjugal",
    "conjugalo": "conjugal",
    "conjugalul": "conjugal",
    "conjugalule": "conjugal",
    "conjugalului": "conjugal",
    "conjugarea": "conjugare",
    "conjugareo": "conjugare",
    "conjugări": "conjugare",
    "conjugării": "conjugare",
    "conjugările": "conjugare",
    "conjugărilor": "conjugare",
    "conjugata": "conjugat",
    "conjugată": "conjugat",
    "conjugate": "conjugat",
    "conjugatei": "conjugat",
    "conjugatele": "conjugat",
    "conjugatelor": "conjugat",
    "conjugați": "conjugat",
    "conjugații": "conjugat",
    "conjugaților": "conjugat",
    "conjugato": "conjugat",
    "conjugatul": "conjugat",
    "conjugatule": "conjugat",
    "conjugatului": "conjugat",
    "conjuncta": "conjunct",
    "conjunctă": "conjunct",
    "conjuncte": "conjunct",
    "conjunctei": "conjunct",
    "conjunctele": "conjunct",
    "conjunctelor": "conjunct",
    "conjuncți": "conjunct",
    "conjuncții": "conjunct",
    "conjuncților": "conjunct",
    "conjuncto": "conjunct",
    "conjunctul": "conjunct",
    "conjunctule": "conjunct",
    "conjunctului": "conjunct",
    "conj.": "conjuncție",
    "conjuncția": "conjuncție",
    "conjuncției": "conjuncție",
    "conjuncții": "conjuncție",
    "conjuncțiile": "conjuncție",
    "conjuncțiilor": "conjuncție",
    "conjuncțio": "conjuncție",
    "conjunctiva": "conjunctiv",
    "conjunctivă": "conjunctiv",
    "conjunctive": "conjunctiv",
    "conjunctivei": "conjunctiv",
    "conjunctivele": "conjunctiv",
    "conjunctivelor": "conjunctiv",
    "conjunctivi": "conjunctiv",
    "conjunctivii": "conjunctiv",
    "conjunctivilor": "conjunctiv",
    "conjunctivo": "conjunctiv",
    "conjunctivul": "conjunctiv",
    "conjunctivule": "conjunctiv",
    "conjunctivului": "conjunctiv",
    "conjunctiva": "conjunctivă",
    "conjunctive": "conjunctivă",
    "conjunctivei": "conjunctivă",
    "conjunctivele": "conjunctivă",
    "conjunctivelor": "conjunctivă",
    "conjunctivo": "conjunctivă",
    "conjunctivita": "conjunctivită",
    "conjunctivite": "conjunctivită",
    "conjunctivitei": "conjunctivită",
    "conjunctivitele": "conjunctivită",
    "conjunctivitelor": "conjunctivită",
    "conjunctivito": "conjunctivită",
    "conjunctoare": "conjunctor",
    "conjunctoarele": "conjunctor",
    "conjunctoarelor": "conjunctor",
    "conjunctorul": "conjunctor",
    "conjunctorule": "conjunctor",
    "conjunctorului": "conjunctor",
    "conjunctura": "conjunctură",
    "conjuncturi": "conjunctură",
    "conjuncturii": "conjunctură",
    "conjuncturile": "conjunctură",
    "conjuncturilor": "conjunctură",
    "conjuncturo": "conjunctură",
    "conjuncturala": "conjunctural",
    "conjuncturală": "conjunctural",
    "conjuncturale": "conjunctural",
    "conjuncturalei": "conjunctural",
    "conjuncturalele": "conjunctural",
    "conjuncturalelor": "conjunctural",
    "conjuncturali": "conjunctural",
    "conjuncturalii": "conjunctural",
    "conjuncturalilor": "conjunctural",
    "conjuncturalul": "conjunctural",
    "conjuncturalului": "conjunctural",
    "conjur": "conjura",
    "conjură": "conjura",
    "conjurai": "conjura",
    "conjuram": "conjura",
    "conjurăm": "conjura",
    "conjurând": "conjura",
    "conjurându": "conjura",
    "conjurară": "conjura",
    "conjurarăm": "conjura",
    "conjurarăți": "conjura",
    "conjurase": "conjura",
    "conjurasem": "conjura",
    "conjuraseră": "conjura",
    "conjuraserăm": "conjura",
    "conjuraserăți": "conjura",
    "conjuraseși": "conjura",
    "conjurași": "conjura",
    "conjurat": "conjura",
    "conjurați": "conjura",
    "conjuratu": "conjura",
    "conjurau": "conjura",
    "conjure": "conjura",
    "conjuri": "conjura",
    "neconjurând": "conjura",
    "neconjurându": "conjura",
    "nemaiconjurând": "conjura",
    "nemaiconjurându": "conjura",
    "conjurați": "conjurat",
    "conjurații": "conjurat",
    "conjuraților": "conjurat",
    "conjuratul": "conjurat",
    "conjuratule": "conjurat",
    "conjuratului": "conjurat",
    "conjurata": "conjurată",
    "conjurate": "conjurată",
    "conjuratei": "conjurată",
    "conjuratele": "conjurată",
    "conjuratelor": "conjurată",
    "conjurato": "conjurată",
    "conjurația": "conjurație",
    "conjurației": "conjurație",
    "conjurații": "conjurație",
    "conjurațiile": "conjurație",
    "conjurațiilor": "conjurație",
    "conjurațio": "conjurație",
    "conlocuirea": "conlocuire",
    "conlocuireo": "conlocuire",
    "conlocuiri": "conlocuire",
    "conlocuirii": "conlocuire",
    "conlocuirile": "conlocuire",
    "conlocuirilor": "conlocuire",
    "conlocuitoarea": "conlocuitoare",
    "conlocuitoarei": "conlocuitoare",
    "conlocuitoarele": "conlocuitoare",
    "conlocuitoarelor": "conlocuitoare",
    "conlocuitoareo": "conlocuitoare",
    "conlocuitoare": "conlocuitor",
    "conlocuitoarea": "conlocuitor",
    "conlocuitoarei": "conlocuitor",
    "conlocuitoarele": "conlocuitor",
    "conlocuitoarelor": "conlocuitor",
    "conlocuitoareo": "conlocuitor",
    "conlocuitori": "conlocuitor",
    "conlocuitorii": "conlocuitor",
    "conlocuitorilor": "conlocuitor",
    "conlocuitorul": "conlocuitor",
    "conlocuitorule": "conlocuitor",
    "conlocuitorului": "conlocuitor",
    "conlucră": "conlucra",
    "conlucrai": "conlucra",
    "conlucram": "conlucra",
    "conlucrăm": "conlucra",
    "conlucrând": "conlucra",
    "conlucrându": "conlucra",
    "conlucrară": "conlucra",
    "conlucrarăm": "conlucra",
    "conlucrarăți": "conlucra",
    "conlucrase": "conlucra",
    "conlucrasem": "conlucra",
    "conlucraseră": "conlucra",
    "conlucraserăm": "conlucra",
    "conlucraserăți": "conlucra",
    "conlucraseși": "conlucra",
    "conlucrași": "conlucra",
    "conlucrat": "conlucra",
    "conlucrați": "conlucra",
    "conlucratu": "conlucra",
    "conlucrau": "conlucra",
    "conlucrează": "conlucra",
    "conlucrez": "conlucra",
    "conlucreze": "conlucra",
    "conlucrezi": "conlucra",
    "conlucrarea": "conlucrare",
    "conlucrareo": "conlucrare",
    "conlucrări": "conlucrare",
    "conlucrării": "conlucrare",
    "conlucrările": "conlucrare",
    "conlucrărilor": "conlucrare",
    "conlucrată": "conlucrat",
    "conlucrate": "conlucrat",
    "conlucrați": "conlucrat",
    "conopida": "conopidă",
    "conopide": "conopidă",
    "conopidei": "conopidă",
    "conopidele": "conopidă",
    "conopidelor": "conopidă",
    "conopido": "conopidă",
    "conotația": "conotație",
    "conotației": "conotație",
    "conotații": "conotație",
    "conotațiile": "conotație",
    "conotațiilor": "conotație",
    "conotațio": "conotație",
    "consacră": "consacra",
    "consacrai": "consacra",
    "consacram": "consacra",
    "consacrăm": "consacra",
    "consacrând": "consacra",
    "consacrându": "consacra",
    "consacrară": "consacra",
    "consacrarăm": "consacra",
    "consacrarăți": "consacra",
    "consacrase": "consacra",
    "consacrasem": "consacra",
    "consacraseră": "consacra",
    "consacraserăm": "consacra",
    "consacraserăți": "consacra",
    "consacraseși": "consacra",
    "consacrași": "consacra",
    "consacrat": "consacra",
    "consacrați": "consacra",
    "consacratu": "consacra",
    "consacrau": "consacra",
    "consacre": "consacra",
    "consacri": "consacra",
    "consacru": "consacra",
    "neconsacrând": "consacra",
    "neconsacrându": "consacra",
    "nemaiconsacrând": "consacra",
    "nemaiconsacrându": "consacra",
    "consacrarea": "consacrare",
    "consacrareo": "consacrare",
    "consacrări": "consacrare",
    "consacrării": "consacrare",
    "consacrările": "consacrare",
    "consacrărilor": "consacrare",
    "consacrata": "consacrat",
    "consacrată": "consacrat",
    "consacrate": "consacrat",
    "consacratei": "consacrat",
    "consacratele": "consacrat",
    "consacratelor": "consacrat",
    "consacrați": "consacrat",
    "consacrații": "consacrat",
    "consacraților": "consacrat",
    "consacrato": "consacrat",
    "consacratul": "consacrat",
    "consacratule": "consacrat",
    "consacratului": "consacrat",
    "consăteanul": "consătean",
    "consăteanului": "consătean",
    "consăteni": "consătean",
    "consătenii": "consătean",
    "consătenilor": "consătean",
    "consăteanca": "consăteancă",
    "consătence": "consăteancă",
    "consătencei": "consăteancă",
    "consătencele": "consăteancă",
    "consătencelor": "consăteancă",
    "conscripția": "conscripție",
    "conscripției": "conscripție",
    "conscripții": "conscripție",
    "conscripțiile": "conscripție",
    "conscripțiilor": "conscripție",
    "conscripțio": "conscripție",
    "consecința": "consecință",
    "consecințe": "consecință",
    "consecinței": "consecință",
    "consecințele": "consecință",
    "consecințelor": "consecință",
    "consecințo": "consecință",
    "consecutiva": "consecutiv",
    "consecutivă": "consecutiv",
    "consecutive": "consecutiv",
    "consecutivei": "consecutiv",
    "consecutivele": "consecutiv",
    "consecutivelor": "consecutiv",
    "consecutivi": "consecutiv",
    "consecutivii": "consecutiv",
    "consecutivilor": "consecutiv",
    "consecutivo": "consecutiv",
    "consecutivul": "consecutiv",
    "consecutivule": "consecutiv",
    "consecutivului": "consecutiv",
    "consecventa": "consecvent",
    "consecventă": "consecvent",
    "consecvente": "consecvent",
    "consecventei": "consecvent",
    "consecventele": "consecvent",
    "consecventelor": "consecvent",
    "consecvenți": "consecvent",
    "consecvenții": "consecvent",
    "consecvenților": "consecvent",
    "consecvento": "consecvent",
    "consecventul": "consecvent",
    "consecventule": "consecvent",
    "consecventului": "consecvent",
    "consecvența": "consecvență",
    "consecvențe": "consecvență",
    "consecvenței": "consecvență",
    "consecvențele": "consecvență",
    "consecvențelor": "consecvență",
    "consecvențo": "consecvență",
    "consemne": "consemn",
    "consemnele": "consemn",
    "consemnelor": "consemn",
    "consemnul": "consemn",
    "consemnule": "consemn",
    "consemnului": "consemn",
    "consemnă": "consemna",
    "consemnai": "consemna",
    "consemnam": "consemna",
    "consemnăm": "consemna",
    "consemnând": "consemna",
    "consemnându": "consemna",
    "consemnară": "consemna",
    "consemnarăm": "consemna",
    "consemnarăți": "consemna",
    "consemnase": "consemna",
    "consemnasem": "consemna",
    "consemnaseră": "consemna",
    "consemnaserăm": "consemna",
    "consemnaserăți": "consemna",
    "consemnaseși": "consemna",
    "consemnași": "consemna",
    "consemnat": "consemna",
    "consemnați": "consemna",
    "consemnatu": "consemna",
    "consemnau": "consemna",
    "consemnează": "consemna",
    "consemnez": "consemna",
    "consemneze": "consemna",
    "consemnezi": "consemna",
    "neconsemnând": "consemna",
    "neconsemnându": "consemna",
    "nemaiconsemnând": "consemna",
    "nemaiconsemnându": "consemna",
    "consemnarea": "consemnare",
    "consemnareo": "consemnare",
    "consemnări": "consemnare",
    "consemnării": "consemnare",
    "consemnările": "consemnare",
    "consemnărilor": "consemnare",
    "consemnată": "consemnat",
    "consemnate": "consemnat",
    "consemnați": "consemnat",
    "consemnațiunea": "consemnațiune",
    "consemnațiuneo": "consemnațiune",
    "consemnațiuni": "consemnațiune",
    "consemnațiunii": "consemnațiune",
    "consemnațiunile": "consemnațiune",
    "consemnațiunilor": "consemnațiune",
    "consensul": "consens",
    "consensule": "consens",
    "consensului": "consens",
    "consensuri": "consens",
    "consensurile": "consens",
    "consensurilor": "consens",
    "conserv": "conserva",
    "conservă": "conserva",
    "conservai": "conserva",
    "conservam": "conserva",
    "conservăm": "conserva",
    "conservând": "conserva",
    "conservându": "conserva",
    "conservară": "conserva",
    "conservarăm": "conserva",
    "conservarăți": "conserva",
    "conservase": "conserva",
    "conservasem": "conserva",
    "conservaseră": "conserva",
    "conservaserăm": "conserva",
    "conservaserăți": "conserva",
    "conservaseși": "conserva",
    "conservași": "conserva",
    "conservat": "conserva",
    "conservați": "conserva",
    "conservatu": "conserva",
    "conservau": "conserva",
    "conserve": "conserva",
    "conservi": "conserva",
    "neconservând": "conserva",
    "neconservându": "conserva",
    "nemaiconservând": "conserva",
    "nemaiconservându": "conserva",
    "conserva": "conservă",
    "conserve": "conservă",
    "conservei": "conservă",
    "conservele": "conservă",
    "conservelor": "conservă",
    "conservo": "conservă",
    "conservarea": "conservare",
    "conservareo": "conservare",
    "conservări": "conservare",
    "conservării": "conservare",
    "conservările": "conservare",
    "conservărilor": "conservare",
    "conservată": "conservat",
    "conservate": "conservat",
    "conservați": "conservat",
    "conservativa": "conservativ",
    "conservativă": "conservativ",
    "conservative": "conservativ",
    "conservativei": "conservativ",
    "conservativele": "conservativ",
    "conservativelor": "conservativ",
    "conservativi": "conservativ",
    "conservativii": "conservativ",
    "conservativilor": "conservativ",
    "conservativo": "conservativ",
    "conservativul": "conservativ",
    "conservativule": "conservativ",
    "conservativului": "conservativ",
    "conservatoarea": "conservatoare",
    "conservatoarei": "conservatoare",
    "conservatoarele": "conservatoare",
    "conservatoarelor": "conservatoare",
    "conservatoareo": "conservatoare",
    "conservatoare": "conservator",
    "conservatoarea": "conservator",
    "conservatoarei": "conservator",
    "conservatoarele": "conservator",
    "conservatoarelor": "conservator",
    "conservatoareo": "conservator",
    "conservatori": "conservator",
    "conservatorii": "conservator",
    "conservatorilor": "conservator",
    "conservatorul": "conservator",
    "conservatorule": "conservator",
    "conservatorului": "conservator",
    "consfătuirea": "consfătuire",
    "consfătuireo": "consfătuire",
    "consfătuiri": "consfătuire",
    "consfătuirii": "consfătuire",
    "consfătuirile": "consfătuire",
    "consfătuirilor": "consfătuire",
    "consfințea": "consfinți",
    "consfințeai": "consfinți",
    "consfințeam": "consfinți",
    "consfințească": "consfinți",
    "consfințeați": "consfinți",
    "consfințeau": "consfinți",
    "consfințesc": "consfinți",
    "consfințește": "consfinți",
    "consfințești": "consfinți",
    "consfinții": "consfinți",
    "consfințim": "consfinți",
    "consfințind": "consfinți",
    "consfințindu": "consfinți",
    "consfințiră": "consfinți",
    "consfințirăm": "consfinți",
    "consfințirăți": "consfinți",
    "consfințise": "consfinți",
    "consfințisem": "consfinți",
    "consfințiseră": "consfinți",
    "consfințiserăm": "consfinți",
    "consfințiserăți": "consfinți",
    "consfințiseși": "consfinți",
    "consfințiși": "consfinți",
    "consfințit": "consfinți",
    "consfințiți": "consfinți",
    "consfințitu": "consfinți",
    "consfințita": "consfințit",
    "consfințită": "consfințit",
    "consfințite": "consfințit",
    "consfințitei": "consfințit",
    "consfințitele": "consfințit",
    "consfințitelor": "consfințit",
    "consfințiți": "consfințit",
    "consfințiții": "consfințit",
    "consfințiților": "consfințit",
    "consfințito": "consfințit",
    "consfințitul": "consfințit",
    "consfințitule": "consfințit",
    "consfințitului": "consfințit",
    "consider": "considera",
    "consideră": "considera",
    "considerai": "considera",
    "consideram": "considera",
    "considerăm": "considera",
    "considerând": "considera",
    "considerându": "considera",
    "considerară": "considera",
    "considerarăm": "considera",
    "considerarăți": "considera",
    "considerase": "considera",
    "considerasem": "considera",
    "consideraseră": "considera",
    "consideraserăm": "considera",
    "consideraserăți": "considera",
    "consideraseși": "considera",
    "considerași": "considera",
    "considerat": "considera",
    "considerați": "considera",
    "consideratu": "considera",
    "considerau": "considera",
    "considere": "considera",
    "consideri": "considera",
    "neconsiderând": "considera",
    "neconsiderându": "considera",
    "nemaiconsiderând": "considera",
    "nemaiconsiderându": "considera",
    "considerabila": "considerabil",
    "considerabilă": "considerabil",
    "considerabile": "considerabil",
    "considerabilei": "considerabil",
    "considerabilele": "considerabil",
    "considerabilelor": "considerabil",
    "considerabili": "considerabil",
    "considerabilii": "considerabil",
    "considerabililor": "considerabil",
    "considerabilo": "considerabil",
    "considerabilul": "considerabil",
    "considerabilule": "considerabil",
    "considerabilului": "considerabil",
    "considerarea": "considerare",
    "considerareo": "considerare",
    "considerări": "considerare",
    "considerării": "considerare",
    "considerările": "considerare",
    "considerărilor": "considerare",
    "considerată": "considerat",
    "considerate": "considerat",
    "considerați": "considerat",
    "considerația": "considerație",
    "considerației": "considerație",
    "considerații": "considerație",
    "considerațiile": "considerație",
    "considerațiilor": "considerație",
    "considerațio": "considerație",
    "considerațiunea": "considerațiune",
    "considerațiuneo": "considerațiune",
    "considerațiuni": "considerațiune",
    "considerațiunii": "considerațiune",
    "considerațiunile": "considerațiune",
    "considerațiunilor": "considerațiune",
    "considerente": "considerent",
    "considerentele": "considerent",
    "considerentelor": "considerent",
    "considerentul": "considerent",
    "considerentule": "considerent",
    "considerentului": "considerent",
    "consignația": "consignație",
    "consignației": "consignație",
    "consignații": "consignație",
    "consignațiile": "consignație",
    "consignațiilor": "consignație",
    "consignațio": "consignație",
    "consiliai": "consilia",
    "consiliam": "consilia",
    "consiliară": "consilia",
    "consiliarăm": "consilia",
    "consiliarăți": "consilia",
    "consiliase": "consilia",
    "consiliasem": "consilia",
    "consiliaseră": "consilia",
    "consiliaserăm": "consilia",
    "consiliaserăți": "consilia",
    "consiliaseși": "consilia",
    "consiliași": "consilia",
    "consiliat": "consilia",
    "consiliați": "consilia",
    "consiliatu": "consilia",
    "consiliau": "consilia",
    "consiliază": "consilia",
    "consilie": "consilia",
    "consiliem": "consilia",
    "consiliez": "consilia",
    "consilieze": "consilia",
    "consiliezi": "consilia",
    "consiliind": "consilia",
    "consiliindu": "consilia",
    "neconsiliind": "consilia",
    "neconsiliindu": "consilia",
    "nemaiconsiliind": "consilia",
    "nemaiconsiliindu": "consilia",
    "consiliată": "consiliat",
    "consiliate": "consiliat",
    "consiliați": "consiliat",
    "consilieri": "consilier",
    "consilierii": "consilier",
    "consilierilor": "consilier",
    "consilierul": "consilier",
    "consilierule": "consilier",
    "consilierului": "consilier",
    "consiliera": "consilieră",
    "consiliere": "consilieră",
    "consilierei": "consilieră",
    "consilierele": "consilieră",
    "consilierelor": "consilieră",
    "consiliero": "consilieră",
    "consilierea": "consiliere",
    "consilieri": "consiliere",
    "consilierii": "consiliere",
    "consilierile": "consiliere",
    "consilierilor": "consiliere",
    "CA-uri": "Consilii_de_Administrație",
    "consilii": "consiliu",
    "consiliile": "consiliu",
    "consiliilor": "consiliu",
    "consiliul": "consiliu",
    "consiliule": "consiliu",
    "consiliului": "consiliu",
    "CA": "Consiliu_de_Administrație",
    "C.E.": "Consiliul_Europei",
    "consimțământul": "consimțământ",
    "consimțământule": "consimțământ",
    "consimțământului": "consimțământ",
    "consimțăminte": "consimțământ",
    "consimțămintele": "consimțământ",
    "consimțămintelor": "consimțământ",
    "consimt": "consimți",
    "consimtă": "consimți",
    "consimte": "consimți",
    "consimțea": "consimți",
    "consimțeai": "consimți",
    "consimțeam": "consimți",
    "consimțeați": "consimți",
    "consimțeau": "consimți",
    "consimțim": "consimți",
    "consimțind": "consimți",
    "consimțindu": "consimți",
    "consimțiră": "consimți",
    "consimțirăm": "consimți",
    "consimțirăți": "consimți",
    "consimțise": "consimți",
    "consimțisem": "consimți",
    "consimțiseră": "consimți",
    "consimțiserăm": "consimți",
    "consimțiserăți": "consimți",
    "consimțiseși": "consimți",
    "consimțiși": "consimți",
    "consimțit": "consimți",
    "consimțiți": "consimți",
    "consimțitu": "consimți",
    "consimțita": "consimțit",
    "consimțită": "consimțit",
    "consimțite": "consimțit",
    "consimțitei": "consimțit",
    "consimțitele": "consimțit",
    "consimțitelor": "consimțit",
    "consimțiți": "consimțit",
    "consimțiții": "consimțit",
    "consimțiților": "consimțit",
    "consimțito": "consimțit",
    "consimțitul": "consimțit",
    "consimțitule": "consimțit",
    "consimțitului": "consimțit",
    "consist": "consista",
    "consistă": "consista",
    "consistai": "consista",
    "consistam": "consista",
    "consistăm": "consista",
    "consistând": "consista",
    "consistându": "consista",
    "consistară": "consista",
    "consistarăm": "consista",
    "consistarăți": "consista",
    "consistase": "consista",
    "consistasem": "consista",
    "consistaseră": "consista",
    "consistaserăm": "consista",
    "consistaserăți": "consista",
    "consistaseși": "consista",
    "consistași": "consista",
    "consistat": "consista",
    "consistați": "consista",
    "consistatu": "consista",
    "consistau": "consista",
    "consiste": "consista",
    "consiști": "consista",
    "neconsistând": "consista",
    "neconsistându": "consista",
    "nemaiconsistând": "consista",
    "nemaiconsistându": "consista",
    "consistată": "consistat",
    "consistate": "consistat",
    "consistați": "consistat",
    "consistenta": "consistent",
    "consistentă": "consistent",
    "consistente": "consistent",
    "consistentei": "consistent",
    "consistentele": "consistent",
    "consistentelor": "consistent",
    "consistenți": "consistent",
    "consistenții": "consistent",
    "consistenților": "consistent",
    "consistento": "consistent",
    "consistentul": "consistent",
    "consistentule": "consistent",
    "consistentului": "consistent",
    "consistența": "consistență",
    "consistențe": "consistență",
    "consistenței": "consistență",
    "consistențele": "consistență",
    "consistențelor": "consistență",
    "consistențo": "consistență",
    "consoana": "consoană",
    "consoane": "consoană",
    "consoanei": "consoană",
    "consoanele": "consoană",
    "consoanelor": "consoană",
    "consoano": "consoană",
    "consoarta": "consoartă",
    "consoarte": "consoartă",
    "consoartei": "consoartă",
    "consoartele": "consoartă",
    "consoartelor": "consoartă",
    "consoarto": "consoartă",
    "consolă": "consola",
    "consolai": "consola",
    "consolam": "consola",
    "consolăm": "consola",
    "consolând": "consola",
    "consolându": "consola",
    "consolară": "consola",
    "consolarăm": "consola",
    "consolarăți": "consola",
    "consolase": "consola",
    "consolasem": "consola",
    "consolaseră": "consola",
    "consolaserăm": "consola",
    "consolaserăți": "consola",
    "consolaseși": "consola",
    "consolași": "consola",
    "consolat": "consola",
    "consolați": "consola",
    "consolatu": "consola",
    "consolau": "consola",
    "consolează": "consola",
    "consolez": "consola",
    "consoleze": "consola",
    "consolezi": "consola",
    "neconsolând": "consola",
    "neconsolându": "consola",
    "nemaiconsolând": "consola",
    "nemaiconsolându": "consola",
    "consola": "consolă",
    "console": "consolă",
    "consolei": "consolă",
    "consolele": "consolă",
    "consolelor": "consolă",
    "consolo": "consolă",
    "consolarea": "consolare",
    "consolareo": "consolare",
    "consolări": "consolare",
    "consolării": "consolare",
    "consolările": "consolare",
    "consolărilor": "consolare",
    "consolată": "consolat",
    "consolate": "consolat",
    "consolați": "consolat",
    "consolidă": "consolida",
    "consolidai": "consolida",
    "consolidam": "consolida",
    "consolidăm": "consolida",
    "consolidând": "consolida",
    "consolidându": "consolida",
    "consolidară": "consolida",
    "consolidarăm": "consolida",
    "consolidarăți": "consolida",
    "consolidase": "consolida",
    "consolidasem": "consolida",
    "consolidaseră": "consolida",
    "consolidaserăm": "consolida",
    "consolidaserăți": "consolida",
    "consolidaseși": "consolida",
    "consolidași": "consolida",
    "consolidat": "consolida",
    "consolidați": "consolida",
    "consolidatu": "consolida",
    "consolidau": "consolida",
    "consolidează": "consolida",
    "consolidez": "consolida",
    "consolideze": "consolida",
    "consolidezi": "consolida",
    "neconsolidând": "consolida",
    "neconsolidându": "consolida",
    "nemaiconsolidând": "consolida",
    "nemaiconsolidându": "consolida",
    "consolidarea": "consolidare",
    "consolidareo": "consolidare",
    "consolidări": "consolidare",
    "consolidării": "consolidare",
    "consolidările": "consolidare",
    "consolidărilor": "consolidare",
    "consolidată": "consolidat",
    "consolidate": "consolidat",
    "consolidați": "consolidat",
    "consonanta": "consonant",
    "consonantă": "consonant",
    "consonante": "consonant",
    "consonantei": "consonant",
    "consonantele": "consonant",
    "consonantelor": "consonant",
    "consonanți": "consonant",
    "consonanții": "consonant",
    "consonanților": "consonant",
    "consonanto": "consonant",
    "consonantul": "consonant",
    "consonantule": "consonant",
    "consonantului": "consonant",
    "consonanța": "consonanță",
    "consonanțe": "consonanță",
    "consonanței": "consonanță",
    "consonanțele": "consonanță",
    "consonanțelor": "consonanță",
    "consonanțo": "consonanță",
    "consonantica": "consonantic",
    "consonantică": "consonantic",
    "consonantice": "consonantic",
    "consonanticei": "consonantic",
    "consonanticele": "consonantic",
    "consonanticelor": "consonantic",
    "consonantici": "consonantic",
    "consonanticii": "consonantic",
    "consonanticilor": "consonantic",
    "consonantico": "consonantic",
    "consonanticul": "consonantic",
    "consonanticule": "consonantic",
    "consonanticului": "consonantic",
    "consorți": "consort",
    "consorții": "consort",
    "consorților": "consort",
    "consortul": "consort",
    "consortule": "consort",
    "consortului": "consort",
    "consorții": "consorțiu",
    "consorțiile": "consorțiu",
    "consorțiilor": "consorțiu",
    "consorțiul": "consorțiu",
    "consorțiule": "consorțiu",
    "consorțiului": "consorțiu",
    "conspecte": "conspect",
    "conspectele": "conspect",
    "conspectelor": "conspect",
    "conspectul": "conspect",
    "conspectule": "conspect",
    "conspectului": "conspect",
    "conspectă": "conspecta",
    "conspectai": "conspecta",
    "conspectam": "conspecta",
    "conspectăm": "conspecta",
    "conspectând": "conspecta",
    "conspectându": "conspecta",
    "conspectară": "conspecta",
    "conspectarăm": "conspecta",
    "conspectarăți": "conspecta",
    "conspectase": "conspecta",
    "conspectasem": "conspecta",
    "conspectaseră": "conspecta",
    "conspectaserăm": "conspecta",
    "conspectaserăți": "conspecta",
    "conspectaseși": "conspecta",
    "conspectași": "conspecta",
    "conspectat": "conspecta",
    "conspectați": "conspecta",
    "conspectatu": "conspecta",
    "conspectau": "conspecta",
    "conspectează": "conspecta",
    "conspectez": "conspecta",
    "conspecteze": "conspecta",
    "conspectezi": "conspecta",
    "neconspectând": "conspecta",
    "neconspectându": "conspecta",
    "nemaiconspectând": "conspecta",
    "nemaiconspectându": "conspecta",
    "conspectarea": "conspectare",
    "conspectareo": "conspectare",
    "conspectări": "conspectare",
    "conspectării": "conspectare",
    "conspectările": "conspectare",
    "conspectărilor": "conspectare",
    "conspectată": "conspectat",
    "conspectate": "conspectat",
    "conspectați": "conspectat",
    "conspir": "conspira",
    "conspiră": "conspira",
    "conspirai": "conspira",
    "conspiram": "conspira",
    "conspirăm": "conspira",
    "conspirând": "conspira",
    "conspirându": "conspira",
    "conspirară": "conspira",
    "conspirarăm": "conspira",
    "conspirarăți": "conspira",
    "conspirase": "conspira",
    "conspirasem": "conspira",
    "conspiraseră": "conspira",
    "conspiraserăm": "conspira",
    "conspiraserăți": "conspira",
    "conspiraseși": "conspira",
    "conspirași": "conspira",
    "conspirat": "conspira",
    "conspirați": "conspira",
    "conspiratu": "conspira",
    "conspirau": "conspira",
    "conspire": "conspira",
    "conspiri": "conspira",
    "neconspirând": "conspira",
    "neconspirându": "conspira",
    "nemaiconspirând": "conspira",
    "nemaiconspirându": "conspira",
    "conspirată": "conspirat",
    "conspirate": "conspirat",
    "conspirați": "conspirat",
    "conspirația": "conspirație",
    "conspirației": "conspirație",
    "conspirații": "conspirație",
    "conspirațiile": "conspirație",
    "conspirațiilor": "conspirație",
    "conspirațio": "conspirație",
    "conspiraționiștii": "conspiraționist",
    "conspiraționistul": "conspiraționist",
    "conspirativa": "conspirativ",
    "conspirativă": "conspirativ",
    "conspirative": "conspirativ",
    "conspirativei": "conspirativ",
    "conspirativele": "conspirativ",
    "conspirativelor": "conspirativ",
    "conspirativi": "conspirativ",
    "conspirativii": "conspirativ",
    "conspirativilor": "conspirativ",
    "conspirativo": "conspirativ",
    "conspirativul": "conspirativ",
    "conspirativule": "conspirativ",
    "conspirativului": "conspirativ",
    "conspiratoarea": "conspiratoare",
    "conspiratoarei": "conspiratoare",
    "conspiratoarele": "conspiratoare",
    "conspiratoarelor": "conspiratoare",
    "conspiratoareo": "conspiratoare",
    "conspiratori": "conspirator",
    "conspiratorii": "conspirator",
    "conspiratorilor": "conspirator",
    "conspiratorul": "conspirator",
    "conspiratorule": "conspirator",
    "conspiratorului": "conspirator",
    "constă": "consta",
    "constai": "consta",
    "constam": "consta",
    "constăm": "consta",
    "constând": "consta",
    "constându": "consta",
    "constară": "consta",
    "constarăm": "consta",
    "constarăți": "consta",
    "constase": "consta",
    "constasem": "consta",
    "constaseră": "consta",
    "constaserăm": "consta",
    "constaserăți": "consta",
    "constaseși": "consta",
    "constași": "consta",
    "constat": "consta",
    "constați": "consta",
    "constatu": "consta",
    "constau": "consta",
    "constea": "consta",
    "neconstând": "consta",
    "neconstându": "consta",
    "nemaiconstând": "consta",
    "nemaiconstându": "consta",
    "constanta": "constant",
    "constantă": "constant",
    "constante": "constant",
    "constantei": "constant",
    "constantele": "constant",
    "constantelor": "constant",
    "constanți": "constant",
    "constanții": "constant",
    "constanților": "constant",
    "constanto": "constant",
    "constantul": "constant",
    "constantule": "constant",
    "constantului": "constant",
    "constanta": "constantă",
    "constante": "constantă",
    "constantei": "constantă",
    "constantele": "constantă",
    "constantelor": "constantă",
    "constanto": "constantă",
    "Constanței": "Constanța",
    "constanța": "constanță",
    "constanțe": "constanță",
    "constanței": "constanță",
    "constanțele": "constanță",
    "constanțelor": "constanță",
    "constanțo": "constanță",
    "constantanul": "constantan",
    "constantanule": "constantan",
    "constantanului": "constantan",
    "constănțeana": "constănțean",
    "constănțeană": "constănțean",
    "constănțeanul": "constănțean",
    "constănțeanului": "constănțean",
    "constănțene": "constănțean",
    "constănțenei": "constănțean",
    "constănțenele": "constănțean",
    "constănțenelor": "constănțean",
    "constănțeni": "constănțean",
    "constănțenii": "constănțean",
    "constănțenilor": "constănțean",
    "constănțeanca": "constănțeancă",
    "constănțence": "constănțeancă",
    "constănțencei": "constănțeancă",
    "constănțencele": "constănțeancă",
    "constănțencelor": "constănțeancă",
    "C.": "Constantin",
    "constați": "constat",
    "constat": "constata",
    "constată": "constata",
    "constatai": "constata",
    "constatam": "constata",
    "constatăm": "constata",
    "constatând": "constata",
    "constatându": "constata",
    "constatară": "constata",
    "constatarăm": "constata",
    "constatarăți": "constata",
    "constatase": "constata",
    "constatasem": "constata",
    "constataseră": "constata",
    "constataserăm": "constata",
    "constataserăți": "constata",
    "constataseși": "constata",
    "constatași": "constata",
    "constatat": "constata",
    "constatați": "constata",
    "constatatu": "constata",
    "constatau": "constata",
    "constate": "constata",
    "constați": "constata",
    "neconstatând": "constata",
    "neconstatându": "constata",
    "nemaiconstatând": "constata",
    "nemaiconstatându": "constata",
    "constatarea": "constatare",
    "constatareo": "constatare",
    "constatări": "constatare",
    "constatării": "constatare",
    "constatările": "constatare",
    "constatărilor": "constatare",
    "constatată": "constatat",
    "constatate": "constatat",
    "constatați": "constatat",
    "constatatoare": "constatator",
    "constatatoarea": "constatator",
    "constatatoarei": "constatator",
    "constatatoarele": "constatator",
    "constatatoarelor": "constatator",
    "constatatoareo": "constatator",
    "constatatori": "constatator",
    "constatatorii": "constatator",
    "constatatorilor": "constatator",
    "constatatorul": "constatator",
    "constatatorule": "constatator",
    "constatatorului": "constatator",
    "constelația": "constelație",
    "constelației": "constelație",
    "constelații": "constelație",
    "constelațiile": "constelație",
    "constelațiilor": "constelație",
    "constelațio": "constelație",
    "consternă": "consterna",
    "consternai": "consterna",
    "consternam": "consterna",
    "consternăm": "consterna",
    "consternând": "consterna",
    "consternându": "consterna",
    "consternară": "consterna",
    "consternarăm": "consterna",
    "consternarăți": "consterna",
    "consternase": "consterna",
    "consternasem": "consterna",
    "consternaseră": "consterna",
    "consternaserăm": "consterna",
    "consternaserăți": "consterna",
    "consternaseși": "consterna",
    "consternași": "consterna",
    "consternat": "consterna",
    "consternați": "consterna",
    "consternatu": "consterna",
    "consternau": "consterna",
    "consternează": "consterna",
    "consternez": "consterna",
    "consterneze": "consterna",
    "consternezi": "consterna",
    "neconsternând": "consterna",
    "neconsternându": "consterna",
    "nemaiconsternând": "consterna",
    "nemaiconsternându": "consterna",
    "consternanta": "consternant",
    "consternantă": "consternant",
    "consternante": "consternant",
    "consternantele": "consternant",
    "consternantelor": "consternant",
    "consternanți": "consternant",
    "consternanții": "consternant",
    "consternanților": "consternant",
    "consternantul": "consternant",
    "consternantului": "consternant",
    "consternarea": "consternare",
    "consternareo": "consternare",
    "consternări": "consternare",
    "consternării": "consternare",
    "consternările": "consternare",
    "consternărilor": "consternare",
    "consternata": "consternat",
    "consternată": "consternat",
    "consternate": "consternat",
    "consternatei": "consternat",
    "consternatele": "consternat",
    "consternatelor": "consternat",
    "consternați": "consternat",
    "consternații": "consternat",
    "consternaților": "consternat",
    "consternato": "consternat",
    "consternatul": "consternat",
    "consternatule": "consternat",
    "consternatului": "consternat",
    "conștienta": "conștient",
    "conștientă": "conștient",
    "conștiente": "conștient",
    "conștientei": "conștient",
    "conștientele": "conștient",
    "conștientelor": "conștient",
    "conștienți": "conștient",
    "conștienții": "conștient",
    "conștienților": "conștient",
    "conștiento": "conștient",
    "conștientul": "conștient",
    "conștientule": "conștient",
    "conștientului": "conștient",
    "conștiența": "conștiență",
    "conștiențe": "conștiență",
    "conștienței": "conștiență",
    "conștiențele": "conștiență",
    "conștiențelor": "conștiență",
    "conștiențo": "conștiență",
    "conștientiză": "conștientiza",
    "conștientizai": "conștientiza",
    "conștientizam": "conștientiza",
    "conștientizăm": "conștientiza",
    "conștientizând": "conștientiza",
    "conștientizându": "conștientiza",
    "conștientizară": "conștientiza",
    "conștientizarăm": "conștientiza",
    "conștientizarăți": "conștientiza",
    "conștientizase": "conștientiza",
    "conștientizasem": "conștientiza",
    "conștientizaseră": "conștientiza",
    "conștientizaserăm": "conștientiza",
    "conștientizaserăți": "conștientiza",
    "conștientizaseși": "conștientiza",
    "conștientizași": "conștientiza",
    "conștientizat": "conștientiza",
    "conștientizați": "conștientiza",
    "conștientizatu": "conștientiza",
    "conștientizau": "conștientiza",
    "conștientizează": "conștientiza",
    "conștientizez": "conștientiza",
    "conștientizeze": "conștientiza",
    "conștientizezi": "conștientiza",
    "conștientizarea": "conștientizare",
    "conștientizareo": "conștientizare",
    "conștientizări": "conștientizare",
    "conștientizării": "conștientizare",
    "conștientizările": "conștientizare",
    "conștientizărilor": "conștientizare",
    "conștientizata": "conștientizat",
    "conștientizată": "conștientizat",
    "conștientizate": "conștientizat",
    "conștientizatei": "conștientizat",
    "conștientizatele": "conștientizat",
    "conștientizatelor": "conștientizat",
    "conștientizați": "conștientizat",
    "conștientizații": "conștientizat",
    "conștientizaților": "conștientizat",
    "conștientizato": "conștientizat",
    "conștientizatul": "conștientizat",
    "conștientizatule": "conștientizat",
    "conștientizatului": "conștientizat",
    "conștiincioasa": "conștiincios",
    "conștiincioasă": "conștiincios",
    "conștiincioase": "conștiincios",
    "conștiincioasei": "conștiincios",
    "conștiincioasele": "conștiincios",
    "conștiincioaselor": "conștiincios",
    "conștiincioaso": "conștiincios",
    "conștiincioși": "conștiincios",
    "conștiincioșii": "conștiincios",
    "conștiincioșilor": "conștiincios",
    "conștiinciosul": "conștiincios",
    "conștiinciosule": "conștiincios",
    "conștiinciosului": "conștiincios",
    "conștiința": "conștiință",
    "conștiințe": "conștiință",
    "conștiinței": "conștiință",
    "conștiințele": "conștiință",
    "conștiințelor": "conștiință",
    "conștiințo": "conștiință",
    "constip": "constipa",
    "constipă": "constipa",
    "constipai": "constipa",
    "constipam": "constipa",
    "constipăm": "constipa",
    "constipând": "constipa",
    "constipându": "constipa",
    "constipară": "constipa",
    "constiparăm": "constipa",
    "constiparăți": "constipa",
    "constipase": "constipa",
    "constipasem": "constipa",
    "constipaseră": "constipa",
    "constipaserăm": "constipa",
    "constipaserăți": "constipa",
    "constipaseși": "constipa",
    "constipași": "constipa",
    "constipat": "constipa",
    "constipați": "constipa",
    "constipatu": "constipa",
    "constipau": "constipa",
    "constipe": "constipa",
    "constipi": "constipa",
    "neconstipând": "constipa",
    "neconstipându": "constipa",
    "nemaiconstipând": "constipa",
    "nemaiconstipându": "constipa",
    "constipata": "constipat",
    "constipată": "constipat",
    "constipate": "constipat",
    "constipatei": "constipat",
    "constipatele": "constipat",
    "constipatelor": "constipat",
    "constipați": "constipat",
    "constipații": "constipat",
    "constipaților": "constipat",
    "constipato": "constipat",
    "constipatul": "constipat",
    "constipatule": "constipat",
    "constipatului": "constipat",
    "constituanta": "constituant",
    "constituantă": "constituant",
    "constituante": "constituant",
    "constituantei": "constituant",
    "constituantele": "constituant",
    "constituantelor": "constituant",
    "constituanți": "constituant",
    "constituanții": "constituant",
    "constituanților": "constituant",
    "constituanto": "constituant",
    "constituantul": "constituant",
    "constituantule": "constituant",
    "constituantului": "constituant",
    "constituentul": "constituent",
    "constituentule": "constituent",
    "constituentului": "constituent",
    "constituia": "constitui",
    "constituiai": "constitui",
    "constituiam": "constitui",
    "constituiați": "constitui",
    "constituiau": "constitui",
    "constituie": "constitui",
    "constituiească": "constitui",
    "constituiesc": "constitui",
    "constituiește": "constitui",
    "constituiești": "constitui",
    "constituii": "constitui",
    "constituim": "constitui",
    "constituind": "constitui",
    "constituindu": "constitui",
    "constituiră": "constitui",
    "constituirăm": "constitui",
    "constituirăți": "constitui",
    "constituise": "constitui",
    "constituisem": "constitui",
    "constituiseră": "constitui",
    "constituiserăm": "constitui",
    "constituiserăți": "constitui",
    "constituiseși": "constitui",
    "constituiși": "constitui",
    "constituit": "constitui",
    "constituiți": "constitui",
    "constituitu": "constitui",
    "neconstituind": "constitui",
    "neconstituindu": "constitui",
    "nemaiconstituind": "constitui",
    "nemaiconstituindu": "constitui",
    "constituirea": "constituire",
    "constituireo": "constituire",
    "constituiri": "constituire",
    "constituirii": "constituire",
    "constituirile": "constituire",
    "constituirilor": "constituire",
    "constituita": "constituit",
    "constituită": "constituit",
    "constituite": "constituit",
    "constituitei": "constituit",
    "constituitele": "constituit",
    "constituitelor": "constituit",
    "constituiți": "constituit",
    "constituiții": "constituit",
    "constituiților": "constituit",
    "constituito": "constituit",
    "constituitul": "constituit",
    "constituitule": "constituit",
    "constituitului": "constituit",
    "constituția": "constituție",
    "constituției": "constituție",
    "constituții": "constituție",
    "constituțiile": "constituție",
    "constituțiilor": "constituție",
    "constituțio": "constituție",
    "constituționala": "constituțional",
    "constituțională": "constituțional",
    "constituționale": "constituțional",
    "constituționalei": "constituțional",
    "constituționalele": "constituțional",
    "constituționalelor": "constituțional",
    "constituționali": "constituțional",
    "constituționalii": "constituțional",
    "constituționalilor": "constituțional",
    "constituționalo": "constituțional",
    "constituționalul": "constituțional",
    "constituționalule": "constituțional",
    "constituționalului": "constituțional",
    "constituționalismul": "constituționalism",
    "constituționalismule": "constituționalism",
    "constituționalismului": "constituționalism",
    "constituționaliști": "constituționalist",
    "constituționaliștii": "constituționalist",
    "constituționaliștilor": "constituționalist",
    "constituționalistul": "constituționalist",
    "constituționalistule": "constituționalist",
    "constituționalistului": "constituționalist",
    "constituționalista": "constituționalistă",
    "constituționaliste": "constituționalistă",
    "constituționalistei": "constituționalistă",
    "constituționalistele": "constituționalistă",
    "constituționalistelor": "constituționalistă",
    "constituționalisto": "constituționalistă",
    "constituționalitatea": "constituționalitate",
    "constituționalitateo": "constituționalitate",
    "constituționalități": "constituționalitate",
    "constituționalității": "constituționalitate",
    "constituționalitățile": "constituționalitate",
    "constituționalităților": "constituționalitate",
    "constitutiva": "constitutiv",
    "constitutivă": "constitutiv",
    "constitutive": "constitutiv",
    "constitutivei": "constitutiv",
    "constitutivele": "constitutiv",
    "constitutivelor": "constitutiv",
    "constitutivi": "constitutiv",
    "constitutivii": "constitutiv",
    "constitutivilor": "constitutiv",
    "constitutivo": "constitutiv",
    "constitutivul": "constitutiv",
    "constitutivule": "constitutiv",
    "constitutivului": "constitutiv",
    "constrâng": "constrânge",
    "constrângă": "constrânge",
    "constrângând": "constrânge",
    "constrângându": "constrânge",
    "constrângea": "constrânge",
    "constrângeai": "constrânge",
    "constrângeam": "constrânge",
    "constrângeați": "constrânge",
    "constrângeau": "constrânge",
    "constrângem": "constrânge",
    "constrângeți": "constrânge",
    "constrângi": "constrânge",
    "constrâns": "constrânge",
    "constrânse": "constrânge",
    "constrânsei": "constrânge",
    "constrânseră": "constrânge",
    "constrânserăm": "constrânge",
    "constrânserăți": "constrânge",
    "constrânsese": "constrânge",
    "constrânsesem": "constrânge",
    "constrânseseră": "constrânge",
    "constrânseserăm": "constrânge",
    "constrânseserăți": "constrânge",
    "constrânseseși": "constrânge",
    "constrânseși": "constrânge",
    "constrângerea": "constrângere",
    "constrângereo": "constrângere",
    "constrângeri": "constrângere",
    "constrângerii": "constrângere",
    "constrângerile": "constrângere",
    "constrângerilor": "constrângere",
    "constrânsa": "constrâns",
    "constrânsă": "constrâns",
    "constrânse": "constrâns",
    "constrânsei": "constrâns",
    "constrânsele": "constrâns",
    "constrânselor": "constrâns",
    "constrânși": "constrâns",
    "constrânșii": "constrâns",
    "constrânșilor": "constrâns",
    "constrânsul": "constrâns",
    "constrânsului": "constrâns",
    "constricția": "constricție",
    "constricției": "constricție",
    "constricții": "constricție",
    "constricțiile": "constricție",
    "constricțiilor": "constricție",
    "constricțio": "constricție",
    "constrictiva": "constrictiv",
    "constrictivă": "constrictiv",
    "constrictive": "constrictiv",
    "constrictivei": "constrictiv",
    "constrictivele": "constrictiv",
    "constrictivelor": "constrictiv",
    "constrictivi": "constrictiv",
    "constrictivii": "constrictiv",
    "constrictivilor": "constrictiv",
    "constrictivo": "constrictiv",
    "constrictivul": "constrictiv",
    "constrictivule": "constrictiv",
    "constrictivului": "constrictiv",
    "constrictoare": "constrictor",
    "constrictoarea": "constrictor",
    "constrictoarei": "constrictor",
    "constrictoarele": "constrictor",
    "constrictoarelor": "constrictor",
    "constrictoareo": "constrictor",
    "constrictori": "constrictor",
    "constrictorii": "constrictor",
    "constrictorilor": "constrictor",
    "constrictorul": "constrictor",
    "constrictorule": "constrictor",
    "constrictorului": "constrictor",
    "construcția": "construcție",
    "construcției": "construcție",
    "construcții": "construcție",
    "construcțiile": "construcție",
    "construcțiilor": "construcție",
    "construcțio": "construcție",
    "constr.": "construcții",
    "constructiva": "constructiv",
    "constructivă": "constructiv",
    "constructive": "constructiv",
    "constructivei": "constructiv",
    "constructivele": "constructiv",
    "constructivelor": "constructiv",
    "constructivi": "constructiv",
    "constructivii": "constructiv",
    "constructivilor": "constructiv",
    "constructivo": "constructiv",
    "constructivul": "constructiv",
    "constructivule": "constructiv",
    "constructivului": "constructiv",
    "constructoarea": "constructoare",
    "constructoarei": "constructoare",
    "constructoarele": "constructoare",
    "constructoarelor": "constructoare",
    "constructoareo": "constructoare",
    "constructori": "constructor",
    "constructorii": "constructor",
    "constructorilor": "constructor",
    "constructorul": "constructor",
    "constructorule": "constructor",
    "constructorului": "constructor",
    "construia": "construi",
    "construiai": "construi",
    "construiam": "construi",
    "construiască": "construi",
    "construiați": "construi",
    "construiau": "construi",
    "construiesc": "construi",
    "construiește": "construi",
    "construiești": "construi",
    "construii": "construi",
    "construim": "construi",
    "construind": "construi",
    "construindu": "construi",
    "construiră": "construi",
    "construirăm": "construi",
    "construirăți": "construi",
    "construise": "construi",
    "construisem": "construi",
    "construiseră": "construi",
    "construiserăm": "construi",
    "construiserăți": "construi",
    "construiseși": "construi",
    "construiși": "construi",
    "construit": "construi",
    "construiți": "construi",
    "construitu": "construi",
    "neconstruind": "construi",
    "neconstruindu": "construi",
    "nemaiconstruind": "construi",
    "nemaiconstruindu": "construi",
    "construirea": "construire",
    "construireo": "construire",
    "construiri": "construire",
    "construirii": "construire",
    "construirile": "construire",
    "construirilor": "construire",
    "construită": "construit",
    "construite": "construit",
    "construiți": "construit",
    "consuli": "consul",
    "consulii": "consul",
    "consulilor": "consul",
    "consulul": "consul",
    "consulule": "consul",
    "consulului": "consul",
    "consulate": "consulat",
    "consulatele": "consulat",
    "consulatelor": "consulat",
    "consulatul": "consulat",
    "consulatule": "consulat",
    "consulatului": "consulat",
    "consultul": "consult",
    "consultule": "consult",
    "consultului": "consult",
    "consulturi": "consult",
    "consulturile": "consult",
    "consulturilor": "consult",
    "consult": "consulta",
    "consultă": "consulta",
    "consultai": "consulta",
    "consultam": "consulta",
    "consultăm": "consulta",
    "consultând": "consulta",
    "consultându": "consulta",
    "consultară": "consulta",
    "consultarăm": "consulta",
    "consultarăți": "consulta",
    "consultase": "consulta",
    "consultasem": "consulta",
    "consultaseră": "consulta",
    "consultaserăm": "consulta",
    "consultaserăți": "consulta",
    "consultaseși": "consulta",
    "consultași": "consulta",
    "consultat": "consulta",
    "consultați": "consulta",
    "consultatu": "consulta",
    "consultau": "consulta",
    "consulte": "consulta",
    "consulți": "consulta",
    "neconsultând": "consulta",
    "neconsultându": "consulta",
    "nemaiconsultând": "consulta",
    "nemaiconsultându": "consulta",
    "consultanți": "consultant",
    "consultanții": "consultant",
    "consultanților": "consultant",
    "consultantul": "consultant",
    "consultantule": "consultant",
    "consultantului": "consultant",
    "consultanta": "consultantă",
    "consultante": "consultantă",
    "consultantei": "consultantă",
    "consultantele": "consultantă",
    "consultantelor": "consultantă",
    "consultanto": "consultantă",
    "consultarea": "consultare",
    "consultareo": "consultare",
    "consultări": "consultare",
    "consultării": "consultare",
    "consultările": "consultare",
    "consultărilor": "consultare",
    "consultată": "consultat",
    "consultate": "consultat",
    "consultați": "consultat",
    "consultația": "consultație",
    "consultației": "consultație",
    "consultații": "consultație",
    "consultațiile": "consultație",
    "consultațiilor": "consultație",
    "consultațio": "consultație",
    "consultativa": "consultativ",
    "consultativă": "consultativ",
    "consultative": "consultativ",
    "consultativei": "consultativ",
    "consultativele": "consultativ",
    "consultativelor": "consultativ",
    "consultativi": "consultativ",
    "consultativii": "consultativ",
    "consultativilor": "consultativ",
    "consultativo": "consultativ",
    "consultativul": "consultativ",
    "consultativule": "consultativ",
    "consultativului": "consultativ",
    "consumul": "consum",
    "consumule": "consum",
    "consumului": "consum",
    "consumuri": "consum",
    "consumurile": "consum",
    "consumurilor": "consum",
    "consum": "consuma",
    "consumă": "consuma",
    "consumai": "consuma",
    "consumam": "consuma",
    "consumăm": "consuma",
    "consumând": "consuma",
    "consumându": "consuma",
    "consumară": "consuma",
    "consumarăm": "consuma",
    "consumarăți": "consuma",
    "consumase": "consuma",
    "consumasem": "consuma",
    "consumaseră": "consuma",
    "consumaserăm": "consuma",
    "consumaserăți": "consuma",
    "consumaseși": "consuma",
    "consumași": "consuma",
    "consumat": "consuma",
    "consumați": "consuma",
    "consumatu": "consuma",
    "consumau": "consuma",
    "consume": "consuma",
    "consumi": "consuma",
    "neconsumând": "consuma",
    "neconsumându": "consuma",
    "nemaiconsumând": "consuma",
    "nemaiconsumându": "consuma",
    "consumarea": "consumare",
    "consumareo": "consumare",
    "consumări": "consumare",
    "consumării": "consumare",
    "consumările": "consumare",
    "consumărilor": "consumare",
    "consumată": "consumat",
    "consumate": "consumat",
    "consumați": "consumat",
    "consumația": "consumație",
    "consumației": "consumație",
    "consumații": "consumație",
    "consumațiile": "consumație",
    "consumațiilor": "consumație",
    "consumațio": "consumație",
    "consumatoarea": "consumatoare",
    "consumatoarei": "consumatoare",
    "consumatoarele": "consumatoare",
    "consumatoarelor": "consumatoare",
    "consumatoareo": "consumatoare",
    "consumatori": "consumator",
    "consumatorii": "consumator",
    "consumatorilor": "consumator",
    "consumatorul": "consumator",
    "consumatorule": "consumator",
    "consumatorului": "consumator",
    "contul": "cont",
    "contule": "cont",
    "contului": "cont",
    "conturi": "cont",
    "conturile": "cont",
    "conturilor": "cont",
    "contă": "conta",
    "contai": "conta",
    "contam": "conta",
    "contăm": "conta",
    "contând": "conta",
    "contându": "conta",
    "contară": "conta",
    "contarăm": "conta",
    "contarăți": "conta",
    "contase": "conta",
    "contasem": "conta",
    "contaseră": "conta",
    "contaserăm": "conta",
    "contaserăți": "conta",
    "contaseși": "conta",
    "contași": "conta",
    "contat": "conta",
    "contați": "conta",
    "contatu": "conta",
    "contau": "conta",
    "contează": "conta",
    "contez": "conta",
    "conteze": "conta",
    "contezi": "conta",
    "necontând": "conta",
    "necontându": "conta",
    "nemaicontând": "conta",
    "nemaicontându": "conta",
    "contabilă": "contabil",
    "contabile": "contabil",
    "contabili": "contabil",
    "contabilii": "contabil",
    "contabililor": "contabil",
    "contabilul": "contabil",
    "contabilule": "contabil",
    "contabilului": "contabil",
    "contabila": "contabilă",
    "contabile": "contabilă",
    "contabilei": "contabilă",
    "contabilele": "contabilă",
    "contabilelor": "contabilă",
    "contabilo": "contabilă",
    "cont.": "contabilitate",
    "contabilitatea": "contabilitate",
    "contabilitateo": "contabilitate",
    "contabilități": "contabilitate",
    "contabilității": "contabilitate",
    "contabilitățile": "contabilitate",
    "contabilităților": "contabilitate",
    "contabiliză": "contabiliza",
    "contabilizai": "contabiliza",
    "contabilizam": "contabiliza",
    "contabilizăm": "contabiliza",
    "contabilizând": "contabiliza",
    "contabilizându": "contabiliza",
    "contabilizară": "contabiliza",
    "contabilizarăm": "contabiliza",
    "contabilizarăți": "contabiliza",
    "contabilizase": "contabiliza",
    "contabilizasem": "contabiliza",
    "contabilizaseră": "contabiliza",
    "contabilizaserăm": "contabiliza",
    "contabilizaserăți": "contabiliza",
    "contabilizaseși": "contabiliza",
    "contabilizași": "contabiliza",
    "contabilizat": "contabiliza",
    "contabilizați": "contabiliza",
    "contabilizatu": "contabiliza",
    "contabilizau": "contabiliza",
    "contabilizează": "contabiliza",
    "contabilizez": "contabiliza",
    "contabilizeze": "contabiliza",
    "contabilizezi": "contabiliza",
    "necontabilizând": "contabiliza",
    "necontabilizându": "contabiliza",
    "nemaicontabilizând": "contabiliza",
    "nemaicontabilizându": "contabiliza",
    "contabilizarea": "contabilizare",
    "contabilizareo": "contabilizare",
    "contabilizări": "contabilizare",
    "contabilizării": "contabilizare",
    "contabilizările": "contabilizare",
    "contabilizărilor": "contabilizare",
    "contabilizată": "contabilizat",
    "contabilizate": "contabilizat",
    "contabilizați": "contabilizat",
    "contacte": "contact",
    "contactele": "contact",
    "contactelor": "contact",
    "contactul": "contact",
    "contactule": "contact",
    "contactului": "contact",
    "contactă": "contacta",
    "contactai": "contacta",
    "contactam": "contacta",
    "contactăm": "contacta",
    "contactând": "contacta",
    "contactându": "contacta",
    "contactară": "contacta",
    "contactarăm": "contacta",
    "contactarăți": "contacta",
    "contactase": "contacta",
    "contactasem": "contacta",
    "contactaseră": "contacta",
    "contactaserăm": "contacta",
    "contactaserăți": "contacta",
    "contactaseși": "contacta",
    "contactași": "contacta",
    "contactat": "contacta",
    "contactați": "contacta",
    "contactatu": "contacta",
    "contactau": "contacta",
    "contactează": "contacta",
    "contactez": "contacta",
    "contacteze": "contacta",
    "contactezi": "contacta",
    "contactarea": "contactare",
    "contactări": "contactare",
    "contactării": "contactare",
    "contactările": "contactare",
    "contactărilor": "contactare",
    "contactată": "contactat",
    "contactate": "contactat",
    "contactați": "contactat",
    "contactoare": "contactor",
    "contactoarele": "contactor",
    "contactoarelor": "contactor",
    "contactorul": "contactor",
    "contactorule": "contactor",
    "contactorului": "contactor",
    "contagiai": "contagia",
    "contagiam": "contagia",
    "contagiară": "contagia",
    "contagiarăm": "contagia",
    "contagiarăți": "contagia",
    "contagiase": "contagia",
    "contagiasem": "contagia",
    "contagiaseră": "contagia",
    "contagiaserăm": "contagia",
    "contagiaserăți": "contagia",
    "contagiaseși": "contagia",
    "contagiași": "contagia",
    "contagiat": "contagia",
    "contagiați": "contagia",
    "contagiatu": "contagia",
    "contagiau": "contagia",
    "contagiază": "contagia",
    "contagie": "contagia",
    "contagiem": "contagia",
    "contagiez": "contagia",
    "contagieze": "contagia",
    "contagiezi": "contagia",
    "contagiind": "contagia",
    "contagiindu": "contagia",
    "necontagiind": "contagia",
    "necontagiindu": "contagia",
    "nemaicontagiind": "contagia",
    "nemaicontagiindu": "contagia",
    "contagiată": "contagiat",
    "contagiate": "contagiat",
    "contagiați": "contagiat",
    "contagioasa": "contagios",
    "contagioasă": "contagios",
    "contagioase": "contagios",
    "contagioasei": "contagios",
    "contagioasele": "contagios",
    "contagioaselor": "contagios",
    "contagioaso": "contagios",
    "contagioși": "contagios",
    "contagioșii": "contagios",
    "contagioșilor": "contagios",
    "contagiosul": "contagios",
    "contagiosule": "contagios",
    "contagiosului": "contagios",
    "contagiunea": "contagiune",
    "contagiuneo": "contagiune",
    "contagiuni": "contagiune",
    "contagiunii": "contagiune",
    "contagiunile": "contagiune",
    "contagiunilor": "contagiune",
    "contamină": "contamina",
    "contaminai": "contamina",
    "contaminam": "contamina",
    "contaminăm": "contamina",
    "contaminând": "contamina",
    "contaminându": "contamina",
    "contaminară": "contamina",
    "contaminarăm": "contamina",
    "contaminarăți": "contamina",
    "contaminase": "contamina",
    "contaminasem": "contamina",
    "contaminaseră": "contamina",
    "contaminaserăm": "contamina",
    "contaminaserăți": "contamina",
    "contaminaseși": "contamina",
    "contaminași": "contamina",
    "contaminat": "contamina",
    "contaminați": "contamina",
    "contaminatu": "contamina",
    "contaminau": "contamina",
    "contaminează": "contamina",
    "contaminez": "contamina",
    "contamineze": "contamina",
    "contaminezi": "contamina",
    "necontaminând": "contamina",
    "necontaminându": "contamina",
    "nemaicontaminând": "contamina",
    "nemaicontaminându": "contamina",
    "contaminabila": "contaminabil",
    "contaminabilă": "contaminabil",
    "contaminabile": "contaminabil",
    "contaminabilei": "contaminabil",
    "contaminabilele": "contaminabil",
    "contaminabilelor": "contaminabil",
    "contaminabili": "contaminabil",
    "contaminabilii": "contaminabil",
    "contaminabililor": "contaminabil",
    "contaminabilo": "contaminabil",
    "contaminabilul": "contaminabil",
    "contaminabilule": "contaminabil",
    "contaminabilului": "contaminabil",
    "contaminarea": "contaminare",
    "contaminareo": "contaminare",
    "contaminări": "contaminare",
    "contaminării": "contaminare",
    "contaminările": "contaminare",
    "contaminărilor": "contaminare",
    "contaminată": "contaminat",
    "contaminate": "contaminat",
    "contaminați": "contaminat",
    "contășe": "contăș",
    "contășele": "contăș",
    "contășelor": "contăș",
    "contășul": "contăș",
    "contășule": "contăș",
    "contășului": "contăș",
    "contată": "contat",
    "contate": "contat",
    "contați": "contat",
    "contele": "conte",
    "contelui": "conte",
    "conți": "conte",
    "conții": "conte",
    "conților": "conte",
    "contemplă": "contempla",
    "contemplai": "contempla",
    "contemplam": "contempla",
    "contemplăm": "contempla",
    "contemplând": "contempla",
    "contemplându": "contempla",
    "contemplară": "contempla",
    "contemplarăm": "contempla",
    "contemplarăți": "contempla",
    "contemplase": "contempla",
    "contemplasem": "contempla",
    "contemplaseră": "contempla",
    "contemplaserăm": "contempla",
    "contemplaserăți": "contempla",
    "contemplaseși": "contempla",
    "contemplași": "contempla",
    "contemplat": "contempla",
    "contemplați": "contempla",
    "contemplatu": "contempla",
    "contemplau": "contempla",
    "contemple": "contempla",
    "contempli": "contempla",
    "contemplu": "contempla",
    "necontemplând": "contempla",
    "necontemplându": "contempla",
    "nemaicontemplând": "contempla",
    "nemaicontemplându": "contempla",
    "contemplarea": "contemplare",
    "contemplareo": "contemplare",
    "contemplări": "contemplare",
    "contemplării": "contemplare",
    "contemplările": "contemplare",
    "contemplărilor": "contemplare",
    "contemplată": "contemplat",
    "contemplate": "contemplat",
    "contemplați": "contemplat",
    "contemplația": "contemplație",
    "contemplației": "contemplație",
    "contemplații": "contemplație",
    "contemplațiile": "contemplație",
    "contemplațiilor": "contemplație",
    "contemplațio": "contemplație",
    "contemplativa": "contemplativ",
    "contemplativă": "contemplativ",
    "contemplative": "contemplativ",
    "contemplativei": "contemplativ",
    "contemplativele": "contemplativ",
    "contemplativelor": "contemplativ",
    "contemplativi": "contemplativ",
    "contemplativii": "contemplativ",
    "contemplativilor": "contemplativ",
    "contemplativo": "contemplativ",
    "contemplativul": "contemplativ",
    "contemplativule": "contemplativ",
    "contemplativului": "contemplativ",
    "contemplatoarea": "contemplatoare",
    "contemplatoarei": "contemplatoare",
    "contemplatoarele": "contemplatoare",
    "contemplatoarelor": "contemplatoare",
    "contemplatoareo": "contemplatoare",
    "contemplatori": "contemplator",
    "contemplatorii": "contemplator",
    "contemplatorilor": "contemplator",
    "contemplatorul": "contemplator",
    "contemplatorule": "contemplator",
    "contemplatorului": "contemplator",
    "contemporana": "contemporan",
    "contemporană": "contemporan",
    "contemporane": "contemporan",
    "contemporanei": "contemporan",
    "contemporanele": "contemporan",
    "contemporanelor": "contemporan",
    "contemporani": "contemporan",
    "contemporanii": "contemporan",
    "contemporanilor": "contemporan",
    "contemporano": "contemporan",
    "contemporanul": "contemporan",
    "contemporanule": "contemporan",
    "contemporanului": "contemporan",
    "contemporaneitatea": "contemporaneitate",
    "contemporaneitateo": "contemporaneitate",
    "contemporaneități": "contemporaneitate",
    "contemporaneității": "contemporaneitate",
    "contemporaneitățile": "contemporaneitate",
    "contemporaneităților": "contemporaneitate",
    "contencioase": "contencios",
    "contencioasele": "contencios",
    "contencioaselor": "contencios",
    "contenciosul": "contencios",
    "contenciosule": "contencios",
    "contenciosului": "contencios",
    "contenea": "conteni",
    "conteneai": "conteni",
    "conteneam": "conteni",
    "contenească": "conteni",
    "conteneați": "conteni",
    "conteneau": "conteni",
    "contenesc": "conteni",
    "contenește": "conteni",
    "contenești": "conteni",
    "contenii": "conteni",
    "contenim": "conteni",
    "contenind": "conteni",
    "contenindu": "conteni",
    "conteniră": "conteni",
    "contenirăm": "conteni",
    "contenirăți": "conteni",
    "contenise": "conteni",
    "contenisem": "conteni",
    "conteniseră": "conteni",
    "conteniserăm": "conteni",
    "conteniserăți": "conteni",
    "conteniseși": "conteni",
    "conteniși": "conteni",
    "contenit": "conteni",
    "conteniți": "conteni",
    "contenitu": "conteni",
    "necontenind": "conteni",
    "necontenindu": "conteni",
    "nemaicontenind": "conteni",
    "nemaicontenindu": "conteni",
    "contenirea": "contenire",
    "contenireo": "contenire",
    "conteniri": "contenire",
    "contenirii": "contenire",
    "contenirile": "contenire",
    "contenirilor": "contenire",
    "contenită": "contenit",
    "contenite": "contenit",
    "conteniți": "contenit",
    "contesa": "contesă",
    "contese": "contesă",
    "contesei": "contesă",
    "contesele": "contesă",
    "conteselor": "contesă",
    "conteso": "contesă",
    "contest": "contesta",
    "contestă": "contesta",
    "contestai": "contesta",
    "contestam": "contesta",
    "contestăm": "contesta",
    "contestând": "contesta",
    "contestându": "contesta",
    "contestară": "contesta",
    "contestarăm": "contesta",
    "contestarăți": "contesta",
    "contestase": "contesta",
    "contestasem": "contesta",
    "contestaseră": "contesta",
    "contestaserăm": "contesta",
    "contestaserăți": "contesta",
    "contestaseși": "contesta",
    "contestași": "contesta",
    "contestat": "contesta",
    "contestați": "contesta",
    "contestatu": "contesta",
    "contestau": "contesta",
    "conteste": "contesta",
    "contești": "contesta",
    "necontestând": "contesta",
    "necontestându": "contesta",
    "nemaicontestând": "contesta",
    "nemaicontestându": "contesta",
    "contestabila": "contestabil",
    "contestabilă": "contestabil",
    "contestabile": "contestabil",
    "contestabilei": "contestabil",
    "contestabilele": "contestabil",
    "contestabilelor": "contestabil",
    "contestabili": "contestabil",
    "contestabilii": "contestabil",
    "contestabililor": "contestabil",
    "contestabilo": "contestabil",
    "contestabilul": "contestabil",
    "contestabilule": "contestabil",
    "contestabilului": "contestabil",
    "contestarea": "contestare",
    "contestareo": "contestare",
    "contestări": "contestare",
    "contestării": "contestare",
    "contestările": "contestare",
    "contestărilor": "contestare",
    "contestată": "contestat",
    "contestate": "contestat",
    "contestați": "contestat",
    "contestația": "contestație",
    "contestației": "contestație",
    "contestații": "contestație",
    "contestațiile": "contestație",
    "contestațiilor": "contestație",
    "contestațio": "contestație",
    "contexte": "context",
    "contextele": "context",
    "contextelor": "context",
    "contextul": "context",
    "contextule": "context",
    "contextului": "context",
    "contiguitatea": "contiguitate",
    "contiguitateo": "contiguitate",
    "contiguități": "contiguitate",
    "contiguității": "contiguitate",
    "contiguitățile": "contiguitate",
    "contiguităților": "contiguitate",
    "contigua": "contiguu",
    "contiguă": "contiguu",
    "contigue": "contiguu",
    "contiguei": "contiguu",
    "contiguele": "contiguu",
    "contiguelor": "contiguu",
    "contigui": "contiguu",
    "contiguii": "contiguu",
    "contiguilor": "contiguu",
    "contiguo": "contiguu",
    "contiguul": "contiguu",
    "contiguule": "contiguu",
    "contiguului": "contiguu",
    "conții": "conține",
    "conțin": "conține",
    "conțină": "conține",
    "conținând": "conține",
    "conținându": "conține",
    "conținea": "conține",
    "conțineai": "conține",
    "conțineam": "conține",
    "conțineați": "conține",
    "conțineau": "conține",
    "conținem": "conține",
    "conțineți": "conține",
    "conținu": "conține",
    "conținui": "conține",
    "conținură": "conține",
    "conținurăm": "conține",
    "conținurăți": "conține",
    "conținuse": "conține",
    "conținusem": "conține",
    "conținuseră": "conține",
    "conținuserăm": "conține",
    "conținuserăți": "conține",
    "conținuseși": "conține",
    "conținuși": "conține",
    "conținut": "conține",
    "conținutu": "conține",
    "neconținând": "conține",
    "neconținându": "conține",
    "nemaiconținând": "conține",
    "nemaiconținându": "conține",
    "continente": "continent",
    "continentele": "continent",
    "continentelor": "continent",
    "continentul": "continent",
    "continentule": "continent",
    "continentului": "continent",
    "continentala": "continental",
    "continentală": "continental",
    "continentale": "continental",
    "continentalei": "continental",
    "continentalele": "continental",
    "continentalelor": "continental",
    "continentali": "continental",
    "continentalii": "continental",
    "continentalilor": "continental",
    "continentalo": "continental",
    "continentalul": "continental",
    "continentalule": "continental",
    "continentalului": "continental",
    "contingente": "contingent",
    "contingentele": "contingent",
    "contingentelor": "contingent",
    "contingentul": "contingent",
    "contingentule": "contingent",
    "contingentului": "contingent",
    "contingentata": "contingentat",
    "contingentată": "contingentat",
    "contingentate": "contingentat",
    "contingentatei": "contingentat",
    "contingentatele": "contingentat",
    "contingentatelor": "contingentat",
    "contingentați": "contingentat",
    "contingentații": "contingentat",
    "contingentaților": "contingentat",
    "contingentato": "contingentat",
    "contingentatul": "contingentat",
    "contingentatule": "contingentat",
    "contingentatului": "contingentat",
    "continuă": "continua",
    "continuai": "continua",
    "continuam": "continua",
    "continuăm": "continua",
    "continuând": "continua",
    "continuându": "continua",
    "continuară": "continua",
    "continuarăm": "continua",
    "continuarăți": "continua",
    "continuase": "continua",
    "continuasem": "continua",
    "continuaseră": "continua",
    "continuaserăm": "continua",
    "continuaserăți": "continua",
    "continuaseși": "continua",
    "continuași": "continua",
    "continuat": "continua",
    "continuați": "continua",
    "continuatu": "continua",
    "continuau": "continua",
    "continue": "continua",
    "continui": "continua",
    "continuu": "continua",
    "necontinuând": "continua",
    "necontinuându": "continua",
    "nemaicontinuând": "continua",
    "nemaicontinuându": "continua",
    "continuarea": "continuare",
    "continuareo": "continuare",
    "continuări": "continuare",
    "continuării": "continuare",
    "continuările": "continuare",
    "continuărilor": "continuare",
    "continuata": "continuat",
    "continuată": "continuat",
    "continuate": "continuat",
    "continuatei": "continuat",
    "continuatele": "continuat",
    "continuatelor": "continuat",
    "continuați": "continuat",
    "continuații": "continuat",
    "continuaților": "continuat",
    "continuato": "continuat",
    "continuatul": "continuat",
    "continuatule": "continuat",
    "continuatului": "continuat",
    "continuatoarea": "continuatoare",
    "continuatoarei": "continuatoare",
    "continuatoarele": "continuatoare",
    "continuatoarelor": "continuatoare",
    "continuatoareo": "continuatoare",
    "continuatori": "continuator",
    "continuatorii": "continuator",
    "continuatorilor": "continuator",
    "continuatorul": "continuator",
    "continuatorule": "continuator",
    "continuatorului": "continuator",
    "continuitatea": "continuitate",
    "continuitateo": "continuitate",
    "continuități": "continuitate",
    "continuității": "continuitate",
    "continuitățile": "continuitate",
    "continuităților": "continuitate",
    "conținută": "conținut",
    "conținute": "conținut",
    "conținuți": "conținut",
    "conținutul": "conținut",
    "conținutule": "conținut",
    "conținutului": "conținut",
    "conținuturi": "conținut",
    "conținuturile": "conținut",
    "conținuturilor": "conținut",
    "continua": "continuu",
    "continuă": "continuu",
    "continue": "continuu",
    "continuei": "continuu",
    "continuele": "continuu",
    "continuelor": "continuu",
    "continui": "continuu",
    "continuii": "continuu",
    "continuilor": "continuu",
    "continuo": "continuu",
    "continuul": "continuu",
    "continuule": "continuu",
    "continuului": "continuu",
    "contondenta": "contondent",
    "contondentă": "contondent",
    "contondente": "contondent",
    "contondentei": "contondent",
    "contondentele": "contondent",
    "contondentelor": "contondent",
    "contondenți": "contondent",
    "contondenții": "contondent",
    "contondenților": "contondent",
    "contondento": "contondent",
    "contondentul": "contondent",
    "contondentule": "contondent",
    "contondentului": "contondent",
    "contopea": "contopi",
    "contopeai": "contopi",
    "contopeam": "contopi",
    "contopească": "contopi",
    "contopeați": "contopi",
    "contopeau": "contopi",
    "contopesc": "contopi",
    "contopește": "contopi",
    "contopești": "contopi",
    "contopii": "contopi",
    "contopim": "contopi",
    "contopind": "contopi",
    "contopindu": "contopi",
    "contopiră": "contopi",
    "contopirăm": "contopi",
    "contopirăți": "contopi",
    "contopise": "contopi",
    "contopisem": "contopi",
    "contopiseră": "contopi",
    "contopiserăm": "contopi",
    "contopiserăți": "contopi",
    "contopiseși": "contopi",
    "contopiși": "contopi",
    "contopit": "contopi",
    "contopiți": "contopi",
    "contopitu": "contopi",
    "necontopind": "contopi",
    "necontopindu": "contopi",
    "nemaicontopind": "contopi",
    "nemaicontopindu": "contopi",
    "contopirea": "contopire",
    "contopireo": "contopire",
    "contopiri": "contopire",
    "contopirii": "contopire",
    "contopirile": "contopire",
    "contopirilor": "contopire",
    "conțopiști": "conțopist",
    "conțopiștii": "conțopist",
    "conțopiștilor": "conțopist",
    "conțopistul": "conțopist",
    "conțopistule": "conțopist",
    "conțopistului": "conțopist",
    "conțopista": "conțopistă",
    "conțopiste": "conțopistă",
    "conțopistei": "conțopistă",
    "conțopistele": "conțopistă",
    "conțopistelor": "conțopistă",
    "conțopisto": "conțopistă",
    "contopită": "contopit",
    "contopite": "contopit",
    "contopiți": "contopit",
    "contoare": "contor",
    "contoarele": "contor",
    "contoarelor": "contor",
    "contorul": "contor",
    "contorule": "contor",
    "contorului": "contor",
    "contorsionă": "contorsiona",
    "contorsionai": "contorsiona",
    "contorsionam": "contorsiona",
    "contorsionăm": "contorsiona",
    "contorsionând": "contorsiona",
    "contorsionându": "contorsiona",
    "contorsionară": "contorsiona",
    "contorsionarăm": "contorsiona",
    "contorsionarăți": "contorsiona",
    "contorsionase": "contorsiona",
    "contorsionasem": "contorsiona",
    "contorsionaseră": "contorsiona",
    "contorsionaserăm": "contorsiona",
    "contorsionaserăți": "contorsiona",
    "contorsionaseși": "contorsiona",
    "contorsionași": "contorsiona",
    "contorsionat": "contorsiona",
    "contorsionați": "contorsiona",
    "contorsionatu": "contorsiona",
    "contorsionau": "contorsiona",
    "contorsionează": "contorsiona",
    "contorsionez": "contorsiona",
    "contorsioneze": "contorsiona",
    "contorsionezi": "contorsiona",
    "necontorsionând": "contorsiona",
    "necontorsionându": "contorsiona",
    "nemaicontorsionând": "contorsiona",
    "nemaicontorsionându": "contorsiona",
    "contorsionată": "contorsionat",
    "contorsionate": "contorsionat",
    "contorsionați": "contorsionat",
    "contorsioniști": "contorsionist",
    "contorsioniștii": "contorsionist",
    "contorsioniștilor": "contorsionist",
    "contorsionistul": "contorsionist",
    "contorsionistule": "contorsionist",
    "contorsionistului": "contorsionist",
    "contorsionista": "contorsionistă",
    "contorsioniste": "contorsionistă",
    "contorsionistei": "contorsionistă",
    "contorsionistele": "contorsionistă",
    "contorsionistelor": "contorsionistă",
    "contorsionisto": "contorsionistă",
    "contorsiunea": "contorsiune",
    "contorsiuneo": "contorsiune",
    "contorsiuni": "contorsiune",
    "contorsiunii": "contorsiune",
    "contorsiunile": "contorsiune",
    "contorsiunilor": "contorsiune",
    "con.": "contra",
    "contră": "contra",
    "contrai": "contra",
    "contram": "contra",
    "contrăm": "contra",
    "contrând": "contra",
    "contrându": "contra",
    "contrară": "contra",
    "contrarăm": "contra",
    "contrarăți": "contra",
    "contrase": "contra",
    "contrasem": "contra",
    "contraseră": "contra",
    "contraserăm": "contra",
    "contraserăți": "contra",
    "contraseși": "contra",
    "contrași": "contra",
    "contrat": "contra",
    "contrați": "contra",
    "contratu": "contra",
    "contrau": "contra",
    "contrează": "contra",
    "contrez": "contra",
    "contreze": "contra",
    "contrezi": "contra",
    "cr.": "contra",
    "contra": "contră",
    "contre": "contră",
    "contrei": "contră",
    "contrele": "contră",
    "contrelor": "contră",
    "contro": "contră",
    "contraargumente": "contraargument",
    "contraargumentele": "contraargument",
    "contraargumentelor": "contraargument",
    "contraargumentul": "contraargument",
    "contraargumentului": "contraargument",
    "contraargumentă": "contraargumenta",
    "contraargumentai": "contraargumenta",
    "contraargumentam": "contraargumenta",
    "contraargumentăm": "contraargumenta",
    "contraargumentând": "contraargumenta",
    "contraargumentându": "contraargumenta",
    "contraargumentară": "contraargumenta",
    "contraargumentarăm": "contraargumenta",
    "contraargumentarăți": "contraargumenta",
    "contraargumentase": "contraargumenta",
    "contraargumentasem": "contraargumenta",
    "contraargumentaseră": "contraargumenta",
    "contraargumentaserăm": "contraargumenta",
    "contraargumentaserăți": "contraargumenta",
    "contraargumentaseși": "contraargumenta",
    "contraargumentași": "contraargumenta",
    "contraargumentat": "contraargumenta",
    "contraargumentați": "contraargumenta",
    "contraargumentatu": "contraargumenta",
    "contraargumentau": "contraargumenta",
    "contraargumentează": "contraargumenta",
    "contraargumentez": "contraargumenta",
    "contraargumenteze": "contraargumenta",
    "contraargumentezi": "contraargumenta",
    "contraargumentarea": "contraargumentare",
    "contraargumentări": "contraargumentare",
    "contraargumentării": "contraargumentare",
    "contraargumentările": "contraargumentare",
    "contraargumentărilor": "contraargumentare",
    "contraargumentata": "contraargumentat",
    "contraargumentată": "contraargumentat",
    "contraargumentate": "contraargumentat",
    "contraargumentatei": "contraargumentat",
    "contraargumentatele": "contraargumentat",
    "contraargumentatelor": "contraargumentat",
    "contraargumentați": "contraargumentat",
    "contraargumentații": "contraargumentat",
    "contraargumentaților": "contraargumentat",
    "contraargumentatul": "contraargumentat",
    "contraargumentatului": "contraargumentat",
    "contrabalansă": "contrabalansa",
    "contrabalansai": "contrabalansa",
    "contrabalansam": "contrabalansa",
    "contrabalansăm": "contrabalansa",
    "contrabalansând": "contrabalansa",
    "contrabalansându": "contrabalansa",
    "contrabalansară": "contrabalansa",
    "contrabalansarăm": "contrabalansa",
    "contrabalansarăți": "contrabalansa",
    "contrabalansase": "contrabalansa",
    "contrabalansasem": "contrabalansa",
    "contrabalansaseră": "contrabalansa",
    "contrabalansaserăm": "contrabalansa",
    "contrabalansaserăți": "contrabalansa",
    "contrabalansaseși": "contrabalansa",
    "contrabalansași": "contrabalansa",
    "contrabalansat": "contrabalansa",
    "contrabalansați": "contrabalansa",
    "contrabalansatu": "contrabalansa",
    "contrabalansau": "contrabalansa",
    "contrabalansează": "contrabalansa",
    "contrabalansez": "contrabalansa",
    "contrabalanseze": "contrabalansa",
    "contrabalansezi": "contrabalansa",
    "contrabalansata": "contrabalansat",
    "contrabalansată": "contrabalansat",
    "contrabalansate": "contrabalansat",
    "contrabalansatei": "contrabalansat",
    "contrabalansatele": "contrabalansat",
    "contrabalansatelor": "contrabalansat",
    "contrabalansați": "contrabalansat",
    "contrabalansații": "contrabalansat",
    "contrabalansaților": "contrabalansat",
    "contrabalansato": "contrabalansat",
    "contrabalansatul": "contrabalansat",
    "contrabalansatule": "contrabalansat",
    "contrabalansatului": "contrabalansat",
    "contrabanda": "contrabandă",
    "contrabande": "contrabandă",
    "contrabandei": "contrabandă",
    "contrabandele": "contrabandă",
    "contrabandelor": "contrabandă",
    "contrabando": "contrabandă",
    "contrabandiști": "contrabandist",
    "contrabandiștii": "contrabandist",
    "contrabandiștilor": "contrabandist",
    "contrabandistul": "contrabandist",
    "contrabandistule": "contrabandist",
    "contrabandistului": "contrabandist",
    "contrabandista": "contrabandistă",
    "contrabandiste": "contrabandistă",
    "contrabandistei": "contrabandistă",
    "contrabandistele": "contrabandistă",
    "contrabandistelor": "contrabandistă",
    "contrabandisto": "contrabandistă",
    "contrabași": "contrabas",
    "contrabașii": "contrabas",
    "contrabașilor": "contrabas",
    "contrabasul": "contrabas",
    "contrabasule": "contrabas",
    "contrabasului": "contrabas",
    "contrabasuri": "contrabas",
    "contrabasurile": "contrabas",
    "contrabasurilor": "contrabas",
    "contracandidatura": "contracandidatură",
    "contracandidaturi": "contracandidatură",
    "contracandidaturii": "contracandidatură",
    "contracandidaturile": "contracandidatură",
    "contracandidaturilor": "contracandidatură",
    "contracară": "contracara",
    "contracarai": "contracara",
    "contracaram": "contracara",
    "contracarăm": "contracara",
    "contracarând": "contracara",
    "contracarându": "contracara",
    "contracarară": "contracara",
    "contracararăm": "contracara",
    "contracararăți": "contracara",
    "contracarase": "contracara",
    "contracarasem": "contracara",
    "contracaraseră": "contracara",
    "contracaraserăm": "contracara",
    "contracaraserăți": "contracara",
    "contracaraseși": "contracara",
    "contracarași": "contracara",
    "contracarat": "contracara",
    "contracarați": "contracara",
    "contracaratu": "contracara",
    "contracarau": "contracara",
    "contracarează": "contracara",
    "contracarez": "contracara",
    "contracareze": "contracara",
    "contracarezi": "contracara",
    "necontracarând": "contracara",
    "necontracarându": "contracara",
    "nemaicontracarând": "contracara",
    "nemaicontracarându": "contracara",
    "contracararea": "contracarare",
    "contracarări": "contracarare",
    "contracarările": "contracarare",
    "contracarărilor": "contracarare",
    "contracarată": "contracarat",
    "contracarate": "contracarat",
    "contracarați": "contracarat",
    "contracepția": "contracepție",
    "contracepției": "contracepție",
    "contracepții": "contracepție",
    "contracepțiile": "contracepție",
    "contracepțiilor": "contracepție",
    "contracepțio": "contracepție",
    "contracte": "contract",
    "contractele": "contract",
    "contractelor": "contract",
    "contractul": "contract",
    "contractule": "contract",
    "contractului": "contract",
    "contract": "contracta",
    "contractă": "contracta",
    "contractai": "contracta",
    "contractam": "contracta",
    "contractăm": "contracta",
    "contractând": "contracta",
    "contractându": "contracta",
    "contractară": "contracta",
    "contractarăm": "contracta",
    "contractarăți": "contracta",
    "contractase": "contracta",
    "contractasem": "contracta",
    "contractaseră": "contracta",
    "contractaserăm": "contracta",
    "contractaserăți": "contracta",
    "contractaseși": "contracta",
    "contractași": "contracta",
    "contractat": "contracta",
    "contractați": "contracta",
    "contractatu": "contracta",
    "contractau": "contracta",
    "contracte": "contracta",
    "contractează": "contracta",
    "contractez": "contracta",
    "contracteze": "contracta",
    "contractezi": "contracta",
    "contracți": "contracta",
    "necontractând": "contracta",
    "necontractându": "contracta",
    "nemaicontractând": "contracta",
    "nemaicontractându": "contracta",
    "contractarea": "contractare",
    "contractareo": "contractare",
    "contractări": "contractare",
    "contractării": "contractare",
    "contractările": "contractare",
    "contractărilor": "contractare",
    "contractată": "contractat",
    "contractate": "contractat",
    "contractați": "contractat",
    "contractibilitatea": "contractibilitate",
    "contractibilitateo": "contractibilitate",
    "contractibilități": "contractibilitate",
    "contractibilității": "contractibilitate",
    "contractibilitățile": "contractibilitate",
    "contractibilităților": "contractibilitate",
    "contractoare": "contractor",
    "contractoarea": "contractor",
    "contractoarei": "contractor",
    "contractoarele": "contractor",
    "contractoarelor": "contractor",
    "contractoareo": "contractor",
    "contractori": "contractor",
    "contractorii": "contractor",
    "contractorilor": "contractor",
    "contractorul": "contractor",
    "contractorule": "contractor",
    "contractorului": "contractor",
    "contractuala": "contractual",
    "contractuală": "contractual",
    "contractuale": "contractual",
    "contractualei": "contractual",
    "contractualele": "contractual",
    "contractualelor": "contractual",
    "contractuali": "contractual",
    "contractualii": "contractual",
    "contractualilor": "contractual",
    "contractualo": "contractual",
    "contractualul": "contractual",
    "contractualule": "contractual",
    "contractualului": "contractual",
    "contradicția": "contradicție",
    "contradicției": "contradicție",
    "contradicții": "contradicție",
    "contradicțiile": "contradicție",
    "contradicțiilor": "contradicție",
    "contradicțio": "contradicție",
    "contradictoria": "contradictoriu",
    "contradictorie": "contradictoriu",
    "contradictoriei": "contradictoriu",
    "contradictorii": "contradictoriu",
    "contradictoriii": "contradictoriu",
    "contradictoriile": "contradictoriu",
    "contradictoriilor": "contradictoriu",
    "contradictorio": "contradictoriu",
    "contradictoriul": "contradictoriu",
    "contradictoriule": "contradictoriu",
    "contradictoriului": "contradictoriu",
    "contrafăcuta": "contrafăcut",
    "contrafăcută": "contrafăcut",
    "contrafăcute": "contrafăcut",
    "contrafăcutei": "contrafăcut",
    "contrafăcutele": "contrafăcut",
    "contrafăcutelor": "contrafăcut",
    "contrafăcuți": "contrafăcut",
    "contrafăcuții": "contrafăcut",
    "contrafăcuților": "contrafăcut",
    "contrafăcuto": "contrafăcut",
    "contrafăcutul": "contrafăcut",
    "contrafăcutule": "contrafăcut",
    "contrafăcutului": "contrafăcut",
    "contrafortul": "contrafort",
    "contrafortule": "contrafort",
    "contrafortului": "contrafort",
    "contraforturi": "contrafort",
    "contraforturile": "contrafort",
    "contraforturilor": "contrafort",
    "contrag": "contrage",
    "contragă": "contrage",
    "contrăgând": "contrage",
    "contrăgându": "contrage",
    "contrăgea": "contrage",
    "contrăgeai": "contrage",
    "contrăgeam": "contrage",
    "contrăgeați": "contrage",
    "contrăgeau": "contrage",
    "contragem": "contrage",
    "contrageți": "contrage",
    "contragi": "contrage",
    "contras": "contrage",
    "contrase": "contrage",
    "contrăsei": "contrage",
    "contraseră": "contrage",
    "contraserăm": "contrage",
    "contraserăți": "contrage",
    "contrăsese": "contrage",
    "contrăsesem": "contrage",
    "contrăseseră": "contrage",
    "contrăseserăm": "contrage",
    "contrăseserăți": "contrage",
    "contrăseseși": "contrage",
    "contrăseși": "contrage",
    "contrasu": "contrage",
    "necontrăgând": "contrage",
    "necontrăgându": "contrage",
    "nemaicontrăgând": "contrage",
    "nemaicontrăgându": "contrage",
    "contragerea": "contragere",
    "contragereo": "contragere",
    "contrageri": "contragere",
    "contragerii": "contragere",
    "contragerile": "contragere",
    "contragerilor": "contragere",
    "contramandă": "contramanda",
    "contramandai": "contramanda",
    "contramandam": "contramanda",
    "contramandăm": "contramanda",
    "contramandând": "contramanda",
    "contramandându": "contramanda",
    "contramandară": "contramanda",
    "contramandarăm": "contramanda",
    "contramandarăți": "contramanda",
    "contramandase": "contramanda",
    "contramandasem": "contramanda",
    "contramandaseră": "contramanda",
    "contramandaserăm": "contramanda",
    "contramandaserăți": "contramanda",
    "contramandaseși": "contramanda",
    "contramandași": "contramanda",
    "contramandat": "contramanda",
    "contramandați": "contramanda",
    "contramandatu": "contramanda",
    "contramandau": "contramanda",
    "contramandează": "contramanda",
    "contramandez": "contramanda",
    "contramandeze": "contramanda",
    "contramandezi": "contramanda",
    "necontramandând": "contramanda",
    "necontramandându": "contramanda",
    "nemaicontramandând": "contramanda",
    "nemaicontramandându": "contramanda",
    "contramandarea": "contramandare",
    "contramandareo": "contramandare",
    "contramandări": "contramandare",
    "contramandării": "contramandare",
    "contramandările": "contramandare",
    "contramandărilor": "contramandare",
    "contramandată": "contramandat",
    "contramandate": "contramandat",
    "contramandați": "contramandat",
    "contra-ofensiva": "contra-ofensivă",
    "contra-ofensive": "contra-ofensivă",
    "contra-ofensivei": "contra-ofensivă",
    "contra-ofensivele": "contra-ofensivă",
    "contra-ofensivelor": "contra-ofensivă",
    "contra-ofensivo": "contra-ofensivă",
    "contrapartida": "contrapartidă",
    "contrapartide": "contrapartidă",
    "contrapartidei": "contrapartidă",
    "contrapartidele": "contrapartidă",
    "contrapartidelor": "contrapartidă",
    "contrapartido": "contrapartidă",
    "contra-partida": "contra-partidă",
    "contra-partide": "contra-partidă",
    "contra-partidei": "contra-partidă",
    "contra-partidele": "contra-partidă",
    "contra-partidelor": "contra-partidă",
    "contrapuncte": "contrapunct",
    "contrapunctele": "contrapunct",
    "contrapunctelor": "contrapunct",
    "contrapunctul": "contrapunct",
    "contrapunctule": "contrapunct",
    "contrapunctului": "contrapunct",
    "contrapunctica": "contrapunctic",
    "contrapunctică": "contrapunctic",
    "contrapunctice": "contrapunctic",
    "contrapuncticei": "contrapunctic",
    "contrapuncticele": "contrapunctic",
    "contrapuncticelor": "contrapunctic",
    "contrapunctici": "contrapunctic",
    "contrapuncticii": "contrapunctic",
    "contrapuncticilor": "contrapunctic",
    "contrapunctico": "contrapunctic",
    "contrapuncticul": "contrapunctic",
    "contrapuncticule": "contrapunctic",
    "contrapuncticului": "contrapunctic",
    "contrara": "contrar",
    "contrară": "contrar",
    "contrare": "contrar",
    "contrarei": "contrar",
    "contrarele": "contrar",
    "contrarelor": "contrar",
    "contrari": "contrar",
    "contrarilor": "contrar",
    "contrarul": "contrar",
    "contrarule": "contrar",
    "contrarului": "contrar",
    "contra-revoluții": "contra-revoluție",
    "contrarevoluționara": "contrarevoluționar",
    "contrarevoluționară": "contrarevoluționar",
    "contrarevoluționare": "contrarevoluționar",
    "contrarevoluționarei": "contrarevoluționar",
    "contrarevoluționarele": "contrarevoluționar",
    "contrarevoluționarelor": "contrarevoluționar",
    "contrarevoluționari": "contrarevoluționar",
    "contrarevoluționarii": "contrarevoluționar",
    "contrarevoluționarilor": "contrarevoluționar",
    "contrarevoluționaro": "contrarevoluționar",
    "contrarevoluționarul": "contrarevoluționar",
    "contrarevoluționarule": "contrarevoluționar",
    "contrarevoluționarului": "contrarevoluționar",
    "contrarevoluționara": "contrarevoluționară",
    "contrarevoluționare": "contrarevoluționară",
    "contrarevoluționarei": "contrarevoluționară",
    "contrarevoluționarele": "contrarevoluționară",
    "contrarevoluționarelor": "contrarevoluționară",
    "contrarevoluționaro": "contrarevoluționară",
    "contrariai": "contraria",
    "contrariam": "contraria",
    "contrariară": "contraria",
    "contrariarăm": "contraria",
    "contrariarăți": "contraria",
    "contrariase": "contraria",
    "contrariasem": "contraria",
    "contrariaseră": "contraria",
    "contrariaserăm": "contraria",
    "contrariaserăți": "contraria",
    "contrariaseși": "contraria",
    "contrariași": "contraria",
    "contrariat": "contraria",
    "contrariați": "contraria",
    "contrariatu": "contraria",
    "contrariau": "contraria",
    "contrariază": "contraria",
    "contrarie": "contraria",
    "contrariem": "contraria",
    "contrariez": "contraria",
    "contrarieze": "contraria",
    "contrariezi": "contraria",
    "contrariind": "contraria",
    "contrariindu": "contraria",
    "necontrariind": "contraria",
    "necontrariindu": "contraria",
    "nemaicontrariind": "contraria",
    "nemaicontrariindu": "contraria",
    "contrariata": "contrariat",
    "contrariată": "contrariat",
    "contrariate": "contrariat",
    "contrariatei": "contrariat",
    "contrariatele": "contrariat",
    "contrariatelor": "contrariat",
    "contrariați": "contrariat",
    "contrariații": "contrariat",
    "contrariaților": "contrariat",
    "contrariato": "contrariat",
    "contrariatul": "contrariat",
    "contrariatule": "contrariat",
    "contrariatului": "contrariat",
    "contrarietatea": "contrarietate",
    "contrarietateo": "contrarietate",
    "contrarietăți": "contrarietate",
    "contrarietății": "contrarietate",
    "contrarietățile": "contrarietate",
    "contrarietăților": "contrarietate",
    "contrarie": "contrariu",
    "contrarii": "contrariu",
    "contrariile": "contrariu",
    "contrariilor": "contrariu",
    "contrariul": "contrariu",
    "contrariului": "contrariu",
    "contrasa": "contras",
    "contrasă": "contras",
    "contrase": "contras",
    "contrasei": "contras",
    "contrasele": "contras",
    "contraselor": "contras",
    "contrași": "contras",
    "contrașii": "contras",
    "contrașilor": "contras",
    "contraso": "contras",
    "contrasul": "contras",
    "contrasule": "contras",
    "contrasului": "contras",
    "contraspionaje": "contraspionaj",
    "contraspionajele": "contraspionaj",
    "contraspionajelor": "contraspionaj",
    "contraspionajul": "contraspionaj",
    "contraspionajule": "contraspionaj",
    "contraspionajului": "contraspionaj",
    "contraste": "contrast",
    "contrastele": "contrast",
    "contrastelor": "contrast",
    "contrastul": "contrast",
    "contrastule": "contrast",
    "contrastului": "contrast",
    "contrastă": "contrasta",
    "contrastai": "contrasta",
    "contrastam": "contrasta",
    "contrastăm": "contrasta",
    "contrastând": "contrasta",
    "contrastându": "contrasta",
    "contrastară": "contrasta",
    "contrastarăm": "contrasta",
    "contrastarăți": "contrasta",
    "contrastase": "contrasta",
    "contrastasem": "contrasta",
    "contrastaseră": "contrasta",
    "contrastaserăm": "contrasta",
    "contrastaserăți": "contrasta",
    "contrastaseși": "contrasta",
    "contrastași": "contrasta",
    "contrastat": "contrasta",
    "contrastați": "contrasta",
    "contrastatu": "contrasta",
    "contrastau": "contrasta",
    "contrastează": "contrasta",
    "contrastez": "contrasta",
    "contrasteze": "contrasta",
    "contrastezi": "contrasta",
    "necontrastând": "contrasta",
    "necontrastându": "contrasta",
    "nemaicontrastând": "contrasta",
    "nemaicontrastându": "contrasta",
    "contrastată": "contrastat",
    "contrastate": "contrastat",
    "contrastați": "contrastat",
    "contrată": "contrat",
    "contrate": "contrat",
    "contrați": "contrat",
    "contravaloarea": "contravaloare",
    "contravaloareo": "contravaloare",
    "contravalori": "contravaloare",
    "contravalorii": "contravaloare",
    "contravalorile": "contravaloare",
    "contravalorilor": "contravaloare",
    "contravenea": "contraveni",
    "contraveneai": "contraveni",
    "contraveneam": "contraveni",
    "contraveneați": "contraveni",
    "contraveneau": "contraveni",
    "contravenii": "contraveni",
    "contravenim": "contraveni",
    "contravenind": "contraveni",
    "contravenindu": "contraveni",
    "contraveniră": "contraveni",
    "contravenirăm": "contraveni",
    "contravenirăți": "contraveni",
    "contravenise": "contraveni",
    "contravenisem": "contraveni",
    "contraveniseră": "contraveni",
    "contraveniserăm": "contraveni",
    "contraveniserăți": "contraveni",
    "contraveniseși": "contraveni",
    "contraveniși": "contraveni",
    "contravenit": "contraveni",
    "contraveniți": "contraveni",
    "contravenitu": "contraveni",
    "contravii": "contraveni",
    "contravin": "contraveni",
    "contravină": "contraveni",
    "contravine": "contraveni",
    "contravino": "contraveni",
    "necontravenind": "contraveni",
    "necontravenindu": "contraveni",
    "nemaicontravenind": "contraveni",
    "nemaicontravenindu": "contraveni",
    "contravenienți": "contravenient",
    "contravenienții": "contravenient",
    "contravenienților": "contravenient",
    "contravenientul": "contravenient",
    "contravenientule": "contravenient",
    "contravenientului": "contravenient",
    "contravenienta": "contravenientă",
    "contraveniente": "contravenientă",
    "contravenientei": "contravenientă",
    "contravenientele": "contravenientă",
    "contravenientelor": "contravenientă",
    "contraveniento": "contravenientă",
    "contravenită": "contravenit",
    "contravenite": "contravenit",
    "contraveniți": "contravenit",
    "contravenția": "contravenție",
    "contravenției": "contravenție",
    "contravenții": "contravenție",
    "contravențiile": "contravenție",
    "contravențiilor": "contravenție",
    "contravențio": "contravenție",
    "contrazic": "contrazice",
    "contrazică": "contrazice",
    "contrazicând": "contrazice",
    "contrazicându": "contrazice",
    "contrazicea": "contrazice",
    "contraziceai": "contrazice",
    "contraziceam": "contrazice",
    "contraziceați": "contrazice",
    "contraziceau": "contrazice",
    "contrazicem": "contrazice",
    "contraziceți": "contrazice",
    "contrazici": "contrazice",
    "contrazis": "contrazice",
    "contrazise": "contrazice",
    "contrazisei": "contrazice",
    "contraziseră": "contrazice",
    "contraziserăm": "contrazice",
    "contraziserăți": "contrazice",
    "contrazisese": "contrazice",
    "contrazisesem": "contrazice",
    "contraziseseră": "contrazice",
    "contraziseserăm": "contrazice",
    "contraziseserăți": "contrazice",
    "contraziseseși": "contrazice",
    "contraziseși": "contrazice",
    "contrazisu": "contrazice",
    "necontrazicând": "contrazice",
    "necontrazicându": "contrazice",
    "nemaicontrazicând": "contrazice",
    "nemaicontrazicându": "contrazice",
    "contrazisă": "contrazis",
    "contrazise": "contrazis",
    "contraziși": "contrazis",
    "contribuabili": "contribuabil",
    "contribuabilii": "contribuabil",
    "contribuabililor": "contribuabil",
    "contribuabilul": "contribuabil",
    "contribuabilule": "contribuabil",
    "contribuabilului": "contribuabil",
    "contribuabila": "contribuabilă",
    "contribuabile": "contribuabilă",
    "contribuabilei": "contribuabilă",
    "contribuabilele": "contribuabilă",
    "contribuabilelor": "contribuabilă",
    "contribuabilo": "contribuabilă",
    "contribuia": "contribui",
    "contribuiai": "contribui",
    "contribuiam": "contribui",
    "contribuiați": "contribui",
    "contribuiau": "contribui",
    "contribuie": "contribui",
    "contribuii": "contribui",
    "contribuim": "contribui",
    "contribuind": "contribui",
    "contribuindu": "contribui",
    "contribuiră": "contribui",
    "contribuirăm": "contribui",
    "contribuirăți": "contribui",
    "contribuise": "contribui",
    "contribuisem": "contribui",
    "contribuiseră": "contribui",
    "contribuiserăm": "contribui",
    "contribuiserăți": "contribui",
    "contribuiseși": "contribui",
    "contribuiși": "contribui",
    "contribuit": "contribui",
    "contribuiți": "contribui",
    "contribuitu": "contribui",
    "necontribuind": "contribui",
    "necontribuindu": "contribui",
    "nemaicontribuind": "contribui",
    "nemaicontribuindu": "contribui",
    "contribuită": "contribuit",
    "contribuite": "contribuit",
    "contribuiți": "contribuit",
    "contribuția": "contribuție",
    "contribuției": "contribuție",
    "contribuții": "contribuție",
    "contribuțiile": "contribuție",
    "contribuțiilor": "contribuție",
    "contribuțio": "contribuție",
    "contribuțiunea": "contribuțiune",
    "contribuțiuneo": "contribuțiune",
    "contribuțiuni": "contribuțiune",
    "contribuțiunii": "contribuțiune",
    "contribuțiunile": "contribuțiune",
    "contribuțiunilor": "contribuțiune",
    "controale": "control",
    "controalele": "control",
    "controalelor": "control",
    "controlul": "control",
    "controlule": "control",
    "controlului": "control",
    "CFI": "Control_Financiar_Intern",
    "controlă": "controla",
    "controlai": "controla",
    "controlam": "controla",
    "controlăm": "controla",
    "controlând": "controla",
    "controlându": "controla",
    "controlară": "controla",
    "controlarăm": "controla",
    "controlarăți": "controla",
    "controlase": "controla",
    "controlasem": "controla",
    "controlaseră": "controla",
    "controlaserăm": "controla",
    "controlaserăți": "controla",
    "controlaseși": "controla",
    "controlași": "controla",
    "controlat": "controla",
    "controlați": "controla",
    "controlatu": "controla",
    "controlau": "controla",
    "controlează": "controla",
    "controlez": "controla",
    "controleze": "controla",
    "controlezi": "controla",
    "necontrolând": "controla",
    "necontrolându": "controla",
    "nemaicontrolând": "controla",
    "nemaicontrolându": "controla",
    "controlabila": "controlabil",
    "controlabilă": "controlabil",
    "controlabile": "controlabil",
    "controlabilei": "controlabil",
    "controlabilele": "controlabil",
    "controlabilelor": "controlabil",
    "controlabili": "controlabil",
    "controlabilii": "controlabil",
    "controlabililor": "controlabil",
    "controlabilo": "controlabil",
    "controlabilul": "controlabil",
    "controlabilule": "controlabil",
    "controlabilului": "controlabil",
    "controlată": "controlat",
    "controlate": "controlat",
    "controlați": "controlat",
    "controloarea": "controloare",
    "controloarei": "controloare",
    "controloarele": "controloare",
    "controloarelor": "controloare",
    "controloareo": "controloare",
    "controlori": "controlor",
    "controlorii": "controlor",
    "controlorilor": "controlor",
    "controlorul": "controlor",
    "controlorule": "controlor",
    "controlorului": "controlor",
    "controversa": "controversă",
    "controverse": "controversă",
    "controversei": "controversă",
    "controversele": "controversă",
    "controverselor": "controversă",
    "controverso": "controversă",
    "controversata": "controversat",
    "controversată": "controversat",
    "controversate": "controversat",
    "controversatei": "controversat",
    "controversatele": "controversat",
    "controversatelor": "controversat",
    "controversați": "controversat",
    "controversații": "controversat",
    "controversaților": "controversat",
    "controversato": "controversat",
    "controversatul": "controversat",
    "controversatule": "controversat",
    "controversatului": "controversat",
    "contumacia": "contumacie",
    "contumaciei": "contumacie",
    "contumacii": "contumacie",
    "contumaciile": "contumacie",
    "contumaciilor": "contumacie",
    "contumacio": "contumacie",
    "conturul": "contur",
    "conturule": "contur",
    "conturului": "contur",
    "contururi": "contur",
    "contururile": "contur",
    "contururilor": "contur",
    "contură": "contura",
    "conturai": "contura",
    "conturam": "contura",
    "conturăm": "contura",
    "conturând": "contura",
    "conturându": "contura",
    "conturară": "contura",
    "conturarăm": "contura",
    "conturarăți": "contura",
    "conturase": "contura",
    "conturasem": "contura",
    "conturaseră": "contura",
    "conturaserăm": "contura",
    "conturaserăți": "contura",
    "conturaseși": "contura",
    "conturași": "contura",
    "conturat": "contura",
    "conturați": "contura",
    "conturatu": "contura",
    "conturau": "contura",
    "conturează": "contura",
    "conturez": "contura",
    "contureze": "contura",
    "conturezi": "contura",
    "neconturând": "contura",
    "neconturându": "contura",
    "nemaiconturând": "contura",
    "nemaiconturându": "contura",
    "conturarea": "conturare",
    "conturareo": "conturare",
    "conturări": "conturare",
    "conturării": "conturare",
    "conturările": "conturare",
    "conturărilor": "conturare",
    "conturata": "conturat",
    "conturată": "conturat",
    "conturate": "conturat",
    "conturatei": "conturat",
    "conturatele": "conturat",
    "conturatelor": "conturat",
    "conturați": "conturat",
    "conturații": "conturat",
    "conturaților": "conturat",
    "conturato": "conturat",
    "conturatul": "conturat",
    "conturatule": "conturat",
    "conturatului": "conturat",
    "conturb": "conturba",
    "conturbă": "conturba",
    "conturbai": "conturba",
    "conturbam": "conturba",
    "conturbăm": "conturba",
    "conturbând": "conturba",
    "conturbându": "conturba",
    "conturbară": "conturba",
    "conturbarăm": "conturba",
    "conturbarăți": "conturba",
    "conturbase": "conturba",
    "conturbasem": "conturba",
    "conturbaseră": "conturba",
    "conturbaserăm": "conturba",
    "conturbaserăți": "conturba",
    "conturbaseși": "conturba",
    "conturbași": "conturba",
    "conturbat": "conturba",
    "conturbați": "conturba",
    "conturbatu": "conturba",
    "conturbau": "conturba",
    "conturbe": "conturba",
    "conturbi": "conturba",
    "neconturbând": "conturba",
    "neconturbându": "conturba",
    "nemaiconturbând": "conturba",
    "nemaiconturbându": "conturba",
    "conturbată": "conturbat",
    "conturbate": "conturbat",
    "conturbați": "conturbat",
    "contuzia": "contuzie",
    "contuziei": "contuzie",
    "contuzii": "contuzie",
    "contuziile": "contuzie",
    "contuziilor": "contuzie",
    "contuzio": "contuzie",
    "contuzionă": "contuziona",
    "contuzionai": "contuziona",
    "contuzionam": "contuziona",
    "contuzionăm": "contuziona",
    "contuzionând": "contuziona",
    "contuzionându": "contuziona",
    "contuzionară": "contuziona",
    "contuzionarăm": "contuziona",
    "contuzionarăți": "contuziona",
    "contuzionase": "contuziona",
    "contuzionasem": "contuziona",
    "contuzionaseră": "contuziona",
    "contuzionaserăm": "contuziona",
    "contuzionaserăți": "contuziona",
    "contuzionaseși": "contuziona",
    "contuzionași": "contuziona",
    "contuzionat": "contuziona",
    "contuzionați": "contuziona",
    "contuzionatu": "contuziona",
    "contuzionau": "contuziona",
    "contuzionează": "contuziona",
    "contuzionez": "contuziona",
    "contuzioneze": "contuziona",
    "contuzionezi": "contuziona",
    "necontuzionând": "contuziona",
    "necontuzionându": "contuziona",
    "nemaicontuzionând": "contuziona",
    "nemaicontuzionându": "contuziona",
    "contuzionată": "contuzionat",
    "contuzionate": "contuzionat",
    "contuzionați": "contuzionat",
    "convalescenta": "convalescent",
    "convalescentă": "convalescent",
    "convalescente": "convalescent",
    "convalescentei": "convalescent",
    "convalescentele": "convalescent",
    "convalescentelor": "convalescent",
    "convalescenți": "convalescent",
    "convalescenții": "convalescent",
    "convalescenților": "convalescent",
    "convalescento": "convalescent",
    "convalescentul": "convalescent",
    "convalescentule": "convalescent",
    "convalescentului": "convalescent",
    "convalescența": "convalescență",
    "convalescențe": "convalescență",
    "convalescenței": "convalescență",
    "convalescențele": "convalescență",
    "convalescențelor": "convalescență",
    "convalescențo": "convalescență",
    "convenabila": "convenabil",
    "convenabilă": "convenabil",
    "convenabile": "convenabil",
    "convenabilei": "convenabil",
    "convenabilele": "convenabil",
    "convenabilelor": "convenabil",
    "convenabili": "convenabil",
    "convenabilii": "convenabil",
    "convenabililor": "convenabil",
    "convenabilo": "convenabil",
    "convenabilul": "convenabil",
    "convenabilule": "convenabil",
    "convenabilului": "convenabil",
    "convenea": "conveni",
    "conveneai": "conveni",
    "conveneam": "conveni",
    "conveneați": "conveni",
    "conveneau": "conveni",
    "convenii": "conveni",
    "convenim": "conveni",
    "convenind": "conveni",
    "convenindu": "conveni",
    "conveniră": "conveni",
    "convenirăm": "conveni",
    "convenirăți": "conveni",
    "convenise": "conveni",
    "convenisem": "conveni",
    "conveniseră": "conveni",
    "conveniserăm": "conveni",
    "conveniserăți": "conveni",
    "conveniseși": "conveni",
    "conveniși": "conveni",
    "convenit": "conveni",
    "conveniți": "conveni",
    "convenitu": "conveni",
    "convii": "conveni",
    "convin": "conveni",
    "convină": "conveni",
    "convine": "conveni",
    "convino": "conveni",
    "neconvenind": "conveni",
    "neconvenindu": "conveni",
    "nemaiconvenind": "conveni",
    "nemaiconvenindu": "conveni",
    "conveniența": "conveniență",
    "conveniențe": "conveniență",
    "convenienței": "conveniență",
    "conveniențele": "conveniență",
    "conveniențelor": "conveniență",
    "conveniențo": "conveniență",
    "convenită": "convenit",
    "convenite": "convenit",
    "conveniți": "convenit",
    "C.D.R.": "Convenția_Democratică_din_România",
    "CDR": "Convenția_Democratică_din_România",
    "convenția": "convenție",
    "convenției": "convenție",
    "convenții": "convenție",
    "convențiile": "convenție",
    "convențiilor": "convenție",
    "convențio": "convenție",
    "convenționala": "convențional",
    "convențională": "convențional",
    "convenționale": "convențional",
    "convenționalei": "convențional",
    "convenționalele": "convențional",
    "convenționalelor": "convențional",
    "convenționali": "convențional",
    "convenționalii": "convențional",
    "convenționalilor": "convențional",
    "convenționalo": "convențional",
    "convenționalul": "convențional",
    "convenționalule": "convențional",
    "convenționalului": "convențional",
    "convențiunea": "convențiune",
    "convențiuneo": "convențiune",
    "convențiuni": "convențiune",
    "convențiunii": "convențiune",
    "convențiunile": "convențiune",
    "convențiunilor": "convențiune",
    "conveargă": "converge",
    "converg": "converge",
    "convergând": "converge",
    "convergându": "converge",
    "convergea": "converge",
    "convergeai": "converge",
    "convergeam": "converge",
    "convergeați": "converge",
    "convergeau": "converge",
    "convergem": "converge",
    "convergeți": "converge",
    "convergi": "converge",
    "convers": "converge",
    "converse": "converge",
    "conversei": "converge",
    "converseră": "converge",
    "converserăm": "converge",
    "converserăți": "converge",
    "conversese": "converge",
    "conversesem": "converge",
    "converseseră": "converge",
    "converseserăm": "converge",
    "converseserăți": "converge",
    "converseseși": "converge",
    "converseși": "converge",
    "conversu": "converge",
    "neconvergând": "converge",
    "neconvergându": "converge",
    "nemaiconvergând": "converge",
    "nemaiconvergându": "converge",
    "conversă": "convers",
    "converse": "convers",
    "converși": "convers",
    "conversă": "conversa",
    "conversai": "conversa",
    "conversam": "conversa",
    "conversăm": "conversa",
    "conversând": "conversa",
    "conversându": "conversa",
    "conversară": "conversa",
    "conversarăm": "conversa",
    "conversarăți": "conversa",
    "conversase": "conversa",
    "conversasem": "conversa",
    "conversaseră": "conversa",
    "conversaserăm": "conversa",
    "conversaserăți": "conversa",
    "conversaseși": "conversa",
    "conversași": "conversa",
    "conversat": "conversa",
    "conversați": "conversa",
    "conversatu": "conversa",
    "conversau": "conversa",
    "conversează": "conversa",
    "conversez": "conversa",
    "converseze": "conversa",
    "conversezi": "conversa",
    "neconversând": "conversa",
    "neconversându": "conversa",
    "nemaiconversând": "conversa",
    "nemaiconversându": "conversa",
    "conversată": "conversat",
    "conversate": "conversat",
    "conversați": "conversat",
    "conversația": "conversație",
    "conversației": "conversație",
    "conversații": "conversație",
    "conversațiile": "conversație",
    "conversațiilor": "conversație",
    "conversațio": "conversație",
    "conversia": "conversie",
    "conversiei": "conversie",
    "conversii": "conversie",
    "conversiile": "conversie",
    "conversiilor": "conversie",
    "conversio": "conversie",
    "conversiunea": "conversiune",
    "conversiuneo": "conversiune",
    "conversiuni": "conversiune",
    "conversiunii": "conversiune",
    "conversiunile": "conversiune",
    "conversiunilor": "conversiune",
    "convertea": "converti",
    "converteai": "converti",
    "converteam": "converti",
    "convertească": "converti",
    "converteați": "converti",
    "converteau": "converti",
    "convertesc": "converti",
    "convertește": "converti",
    "convertești": "converti",
    "convertii": "converti",
    "convertim": "converti",
    "convertind": "converti",
    "convertindu": "converti",
    "convertiră": "converti",
    "convertirăm": "converti",
    "convertirăți": "converti",
    "convertise": "converti",
    "convertisem": "converti",
    "convertiseră": "converti",
    "convertiserăm": "converti",
    "convertiserăți": "converti",
    "convertiseși": "converti",
    "convertiși": "converti",
    "convertit": "converti",
    "convertiți": "converti",
    "convertitu": "converti",
    "neconvertind": "converti",
    "neconvertindu": "converti",
    "nemaiconvertind": "converti",
    "nemaiconvertindu": "converti",
    "convertibila": "convertibil",
    "convertibilă": "convertibil",
    "convertibile": "convertibil",
    "convertibilei": "convertibil",
    "convertibilele": "convertibil",
    "convertibilelor": "convertibil",
    "convertibili": "convertibil",
    "convertibilii": "convertibil",
    "convertibililor": "convertibil",
    "convertibilo": "convertibil",
    "convertibilul": "convertibil",
    "convertibilule": "convertibil",
    "convertibilului": "convertibil",
    "convertibilitatea": "convertibilitate",
    "convertibilității": "convertibilitate",
    "convertirea": "convertire",
    "convertireo": "convertire",
    "convertiri": "convertire",
    "convertirii": "convertire",
    "convertirile": "convertire",
    "convertirilor": "convertire",
    "convertită": "convertit",
    "convertite": "convertit",
    "convertiți": "convertit",
    "convertizoare": "convertizor",
    "convertizoarele": "convertizor",
    "convertizoarelor": "convertizor",
    "convertizorul": "convertizor",
    "convertizorule": "convertizor",
    "convertizorului": "convertizor",
    "convecși": "convex",
    "convecșii": "convex",
    "convecșilor": "convex",
    "convexa": "convex",
    "convexă": "convex",
    "convexe": "convex",
    "convexei": "convex",
    "convexele": "convex",
    "convexelor": "convex",
    "convexo": "convex",
    "convexul": "convex",
    "convexule": "convex",
    "convexului": "convex",
    "convexitatea": "convexitate",
    "convexitateo": "convexitate",
    "convexități": "convexitate",
    "convexității": "convexitate",
    "convexitățile": "convexitate",
    "convexităților": "convexitate",
    "conviețuia": "conviețui",
    "conviețuiai": "conviețui",
    "conviețuiam": "conviețui",
    "conviețuiați": "conviețui",
    "conviețuiau": "conviețui",
    "conviețuiească": "conviețui",
    "conviețuiesc": "conviețui",
    "conviețuiește": "conviețui",
    "conviețuiești": "conviețui",
    "conviețuii": "conviețui",
    "conviețuim": "conviețui",
    "conviețuind": "conviețui",
    "conviețuindu": "conviețui",
    "conviețuiră": "conviețui",
    "conviețuirăm": "conviețui",
    "conviețuirăți": "conviețui",
    "conviețuise": "conviețui",
    "conviețuisem": "conviețui",
    "conviețuiseră": "conviețui",
    "conviețuiserăm": "conviețui",
    "conviețuiserăți": "conviețui",
    "conviețuiseși": "conviețui",
    "conviețuiși": "conviețui",
    "conviețuit": "conviețui",
    "conviețuiți": "conviețui",
    "conviețuitu": "conviețui",
    "conviețuirea": "conviețuire",
    "conviețuiri": "conviețuire",
    "conviețuirii": "conviețuire",
    "conviețuirile": "conviețuire",
    "conviețuirilor": "conviețuire",
    "conviețuită": "conviețuit",
    "conviețuite": "conviețuit",
    "conviețuiți": "conviețuit",
    "convingătoare": "convingător",
    "convingătoarea": "convingător",
    "convingătoarei": "convingător",
    "convingătoarele": "convingător",
    "convingătoarelor": "convingător",
    "convingătoareo": "convingător",
    "convingători": "convingător",
    "convingătorii": "convingător",
    "convingătorilor": "convingător",
    "convingătorul": "convingător",
    "convingătorule": "convingător",
    "convingătorului": "convingător",
    "conving": "convinge",
    "convingă": "convinge",
    "convingând": "convinge",
    "convingându": "convinge",
    "convingea": "convinge",
    "convingeai": "convinge",
    "convingeam": "convinge",
    "convingeați": "convinge",
    "convingeau": "convinge",
    "convingem": "convinge",
    "convingeți": "convinge",
    "convingi": "convinge",
    "convins": "convinge",
    "convinse": "convinge",
    "convinsei": "convinge",
    "convinseră": "convinge",
    "convinserăm": "convinge",
    "convinserăți": "convinge",
    "convinsese": "convinge",
    "convinsesem": "convinge",
    "convinseseră": "convinge",
    "convinseserăm": "convinge",
    "convinseserăți": "convinge",
    "convinseseși": "convinge",
    "convinseși": "convinge",
    "convinsu": "convinge",
    "neconvingând": "convinge",
    "neconvingându": "convinge",
    "nemaiconvingând": "convinge",
    "nemaiconvingându": "convinge",
    "convingerea": "convingere",
    "convingereo": "convingere",
    "convingeri": "convingere",
    "convingerii": "convingere",
    "convingerile": "convingere",
    "convingerilor": "convingere",
    "convinsa": "convins",
    "convinsă": "convins",
    "convinse": "convins",
    "convinsei": "convins",
    "convinsele": "convins",
    "convinselor": "convins",
    "convinși": "convins",
    "convinșii": "convins",
    "convinșilor": "convins",
    "convinso": "convins",
    "convinsul": "convins",
    "convinsule": "convins",
    "convinsului": "convins",
    "convivi": "conviv",
    "convivii": "conviv",
    "convivilor": "conviv",
    "convivul": "conviv",
    "convivule": "conviv",
    "convivului": "conviv",
    "conviva": "convivă",
    "convive": "convivă",
    "convivei": "convivă",
    "convivele": "convivă",
    "convivelor": "convivă",
    "convivo": "convivă",
    "convoacă": "convoca",
    "convoace": "convoca",
    "convoc": "convoca",
    "convocă": "convoca",
    "convocai": "convoca",
    "convocam": "convoca",
    "convocăm": "convoca",
    "convocând": "convoca",
    "convocându": "convoca",
    "convocară": "convoca",
    "convocarăm": "convoca",
    "convocarăți": "convoca",
    "convocase": "convoca",
    "convocasem": "convoca",
    "convocaseră": "convoca",
    "convocaserăm": "convoca",
    "convocaserăți": "convoca",
    "convocaseși": "convoca",
    "convocași": "convoca",
    "convocat": "convoca",
    "convocați": "convoca",
    "convocatu": "convoca",
    "convocau": "convoca",
    "convoci": "convoca",
    "neconvocând": "convoca",
    "neconvocându": "convoca",
    "nemaiconvocând": "convoca",
    "nemaiconvocându": "convoca",
    "convocarea": "convocare",
    "convocareo": "convocare",
    "convocări": "convocare",
    "convocării": "convocare",
    "convocările": "convocare",
    "convocărilor": "convocare",
    "convocată": "convocat",
    "convocate": "convocat",
    "convocați": "convocat",
    "convoaie": "convoi",
    "convoaiele": "convoi",
    "convoaielor": "convoi",
    "convoiul": "convoi",
    "convoiule": "convoi",
    "convoiului": "convoi",
    "conv.": "convorbire",
    "convorbirea": "convorbire",
    "convorbireo": "convorbire",
    "convorbiri": "convorbire",
    "convorbirii": "convorbire",
    "convorbirile": "convorbire",
    "convorbirilor": "convorbire",
    "convulsia": "convulsie",
    "convulsiei": "convulsie",
    "convulsii": "convulsie",
    "convulsiile": "convulsie",
    "convulsiilor": "convulsie",
    "convulsio": "convulsie",
    "convulsionă": "convulsiona",
    "convulsionai": "convulsiona",
    "convulsionam": "convulsiona",
    "convulsionăm": "convulsiona",
    "convulsionând": "convulsiona",
    "convulsionându": "convulsiona",
    "convulsionară": "convulsiona",
    "convulsionarăm": "convulsiona",
    "convulsionarăți": "convulsiona",
    "convulsionase": "convulsiona",
    "convulsionasem": "convulsiona",
    "convulsionaseră": "convulsiona",
    "convulsionaserăm": "convulsiona",
    "convulsionaserăți": "convulsiona",
    "convulsionaseși": "convulsiona",
    "convulsionași": "convulsiona",
    "convulsionat": "convulsiona",
    "convulsionați": "convulsiona",
    "convulsionatu": "convulsiona",
    "convulsionau": "convulsiona",
    "convulsionează": "convulsiona",
    "convulsionez": "convulsiona",
    "convulsioneze": "convulsiona",
    "convulsionezi": "convulsiona",
    "neconvulsionând": "convulsiona",
    "neconvulsionându": "convulsiona",
    "nemaiconvulsionând": "convulsiona",
    "nemaiconvulsionându": "convulsiona",
    "convulsionata": "convulsionat",
    "convulsionată": "convulsionat",
    "convulsionate": "convulsionat",
    "convulsionatei": "convulsionat",
    "convulsionatele": "convulsionat",
    "convulsionatelor": "convulsionat",
    "convulsionați": "convulsionat",
    "convulsionații": "convulsionat",
    "convulsionaților": "convulsionat",
    "convulsionato": "convulsionat",
    "convulsionatul": "convulsionat",
    "convulsionatule": "convulsionat",
    "convulsionatului": "convulsionat",
    "convulsiva": "convulsiv",
    "convulsivă": "convulsiv",
    "convulsive": "convulsiv",
    "convulsivei": "convulsiv",
    "convulsivele": "convulsiv",
    "convulsivelor": "convulsiv",
    "convulsivi": "convulsiv",
    "convulsivii": "convulsiv",
    "convulsivilor": "convulsiv",
    "convulsivo": "convulsiv",
    "convulsivul": "convulsiv",
    "convulsivule": "convulsiv",
    "convulsivului": "convulsiv",
    "cooperă": "coopera",
    "cooperai": "coopera",
    "cooperam": "coopera",
    "cooperăm": "coopera",
    "cooperând": "coopera",
    "cooperându": "coopera",
    "cooperară": "coopera",
    "cooperarăm": "coopera",
    "cooperarăți": "coopera",
    "cooperase": "coopera",
    "cooperasem": "coopera",
    "cooperaseră": "coopera",
    "cooperaserăm": "coopera",
    "cooperaserăți": "coopera",
    "cooperaseși": "coopera",
    "cooperași": "coopera",
    "cooperat": "coopera",
    "cooperați": "coopera",
    "cooperatu": "coopera",
    "cooperau": "coopera",
    "cooperează": "coopera",
    "cooperez": "coopera",
    "coopereze": "coopera",
    "cooperezi": "coopera",
    "necooperând": "coopera",
    "necooperându": "coopera",
    "nemaicooperând": "coopera",
    "nemaicooperându": "coopera",
    "cooperanta": "cooperant",
    "cooperantă": "cooperant",
    "cooperante": "cooperant",
    "cooperantei": "cooperant",
    "cooperantele": "cooperant",
    "cooperantelor": "cooperant",
    "cooperanți": "cooperant",
    "cooperanții": "cooperant",
    "cooperanților": "cooperant",
    "cooperanto": "cooperant",
    "cooperantul": "cooperant",
    "cooperantule": "cooperant",
    "cooperantului": "cooperant",
    "cooperarea": "cooperare",
    "cooperareo": "cooperare",
    "cooperări": "cooperare",
    "cooperării": "cooperare",
    "cooperările": "cooperare",
    "cooperărilor": "cooperare",
    "cooperată": "cooperat",
    "cooperate": "cooperat",
    "cooperați": "cooperat",
    "cooperația": "cooperație",
    "cooperației": "cooperație",
    "cooperații": "cooperație",
    "cooperațiile": "cooperație",
    "cooperațiilor": "cooperație",
    "cooperațio": "cooperație",
    "cooperatista": "cooperatist",
    "cooperatistă": "cooperatist",
    "cooperatiste": "cooperatist",
    "cooperatistei": "cooperatist",
    "cooperatistele": "cooperatist",
    "cooperatistelor": "cooperatist",
    "cooperatiști": "cooperatist",
    "cooperatiștii": "cooperatist",
    "cooperatiștilor": "cooperatist",
    "cooperatisto": "cooperatist",
    "cooperatistul": "cooperatist",
    "cooperatistule": "cooperatist",
    "cooperatistului": "cooperatist",
    "coop.": "cooperativă",
    "cooperativa": "cooperativă",
    "cooperative": "cooperativă",
    "cooperativei": "cooperativă",
    "cooperativele": "cooperativă",
    "cooperativelor": "cooperativă",
    "cooperativo": "cooperativă",
    "C.A.P.": "Cooperativa_Agricolă_de_Producție",
    "cooperatoarea": "cooperatoare",
    "cooperatoarei": "cooperatoare",
    "cooperatoarele": "cooperatoare",
    "cooperatoarelor": "cooperatoare",
    "cooperatoareo": "cooperatoare",
    "cooperatori": "cooperator",
    "cooperatorii": "cooperator",
    "cooperatorilor": "cooperator",
    "cooperatorul": "cooperator",
    "cooperatorule": "cooperator",
    "cooperatorului": "cooperator",
    "cooptă": "coopta",
    "cooptai": "coopta",
    "cooptam": "coopta",
    "cooptăm": "coopta",
    "cooptând": "coopta",
    "cooptându": "coopta",
    "cooptară": "coopta",
    "cooptarăm": "coopta",
    "cooptarăți": "coopta",
    "cooptase": "coopta",
    "cooptasem": "coopta",
    "cooptaseră": "coopta",
    "cooptaserăm": "coopta",
    "cooptaserăți": "coopta",
    "cooptaseși": "coopta",
    "cooptași": "coopta",
    "cooptat": "coopta",
    "cooptați": "coopta",
    "cooptatu": "coopta",
    "cooptau": "coopta",
    "cooptează": "coopta",
    "cooptez": "coopta",
    "coopteze": "coopta",
    "cooptezi": "coopta",
    "necooptând": "coopta",
    "necooptându": "coopta",
    "nemaicooptând": "coopta",
    "nemaicooptându": "coopta",
    "cooptarea": "cooptare",
    "cooptareo": "cooptare",
    "cooptări": "cooptare",
    "cooptării": "cooptare",
    "cooptările": "cooptare",
    "cooptărilor": "cooptare",
    "cooptată": "cooptat",
    "cooptate": "cooptat",
    "cooptați": "cooptat",
    "coordonă": "coordona",
    "coordonai": "coordona",
    "coordonam": "coordona",
    "coordonăm": "coordona",
    "coordonând": "coordona",
    "coordonându": "coordona",
    "coordonară": "coordona",
    "coordonarăm": "coordona",
    "coordonarăți": "coordona",
    "coordonase": "coordona",
    "coordonasem": "coordona",
    "coordonaseră": "coordona",
    "coordonaserăm": "coordona",
    "coordonaserăți": "coordona",
    "coordonaseși": "coordona",
    "coordonași": "coordona",
    "coordonat": "coordona",
    "coordonați": "coordona",
    "coordonatu": "coordona",
    "coordonau": "coordona",
    "coordonează": "coordona",
    "coordonez": "coordona",
    "coordoneze": "coordona",
    "coordonezi": "coordona",
    "necoordonând": "coordona",
    "necoordonându": "coordona",
    "nemaicoordonând": "coordona",
    "nemaicoordonându": "coordona",
    "coordonarea": "coordonare",
    "coordonareo": "coordonare",
    "coordonări": "coordonare",
    "coordonării": "coordonare",
    "coordonările": "coordonare",
    "coordonărilor": "coordonare",
    "coordonata": "coordonat",
    "coordonată": "coordonat",
    "coordonate": "coordonat",
    "coordonatei": "coordonat",
    "coordonatele": "coordonat",
    "coordonatelor": "coordonat",
    "coordonați": "coordonat",
    "coordonații": "coordonat",
    "coordonaților": "coordonat",
    "coordonato": "coordonat",
    "coordonatul": "coordonat",
    "coordonatule": "coordonat",
    "coordonatului": "coordonat",
    "coordonata": "coordonată",
    "coordonate": "coordonată",
    "coordonatei": "coordonată",
    "coordonatele": "coordonată",
    "coordonatelor": "coordonată",
    "coordonato": "coordonată",
    "coordonatoarea": "coordonatoare",
    "coordonatoarei": "coordonatoare",
    "coordonatoarele": "coordonatoare",
    "coordonatoarelor": "coordonatoare",
    "coordonatoareo": "coordonatoare",
    "coordonatoare": "coordonator",
    "coordonatoarea": "coordonator",
    "coordonatoarei": "coordonator",
    "coordonatoarele": "coordonator",
    "coordonatoarelor": "coordonator",
    "coordonatoareo": "coordonator",
    "coordonatori": "coordonator",
    "coordonatorii": "coordonator",
    "coordonatorilor": "coordonator",
    "coordonatorul": "coordonator",
    "coordonatorule": "coordonator",
    "coordonatorului": "coordonator",
    "copaci": "copac",
    "copacii": "copac",
    "copacilor": "copac",
    "copacul": "copac",
    "copacule": "copac",
    "copacului": "copac",
    "copăcei": "copăcel",
    "copăceii": "copăcel",
    "copăceilor": "copăcel",
    "copăcelul": "copăcel",
    "copăcelule": "copăcel",
    "copăcelului": "copăcel",
    "copăi": "copaie",
    "copaia": "copaie",
    "copăii": "copaie",
    "copăile": "copaie",
    "copăilor": "copaie",
    "copaio": "copaie",
    "copalul": "copal",
    "copalule": "copal",
    "copalului": "copal",
    "copane": "copan",
    "copanele": "copan",
    "copanelor": "copan",
    "copanul": "copan",
    "copanule": "copan",
    "copanului": "copan",
    "copârșeie": "copârșeu",
    "copârșeiele": "copârșeu",
    "copârșeielor": "copârșeu",
    "copârșeul": "copârșeu",
    "copârșeule": "copârșeu",
    "copârșeului": "copârșeu",
    "copca": "copcă",
    "copci": "copcă",
    "copcii": "copcă",
    "copcile": "copcă",
    "copcilor": "copcă",
    "copco": "copcă",
    "coperta": "copertă",
    "coperte": "copertă",
    "copertei": "copertă",
    "copertele": "copertă",
    "copertelor": "copertă",
    "coperți": "copertă",
    "coperții": "copertă",
    "coperțile": "copertă",
    "coperților": "copertă",
    "coperto": "copertă",
    "copiai": "copia",
    "copiam": "copia",
    "copiară": "copia",
    "copiarăm": "copia",
    "copiarăți": "copia",
    "copiase": "copia",
    "copiasem": "copia",
    "copiaseră": "copia",
    "copiaserăm": "copia",
    "copiaserăți": "copia",
    "copiaseși": "copia",
    "copiași": "copia",
    "copiat": "copia",
    "copiați": "copia",
    "copiatu": "copia",
    "copiau": "copia",
    "copiază": "copia",
    "copie": "copia",
    "copiem": "copia",
    "copiez": "copia",
    "copieze": "copia",
    "copiezi": "copia",
    "copiind": "copia",
    "copiindu": "copia",
    "necopiind": "copia",
    "necopiindu": "copia",
    "nemaicopiind": "copia",
    "nemaicopiindu": "copia",
    "copiată": "copiat",
    "copiate": "copiat",
    "copiați": "copiat",
    "copiații": "copiat",
    "copiaților": "copiat",
    "copiatul": "copiat",
    "copiatule": "copiat",
    "copiatului": "copiat",
    "copia": "copie",
    "copiei": "copie",
    "copii": "copie",
    "copiile": "copie",
    "copiilor": "copie",
    "copio": "copie",
    "copierea": "copiere",
    "copiereo": "copiere",
    "copieri": "copiere",
    "copierii": "copiere",
    "copierile": "copiere",
    "copierilor": "copiere",
    "copii": "copil",
    "copiii": "copil",
    "copiilor": "copil",
    "copilul": "copil",
    "copilule": "copil",
    "copilului": "copil",
    "copila": "copilă",
    "copile": "copilă",
    "copilei": "copilă",
    "copilele": "copilă",
    "copilelor": "copilă",
    "copilo": "copilă",
    "copilandra": "copilandră",
    "copilandre": "copilandră",
    "copilandrei": "copilandră",
    "copilandrele": "copilandră",
    "copilandrelor": "copilandră",
    "copilandro": "copilandră",
    "copilandri": "copilandru",
    "copilandrii": "copilandru",
    "copilandrilor": "copilandru",
    "copilandrul": "copilandru",
    "copilandrule": "copilandru",
    "copilandrului": "copilandru",
    "copilărească": "copilăresc",
    "copilărești": "copilăresc",
    "copilărea": "copilări",
    "copilăreai": "copilări",
    "copilăream": "copilări",
    "copilărească": "copilări",
    "copilăreați": "copilări",
    "copilăreau": "copilări",
    "copilăresc": "copilări",
    "copilărește": "copilări",
    "copilărești": "copilări",
    "copilării": "copilări",
    "copilărim": "copilări",
    "copilărind": "copilări",
    "copilărindu": "copilări",
    "copilăriră": "copilări",
    "copilărirăm": "copilări",
    "copilărirăți": "copilări",
    "copilărise": "copilări",
    "copilărisem": "copilări",
    "copilăriseră": "copilări",
    "copilăriserăm": "copilări",
    "copilăriserăți": "copilări",
    "copilăriseși": "copilări",
    "copilăriși": "copilări",
    "copilărit": "copilări",
    "copilăriți": "copilări",
    "copilăritu": "copilări",
    "necopilărind": "copilări",
    "necopilărindu": "copilări",
    "nemaicopilărind": "copilări",
    "nemaicopilărindu": "copilări",
    "copilăria": "copilărie",
    "copilăriei": "copilărie",
    "copilării": "copilărie",
    "copilăriile": "copilărie",
    "copilăriilor": "copilărie",
    "copilărio": "copilărie",
    "copilărită": "copilărit",
    "copilărite": "copilărit",
    "copilăriți": "copilărit",
    "copilași": "copilaș",
    "copilașii": "copilaș",
    "copilașilor": "copilaș",
    "copilașul": "copilaș",
    "copilașule": "copilaș",
    "copilașului": "copilaș",
    "copioasa": "copios",
    "copioasă": "copios",
    "copioase": "copios",
    "copioasei": "copios",
    "copioasele": "copios",
    "copioaselor": "copios",
    "copioaso": "copios",
    "copioși": "copios",
    "copioșii": "copios",
    "copioșilor": "copios",
    "copiosul": "copios",
    "copiosule": "copios",
    "copiosului": "copios",
    "copita": "copită",
    "copite": "copită",
    "copitei": "copită",
    "copitele": "copită",
    "copitelor": "copită",
    "copito": "copită",
    "copleșea": "copleși",
    "copleșeai": "copleși",
    "copleșeam": "copleși",
    "copleșească": "copleși",
    "copleșeați": "copleși",
    "copleșeau": "copleși",
    "copleșesc": "copleși",
    "copleșește": "copleși",
    "copleșești": "copleși",
    "copleșii": "copleși",
    "copleșim": "copleși",
    "copleșind": "copleși",
    "copleșindu": "copleși",
    "copleșiră": "copleși",
    "copleșirăm": "copleși",
    "copleșirăți": "copleși",
    "copleșise": "copleși",
    "copleșisem": "copleși",
    "copleșiseră": "copleși",
    "copleșiserăm": "copleși",
    "copleșiserăți": "copleși",
    "copleșiseși": "copleși",
    "copleșiși": "copleși",
    "copleșit": "copleși",
    "copleșiți": "copleși",
    "copleșitu": "copleși",
    "necopleșind": "copleși",
    "necopleșindu": "copleși",
    "nemaicopleșind": "copleși",
    "nemaicopleșindu": "copleși",
    "copleșirea": "copleșire",
    "copleșireo": "copleșire",
    "copleșiri": "copleșire",
    "copleșirii": "copleșire",
    "copleșirile": "copleșire",
    "copleșirilor": "copleșire",
    "copleșită": "copleșit",
    "copleșite": "copleșit",
    "copleșiți": "copleșit",
    "copleșitoare": "copleșitor",
    "copleșitoarea": "copleșitor",
    "copleșitoarei": "copleșitor",
    "copleșitoarele": "copleșitor",
    "copleșitoarelor": "copleșitor",
    "copleșitoareo": "copleșitor",
    "copleșitori": "copleșitor",
    "copleșitorii": "copleșitor",
    "copleșitorilor": "copleșitor",
    "copleșitorul": "copleșitor",
    "copleșitorule": "copleșitor",
    "copleșitorului": "copleșitor",
    "copoii": "copoi",
    "copoilor": "copoi",
    "copoiul": "copoi",
    "copoiule": "copoi",
    "copoiului": "copoi",
    "coproducția": "coproducție",
    "coproducției": "coproducție",
    "coproducții": "coproducție",
    "coproducțiile": "coproducție",
    "coproducțiilor": "coproducție",
    "coproducțio": "coproducție",
    "coproliți": "coprolit",
    "coproliții": "coprolit",
    "coproliților": "coprolit",
    "coprolitul": "coprolit",
    "coprolitule": "coprolit",
    "coprolitului": "coprolit",
    "coapta": "copt",
    "coaptă": "copt",
    "coapte": "copt",
    "coaptei": "copt",
    "coaptele": "copt",
    "coaptelor": "copt",
    "coapto": "copt",
    "copți": "copt",
    "copții": "copt",
    "copților": "copt",
    "coptul": "copt",
    "coptule": "copt",
    "coptului": "copt",
    "copturi": "copt",
    "copturile": "copt",
    "copturilor": "copt",
    "copta": "coptă",
    "copte": "coptă",
    "coptei": "coptă",
    "coptele": "coptă",
    "coptelor": "coptă",
    "copto": "coptă",
    "coptura": "coptură",
    "copturi": "coptură",
    "copturii": "coptură",
    "copturile": "coptură",
    "copturilor": "coptură",
    "copturo": "coptură",
    "copulă": "copula",
    "copulai": "copula",
    "copulam": "copula",
    "copulăm": "copula",
    "copulând": "copula",
    "copulându": "copula",
    "copulară": "copula",
    "copularăm": "copula",
    "copularăți": "copula",
    "copulase": "copula",
    "copulasem": "copula",
    "copulaseră": "copula",
    "copulaserăm": "copula",
    "copulaserăți": "copula",
    "copulaseși": "copula",
    "copulași": "copula",
    "copulat": "copula",
    "copulați": "copula",
    "copulatu": "copula",
    "copulau": "copula",
    "copulează": "copula",
    "copulez": "copula",
    "copuleze": "copula",
    "copulezi": "copula",
    "necopulând": "copula",
    "necopulându": "copula",
    "nemaicopulând": "copula",
    "nemaicopulându": "copula",
    "copula": "copulă",
    "copule": "copulă",
    "copulei": "copulă",
    "copulele": "copulă",
    "copulelor": "copulă",
    "copulo": "copulă",
    "copulată": "copulat",
    "copulate": "copulat",
    "copulați": "copulat",
    "copulația": "copulație",
    "copulației": "copulație",
    "copulații": "copulație",
    "copulațiile": "copulație",
    "copulațiilor": "copulație",
    "copulațio": "copulație",
    "copulativa": "copulativ",
    "copulativă": "copulativ",
    "copulative": "copulativ",
    "copulativei": "copulativ",
    "copulativele": "copulativ",
    "copulativelor": "copulativ",
    "copulativi": "copulativ",
    "copulativii": "copulativ",
    "copulativilor": "copulativ",
    "copulativo": "copulativ",
    "copulativul": "copulativ",
    "copulativule": "copulativ",
    "copulativului": "copulativ",
    "corul": "cor",
    "corule": "cor",
    "corului": "cor",
    "coruri": "cor",
    "corurile": "cor",
    "corurilor": "cor",
    "corabia": "corabie",
    "corăbiei": "corabie",
    "corăbii": "corabie",
    "corăbiile": "corabie",
    "corăbiilor": "corabie",
    "corabio": "corabie",
    "corali": "coral",
    "coralii": "coral",
    "coralilor": "coral",
    "coralul": "coral",
    "coralule": "coral",
    "coralului": "coral",
    "coralieri": "coralier",
    "coralierii": "coralier",
    "coralierilor": "coralier",
    "coralierul": "coralier",
    "coralierule": "coralier",
    "coralierului": "coralier",
    "coranul": "coran",
    "coranule": "coran",
    "coranului": "coran",
    "corbi": "corb",
    "corbii": "corb",
    "corbilor": "corb",
    "corbul": "corb",
    "corbule": "corb",
    "corbului": "corb",
    "corbi-albaștri": "corb-albastru",
    "corbilor-albaștri": "corb-albastru",
    "corbul-albastru": "corb-albastru",
    "corbului-albastru": "corb-albastru",
    "corbi-de-mare": "corb-de-mare",
    "corbilor-de-mare": "corb-de-mare",
    "corbul-de-mare": "corb-de-mare",
    "corbului-de-mare": "corb-de-mare",
    "corbi-de-noapte": "corb-de-noapte",
    "corbilor-de-noapte": "corb-de-noapte",
    "corbul-de-noapte": "corb-de-noapte",
    "corbului-de-noapte": "corb-de-noapte",
    "corbia": "corbiu",
    "corbie": "corbiu",
    "corbiei": "corbiu",
    "corbiele": "corbiu",
    "corbielor": "corbiu",
    "corbii": "corbiu",
    "corbiii": "corbiu",
    "corbiilor": "corbiu",
    "corbio": "corbiu",
    "corbiul": "corbiu",
    "corbiule": "corbiu",
    "corbiului": "corbiu",
    "corbie-argintata": "corbiu-argintat",
    "corbie-argintată": "corbiu-argintat",
    "corbie-argintate": "corbiu-argintat",
    "corbie-argintatei": "corbiu-argintat",
    "corbie-argintatele": "corbiu-argintat",
    "corbie-argintatelor": "corbiu-argintat",
    "corbie-argintato": "corbiu-argintat",
    "corbiu-argintați": "corbiu-argintat",
    "corbiu-argintații": "corbiu-argintat",
    "corbiu-argintaților": "corbiu-argintat",
    "corbiu-argintatul": "corbiu-argintat",
    "corbiu-argintatule": "corbiu-argintat",
    "corbiu-argintatului": "corbiu-argintat",
    "corcea": "corci",
    "corceai": "corci",
    "corceam": "corci",
    "corcească": "corci",
    "corceați": "corci",
    "corceau": "corci",
    "corcesc": "corci",
    "corcește": "corci",
    "corcești": "corci",
    "corcii": "corci",
    "corcim": "corci",
    "corcind": "corci",
    "corcindu": "corci",
    "corciră": "corci",
    "corcirăm": "corci",
    "corcirăți": "corci",
    "corcise": "corci",
    "corcisem": "corci",
    "corciseră": "corci",
    "corciserăm": "corci",
    "corciserăți": "corci",
    "corciseși": "corci",
    "corciși": "corci",
    "corcit": "corci",
    "corciți": "corci",
    "corcitu": "corci",
    "necorcind": "corci",
    "necorcindu": "corci",
    "nemaicorcind": "corci",
    "nemaicorcindu": "corci",
    "corcirea": "corcire",
    "corcireo": "corcire",
    "corciri": "corcire",
    "corcirii": "corcire",
    "corcirile": "corcire",
    "corcirilor": "corcire",
    "corcita": "corcit",
    "corcită": "corcit",
    "corcite": "corcit",
    "corcitei": "corcit",
    "corcitele": "corcit",
    "corcitelor": "corcit",
    "corciți": "corcit",
    "corciții": "corcit",
    "corciților": "corcit",
    "corcito": "corcit",
    "corcitul": "corcit",
    "corcitule": "corcit",
    "corcitului": "corcit",
    "corcitura": "corcitură",
    "corcituri": "corcitură",
    "corciturii": "corcitură",
    "corciturile": "corcitură",
    "corciturilor": "corcitură",
    "corcituro": "corcitură",
    "corcodeli": "corcodel",
    "corcodelii": "corcodel",
    "corcodelilor": "corcodel",
    "corcodelul": "corcodel",
    "corcodelule": "corcodel",
    "corcodelului": "corcodel",
    "corcoduși": "corcoduș",
    "corcodușii": "corcoduș",
    "corcodușilor": "corcoduș",
    "corcodușul": "corcoduș",
    "corcodușule": "corcoduș",
    "corcodușului": "corcoduș",
    "corcodușa": "corcodușă",
    "corcodușe": "corcodușă",
    "corcodușei": "corcodușă",
    "corcodușele": "corcodușă",
    "corcodușelor": "corcodușă",
    "corcodușo": "corcodușă",
    "corcolea": "corcoli",
    "corcoleai": "corcoli",
    "corcoleam": "corcoli",
    "corcolească": "corcoli",
    "corcoleați": "corcoli",
    "corcoleau": "corcoli",
    "corcolesc": "corcoli",
    "corcolește": "corcoli",
    "corcolești": "corcoli",
    "corcolii": "corcoli",
    "corcolim": "corcoli",
    "corcolind": "corcoli",
    "corcolindu": "corcoli",
    "corcoliră": "corcoli",
    "corcolirăm": "corcoli",
    "corcolirăți": "corcoli",
    "corcolise": "corcoli",
    "corcolisem": "corcoli",
    "corcoliseră": "corcoli",
    "corcoliserăm": "corcoli",
    "corcoliserăți": "corcoli",
    "corcoliseși": "corcoli",
    "corcoliși": "corcoli",
    "corcolit": "corcoli",
    "corcoliți": "corcoli",
    "corcolitu": "corcoli",
    "corcolită": "corcolit",
    "corcolite": "corcolit",
    "corcoliți": "corcolit",
    "cordul": "cord",
    "cordule": "cord",
    "cordului": "cord",
    "corduri": "cord",
    "cordurile": "cord",
    "cordurilor": "cord",
    "cordaje": "cordaj",
    "cordajele": "cordaj",
    "cordajelor": "cordaj",
    "cordajul": "cordaj",
    "cordajule": "cordaj",
    "cordajului": "cordaj",
    "cordeao": "cordea",
    "cordeaua": "cordea",
    "cordele": "cordea",
    "cordelei": "cordea",
    "cordelele": "cordea",
    "cordelelor": "cordea",
    "cordela": "cordelă",
    "cordiala": "cordial",
    "cordială": "cordial",
    "cordiale": "cordial",
    "cordialei": "cordial",
    "cordialele": "cordial",
    "cordialelor": "cordial",
    "cordiali": "cordial",
    "cordialii": "cordial",
    "cordialilor": "cordial",
    "cordialo": "cordial",
    "cordialul": "cordial",
    "cordialule": "cordial",
    "cordialului": "cordial",
    "cordoane": "cordon",
    "cordoanele": "cordon",
    "cordoanelor": "cordon",
    "cordonul": "cordon",
    "cordonule": "cordon",
    "cordonului": "cordon",
    "corecta": "corect",
    "corectă": "corect",
    "corecte": "corect",
    "corectei": "corect",
    "corectele": "corect",
    "corectelor": "corect",
    "corecți": "corect",
    "corecții": "corect",
    "corecților": "corect",
    "corecto": "corect",
    "corectul": "corect",
    "corectule": "corect",
    "corectului": "corect",
    "corectă": "corecta",
    "corectai": "corecta",
    "corectam": "corecta",
    "corectăm": "corecta",
    "corectând": "corecta",
    "corectându": "corecta",
    "corectară": "corecta",
    "corectarăm": "corecta",
    "corectarăți": "corecta",
    "corectase": "corecta",
    "corectasem": "corecta",
    "corectaseră": "corecta",
    "corectaserăm": "corecta",
    "corectaserăți": "corecta",
    "corectaseși": "corecta",
    "corectași": "corecta",
    "corectat": "corecta",
    "corectați": "corecta",
    "corectatu": "corecta",
    "corectau": "corecta",
    "corectează": "corecta",
    "corectez": "corecta",
    "corecteze": "corecta",
    "corectezi": "corecta",
    "necorectând": "corecta",
    "necorectându": "corecta",
    "nemaicorectând": "corecta",
    "nemaicorectându": "corecta",
    "corectarea": "corectare",
    "corectareo": "corectare",
    "corectări": "corectare",
    "corectării": "corectare",
    "corectările": "corectare",
    "corectărilor": "corectare",
    "corectată": "corectat",
    "corectate": "corectat",
    "corectați": "corectat",
    "corecția": "corecție",
    "corecției": "corecție",
    "corecții": "corecție",
    "corecțiile": "corecție",
    "corecțiilor": "corecție",
    "corecțio": "corecție",
    "corecționala": "corecțional",
    "corecțională": "corecțional",
    "corecționale": "corecțional",
    "corecționalei": "corecțional",
    "corecționalele": "corecțional",
    "corecționalelor": "corecțional",
    "corecționali": "corecțional",
    "corecționalii": "corecțional",
    "corecționalilor": "corecțional",
    "corecționalo": "corecțional",
    "corecționalul": "corecțional",
    "corecționalule": "corecțional",
    "corecționalului": "corecțional",
    "corectitudinea": "corectitudine",
    "corectitudineo": "corectitudine",
    "corectitudini": "corectitudine",
    "corectitudinii": "corectitudine",
    "corectitudinile": "corectitudine",
    "corectitudinilor": "corectitudine",
    "corectivă": "corectiv",
    "corective": "corectiv",
    "corectivele": "corectiv",
    "corectivelor": "corectiv",
    "corectivul": "corectiv",
    "corectivului": "corectiv",
    "corectoarea": "corectoare",
    "corectoarei": "corectoare",
    "corectoarele": "corectoare",
    "corectoarelor": "corectoare",
    "corectoareo": "corectoare",
    "corectori": "corector",
    "corectorii": "corector",
    "corectorilor": "corector",
    "corectorul": "corector",
    "corectorule": "corector",
    "corectorului": "corector",
    "corectura": "corectură",
    "corecturi": "corectură",
    "corecturii": "corectură",
    "corecturile": "corectură",
    "corecturilor": "corectură",
    "corecturo": "corectură",
    "Coree": "Coreea",
    "Coreei": "Coreea",
    "coregrafi": "coregraf",
    "coregrafii": "coregraf",
    "coregrafilor": "coregraf",
    "coregraful": "coregraf",
    "coregrafule": "coregraf",
    "coregrafului": "coregraf",
    "coregrafa": "coregrafă",
    "coregrafe": "coregrafă",
    "coregrafei": "coregrafă",
    "coregrafele": "coregrafă",
    "coregrafelor": "coregrafă",
    "coregrafo": "coregrafă",
    "coregrafica": "coregrafic",
    "coregrafică": "coregrafic",
    "coregrafice": "coregrafic",
    "coregraficei": "coregrafic",
    "coregraficele": "coregrafic",
    "coregraficelor": "coregrafic",
    "coregrafici": "coregrafic",
    "coregraficii": "coregrafic",
    "coregraficilor": "coregrafic",
    "coregrafico": "coregrafic",
    "coregraficul": "coregrafic",
    "coregraficule": "coregrafic",
    "coregraficului": "coregrafic",
    "cor.": "coregrafie",
    "coregrafia": "coregrafie",
    "coregrafii": "coregrafie",
    "coregrafiile": "coregrafie",
    "coregrafiilor": "coregrafie",
    "coreleze": "corela",
    "corelata": "corelat",
    "corelată": "corelat",
    "corelate": "corelat",
    "corelatei": "corelat",
    "corelatele": "corelat",
    "corelatelor": "corelat",
    "corelați": "corelat",
    "corelații": "corelat",
    "corelaților": "corelat",
    "corelato": "corelat",
    "corelatul": "corelat",
    "corelatule": "corelat",
    "corelatului": "corelat",
    "corelativa": "corelativ",
    "corelativă": "corelativ",
    "corelative": "corelativ",
    "corelativei": "corelativ",
    "corelativele": "corelativ",
    "corelativelor": "corelativ",
    "corelativi": "corelativ",
    "corelativii": "corelativ",
    "corelativilor": "corelativ",
    "corelativo": "corelativ",
    "corelativul": "corelativ",
    "corelativule": "corelativ",
    "corelativului": "corelativ",
    "corespondă": "coresponda",
    "corespondai": "coresponda",
    "corespondam": "coresponda",
    "corespondăm": "coresponda",
    "corespondând": "coresponda",
    "corespondându": "coresponda",
    "corespondară": "coresponda",
    "corespondarăm": "coresponda",
    "corespondarăți": "coresponda",
    "corespondase": "coresponda",
    "corespondasem": "coresponda",
    "corespondaseră": "coresponda",
    "corespondaserăm": "coresponda",
    "corespondaserăți": "coresponda",
    "corespondaseși": "coresponda",
    "corespondași": "coresponda",
    "corespondat": "coresponda",
    "corespondați": "coresponda",
    "corespondatu": "coresponda",
    "corespondau": "coresponda",
    "corespondează": "coresponda",
    "corespondez": "coresponda",
    "corespondeze": "coresponda",
    "corespondezi": "coresponda",
    "necorespondând": "coresponda",
    "necorespondându": "coresponda",
    "nemaicorespondând": "coresponda",
    "nemaicorespondându": "coresponda",
    "corespondată": "corespondat",
    "corespondate": "corespondat",
    "corespondați": "corespondat",
    "corespondenți": "corespondent",
    "corespondenții": "corespondent",
    "corespondenților": "corespondent",
    "corespondentul": "corespondent",
    "corespondentule": "corespondent",
    "corespondentului": "corespondent",
    "corespondenta": "corespondentă",
    "corespondente": "corespondentă",
    "corespondentei": "corespondentă",
    "corespondentele": "corespondentă",
    "corespondentelor": "corespondentă",
    "corespondento": "corespondentă",
    "corespondența": "corespondență",
    "corespondențe": "corespondență",
    "corespondenței": "corespondență",
    "corespondențele": "corespondență",
    "corespondențelor": "corespondență",
    "corespondențo": "corespondență",
    "corespund": "corespunde",
    "corespundă": "corespunde",
    "corespundea": "corespunde",
    "corespundeai": "corespunde",
    "corespundeam": "corespunde",
    "corespundeați": "corespunde",
    "corespundeau": "corespunde",
    "corespundem": "corespunde",
    "corespundeți": "corespunde",
    "corespuns": "corespunde",
    "corespunse": "corespunde",
    "corespunsei": "corespunde",
    "corespunseră": "corespunde",
    "corespunserăm": "corespunde",
    "corespunserăți": "corespunde",
    "corespunsese": "corespunde",
    "corespunsesem": "corespunde",
    "corespunseseră": "corespunde",
    "corespunseserăm": "corespunde",
    "corespunseserăți": "corespunde",
    "corespunseseși": "corespunde",
    "corespunseși": "corespunde",
    "corespunsu": "corespunde",
    "corespunzând": "corespunde",
    "corespunzându": "corespunde",
    "corespunzi": "corespunde",
    "necorespunzând": "corespunde",
    "necorespunzându": "corespunde",
    "nemaicorespunzând": "corespunde",
    "nemaicorespunzându": "corespunde",
    "corespunsă": "corespuns",
    "corespunse": "corespuns",
    "corespunși": "corespuns",
    "corespunzătoare": "corespunzător",
    "corespunzătoarea": "corespunzător",
    "corespunzătoarei": "corespunzător",
    "corespunzătoarele": "corespunzător",
    "corespunzătoarelor": "corespunzător",
    "corespunzătoareo": "corespunzător",
    "corespunzători": "corespunzător",
    "corespunzătorii": "corespunzător",
    "corespunzătorilor": "corespunzător",
    "corespunzătorul": "corespunzător",
    "corespunzătorule": "corespunzător",
    "corespunzătorului": "corespunzător",
    "coreuți": "coreut",
    "coreuții": "coreut",
    "coreuților": "coreut",
    "coreutul": "coreut",
    "coreutului": "coreut",
    "coridoare": "coridor",
    "coridoarele": "coridor",
    "coridoarelor": "coridor",
    "coridorul": "coridor",
    "coridorule": "coridor",
    "coridorului": "coridor",
    "corifei": "corifeu",
    "corifeii": "corifeu",
    "corifeilor": "corifeu",
    "corifeul": "corifeu",
    "corifeule": "corifeu",
    "corifeului": "corifeu",
    "corigenți": "corigent",
    "corigenții": "corigent",
    "corigenților": "corigent",
    "corigentul": "corigent",
    "corigentule": "corigent",
    "corigentului": "corigent",
    "corigenta": "corigentă",
    "corigente": "corigentă",
    "corigentei": "corigentă",
    "corigentele": "corigentă",
    "corigentelor": "corigentă",
    "corigento": "corigentă",
    "corigența": "corigență",
    "corigențe": "corigență",
    "corigenței": "corigență",
    "corigențele": "corigență",
    "corigențelor": "corigență",
    "corigențo": "corigență",
    "corigibila": "corigibil",
    "corigibilă": "corigibil",
    "corigibile": "corigibil",
    "corigibilei": "corigibil",
    "corigibilele": "corigibil",
    "corigibilelor": "corigibil",
    "corigibili": "corigibil",
    "corigibilii": "corigibil",
    "corigibililor": "corigibil",
    "corigibilo": "corigibil",
    "corigibilul": "corigibil",
    "corigibilule": "corigibil",
    "corigibilului": "corigibil",
    "corijă": "corija",
    "corijai": "corija",
    "corijam": "corija",
    "corijăm": "corija",
    "corijând": "corija",
    "corijându": "corija",
    "corijară": "corija",
    "corijarăm": "corija",
    "corijarăți": "corija",
    "corijase": "corija",
    "corijasem": "corija",
    "corijaseră": "corija",
    "corijaserăm": "corija",
    "corijaserăți": "corija",
    "corijaseși": "corija",
    "corijași": "corija",
    "corijat": "corija",
    "corijați": "corija",
    "corijatu": "corija",
    "corijau": "corija",
    "corijează": "corija",
    "corijez": "corija",
    "corijeze": "corija",
    "corijezi": "corija",
    "necorijând": "corija",
    "necorijându": "corija",
    "nemaicorijând": "corija",
    "nemaicorijându": "corija",
    "corijarea": "corijare",
    "corijareo": "corijare",
    "corijări": "corijare",
    "corijării": "corijare",
    "corijările": "corijare",
    "corijărilor": "corijare",
    "corijată": "corijat",
    "corijate": "corijat",
    "corijați": "corijat",
    "Corinei": "Corina",
    "Corintul": "Corint",
    "Corintului": "Corint",
    "Cor.": "Corinteni",
    "corintiana": "corintian",
    "corintiană": "corintian",
    "corintiano": "corintian",
    "corintianul": "corintian",
    "corintianule": "corintian",
    "corintianului": "corintian",
    "corintiene": "corintian",
    "corintienei": "corintian",
    "corintienele": "corintian",
    "corintienelor": "corintian",
    "corintieni": "corintian",
    "corintienii": "corintian",
    "corintienilor": "corintian",
    "corintica": "corintic",
    "corintică": "corintic",
    "corintice": "corintic",
    "corinticei": "corintic",
    "corinticele": "corintic",
    "corinticelor": "corintic",
    "corintici": "corintic",
    "corinticii": "corintic",
    "corinticilor": "corintic",
    "corintico": "corintic",
    "corinticul": "corintic",
    "corinticule": "corintic",
    "corinticului": "corintic",
    "corlata": "corlată",
    "corlate": "corlată",
    "corlatei": "corlată",
    "corlatele": "corlată",
    "corlatelor": "corlată",
    "corlăți": "corlată",
    "corlății": "corlată",
    "corlățile": "corlată",
    "corlăților": "corlată",
    "corlato": "corlată",
    "cormorani": "cormoran",
    "cormoranii": "cormoran",
    "cormoranilor": "cormoran",
    "cormoranul": "cormoran",
    "cormoranule": "cormoran",
    "cormoranului": "cormoran",
    "coarne": "corn",
    "coarnele": "corn",
    "coarnelor": "corn",
    "corni": "corn",
    "cornii": "corn",
    "cornilor": "corn",
    "cornul": "corn",
    "cornule": "corn",
    "cornului": "corn",
    "cornuri": "corn",
    "cornurile": "corn",
    "cornurilor": "corn",
    "corneea": "cornee",
    "corneei": "cornee",
    "corneele": "cornee",
    "corneelor": "cornee",
    "corneeo": "cornee",
    "Corneliei": "Cornelia",
    "C.V.": "Corneliu_Vadim",
    "cornete": "cornet",
    "cornetele": "cornet",
    "cornetelor": "cornet",
    "corneți": "cornet",
    "corneții": "cornet",
    "corneților": "cornet",
    "cornetul": "cornet",
    "cornetule": "cornet",
    "cornetului": "cornet",
    "corneturi": "cornet",
    "corneturile": "cornet",
    "corneturilor": "cornet",
    "cornișa": "cornișă",
    "cornișe": "cornișă",
    "cornișei": "cornișă",
    "cornișele": "cornișă",
    "cornișelor": "cornișă",
    "cornișo": "cornișă",
    "cornoasa": "cornos",
    "cornoasă": "cornos",
    "cornoase": "cornos",
    "cornoasei": "cornos",
    "cornoasele": "cornos",
    "cornoaselor": "cornos",
    "cornoaso": "cornos",
    "cornoși": "cornos",
    "cornoșii": "cornos",
    "cornoșilor": "cornos",
    "cornosul": "cornos",
    "cornosule": "cornos",
    "cornosului": "cornos",
    "cornuta": "cornut",
    "cornută": "cornut",
    "cornute": "cornut",
    "cornutei": "cornut",
    "cornutele": "cornut",
    "cornutelor": "cornut",
    "cornuți": "cornut",
    "cornuții": "cornut",
    "cornuților": "cornut",
    "cornuto": "cornut",
    "cornutul": "cornut",
    "cornutule": "cornut",
    "cornutului": "cornut",
    "coroana": "coroană",
    "coroane": "coroană",
    "coroanei": "coroană",
    "coroanele": "coroană",
    "coroanelor": "coroană",
    "coroano": "coroană",
    "coroboră": "corobora",
    "coroborai": "corobora",
    "coroboram": "corobora",
    "coroborăm": "corobora",
    "coroborând": "corobora",
    "coroborându": "corobora",
    "coroborară": "corobora",
    "coroborarăm": "corobora",
    "coroborarăți": "corobora",
    "coroborase": "corobora",
    "coroborasem": "corobora",
    "coroboraseră": "corobora",
    "coroboraserăm": "corobora",
    "coroboraserăți": "corobora",
    "coroboraseși": "corobora",
    "coroborași": "corobora",
    "coroborat": "corobora",
    "coroborați": "corobora",
    "coroboratu": "corobora",
    "coroborau": "corobora",
    "coroborează": "corobora",
    "coroborez": "corobora",
    "coroboreze": "corobora",
    "coroborezi": "corobora",
    "necoroborând": "corobora",
    "necoroborându": "corobora",
    "nemaicoroborând": "corobora",
    "nemaicoroborându": "corobora",
    "coroborarea": "coroborare",
    "coroborareo": "coroborare",
    "coroborări": "coroborare",
    "coroborării": "coroborare",
    "coroborările": "coroborare",
    "coroborărilor": "coroborare",
    "coroborată": "coroborat",
    "coroborate": "coroborat",
    "coroborați": "coroborat",
    "coroii": "coroi",
    "coroilor": "coroi",
    "coroiul": "coroi",
    "coroiule": "coroi",
    "coroiului": "coroi",
    "coroiai": "coroia",
    "coroiam": "coroia",
    "coroiară": "coroia",
    "coroiarăm": "coroia",
    "coroiarăți": "coroia",
    "coroiase": "coroia",
    "coroiasem": "coroia",
    "coroiaseră": "coroia",
    "coroiaserăm": "coroia",
    "coroiaserăți": "coroia",
    "coroiaseși": "coroia",
    "coroiași": "coroia",
    "coroiat": "coroia",
    "coroiați": "coroia",
    "coroiatu": "coroia",
    "coroiau": "coroia",
    "coroiază": "coroia",
    "coroie": "coroia",
    "coroiem": "coroia",
    "coroiez": "coroia",
    "coroieze": "coroia",
    "coroiezi": "coroia",
    "coroind": "coroia",
    "coroindu": "coroia",
    "necoroind": "coroia",
    "necoroindu": "coroia",
    "nemaicoroind": "coroia",
    "nemaicoroindu": "coroia",
    "coroiata": "coroiat",
    "coroiată": "coroiat",
    "coroiate": "coroiat",
    "coroiatei": "coroiat",
    "coroiatele": "coroiat",
    "coroiatelor": "coroiat",
    "coroiați": "coroiat",
    "coroiații": "coroiat",
    "coroiaților": "coroiat",
    "coroiato": "coroiat",
    "coroiatul": "coroiat",
    "coroiatule": "coroiat",
    "coroiatului": "coroiat",
    "coroida": "coroidă",
    "coroide": "coroidă",
    "coroidei": "coroidă",
    "coroidele": "coroidă",
    "coroidelor": "coroidă",
    "coroido": "coroidă",
    "corola": "corolă",
    "corole": "corolă",
    "corolei": "corolă",
    "corolele": "corolă",
    "corolelor": "corolă",
    "corolo": "corolă",
    "corolare": "corolar",
    "corolarele": "corolar",
    "corolarelor": "corolar",
    "corolarul": "corolar",
    "corolarule": "corolar",
    "corolarului": "corolar",
    "coronamente": "coronament",
    "coronamentele": "coronament",
    "coronamentelor": "coronament",
    "coronamentul": "coronament",
    "coronamentule": "coronament",
    "coronamentului": "coronament",
    "coropișnița": "coropișniță",
    "coropișnițe": "coropișniță",
    "coropișniței": "coropișniță",
    "coropișnițele": "coropișniță",
    "coropișnițelor": "coropișniță",
    "coropișnițo": "coropișniță",
    "coroziunea": "coroziune",
    "coroziuneo": "coroziune",
    "coroziuni": "coroziune",
    "coroziunii": "coroziune",
    "coroziunile": "coroziune",
    "coroziunilor": "coroziune",
    "corpi": "corp",
    "corpii": "corp",
    "corpilor": "corp",
    "corpul": "corp",
    "corpule": "corp",
    "corpului": "corp",
    "corpuri": "corp",
    "corpurile": "corp",
    "corpurilor": "corp",
    "corpolenta": "corpolent",
    "corpolentă": "corpolent",
    "corpolente": "corpolent",
    "corpolentei": "corpolent",
    "corpolentele": "corpolent",
    "corpolentelor": "corpolent",
    "corpolenți": "corpolent",
    "corpolenții": "corpolent",
    "corpolenților": "corpolent",
    "corpolento": "corpolent",
    "corpolentul": "corpolent",
    "corpolentule": "corpolent",
    "corpolentului": "corpolent",
    "corpolența": "corpolență",
    "corpolențe": "corpolență",
    "corpolenței": "corpolență",
    "corpolențele": "corpolență",
    "corpolențelor": "corpolență",
    "corpolențo": "corpolență",
    "corporala": "corporal",
    "corporală": "corporal",
    "corporale": "corporal",
    "corporalei": "corporal",
    "corporalele": "corporal",
    "corporalelor": "corporal",
    "corporali": "corporal",
    "corporalii": "corporal",
    "corporalilor": "corporal",
    "corporalo": "corporal",
    "corporalul": "corporal",
    "corporalule": "corporal",
    "corporalului": "corporal",
    "corporația": "corporație",
    "corporației": "corporație",
    "corporații": "corporație",
    "corporațiile": "corporație",
    "corporațiilor": "corporație",
    "corporațio": "corporație",
    "corpusul": "corpus",
    "corpusule": "corpus",
    "corpusului": "corpus",
    "corpusuri": "corpus",
    "corpusurile": "corpus",
    "corpusurilor": "corpus",
    "corpuscule": "corpuscul",
    "corpusculele": "corpuscul",
    "corpusculelor": "corpuscul",
    "corpusculi": "corpuscul",
    "corpusculii": "corpuscul",
    "corpusculilor": "corpuscul",
    "corpusculul": "corpuscul",
    "corpusculule": "corpuscul",
    "corpusculului": "corpuscul",
    "corsaje": "corsaj",
    "corsajele": "corsaj",
    "corsajelor": "corsaj",
    "corsajul": "corsaj",
    "corsajule": "corsaj",
    "corsajului": "corsaj",
    "corsari": "corsar",
    "corsarii": "corsar",
    "corsarilor": "corsar",
    "corsarul": "corsar",
    "corsarule": "corsar",
    "corsarului": "corsar",
    "corsete": "corset",
    "corsetele": "corset",
    "corsetelor": "corset",
    "corsetul": "corset",
    "corsetule": "corset",
    "corsetului": "corset",
    "cortul": "cort",
    "cortule": "cort",
    "cortului": "cort",
    "corturi": "cort",
    "corturile": "cort",
    "corturilor": "cort",
    "cortegii": "cortegiu",
    "cortegiile": "cortegiu",
    "cortegiilor": "cortegiu",
    "cortegiul": "cortegiu",
    "cortegiule": "cortegiu",
    "cortegiului": "cortegiu",
    "corticala": "cortical",
    "corticală": "cortical",
    "corticale": "cortical",
    "corticalei": "cortical",
    "corticalele": "cortical",
    "corticalelor": "cortical",
    "corticali": "cortical",
    "corticalii": "cortical",
    "corticalilor": "cortical",
    "corticalo": "cortical",
    "corticalul": "cortical",
    "corticalule": "cortical",
    "corticalului": "cortical",
    "cortina": "cortină",
    "cortine": "cortină",
    "cortinei": "cortină",
    "cortinele": "cortină",
    "cortinelor": "cortină",
    "cortino": "cortină",
    "corupătoarea": "corupătoare",
    "corupătoarei": "corupătoare",
    "corupătoarele": "corupătoare",
    "corupătoarelor": "corupătoare",
    "corupătoareo": "corupătoare",
    "corupătoare": "corupător",
    "corupătoarea": "corupător",
    "corupătoarei": "corupător",
    "corupătoarele": "corupător",
    "corupătoarelor": "corupător",
    "corupătoareo": "corupător",
    "corupători": "corupător",
    "corupătorii": "corupător",
    "corupătorilor": "corupător",
    "corupătorul": "corupător",
    "corupătorule": "corupător",
    "corupătorului": "corupător",
    "corup": "corupe",
    "corupă": "corupe",
    "corupând": "corupe",
    "corupându": "corupe",
    "corupea": "corupe",
    "corupeai": "corupe",
    "corupeam": "corupe",
    "corupeați": "corupe",
    "corupeau": "corupe",
    "corupem": "corupe",
    "corupeți": "corupe",
    "corupi": "corupe",
    "corupse": "corupe",
    "corupsei": "corupe",
    "corupseră": "corupe",
    "corupserăm": "corupe",
    "corupserăți": "corupe",
    "corupsese": "corupe",
    "corupsesem": "corupe",
    "corupseseră": "corupe",
    "corupseserăm": "corupe",
    "corupseserăți": "corupe",
    "corupseseși": "corupe",
    "corupseși": "corupe",
    "corupt": "corupe",
    "coruptu": "corupe",
    "necorupând": "corupe",
    "necorupându": "corupe",
    "nemaicorupând": "corupe",
    "nemaicorupându": "corupe",
    "coruperea": "corupere",
    "corupereo": "corupere",
    "coruperi": "corupere",
    "coruperii": "corupere",
    "coruperile": "corupere",
    "coruperilor": "corupere",
    "corupta": "corupt",
    "coruptă": "corupt",
    "corupte": "corupt",
    "coruptei": "corupt",
    "coruptele": "corupt",
    "coruptelor": "corupt",
    "corupți": "corupt",
    "corupții": "corupt",
    "corupților": "corupt",
    "corupto": "corupt",
    "coruptul": "corupt",
    "coruptule": "corupt",
    "coruptului": "corupt",
    "coruptibila": "coruptibil",
    "coruptibilă": "coruptibil",
    "coruptibile": "coruptibil",
    "coruptibilei": "coruptibil",
    "coruptibilele": "coruptibil",
    "coruptibilelor": "coruptibil",
    "coruptibili": "coruptibil",
    "coruptibilii": "coruptibil",
    "coruptibililor": "coruptibil",
    "coruptibilo": "coruptibil",
    "coruptibilul": "coruptibil",
    "coruptibilule": "coruptibil",
    "coruptibilului": "coruptibil",
    "corupția": "corupție",
    "corupției": "corupție",
    "corupții": "corupție",
    "corupțiile": "corupție",
    "corupțiilor": "corupție",
    "corupțio": "corupție",
    "corveta": "corvetă",
    "corvete": "corvetă",
    "corvetei": "corvetă",
    "corvetele": "corvetă",
    "corvetelor": "corvetă",
    "corveto": "corvetă",
    "corvezi": "corvoadă",
    "corvezii": "corvoadă",
    "corveziii": "corvoadă",
    "corveziile": "corvoadă",
    "corveziilor": "corvoadă",
    "corvezile": "corvoadă",
    "corvezilor": "corvoadă",
    "corvoada": "corvoadă",
    "corvoado": "corvoadă",
    "coșul": "coș",
    "coșule": "coș",
    "coșului": "coș",
    "coșuri": "coș",
    "coșurile": "coș",
    "coșurilor": "coș",
    "cosaci": "cosac",
    "cosacii": "cosac",
    "cosacilor": "cosac",
    "cosacul": "cosac",
    "cosacule": "cosac",
    "cosacului": "cosac",
    "coșare": "coșar",
    "coșarele": "coșar",
    "coșarelor": "coșar",
    "coșari": "coșar",
    "coșarii": "coșar",
    "coșarilor": "coșar",
    "coșarul": "coșar",
    "coșarule": "coșar",
    "coșarului": "coșar",
    "coșarca": "coșarcă",
    "coșărci": "coșarcă",
    "coșărcii": "coșarcă",
    "coșărcile": "coșarcă",
    "coșărcilor": "coșarcă",
    "coșarco": "coșarcă",
    "cosași": "cosaș",
    "cosașii": "cosaș",
    "cosașilor": "cosaș",
    "cosașul": "cosaș",
    "cosașule": "cosaș",
    "cosașului": "cosaș",
    "cosciuge": "cosciug",
    "cosciugele": "cosciug",
    "cosciugelor": "cosciug",
    "cosciugul": "cosciug",
    "cosciugule": "cosciug",
    "cosciugului": "cosciug",
    "coșciuge": "coșciug",
    "coșciugele": "coșciug",
    "coșciugelor": "coșciug",
    "coșciugul": "coșciug",
    "coșciugule": "coșciug",
    "coșciugului": "coșciug",
    "coșcoveala": "coșcoveală",
    "coșcovealo": "coșcoveală",
    "coșcoveli": "coșcoveală",
    "coșcovelii": "coșcoveală",
    "coșcovelile": "coșcoveală",
    "coșcovelilor": "coșcoveală",
    "coșcovea": "coșcovi",
    "coșcoveai": "coșcovi",
    "coșcoveam": "coșcovi",
    "coșcovească": "coșcovi",
    "coșcoveați": "coșcovi",
    "coșcoveau": "coșcovi",
    "coșcovesc": "coșcovi",
    "coșcovește": "coșcovi",
    "coșcovești": "coșcovi",
    "coșcovii": "coșcovi",
    "coșcovim": "coșcovi",
    "coșcovind": "coșcovi",
    "coșcovindu": "coșcovi",
    "coșcoviră": "coșcovi",
    "coșcovirăm": "coșcovi",
    "coșcovirăți": "coșcovi",
    "coșcovise": "coșcovi",
    "coșcovisem": "coșcovi",
    "coșcoviseră": "coșcovi",
    "coșcoviserăm": "coșcovi",
    "coșcoviserăți": "coșcovi",
    "coșcoviseși": "coșcovi",
    "coșcoviși": "coșcovi",
    "coșcovit": "coșcovi",
    "coșcoviți": "coșcovi",
    "coșcovitu": "coșcovi",
    "necoșcovind": "coșcovi",
    "necoșcovindu": "coșcovi",
    "nemaicoșcovind": "coșcovi",
    "nemaicoșcovindu": "coșcovi",
    "coșcovita": "coșcovit",
    "coșcovită": "coșcovit",
    "coșcovite": "coșcovit",
    "coșcovitei": "coșcovit",
    "coșcovitele": "coșcovit",
    "coșcovitelor": "coșcovit",
    "coșcoviți": "coșcovit",
    "coșcoviții": "coșcovit",
    "coșcoviților": "coșcovit",
    "coșcovito": "coșcovit",
    "coșcovitul": "coșcovit",
    "coșcovitule": "coșcovit",
    "coșcovitului": "coșcovit",
    "cosecanta": "cosecantă",
    "cosecante": "cosecantă",
    "cosecantei": "cosecantă",
    "cosecantele": "cosecantă",
    "cosecantelor": "cosecantă",
    "cosecanto": "cosecantă",
    "cosea": "cosi",
    "coseai": "cosi",
    "coseam": "cosi",
    "cosească": "cosi",
    "coseați": "cosi",
    "coseau": "cosi",
    "cosesc": "cosi",
    "cosește": "cosi",
    "cosești": "cosi",
    "cosii": "cosi",
    "cosim": "cosi",
    "cosind": "cosi",
    "cosindu": "cosi",
    "cosiră": "cosi",
    "cosirăm": "cosi",
    "cosirăți": "cosi",
    "cosise": "cosi",
    "cosisem": "cosi",
    "cosiseră": "cosi",
    "cosiserăm": "cosi",
    "cosiserăți": "cosi",
    "cosiseși": "cosi",
    "cosiși": "cosi",
    "cosit": "cosi",
    "cosiți": "cosi",
    "cositu": "cosi",
    "necosind": "cosi",
    "necosindu": "cosi",
    "nemaicosind": "cosi",
    "nemaicosindu": "cosi",
    "cos": "cosinus",
    "cosinusul": "cosinus",
    "cosinusule": "cosinus",
    "cosinusului": "cosinus",
    "cosinusuri": "cosinus",
    "cosinusurile": "cosinus",
    "cosinusurilor": "cosinus",
    "cosită": "cosit",
    "cosite": "cosit",
    "cosiți": "cosit",
    "cositul": "cosit",
    "cositule": "cosit",
    "cositului": "cosit",
    "cosița": "cosiță",
    "cosițe": "cosiță",
    "cosiței": "cosiță",
    "cosițele": "cosiță",
    "cosițelor": "cosiță",
    "cosițo": "cosiță",
    "cositoarea": "cositoare",
    "cositoarei": "cositoare",
    "cositoarele": "cositoare",
    "cositoarelor": "cositoare",
    "cositoareo": "cositoare",
    "cositori": "cositoare",
    "cositorii": "cositoare",
    "cositorile": "cositoare",
    "cositorilor": "cositoare",
    "cositoare": "cositor",
    "cositoarea": "cositor",
    "cositoarei": "cositor",
    "cositoarele": "cositor",
    "cositoarelor": "cositor",
    "cositoareo": "cositor",
    "cositori": "cositor",
    "cositorii": "cositor",
    "cositorilor": "cositor",
    "cositorul": "cositor",
    "cositorule": "cositor",
    "cositorului": "cositor",
    "coșmare": "coșmar",
    "coșmarele": "coșmar",
    "coșmarelor": "coșmar",
    "coșmarul": "coșmar",
    "coșmarule": "coșmar",
    "coșmarului": "coșmar",
    "coșmaruri": "coșmar",
    "coșmarurile": "coșmar",
    "coșmarurilor": "coșmar",
    "coșmelia": "coșmelie",
    "coșmeliei": "coșmelie",
    "coșmelii": "coșmelie",
    "coșmeliile": "coșmelie",
    "coșmeliilor": "coșmelie",
    "coșmelio": "coșmelie",
    "cosmetica": "cosmetic",
    "cosmetică": "cosmetic",
    "cosmetice": "cosmetic",
    "cosmeticei": "cosmetic",
    "cosmeticele": "cosmetic",
    "cosmeticelor": "cosmetic",
    "cosmetici": "cosmetic",
    "cosmeticii": "cosmetic",
    "cosmeticilor": "cosmetic",
    "cosmetico": "cosmetic",
    "cosmeticul": "cosmetic",
    "cosmeticule": "cosmetic",
    "cosmeticului": "cosmetic",
    "cosmetica": "cosmetică",
    "cosmetice": "cosmetică",
    "cosmeticei": "cosmetică",
    "cosmetico": "cosmetică",
    "cosmeticianul": "cosmetician",
    "cosmeticianule": "cosmetician",
    "cosmeticianului": "cosmetician",
    "cosmeticieni": "cosmetician",
    "cosmeticienii": "cosmetician",
    "cosmeticienilor": "cosmetician",
    "cosmeticiana": "cosmeticiană",
    "cosmeticiano": "cosmeticiană",
    "cosmeticiene": "cosmeticiană",
    "cosmeticienei": "cosmeticiană",
    "cosmeticienele": "cosmeticiană",
    "cosmeticienelor": "cosmeticiană",
    "cosmica": "cosmic",
    "cosmică": "cosmic",
    "cosmice": "cosmic",
    "cosmicei": "cosmic",
    "cosmicele": "cosmic",
    "cosmicelor": "cosmic",
    "cosmici": "cosmic",
    "cosmicii": "cosmic",
    "cosmicilor": "cosmic",
    "cosmico": "cosmic",
    "cosmicul": "cosmic",
    "cosmicule": "cosmic",
    "cosmicului": "cosmic",
    "cosmobiologica": "cosmobiologic",
    "cosmobiologică": "cosmobiologic",
    "cosmobiologice": "cosmobiologic",
    "cosmobiologicei": "cosmobiologic",
    "cosmobiologicele": "cosmobiologic",
    "cosmobiologicelor": "cosmobiologic",
    "cosmobiologici": "cosmobiologic",
    "cosmobiologicii": "cosmobiologic",
    "cosmobiologicilor": "cosmobiologic",
    "cosmobiologico": "cosmobiologic",
    "cosmobiologicul": "cosmobiologic",
    "cosmobiologicule": "cosmobiologic",
    "cosmobiologicului": "cosmobiologic",
    "cosmogonica": "cosmogonic",
    "cosmogonică": "cosmogonic",
    "cosmogonice": "cosmogonic",
    "cosmogonicei": "cosmogonic",
    "cosmogonicele": "cosmogonic",
    "cosmogonicelor": "cosmogonic",
    "cosmogonici": "cosmogonic",
    "cosmogonicii": "cosmogonic",
    "cosmogonicilor": "cosmogonic",
    "cosmogonico": "cosmogonic",
    "cosmogonicul": "cosmogonic",
    "cosmogonicule": "cosmogonic",
    "cosmogonicului": "cosmogonic",
    "cosmogonia": "cosmogonie",
    "cosmogoniei": "cosmogonie",
    "cosmogonii": "cosmogonie",
    "cosmogoniile": "cosmogonie",
    "cosmogoniilor": "cosmogonie",
    "cosmogonio": "cosmogonie",
    "cosmografica": "cosmografic",
    "cosmografică": "cosmografic",
    "cosmografice": "cosmografic",
    "cosmograficei": "cosmografic",
    "cosmograficele": "cosmografic",
    "cosmograficelor": "cosmografic",
    "cosmografici": "cosmografic",
    "cosmograficii": "cosmografic",
    "cosmograficilor": "cosmografic",
    "cosmografico": "cosmografic",
    "cosmograficul": "cosmografic",
    "cosmograficule": "cosmografic",
    "cosmograficului": "cosmografic",
    "cosmografia": "cosmografie",
    "cosmografiei": "cosmografie",
    "cosmografii": "cosmografie",
    "cosmografiile": "cosmografie",
    "cosmografiilor": "cosmografie",
    "cosmografio": "cosmografie",
    "cosmologia": "cosmologie",
    "cosmologiei": "cosmologie",
    "cosmologii": "cosmologie",
    "cosmologiile": "cosmologie",
    "cosmologiilor": "cosmologie",
    "cosmologio": "cosmologie",
    "cosmonauți": "cosmonaut",
    "cosmonauții": "cosmonaut",
    "cosmonauților": "cosmonaut",
    "cosmonautul": "cosmonaut",
    "cosmonautule": "cosmonaut",
    "cosmonautului": "cosmonaut",
    "cosmonautica": "cosmonautică",
    "cosmonautici": "cosmonautică",
    "cosmonauticii": "cosmonautică",
    "cosmonautico": "cosmonautică",
    "cosmopolita": "cosmopolit",
    "cosmopolită": "cosmopolit",
    "cosmopolite": "cosmopolit",
    "cosmopolitei": "cosmopolit",
    "cosmopolitele": "cosmopolit",
    "cosmopolitelor": "cosmopolit",
    "cosmopoliți": "cosmopolit",
    "cosmopoliții": "cosmopolit",
    "cosmopoliților": "cosmopolit",
    "cosmopolito": "cosmopolit",
    "cosmopolitul": "cosmopolit",
    "cosmopolitule": "cosmopolit",
    "cosmopolitului": "cosmopolit",
    "cosmosul": "cosmos",
    "cosmosule": "cosmos",
    "cosmosului": "cosmos",
    "cosmosuri": "cosmos",
    "cosmosurile": "cosmos",
    "cosmosurilor": "cosmos",
    "coșnița": "coșniță",
    "coșnițe": "coșniță",
    "coșniței": "coșniță",
    "coșnițele": "coșniță",
    "coșnițelor": "coșniță",
    "coșnițo": "coșniță",
    "cosoare": "cosor",
    "cosoarele": "cosor",
    "cosoarelor": "cosor",
    "cosorul": "cosor",
    "cosorule": "cosor",
    "cosorului": "cosor",
    "cosorâtă": "cosorât",
    "cosorâte": "cosorât",
    "cosorâți": "cosorât",
    "cosora": "cosorî",
    "cosorai": "cosorî",
    "cosorâi": "cosorî",
    "cosoram": "cosorî",
    "cosorâm": "cosorî",
    "cosorând": "cosorî",
    "cosorându": "cosorî",
    "cosorâră": "cosorî",
    "cosorârăm": "cosorî",
    "cosorârăți": "cosorî",
    "cosorăsc": "cosorî",
    "cosorască": "cosorî",
    "cosorâse": "cosorî",
    "cosorâsem": "cosorî",
    "cosorâseră": "cosorî",
    "cosorâserăm": "cosorî",
    "cosorâserăți": "cosorî",
    "cosorâseși": "cosorî",
    "cosorâși": "cosorî",
    "cosorăște": "cosorî",
    "cosorăști": "cosorî",
    "cosorât": "cosorî",
    "cosorați": "cosorî",
    "cosorâți": "cosorî",
    "cosorâtu": "cosorî",
    "cosorau": "cosorî",
    "necosorând": "cosorî",
    "necosorându": "cosorî",
    "nemaicosorând": "cosorî",
    "nemaicosorându": "cosorî",
    "costul": "cost",
    "costule": "cost",
    "costului": "cost",
    "costuri": "cost",
    "costurile": "cost",
    "costurilor": "cost",
    "cost": "costa",
    "costă": "costa",
    "costai": "costa",
    "costam": "costa",
    "costăm": "costa",
    "costând": "costa",
    "costându": "costa",
    "costară": "costa",
    "costarăm": "costa",
    "costarăți": "costa",
    "costase": "costa",
    "costasem": "costa",
    "costaseră": "costa",
    "costaserăm": "costa",
    "costaserăți": "costa",
    "costaseși": "costa",
    "costași": "costa",
    "costat": "costa",
    "costați": "costa",
    "costatu": "costa",
    "costau": "costa",
    "coste": "costa",
    "coști": "costa",
    "necostând": "costa",
    "necostându": "costa",
    "nemaicostând": "costa",
    "nemaicostându": "costa",
    "costale": "costal",
    "costată": "costat",
    "costate": "costat",
    "costați": "costat",
    "costeliva": "costeliv",
    "costelivă": "costeliv",
    "costelive": "costeliv",
    "costelivei": "costeliv",
    "costelivele": "costeliv",
    "costelivelor": "costeliv",
    "costelivi": "costeliv",
    "costelivii": "costeliv",
    "costelivilor": "costeliv",
    "costelivo": "costeliv",
    "costelivul": "costeliv",
    "costelivule": "costeliv",
    "costelivului": "costeliv",
    "costișa": "costișă",
    "costișe": "costișă",
    "costișei": "costișă",
    "costișele": "costișă",
    "costișelor": "costișă",
    "costișo": "costișă",
    "costisitoare": "costisitor",
    "costisitoarea": "costisitor",
    "costisitoarei": "costisitor",
    "costisitoarele": "costisitor",
    "costisitoarelor": "costisitor",
    "costisitoareo": "costisitor",
    "costisitori": "costisitor",
    "costisitorii": "costisitor",
    "costisitorilor": "costisitor",
    "costisitorul": "costisitor",
    "costisitorule": "costisitor",
    "costisitorului": "costisitor",
    "costreii": "costrei",
    "costreilor": "costrei",
    "costreiul": "costrei",
    "costreiule": "costrei",
    "costreiului": "costrei",
    "costume": "costum",
    "costumele": "costum",
    "costumelor": "costum",
    "costumul": "costum",
    "costumule": "costum",
    "costumului": "costum",
    "costumă": "costuma",
    "costumai": "costuma",
    "costumam": "costuma",
    "costumăm": "costuma",
    "costumând": "costuma",
    "costumându": "costuma",
    "costumară": "costuma",
    "costumarăm": "costuma",
    "costumarăți": "costuma",
    "costumase": "costuma",
    "costumasem": "costuma",
    "costumaseră": "costuma",
    "costumaserăm": "costuma",
    "costumaserăți": "costuma",
    "costumaseși": "costuma",
    "costumași": "costuma",
    "costumat": "costuma",
    "costumați": "costuma",
    "costumatu": "costuma",
    "costumau": "costuma",
    "costumează": "costuma",
    "costumez": "costuma",
    "costumeze": "costuma",
    "costumezi": "costuma",
    "necostumând": "costuma",
    "necostumându": "costuma",
    "nemaicostumând": "costuma",
    "nemaicostumându": "costuma",
    "costumarea": "costumare",
    "costumareo": "costumare",
    "costumări": "costumare",
    "costumării": "costumare",
    "costumările": "costumare",
    "costumărilor": "costumare",
    "costumata": "costumat",
    "costumată": "costumat",
    "costumate": "costumat",
    "costumatei": "costumat",
    "costumatele": "costumat",
    "costumatelor": "costumat",
    "costumați": "costumat",
    "costumații": "costumat",
    "costumaților": "costumat",
    "costumato": "costumat",
    "costumatul": "costumat",
    "costumatule": "costumat",
    "costumatului": "costumat",
    "coate": "cot",
    "coatele": "cot",
    "coatelor": "cot",
    "coți": "cot",
    "coții": "cot",
    "coților": "cot",
    "cotul": "cot",
    "cotule": "cot",
    "cotului": "cot",
    "coturi": "cot",
    "coturile": "cot",
    "coturilor": "cot",
    "cotă": "cota",
    "cotai": "cota",
    "cotam": "cota",
    "cotăm": "cota",
    "cotând": "cota",
    "cotându": "cota",
    "cotară": "cota",
    "cotarăm": "cota",
    "cotarăți": "cota",
    "cotase": "cota",
    "cotasem": "cota",
    "cotaseră": "cota",
    "cotaserăm": "cota",
    "cotaserăți": "cota",
    "cotaseși": "cota",
    "cotași": "cota",
    "cotat": "cota",
    "cotați": "cota",
    "cotatu": "cota",
    "cotau": "cota",
    "cotează": "cota",
    "cotez": "cota",
    "coteze": "cota",
    "cotezi": "cota",
    "necotând": "cota",
    "necotându": "cota",
    "nemaicotând": "cota",
    "nemaicotându": "cota",
    "cota": "cotă",
    "cote": "cotă",
    "cotei": "cotă",
    "cotele": "cotă",
    "cotelor": "cotă",
    "coto": "cotă",
    "cotangenta": "cotangentă",
    "cotangente": "cotangentă",
    "cotangentei": "cotangentă",
    "cotangentele": "cotangentă",
    "cotangentelor": "cotangentă",
    "cotangento": "cotangentă",
    "ctg": "cotangentă",
    "cota-parte": "cotă-parte",
    "cotei-părți": "cotă-parte",
    "cotele-părți": "cotă-parte",
    "cotelor-părți": "cotă-parte",
    "cote-părți": "cotă-parte",
    "cotarea": "cotare",
    "cotareo": "cotare",
    "cotări": "cotare",
    "cotării": "cotare",
    "cotările": "cotare",
    "cotărilor": "cotare",
    "cotarla": "cotarlă",
    "cotarle": "cotarlă",
    "cotarlei": "cotarlă",
    "cotarlele": "cotarlă",
    "cotarlelor": "cotarlă",
    "cotarlo": "cotarlă",
    "cotată": "cotat",
    "cotate": "cotat",
    "cotați": "cotat",
    "coțcari": "coțcar",
    "coțcarii": "coțcar",
    "coțcarilor": "coțcar",
    "coțcarul": "coțcar",
    "coțcarule": "coțcar",
    "coțcarului": "coțcar",
    "cotcodăcea": "cotcodăci",
    "cotcodăceai": "cotcodăci",
    "cotcodăceam": "cotcodăci",
    "cotcodăcească": "cotcodăci",
    "cotcodăceați": "cotcodăci",
    "cotcodăceau": "cotcodăci",
    "cotcodăcesc": "cotcodăci",
    "cotcodăcește": "cotcodăci",
    "cotcodăcești": "cotcodăci",
    "cotcodăcii": "cotcodăci",
    "cotcodăcim": "cotcodăci",
    "cotcodăcind": "cotcodăci",
    "cotcodăcindu": "cotcodăci",
    "cotcodăciră": "cotcodăci",
    "cotcodăcirăm": "cotcodăci",
    "cotcodăcirăți": "cotcodăci",
    "cotcodăcise": "cotcodăci",
    "cotcodăcisem": "cotcodăci",
    "cotcodăciseră": "cotcodăci",
    "cotcodăciserăm": "cotcodăci",
    "cotcodăciserăți": "cotcodăci",
    "cotcodăciseși": "cotcodăci",
    "cotcodăciși": "cotcodăci",
    "cotcodăcit": "cotcodăci",
    "cotcodăciți": "cotcodăci",
    "cotcodăcitu": "cotcodăci",
    "necotcodăcind": "cotcodăci",
    "necotcodăcindu": "cotcodăci",
    "nemaicotcodăcind": "cotcodăci",
    "nemaicotcodăcindu": "cotcodăci",
    "cotcodăcirea": "cotcodăcire",
    "cotcodăcireo": "cotcodăcire",
    "cotcodăciri": "cotcodăcire",
    "cotcodăcirii": "cotcodăcire",
    "cotcodăcirile": "cotcodăcire",
    "cotcodăcirilor": "cotcodăcire",
    "cotcodăcită": "cotcodăcit",
    "cotcodăcite": "cotcodăcit",
    "cotcodăciți": "cotcodăcit",
    "cotcodăcitul": "cotcodăcit",
    "cotcodăcitule": "cotcodăcit",
    "cotcodăcitului": "cotcodăcit",
    "cotcodăcituri": "cotcodăcit",
    "cotcodăciturile": "cotcodăcit",
    "cotcodăciturilor": "cotcodăcit",
    "coteie": "cotei",
    "coteiele": "cotei",
    "coteielor": "cotei",
    "coteii": "cotei",
    "coteilor": "cotei",
    "coteiul": "cotei",
    "coteiule": "cotei",
    "coteiului": "cotei",
    "cotețe": "coteț",
    "cotețele": "coteț",
    "cotețelor": "coteț",
    "cotețul": "coteț",
    "cotețule": "coteț",
    "cotețului": "coteț",
    "cotea": "coti",
    "coteai": "coti",
    "coteam": "coti",
    "cotească": "coti",
    "coteați": "coti",
    "coteau": "coti",
    "cotesc": "coti",
    "cotește": "coti",
    "cotești": "coti",
    "cotii": "coti",
    "cotim": "coti",
    "cotind": "coti",
    "cotindu": "coti",
    "cotiră": "coti",
    "cotirăm": "coti",
    "cotirăți": "coti",
    "cotise": "coti",
    "cotisem": "coti",
    "cotiseră": "coti",
    "cotiserăm": "coti",
    "cotiserăți": "coti",
    "cotiseși": "coti",
    "cotiși": "coti",
    "cotit": "coti",
    "cotiți": "coti",
    "cotitu": "coti",
    "necotind": "coti",
    "necotindu": "coti",
    "nemaicotind": "coti",
    "nemaicotindu": "coti",
    "cotidiana": "cotidian",
    "cotidiană": "cotidian",
    "cotidiano": "cotidian",
    "cotidianul": "cotidian",
    "cotidianule": "cotidian",
    "cotidianului": "cotidian",
    "cotidiene": "cotidian",
    "cotidienei": "cotidian",
    "cotidienele": "cotidian",
    "cotidienelor": "cotidian",
    "cotidieni": "cotidian",
    "cotidienii": "cotidian",
    "cotidienilor": "cotidian",
    "cotiera": "cotieră",
    "cotiere": "cotieră",
    "cotierei": "cotieră",
    "cotierele": "cotieră",
    "cotierelor": "cotieră",
    "cotiga": "cotigă",
    "cotigi": "cotigă",
    "cotigii": "cotigă",
    "cotigile": "cotigă",
    "cotigilor": "cotigă",
    "cotigo": "cotigă",
    "cotiledoane": "cotiledon",
    "cotiledoanele": "cotiledon",
    "cotiledoanelor": "cotiledon",
    "cotiledonul": "cotiledon",
    "cotiledonule": "cotiledon",
    "cotiledonului": "cotiledon",
    "Cotimaniul": "Cotimani",
    "Cotimaniului": "Cotimani",
    "cotita": "cotit",
    "cotită": "cotit",
    "cotite": "cotit",
    "cotitei": "cotit",
    "cotitele": "cotit",
    "cotitelor": "cotit",
    "cotiți": "cotit",
    "cotiții": "cotit",
    "cotiților": "cotit",
    "cotito": "cotit",
    "cotitul": "cotit",
    "cotitule": "cotit",
    "cotitului": "cotit",
    "cotitura": "cotitură",
    "cotituri": "cotitură",
    "cotiturii": "cotitură",
    "cotiturile": "cotitură",
    "cotiturilor": "cotitură",
    "cotituro": "cotitură",
    "cotiză": "cotiza",
    "cotizai": "cotiza",
    "cotizam": "cotiza",
    "cotizăm": "cotiza",
    "cotizând": "cotiza",
    "cotizându": "cotiza",
    "cotizară": "cotiza",
    "cotizarăm": "cotiza",
    "cotizarăți": "cotiza",
    "cotizase": "cotiza",
    "cotizasem": "cotiza",
    "cotizaseră": "cotiza",
    "cotizaserăm": "cotiza",
    "cotizaserăți": "cotiza",
    "cotizaseși": "cotiza",
    "cotizași": "cotiza",
    "cotizat": "cotiza",
    "cotizați": "cotiza",
    "cotizatu": "cotiza",
    "cotizau": "cotiza",
    "cotizează": "cotiza",
    "cotizez": "cotiza",
    "cotizeze": "cotiza",
    "cotizezi": "cotiza",
    "necotizând": "cotiza",
    "necotizându": "cotiza",
    "nemaicotizând": "cotiza",
    "nemaicotizându": "cotiza",
    "cotizată": "cotizat",
    "cotizate": "cotizat",
    "cotizați": "cotizat",
    "cotizația": "cotizație",
    "cotizații": "cotizație",
    "cotizațiile": "cotizație",
    "cotizațiilor": "cotizație",
    "cotlete": "cotlet",
    "cotletele": "cotlet",
    "cotletelor": "cotlet",
    "cotletul": "cotlet",
    "cotletule": "cotlet",
    "cotletului": "cotlet",
    "cotloane": "cotlon",
    "cotloanele": "cotlon",
    "cotloanelor": "cotlon",
    "cotlonul": "cotlon",
    "cotlonule": "cotlon",
    "cotlonului": "cotlon",
    "coțofana": "coțofană",
    "coțofano": "coțofană",
    "coțofene": "coțofană",
    "coțofenei": "coțofană",
    "coțofenele": "coțofană",
    "coțofenelor": "coțofană",
    "cotoii": "cotoi",
    "cotoilor": "cotoi",
    "cotoiul": "cotoi",
    "cotoiule": "cotoi",
    "cotoiului": "cotoi",
    "cotonogeala": "cotonogeală",
    "cotonogealo": "cotonogeală",
    "cotonogeli": "cotonogeală",
    "cotonogelii": "cotonogeală",
    "cotonogelile": "cotonogeală",
    "cotonogelilor": "cotonogeală",
    "cotonogea": "cotonogi",
    "cotonogeai": "cotonogi",
    "cotonogeam": "cotonogi",
    "cotonogească": "cotonogi",
    "cotonogeați": "cotonogi",
    "cotonogeau": "cotonogi",
    "cotonogesc": "cotonogi",
    "cotonogește": "cotonogi",
    "cotonogești": "cotonogi",
    "cotonogii": "cotonogi",
    "cotonogim": "cotonogi",
    "cotonogind": "cotonogi",
    "cotonogindu": "cotonogi",
    "cotonogiră": "cotonogi",
    "cotonogirăm": "cotonogi",
    "cotonogirăți": "cotonogi",
    "cotonogise": "cotonogi",
    "cotonogisem": "cotonogi",
    "cotonogiseră": "cotonogi",
    "cotonogiserăm": "cotonogi",
    "cotonogiserăți": "cotonogi",
    "cotonogiseși": "cotonogi",
    "cotonogiși": "cotonogi",
    "cotonogit": "cotonogi",
    "cotonogiți": "cotonogi",
    "cotonogitu": "cotonogi",
    "necotonogind": "cotonogi",
    "necotonogindu": "cotonogi",
    "nemaicotonogind": "cotonogi",
    "nemaicotonogindu": "cotonogi",
    "cotonogită": "cotonogit",
    "cotonogite": "cotonogit",
    "cotonogiți": "cotonogit",
    "cotoare": "cotor",
    "cotoarele": "cotor",
    "cotoarelor": "cotor",
    "cotorul": "cotor",
    "cotorule": "cotor",
    "cotorului": "cotor",
    "cotoroanța": "cotoroanță",
    "cotoroanțe": "cotoroanță",
    "cotoroanței": "cotoroanță",
    "cotoroanțele": "cotoroanță",
    "cotoroanțelor": "cotoroanță",
    "cotoroanțo": "cotoroanță",
    "cotrobăia": "cotrobăi",
    "cotrobăiai": "cotrobăi",
    "cotrobăiam": "cotrobăi",
    "cotrobăiască": "cotrobăi",
    "cotrobăiați": "cotrobăi",
    "cotrobăiau": "cotrobăi",
    "cotrobăiesc": "cotrobăi",
    "cotrobăiește": "cotrobăi",
    "cotrobăiești": "cotrobăi",
    "cotrobăii": "cotrobăi",
    "cotrobăim": "cotrobăi",
    "cotrobăind": "cotrobăi",
    "cotrobăindu": "cotrobăi",
    "cotrobăiră": "cotrobăi",
    "cotrobăirăm": "cotrobăi",
    "cotrobăirăți": "cotrobăi",
    "cotrobăise": "cotrobăi",
    "cotrobăisem": "cotrobăi",
    "cotrobăiseră": "cotrobăi",
    "cotrobăiserăm": "cotrobăi",
    "cotrobăiserăți": "cotrobăi",
    "cotrobăiseși": "cotrobăi",
    "cotrobăiși": "cotrobăi",
    "cotrobăit": "cotrobăi",
    "cotrobăiți": "cotrobăi",
    "cotrobăitu": "cotrobăi",
    "necotrobăind": "cotrobăi",
    "necotrobăindu": "cotrobăi",
    "nemaicotrobăind": "cotrobăi",
    "nemaicotrobăindu": "cotrobăi",
    "cotrobăiala": "cotrobăială",
    "cotrobăialo": "cotrobăială",
    "cotrobăieli": "cotrobăială",
    "cotrobăielii": "cotrobăială",
    "cotrobăielile": "cotrobăială",
    "cotrobăielilor": "cotrobăială",
    "cotrobăirea": "cotrobăire",
    "cotrobăireo": "cotrobăire",
    "cotrobăiri": "cotrobăire",
    "cotrobăirii": "cotrobăire",
    "cotrobăirile": "cotrobăire",
    "cotrobăirilor": "cotrobăire",
    "cotrobăită": "cotrobăit",
    "cotrobăite": "cotrobăit",
    "cotrobăiți": "cotrobăit",
    "Cotrocenii": "Cotroceni",
    "Cotrocenilor": "Cotroceni",
    "Cotroceniul": "Cotroceni",
    "Cotroceniului": "Cotroceni",
    "cotropea": "cotropi",
    "cotropeai": "cotropi",
    "cotropeam": "cotropi",
    "cotropească": "cotropi",
    "cotropeați": "cotropi",
    "cotropeau": "cotropi",
    "cotropesc": "cotropi",
    "cotropește": "cotropi",
    "cotropești": "cotropi",
    "cotropii": "cotropi",
    "cotropim": "cotropi",
    "cotropind": "cotropi",
    "cotropindu": "cotropi",
    "cotropiră": "cotropi",
    "cotropirăm": "cotropi",
    "cotropirăți": "cotropi",
    "cotropise": "cotropi",
    "cotropisem": "cotropi",
    "cotropiseră": "cotropi",
    "cotropiserăm": "cotropi",
    "cotropiserăți": "cotropi",
    "cotropiseși": "cotropi",
    "cotropiși": "cotropi",
    "cotropit": "cotropi",
    "cotropiți": "cotropi",
    "cotropitu": "cotropi",
    "necotropind": "cotropi",
    "necotropindu": "cotropi",
    "nemaicotropind": "cotropi",
    "nemaicotropindu": "cotropi",
    "cotropirea": "cotropire",
    "cotropireo": "cotropire",
    "cotropiri": "cotropire",
    "cotropirii": "cotropire",
    "cotropirile": "cotropire",
    "cotropirilor": "cotropire",
    "cotropită": "cotropit",
    "cotropite": "cotropit",
    "cotropiți": "cotropit",
    "cotropitoarea": "cotropitoare",
    "cotropitoarei": "cotropitoare",
    "cotropitoarele": "cotropitoare",
    "cotropitoarelor": "cotropitoare",
    "cotropitoareo": "cotropitoare",
    "cotropitoare": "cotropitor",
    "cotropitoarea": "cotropitor",
    "cotropitoarei": "cotropitor",
    "cotropitoarele": "cotropitor",
    "cotropitoarelor": "cotropitor",
    "cotropitoareo": "cotropitor",
    "cotropitori": "cotropitor",
    "cotropitorii": "cotropitor",
    "cotropitorilor": "cotropitor",
    "cotropitorul": "cotropitor",
    "cotropitorule": "cotropitor",
    "cotropitorului": "cotropitor",
    "coulombi": "coulomb",
    "coulombii": "coulomb",
    "coulombilor": "coulomb",
    "coulombul": "coulomb",
    "coulombule": "coulomb",
    "coulombului": "coulomb",
    "covârșea": "covârși",
    "covârșeai": "covârși",
    "covârșeam": "covârși",
    "covârșească": "covârși",
    "covârșeați": "covârși",
    "covârșeau": "covârși",
    "covârșesc": "covârși",
    "covârșește": "covârși",
    "covârșești": "covârși",
    "covârșii": "covârși",
    "covârșim": "covârși",
    "covârșind": "covârși",
    "covârșindu": "covârși",
    "covârșiră": "covârși",
    "covârșirăm": "covârși",
    "covârșirăți": "covârși",
    "covârșise": "covârși",
    "covârșisem": "covârși",
    "covârșiseră": "covârși",
    "covârșiserăm": "covârși",
    "covârșiserăți": "covârși",
    "covârșiseși": "covârși",
    "covârșiși": "covârși",
    "covârșit": "covârși",
    "covârșiți": "covârși",
    "covârșitu": "covârși",
    "necovârșind": "covârși",
    "necovârșindu": "covârși",
    "nemaicovârșind": "covârși",
    "nemaicovârșindu": "covârși",
    "covârșită": "covârșit",
    "covârșite": "covârșit",
    "covârșiți": "covârșit",
    "covârșitoare": "covârșitor",
    "covârșitoarea": "covârșitor",
    "covârșitoarei": "covârșitor",
    "covârșitoarele": "covârșitor",
    "covârșitoarelor": "covârșitor",
    "covârșitoareo": "covârșitor",
    "covârșitori": "covârșitor",
    "covârșitorii": "covârșitor",
    "covârșitorilor": "covârșitor",
    "covârșitorul": "covârșitor",
    "covârșitorule": "covârșitor",
    "covârșitorului": "covârșitor",
    "covăsea": "covăsi",
    "covăseai": "covăsi",
    "covăseam": "covăsi",
    "covăsească": "covăsi",
    "covăseați": "covăsi",
    "covăseau": "covăsi",
    "covăsesc": "covăsi",
    "covăsește": "covăsi",
    "covăsești": "covăsi",
    "covăsii": "covăsi",
    "covăsim": "covăsi",
    "covăsind": "covăsi",
    "covăsindu": "covăsi",
    "covăsiră": "covăsi",
    "covăsirăm": "covăsi",
    "covăsirăți": "covăsi",
    "covăsise": "covăsi",
    "covăsisem": "covăsi",
    "covăsiseră": "covăsi",
    "covăsiserăm": "covăsi",
    "covăsiserăți": "covăsi",
    "covăsiseși": "covăsi",
    "covăsiși": "covăsi",
    "covăsit": "covăsi",
    "covăsiți": "covăsi",
    "covăsitu": "covăsi",
    "necovăsind": "covăsi",
    "necovăsindu": "covăsi",
    "nemaicovăsind": "covăsi",
    "nemaicovăsindu": "covăsi",
    "covăsită": "covăsit",
    "covăsite": "covăsit",
    "covăsiți": "covăsit",
    "covăsiții": "covăsit",
    "covăsiților": "covăsit",
    "covăsitul": "covăsit",
    "covăsitule": "covăsit",
    "covăsitului": "covăsit",
    "covata": "covată",
    "covato": "covată",
    "coveți": "covată",
    "coveții": "covată",
    "covețile": "covată",
    "coveților": "covată",
    "coverga": "covergă",
    "covergi": "covergă",
    "covergii": "covergă",
    "covergile": "covergă",
    "covergilor": "covergă",
    "covergo": "covergă",
    "coverta": "covertă",
    "coverte": "covertă",
    "covertei": "covertă",
    "covertele": "covertă",
    "covertelor": "covertă",
    "coverto": "covertă",
    "coviltire": "coviltir",
    "coviltirele": "coviltir",
    "coviltirelor": "coviltir",
    "coviltirul": "coviltir",
    "coviltirule": "coviltir",
    "coviltirului": "coviltir",
    "covoare": "covor",
    "covoarele": "covor",
    "covoarelor": "covor",
    "covorul": "covor",
    "covorule": "covor",
    "covorului": "covor",
    "covrigi": "covrig",
    "covrigii": "covrig",
    "covrigilor": "covrig",
    "covrigul": "covrig",
    "covrigule": "covrig",
    "covrigului": "covrig",
    "coxalgia": "coxalgie",
    "coxalgiei": "coxalgie",
    "coxalgii": "coxalgie",
    "coxalgiile": "coxalgie",
    "coxalgiilor": "coxalgie",
    "coxalgio": "coxalgie",
    "cozonaci": "cozonac",
    "cozonacii": "cozonac",
    "cozonacilor": "cozonac",
    "cozonacul": "cozonac",
    "cozonacule": "cozonac",
    "cozonacului": "cozonac",
    "cozoroace": "cozoroc",
    "cozoroacele": "cozoroc",
    "cozoroacelor": "cozoroc",
    "cozorocul": "cozoroc",
    "cozorocule": "cozoroc",
    "cozorocului": "cozoroc",
    "crabi": "crab",
    "crabii": "crab",
    "crabilor": "crab",
    "crabul": "crab",
    "crabule": "crab",
    "crabului": "crab",
    "craci": "crac",
    "cracii": "crac",
    "cracilor": "crac",
    "cracul": "crac",
    "cracule": "crac",
    "cracului": "crac",
    "craca": "cracă",
    "crăci": "cracă",
    "crăcii": "cracă",
    "crăcile": "cracă",
    "crăcilor": "cracă",
    "craco": "cracă",
    "crăcanul": "crăcan",
    "crăcanule": "crăcan",
    "crăcanului": "crăcan",
    "crăcana": "crăcană",
    "crăcane": "crăcană",
    "crăcanei": "crăcană",
    "crăcanele": "crăcană",
    "crăcanelor": "crăcană",
    "crăcano": "crăcană",
    "crăcănă": "crăcăna",
    "crăcănai": "crăcăna",
    "crăcănam": "crăcăna",
    "crăcănăm": "crăcăna",
    "crăcănând": "crăcăna",
    "crăcănându": "crăcăna",
    "crăcănară": "crăcăna",
    "crăcănarăm": "crăcăna",
    "crăcănarăți": "crăcăna",
    "crăcănase": "crăcăna",
    "crăcănasem": "crăcăna",
    "crăcănaseră": "crăcăna",
    "crăcănaserăm": "crăcăna",
    "crăcănaserăți": "crăcăna",
    "crăcănaseși": "crăcăna",
    "crăcănași": "crăcăna",
    "crăcănat": "crăcăna",
    "crăcănați": "crăcăna",
    "crăcănatu": "crăcăna",
    "crăcănau": "crăcăna",
    "crăcănează": "crăcăna",
    "crăcănez": "crăcăna",
    "crăcăneze": "crăcăna",
    "crăcănezi": "crăcăna",
    "necrăcănând": "crăcăna",
    "necrăcănându": "crăcăna",
    "nemaicrăcănând": "crăcăna",
    "nemaicrăcănându": "crăcăna",
    "crăcănata": "crăcănat",
    "crăcănată": "crăcănat",
    "crăcănate": "crăcănat",
    "crăcănatei": "crăcănat",
    "crăcănatele": "crăcănat",
    "crăcănatelor": "crăcănat",
    "crăcănați": "crăcănat",
    "crăcănații": "crăcănat",
    "crăcănaților": "crăcănat",
    "crăcănato": "crăcănat",
    "crăcănatul": "crăcănat",
    "crăcănatule": "crăcănat",
    "crăcănatului": "crăcănat",
    "cracarea": "cracare",
    "cracareo": "cracare",
    "cracări": "cracare",
    "cracării": "cracare",
    "cracările": "cracare",
    "cracărilor": "cracare",
    "crăcea": "crăci",
    "crăceai": "crăci",
    "crăceam": "crăci",
    "crăcească": "crăci",
    "crăceați": "crăci",
    "crăceau": "crăci",
    "crăcesc": "crăci",
    "crăcește": "crăci",
    "crăcești": "crăci",
    "crăcii": "crăci",
    "crăcim": "crăci",
    "crăcind": "crăci",
    "crăcindu": "crăci",
    "crăciră": "crăci",
    "crăcirăm": "crăci",
    "crăcirăți": "crăci",
    "crăcise": "crăci",
    "crăcisem": "crăci",
    "crăciseră": "crăci",
    "crăciserăm": "crăci",
    "crăciserăți": "crăci",
    "crăciseși": "crăci",
    "crăciși": "crăci",
    "crăcit": "crăci",
    "crăciți": "crăci",
    "crăcitu": "crăci",
    "necrăcind": "crăci",
    "necrăcindu": "crăci",
    "nemaicrăcind": "crăci",
    "nemaicrăcindu": "crăci",
    "crăcita": "crăcit",
    "crăcită": "crăcit",
    "crăcite": "crăcit",
    "crăcitei": "crăcit",
    "crăcitele": "crăcit",
    "crăcitelor": "crăcit",
    "crăciți": "crăcit",
    "crăciții": "crăcit",
    "crăciților": "crăcit",
    "crăcito": "crăcit",
    "crăcitul": "crăcit",
    "crăcitule": "crăcit",
    "crăcitului": "crăcit",
    "Crăciunul": "Crăciun",
    "Crăciunului": "Crăciun",
    "crâcneala": "crâcneală",
    "crâcnealo": "crâcneală",
    "crâcneli": "crâcneală",
    "crâcnelii": "crâcneală",
    "crâcnelile": "crâcneală",
    "crâcnelilor": "crâcneală",
    "crâcnea": "crâcni",
    "crâcneai": "crâcni",
    "crâcneam": "crâcni",
    "crâcnească": "crâcni",
    "crâcneați": "crâcni",
    "crâcneau": "crâcni",
    "crâcnesc": "crâcni",
    "crâcnește": "crâcni",
    "crâcnești": "crâcni",
    "crâcnii": "crâcni",
    "crâcnim": "crâcni",
    "crâcnind": "crâcni",
    "crâcnindu": "crâcni",
    "crâcniră": "crâcni",
    "crâcnirăm": "crâcni",
    "crâcnirăți": "crâcni",
    "crâcnise": "crâcni",
    "crâcnisem": "crâcni",
    "crâcniseră": "crâcni",
    "crâcniserăm": "crâcni",
    "crâcniserăți": "crâcni",
    "crâcniseși": "crâcni",
    "crâcniși": "crâcni",
    "crâcnit": "crâcni",
    "crâcniți": "crâcni",
    "crâcnitu": "crâcni",
    "necrâcnind": "crâcni",
    "necrâcnindu": "crâcni",
    "nemaicrâcnind": "crâcni",
    "nemaicrâcnindu": "crâcni",
    "crâcnirea": "crâcnire",
    "crâcnireo": "crâcnire",
    "crâcniri": "crâcnire",
    "crâcnirii": "crâcnire",
    "crâcnirile": "crâcnire",
    "crâcnirilor": "crâcnire",
    "crâcnită": "crâcnit",
    "crâcnite": "crâcnit",
    "crâcniți": "crâcnit",
    "crahul": "crah",
    "crahule": "crah",
    "crahului": "crah",
    "crahuri": "crah",
    "crahurile": "crah",
    "crahurilor": "crah",
    "craii": "crai",
    "crailor": "crai",
    "craiul": "crai",
    "craiule": "crai",
    "craiului": "crai",
    "craidoni": "craidon",
    "craidonii": "craidon",
    "craidonilor": "craidon",
    "craidonul": "craidon",
    "craidonule": "craidon",
    "craidonului": "craidon",
    "crainici": "crainic",
    "crainicii": "crainic",
    "crainicilor": "crainic",
    "crainicul": "crainic",
    "crainicule": "crainic",
    "crainicului": "crainic",
    "Craiovei": "Craiova",
    "Crăișorului": "Crăișor",
    "crăița": "crăiță",
    "crăițe": "crăiță",
    "crăiței": "crăiță",
    "crăițele": "crăiță",
    "crăițelor": "crăiță",
    "crăițo": "crăiță",
    "crăițari": "crăițar",
    "crăițarii": "crăițar",
    "crăițarilor": "crăițar",
    "crăițarul": "crăițar",
    "crăițarule": "crăițar",
    "crăițarului": "crăițar",
    "crama": "cramă",
    "crame": "cramă",
    "cramei": "cramă",
    "cramele": "cramă",
    "cramelor": "cramă",
    "cramo": "cramă",
    "crampa": "crampă",
    "crampe": "crampă",
    "crampei": "crampă",
    "crampele": "crampă",
    "crampelor": "crampă",
    "crampo": "crampă",
    "crâmpeie": "crâmpei",
    "crâmpeiele": "crâmpei",
    "crâmpeielor": "crâmpei",
    "crâmpeiul": "crâmpei",
    "crâmpeiule": "crâmpei",
    "crâmpeiului": "crâmpei",
    "crampoane": "crampon",
    "crampoanele": "crampon",
    "crampoanelor": "crampon",
    "cramponul": "crampon",
    "cramponule": "crampon",
    "cramponului": "crampon",
    "cramponă": "crampona",
    "cramponai": "crampona",
    "cramponam": "crampona",
    "cramponăm": "crampona",
    "cramponând": "crampona",
    "cramponându": "crampona",
    "cramponară": "crampona",
    "cramponarăm": "crampona",
    "cramponarăți": "crampona",
    "cramponase": "crampona",
    "cramponasem": "crampona",
    "cramponaseră": "crampona",
    "cramponaserăm": "crampona",
    "cramponaserăți": "crampona",
    "cramponaseși": "crampona",
    "cramponași": "crampona",
    "cramponat": "crampona",
    "cramponați": "crampona",
    "cramponatu": "crampona",
    "cramponau": "crampona",
    "cramponează": "crampona",
    "cramponez": "crampona",
    "cramponeze": "crampona",
    "cramponezi": "crampona",
    "necramponând": "crampona",
    "necramponându": "crampona",
    "nemaicramponând": "crampona",
    "nemaicramponându": "crampona",
    "cramponarea": "cramponare",
    "cramponareo": "cramponare",
    "cramponări": "cramponare",
    "cramponării": "cramponare",
    "cramponările": "cramponare",
    "cramponărilor": "cramponare",
    "cramponată": "cramponat",
    "cramponate": "cramponat",
    "cramponați": "cramponat",
    "crâmpoțea": "crâmpoți",
    "crâmpoțeai": "crâmpoți",
    "crâmpoțeam": "crâmpoți",
    "crâmpoțească": "crâmpoți",
    "crâmpoțeați": "crâmpoți",
    "crâmpoțeau": "crâmpoți",
    "crâmpoțesc": "crâmpoți",
    "crâmpoțește": "crâmpoți",
    "crâmpoțești": "crâmpoți",
    "crâmpoții": "crâmpoți",
    "crâmpoțim": "crâmpoți",
    "crâmpoțind": "crâmpoți",
    "crâmpoțindu": "crâmpoți",
    "crâmpoțiră": "crâmpoți",
    "crâmpoțirăm": "crâmpoți",
    "crâmpoțirăți": "crâmpoți",
    "crâmpoțise": "crâmpoți",
    "crâmpoțisem": "crâmpoți",
    "crâmpoțiseră": "crâmpoți",
    "crâmpoțiserăm": "crâmpoți",
    "crâmpoțiserăți": "crâmpoți",
    "crâmpoțiseși": "crâmpoți",
    "crâmpoțiși": "crâmpoți",
    "crâmpoțit": "crâmpoți",
    "crâmpoțiți": "crâmpoți",
    "crâmpoțitu": "crâmpoți",
    "necrâmpoțind": "crâmpoți",
    "necrâmpoțindu": "crâmpoți",
    "nemaicrâmpoțind": "crâmpoți",
    "nemaicrâmpoțindu": "crâmpoți",
    "crâmpoțită": "crâmpoțit",
    "crâmpoțite": "crâmpoțit",
    "crâmpoțiți": "crâmpoțit",
    "crâncena": "crâncen",
    "crâncenă": "crâncen",
    "crâncene": "crâncen",
    "crâncenei": "crâncen",
    "crâncenele": "crâncen",
    "crâncenelor": "crâncen",
    "crânceni": "crâncen",
    "crâncenii": "crâncen",
    "crâncenilor": "crâncen",
    "crânceno": "crâncen",
    "crâncenul": "crâncen",
    "crâncenule": "crâncen",
    "crâncenului": "crâncen",
    "crângul": "crâng",
    "crângule": "crâng",
    "crângului": "crâng",
    "crânguri": "crâng",
    "crângurile": "crâng",
    "crângurilor": "crâng",
    "craniana": "cranian",
    "craniană": "cranian",
    "craniano": "cranian",
    "cranianul": "cranian",
    "cranianule": "cranian",
    "cranianului": "cranian",
    "craniene": "cranian",
    "cranienei": "cranian",
    "cranienele": "cranian",
    "cranienelor": "cranian",
    "cranieni": "cranian",
    "cranienii": "cranian",
    "cranienilor": "cranian",
    "cranio-cerebrală": "cranio-cerebral",
    "cranio-cerebrale": "cranio-cerebral",
    "cranio-cerebrali": "cranio-cerebral",
    "craniologia": "craniologie",
    "craniologiei": "craniologie",
    "craniologii": "craniologie",
    "craniologiile": "craniologie",
    "craniologiilor": "craniologie",
    "craniologio": "craniologie",
    "cranii": "craniu",
    "craniile": "craniu",
    "craniilor": "craniu",
    "craniul": "craniu",
    "craniule": "craniu",
    "craniului": "craniu",
    "crănțănea": "crănțăni",
    "crănțăneai": "crănțăni",
    "crănțăneam": "crănțăni",
    "crănțănească": "crănțăni",
    "crănțăneați": "crănțăni",
    "crănțăneau": "crănțăni",
    "crănțănesc": "crănțăni",
    "crănțănește": "crănțăni",
    "crănțănești": "crănțăni",
    "crănțănii": "crănțăni",
    "crănțănim": "crănțăni",
    "crănțănind": "crănțăni",
    "crănțănindu": "crănțăni",
    "crănțăniră": "crănțăni",
    "crănțănirăm": "crănțăni",
    "crănțănirăți": "crănțăni",
    "crănțănise": "crănțăni",
    "crănțănisem": "crănțăni",
    "crănțăniseră": "crănțăni",
    "crănțăniserăm": "crănțăni",
    "crănțăniserăți": "crănțăni",
    "crănțăniseși": "crănțăni",
    "crănțăniși": "crănțăni",
    "crănțănit": "crănțăni",
    "crănțăniți": "crănțăni",
    "crănțănitu": "crănțăni",
    "necrănțănind": "crănțăni",
    "necrănțănindu": "crănțăni",
    "nemaicrănțănind": "crănțăni",
    "nemaicrănțănindu": "crănțăni",
    "crănțănită": "crănțănit",
    "crănțănite": "crănțănit",
    "crănțăniți": "crănțănit",
    "crapi": "crap",
    "crapii": "crap",
    "crapilor": "crap",
    "crapul": "crap",
    "crapule": "crap",
    "crapului": "crap",
    "crăp": "crăpa",
    "crapă": "crăpa",
    "crăpă": "crăpa",
    "crăpai": "crăpa",
    "crăpam": "crăpa",
    "crăpăm": "crăpa",
    "crăpând": "crăpa",
    "crăpându": "crăpa",
    "crăpară": "crăpa",
    "crăparăm": "crăpa",
    "crăparăți": "crăpa",
    "crăpase": "crăpa",
    "crăpasem": "crăpa",
    "crăpaseră": "crăpa",
    "crăpaserăm": "crăpa",
    "crăpaserăți": "crăpa",
    "crăpaseși": "crăpa",
    "crăpași": "crăpa",
    "crăpat": "crăpa",
    "crăpați": "crăpa",
    "crăpatu": "crăpa",
    "crăpau": "crăpa",
    "crape": "crăpa",
    "crăpi": "crăpa",
    "necrăpând": "crăpa",
    "necrăpându": "crăpa",
    "nemaicrăpând": "crăpa",
    "nemaicrăpându": "crăpa",
    "crăpata": "crăpat",
    "crăpată": "crăpat",
    "crăpate": "crăpat",
    "crăpatei": "crăpat",
    "crăpatele": "crăpat",
    "crăpatelor": "crăpat",
    "crăpați": "crăpat",
    "crăpații": "crăpat",
    "crăpaților": "crăpat",
    "crăpato": "crăpat",
    "crăpatul": "crăpat",
    "crăpatule": "crăpat",
    "crăpatului": "crăpat",
    "crăpătura": "crăpătură",
    "crăpături": "crăpătură",
    "crăpăturii": "crăpătură",
    "crăpăturile": "crăpătură",
    "crăpăturilor": "crăpătură",
    "crăpăturo": "crăpătură",
    "crăpelnița": "crăpelniță",
    "crăpelnițe": "crăpelniță",
    "crăpelniței": "crăpelniță",
    "crăpelnițele": "crăpelniță",
    "crăpelnițelor": "crăpelniță",
    "crăpelnițo": "crăpelniță",
    "crasa": "cras",
    "crasă": "cras",
    "crase": "cras",
    "crasei": "cras",
    "crasele": "cras",
    "craselor": "cras",
    "crași": "cras",
    "crașii": "cras",
    "crașilor": "cras",
    "craso": "cras",
    "crasul": "cras",
    "crasule": "cras",
    "crasului": "cras",
    "crashul": "crash",
    "crashului": "crash",
    "crâșma": "crâșmă",
    "crâșme": "crâșmă",
    "crâșmei": "crâșmă",
    "crâșmele": "crâșmă",
    "crâșmelor": "crâșmă",
    "crâșmo": "crâșmă",
    "crâsnice": "crâsnic",
    "crâsnicele": "crâsnic",
    "crâsnicelor": "crâsnic",
    "crâsnici": "crâsnic",
    "crâsnicii": "crâsnic",
    "crâsnicilor": "crâsnic",
    "crâsnicul": "crâsnic",
    "crâsnicule": "crâsnic",
    "crâsnicului": "crâsnic",
    "cratere": "crater",
    "craterele": "crater",
    "craterelor": "crater",
    "craterul": "crater",
    "craterule": "crater",
    "craterului": "crater",
    "cratima": "cratimă",
    "cratime": "cratimă",
    "cratimei": "cratimă",
    "cratimele": "cratimă",
    "cratimelor": "cratimă",
    "cratimo": "cratimă",
    "cratița": "cratiță",
    "cratițe": "cratiță",
    "cratiței": "cratiță",
    "cratițele": "cratiță",
    "cratițelor": "cratiță",
    "cratițo": "cratiță",
    "craulul": "craul",
    "craulule": "craul",
    "craulului": "craul",
    "cravașă": "cravașa",
    "cravașai": "cravașa",
    "cravașam": "cravașa",
    "cravașăm": "cravașa",
    "cravașând": "cravașa",
    "cravașându": "cravașa",
    "cravașară": "cravașa",
    "cravașarăm": "cravașa",
    "cravașarăți": "cravașa",
    "cravașase": "cravașa",
    "cravașasem": "cravașa",
    "cravașaseră": "cravașa",
    "cravașaserăm": "cravașa",
    "cravașaserăți": "cravașa",
    "cravașaseși": "cravașa",
    "cravașași": "cravașa",
    "cravașat": "cravașa",
    "cravașați": "cravașa",
    "cravașatu": "cravașa",
    "cravașau": "cravașa",
    "cravașează": "cravașa",
    "cravașez": "cravașa",
    "cravașeze": "cravașa",
    "cravașezi": "cravașa",
    "necravașând": "cravașa",
    "necravașându": "cravașa",
    "nemaicravașând": "cravașa",
    "nemaicravașându": "cravașa",
    "cravașa": "cravașă",
    "cravașe": "cravașă",
    "cravașei": "cravașă",
    "cravașele": "cravașă",
    "cravașelor": "cravașă",
    "cravașo": "cravașă",
    "cravașarea": "cravașare",
    "cravașareo": "cravașare",
    "cravașări": "cravașare",
    "cravașării": "cravașare",
    "cravașările": "cravașare",
    "cravașărilor": "cravașare",
    "cravașată": "cravașat",
    "cravașate": "cravașat",
    "cravașați": "cravașat",
    "cravata": "cravată",
    "cravate": "cravată",
    "cravatei": "cravată",
    "cravatele": "cravată",
    "cravatelor": "cravată",
    "cravato": "cravată",
    "crăvățite": "crăvățit",
    "creă": "crea",
    "creai": "crea",
    "cream": "crea",
    "creăm": "crea",
    "creând": "crea",
    "creându": "crea",
    "creară": "crea",
    "crearăm": "crea",
    "crearăți": "crea",
    "crease": "crea",
    "creasem": "crea",
    "creaseră": "crea",
    "creaserăm": "crea",
    "creaserăți": "crea",
    "creaseși": "crea",
    "creași": "crea",
    "creat": "crea",
    "creați": "crea",
    "creatu": "crea",
    "creau": "crea",
    "creează": "crea",
    "creez": "crea",
    "creeze": "crea",
    "creezi": "crea",
    "necreând": "crea",
    "necreându": "crea",
    "nemaicreând": "crea",
    "nemaicreându": "crea",
    "creanga": "creangă",
    "creango": "creangă",
    "crengi": "creangă",
    "crengii": "creangă",
    "crengile": "creangă",
    "crengilor": "creangă",
    "creanța": "creanță",
    "creanțe": "creanță",
    "creanței": "creanță",
    "creanțele": "creanță",
    "creanțelor": "creanță",
    "creanțo": "creanță",
    "crearea": "creare",
    "creareo": "creare",
    "creări": "creare",
    "creării": "creare",
    "creările": "creare",
    "creărilor": "creare",
    "creasta": "creastă",
    "creasto": "creastă",
    "creste": "creastă",
    "crestei": "creastă",
    "crestele": "creastă",
    "crestelor": "creastă",
    "creată": "creat",
    "create": "creat",
    "creați": "creat",
    "creația": "creație",
    "creației": "creație",
    "creații": "creație",
    "creațiile": "creație",
    "creațiilor": "creație",
    "creațio": "creație",
    "creatoarea": "creatoare",
    "creatoarei": "creatoare",
    "creatoarele": "creatoare",
    "creatoarelor": "creatoare",
    "creatoareo": "creatoare",
    "creatoare": "creator",
    "creatoarea": "creator",
    "creatoarei": "creator",
    "creatoarele": "creator",
    "creatoarelor": "creator",
    "creatoareo": "creator",
    "creatori": "creator",
    "creatorii": "creator",
    "creatorilor": "creator",
    "creatorul": "creator",
    "creatorule": "creator",
    "creatorului": "creator",
    "creatura": "creatură",
    "creaturi": "creatură",
    "creaturii": "creatură",
    "creaturile": "creatură",
    "creaturilor": "creatură",
    "creaturo": "creatură",
    "cre'": "crede",
    "creadă": "crede",
    "cred": "crede",
    "credea": "crede",
    "credeai": "crede",
    "credeam": "crede",
    "credeați": "crede",
    "credeau": "crede",
    "credem": "crede",
    "credeți": "crede",
    "crezând": "crede",
    "crezându": "crede",
    "crezi": "crede",
    "crezu": "crede",
    "crezui": "crede",
    "crezură": "crede",
    "crezurăm": "crede",
    "crezurăți": "crede",
    "crezuse": "crede",
    "crezusem": "crede",
    "crezuseră": "crede",
    "crezuserăm": "crede",
    "crezuserăți": "crede",
    "crezuseși": "crede",
    "crezuși": "crede",
    "crezut": "crede",
    "crezutu": "crede",
    "necrezând": "crede",
    "necrezându": "crede",
    "necrezut": "crede",
    "nemaicrezând": "crede",
    "nemaicrezându": "crede",
    "credibila": "credibil",
    "credibilă": "credibil",
    "credibile": "credibil",
    "credibilei": "credibil",
    "credibilele": "credibil",
    "credibilelor": "credibil",
    "credibili": "credibil",
    "credibilii": "credibil",
    "credibililor": "credibil",
    "credibilo": "credibil",
    "credibilul": "credibil",
    "credibilule": "credibil",
    "credibilului": "credibil",
    "credibilitatea": "credibilitate",
    "credibilitateo": "credibilitate",
    "credibilități": "credibilitate",
    "credibilității": "credibilitate",
    "credibilitățile": "credibilitate",
    "credibilităților": "credibilitate",
    "credincioasa": "credincioasă",
    "credincioase": "credincioasă",
    "credincioasei": "credincioasă",
    "credincioasele": "credincioasă",
    "credincioaselor": "credincioasă",
    "credincioaso": "credincioasă",
    "credincioasa": "credincios",
    "credincioasă": "credincios",
    "credincioase": "credincios",
    "credincioasei": "credincios",
    "credincioasele": "credincios",
    "credincioaselor": "credincios",
    "credincioaso": "credincios",
    "credincioși": "credincios",
    "credincioșii": "credincios",
    "credincioșilor": "credincios",
    "credinciosul": "credincios",
    "credinciosule": "credincios",
    "credinciosului": "credincios",
    "credința": "credință",
    "credințe": "credință",
    "credinței": "credință",
    "credințele": "credință",
    "credințelor": "credință",
    "credințo": "credință",
    "credite": "credit",
    "creditele": "credit",
    "creditelor": "credit",
    "creditul": "credit",
    "creditule": "credit",
    "creditului": "credit",
    "credită": "credita",
    "creditai": "credita",
    "creditam": "credita",
    "credităm": "credita",
    "creditând": "credita",
    "creditându": "credita",
    "creditară": "credita",
    "creditarăm": "credita",
    "creditarăți": "credita",
    "creditase": "credita",
    "creditasem": "credita",
    "creditaseră": "credita",
    "creditaserăm": "credita",
    "creditaserăți": "credita",
    "creditaseși": "credita",
    "creditași": "credita",
    "creditat": "credita",
    "creditați": "credita",
    "creditatu": "credita",
    "creditau": "credita",
    "creditează": "credita",
    "creditez": "credita",
    "crediteze": "credita",
    "creditezi": "credita",
    "necreditând": "credita",
    "necreditându": "credita",
    "nemaicreditând": "credita",
    "nemaicreditându": "credita",
    "creditarea": "creditare",
    "creditareo": "creditare",
    "creditări": "creditare",
    "creditării": "creditare",
    "creditările": "creditare",
    "creditărilor": "creditare",
    "creditată": "creditat",
    "creditate": "creditat",
    "creditați": "creditat",
    "creditoarea": "creditoare",
    "creditoarei": "creditoare",
    "creditoarele": "creditoare",
    "creditoarelor": "creditoare",
    "creditoareo": "creditoare",
    "creditoare": "creditor",
    "creditoarea": "creditor",
    "creditoarei": "creditor",
    "creditoarele": "creditor",
    "creditoarelor": "creditor",
    "creditoareo": "creditor",
    "creditori": "creditor",
    "creditorii": "creditor",
    "creditorilor": "creditor",
    "creditorul": "creditor",
    "creditorule": "creditor",
    "creditorului": "creditor",
    "credoul": "credo",
    "credoule": "credo",
    "credoului": "credo",
    "credouri": "credo",
    "credourile": "credo",
    "credourilor": "credo",
    "credula": "credul",
    "credulă": "credul",
    "credule": "credul",
    "credulei": "credul",
    "credulele": "credul",
    "credulelor": "credul",
    "creduli": "credul",
    "credulii": "credul",
    "credulilor": "credul",
    "credulo": "credul",
    "credulul": "credul",
    "credulule": "credul",
    "credulului": "credul",
    "credulitatea": "credulitate",
    "credulitateo": "credulitate",
    "credulități": "credulitate",
    "credulității": "credulitate",
    "credulitățile": "credulitate",
    "credulităților": "credulitate",
    "creiere": "creier",
    "creierele": "creier",
    "creierelor": "creier",
    "creieri": "creier",
    "creierii": "creier",
    "creierilor": "creier",
    "creierul": "creier",
    "creierule": "creier",
    "creierului": "creier",
    "creioane": "creion",
    "creioanele": "creion",
    "creioanelor": "creion",
    "creionul": "creion",
    "creionule": "creion",
    "creionului": "creion",
    "creionă": "creiona",
    "creionai": "creiona",
    "creionam": "creiona",
    "creionăm": "creiona",
    "creionând": "creiona",
    "creionându": "creiona",
    "creionară": "creiona",
    "creionarăm": "creiona",
    "creionarăți": "creiona",
    "creionase": "creiona",
    "creionasem": "creiona",
    "creionaseră": "creiona",
    "creionaserăm": "creiona",
    "creionaserăți": "creiona",
    "creionaseși": "creiona",
    "creionași": "creiona",
    "creionat": "creiona",
    "creionați": "creiona",
    "creionatu": "creiona",
    "creionau": "creiona",
    "creionează": "creiona",
    "creionez": "creiona",
    "creioneze": "creiona",
    "creionezi": "creiona",
    "necreionând": "creiona",
    "necreionându": "creiona",
    "nemaicreionând": "creiona",
    "nemaicreionându": "creiona",
    "creionarea": "creionare",
    "creionareo": "creionare",
    "creionări": "creionare",
    "creionării": "creionare",
    "creionările": "creionare",
    "creionărilor": "creionare",
    "creionată": "creionat",
    "creionate": "creionat",
    "creionați": "creionat",
    "creițari": "creițar",
    "creițarii": "creițar",
    "creițarilor": "creițar",
    "creițarul": "creițar",
    "creițarule": "creițar",
    "creițarului": "creițar",
    "cremul": "crem",
    "cremului": "crem",
    "crema": "cremă",
    "creme": "cremă",
    "cremei": "cremă",
    "cremele": "cremă",
    "cremelor": "cremă",
    "cremo": "cremă",
    "cremaliera": "cremalieră",
    "cremaliere": "cremalieră",
    "cremalierei": "cremalieră",
    "cremalierele": "cremalieră",
    "cremalierelor": "cremalieră",
    "cremaliero": "cremalieră",
    "crematorii": "crematoriu",
    "crematoriile": "crematoriu",
    "crematoriilor": "crematoriu",
    "crematoriul": "crematoriu",
    "crematoriule": "crematoriu",
    "crematoriului": "crematoriu",
    "cremenea": "cremene",
    "cremeneo": "cremene",
    "cremeni": "cremene",
    "cremenii": "cremene",
    "cremona": "cremonă",
    "cremone": "cremonă",
    "cremonei": "cremonă",
    "cremonele": "cremonă",
    "cremonelor": "cremonă",
    "cremono": "cremonă",
    "crenelul": "crenel",
    "crenelule": "crenel",
    "crenelului": "crenel",
    "creneluri": "crenel",
    "crenelurile": "crenel",
    "crenelurilor": "crenel",
    "crenvurști": "crenvurșt",
    "crenvurștii": "crenvurșt",
    "crenvurștilor": "crenvurșt",
    "crenvurștul": "crenvurșt",
    "crenvurștule": "crenvurșt",
    "crenvurștului": "crenvurșt",
    "creoli": "creol",
    "creolii": "creol",
    "creolilor": "creol",
    "creolul": "creol",
    "creolule": "creol",
    "creolului": "creol",
    "creola": "creolă",
    "creole": "creolă",
    "creolei": "creolă",
    "creolele": "creolă",
    "creolelor": "creolă",
    "creolo": "creolă",
    "creolina": "creolină",
    "creoline": "creolină",
    "creolinei": "creolină",
    "creolinele": "creolină",
    "creolinelor": "creolină",
    "creolino": "creolină",
    "creozotul": "creozot",
    "creozotule": "creozot",
    "creozotului": "creozot",
    "crepul": "crep",
    "crepule": "crep",
    "crepului": "crep",
    "crepuri": "crep",
    "crepurile": "crep",
    "crepurilor": "crep",
    "crepida": "crepidă",
    "crepide": "crepidă",
    "crepidei": "crepidă",
    "crepidele": "crepidă",
    "crepidelor": "crepidă",
    "crepido": "crepidă",
    "crepoane": "crepon",
    "crepoanele": "crepon",
    "crepoanelor": "crepon",
    "creponul": "crepon",
    "creponule": "crepon",
    "creponului": "crepon",
    "creponata": "creponat",
    "creponată": "creponat",
    "creponate": "creponat",
    "creponatei": "creponat",
    "creponatele": "creponat",
    "creponatelor": "creponat",
    "creponați": "creponat",
    "creponații": "creponat",
    "creponaților": "creponat",
    "creponato": "creponat",
    "creponatul": "creponat",
    "creponatule": "creponat",
    "creponatului": "creponat",
    "crepuscule": "crepuscul",
    "crepusculele": "crepuscul",
    "crepusculelor": "crepuscul",
    "crepusculul": "crepuscul",
    "crepusculule": "crepuscul",
    "crepusculului": "crepuscul",
    "creșa": "creșă",
    "creșe": "creșă",
    "creșei": "creșă",
    "creșele": "creșă",
    "creșelor": "creșă",
    "creșo": "creșă",
    "crescânda": "crescând",
    "crescândă": "crescând",
    "crescânde": "crescând",
    "crescândei": "crescând",
    "crescândele": "crescând",
    "crescândelor": "crescând",
    "crescândo": "crescând",
    "crescândul": "crescând",
    "crescândule": "crescând",
    "crescândului": "crescând",
    "crescânzi": "crescând",
    "crescânzii": "crescând",
    "crescânzilor": "crescând",
    "crescătoarea": "crescătoare",
    "crescătoarei": "crescătoare",
    "crescătoarele": "crescătoare",
    "crescătoarelor": "crescătoare",
    "crescătoareo": "crescătoare",
    "crescătoare": "crescător",
    "crescătoarea": "crescător",
    "crescătoarei": "crescător",
    "crescătoarele": "crescător",
    "crescătoarelor": "crescător",
    "crescătoareo": "crescător",
    "crescători": "crescător",
    "crescătorii": "crescător",
    "crescătorilor": "crescător",
    "crescătorul": "crescător",
    "crescătorule": "crescător",
    "crescătorului": "crescător",
    "crescătoria": "crescătorie",
    "crescătoriei": "crescătorie",
    "crescătorii": "crescătorie",
    "crescătoriile": "crescătorie",
    "crescătoriilor": "crescătorie",
    "crescătorio": "crescătorie",
    "crescuta": "crescut",
    "crescută": "crescut",
    "crescute": "crescut",
    "crescutei": "crescut",
    "crescutele": "crescut",
    "crescutelor": "crescut",
    "crescuți": "crescut",
    "crescuții": "crescut",
    "crescuților": "crescut",
    "crescuto": "crescut",
    "crescutul": "crescut",
    "crescutule": "crescut",
    "crescutului": "crescut",
    "crestă": "cresta",
    "crestai": "cresta",
    "crestam": "cresta",
    "crestăm": "cresta",
    "crestând": "cresta",
    "crestându": "cresta",
    "crestară": "cresta",
    "crestarăm": "cresta",
    "crestarăți": "cresta",
    "crestase": "cresta",
    "crestasem": "cresta",
    "crestaseră": "cresta",
    "crestaserăm": "cresta",
    "crestaserăți": "cresta",
    "crestaseși": "cresta",
    "crestași": "cresta",
    "crestat": "cresta",
    "crestați": "cresta",
    "crestatu": "cresta",
    "crestau": "cresta",
    "crestează": "cresta",
    "crestez": "cresta",
    "cresteze": "cresta",
    "crestezi": "cresta",
    "necrestând": "cresta",
    "necrestându": "cresta",
    "nemaicrestând": "cresta",
    "nemaicrestându": "cresta",
    "crestarea": "crestare",
    "crestareo": "crestare",
    "crestări": "crestare",
    "crestării": "crestare",
    "crestările": "crestare",
    "crestărilor": "crestare",
    "crestata": "crestat",
    "crestată": "crestat",
    "crestate": "crestat",
    "crestatei": "crestat",
    "crestatele": "crestat",
    "crestatelor": "crestat",
    "crestați": "crestat",
    "crestații": "crestat",
    "crestaților": "crestat",
    "crestato": "crestat",
    "crestatul": "crestat",
    "crestatule": "crestat",
    "crestatului": "crestat",
    "crestătura": "crestătură",
    "crestături": "crestătură",
    "crestăturii": "crestătură",
    "crestăturile": "crestătură",
    "crestăturilor": "crestătură",
    "crestăturo": "crestătură",
    "crească": "crește",
    "cresc": "crește",
    "crescând": "crește",
    "crescându": "crește",
    "crescu": "crește",
    "crescui": "crește",
    "crescură": "crește",
    "crescurăm": "crește",
    "crescurăți": "crește",
    "crescuse": "crește",
    "crescusem": "crește",
    "crescuseră": "crește",
    "crescuserăm": "crește",
    "crescuserăți": "crește",
    "crescuseși": "crește",
    "crescuși": "crește",
    "crescut": "crește",
    "crescutu": "crește",
    "creștea": "crește",
    "creșteai": "crește",
    "creșteam": "crește",
    "creșteați": "crește",
    "creșteau": "crește",
    "creștem": "crește",
    "creșteți": "crește",
    "crești": "crește",
    "necrescând": "crește",
    "necrescându": "crește",
    "nemaicrescând": "crește",
    "nemaicrescându": "crește",
    "creșterea": "creștere",
    "creștereo": "creștere",
    "creșteri": "creștere",
    "creșterii": "creștere",
    "creșterile": "creștere",
    "creșterilor": "creștere",
    "creștete": "creștet",
    "creștetele": "creștet",
    "creștetelor": "creștet",
    "creștetul": "creștet",
    "creștetule": "creștet",
    "creștetului": "creștet",
    "creștina": "creștin",
    "creștină": "creștin",
    "creștine": "creștin",
    "creștinei": "creștin",
    "creștinele": "creștin",
    "creștinelor": "creștin",
    "creștini": "creștin",
    "creștinii": "creștin",
    "creștinilor": "creștin",
    "creștinul": "creștin",
    "creștinule": "creștin",
    "creștinului": "creștin",
    "creștină": "creștina",
    "creștinai": "creștina",
    "creștinam": "creștina",
    "creștinăm": "creștina",
    "creștinând": "creștina",
    "creștinându": "creștina",
    "creștinară": "creștina",
    "creștinarăm": "creștina",
    "creștinarăți": "creștina",
    "creștinase": "creștina",
    "creștinasem": "creștina",
    "creștinaseră": "creștina",
    "creștinaserăm": "creștina",
    "creștinaserăți": "creștina",
    "creștinaseși": "creștina",
    "creștinași": "creștina",
    "creștinat": "creștina",
    "creștinați": "creștina",
    "creștinatu": "creștina",
    "creștinau": "creștina",
    "creștinează": "creștina",
    "creștinez": "creștina",
    "creștineze": "creștina",
    "creștinezi": "creștina",
    "necreștinând": "creștina",
    "necreștinându": "creștina",
    "nemaicreștinând": "creștina",
    "nemaicreștinându": "creștina",
    "creștina": "creștină",
    "creștine": "creștină",
    "creștinei": "creștină",
    "creștinele": "creștină",
    "creștinelor": "creștină",
    "creștino": "creștină",
    "creștinarea": "creștinare",
    "creștinareo": "creștinare",
    "creștinări": "creștinare",
    "creștinării": "creștinare",
    "creștinările": "creștinare",
    "creștinărilor": "creștinare",
    "creștinată": "creștinat",
    "creștinate": "creștinat",
    "creștinați": "creștinat",
    "creștinătatea": "creștinătate",
    "creștinătateo": "creștinătate",
    "creștinătăți": "creștinătate",
    "creștinătății": "creștinătate",
    "creștinătățile": "creștinătate",
    "creștinătăților": "creștinătate",
    "creștin-culturala": "creștin-cultural",
    "creștin-culturală": "creștin-cultural",
    "creștin-culturale": "creștin-cultural",
    "creștin-culturalei": "creștin-cultural",
    "creștin-culturalele": "creștin-cultural",
    "creștin-culturalelor": "creștin-cultural",
    "creștin-culturali": "creștin-cultural",
    "creștin-culturalii": "creștin-cultural",
    "creștin-culturalilor": "creștin-cultural",
    "creștin-culturalo": "creștin-cultural",
    "creștin-culturalul": "creștin-cultural",
    "creștin-culturalule": "creștin-cultural",
    "creștin-culturalului": "creștin-cultural",
    "creștin-democrata": "creștin-democrat",
    "creștin-democrată": "creștin-democrat",
    "creștin-democrate": "creștin-democrat",
    "creștin-democratei": "creștin-democrat",
    "creștin-democratele": "creștin-democrat",
    "creștin-democratelor": "creștin-democrat",
    "creștin-democrați": "creștin-democrat",
    "creștin-democrații": "creștin-democrat",
    "creștin-democraților": "creștin-democrat",
    "creștin-democrato": "creștin-democrat",
    "creștin-democratul": "creștin-democrat",
    "creștin-democratule": "creștin-democrat",
    "creștin-democratului": "creștin-democrat",
    "creștineasca": "creștinesc",
    "creștinească": "creștinesc",
    "creștinescul": "creștinesc",
    "creștinescule": "creștinesc",
    "creștinescului": "creștinesc",
    "creștinești": "creștinesc",
    "creștineștii": "creștinesc",
    "creștineștile": "creștinesc",
    "creștineștilor": "creștinesc",
    "creștinismul": "creștinism",
    "creștinismule": "creștinism",
    "creștinismului": "creștinism",
    "crestomația": "crestomație",
    "crestomației": "crestomație",
    "crestomații": "crestomație",
    "crestomațiile": "crestomație",
    "crestomațiilor": "crestomație",
    "crestomațio": "crestomație",
    "creața": "creț",
    "creață": "creț",
    "creațo": "creț",
    "crețe": "creț",
    "creței": "creț",
    "crețele": "creț",
    "crețelor": "creț",
    "creți": "creț",
    "creții": "creț",
    "creților": "creț",
    "crețul": "creț",
    "crețule": "creț",
    "crețului": "creț",
    "crețuri": "creț",
    "crețurile": "creț",
    "crețurilor": "creț",
    "creta": "cretă",
    "crete": "cretă",
    "cretei": "cretă",
    "cretele": "cretă",
    "cretelor": "cretă",
    "creto": "cretă",
    "cretacicul": "cretacic",
    "cretacicule": "cretacic",
    "cretacicului": "cretacic",
    "cretana": "cretan",
    "cretană": "cretan",
    "cretane": "cretan",
    "cretanei": "cretan",
    "cretanele": "cretan",
    "cretanelor": "cretan",
    "cretani": "cretan",
    "cretanii": "cretan",
    "cretanilor": "cretan",
    "cretanul": "cretan",
    "cretanului": "cretan",
    "cretana": "cretană",
    "cretane": "cretană",
    "cretanei": "cretană",
    "cretanele": "cretană",
    "cretanelor": "cretană",
    "cretata": "cretat",
    "cretată": "cretat",
    "cretate": "cretat",
    "cretatei": "cretat",
    "cretatele": "cretat",
    "cretatelor": "cretat",
    "cretați": "cretat",
    "cretații": "cretat",
    "cretaților": "cretat",
    "cretato": "cretat",
    "cretatul": "cretat",
    "cretatule": "cretat",
    "cretatului": "cretat",
    "cretina": "cretin",
    "cretină": "cretin",
    "cretine": "cretin",
    "cretinei": "cretin",
    "cretinele": "cretin",
    "cretinelor": "cretin",
    "cretini": "cretin",
    "cretinii": "cretin",
    "cretinilor": "cretin",
    "cretino": "cretin",
    "cretinul": "cretin",
    "cretinule": "cretin",
    "cretinului": "cretin",
    "cretina": "cretină",
    "cretine": "cretină",
    "cretinei": "cretină",
    "cretinele": "cretină",
    "cretinelor": "cretină",
    "cretino": "cretină",
    "creuzete": "creuzet",
    "creuzetele": "creuzet",
    "creuzetelor": "creuzet",
    "creuzetul": "creuzet",
    "creuzetule": "creuzet",
    "creuzetului": "creuzet",
    "creveta": "crevetă",
    "crevete": "crevetă",
    "crevetei": "crevetă",
    "crevetele": "crevetă",
    "crevetelor": "crevetă",
    "creveto": "crevetă",
    "crezul": "crez",
    "crezule": "crez",
    "crezului": "crez",
    "crezuri": "crez",
    "crezurile": "crez",
    "crezurilor": "crez",
    "crezământul": "crezământ",
    "crezământule": "crezământ",
    "crezământului": "crezământ",
    "crezăminte": "crezământ",
    "crezămintele": "crezământ",
    "crezămintelor": "crezământ",
    "crezarea": "crezare",
    "crezareo": "crezare",
    "crezări": "crezare",
    "crezării": "crezare",
    "crezările": "crezare",
    "crezărilor": "crezare",
    "crezută": "crezut",
    "crezute": "crezut",
    "crezuți": "crezut",
    "criblura": "criblură",
    "cribluri": "criblură",
    "criblurii": "criblură",
    "criblurile": "criblură",
    "criblurilor": "criblură",
    "cribluro": "criblură",
    "cricul": "cric",
    "cricule": "cric",
    "cricului": "cric",
    "cricuri": "cric",
    "cricurile": "cric",
    "cricurilor": "cric",
    "crichetul": "crichet",
    "crichetule": "crichet",
    "crichetului": "crichet",
    "crima": "crimă",
    "crime": "crimă",
    "crimei": "crimă",
    "crimele": "crimă",
    "crimelor": "crimă",
    "crimo": "crimă",
    "crimăgânditul": "crimăgândit",
    "Crimee": "Crimeea",
    "Crimeei": "Crimeea",
    "cri-mi-nal": "criminal",
    "criminala": "criminal",
    "criminală": "criminal",
    "criminale": "criminal",
    "criminalei": "criminal",
    "criminalele": "criminal",
    "criminalelor": "criminal",
    "criminali": "criminal",
    "criminalii": "criminal",
    "criminalilor": "criminal",
    "criminalul": "criminal",
    "criminalule": "criminal",
    "criminalului": "criminal",
    "criminala": "criminală",
    "criminale": "criminală",
    "criminalei": "criminală",
    "criminalele": "criminală",
    "criminalelor": "criminală",
    "criminalo": "criminală",
    "criminalista": "criminalist",
    "criminalistă": "criminalist",
    "criminaliste": "criminalist",
    "criminalistei": "criminalist",
    "criminalistele": "criminalist",
    "criminalistelor": "criminalist",
    "criminaliști": "criminalist",
    "criminaliștii": "criminalist",
    "criminaliștilor": "criminalist",
    "criminalistul": "criminalist",
    "criminalistului": "criminalist",
    "criminalista": "criminalistă",
    "criminaliste": "criminalistă",
    "criminalistei": "criminalistă",
    "criminalistele": "criminalistă",
    "criminalistelor": "criminalistă",
    "criminalistica": "criminalistică",
    "criminalistici": "criminalistică",
    "criminalitatea": "criminalitate",
    "criminalitateo": "criminalitate",
    "criminalități": "criminalitate",
    "criminalității": "criminalitate",
    "criminologia": "criminologie",
    "criminologiei": "criminologie",
    "criminologii": "criminologie",
    "criminologiile": "criminologie",
    "criminologiilor": "criminologie",
    "criminologio": "criminologie",
    "crini": "crin",
    "crinii": "crin",
    "crinilor": "crin",
    "crinul": "crin",
    "crinule": "crin",
    "crinului": "crin",
    "crinolina": "crinolină",
    "crinoline": "crinolină",
    "crinolinei": "crinolină",
    "crinolinele": "crinolină",
    "crinolinelor": "crinolină",
    "crinolino": "crinolină",
    "criolitul": "criolit",
    "criolitule": "criolit",
    "criolitului": "criolit",
    "crioscopia": "crioscopie",
    "crioscopiei": "crioscopie",
    "crioscopii": "crioscopie",
    "crioscopiile": "crioscopie",
    "crioscopiilor": "crioscopie",
    "crioscopio": "crioscopie",
    "cripta": "criptă",
    "cripte": "criptă",
    "criptei": "criptă",
    "criptele": "criptă",
    "criptelor": "criptă",
    "cripto": "criptă",
    "criptica": "criptic",
    "criptică": "criptic",
    "criptice": "criptic",
    "cripticei": "criptic",
    "cripticele": "criptic",
    "cripticelor": "criptic",
    "criptici": "criptic",
    "cripticii": "criptic",
    "cripticilor": "criptic",
    "criptico": "criptic",
    "cripticul": "criptic",
    "cripticule": "criptic",
    "cripticului": "criptic",
    "criptogama": "criptogamă",
    "criptogame": "criptogamă",
    "criptogamei": "criptogamă",
    "criptogamele": "criptogamă",
    "criptogamelor": "criptogamă",
    "criptogamo": "criptogamă",
    "criptografica": "criptografic",
    "criptografică": "criptografic",
    "criptografice": "criptografic",
    "criptograficei": "criptografic",
    "criptograficele": "criptografic",
    "criptograficelor": "criptografic",
    "criptografici": "criptografic",
    "criptograficii": "criptografic",
    "criptograficilor": "criptografic",
    "criptografico": "criptografic",
    "criptograficul": "criptografic",
    "criptograficule": "criptografic",
    "criptograficului": "criptografic",
    "criptografia": "criptografie",
    "criptografiei": "criptografie",
    "criptografii": "criptografie",
    "criptografiile": "criptografie",
    "criptografiilor": "criptografie",
    "criptografio": "criptografie",
    "criptograma": "criptogramă",
    "criptograme": "criptogramă",
    "criptogramei": "criptogramă",
    "criptogramele": "criptogramă",
    "criptogramelor": "criptogramă",
    "criptogramo": "criptogramă",
    "crisalida": "crisalidă",
    "crisalide": "crisalidă",
    "crisalidei": "crisalidă",
    "crisalidele": "crisalidă",
    "crisalidelor": "crisalidă",
    "crisalido": "crisalidă",
    "crispă": "crispa",
    "crispai": "crispa",
    "crispam": "crispa",
    "crispăm": "crispa",
    "crispând": "crispa",
    "crispându": "crispa",
    "crispară": "crispa",
    "crisparăm": "crispa",
    "crisparăți": "crispa",
    "crispase": "crispa",
    "crispasem": "crispa",
    "crispaseră": "crispa",
    "crispaserăm": "crispa",
    "crispaserăți": "crispa",
    "crispaseși": "crispa",
    "crispași": "crispa",
    "crispat": "crispa",
    "crispați": "crispa",
    "crispatu": "crispa",
    "crispau": "crispa",
    "crispează": "crispa",
    "crispez": "crispa",
    "crispeze": "crispa",
    "crispezi": "crispa",
    "necrispând": "crispa",
    "necrispându": "crispa",
    "nemaicrispând": "crispa",
    "nemaicrispându": "crispa",
    "crisparea": "crispare",
    "crispareo": "crispare",
    "crispări": "crispare",
    "crispării": "crispare",
    "crispările": "crispare",
    "crispărilor": "crispare",
    "crispata": "crispat",
    "crispată": "crispat",
    "crispate": "crispat",
    "crispatei": "crispat",
    "crispatele": "crispat",
    "crispatelor": "crispat",
    "crispați": "crispat",
    "crispații": "crispat",
    "crispaților": "crispat",
    "crispato": "crispat",
    "crispatul": "crispat",
    "crispatule": "crispat",
    "crispatului": "crispat",
    "cristale": "cristal",
    "cristalele": "cristal",
    "cristalelor": "cristal",
    "cristalul": "cristal",
    "cristalule": "cristal",
    "cristalului": "cristal",
    "cristaluri": "cristal",
    "cristalurile": "cristal",
    "cristalurilor": "cristal",
    "cristalina": "cristalin",
    "cristalină": "cristalin",
    "cristaline": "cristalin",
    "cristalinei": "cristalin",
    "cristalinele": "cristalin",
    "cristalinelor": "cristalin",
    "cristalini": "cristalin",
    "cristalinii": "cristalin",
    "cristalinilor": "cristalin",
    "cristalino": "cristalin",
    "cristalinul": "cristalin",
    "cristalinule": "cristalin",
    "cristalinului": "cristalin",
    "cristalinuri": "cristalin",
    "cristalinurile": "cristalin",
    "cristalinurilor": "cristalin",
    "cristaliză": "cristaliza",
    "cristalizai": "cristaliza",
    "cristalizam": "cristaliza",
    "cristalizăm": "cristaliza",
    "cristalizând": "cristaliza",
    "cristalizându": "cristaliza",
    "cristalizară": "cristaliza",
    "cristalizarăm": "cristaliza",
    "cristalizarăți": "cristaliza",
    "cristalizase": "cristaliza",
    "cristalizasem": "cristaliza",
    "cristalizaseră": "cristaliza",
    "cristalizaserăm": "cristaliza",
    "cristalizaserăți": "cristaliza",
    "cristalizaseși": "cristaliza",
    "cristalizași": "cristaliza",
    "cristalizat": "cristaliza",
    "cristalizați": "cristaliza",
    "cristalizatu": "cristaliza",
    "cristalizau": "cristaliza",
    "cristalizează": "cristaliza",
    "cristalizez": "cristaliza",
    "cristalizeze": "cristaliza",
    "cristalizezi": "cristaliza",
    "necristalizând": "cristaliza",
    "necristalizându": "cristaliza",
    "nemaicristalizând": "cristaliza",
    "nemaicristalizându": "cristaliza",
    "cristalizarea": "cristalizare",
    "cristalizareo": "cristalizare",
    "cristalizări": "cristalizare",
    "cristalizării": "cristalizare",
    "cristalizările": "cristalizare",
    "cristalizărilor": "cristalizare",
    "cristalizată": "cristalizat",
    "cristalizate": "cristalizat",
    "cristalizați": "cristalizat",
    "cristalizoare": "cristalizor",
    "cristalizoarele": "cristalizor",
    "cristalizoarelor": "cristalizor",
    "cristalizorul": "cristalizor",
    "cristalizorule": "cristalizor",
    "cristalizorului": "cristalizor",
    "cristalografia": "cristalografie",
    "cristalografiei": "cristalografie",
    "cristalografii": "cristalografie",
    "cristalografiile": "cristalografie",
    "cristalografiilor": "cristalografie",
    "cristalografio": "cristalografie",
    "cristaloida": "cristaloid",
    "cristaloidă": "cristaloid",
    "cristaloide": "cristaloid",
    "cristaloidei": "cristaloid",
    "cristaloidele": "cristaloid",
    "cristaloidelor": "cristaloid",
    "cristaloido": "cristaloid",
    "cristaloidul": "cristaloid",
    "cristaloidule": "cristaloid",
    "cristaloidului": "cristaloid",
    "cristaloizi": "cristaloid",
    "cristaloizii": "cristaloid",
    "cristaloizilor": "cristaloid",
    "cristelnița": "cristelniță",
    "cristelnițe": "cristelniță",
    "cristelniței": "cristelniță",
    "cristelnițele": "cristelniță",
    "cristelnițelor": "cristelniță",
    "cristelnițo": "cristelniță",
    "Cristianei": "Cristiana",
    "cristica": "cristic",
    "cristică": "cristic",
    "cristice": "cristic",
    "cristicei": "cristic",
    "cristicele": "cristic",
    "cristicelor": "cristic",
    "cristici": "cristic",
    "cristicii": "cristic",
    "cristicilor": "cristic",
    "cristico": "cristic",
    "cristicul": "cristic",
    "cristicule": "cristic",
    "cristicului": "cristic",
    "Cristine": "Cristina",
    "Cristinei": "Cristina",
    "criterii": "criteriu",
    "criteriile": "criteriu",
    "criteriilor": "criteriu",
    "criteriul": "criteriu",
    "criteriule": "criteriu",
    "criteriului": "criteriu",
    "critica": "critic",
    "critică": "critic",
    "critice": "critic",
    "criticei": "critic",
    "criticele": "critic",
    "criticelor": "critic",
    "critici": "critic",
    "criticii": "critic",
    "criticilor": "critic",
    "critico": "critic",
    "criticul": "critic",
    "criticule": "critic",
    "criticului": "critic",
    "critic": "critica",
    "critică": "critica",
    "criticai": "critica",
    "criticam": "critica",
    "criticăm": "critica",
    "criticând": "critica",
    "criticându": "critica",
    "criticară": "critica",
    "criticarăm": "critica",
    "criticarăți": "critica",
    "criticase": "critica",
    "criticasem": "critica",
    "criticaseră": "critica",
    "criticaserăm": "critica",
    "criticaserăți": "critica",
    "criticaseși": "critica",
    "criticași": "critica",
    "criticat": "critica",
    "criticați": "critica",
    "criticatu": "critica",
    "criticau": "critica",
    "critice": "critica",
    "critici": "critica",
    "necriticând": "critica",
    "necriticându": "critica",
    "nemaicriticând": "critica",
    "nemaicriticându": "critica",
    "critica": "critică",
    "critici": "critică",
    "criticii": "critică",
    "criticile": "critică",
    "criticilor": "critică",
    "critico": "critică",
    "criticabila": "criticabil",
    "criticabilă": "criticabil",
    "criticabile": "criticabil",
    "criticabilei": "criticabil",
    "criticabilele": "criticabil",
    "criticabilelor": "criticabil",
    "criticabili": "criticabil",
    "criticabilii": "criticabil",
    "criticabililor": "criticabil",
    "criticabilo": "criticabil",
    "criticabilul": "criticabil",
    "criticabilule": "criticabil",
    "criticabilului": "criticabil",
    "criticarea": "criticare",
    "criticareo": "criticare",
    "criticări": "criticare",
    "criticării": "criticare",
    "criticările": "criticare",
    "criticărilor": "criticare",
    "criticată": "criticat",
    "criticate": "criticat",
    "criticați": "criticat",
    "crivățul": "crivăț",
    "crivățule": "crivăț",
    "crivățului": "crivăț",
    "criza": "criză",
    "crize": "criză",
    "crizei": "criză",
    "crizele": "criză",
    "crizelor": "criză",
    "crizo": "criză",
    "crizantema": "crizantemă",
    "crizanteme": "crizantemă",
    "crizantemei": "crizantemă",
    "crizantemele": "crizantemă",
    "crizantemelor": "crizantemă",
    "crizantemo": "crizantemă",
    "croată": "croat",
    "croați": "croat",
    "croații": "croat",
    "croaților": "croat",
    "croatul": "croat",
    "croatule": "croat",
    "croatului": "croat",
    "croata": "croată",
    "croate": "croată",
    "croatei": "croată",
    "croatele": "croată",
    "croatelor": "croată",
    "croato": "croată",
    "Croație": "Croația",
    "Croației": "Croația",
    "croaziera": "croazieră",
    "croaziere": "croazieră",
    "croazierei": "croazieră",
    "croazierele": "croazieră",
    "croazierelor": "croazieră",
    "croaziero": "croazieră",
    "crochetul": "crochet",
    "crochetule": "crochet",
    "crochetului": "crochet",
    "crocheta": "crochetă",
    "crochete": "crochetă",
    "crochetei": "crochetă",
    "crochetele": "crochetă",
    "crochetelor": "crochetă",
    "crocheto": "crochetă",
    "crochiul": "crochiu",
    "crochiule": "crochiu",
    "crochiului": "crochiu",
    "crochiuri": "crochiu",
    "crochiurile": "crochiu",
    "crochiurilor": "crochiu",
    "crocodili": "crocodil",
    "crocodilii": "crocodil",
    "crocodililor": "crocodil",
    "crocodilul": "crocodil",
    "crocodilule": "crocodil",
    "crocodilului": "crocodil",
    "croia": "croi",
    "croiai": "croi",
    "croiam": "croi",
    "croiască": "croi",
    "croiați": "croi",
    "croiau": "croi",
    "croiesc": "croi",
    "croiește": "croi",
    "croiești": "croi",
    "croii": "croi",
    "croim": "croi",
    "croind": "croi",
    "croindu": "croi",
    "croiră": "croi",
    "croirăm": "croi",
    "croirăți": "croi",
    "croise": "croi",
    "croisem": "croi",
    "croiseră": "croi",
    "croiserăm": "croi",
    "croiserăți": "croi",
    "croiseși": "croi",
    "croiși": "croi",
    "croit": "croi",
    "croiți": "croi",
    "croitu": "croi",
    "necroind": "croi",
    "necroindu": "croi",
    "nemaicroind": "croi",
    "nemaicroindu": "croi",
    "croiala": "croială",
    "croialo": "croială",
    "croieli": "croială",
    "croielii": "croială",
    "croielile": "croială",
    "croielilor": "croială",
    "croită": "croit",
    "croite": "croit",
    "croiți": "croit",
    "croitul": "croit",
    "croitule": "croit",
    "croitului": "croit",
    "croitori": "croitor",
    "croitorii": "croitor",
    "croitorilor": "croitor",
    "croitorul": "croitor",
    "croitorule": "croitor",
    "croitorului": "croitor",
    "croitoreasa": "croitoreasă",
    "croitoreaso": "croitoreasă",
    "croitorese": "croitoreasă",
    "croitoresei": "croitoreasă",
    "croitoresele": "croitoreasă",
    "croitoreselor": "croitoreasă",
    "Cr": "crom",
    "cromul": "crom",
    "cromule": "crom",
    "cromului": "crom",
    "cromă": "croma",
    "cromai": "croma",
    "cromam": "croma",
    "cromăm": "croma",
    "cromând": "croma",
    "cromându": "croma",
    "cromară": "croma",
    "cromarăm": "croma",
    "cromarăți": "croma",
    "cromase": "croma",
    "cromasem": "croma",
    "cromaseră": "croma",
    "cromaserăm": "croma",
    "cromaserăți": "croma",
    "cromaseși": "croma",
    "cromași": "croma",
    "cromat": "croma",
    "cromați": "croma",
    "cromatu": "croma",
    "cromau": "croma",
    "cromează": "croma",
    "cromez": "croma",
    "cromeze": "croma",
    "cromezi": "croma",
    "necromând": "croma",
    "necromându": "croma",
    "nemaicromând": "croma",
    "nemaicromându": "croma",
    "cromaje": "cromaj",
    "cromajele": "cromaj",
    "cromajelor": "cromaj",
    "cromajul": "cromaj",
    "cromajule": "cromaj",
    "cromajului": "cromaj",
    "cromarea": "cromare",
    "cromareo": "cromare",
    "cromări": "cromare",
    "cromării": "cromare",
    "cromările": "cromare",
    "cromărilor": "cromare",
    "cromata": "cromat",
    "cromată": "cromat",
    "cromate": "cromat",
    "cromatei": "cromat",
    "cromatele": "cromat",
    "cromatelor": "cromat",
    "cromați": "cromat",
    "cromații": "cromat",
    "cromaților": "cromat",
    "cromato": "cromat",
    "cromatul": "cromat",
    "cromatule": "cromat",
    "cromatului": "cromat",
    "cromatica": "cromatic",
    "cromatică": "cromatic",
    "cromatice": "cromatic",
    "cromaticei": "cromatic",
    "cromaticele": "cromatic",
    "cromaticelor": "cromatic",
    "cromatici": "cromatic",
    "cromaticii": "cromatic",
    "cromaticilor": "cromatic",
    "cromatico": "cromatic",
    "cromaticul": "cromatic",
    "cromaticule": "cromatic",
    "cromaticului": "cromatic",
    "cromatica": "cromatică",
    "cromatici": "cromatică",
    "cromaticii": "cromatică",
    "cromaticile": "cromatică",
    "cromaticilor": "cromatică",
    "cromatico": "cromatică",
    "cromatismul": "cromatism",
    "cromatismule": "cromatism",
    "cromatismului": "cromatism",
    "cromatografia": "cromatografie",
    "cromatografiei": "cromatografie",
    "cromatografii": "cromatografie",
    "cromatografiile": "cromatografie",
    "cromatografiilor": "cromatografie",
    "cromatografio": "cromatografie",
    "cromofori": "cromofor",
    "cromoforii": "cromofor",
    "cromoforilor": "cromofor",
    "cromoforul": "cromofor",
    "cromoforule": "cromofor",
    "cromoforului": "cromofor",
    "cromofotografia": "cromofotografie",
    "cromofotografiei": "cromofotografie",
    "cromofotografii": "cromofotografie",
    "cromofotografiile": "cromofotografie",
    "cromofotografiilor": "cromofotografie",
    "cromofotografio": "cromofotografie",
    "cromolitografica": "cromolitografic",
    "cromolitografică": "cromolitografic",
    "cromolitografice": "cromolitografic",
    "cromolitograficei": "cromolitografic",
    "cromolitograficele": "cromolitografic",
    "cromolitograficelor": "cromolitografic",
    "cromolitografici": "cromolitografic",
    "cromolitograficii": "cromolitografic",
    "cromolitograficilor": "cromolitografic",
    "cromolitografico": "cromolitografic",
    "cromolitograficul": "cromolitografic",
    "cromolitograficule": "cromolitografic",
    "cromolitograficului": "cromolitografic",
    "cromolitografia": "cromolitografie",
    "cromolitografiei": "cromolitografie",
    "cromolitografii": "cromolitografie",
    "cromolitografiile": "cromolitografie",
    "cromolitografiilor": "cromolitografie",
    "cromolitografio": "cromolitografie",
    "cromosfera": "cromosferă",
    "cromosfere": "cromosferă",
    "cromosferei": "cromosferă",
    "cromosferele": "cromosferă",
    "cromosferelor": "cromosferă",
    "cromosfero": "cromosferă",
    "cromotipia": "cromotipie",
    "cromotipiei": "cromotipie",
    "cromotipii": "cromotipie",
    "cromotipiile": "cromotipie",
    "cromotipiilor": "cromotipie",
    "cromotipio": "cromotipie",
    "cromozomi": "cromozom",
    "cromozomii": "cromozom",
    "cromozomilor": "cromozom",
    "cromozomul": "cromozom",
    "cromozomule": "cromozom",
    "cromozomului": "cromozom",
    "croncănea": "croncăni",
    "croncăneai": "croncăni",
    "croncăneam": "croncăni",
    "croncănească": "croncăni",
    "croncăneați": "croncăni",
    "croncăneau": "croncăni",
    "croncănesc": "croncăni",
    "croncănește": "croncăni",
    "croncănești": "croncăni",
    "croncănii": "croncăni",
    "croncănim": "croncăni",
    "croncănind": "croncăni",
    "croncănindu": "croncăni",
    "croncăniră": "croncăni",
    "croncănirăm": "croncăni",
    "croncănirăți": "croncăni",
    "croncănise": "croncăni",
    "croncănisem": "croncăni",
    "croncăniseră": "croncăni",
    "croncăniserăm": "croncăni",
    "croncăniserăți": "croncăni",
    "croncăniseși": "croncăni",
    "croncăniși": "croncăni",
    "croncănit": "croncăni",
    "croncăniți": "croncăni",
    "croncănitu": "croncăni",
    "necroncănind": "croncăni",
    "necroncănindu": "croncăni",
    "nemaicroncănind": "croncăni",
    "nemaicroncănindu": "croncăni",
    "croncănirea": "croncănire",
    "croncănireo": "croncănire",
    "croncăniri": "croncănire",
    "croncănirii": "croncănire",
    "croncănirile": "croncănire",
    "croncănirilor": "croncănire",
    "croncănită": "croncănit",
    "croncănite": "croncănit",
    "croncăniți": "croncănit",
    "croncănitul": "croncănit",
    "croncănitule": "croncănit",
    "croncănitului": "croncănit",
    "croncănitoare": "croncănitor",
    "croncănitoarea": "croncănitor",
    "croncănitoarei": "croncănitor",
    "croncănitoarele": "croncănitor",
    "croncănitoarelor": "croncănitor",
    "croncănitoareo": "croncănitor",
    "croncănitori": "croncănitor",
    "croncănitorii": "croncănitor",
    "croncănitorilor": "croncănitor",
    "croncănitorul": "croncănitor",
    "croncănitorule": "croncănitor",
    "croncănitorului": "croncănitor",
    "croncănitura": "croncănitură",
    "croncănituri": "croncănitură",
    "croncăniturii": "croncănitură",
    "croncăniturile": "croncănitură",
    "croncăniturilor": "croncănitură",
    "croncănituro": "croncănitură",
    "cronica": "cronic",
    "cronică": "cronic",
    "cronice": "cronic",
    "cronicei": "cronic",
    "cronicele": "cronic",
    "cronicelor": "cronic",
    "cronici": "cronic",
    "cronicii": "cronic",
    "cronicilor": "cronic",
    "cronico": "cronic",
    "cronicul": "cronic",
    "cronicule": "cronic",
    "cronicului": "cronic",
    "cronica": "cronică",
    "cronici": "cronică",
    "cronicii": "cronică",
    "cronicile": "cronică",
    "cronicilor": "cronică",
    "cronico": "cronică",
    "cronicari": "cronicar",
    "cronicarii": "cronicar",
    "cronicarilor": "cronicar",
    "cronicarul": "cronicar",
    "cronicarule": "cronicar",
    "cronicarului": "cronicar",
    "cronicăreasca": "cronicăresc",
    "cronicărească": "cronicăresc",
    "cronicăreasco": "cronicăresc",
    "cronicărescul": "cronicăresc",
    "cronicărescule": "cronicăresc",
    "cronicărescului": "cronicăresc",
    "cronicărești": "cronicăresc",
    "cronicăreștii": "cronicăresc",
    "cronicăreștile": "cronicăresc",
    "cronicăreștilor": "cronicăresc",
    "cronografe": "cronograf",
    "cronografele": "cronograf",
    "cronografelor": "cronograf",
    "cronografi": "cronograf",
    "cronografii": "cronograf",
    "cronografilor": "cronograf",
    "cronograful": "cronograf",
    "cronografule": "cronograf",
    "cronografului": "cronograf",
    "cronologica": "cronologic",
    "cronologică": "cronologic",
    "cronologice": "cronologic",
    "cronologicei": "cronologic",
    "cronologicele": "cronologic",
    "cronologicelor": "cronologic",
    "cronologici": "cronologic",
    "cronologicii": "cronologic",
    "cronologicilor": "cronologic",
    "cronologico": "cronologic",
    "cronologicul": "cronologic",
    "cronologicule": "cronologic",
    "cronologicului": "cronologic",
    "cronologia": "cronologie",
    "cronologiei": "cronologie",
    "cronologii": "cronologie",
    "cronologiile": "cronologie",
    "cronologiilor": "cronologie",
    "cronologio": "cronologie",
    "cronometră": "cronometra",
    "cronometrai": "cronometra",
    "cronometram": "cronometra",
    "cronometrăm": "cronometra",
    "cronometrând": "cronometra",
    "cronometrându": "cronometra",
    "cronometrară": "cronometra",
    "cronometrarăm": "cronometra",
    "cronometrarăți": "cronometra",
    "cronometrase": "cronometra",
    "cronometrasem": "cronometra",
    "cronometraseră": "cronometra",
    "cronometraserăm": "cronometra",
    "cronometraserăți": "cronometra",
    "cronometraseși": "cronometra",
    "cronometrași": "cronometra",
    "cronometrat": "cronometra",
    "cronometrați": "cronometra",
    "cronometratu": "cronometra",
    "cronometrau": "cronometra",
    "cronometrează": "cronometra",
    "cronometrez": "cronometra",
    "cronometreze": "cronometra",
    "cronometrezi": "cronometra",
    "necronometrând": "cronometra",
    "necronometrându": "cronometra",
    "nemaicronometrând": "cronometra",
    "nemaicronometrându": "cronometra",
    "cronometraje": "cronometraj",
    "cronometrajele": "cronometraj",
    "cronometrajelor": "cronometraj",
    "cronometrajul": "cronometraj",
    "cronometrajule": "cronometraj",
    "cronometrajului": "cronometraj",
    "cronometrarea": "cronometrare",
    "cronometrareo": "cronometrare",
    "cronometrări": "cronometrare",
    "cronometrării": "cronometrare",
    "cronometrările": "cronometrare",
    "cronometrărilor": "cronometrare",
    "cronometrată": "cronometrat",
    "cronometrate": "cronometrat",
    "cronometrați": "cronometrat",
    "cronometrica": "cronometric",
    "cronometrică": "cronometric",
    "cronometrice": "cronometric",
    "cronometricei": "cronometric",
    "cronometricele": "cronometric",
    "cronometricelor": "cronometric",
    "cronometrici": "cronometric",
    "cronometricii": "cronometric",
    "cronometricilor": "cronometric",
    "cronometrico": "cronometric",
    "cronometricul": "cronometric",
    "cronometricule": "cronometric",
    "cronometricului": "cronometric",
    "cronometria": "cronometrie",
    "cronometriei": "cronometrie",
    "cronometrii": "cronometrie",
    "cronometriile": "cronometrie",
    "cronometriilor": "cronometrie",
    "cronometrio": "cronometrie",
    "cronometrori": "cronometror",
    "cronometrorii": "cronometror",
    "cronometrorilor": "cronometror",
    "cronometrorul": "cronometror",
    "cronometrorule": "cronometror",
    "cronometrorului": "cronometror",
    "cronometre": "cronometru",
    "cronometrele": "cronometru",
    "cronometrelor": "cronometru",
    "cronometrul": "cronometru",
    "cronometrule": "cronometru",
    "cronometrului": "cronometru",
    "crosul": "cros",
    "crosule": "cros",
    "crosului": "cros",
    "crosuri": "cros",
    "crosurile": "cros",
    "crosurilor": "cros",
    "crosa": "crosă",
    "crose": "crosă",
    "crosei": "crosă",
    "crosele": "crosă",
    "croselor": "crosă",
    "croso": "crosă",
    "croșetă": "croșeta",
    "croșetai": "croșeta",
    "croșetam": "croșeta",
    "croșetăm": "croșeta",
    "croșetând": "croșeta",
    "croșetându": "croșeta",
    "croșetară": "croșeta",
    "croșetarăm": "croșeta",
    "croșetarăți": "croșeta",
    "croșetase": "croșeta",
    "croșetasem": "croșeta",
    "croșetaseră": "croșeta",
    "croșetaserăm": "croșeta",
    "croșetaserăți": "croșeta",
    "croșetaseși": "croșeta",
    "croșetași": "croșeta",
    "croșetat": "croșeta",
    "croșetați": "croșeta",
    "croșetatu": "croșeta",
    "croșetau": "croșeta",
    "croșetează": "croșeta",
    "croșetez": "croșeta",
    "croșeteze": "croșeta",
    "croșetezi": "croșeta",
    "necroșetând": "croșeta",
    "necroșetându": "croșeta",
    "nemaicroșetând": "croșeta",
    "nemaicroșetându": "croșeta",
    "croșeta": "croșetă",
    "croșete": "croșetă",
    "croșetei": "croșetă",
    "croșetele": "croșetă",
    "croșetelor": "croșetă",
    "croșeto": "croșetă",
    "croșetată": "croșetat",
    "croșetate": "croșetat",
    "croșetați": "croșetat",
    "croșetatul": "croșetat",
    "croșetatule": "croșetat",
    "croșetatului": "croșetat",
    "crotale": "crotal",
    "crotalele": "crotal",
    "crotalelor": "crotal",
    "crotali": "crotal",
    "crotalii": "crotal",
    "crotalilor": "crotal",
    "crotalul": "crotal",
    "crotalule": "crotal",
    "crotalului": "crotal",
    "crucea": "cruce",
    "cruceo": "cruce",
    "cruci": "cruce",
    "crucii": "cruce",
    "crucile": "cruce",
    "crucilor": "cruce",
    "crucea": "cruci",
    "cruceai": "cruci",
    "cruceam": "cruci",
    "crucească": "cruci",
    "cruceați": "cruci",
    "cruceau": "cruci",
    "crucesc": "cruci",
    "crucește": "cruci",
    "crucești": "cruci",
    "crucii": "cruci",
    "crucim": "cruci",
    "crucind": "cruci",
    "crucindu": "cruci",
    "cruciră": "cruci",
    "crucirăm": "cruci",
    "crucirăți": "cruci",
    "crucise": "cruci",
    "crucisem": "cruci",
    "cruciseră": "cruci",
    "cruciserăm": "cruci",
    "cruciserăți": "cruci",
    "cruciseși": "cruci",
    "cruciși": "cruci",
    "crucit": "cruci",
    "cruciți": "cruci",
    "crucitu": "cruci",
    "necrucind": "cruci",
    "necrucindu": "cruci",
    "nemaicrucind": "cruci",
    "nemaicrucindu": "cruci",
    "cruciada": "cruciadă",
    "cruciade": "cruciadă",
    "cruciadei": "cruciadă",
    "cruciadele": "cruciadă",
    "cruciadelor": "cruciadă",
    "cruciado": "cruciadă",
    "cruciala": "crucial",
    "crucială": "crucial",
    "cruciale": "crucial",
    "crucialei": "crucial",
    "crucialele": "crucial",
    "crucialelor": "crucial",
    "cruciali": "crucial",
    "crucialii": "crucial",
    "crucialilor": "crucial",
    "crucialo": "crucial",
    "crucialul": "crucial",
    "crucialule": "crucial",
    "crucialului": "crucial",
    "cruciați": "cruciat",
    "cruciații": "cruciat",
    "cruciaților": "cruciat",
    "cruciatul": "cruciat",
    "cruciatule": "cruciat",
    "cruciatului": "cruciat",
    "crucifera": "cruciferă",
    "crucifere": "cruciferă",
    "cruciferei": "cruciferă",
    "cruciferele": "cruciferă",
    "cruciferelor": "cruciferă",
    "crucifero": "cruciferă",
    "crucific": "crucifica",
    "crucifică": "crucifica",
    "crucificai": "crucifica",
    "crucificam": "crucifica",
    "crucificăm": "crucifica",
    "crucificând": "crucifica",
    "crucificându": "crucifica",
    "crucificară": "crucifica",
    "crucificarăm": "crucifica",
    "crucificarăți": "crucifica",
    "crucificase": "crucifica",
    "crucificasem": "crucifica",
    "crucificaseră": "crucifica",
    "crucificaserăm": "crucifica",
    "crucificaserăți": "crucifica",
    "crucificaseși": "crucifica",
    "crucificași": "crucifica",
    "crucificat": "crucifica",
    "crucificați": "crucifica",
    "crucificatu": "crucifica",
    "crucificau": "crucifica",
    "crucifice": "crucifica",
    "crucifici": "crucifica",
    "necrucificând": "crucifica",
    "necrucificându": "crucifica",
    "nemaicrucificând": "crucifica",
    "nemaicrucificându": "crucifica",
    "crucificarea": "crucificare",
    "crucificareo": "crucificare",
    "crucificări": "crucificare",
    "crucificării": "crucificare",
    "crucificările": "crucificare",
    "crucificărilor": "crucificare",
    "crucificată": "crucificat",
    "crucificate": "crucificat",
    "crucificați": "crucificat",
    "crucifixe": "crucifix",
    "crucifixele": "crucifix",
    "crucifixelor": "crucifix",
    "crucifixul": "crucifix",
    "crucifixule": "crucifix",
    "crucifixului": "crucifix",
    "cruciforma": "cruciform",
    "cruciformă": "cruciform",
    "cruciforme": "cruciform",
    "cruciformei": "cruciform",
    "cruciformele": "cruciform",
    "cruciformelor": "cruciform",
    "cruciformi": "cruciform",
    "cruciformii": "cruciform",
    "cruciformilor": "cruciform",
    "cruciformo": "cruciform",
    "cruciformul": "cruciform",
    "cruciformule": "cruciform",
    "cruciformului": "cruciform",
    "crucișa": "cruciș",
    "crucișă": "cruciș",
    "crucișe": "cruciș",
    "crucișei": "cruciș",
    "crucișele": "cruciș",
    "crucișelor": "cruciș",
    "cruciși": "cruciș",
    "crucișii": "cruciș",
    "crucișilor": "cruciș",
    "crucișo": "cruciș",
    "crucișul": "cruciș",
    "crucișule": "cruciș",
    "crucișului": "cruciș",
    "crucișătoare": "crucișător",
    "crucișătoarele": "crucișător",
    "crucișătoarelor": "crucișător",
    "crucișătorul": "crucișător",
    "crucișătorule": "crucișător",
    "crucișătorului": "crucișător",
    "crucita": "crucit",
    "crucită": "crucit",
    "crucite": "crucit",
    "crucitei": "crucit",
    "crucitele": "crucit",
    "crucitelor": "crucit",
    "cruciți": "crucit",
    "cruciții": "crucit",
    "cruciților": "crucit",
    "crucito": "crucit",
    "crucitul": "crucit",
    "crucitule": "crucit",
    "crucitului": "crucit",
    "cruciulița": "cruciuliță",
    "cruciulițe": "cruciuliță",
    "cruciuliței": "cruciuliță",
    "cruciulițele": "cruciuliță",
    "cruciulițelor": "cruciuliță",
    "cruciulițo": "cruciuliță",
    "cruda": "crud",
    "crudă": "crud",
    "crude": "crud",
    "crudei": "crud",
    "crudele": "crud",
    "crudelor": "crud",
    "crudo": "crud",
    "crudul": "crud",
    "crudule": "crud",
    "crudului": "crud",
    "cruzi": "crud",
    "cruzii": "crud",
    "cruzilor": "crud",
    "crugul": "crug",
    "crugule": "crug",
    "crugului": "crug",
    "cruguri": "crug",
    "crugurile": "crug",
    "crugurilor": "crug",
    "crunta": "crunt",
    "cruntă": "crunt",
    "crunte": "crunt",
    "cruntei": "crunt",
    "cruntele": "crunt",
    "cruntelor": "crunt",
    "crunți": "crunt",
    "crunții": "crunt",
    "crunților": "crunt",
    "crunto": "crunt",
    "cruntul": "crunt",
    "cruntule": "crunt",
    "cruntului": "crunt",
    "crupa": "crupă",
    "crupe": "crupă",
    "crupei": "crupă",
    "crupele": "crupă",
    "crupelor": "crupă",
    "crupo": "crupă",
    "crupele": "crupe",
    "crupelor": "crupe",
    "crupieri": "crupier",
    "crupierii": "crupier",
    "crupierilor": "crupier",
    "crupierul": "crupier",
    "crupierule": "crupier",
    "crupierului": "crupier",
    "crupoane": "crupon",
    "crupoanele": "crupon",
    "crupoanelor": "crupon",
    "cruponul": "crupon",
    "cruponule": "crupon",
    "cruponului": "crupon",
    "crusta": "crustă",
    "cruste": "crustă",
    "crustei": "crustă",
    "crustele": "crustă",
    "crustelor": "crustă",
    "crusto": "crustă",
    "crustacee": "crustaceu",
    "crustaceele": "crustaceu",
    "crustaceelor": "crustaceu",
    "crustaceul": "crustaceu",
    "crustaceule": "crustaceu",
    "crustaceului": "crustaceu",
    "cruț": "cruța",
    "cruță": "cruța",
    "cruțai": "cruța",
    "cruțam": "cruța",
    "cruțăm": "cruța",
    "cruțând": "cruța",
    "cruțându": "cruța",
    "cruțară": "cruța",
    "cruțarăm": "cruța",
    "cruțarăți": "cruța",
    "cruțase": "cruța",
    "cruțasem": "cruța",
    "cruțaseră": "cruța",
    "cruțaserăm": "cruța",
    "cruțaserăți": "cruța",
    "cruțaseși": "cruța",
    "cruțași": "cruța",
    "cruțat": "cruța",
    "cruțați": "cruța",
    "cruțatu": "cruța",
    "cruțau": "cruța",
    "cruțe": "cruța",
    "cruți": "cruța",
    "necruțând": "cruța",
    "necruțându": "cruța",
    "nemaicruțând": "cruța",
    "nemaicruțându": "cruța",
    "cruțarea": "cruțare",
    "cruțareo": "cruțare",
    "cruțări": "cruțare",
    "cruțării": "cruțare",
    "cruțările": "cruțare",
    "cruțărilor": "cruțare",
    "cruțată": "cruțat",
    "cruțate": "cruțat",
    "cruțați": "cruțat",
    "cruzimea": "cruzime",
    "cruzimeo": "cruzime",
    "cruzimi": "cruzime",
    "cruzimii": "cruzime",
    "cruzimile": "cruzime",
    "cruzimilor": "cruzime",
    "ctitori": "ctitor",
    "ctitorii": "ctitor",
    "ctitorilor": "ctitor",
    "ctitorul": "ctitor",
    "ctitorule": "ctitor",
    "ctitorului": "ctitor",
    "ctitora": "ctitoră",
    "ctitore": "ctitoră",
    "ctitorei": "ctitoră",
    "ctitorele": "ctitoră",
    "ctitorelor": "ctitoră",
    "ctitoro": "ctitoră",
    "ctitorea": "ctitori",
    "ctitoreai": "ctitori",
    "ctitoream": "ctitori",
    "ctitorească": "ctitori",
    "ctitoreați": "ctitori",
    "ctitoreau": "ctitori",
    "ctitoresc": "ctitori",
    "ctitorește": "ctitori",
    "ctitorești": "ctitori",
    "ctitorii": "ctitori",
    "ctitorim": "ctitori",
    "ctitorind": "ctitori",
    "ctitorindu": "ctitori",
    "ctitoriră": "ctitori",
    "ctitorirăm": "ctitori",
    "ctitorirăți": "ctitori",
    "ctitorise": "ctitori",
    "ctitorisem": "ctitori",
    "ctitoriseră": "ctitori",
    "ctitoriserăm": "ctitori",
    "ctitoriserăți": "ctitori",
    "ctitoriseși": "ctitori",
    "ctitoriși": "ctitori",
    "ctitorit": "ctitori",
    "ctitoriți": "ctitori",
    "ctitoritu": "ctitori",
    "nectitorind": "ctitori",
    "nectitorindu": "ctitori",
    "nemaictitorind": "ctitori",
    "nemaictitorindu": "ctitori",
    "ctitoria": "ctitorie",
    "ctitoriei": "ctitorie",
    "ctitorii": "ctitorie",
    "ctitoriile": "ctitorie",
    "ctitoriilor": "ctitorie",
    "ctitorio": "ctitorie",
    "ctitorită": "ctitorit",
    "ctitorite": "ctitorit",
    "ctitoriți": "ctitorit",
    "c-": "cu",
    "cuanta": "cuantă",
    "cuante": "cuantă",
    "cuantei": "cuantă",
    "cuantele": "cuantă",
    "cuantelor": "cuantă",
    "cuanto": "cuantă",
    "cuantica": "cuantic",
    "cuantică": "cuantic",
    "cuantice": "cuantic",
    "cuanticei": "cuantic",
    "cuanticele": "cuantic",
    "cuanticelor": "cuantic",
    "cuantici": "cuantic",
    "cuanticii": "cuantic",
    "cuanticilor": "cuantic",
    "cuantico": "cuantic",
    "cuanticul": "cuantic",
    "cuanticule": "cuantic",
    "cuanticului": "cuantic",
    "cuantificabila": "cuantificabil",
    "cuantificabilă": "cuantificabil",
    "cuantificabile": "cuantificabil",
    "cuantificabilei": "cuantificabil",
    "cuantificabilele": "cuantificabil",
    "cuantificabilelor": "cuantificabil",
    "cuantificabili": "cuantificabil",
    "cuantificabilii": "cuantificabil",
    "cuantificabililor": "cuantificabil",
    "cuantificabilul": "cuantificabil",
    "cuantificabilului": "cuantificabil",
    "cuantumul": "cuantum",
    "cuantumule": "cuantum",
    "cuantumului": "cuantum",
    "cuantumuri": "cuantum",
    "cuantumurile": "cuantum",
    "cuantumurilor": "cuantum",
    "cuarțul": "cuarț",
    "cuarțule": "cuarț",
    "cuarțului": "cuarț",
    "cuarțuri": "cuarț",
    "cuarțurile": "cuarț",
    "cuarțurilor": "cuarț",
    "cuaternarul": "cuaternar",
    "cuaternarule": "cuaternar",
    "cuaternarului": "cuaternar",
    "cubi": "cub",
    "cubul": "cub",
    "cubule": "cub",
    "cubului": "cub",
    "cuburi": "cub",
    "cuburile": "cub",
    "cuburilor": "cub",
    "Cube": "Cuba",
    "Cubei": "Cuba",
    "cubaje": "cubaj",
    "cubajele": "cubaj",
    "cubajelor": "cubaj",
    "cubajul": "cubaj",
    "cubajule": "cubaj",
    "cubajului": "cubaj",
    "cubica": "cubic",
    "cubică": "cubic",
    "cubice": "cubic",
    "cubicei": "cubic",
    "cubicele": "cubic",
    "cubicelor": "cubic",
    "cubici": "cubic",
    "cubicii": "cubic",
    "cubicilor": "cubic",
    "cubico": "cubic",
    "cubicul": "cubic",
    "cubicule": "cubic",
    "cubicului": "cubic",
    "cubiloul": "cubilou",
    "cubiloule": "cubilou",
    "cubiloului": "cubilou",
    "cubilouri": "cubilou",
    "cubilourile": "cubilou",
    "cubilourilor": "cubilou",
    "cubitusul": "cubitus",
    "cubitusule": "cubitus",
    "cubitusului": "cubitus",
    "cubitusuri": "cubitus",
    "cubitusurile": "cubitus",
    "cubitusurilor": "cubitus",
    "cuci": "cuc",
    "cucii": "cuc",
    "cucilor": "cuc",
    "cucul": "cuc",
    "cucule": "cuc",
    "cucului": "cuc",
    "cucul-armenesc": "cuc-armenesc",
    "cucului-armenesc": "cuc-armenesc",
    "cucerea": "cuceri",
    "cucereai": "cuceri",
    "cuceream": "cuceri",
    "cucerească": "cuceri",
    "cucereați": "cuceri",
    "cucereau": "cuceri",
    "cuceresc": "cuceri",
    "cucerește": "cuceri",
    "cucerești": "cuceri",
    "cucerii": "cuceri",
    "cucerim": "cuceri",
    "cucerind": "cuceri",
    "cucerindu": "cuceri",
    "cuceriră": "cuceri",
    "cucerirăm": "cuceri",
    "cucerirăți": "cuceri",
    "cucerise": "cuceri",
    "cucerisem": "cuceri",
    "cuceriseră": "cuceri",
    "cuceriserăm": "cuceri",
    "cuceriserăți": "cuceri",
    "cuceriseși": "cuceri",
    "cuceriși": "cuceri",
    "cucerit": "cuceri",
    "cuceriți": "cuceri",
    "cuceritu": "cuceri",
    "necucerind": "cuceri",
    "necucerindu": "cuceri",
    "nemaicucerind": "cuceri",
    "nemaicucerindu": "cuceri",
    "cucerirea": "cucerire",
    "cucerireo": "cucerire",
    "cuceriri": "cucerire",
    "cuceririi": "cucerire",
    "cuceririle": "cucerire",
    "cuceririlor": "cucerire",
    "cucerită": "cucerit",
    "cucerite": "cucerit",
    "cuceriți": "cucerit",
    "cuceritoarea": "cuceritoare",
    "cuceritoarei": "cuceritoare",
    "cuceritoarele": "cuceritoare",
    "cuceritoarelor": "cuceritoare",
    "cuceritoareo": "cuceritoare",
    "cuceritori": "cuceritor",
    "cuceritorii": "cuceritor",
    "cuceritorilor": "cuceritor",
    "cuceritorul": "cuceritor",
    "cuceritorule": "cuceritor",
    "cuceritorului": "cuceritor",
    "cucernica": "cucernic",
    "cucernică": "cucernic",
    "cucernice": "cucernic",
    "cucernicei": "cucernic",
    "cucernicele": "cucernic",
    "cucernicelor": "cucernic",
    "cucernici": "cucernic",
    "cucernicii": "cucernic",
    "cucernicilor": "cucernic",
    "cucernico": "cucernic",
    "cucernicul": "cucernic",
    "cucernicule": "cucernic",
    "cucernicului": "cucernic",
    "cucernicia": "cucernicie",
    "cucerniciei": "cucernicie",
    "cucernicii": "cucernicie",
    "cucerniciile": "cucernicie",
    "cucerniciilor": "cucernicie",
    "cucernicio": "cucernicie",
    "cucoana": "cucoană",
    "cucoane": "cucoană",
    "cucoanei": "cucoană",
    "cucoanele": "cucoană",
    "cucoanelor": "cucoană",
    "cucoano": "cucoană",
    "cuconi": "cucon",
    "cuconii": "cucon",
    "cuconilor": "cucon",
    "cuconul": "cucon",
    "cuconule": "cucon",
    "cuconului": "cucon",
    "cuconea": "cuconi",
    "cuconeai": "cuconi",
    "cuconeam": "cuconi",
    "cuconească": "cuconi",
    "cuconeați": "cuconi",
    "cuconeau": "cuconi",
    "cuconesc": "cuconi",
    "cuconește": "cuconi",
    "cuconești": "cuconi",
    "cuconii": "cuconi",
    "cuconim": "cuconi",
    "cuconind": "cuconi",
    "cuconindu": "cuconi",
    "cuconiră": "cuconi",
    "cuconirăm": "cuconi",
    "cuconirăți": "cuconi",
    "cuconise": "cuconi",
    "cuconisem": "cuconi",
    "cuconiseră": "cuconi",
    "cuconiserăm": "cuconi",
    "cuconiserăți": "cuconi",
    "cuconiseși": "cuconi",
    "cuconiși": "cuconi",
    "cuconit": "cuconi",
    "cuconiți": "cuconi",
    "cuconitu": "cuconi",
    "necuconind": "cuconi",
    "necuconindu": "cuconi",
    "nemaicuconind": "cuconi",
    "nemaicuconindu": "cuconi",
    "cuconită": "cuconit",
    "cuconite": "cuconit",
    "cuconiți": "cuconit",
    "cucuie": "cucui",
    "cucuiele": "cucui",
    "cucuielor": "cucui",
    "cucuiul": "cucui",
    "cucuiule": "cucui",
    "cucuiului": "cucui",
    "cucuiata": "cucuiat",
    "cucuiată": "cucuiat",
    "cucuiate": "cucuiat",
    "cucuiatei": "cucuiat",
    "cucuiatele": "cucuiat",
    "cucuiatelor": "cucuiat",
    "cucuiați": "cucuiat",
    "cucuiații": "cucuiat",
    "cucuiaților": "cucuiat",
    "cucuiato": "cucuiat",
    "cucuiatul": "cucuiat",
    "cucuiatule": "cucuiat",
    "cucuiatului": "cucuiat",
    "cucurbitaceea": "cucurbitacee",
    "cucurbitaceei": "cucurbitacee",
    "cucurbitaceele": "cucurbitacee",
    "cucurbitaceelor": "cucurbitacee",
    "cucurbitaceeo": "cucurbitacee",
    "cucurig": "cucuriga",
    "cucurigă": "cucuriga",
    "cucurigai": "cucuriga",
    "cucurigam": "cucuriga",
    "cucurigăm": "cucuriga",
    "cucurigând": "cucuriga",
    "cucurigându": "cucuriga",
    "cucurigară": "cucuriga",
    "cucurigarăm": "cucuriga",
    "cucurigarăți": "cucuriga",
    "cucurigase": "cucuriga",
    "cucurigasem": "cucuriga",
    "cucurigaseră": "cucuriga",
    "cucurigaserăm": "cucuriga",
    "cucurigaserăți": "cucuriga",
    "cucurigaseși": "cucuriga",
    "cucurigași": "cucuriga",
    "cucurigat": "cucuriga",
    "cucurigați": "cucuriga",
    "cucurigatu": "cucuriga",
    "cucurigau": "cucuriga",
    "cucurige": "cucuriga",
    "cucurigi": "cucuriga",
    "necucurigând": "cucuriga",
    "necucurigându": "cucuriga",
    "nemaicucurigând": "cucuriga",
    "nemaicucurigându": "cucuriga",
    "cucurigată": "cucurigat",
    "cucurigate": "cucurigat",
    "cucurigați": "cucurigat",
    "cucurigatul": "cucurigat",
    "cucurigatule": "cucurigat",
    "cucurigatului": "cucurigat",
    "cucurigul": "cucurigu",
    "cucurigule": "cucurigu",
    "cucurigului": "cucurigu",
    "cucuriguri": "cucurigu",
    "cucurigurile": "cucurigu",
    "cucurigurilor": "cucurigu",
    "cucuruze": "cucuruz",
    "cucuruzele": "cucuruz",
    "cucuruzelor": "cucuruz",
    "cucuruzi": "cucuruz",
    "cucuruzii": "cucuruz",
    "cucuruzilor": "cucuruz",
    "cucuruzul": "cucuruz",
    "cucuruzule": "cucuruz",
    "cucuruzului": "cucuruz",
    "cucuta": "cucută",
    "cucute": "cucută",
    "cucutei": "cucută",
    "cucutele": "cucută",
    "cucutelor": "cucută",
    "cucuto": "cucută",
    "cucuvăi": "cucuvaie",
    "cucuvaia": "cucuvaie",
    "cucuvăii": "cucuvaie",
    "cucuvăile": "cucuvaie",
    "cucuvăilor": "cucuvaie",
    "cucuvaio": "cucuvaie",
    "cucuveao": "cucuvea",
    "cucuveaua": "cucuvea",
    "cucuvele": "cucuvea",
    "cucuvelei": "cucuvea",
    "cucuvelele": "cucuvea",
    "cucuvelelor": "cucuvea",
    "cufărul": "cufăr",
    "cufărule": "cufăr",
    "cufărului": "cufăr",
    "cufere": "cufăr",
    "cuferele": "cufăr",
    "cuferelor": "cufăr",
    "cufărașe": "cufăraș",
    "cufărașele": "cufăraș",
    "cufărașelor": "cufăraș",
    "cufărașul": "cufăraș",
    "cufărașule": "cufăraș",
    "cufărașului": "cufăraș",
    "cufund": "cufunda",
    "cufundă": "cufunda",
    "cufundai": "cufunda",
    "cufundam": "cufunda",
    "cufundăm": "cufunda",
    "cufundând": "cufunda",
    "cufundându": "cufunda",
    "cufundară": "cufunda",
    "cufundarăm": "cufunda",
    "cufundarăți": "cufunda",
    "cufundase": "cufunda",
    "cufundasem": "cufunda",
    "cufundaseră": "cufunda",
    "cufundaserăm": "cufunda",
    "cufundaserăți": "cufunda",
    "cufundaseși": "cufunda",
    "cufundași": "cufunda",
    "cufundat": "cufunda",
    "cufundați": "cufunda",
    "cufundatu": "cufunda",
    "cufundau": "cufunda",
    "cufunde": "cufunda",
    "cufunzi": "cufunda",
    "necufundând": "cufunda",
    "necufundându": "cufunda",
    "nemaicufundând": "cufunda",
    "nemaicufundându": "cufunda",
    "cufundaci": "cufundac",
    "cufundacii": "cufundac",
    "cufundacilor": "cufundac",
    "cufundacul": "cufundac",
    "cufundacule": "cufundac",
    "cufundacului": "cufundac",
    "cufundari": "cufundar",
    "cufundarii": "cufundar",
    "cufundarilor": "cufundar",
    "cufundarul": "cufundar",
    "cufundarule": "cufundar",
    "cufundarului": "cufundar",
    "cufundarea": "cufundare",
    "cufundareo": "cufundare",
    "cufundări": "cufundare",
    "cufundării": "cufundare",
    "cufundările": "cufundare",
    "cufundărilor": "cufundare",
    "cufundată": "cufundat",
    "cufundate": "cufundat",
    "cufundați": "cufundat",
    "cugete": "cuget",
    "cugetele": "cuget",
    "cugetelor": "cuget",
    "cugetul": "cuget",
    "cugetule": "cuget",
    "cugetului": "cuget",
    "cuget": "cugeta",
    "cugetă": "cugeta",
    "cugetai": "cugeta",
    "cugetam": "cugeta",
    "cugetăm": "cugeta",
    "cugetând": "cugeta",
    "cugetându": "cugeta",
    "cugetară": "cugeta",
    "cugetarăm": "cugeta",
    "cugetarăți": "cugeta",
    "cugetase": "cugeta",
    "cugetasem": "cugeta",
    "cugetaseră": "cugeta",
    "cugetaserăm": "cugeta",
    "cugetaserăți": "cugeta",
    "cugetaseși": "cugeta",
    "cugetași": "cugeta",
    "cugetat": "cugeta",
    "cugetați": "cugeta",
    "cugetatu": "cugeta",
    "cugetau": "cugeta",
    "cugete": "cugeta",
    "cugeți": "cugeta",
    "necugetând": "cugeta",
    "necugetându": "cugeta",
    "nemaicugetând": "cugeta",
    "nemaicugetându": "cugeta",
    "cugetarea": "cugetare",
    "cugetareo": "cugetare",
    "cugetări": "cugetare",
    "cugetării": "cugetare",
    "cugetările": "cugetare",
    "cugetărilor": "cugetare",
    "cugetată": "cugetat",
    "cugetate": "cugetat",
    "cugetați": "cugetat",
    "cugetătoarea": "cugetătoare",
    "cugetătoarei": "cugetătoare",
    "cugetătoarele": "cugetătoare",
    "cugetătoarelor": "cugetătoare",
    "cugetătoareo": "cugetătoare",
    "cugetătoare": "cugetător",
    "cugetătoarea": "cugetător",
    "cugetătoarei": "cugetător",
    "cugetătoarele": "cugetător",
    "cugetătoarelor": "cugetător",
    "cugetătoareo": "cugetător",
    "cugetători": "cugetător",
    "cugetătorii": "cugetător",
    "cugetătorilor": "cugetător",
    "cugetătorul": "cugetător",
    "cugetătorule": "cugetător",
    "cugetătorului": "cugetător",
    "cuhnia": "cuhnie",
    "cuhniei": "cuhnie",
    "cuhnii": "cuhnie",
    "cuhniile": "cuhnie",
    "cuhniilor": "cuhnie",
    "cuhnio": "cuhnie",
    "cuie": "cui",
    "cuiele": "cui",
    "cuielor": "cui",
    "cuiul": "cui",
    "cuiule": "cui",
    "cuiului": "cui",
    "cuibul": "cuib",
    "cuibule": "cuib",
    "cuibului": "cuib",
    "cuiburi": "cuib",
    "cuiburile": "cuib",
    "cuiburilor": "cuib",
    "cuibă": "cuiba",
    "cuibai": "cuiba",
    "cuibam": "cuiba",
    "cuibăm": "cuiba",
    "cuibând": "cuiba",
    "cuibându": "cuiba",
    "cuibară": "cuiba",
    "cuibarăm": "cuiba",
    "cuibarăți": "cuiba",
    "cuibase": "cuiba",
    "cuibasem": "cuiba",
    "cuibaseră": "cuiba",
    "cuibaserăm": "cuiba",
    "cuibaserăți": "cuiba",
    "cuibaseși": "cuiba",
    "cuibași": "cuiba",
    "cuibat": "cuiba",
    "cuibați": "cuiba",
    "cuibatu": "cuiba",
    "cuibau": "cuiba",
    "cuibează": "cuiba",
    "cuibez": "cuiba",
    "cuibeze": "cuiba",
    "cuibezi": "cuiba",
    "necuibând": "cuiba",
    "necuibându": "cuiba",
    "nemaicuibând": "cuiba",
    "nemaicuibându": "cuiba",
    "cuibare": "cuibar",
    "cuibarele": "cuibar",
    "cuibarelor": "cuibar",
    "cuibarul": "cuibar",
    "cuibarule": "cuibar",
    "cuibarului": "cuibar",
    "cuibărea": "cuibări",
    "cuibăreai": "cuibări",
    "cuibăream": "cuibări",
    "cuibărească": "cuibări",
    "cuibăreați": "cuibări",
    "cuibăreau": "cuibări",
    "cuibăresc": "cuibări",
    "cuibărește": "cuibări",
    "cuibărești": "cuibări",
    "cuibării": "cuibări",
    "cuibărim": "cuibări",
    "cuibărind": "cuibări",
    "cuibărindu": "cuibări",
    "cuibăriră": "cuibări",
    "cuibărirăm": "cuibări",
    "cuibărirăți": "cuibări",
    "cuibărise": "cuibări",
    "cuibărisem": "cuibări",
    "cuibăriseră": "cuibări",
    "cuibăriserăm": "cuibări",
    "cuibăriserăți": "cuibări",
    "cuibăriseși": "cuibări",
    "cuibăriși": "cuibări",
    "cuibărit": "cuibări",
    "cuibăriți": "cuibări",
    "cuibăritu": "cuibări",
    "necuibărind": "cuibări",
    "necuibărindu": "cuibări",
    "nemaicuibărind": "cuibări",
    "nemaicuibărindu": "cuibări",
    "cuibărită": "cuibărit",
    "cuibărite": "cuibărit",
    "cuibăriți": "cuibărit",
    "cuibată": "cuibat",
    "cuibate": "cuibat",
    "cuibați": "cuibat",
    "cuiere": "cuier",
    "cuierele": "cuier",
    "cuierelor": "cuier",
    "cuierul": "cuier",
    "cuierule": "cuier",
    "cuierului": "cuier",
    "cuirasa": "cuirasă",
    "cuirase": "cuirasă",
    "cuirasei": "cuirasă",
    "cuirasele": "cuirasă",
    "cuiraselor": "cuirasă",
    "cuiraso": "cuirasă",
    "cuirasate": "cuirasat",
    "cuirasatele": "cuirasat",
    "cuirasatelor": "cuirasat",
    "cuirasatul": "cuirasat",
    "cuirasatule": "cuirasat",
    "cuirasatului": "cuirasat",
    "cuișoare": "cuișor",
    "cuișoarele": "cuișor",
    "cuișoarelor": "cuișor",
    "cula": "culă",
    "cule": "culă",
    "culei": "culă",
    "culele": "culă",
    "culelor": "culă",
    "culo": "culă",
    "culasa": "culasă",
    "culase": "culasă",
    "culasei": "culasă",
    "culasele": "culasă",
    "culaselor": "culasă",
    "culaso": "culasă",
    "culata": "culată",
    "culate": "culată",
    "culatei": "culată",
    "culatele": "culată",
    "culatelor": "culată",
    "culato": "culată",
    "culbutoare": "culbutor",
    "culbutoarele": "culbutor",
    "culbutoarelor": "culbutor",
    "culbutorul": "culbutor",
    "culbutorule": "culbutor",
    "culbutorului": "culbutor",
    "culc": "culca",
    "culcă": "culca",
    "culcai": "culca",
    "culcam": "culca",
    "culcăm": "culca",
    "culcând": "culca",
    "culcându": "culca",
    "culcară": "culca",
    "culcarăm": "culca",
    "culcarăți": "culca",
    "culcase": "culca",
    "culcasem": "culca",
    "culcaseră": "culca",
    "culcaserăm": "culca",
    "culcaserăți": "culca",
    "culcaseși": "culca",
    "culcași": "culca",
    "culcat": "culca",
    "culcați": "culca",
    "culcatu": "culca",
    "culcau": "culca",
    "culce": "culca",
    "culci": "culca",
    "neculcând": "culca",
    "neculcându": "culca",
    "nemaiculcând": "culca",
    "nemaiculcându": "culca",
    "culcarea": "culcare",
    "culcareo": "culcare",
    "culcări": "culcare",
    "culcării": "culcare",
    "culcările": "culcare",
    "culcărilor": "culcare",
    "culcata": "culcat",
    "culcată": "culcat",
    "culcate": "culcat",
    "culcatei": "culcat",
    "culcatele": "culcat",
    "culcatelor": "culcat",
    "culcați": "culcat",
    "culcații": "culcat",
    "culcaților": "culcat",
    "culcatul": "culcat",
    "culcatule": "culcat",
    "culcatului": "culcat",
    "culcaturi": "culcat",
    "culcaturile": "culcat",
    "culcaturilor": "culcat",
    "culcușul": "culcuș",
    "culcușule": "culcuș",
    "culcușului": "culcuș",
    "culcușuri": "culcuș",
    "culcușurile": "culcuș",
    "culcușurilor": "culcuș",
    "culegătoarea": "culegătoare",
    "culegătoarei": "culegătoare",
    "culegătoarele": "culegătoare",
    "culegătoarelor": "culegătoare",
    "culegătoareo": "culegătoare",
    "culegători": "culegător",
    "culegătorii": "culegător",
    "culegătorilor": "culegător",
    "culegătorul": "culegător",
    "culegătorule": "culegător",
    "culegătorului": "culegător",
    "culeagă": "culege",
    "culeg": "culege",
    "culegând": "culege",
    "culegându": "culege",
    "culegea": "culege",
    "culegeai": "culege",
    "culegeam": "culege",
    "culegeați": "culege",
    "culegeau": "culege",
    "culegem": "culege",
    "culegeți": "culege",
    "culegi": "culege",
    "cules": "culege",
    "culese": "culege",
    "culesei": "culege",
    "culeseră": "culege",
    "culeserăm": "culege",
    "culeserăți": "culege",
    "culesese": "culege",
    "culesesem": "culege",
    "culeseseră": "culege",
    "culeseserăm": "culege",
    "culeseserăți": "culege",
    "culeseseși": "culege",
    "culeseși": "culege",
    "culesu": "culege",
    "neculegând": "culege",
    "neculegându": "culege",
    "nemaiculegând": "culege",
    "nemaiculegându": "culege",
    "culegerea": "culegere",
    "culegereo": "culegere",
    "culegeri": "culegere",
    "culegerii": "culegere",
    "culegerile": "culegere",
    "culegerilor": "culegere",
    "culeasă": "cules",
    "culese": "cules",
    "culeși": "cules",
    "culesul": "cules",
    "culesule": "cules",
    "culesului": "cules",
    "culesuri": "cules",
    "culesurile": "cules",
    "culesurilor": "cules",
    "culii": "culi",
    "culilor": "culi",
    "culiul": "culi",
    "culiule": "culi",
    "culiului": "culi",
    "culinara": "culinar",
    "culinară": "culinar",
    "culinare": "culinar",
    "culinarei": "culinar",
    "culinarele": "culinar",
    "culinarelor": "culinar",
    "culinari": "culinar",
    "culinarii": "culinar",
    "culinarilor": "culinar",
    "culinaro": "culinar",
    "culinarul": "culinar",
    "culinarule": "culinar",
    "culinarului": "culinar",
    "culisa": "culisă",
    "culise": "culisă",
    "culisei": "culisă",
    "culisele": "culisă",
    "culiselor": "culisă",
    "culiso": "culisă",
    "culmea": "culme",
    "culmeo": "culme",
    "culmi": "culme",
    "culmii": "culme",
    "culmile": "culme",
    "culmilor": "culme",
    "culmină": "culmina",
    "culminai": "culmina",
    "culminam": "culmina",
    "culminăm": "culmina",
    "culminând": "culmina",
    "culminându": "culmina",
    "culminară": "culmina",
    "culminarăm": "culmina",
    "culminarăți": "culmina",
    "culminase": "culmina",
    "culminasem": "culmina",
    "culminaseră": "culmina",
    "culminaserăm": "culmina",
    "culminaserăți": "culmina",
    "culminaseși": "culmina",
    "culminași": "culmina",
    "culminat": "culmina",
    "culminați": "culmina",
    "culminatu": "culmina",
    "culminau": "culmina",
    "culminează": "culmina",
    "culminez": "culmina",
    "culmineze": "culmina",
    "culminezi": "culmina",
    "neculminând": "culmina",
    "neculminându": "culmina",
    "nemaiculminând": "culmina",
    "nemaiculminându": "culmina",
    "culminanta": "culminant",
    "culminantă": "culminant",
    "culminante": "culminant",
    "culminantei": "culminant",
    "culminantele": "culminant",
    "culminantelor": "culminant",
    "culminanți": "culminant",
    "culminanții": "culminant",
    "culminanților": "culminant",
    "culminanto": "culminant",
    "culminantul": "culminant",
    "culminantule": "culminant",
    "culminantului": "culminant",
    "culminarea": "culminare",
    "culminareo": "culminare",
    "culminări": "culminare",
    "culminării": "culminare",
    "culminările": "culminare",
    "culminărilor": "culminare",
    "culminată": "culminat",
    "culminate": "culminat",
    "culminați": "culminat",
    "culminația": "culminație",
    "culminației": "culminație",
    "culminații": "culminație",
    "culminațiile": "culminație",
    "culminațiilor": "culminație",
    "culminațio": "culminație",
    "culoare": "culoar",
    "culoarele": "culoar",
    "culoarelor": "culoar",
    "culoarul": "culoar",
    "culoarule": "culoar",
    "culoarului": "culoar",
    "culoarea": "culoare",
    "culoareo": "culoare",
    "culori": "culoare",
    "culorii": "culoare",
    "culorile": "culoare",
    "culorilor": "culoare",
    "culpa": "culpă",
    "culpe": "culpă",
    "culpei": "culpă",
    "culpele": "culpă",
    "culpelor": "culpă",
    "culpo": "culpă",
    "culpabila": "culpabil",
    "culpabilă": "culpabil",
    "culpabile": "culpabil",
    "culpabilei": "culpabil",
    "culpabilele": "culpabil",
    "culpabilelor": "culpabil",
    "culpabili": "culpabil",
    "culpabilii": "culpabil",
    "culpabililor": "culpabil",
    "culpabilo": "culpabil",
    "culpabilul": "culpabil",
    "culpabilule": "culpabil",
    "culpabilului": "culpabil",
    "culpabilitatea": "culpabilitate",
    "culpabilitateo": "culpabilitate",
    "culpabilități": "culpabilitate",
    "culpabilității": "culpabilitate",
    "culpabilitățile": "culpabilitate",
    "culpabilităților": "culpabilitate",
    "culpabilizarea": "culpabilizare",
    "culpabilizareo": "culpabilizare",
    "culpabilizări": "culpabilizare",
    "culpabilizării": "culpabilizare",
    "culpabilizările": "culpabilizare",
    "culpabilizărilor": "culpabilizare",
    "culta": "cult",
    "cultă": "cult",
    "culte": "cult",
    "cultei": "cult",
    "cultele": "cult",
    "cultelor": "cult",
    "culți": "cult",
    "culții": "cult",
    "culților": "cult",
    "culto": "cult",
    "cultul": "cult",
    "cultule": "cult",
    "cultului": "cult",
    "cultiv": "cultiva",
    "cultivă": "cultiva",
    "cultivai": "cultiva",
    "cultivam": "cultiva",
    "cultivăm": "cultiva",
    "cultivând": "cultiva",
    "cultivându": "cultiva",
    "cultivară": "cultiva",
    "cultivarăm": "cultiva",
    "cultivarăți": "cultiva",
    "cultivase": "cultiva",
    "cultivasem": "cultiva",
    "cultivaseră": "cultiva",
    "cultivaserăm": "cultiva",
    "cultivaserăți": "cultiva",
    "cultivaseși": "cultiva",
    "cultivași": "cultiva",
    "cultivat": "cultiva",
    "cultivați": "cultiva",
    "cultivatu": "cultiva",
    "cultivau": "cultiva",
    "cultive": "cultiva",
    "cultivi": "cultiva",
    "necultivând": "cultiva",
    "necultivându": "cultiva",
    "nemaicultivând": "cultiva",
    "nemaicultivându": "cultiva",
    "cultivabila": "cultivabil",
    "cultivabilă": "cultivabil",
    "cultivabile": "cultivabil",
    "cultivabilei": "cultivabil",
    "cultivabilele": "cultivabil",
    "cultivabilelor": "cultivabil",
    "cultivabili": "cultivabil",
    "cultivabilii": "cultivabil",
    "cultivabililor": "cultivabil",
    "cultivabilo": "cultivabil",
    "cultivabilul": "cultivabil",
    "cultivabilule": "cultivabil",
    "cultivabilului": "cultivabil",
    "cultivarea": "cultivare",
    "cultivareo": "cultivare",
    "cultivări": "cultivare",
    "cultivării": "cultivare",
    "cultivările": "cultivare",
    "cultivărilor": "cultivare",
    "cultivată": "cultivat",
    "cultivate": "cultivat",
    "cultivați": "cultivat",
    "cultivații": "cultivat",
    "cultivaților": "cultivat",
    "cultivatul": "cultivat",
    "cultivatule": "cultivat",
    "cultivatului": "cultivat",
    "cultivata": "cultivată",
    "cultivate": "cultivată",
    "cultivatei": "cultivată",
    "cultivatele": "cultivată",
    "cultivatelor": "cultivată",
    "cultivato": "cultivată",
    "cultivatoarea": "cultivatoare",
    "cultivatoarei": "cultivatoare",
    "cultivatoarele": "cultivatoare",
    "cultivatoarelor": "cultivatoare",
    "cultivatoareo": "cultivatoare",
    "cultivatoare": "cultivator",
    "cultivatoarele": "cultivator",
    "cultivatoarelor": "cultivator",
    "cultivatori": "cultivator",
    "cultivatorii": "cultivator",
    "cultivatorilor": "cultivator",
    "cultivatorul": "cultivator",
    "cultivatorule": "cultivator",
    "cultivatorului": "cultivator",
    "cultura": "cultură",
    "culturi": "cultură",
    "culturii": "cultură",
    "culturile": "cultură",
    "culturilor": "cultură",
    "culturo": "cultură",
    "culturala": "cultural",
    "culturală": "cultural",
    "culturale": "cultural",
    "culturalei": "cultural",
    "culturalele": "cultural",
    "culturalelor": "cultural",
    "culturali": "cultural",
    "culturalii": "cultural",
    "culturalilor": "cultural",
    "culturalo": "cultural",
    "culturalul": "cultural",
    "culturalule": "cultural",
    "culturalului": "cultural",
    "culturaliză": "culturaliza",
    "culturalizai": "culturaliza",
    "culturalizam": "culturaliza",
    "culturalizăm": "culturaliza",
    "culturalizând": "culturaliza",
    "culturalizându": "culturaliza",
    "culturalizară": "culturaliza",
    "culturalizarăm": "culturaliza",
    "culturalizarăți": "culturaliza",
    "culturalizase": "culturaliza",
    "culturalizasem": "culturaliza",
    "culturalizaseră": "culturaliza",
    "culturalizaserăm": "culturaliza",
    "culturalizaserăți": "culturaliza",
    "culturalizaseși": "culturaliza",
    "culturalizași": "culturaliza",
    "culturalizat": "culturaliza",
    "culturalizați": "culturaliza",
    "culturalizatu": "culturaliza",
    "culturalizau": "culturaliza",
    "culturalizează": "culturaliza",
    "culturalizez": "culturaliza",
    "culturalizeze": "culturaliza",
    "culturalizezi": "culturaliza",
    "neculturalizând": "culturaliza",
    "neculturalizându": "culturaliza",
    "nemaiculturalizând": "culturaliza",
    "nemaiculturalizându": "culturaliza",
    "culturalizarea": "culturalizare",
    "culturalizareo": "culturalizare",
    "culturalizări": "culturalizare",
    "culturalizării": "culturalizare",
    "culturalizările": "culturalizare",
    "culturalizărilor": "culturalizare",
    "culturalizată": "culturalizat",
    "culturalizate": "culturalizat",
    "culturalizați": "culturalizat",
    "cultural-religioasa": "cultural-religios",
    "cultural-religioasă": "cultural-religios",
    "cultural-religioase": "cultural-religios",
    "cultural-religioasei": "cultural-religios",
    "cultural-religioasele": "cultural-religios",
    "cultural-religioaselor": "cultural-religios",
    "cultural-religioaso": "cultural-religios",
    "cultural-religioși": "cultural-religios",
    "cultural-religioșii": "cultural-religios",
    "cultural-religioșilor": "cultural-religios",
    "cultural-religiosul": "cultural-religios",
    "cultural-religiosule": "cultural-religios",
    "cultural-religiosului": "cultural-religios",
    "cumătra": "cumătră",
    "cumătro": "cumătră",
    "cumetre": "cumătră",
    "cumetrei": "cumătră",
    "cumetrele": "cumătră",
    "cumetrelor": "cumătră",
    "cumătrul": "cumătru",
    "cumătrule": "cumătru",
    "cumătrului": "cumătru",
    "cumetri": "cumătru",
    "cumetrii": "cumătru",
    "cumetrilor": "cumătru",
    "cumetria": "cumetrie",
    "cumetriei": "cumetrie",
    "cumetrii": "cumetrie",
    "cumetriile": "cumetrie",
    "cumetriilor": "cumetrie",
    "cumetrio": "cumetrie",
    "cuminec": "cumineca",
    "cuminecă": "cumineca",
    "cuminecai": "cumineca",
    "cuminecam": "cumineca",
    "cuminecăm": "cumineca",
    "cuminecând": "cumineca",
    "cuminecându": "cumineca",
    "cuminecară": "cumineca",
    "cuminecarăm": "cumineca",
    "cuminecarăți": "cumineca",
    "cuminecase": "cumineca",
    "cuminecasem": "cumineca",
    "cuminecaseră": "cumineca",
    "cuminecaserăm": "cumineca",
    "cuminecaserăți": "cumineca",
    "cuminecaseși": "cumineca",
    "cuminecași": "cumineca",
    "cuminecat": "cumineca",
    "cuminecați": "cumineca",
    "cuminecatu": "cumineca",
    "cuminecau": "cumineca",
    "cuminece": "cumineca",
    "cumineci": "cumineca",
    "necuminecând": "cumineca",
    "necuminecându": "cumineca",
    "nemaicuminecând": "cumineca",
    "nemaicuminecându": "cumineca",
    "cuminecarea": "cuminecare",
    "cuminecareo": "cuminecare",
    "cuminecări": "cuminecare",
    "cuminecării": "cuminecare",
    "cuminecările": "cuminecare",
    "cuminecărilor": "cuminecare",
    "cuminecată": "cuminecat",
    "cuminecate": "cuminecat",
    "cuminecați": "cuminecat",
    "cuminți": "cuminte",
    "cumințenia": "cumințenie",
    "cumințeniei": "cumințenie",
    "cumințenii": "cumințenie",
    "cumințeniile": "cumințenie",
    "cumințeniilor": "cumințenie",
    "cumințenio": "cumințenie",
    "cumințirea": "cumințire",
    "cumințireo": "cumințire",
    "cumințiri": "cumințire",
    "cumințirii": "cumințire",
    "cumințirile": "cumințire",
    "cumințirilor": "cumințire",
    "cumnați": "cumnat",
    "cumnații": "cumnat",
    "cumnaților": "cumnat",
    "cumnatul": "cumnat",
    "cumnatule": "cumnat",
    "cumnatului": "cumnat",
    "cumnata": "cumnată",
    "cumnate": "cumnată",
    "cumnatei": "cumnată",
    "cumnatele": "cumnată",
    "cumnatelor": "cumnată",
    "cumnato": "cumnată",
    "cumpăna": "cumpănă",
    "cumpăno": "cumpănă",
    "cumpene": "cumpănă",
    "cumpenei": "cumpănă",
    "cumpenele": "cumpănă",
    "cumpenelor": "cumpănă",
    "cumpăneala": "cumpăneală",
    "cumpănealo": "cumpăneală",
    "cumpăneli": "cumpăneală",
    "cumpănelii": "cumpăneală",
    "cumpănelile": "cumpăneală",
    "cumpănelilor": "cumpăneală",
    "cumpănea": "cumpăni",
    "cumpăneai": "cumpăni",
    "cumpăneam": "cumpăni",
    "cumpănească": "cumpăni",
    "cumpăneați": "cumpăni",
    "cumpăneau": "cumpăni",
    "cumpănesc": "cumpăni",
    "cumpănește": "cumpăni",
    "cumpănești": "cumpăni",
    "cumpănii": "cumpăni",
    "cumpănim": "cumpăni",
    "cumpănind": "cumpăni",
    "cumpănindu": "cumpăni",
    "cumpăniră": "cumpăni",
    "cumpănirăm": "cumpăni",
    "cumpănirăți": "cumpăni",
    "cumpănise": "cumpăni",
    "cumpănisem": "cumpăni",
    "cumpăniseră": "cumpăni",
    "cumpăniserăm": "cumpăni",
    "cumpăniserăți": "cumpăni",
    "cumpăniseși": "cumpăni",
    "cumpăniși": "cumpăni",
    "cumpănit": "cumpăni",
    "cumpăniți": "cumpăni",
    "cumpănitu": "cumpăni",
    "necumpănind": "cumpăni",
    "necumpănindu": "cumpăni",
    "nemaicumpănind": "cumpăni",
    "nemaicumpănindu": "cumpăni",
    "cumpănirea": "cumpănire",
    "cumpănireo": "cumpănire",
    "cumpăniri": "cumpănire",
    "cumpănirii": "cumpănire",
    "cumpănirile": "cumpănire",
    "cumpănirilor": "cumpănire",
    "cumpănita": "cumpănit",
    "cumpănită": "cumpănit",
    "cumpănite": "cumpănit",
    "cumpănitei": "cumpănit",
    "cumpănitele": "cumpănit",
    "cumpănitelor": "cumpănit",
    "cumpăniți": "cumpănit",
    "cumpăniții": "cumpănit",
    "cumpăniților": "cumpănit",
    "cumpănito": "cumpănit",
    "cumpănitul": "cumpănit",
    "cumpănitule": "cumpănit",
    "cumpănitului": "cumpănit",
    "cumpăr": "cumpăra",
    "cumpără": "cumpăra",
    "cumpărai": "cumpăra",
    "cumpăram": "cumpăra",
    "cumpărăm": "cumpăra",
    "cumpărând": "cumpăra",
    "cumpărându": "cumpăra",
    "cumpărară": "cumpăra",
    "cumpărarăm": "cumpăra",
    "cumpărarăți": "cumpăra",
    "cumpărase": "cumpăra",
    "cumpărasem": "cumpăra",
    "cumpăraseră": "cumpăra",
    "cumpăraserăm": "cumpăra",
    "cumpăraserăți": "cumpăra",
    "cumpăraseși": "cumpăra",
    "cumpărași": "cumpăra",
    "cumpărat": "cumpăra",
    "cumpărați": "cumpăra",
    "cumpăratu": "cumpăra",
    "cumpărau": "cumpăra",
    "cumpere": "cumpăra",
    "cumperi": "cumpăra",
    "necumpărând": "cumpăra",
    "necumpărându": "cumpăra",
    "nemaicumpărând": "cumpăra",
    "nemaicumpărându": "cumpăra",
    "cumpărarea": "cumpărare",
    "cumpărareo": "cumpărare",
    "cumpărări": "cumpărare",
    "cumpărării": "cumpărare",
    "cumpărările": "cumpărare",
    "cumpărărilor": "cumpărare",
    "cumpărată": "cumpărat",
    "cumpărate": "cumpărat",
    "cumpărați": "cumpărat",
    "cumpăratul": "cumpărat",
    "cumpăratule": "cumpărat",
    "cumpăratului": "cumpărat",
    "cumpărătoarea": "cumpărătoare",
    "cumpărătoarei": "cumpărătoare",
    "cumpărătoarele": "cumpărătoare",
    "cumpărătoarelor": "cumpărătoare",
    "cumpărătoareo": "cumpărătoare",
    "cumpărători": "cumpărător",
    "cumpărătorii": "cumpărător",
    "cumpărătorilor": "cumpărător",
    "cumpărătorul": "cumpărător",
    "cumpărătorule": "cumpărător",
    "cumpărătorului": "cumpărător",
    "cumpărătura": "cumpărătură",
    "cumpărături": "cumpărătură",
    "cumpărăturii": "cumpărătură",
    "cumpărăturile": "cumpărătură",
    "cumpărăturilor": "cumpărătură",
    "cumpărăturo": "cumpărătură",
    "cumpătul": "cumpăt",
    "cumpătule": "cumpăt",
    "cumpătului": "cumpăt",
    "cumpătă": "cumpăta",
    "cumpătai": "cumpăta",
    "cumpătam": "cumpăta",
    "cumpătăm": "cumpăta",
    "cumpătând": "cumpăta",
    "cumpătându": "cumpăta",
    "cumpătară": "cumpăta",
    "cumpătarăm": "cumpăta",
    "cumpătarăți": "cumpăta",
    "cumpătase": "cumpăta",
    "cumpătasem": "cumpăta",
    "cumpătaseră": "cumpăta",
    "cumpătaserăm": "cumpăta",
    "cumpătaserăți": "cumpăta",
    "cumpătaseși": "cumpăta",
    "cumpătași": "cumpăta",
    "cumpătat": "cumpăta",
    "cumpătați": "cumpăta",
    "cumpătatu": "cumpăta",
    "cumpătau": "cumpăta",
    "cumpătează": "cumpăta",
    "cumpătez": "cumpăta",
    "cumpăteze": "cumpăta",
    "cumpătezi": "cumpăta",
    "necumpătând": "cumpăta",
    "necumpătându": "cumpăta",
    "nemaicumpătând": "cumpăta",
    "nemaicumpătându": "cumpăta",
    "cumpătarea": "cumpătare",
    "cumpătareo": "cumpătare",
    "cumpătări": "cumpătare",
    "cumpătării": "cumpătare",
    "cumpătările": "cumpătare",
    "cumpătărilor": "cumpătare",
    "cumpătata": "cumpătat",
    "cumpătată": "cumpătat",
    "cumpătate": "cumpătat",
    "cumpătatei": "cumpătat",
    "cumpătatele": "cumpătat",
    "cumpătatelor": "cumpătat",
    "cumpătați": "cumpătat",
    "cumpătații": "cumpătat",
    "cumpătaților": "cumpătat",
    "cumpătato": "cumpătat",
    "cumpătatul": "cumpătat",
    "cumpătatule": "cumpătat",
    "cumpătatului": "cumpătat",
    "cumplita": "cumplit",
    "cumplită": "cumplit",
    "cumplite": "cumplit",
    "cumplitei": "cumplit",
    "cumplitele": "cumplit",
    "cumplitelor": "cumplit",
    "cumpliți": "cumplit",
    "cumpliții": "cumplit",
    "cumpliților": "cumplit",
    "cumplito": "cumplit",
    "cumplitul": "cumplit",
    "cumplitule": "cumplit",
    "cumplitului": "cumplit",
    "cumsecădenia": "cumsecădenie",
    "cumsecădeniei": "cumsecădenie",
    "cumsecădenii": "cumsecădenie",
    "cumsecădeniile": "cumsecădenie",
    "cumsecădeniilor": "cumsecădenie",
    "cumsecădenio": "cumsecădenie",
    "cumulul": "cumul",
    "cumulule": "cumul",
    "cumulului": "cumul",
    "cumuluri": "cumul",
    "cumulurile": "cumul",
    "cumulurilor": "cumul",
    "cumulă": "cumula",
    "cumulai": "cumula",
    "cumulam": "cumula",
    "cumulăm": "cumula",
    "cumulând": "cumula",
    "cumulându": "cumula",
    "cumulară": "cumula",
    "cumularăm": "cumula",
    "cumularăți": "cumula",
    "cumulase": "cumula",
    "cumulasem": "cumula",
    "cumulaseră": "cumula",
    "cumulaserăm": "cumula",
    "cumulaserăți": "cumula",
    "cumulaseși": "cumula",
    "cumulași": "cumula",
    "cumulat": "cumula",
    "cumulați": "cumula",
    "cumulatu": "cumula",
    "cumulau": "cumula",
    "cumulează": "cumula",
    "cumulez": "cumula",
    "cumuleze": "cumula",
    "cumulezi": "cumula",
    "necumulând": "cumula",
    "necumulându": "cumula",
    "nemaicumulând": "cumula",
    "nemaicumulându": "cumula",
    "cumulardul": "cumulard",
    "cumulardule": "cumulard",
    "cumulardului": "cumulard",
    "cumularzi": "cumulard",
    "cumularzii": "cumulard",
    "cumularzilor": "cumulard",
    "cumularea": "cumulare",
    "cumulareo": "cumulare",
    "cumulări": "cumulare",
    "cumulării": "cumulare",
    "cumulările": "cumulare",
    "cumulărilor": "cumulare",
    "cumulată": "cumulat",
    "cumulate": "cumulat",
    "cumulați": "cumulat",
    "cumulativa": "cumulativ",
    "cumulativă": "cumulativ",
    "cumulative": "cumulativ",
    "cumulativei": "cumulativ",
    "cumulativele": "cumulativ",
    "cumulativelor": "cumulativ",
    "cumulativi": "cumulativ",
    "cumulativii": "cumulativ",
    "cumulativilor": "cumulativ",
    "cumulativo": "cumulativ",
    "cumulativul": "cumulativ",
    "cumulativule": "cumulativ",
    "cumulativului": "cumulativ",
    "cumulusul": "cumulus",
    "cumulusule": "cumulus",
    "cumulusului": "cumulus",
    "cuneiforme": "cuneiform",
    "cuneiformele": "cuneiform",
    "cuneiformelor": "cuneiform",
    "cuneiformul": "cuneiform",
    "cuneiformule": "cuneiform",
    "cuneiformului": "cuneiform",
    "cunoască": "cunoaște",
    "cunoaștem": "cunoaște",
    "cunoașteți": "cunoaște",
    "cunosc": "cunoaște",
    "cunoscând": "cunoaște",
    "cunoscându": "cunoaște",
    "cunoscu": "cunoaște",
    "cunoscui": "cunoaște",
    "cunoscură": "cunoaște",
    "cunoscurăm": "cunoaște",
    "cunoscurăți": "cunoaște",
    "cunoscuse": "cunoaște",
    "cunoscusem": "cunoaște",
    "cunoscuseră": "cunoaște",
    "cunoscuserăm": "cunoaște",
    "cunoscuserăți": "cunoaște",
    "cunoscuseși": "cunoaște",
    "cunoscuși": "cunoaște",
    "cunoscut": "cunoaște",
    "cunoscutu": "cunoaște",
    "cunoștea": "cunoaște",
    "cunoșteai": "cunoaște",
    "cunoșteam": "cunoaște",
    "cunoșteați": "cunoaște",
    "cunoșteau": "cunoaște",
    "cunoști": "cunoaște",
    "necunoscând": "cunoaște",
    "necunoscându": "cunoaște",
    "necunoscut": "cunoaște",
    "nemaicunoscând": "cunoaște",
    "nemaicunoscându": "cunoaște",
    "cunoașterea": "cunoaștere",
    "cunoaștereo": "cunoaștere",
    "cunoașteri": "cunoaștere",
    "cunoașterii": "cunoaștere",
    "cunoașterile": "cunoaștere",
    "cunoașterilor": "cunoaștere",
    "cunoscătoarea": "cunoscătoare",
    "cunoscătoarei": "cunoscătoare",
    "cunoscătoarele": "cunoscătoare",
    "cunoscătoarelor": "cunoscătoare",
    "cunoscătoareo": "cunoscătoare",
    "cunoscătoare": "cunoscător",
    "cunoscătoarea": "cunoscător",
    "cunoscătoarei": "cunoscător",
    "cunoscătoarele": "cunoscător",
    "cunoscătoarelor": "cunoscător",
    "cunoscătoareo": "cunoscător",
    "cunoscători": "cunoscător",
    "cunoscătorii": "cunoscător",
    "cunoscătorilor": "cunoscător",
    "cunoscătorul": "cunoscător",
    "cunoscătorule": "cunoscător",
    "cunoscătorului": "cunoscător",
    "cunoscuta": "cunoscut",
    "cunoscută": "cunoscut",
    "cunoscute": "cunoscut",
    "cunoscutei": "cunoscut",
    "cunoscutele": "cunoscut",
    "cunoscutelor": "cunoscut",
    "cunoscuți": "cunoscut",
    "cunoscuții": "cunoscut",
    "cunoscuților": "cunoscut",
    "cunoscuto": "cunoscut",
    "cunoscutul": "cunoscut",
    "cunoscutule": "cunoscut",
    "cunoscutului": "cunoscut",
    "cunoscuta": "cunoscută",
    "cunoscute": "cunoscută",
    "cunoscutei": "cunoscută",
    "cunoscutele": "cunoscută",
    "cunoscutelor": "cunoscută",
    "cunoscuto": "cunoscută",
    "cunoștința": "cunoștință",
    "cunoștințe": "cunoștință",
    "cunoștinței": "cunoștință",
    "cunoștințele": "cunoștință",
    "cunoștințelor": "cunoștință",
    "cunoștințo": "cunoștință",
    "cunun": "cununa",
    "cunună": "cununa",
    "cununai": "cununa",
    "cununam": "cununa",
    "cununăm": "cununa",
    "cununând": "cununa",
    "cununându": "cununa",
    "cununară": "cununa",
    "cununarăm": "cununa",
    "cununarăți": "cununa",
    "cununase": "cununa",
    "cununasem": "cununa",
    "cununaseră": "cununa",
    "cununaserăm": "cununa",
    "cununaserăți": "cununa",
    "cununaseși": "cununa",
    "cununași": "cununa",
    "cununat": "cununa",
    "cununați": "cununa",
    "cununatu": "cununa",
    "cununau": "cununa",
    "cunune": "cununa",
    "cununi": "cununa",
    "necununând": "cununa",
    "necununându": "cununa",
    "nemaicununând": "cununa",
    "nemaicununându": "cununa",
    "cununa": "cunună",
    "cununi": "cunună",
    "cununii": "cunună",
    "cununile": "cunună",
    "cununilor": "cunună",
    "cununo": "cunună",
    "cununata": "cununat",
    "cununată": "cununat",
    "cununate": "cununat",
    "cununatei": "cununat",
    "cununatele": "cununat",
    "cununatelor": "cununat",
    "cununați": "cununat",
    "cununații": "cununat",
    "cununaților": "cununat",
    "cununato": "cununat",
    "cununatul": "cununat",
    "cununatule": "cununat",
    "cununatului": "cununat",
    "cununia": "cununie",
    "cununiei": "cununie",
    "cununii": "cununie",
    "cununiile": "cununie",
    "cununiilor": "cununie",
    "cununio": "cununie",
    "cupa": "cupă",
    "cupe": "cupă",
    "cupei": "cupă",
    "cupele": "cupă",
    "cupelor": "cupă",
    "cupo": "cupă",
    "cupeul": "cupeu",
    "cupeule": "cupeu",
    "cupeului": "cupeu",
    "cupeuri": "cupeu",
    "cupeurile": "cupeu",
    "cupeurilor": "cupeu",
    "cupida": "cupid",
    "cupidă": "cupid",
    "cupide": "cupid",
    "cupidei": "cupid",
    "cupidele": "cupid",
    "cupidelor": "cupid",
    "cupido": "cupid",
    "cupidul": "cupid",
    "cupidule": "cupid",
    "cupidului": "cupid",
    "cupizi": "cupid",
    "cupizii": "cupid",
    "cupizilor": "cupid",
    "cuplă": "cupla",
    "cuplai": "cupla",
    "cuplam": "cupla",
    "cuplăm": "cupla",
    "cuplând": "cupla",
    "cuplându": "cupla",
    "cuplară": "cupla",
    "cuplarăm": "cupla",
    "cuplarăți": "cupla",
    "cuplase": "cupla",
    "cuplasem": "cupla",
    "cuplaseră": "cupla",
    "cuplaserăm": "cupla",
    "cuplaserăți": "cupla",
    "cuplaseși": "cupla",
    "cuplași": "cupla",
    "cuplat": "cupla",
    "cuplați": "cupla",
    "cuplatu": "cupla",
    "cuplau": "cupla",
    "cuplează": "cupla",
    "cuplez": "cupla",
    "cupleze": "cupla",
    "cuplezi": "cupla",
    "necuplând": "cupla",
    "necuplându": "cupla",
    "nemaicuplând": "cupla",
    "nemaicuplându": "cupla",
    "cupla": "cuplă",
    "cuple": "cuplă",
    "cuplei": "cuplă",
    "cuplele": "cuplă",
    "cuplelor": "cuplă",
    "cuplo": "cuplă",
    "cuplaje": "cuplaj",
    "cuplajele": "cuplaj",
    "cuplajelor": "cuplaj",
    "cuplajul": "cuplaj",
    "cuplajule": "cuplaj",
    "cuplajului": "cuplaj",
    "cuplarea": "cuplare",
    "cuplareo": "cuplare",
    "cuplări": "cuplare",
    "cuplării": "cuplare",
    "cuplările": "cuplare",
    "cuplărilor": "cuplare",
    "cuplata": "cuplat",
    "cuplată": "cuplat",
    "cuplate": "cuplat",
    "cuplatei": "cuplat",
    "cuplatele": "cuplat",
    "cuplatelor": "cuplat",
    "cuplați": "cuplat",
    "cuplații": "cuplat",
    "cuplaților": "cuplat",
    "cuplato": "cuplat",
    "cuplatul": "cuplat",
    "cuplatule": "cuplat",
    "cuplatului": "cuplat",
    "cuplete": "cuplet",
    "cupletele": "cuplet",
    "cupletelor": "cuplet",
    "cupletul": "cuplet",
    "cupletule": "cuplet",
    "cupletului": "cuplet",
    "cuplul": "cuplu",
    "cuplule": "cuplu",
    "cuplului": "cuplu",
    "cupluri": "cuplu",
    "cuplurile": "cuplu",
    "cuplurilor": "cuplu",
    "cuplul-maestru": "cuplu-maestru",
    "cupola": "cupolă",
    "cupole": "cupolă",
    "cupolei": "cupolă",
    "cupolele": "cupolă",
    "cupolelor": "cupolă",
    "cupolo": "cupolă",
    "cupoane": "cupon",
    "cupoanele": "cupon",
    "cupoanelor": "cupon",
    "cuponul": "cupon",
    "cuponule": "cupon",
    "cuponului": "cupon",
    "cuprind": "cuprinde",
    "cuprindă": "cuprinde",
    "cuprindea": "cuprinde",
    "cuprindeai": "cuprinde",
    "cuprindeam": "cuprinde",
    "cuprindeați": "cuprinde",
    "cuprindeau": "cuprinde",
    "cuprindem": "cuprinde",
    "cuprindeți": "cuprinde",
    "cuprins": "cuprinde",
    "cuprinse": "cuprinde",
    "cuprinsei": "cuprinde",
    "cuprinseră": "cuprinde",
    "cuprinserăm": "cuprinde",
    "cuprinserăți": "cuprinde",
    "cuprinsese": "cuprinde",
    "cuprinsesem": "cuprinde",
    "cuprinseseră": "cuprinde",
    "cuprinseserăm": "cuprinde",
    "cuprinseserăți": "cuprinde",
    "cuprinseseși": "cuprinde",
    "cuprinseși": "cuprinde",
    "cuprinsu": "cuprinde",
    "cuprinzând": "cuprinde",
    "cuprinzându": "cuprinde",
    "cuprinzi": "cuprinde",
    "necuprinzând": "cuprinde",
    "necuprinzându": "cuprinde",
    "nemaicuprinzând": "cuprinde",
    "nemaicuprinzându": "cuprinde",
    "cuprinderea": "cuprindere",
    "cuprindereo": "cuprindere",
    "cuprinderi": "cuprindere",
    "cuprinderii": "cuprindere",
    "cuprinderile": "cuprindere",
    "cuprinderilor": "cuprindere",
    "cuprinsa": "cuprins",
    "cuprinsă": "cuprins",
    "cuprinse": "cuprins",
    "cuprinsei": "cuprins",
    "cuprinsele": "cuprins",
    "cuprinselor": "cuprins",
    "cuprinși": "cuprins",
    "cuprinșii": "cuprins",
    "cuprinșilor": "cuprins",
    "cuprinso": "cuprins",
    "cuprinsul": "cuprins",
    "cuprinsule": "cuprins",
    "cuprinsului": "cuprins",
    "cuprinsuri": "cuprins",
    "cuprinsurile": "cuprins",
    "cuprinsurilor": "cuprins",
    "cuprinzătoare": "cuprinzător",
    "cuprinzătoarea": "cuprinzător",
    "cuprinzătoarei": "cuprinzător",
    "cuprinzătoarele": "cuprinzător",
    "cuprinzătoarelor": "cuprinzător",
    "cuprinzătoareo": "cuprinzător",
    "cuprinzători": "cuprinzător",
    "cuprinzătorii": "cuprinzător",
    "cuprinzătorilor": "cuprinzător",
    "cuprinzătorul": "cuprinzător",
    "cuprinzătorule": "cuprinzător",
    "cuprinzătorului": "cuprinzător",
    "cupriți": "cuprit",
    "cupriții": "cuprit",
    "cupriților": "cuprit",
    "cupritul": "cuprit",
    "cupritule": "cuprit",
    "cupritului": "cuprit",
    "Cu": "cupru",
    "cuprul": "cupru",
    "cuprule": "cupru",
    "cuprului": "cupru",
    "cuptoare": "cuptor",
    "cuptoarele": "cuptor",
    "cuptoarelor": "cuptor",
    "cuptorul": "cuptor",
    "cuptorule": "cuptor",
    "cuptorului": "cuptor",
    "curul": "cur",
    "curule": "cur",
    "curului": "cur",
    "cura": "cură",
    "cure": "cură",
    "curei": "cură",
    "curele": "cură",
    "curelor": "cură",
    "curo": "cură",
    "curabila": "curabil",
    "curabilă": "curabil",
    "curabile": "curabil",
    "curabilei": "curabil",
    "curabilele": "curabil",
    "curabilelor": "curabil",
    "curabili": "curabil",
    "curabilii": "curabil",
    "curabililor": "curabil",
    "curabilo": "curabil",
    "curabilul": "curabil",
    "curabilule": "curabil",
    "curabilului": "curabil",
    "curajul": "curaj",
    "curajule": "curaj",
    "curajului": "curaj",
    "curajuri": "curaj",
    "curajurile": "curaj",
    "curajurilor": "curaj",
    "curajoasa": "curajos",
    "curajoasă": "curajos",
    "curajoase": "curajos",
    "curajoasei": "curajos",
    "curajoasele": "curajos",
    "curajoaselor": "curajos",
    "curajoaso": "curajos",
    "curajoși": "curajos",
    "curajoșii": "curajos",
    "curajoșilor": "curajos",
    "curajosul": "curajos",
    "curajosule": "curajos",
    "curajosului": "curajos",
    "curanta": "curant",
    "curantă": "curant",
    "curante": "curant",
    "curantei": "curant",
    "curantele": "curant",
    "curantelor": "curant",
    "curanți": "curant",
    "curanții": "curant",
    "curanților": "curant",
    "curanto": "curant",
    "curantul": "curant",
    "curantule": "curant",
    "curantului": "curant",
    "curata": "curat",
    "curată": "curat",
    "curate": "curat",
    "curatei": "curat",
    "curatele": "curat",
    "curatelor": "curat",
    "curați": "curat",
    "curații": "curat",
    "curaților": "curat",
    "curato": "curat",
    "curatul": "curat",
    "curatule": "curat",
    "curatului": "curat",
    "curăț": "curăța",
    "curăță": "curăța",
    "curățai": "curăța",
    "curățam": "curăța",
    "curățăm": "curăța",
    "curățând": "curăța",
    "curățându": "curăța",
    "curățară": "curăța",
    "curățarăm": "curăța",
    "curățarăți": "curăța",
    "curățase": "curăța",
    "curățasem": "curăța",
    "curățaseră": "curăța",
    "curățaserăm": "curăța",
    "curățaserăți": "curăța",
    "curățaseși": "curăța",
    "curățași": "curăța",
    "curățat": "curăța",
    "curățați": "curăța",
    "curățatu": "curăța",
    "curățau": "curăța",
    "curețe": "curăța",
    "cureți": "curăța",
    "necurățând": "curăța",
    "necurățându": "curăța",
    "nemaicurățând": "curăța",
    "nemaicurățându": "curăța",
    "curățarea": "curățare",
    "curățareo": "curățare",
    "curățări": "curățare",
    "curățării": "curățare",
    "curățările": "curățare",
    "curățărilor": "curățare",
    "curățată": "curățat",
    "curățate": "curățat",
    "curățați": "curățat",
    "curățatul": "curățat",
    "curățatule": "curățat",
    "curățatului": "curățat",
    "curățenia": "curățenie",
    "curățeniei": "curățenie",
    "curățenii": "curățenie",
    "curățeniile": "curățenie",
    "curățeniilor": "curățenie",
    "curățenio": "curățenie",
    "curățea": "curăți",
    "curățeai": "curăți",
    "curățeam": "curăți",
    "curățească": "curăți",
    "curățeați": "curăți",
    "curățeau": "curăți",
    "curățesc": "curăți",
    "curățește": "curăți",
    "curățești": "curăți",
    "curății": "curăți",
    "curățim": "curăți",
    "curățind": "curăți",
    "curățindu": "curăți",
    "curățiră": "curăți",
    "curățirăm": "curăți",
    "curățirăți": "curăți",
    "curățise": "curăți",
    "curățisem": "curăți",
    "curățiseră": "curăți",
    "curățiserăm": "curăți",
    "curățiserăți": "curăți",
    "curățiseși": "curăți",
    "curățiși": "curăți",
    "curățit": "curăți",
    "curățiți": "curăți",
    "curățitu": "curăți",
    "necurățind": "curăți",
    "necurățindu": "curăți",
    "nemaicurățind": "curăți",
    "nemaicurățindu": "curăți",
    "curăția": "curăție",
    "curăției": "curăție",
    "curății": "curăție",
    "curățiile": "curăție",
    "curățiilor": "curăție",
    "curățio": "curăție",
    "curățirea": "curățire",
    "curățireo": "curățire",
    "curățiri": "curățire",
    "curățirii": "curățire",
    "curățirile": "curățire",
    "curățirilor": "curățire",
    "curățită": "curățit",
    "curățite": "curățit",
    "curățiți": "curățit",
    "curățitul": "curățit",
    "curățitule": "curățit",
    "curățitului": "curățit",
    "curativa": "curativ",
    "curativă": "curativ",
    "curative": "curativ",
    "curativei": "curativ",
    "curativele": "curativ",
    "curativelor": "curativ",
    "curativi": "curativ",
    "curativii": "curativ",
    "curativilor": "curativ",
    "curativo": "curativ",
    "curativul": "curativ",
    "curativule": "curativ",
    "curativului": "curativ",
    "curba": "curb",
    "curbă": "curb",
    "curbe": "curb",
    "curbei": "curb",
    "curbele": "curb",
    "curbelor": "curb",
    "curbi": "curb",
    "curbii": "curb",
    "curbilor": "curb",
    "curbo": "curb",
    "curbul": "curb",
    "curbule": "curb",
    "curbului": "curb",
    "curbă": "curba",
    "curbai": "curba",
    "curbam": "curba",
    "curbăm": "curba",
    "curbând": "curba",
    "curbându": "curba",
    "curbară": "curba",
    "curbarăm": "curba",
    "curbarăți": "curba",
    "curbase": "curba",
    "curbasem": "curba",
    "curbaseră": "curba",
    "curbaserăm": "curba",
    "curbaserăți": "curba",
    "curbaseși": "curba",
    "curbași": "curba",
    "curbat": "curba",
    "curbați": "curba",
    "curbatu": "curba",
    "curbau": "curba",
    "curbează": "curba",
    "curbez": "curba",
    "curbeze": "curba",
    "curbezi": "curba",
    "necurbând": "curba",
    "necurbându": "curba",
    "nemaicurbând": "curba",
    "nemaicurbându": "curba",
    "curba": "curbă",
    "curbe": "curbă",
    "curbei": "curbă",
    "curbele": "curbă",
    "curbelor": "curbă",
    "curbo": "curbă",
    "curbarea": "curbare",
    "curbareo": "curbare",
    "curbări": "curbare",
    "curbării": "curbare",
    "curbările": "curbare",
    "curbărilor": "curbare",
    "curbata": "curbat",
    "curbată": "curbat",
    "curbate": "curbat",
    "curbatei": "curbat",
    "curbatele": "curbat",
    "curbatelor": "curbat",
    "curbați": "curbat",
    "curbații": "curbat",
    "curbaților": "curbat",
    "curbato": "curbat",
    "curbatul": "curbat",
    "curbatule": "curbat",
    "curbatului": "curbat",
    "curbatura": "curbatură",
    "curbaturi": "curbatură",
    "curbaturii": "curbatură",
    "curbaturile": "curbatură",
    "curbaturilor": "curbatură",
    "curbaturo": "curbatură",
    "curbilinia": "curbiliniu",
    "curbilinie": "curbiliniu",
    "curbiliniei": "curbiliniu",
    "curbilinii": "curbiliniu",
    "curbiliniii": "curbiliniu",
    "curbiliniile": "curbiliniu",
    "curbiliniilor": "curbiliniu",
    "curbilinio": "curbiliniu",
    "curbiliniul": "curbiliniu",
    "curbiliniule": "curbiliniu",
    "curbiliniului": "curbiliniu",
    "curbura": "curbură",
    "curburi": "curbură",
    "curburii": "curbură",
    "curburile": "curbură",
    "curburilor": "curbură",
    "curburo": "curbură",
    "curcani": "curcan",
    "curcanii": "curcan",
    "curcanilor": "curcan",
    "curcanul": "curcan",
    "curcanule": "curcan",
    "curcanului": "curcan",
    "curcubee": "curcubeu",
    "curcubeele": "curcubeu",
    "curcubeelor": "curcubeu",
    "curcubeul": "curcubeu",
    "curcubeule": "curcubeu",
    "curcubeului": "curcubeu",
    "cureao": "curea",
    "cureaua": "curea",
    "curele": "curea",
    "curelei": "curea",
    "curelele": "curea",
    "curelelor": "curea",
    "curelari": "curelar",
    "curelarii": "curelar",
    "curelarilor": "curelar",
    "curelarul": "curelar",
    "curelarului": "curelar",
    "crt.": "curent",
    "curenta": "curent",
    "curentă": "curent",
    "curente": "curent",
    "curentei": "curent",
    "curentele": "curent",
    "curentelor": "curent",
    "curenți": "curent",
    "curenții": "curent",
    "curenților": "curent",
    "curento": "curent",
    "curentu": "curent",
    "curentu'": "curent",
    "curentul": "curent",
    "curentule": "curent",
    "curentului": "curent",
    "curentă": "curenta",
    "curentai": "curenta",
    "curentam": "curenta",
    "curentăm": "curenta",
    "curentând": "curenta",
    "curentându": "curenta",
    "curentară": "curenta",
    "curentarăm": "curenta",
    "curentarăți": "curenta",
    "curentase": "curenta",
    "curentasem": "curenta",
    "curentaseră": "curenta",
    "curentaserăm": "curenta",
    "curentaserăți": "curenta",
    "curentaseși": "curenta",
    "curentași": "curenta",
    "curentat": "curenta",
    "curentați": "curenta",
    "curentatu": "curenta",
    "curentau": "curenta",
    "curentează": "curenta",
    "curentez": "curenta",
    "curenteze": "curenta",
    "curentezi": "curenta",
    "necurentând": "curenta",
    "necurentându": "curenta",
    "nemaicurentând": "curenta",
    "nemaicurentându": "curenta",
    "curentată": "curentat",
    "curentate": "curentat",
    "curentați": "curentat",
    "curgătoare": "curgător",
    "curgătoarea": "curgător",
    "curgătoarei": "curgător",
    "curgătoarele": "curgător",
    "curgătoarelor": "curgător",
    "curgătoareo": "curgător",
    "curgători": "curgător",
    "curgătorii": "curgător",
    "curgătorilor": "curgător",
    "curgătorul": "curgător",
    "curgătorule": "curgător",
    "curgătorului": "curgător",
    "curg": "curge",
    "curgă": "curge",
    "curgând": "curge",
    "curgându": "curge",
    "curgea": "curge",
    "curgeai": "curge",
    "curgeam": "curge",
    "curgeați": "curge",
    "curgeau": "curge",
    "curgem": "curge",
    "curgeți": "curge",
    "curgi": "curge",
    "curs": "curge",
    "curse": "curge",
    "cursei": "curge",
    "curseră": "curge",
    "curserăm": "curge",
    "curserăți": "curge",
    "cursese": "curge",
    "cursesem": "curge",
    "curseseră": "curge",
    "curseserăm": "curge",
    "curseserăți": "curge",
    "curseseși": "curge",
    "curseși": "curge",
    "cursu": "curge",
    "necurgând": "curge",
    "necurgându": "curge",
    "nemaicurgând": "curge",
    "nemaicurgându": "curge",
    "curgerea": "curgere",
    "curgereo": "curgere",
    "curgeri": "curgere",
    "curgerii": "curgere",
    "curgerile": "curgere",
    "curgerilor": "curgere",
    "curia": "curie",
    "curiei": "curie",
    "curii": "curie",
    "curiile": "curie",
    "curiilor": "curie",
    "curieri": "curier",
    "curierii": "curier",
    "curierilor": "curier",
    "curierul": "curier",
    "curierule": "curier",
    "curierului": "curier",
    "curiera": "curieră",
    "curiere": "curieră",
    "curierei": "curieră",
    "curierele": "curieră",
    "curierelor": "curieră",
    "curiero": "curieră",
    "curioasa": "curios",
    "curioasă": "curios",
    "curioase": "curios",
    "curioasei": "curios",
    "curioasele": "curios",
    "curioaselor": "curios",
    "curioaso": "curios",
    "curioși": "curios",
    "curioșii": "curios",
    "curioșilor": "curios",
    "curiosul": "curios",
    "curiosule": "curios",
    "curiosului": "curios",
    "curiozitatea": "curiozitate",
    "curiozitateo": "curiozitate",
    "curiozități": "curiozitate",
    "curiozității": "curiozitate",
    "curiozitățile": "curiozitate",
    "curiozităților": "curiozitate",
    "curiști": "curist",
    "curiștii": "curist",
    "curiștilor": "curist",
    "curistul": "curist",
    "curistule": "curist",
    "curistului": "curist",
    "curista": "curistă",
    "curiste": "curistă",
    "curistei": "curistă",
    "curistele": "curistă",
    "curistelor": "curistă",
    "curisto": "curistă",
    "curluntrismul": "curluntrism",
    "curm": "curma",
    "curmă": "curma",
    "curmai": "curma",
    "curmam": "curma",
    "curmăm": "curma",
    "curmând": "curma",
    "curmându": "curma",
    "curmară": "curma",
    "curmarăm": "curma",
    "curmarăți": "curma",
    "curmase": "curma",
    "curmasem": "curma",
    "curmaseră": "curma",
    "curmaserăm": "curma",
    "curmaserăți": "curma",
    "curmaseși": "curma",
    "curmași": "curma",
    "curmat": "curma",
    "curmați": "curma",
    "curmatu": "curma",
    "curmau": "curma",
    "curme": "curma",
    "curmi": "curma",
    "necurmând": "curma",
    "necurmându": "curma",
    "nemaicurmând": "curma",
    "nemaicurmându": "curma",
    "curmali": "curmal",
    "curmalii": "curmal",
    "curmalilor": "curmal",
    "curmalul": "curmal",
    "curmalule": "curmal",
    "curmalului": "curmal",
    "curmala": "curmală",
    "curmale": "curmală",
    "curmalei": "curmală",
    "curmalele": "curmală",
    "curmalelor": "curmală",
    "curmalo": "curmală",
    "curmarea": "curmare",
    "curmareo": "curmare",
    "curmări": "curmare",
    "curmării": "curmare",
    "curmările": "curmare",
    "curmărilor": "curmare",
    "curmata": "curmat",
    "curmată": "curmat",
    "curmate": "curmat",
    "curmatei": "curmat",
    "curmatele": "curmat",
    "curmatelor": "curmat",
    "curmați": "curmat",
    "curmații": "curmat",
    "curmaților": "curmat",
    "curmato": "curmat",
    "curmatul": "curmat",
    "curmatule": "curmat",
    "curmatului": "curmat",
    "curmătura": "curmătură",
    "curmături": "curmătură",
    "curmăturii": "curmătură",
    "curmăturile": "curmătură",
    "curmăturilor": "curmătură",
    "curmăturo": "curmătură",
    "curmeie": "curmei",
    "curmeiele": "curmei",
    "curmeielor": "curmei",
    "curmeiul": "curmei",
    "curmeiule": "curmei",
    "curmeiului": "curmei",
    "curpeni": "curpen",
    "curpenii": "curpen",
    "curpenilor": "curpen",
    "curpenul": "curpen",
    "curpenule": "curpen",
    "curpenului": "curpen",
    "c.v.": "curriculum_vitae",
    "cursă": "curs",
    "curse": "curs",
    "curși": "curs",
    "cursul": "curs",
    "cursule": "curs",
    "cursului": "curs",
    "cursuri": "curs",
    "cursurile": "curs",
    "cursurilor": "curs",
    "cursa": "cursă",
    "curse": "cursă",
    "cursei": "cursă",
    "cursele": "cursă",
    "curselor": "cursă",
    "curso": "cursă",
    "cursanți": "cursant",
    "cursanții": "cursant",
    "cursanților": "cursant",
    "cursantul": "cursant",
    "cursantule": "cursant",
    "cursantului": "cursant",
    "cursanta": "cursantă",
    "cursante": "cursantă",
    "cursantei": "cursantă",
    "cursantele": "cursantă",
    "cursantelor": "cursantă",
    "cursanto": "cursantă",
    "cursiva": "cursiv",
    "cursivă": "cursiv",
    "cursive": "cursiv",
    "cursivei": "cursiv",
    "cursivele": "cursiv",
    "cursivelor": "cursiv",
    "cursivi": "cursiv",
    "cursivii": "cursiv",
    "cursivilor": "cursiv",
    "cursivo": "cursiv",
    "cursivul": "cursiv",
    "cursivule": "cursiv",
    "cursivului": "cursiv",
    "cursivitatea": "cursivitate",
    "cursivitateo": "cursivitate",
    "cursivități": "cursivitate",
    "cursivității": "cursivitate",
    "cursivitățile": "cursivitate",
    "cursivităților": "cursivitate",
    "cursoare": "cursor",
    "cursoarele": "cursor",
    "cursoarelor": "cursor",
    "cursorul": "cursor",
    "cursorule": "cursor",
    "cursorului": "cursor",
    "curtă": "curta",
    "curtai": "curta",
    "curtam": "curta",
    "curtăm": "curta",
    "curtând": "curta",
    "curtându": "curta",
    "curtară": "curta",
    "curtarăm": "curta",
    "curtarăți": "curta",
    "curtase": "curta",
    "curtasem": "curta",
    "curtaseră": "curta",
    "curtaserăm": "curta",
    "curtaserăți": "curta",
    "curtaseși": "curta",
    "curtași": "curta",
    "curtat": "curta",
    "curtați": "curta",
    "curtatu": "curta",
    "curtau": "curta",
    "curtează": "curta",
    "curtez": "curta",
    "curteze": "curta",
    "curtezi": "curta",
    "necurtând": "curta",
    "necurtându": "curta",
    "nemaicurtând": "curta",
    "nemaicurtându": "curta",
    "curtată": "curtat",
    "curtate": "curtat",
    "curtați": "curtat",
    "curtea": "curte",
    "curteo": "curte",
    "curți": "curte",
    "curții": "curte",
    "curțile": "curte",
    "curților": "curte",
    "curteanul": "curtean",
    "curteanule": "curtean",
    "curteanului": "curtean",
    "curteni": "curtean",
    "curtenii": "curtean",
    "curtenilor": "curtean",
    "curteana": "curteană",
    "curteano": "curteană",
    "curtene": "curteană",
    "curtenei": "curteană",
    "curtenele": "curteană",
    "curtenelor": "curteană",
    "curteanca": "curteancă",
    "curteanco": "curteancă",
    "curtence": "curteancă",
    "curtencei": "curteancă",
    "curtencele": "curteancă",
    "curtencelor": "curteancă",
    "curtenitoare": "curtenitor",
    "curtenitoarea": "curtenitor",
    "curtenitoarei": "curtenitor",
    "curtenitoarele": "curtenitor",
    "curtenitoarelor": "curtenitor",
    "curtenitoareo": "curtenitor",
    "curtenitori": "curtenitor",
    "curtenitorii": "curtenitor",
    "curtenitorilor": "curtenitor",
    "curtenitorul": "curtenitor",
    "curtenitorule": "curtenitor",
    "curtenitorului": "curtenitor",
    "curtezani": "curtezan",
    "curtezanii": "curtezan",
    "curtezanilor": "curtezan",
    "curtezanul": "curtezan",
    "curtezanule": "curtezan",
    "curtezanului": "curtezan",
    "curtezana": "curtezană",
    "curtezane": "curtezană",
    "curtezanei": "curtezană",
    "curtezanele": "curtezană",
    "curtezanelor": "curtezană",
    "curtezano": "curtezană",
    "curtoazia": "curtoazie",
    "curtoaziei": "curtoazie",
    "curtoazii": "curtoazie",
    "curtoaziile": "curtoazie",
    "curtoaziilor": "curtoazie",
    "curtoazio": "curtoazie",
    "curva": "curvă",
    "curve": "curvă",
    "curvei": "curvă",
    "curvele": "curvă",
    "curvelor": "curvă",
    "curvo": "curvă",
    "curvăsăria": "curvăsărie",
    "curvăsăriei": "curvăsărie",
    "curvăsării": "curvăsărie",
    "curvăsăriile": "curvăsărie",
    "curvăsăriilor": "curvăsărie",
    "curvăsărio": "curvăsărie",
    "cusătura": "cusătură",
    "cusături": "cusătură",
    "cusăturii": "cusătură",
    "cusăturile": "cusătură",
    "cusăturilor": "cusătură",
    "cusăturo": "cusătură",
    "cușca": "cușcă",
    "cușco": "cușcă",
    "cuști": "cușcă",
    "cuștii": "cușcă",
    "cuștile": "cușcă",
    "cuștilor": "cușcă",
    "cuscra": "cuscră",
    "cuscre": "cuscră",
    "cuscrei": "cuscră",
    "cuscrele": "cuscră",
    "cuscrelor": "cuscră",
    "cuscro": "cuscră",
    "cuscri": "cuscru",
    "cuscrii": "cuscru",
    "cuscrilor": "cuscru",
    "cuscrul": "cuscru",
    "cuscrule": "cuscru",
    "cuscrului": "cuscru",
    "cușcușul": "cușcuș",
    "cușcușule": "cușcuș",
    "cușcușului": "cușcuș",
    "cușeta": "cușetă",
    "cușete": "cușetă",
    "cușetei": "cușetă",
    "cușetele": "cușetă",
    "cușetelor": "cușetă",
    "cușeto": "cușetă",
    "cușma": "cușmă",
    "cușme": "cușmă",
    "cușmei": "cușmă",
    "cușmele": "cușmă",
    "cușmelor": "cușmă",
    "cușmo": "cușmă",
    "cușnița": "cușniță",
    "cușnițe": "cușniță",
    "cușniței": "cușniță",
    "cușnițele": "cușniță",
    "cușnițelor": "cușniță",
    "cușnițo": "cușniță",
    "custodele": "custode",
    "custodelui": "custode",
    "custozi": "custode",
    "custozii": "custode",
    "custozilor": "custode",
    "custodia": "custodie",
    "custodiei": "custodie",
    "custodii": "custodie",
    "custodiile": "custodie",
    "custodiilor": "custodie",
    "custura": "custură",
    "custuri": "custură",
    "custurii": "custură",
    "custurile": "custură",
    "custurilor": "custură",
    "custuro": "custură",
    "cusurul": "cusur",
    "cusurule": "cusur",
    "cusurului": "cusur",
    "cusururi": "cusur",
    "cusururile": "cusur",
    "cusururilor": "cusur",
    "cusurgioaica": "cusurgioaică",
    "cusurgioaice": "cusurgioaică",
    "cusurgioaicei": "cusurgioaică",
    "cusurgioaicele": "cusurgioaică",
    "cusurgioaicelor": "cusurgioaică",
    "cusurgioaico": "cusurgioaică",
    "cusurgia": "cusurgiu",
    "cusurgie": "cusurgiu",
    "cusurgiei": "cusurgiu",
    "cusurgii": "cusurgiu",
    "cusurgiii": "cusurgiu",
    "cusurgiile": "cusurgiu",
    "cusurgiilor": "cusurgiu",
    "cusurgiul": "cusurgiu",
    "cusurgiule": "cusurgiu",
    "cusurgiului": "cusurgiu",
    "cusută": "cusut",
    "cusute": "cusut",
    "cusuți": "cusut",
    "cusutul": "cusut",
    "cusutule": "cusut",
    "cusutului": "cusut",
    "cută": "cuta",
    "cutai": "cuta",
    "cutam": "cuta",
    "cutăm": "cuta",
    "cutând": "cuta",
    "cutându": "cuta",
    "cutară": "cuta",
    "cutarăm": "cuta",
    "cutarăți": "cuta",
    "cutase": "cuta",
    "cutasem": "cuta",
    "cutaseră": "cuta",
    "cutaserăm": "cuta",
    "cutaserăți": "cuta",
    "cutaseși": "cuta",
    "cutași": "cuta",
    "cutat": "cuta",
    "cutați": "cuta",
    "cutatu": "cuta",
    "cutau": "cuta",
    "cutează": "cuta",
    "cutez": "cuta",
    "cuteze": "cuta",
    "cutezi": "cuta",
    "necutând": "cuta",
    "necutându": "cuta",
    "nemaicutând": "cuta",
    "nemaicutându": "cuta",
    "cuta": "cută",
    "cute": "cută",
    "cutei": "cută",
    "cutele": "cută",
    "cutelor": "cută",
    "cutanata": "cutanat",
    "cutanată": "cutanat",
    "cutanate": "cutanat",
    "cutanatei": "cutanat",
    "cutanatele": "cutanat",
    "cutanatelor": "cutanat",
    "cutanați": "cutanat",
    "cutanații": "cutanat",
    "cutanaților": "cutanat",
    "cutanato": "cutanat",
    "cutanatul": "cutanat",
    "cutanatule": "cutanat",
    "cutanatului": "cutanat",
    "cutanee": "cutaneu",
    "cutaneea": "cutaneu",
    "cutaneei": "cutaneu",
    "cutaneele": "cutaneu",
    "cutaneelor": "cutaneu",
    "cutaneeo": "cutaneu",
    "cutanei": "cutaneu",
    "cutaneii": "cutaneu",
    "cutaneilor": "cutaneu",
    "cutaneul": "cutaneu",
    "cutaneule": "cutaneu",
    "cutaneului": "cutaneu",
    "cutărei": "cutare",
    "cutăreia": "cutare",
    "cutăror": "cutare",
    "cutărui": "cutare",
    "cutăruia": "cutare",
    "cutata": "cutat",
    "cutată": "cutat",
    "cutate": "cutat",
    "cutatei": "cutat",
    "cutatele": "cutat",
    "cutatelor": "cutat",
    "cutați": "cutat",
    "cutații": "cutat",
    "cutaților": "cutat",
    "cutato": "cutat",
    "cutatul": "cutat",
    "cutatule": "cutat",
    "cutatului": "cutat",
    "cutea": "cute",
    "cutei": "cute",
    "cutele": "cute",
    "cutelor": "cute",
    "cuteo": "cute",
    "cutere": "cuter",
    "cuterele": "cuter",
    "cuterelor": "cuter",
    "cuterul": "cuter",
    "cuterule": "cuter",
    "cuterului": "cuter",
    "cutează": "cuteza",
    "cutez": "cuteza",
    "cuteză": "cuteza",
    "cutezai": "cuteza",
    "cutezam": "cuteza",
    "cutezăm": "cuteza",
    "cutezând": "cuteza",
    "cutezându": "cuteza",
    "cutezară": "cuteza",
    "cutezarăm": "cuteza",
    "cutezarăți": "cuteza",
    "cutezase": "cuteza",
    "cutezasem": "cuteza",
    "cutezaseră": "cuteza",
    "cutezaserăm": "cuteza",
    "cutezaserăți": "cuteza",
    "cutezaseși": "cuteza",
    "cutezași": "cuteza",
    "cutezat": "cuteza",
    "cutezați": "cuteza",
    "cutezatu": "cuteza",
    "cutezau": "cuteza",
    "cuteze": "cuteza",
    "cutezi": "cuteza",
    "necutezând": "cuteza",
    "necutezându": "cuteza",
    "nemaicutezând": "cuteza",
    "nemaicutezându": "cuteza",
    "cutezanța": "cutezanță",
    "cutezanțe": "cutezanță",
    "cutezanței": "cutezanță",
    "cutezanțele": "cutezanță",
    "cutezanțelor": "cutezanță",
    "cutezanțo": "cutezanță",
    "cutezarea": "cutezare",
    "cutezareo": "cutezare",
    "cutezări": "cutezare",
    "cutezării": "cutezare",
    "cutezările": "cutezare",
    "cutezărilor": "cutezare",
    "cutezată": "cutezat",
    "cutezate": "cutezat",
    "cutezați": "cutezat",
    "cutezătoare": "cutezător",
    "cutezătoarea": "cutezător",
    "cutezătoarei": "cutezător",
    "cutezătoarele": "cutezător",
    "cutezătoarelor": "cutezător",
    "cutezătoareo": "cutezător",
    "cutezători": "cutezător",
    "cutezătorii": "cutezător",
    "cutezătorilor": "cutezător",
    "cutezătorul": "cutezător",
    "cutezătorule": "cutezător",
    "cutezătorului": "cutezător",
    "cuticula": "cuticulă",
    "cuticule": "cuticulă",
    "cuticulei": "cuticulă",
    "cuticulele": "cuticulă",
    "cuticulelor": "cuticulă",
    "cuticulo": "cuticulă",
    "cutia": "cutie",
    "cutiei": "cutie",
    "cutii": "cutie",
    "cutiile": "cutie",
    "cutiilor": "cutie",
    "cutio": "cutie",
    "cuțite": "cuțit",
    "cuțitele": "cuțit",
    "cuțitelor": "cuțit",
    "cuțitul": "cuțit",
    "cuțitule": "cuțit",
    "cuțitului": "cuțit",
    "cuțitari": "cuțitar",
    "cuțitarii": "cuțitar",
    "cuțitarilor": "cuțitar",
    "cuțitarul": "cuțitar",
    "cuțitarule": "cuțitar",
    "cuțitarului": "cuțitar",
    "cutiuța": "cutiuță",
    "cutiuțe": "cutiuță",
    "cutiuței": "cutiuță",
    "cutiuțele": "cutiuță",
    "cutiuțelor": "cutiuță",
    "cutiuțo": "cutiuță",
    "cutra": "cutră",
    "cutre": "cutră",
    "cutrei": "cutră",
    "cutrele": "cutră",
    "cutrelor": "cutră",
    "cutro": "cutră",
    "cutreier": "cutreiera",
    "cutreieră": "cutreiera",
    "cutreierai": "cutreiera",
    "cutreieram": "cutreiera",
    "cutreierăm": "cutreiera",
    "cutreierând": "cutreiera",
    "cutreierându": "cutreiera",
    "cutreierară": "cutreiera",
    "cutreierarăm": "cutreiera",
    "cutreierarăți": "cutreiera",
    "cutreierase": "cutreiera",
    "cutreierasem": "cutreiera",
    "cutreieraseră": "cutreiera",
    "cutreieraserăm": "cutreiera",
    "cutreieraserăți": "cutreiera",
    "cutreieraseși": "cutreiera",
    "cutreierași": "cutreiera",
    "cutreierat": "cutreiera",
    "cutreierați": "cutreiera",
    "cutreieratu": "cutreiera",
    "cutreierau": "cutreiera",
    "cutreiere": "cutreiera",
    "cutreieri": "cutreiera",
    "necutreierând": "cutreiera",
    "necutreierându": "cutreiera",
    "nemaicutreierând": "cutreiera",
    "nemaicutreierându": "cutreiera",
    "cutreierată": "cutreierat",
    "cutreierate": "cutreierat",
    "cutreierați": "cutreierat",
    "cutreieratul": "cutreierat",
    "cutreieratule": "cutreierat",
    "cutreieratului": "cutreierat",
    "cutremure": "cutremur",
    "cutremurele": "cutremur",
    "cutremurelor": "cutremur",
    "cutremurul": "cutremur",
    "cutremurule": "cutremur",
    "cutremurului": "cutremur",
    "cutremur": "cutremura",
    "cutremură": "cutremura",
    "cutremurai": "cutremura",
    "cutremuram": "cutremura",
    "cutremurăm": "cutremura",
    "cutremurând": "cutremura",
    "cutremurându": "cutremura",
    "cutremurară": "cutremura",
    "cutremurarăm": "cutremura",
    "cutremurarăți": "cutremura",
    "cutremurase": "cutremura",
    "cutremurasem": "cutremura",
    "cutremuraseră": "cutremura",
    "cutremuraserăm": "cutremura",
    "cutremuraserăți": "cutremura",
    "cutremuraseși": "cutremura",
    "cutremurași": "cutremura",
    "cutremurat": "cutremura",
    "cutremurați": "cutremura",
    "cutremuratu": "cutremura",
    "cutremurau": "cutremura",
    "cutremure": "cutremura",
    "cutremuri": "cutremura",
    "necutremurând": "cutremura",
    "necutremurându": "cutremura",
    "nemaicutremurând": "cutremura",
    "nemaicutremurându": "cutremura",
    "cutremurarea": "cutremurare",
    "cutremurareo": "cutremurare",
    "cutremurări": "cutremurare",
    "cutremurării": "cutremurare",
    "cutremurările": "cutremurare",
    "cutremurărilor": "cutremurare",
    "cutremurată": "cutremurat",
    "cutremurate": "cutremurat",
    "cutremurați": "cutremurat",
    "cutremurătoare": "cutremurător",
    "cutremurătoarea": "cutremurător",
    "cutremurătoarei": "cutremurător",
    "cutremurătoarele": "cutremurător",
    "cutremurătoarelor": "cutremurător",
    "cutremurătoareo": "cutremurător",
    "cutremurători": "cutremurător",
    "cutremurătorii": "cutremurător",
    "cutremurătorilor": "cutremurător",
    "cutremurătorul": "cutremurător",
    "cutremurătorule": "cutremurător",
    "cutremurătorului": "cutremurător",
    "cuțulani": "cuțulan",
    "cuțulanii": "cuțulan",
    "cuțulanilor": "cuțulan",
    "cuțulanul": "cuțulan",
    "cuțulanule": "cuțulan",
    "cuțulanului": "cuțulan",
    "cutuma": "cutumă",
    "cutume": "cutumă",
    "cutumei": "cutumă",
    "cutumele": "cutumă",
    "cutumelor": "cutumă",
    "cutumo": "cutumă",
    "cuva": "cuvă",
    "cuve": "cuvă",
    "cuvei": "cuvă",
    "cuvele": "cuvă",
    "cuvelor": "cuvă",
    "cuvo": "cuvă",
    "cuv.": "cuvânt",
    "cuvân'": "cuvânt",
    "cuvântu": "cuvânt",
    "cuvântu'": "cuvânt",
    "cuvântul": "cuvânt",
    "cuvântule": "cuvânt",
    "cuvântului": "cuvânt",
    "cuvinte": "cuvânt",
    "cuvintele": "cuvânt",
    "cuvintelor": "cuvânt",
    "cuvânt": "cuvânta",
    "cuvântă": "cuvânta",
    "cuvântai": "cuvânta",
    "cuvântam": "cuvânta",
    "cuvântăm": "cuvânta",
    "cuvântând": "cuvânta",
    "cuvântându": "cuvânta",
    "cuvântară": "cuvânta",
    "cuvântarăm": "cuvânta",
    "cuvântarăți": "cuvânta",
    "cuvântase": "cuvânta",
    "cuvântasem": "cuvânta",
    "cuvântaseră": "cuvânta",
    "cuvântaserăm": "cuvânta",
    "cuvântaserăți": "cuvânta",
    "cuvântaseși": "cuvânta",
    "cuvântași": "cuvânta",
    "cuvântat": "cuvânta",
    "cuvântați": "cuvânta",
    "cuvântatu": "cuvânta",
    "cuvântau": "cuvânta",
    "cuvânte": "cuvânta",
    "cuvânți": "cuvânta",
    "necuvântând": "cuvânta",
    "necuvântându": "cuvânta",
    "nemaicuvântând": "cuvânta",
    "nemaicuvântându": "cuvânta",
    "cuvântarea": "cuvântare",
    "cuvântareo": "cuvântare",
    "cuvântări": "cuvântare",
    "cuvântării": "cuvântare",
    "cuvântările": "cuvântare",
    "cuvântărilor": "cuvântare",
    "cuvântată": "cuvântat",
    "cuvântate": "cuvântat",
    "cuvântați": "cuvântat",
    "cuvântătoare": "cuvântător",
    "cuvântătoarea": "cuvântător",
    "cuvântătoarei": "cuvântător",
    "cuvântătoarele": "cuvântător",
    "cuvântătoarelor": "cuvântător",
    "cuvântătoareo": "cuvântător",
    "cuvântători": "cuvântător",
    "cuvântătorii": "cuvântător",
    "cuvântătorilor": "cuvântător",
    "cuvântătorul": "cuvântător",
    "cuvântătorule": "cuvântător",
    "cuvântătorului": "cuvântător",
    "cuvântul-cheie": "cuvânt-cheie",
    "cuvântului-cheie": "cuvânt-cheie",
    "cuvinte-cheie": "cuvânt-cheie",
    "cuvintele-cheie": "cuvânt-cheie",
    "cuvintelor-cheie": "cuvânt-cheie",
    "cuvântul-matcă": "cuvânt-matcă",
    "cuvântului-matcă": "cuvânt-matcă",
    "cuvintele-matcă": "cuvânt-matcă",
    "cuvintelor-matcă": "cuvânt-matcă",
    "cuvinte-matcă": "cuvânt-matcă",
    "cuvântului-vedetă": "cuvânt-vedetă",
    "cuvântul-vedetă": "cuvânt-vedetă",
    "cuvintele-vedetă": "cuvânt-vedetă",
    "cuvintelor-vedetă": "cuvânt-vedetă",
    "cuvinte-vedetă": "cuvânt-vedetă",
    "cuvenea": "cuveni",
    "cuveneai": "cuveni",
    "cuveneam": "cuveni",
    "cuveneați": "cuveni",
    "cuveneau": "cuveni",
    "cuvenii": "cuveni",
    "cuvenim": "cuveni",
    "cuvenind": "cuveni",
    "cuvenindu": "cuveni",
    "cuveniră": "cuveni",
    "cuvenirăm": "cuveni",
    "cuvenirăți": "cuveni",
    "cuvenise": "cuveni",
    "cuvenisem": "cuveni",
    "cuveniseră": "cuveni",
    "cuveniserăm": "cuveni",
    "cuveniserăți": "cuveni",
    "cuveniseși": "cuveni",
    "cuveniși": "cuveni",
    "cuvenit": "cuveni",
    "cuveniți": "cuveni",
    "cuvenitu": "cuveni",
    "cuvii": "cuveni",
    "cuvin": "cuveni",
    "cuvină": "cuveni",
    "cuvine": "cuveni",
    "cuvino": "cuveni",
    "necuvenind": "cuveni",
    "necuvenindu": "cuveni",
    "nemaicuvenind": "cuveni",
    "nemaicuvenindu": "cuveni",
    "cuvenita": "cuvenit",
    "cuvenită": "cuvenit",
    "cuvenite": "cuvenit",
    "cuvenitei": "cuvenit",
    "cuvenitele": "cuvenit",
    "cuvenitelor": "cuvenit",
    "cuveniți": "cuvenit",
    "cuveniții": "cuvenit",
    "cuveniților": "cuvenit",
    "cuvenito": "cuvenit",
    "cuvenitul": "cuvenit",
    "cuvenitule": "cuvenit",
    "cuvenitului": "cuvenit",
    "cuvertura": "cuvertură",
    "cuverturi": "cuvertură",
    "cuverturii": "cuvertură",
    "cuverturile": "cuvertură",
    "cuverturilor": "cuvertură",
    "cuverturo": "cuvertură",
    "cuviincioasa": "cuviincios",
    "cuviincioasă": "cuviincios",
    "cuviincioase": "cuviincios",
    "cuviincioasei": "cuviincios",
    "cuviincioasele": "cuviincios",
    "cuviincioaselor": "cuviincios",
    "cuviincioaso": "cuviincios",
    "cuviincioși": "cuviincios",
    "cuviincioșii": "cuviincios",
    "cuviincioșilor": "cuviincios",
    "cuviinciosul": "cuviincios",
    "cuviinciosule": "cuviincios",
    "cuviinciosului": "cuviincios",
    "cuviința": "cuviință",
    "cuviințe": "cuviință",
    "cuviinței": "cuviință",
    "cuviințele": "cuviință",
    "cuviințelor": "cuviință",
    "cuviințo": "cuviință",
    "cuvințele": "cuvințel",
    "cuvințelele": "cuvințel",
    "cuvințelelor": "cuvințel",
    "cuvințelul": "cuvințel",
    "cuvințelule": "cuvințel",
    "cuvințelului": "cuvințel",
    "cuvioasa": "cuvios",
    "cuvioasă": "cuvios",
    "cuvioase": "cuvios",
    "cuvioasei": "cuvios",
    "cuvioasele": "cuvios",
    "cuvioaselor": "cuvios",
    "cuvioaso": "cuvios",
    "cuvioși": "cuvios",
    "cuvioșii": "cuvios",
    "cuvioșilor": "cuvios",
    "cuviosul": "cuvios",
    "cuviosule": "cuvios",
    "cuviosului": "cuvios",
    "cuvioșia": "cuvioșie",
    "cuvioșiei": "cuvioșie",
    "cuvioșii": "cuvioșie",
    "cuvioșiile": "cuvioșie",
    "cuvioșiilor": "cuvioșie",
    "cuvioșio": "cuvioșie",
    "cuzineți": "cuzinet",
    "cuzineții": "cuzinet",
    "cuzineților": "cuzinet",
    "cuzinetul": "cuzinet",
    "cuzinetule": "cuzinet",
    "cuzinetului": "cuzinet",
    "cvadranți": "cvadrant",
    "cvadranții": "cvadrant",
    "cvadranților": "cvadrant",
    "cvadrantul": "cvadrant",
    "cvadrantule": "cvadrant",
    "cvadrantului": "cvadrant",
    "cvadrate": "cvadrat",
    "cvadratele": "cvadrat",
    "cvadratelor": "cvadrat",
    "cvadrați": "cvadrat",
    "cvadrații": "cvadrat",
    "cvadraților": "cvadrat",
    "cvadratul": "cvadrat",
    "cvadratule": "cvadrat",
    "cvadratului": "cvadrat",
    "cvadratura": "cvadratură",
    "cvadraturi": "cvadratură",
    "cvadraturii": "cvadratură",
    "cvadraturile": "cvadratură",
    "cvadraturilor": "cvadratură",
    "cvadraturo": "cvadratură",
    "cvadripartita": "cvadripartit",
    "cvadripartită": "cvadripartit",
    "cvadripartite": "cvadripartit",
    "cvadripartitei": "cvadripartit",
    "cvadripartitele": "cvadripartit",
    "cvadripartitelor": "cvadripartit",
    "cvadripartiți": "cvadripartit",
    "cvadripartiții": "cvadripartit",
    "cvadripartiților": "cvadripartit",
    "cvadripartito": "cvadripartit",
    "cvadripartitul": "cvadripartit",
    "cvadripartitule": "cvadripartit",
    "cvadripartitului": "cvadripartit",
    "cvadruplă": "cvadrupla",
    "cvadruplai": "cvadrupla",
    "cvadruplam": "cvadrupla",
    "cvadruplăm": "cvadrupla",
    "cvadruplând": "cvadrupla",
    "cvadruplându": "cvadrupla",
    "cvadruplară": "cvadrupla",
    "cvadruplarăm": "cvadrupla",
    "cvadruplarăți": "cvadrupla",
    "cvadruplase": "cvadrupla",
    "cvadruplasem": "cvadrupla",
    "cvadruplaseră": "cvadrupla",
    "cvadruplaserăm": "cvadrupla",
    "cvadruplaserăți": "cvadrupla",
    "cvadruplaseși": "cvadrupla",
    "cvadruplași": "cvadrupla",
    "cvadruplat": "cvadrupla",
    "cvadruplați": "cvadrupla",
    "cvadruplatu": "cvadrupla",
    "cvadruplau": "cvadrupla",
    "cvadruplează": "cvadrupla",
    "cvadruplez": "cvadrupla",
    "cvadrupleze": "cvadrupla",
    "cvadruplezi": "cvadrupla",
    "necvadruplând": "cvadrupla",
    "necvadruplându": "cvadrupla",
    "nemaicvadruplând": "cvadrupla",
    "nemaicvadruplându": "cvadrupla",
    "cvadruplată": "cvadruplat",
    "cvadruplate": "cvadruplat",
    "cvadruplați": "cvadruplat",
    "cvarta": "cvartă",
    "cvarte": "cvartă",
    "cvartei": "cvartă",
    "cvartele": "cvartă",
    "cvartelor": "cvartă",
    "cvarto": "cvartă",
    "cvartale": "cvartal",
    "cvartalele": "cvartal",
    "cvartalelor": "cvartal",
    "cvartalul": "cvartal",
    "cvartalule": "cvartal",
    "cvartalului": "cvartal",
    "cvartete": "cvartet",
    "cvartetele": "cvartet",
    "cvartetelor": "cvartet",
    "cvartetul": "cvartet",
    "cvartetule": "cvartet",
    "cvartetului": "cvartet",
    "cvartirul": "cvartir",
    "cvartirule": "cvartir",
    "cvartirului": "cvartir",
    "cvartiruri": "cvartir",
    "cvartirurile": "cvartir",
    "cvartirurilor": "cvartir",
    "cvasul": "cvas",
    "cvasule": "cvas",
    "cvasului": "cvas",
    "cvasuri": "cvas",
    "cvasurile": "cvas",
    "cvasurilor": "cvas",
    "cvasiabsenta": "cvasiabsent",
    "cvasiabsentă": "cvasiabsent",
    "cvasiabsente": "cvasiabsent",
    "cvasiabsentei": "cvasiabsent",
    "cvasiabsentele": "cvasiabsent",
    "cvasiabsentelor": "cvasiabsent",
    "cvasiabsenți": "cvasiabsent",
    "cvasiabsenții": "cvasiabsent",
    "cvasiabsenților": "cvasiabsent",
    "cvasiabsento": "cvasiabsent",
    "cvasiabsentul": "cvasiabsent",
    "cvasiabsentule": "cvasiabsent",
    "cvasiabsentului": "cvasiabsent",
    "cvasinormala": "cvasinormal",
    "cvasinormală": "cvasinormal",
    "cvasinormale": "cvasinormal",
    "cvasinormalei": "cvasinormal",
    "cvasinormalele": "cvasinormal",
    "cvasinormalelor": "cvasinormal",
    "cvasinormali": "cvasinormal",
    "cvasinormalii": "cvasinormal",
    "cvasinormalilor": "cvasinormal",
    "cvinta": "cvintă",
    "cvinte": "cvintă",
    "cvintei": "cvintă",
    "cvintele": "cvintă",
    "cvintelor": "cvintă",
    "cvinto": "cvintă",
    "cvintete": "cvintet",
    "cvintetele": "cvintet",
    "cvintetelor": "cvintet",
    "cvintetul": "cvintet",
    "cvintetule": "cvintet",
    "cvintetului": "cvintet",
    "cvorumul": "cvorum",
    "cvorumule": "cvorum",
    "cvorumului": "cvorum",
    "cvorumuri": "cvorum",
    "cvorumurile": "cvorum",
    "cvorumurilor": "cvorum",
    "dă": "da",
    "dădea": "da",
    "dădeai": "da",
    "dădeam": "da",
    "dădeați": "da",
    "dădeau": "da",
    "dădu": "da",
    "dădui": "da",
    "dădură": "da",
    "dădurăm": "da",
    "dădurăți": "da",
    "dăduse": "da",
    "dădusem": "da",
    "dăduseră": "da",
    "dăduserăm": "da",
    "dăduserăți": "da",
    "dăduseși": "da",
    "dăduși": "da",
    "dai": "da",
    "dam": "da",
    "dăm": "da",
    "dând": "da",
    "dându": "da",
    "dat": "da",
    "dați": "da",
    "datu": "da",
    "dau": "da",
    "dea": "da",
    "dete": "da",
    "nedând": "da",
    "nedându": "da",
    "nemaidând": "da",
    "nemaidându": "da",
    "daci": "dac",
    "dacii": "dac",
    "dacilor": "dac",
    "dacul": "dac",
    "dacule": "dac",
    "dacului": "dac",
    "dac-": "dacă",
    "daca": "dacă",
    "dace": "dacă",
    "dacei": "dacă",
    "dacele": "dacă",
    "dacelor": "dacă",
    "daco": "dacă",
    "Dacie": "Dacia",
    "Daciei": "Dacia",
    "Dacii": "Dacia",
    "dacica": "dacic",
    "dacică": "dacic",
    "dacice": "dacic",
    "dacicei": "dacic",
    "dacicele": "dacic",
    "dacicelor": "dacic",
    "dacici": "dacic",
    "dacicii": "dacic",
    "dacicilor": "dacic",
    "dacico": "dacic",
    "dacicul": "dacic",
    "dacicule": "dacic",
    "dacicului": "dacic",
    "dacismul": "dacism",
    "daco-romană": "daco-roman",
    "daco-romane": "daco-roman",
    "daco-romani": "daco-roman",
    "dacoromâni": "dacoromân",
    "dacoromânii": "dacoromân",
    "dacoromânilor": "dacoromân",
    "dacoromânul": "dacoromân",
    "dacoromânule": "dacoromân",
    "dacoromânului": "dacoromân",
    "dactili": "dactil",
    "dactilii": "dactil",
    "dactililor": "dactil",
    "dactilul": "dactil",
    "dactilule": "dactil",
    "dactilului": "dactil",
    "dactilica": "dactilic",
    "dactilică": "dactilic",
    "dactilice": "dactilic",
    "dactilicei": "dactilic",
    "dactilicele": "dactilic",
    "dactilicelor": "dactilic",
    "dactilici": "dactilic",
    "dactilicii": "dactilic",
    "dactilicilor": "dactilic",
    "dactilico": "dactilic",
    "dactilicul": "dactilic",
    "dactilicule": "dactilic",
    "dactilicului": "dactilic",
    "dactilografi": "dactilograf",
    "dactilografii": "dactilograf",
    "dactilografilor": "dactilograf",
    "dactilograful": "dactilograf",
    "dactilografule": "dactilograf",
    "dactilografului": "dactilograf",
    "dactilografa": "dactilografă",
    "dactilografe": "dactilografă",
    "dactilografei": "dactilografă",
    "dactilografele": "dactilografă",
    "dactilografelor": "dactilografă",
    "dactilografo": "dactilografă",
    "dactilografiai": "dactilografia",
    "dactilografiam": "dactilografia",
    "dactilografiară": "dactilografia",
    "dactilografiarăm": "dactilografia",
    "dactilografiarăți": "dactilografia",
    "dactilografiase": "dactilografia",
    "dactilografiasem": "dactilografia",
    "dactilografiaseră": "dactilografia",
    "dactilografiaserăm": "dactilografia",
    "dactilografiaserăți": "dactilografia",
    "dactilografiaseși": "dactilografia",
    "dactilografiași": "dactilografia",
    "dactilografiat": "dactilografia",
    "dactilografiați": "dactilografia",
    "dactilografiatu": "dactilografia",
    "dactilografiau": "dactilografia",
    "dactilografiază": "dactilografia",
    "dactilografie": "dactilografia",
    "dactilografiem": "dactilografia",
    "dactilografiez": "dactilografia",
    "dactilografieze": "dactilografia",
    "dactilografiezi": "dactilografia",
    "dactilografiind": "dactilografia",
    "dactilografiindu": "dactilografia",
    "nedactilografiind": "dactilografia",
    "nedactilografiindu": "dactilografia",
    "nemaidactilografiind": "dactilografia",
    "nemaidactilografiindu": "dactilografia",
    "dactilografiata": "dactilografiat",
    "dactilografiată": "dactilografiat",
    "dactilografiate": "dactilografiat",
    "dactilografiatei": "dactilografiat",
    "dactilografiatele": "dactilografiat",
    "dactilografiatelor": "dactilografiat",
    "dactilografiați": "dactilografiat",
    "dactilografiații": "dactilografiat",
    "dactilografiaților": "dactilografiat",
    "dactilografiato": "dactilografiat",
    "dactilografiatul": "dactilografiat",
    "dactilografiatule": "dactilografiat",
    "dactilografiatului": "dactilografiat",
    "dactilografia": "dactilografie",
    "dactilografiei": "dactilografie",
    "dactilografii": "dactilografie",
    "dactilografiile": "dactilografie",
    "dactilografiilor": "dactilografie",
    "dactilografio": "dactilografie",
    "dactilografierea": "dactilografiere",
    "dactilografiereo": "dactilografiere",
    "dactilografieri": "dactilografiere",
    "dactilografierii": "dactilografiere",
    "dactilografierile": "dactilografiere",
    "dactilografierilor": "dactilografiere",
    "dactilologia": "dactilologie",
    "dactilologiei": "dactilologie",
    "dactilologii": "dactilologie",
    "dactilologiile": "dactilologie",
    "dactilologiilor": "dactilologie",
    "dactilologio": "dactilologie",
    "dactiloscopia": "dactiloscopie",
    "dactiloscopiei": "dactiloscopie",
    "dactiloscopii": "dactiloscopie",
    "dactiloscopiile": "dactiloscopie",
    "dactiloscopiilor": "dactiloscopie",
    "dactiloscopio": "dactiloscopie",
    "dădaca": "dădacă",
    "dădace": "dădacă",
    "dădacei": "dădacă",
    "dădacele": "dădacă",
    "dădacelor": "dădacă",
    "dădaco": "dădacă",
    "dădăceala": "dădăceală",
    "dădăcealo": "dădăceală",
    "dădăceli": "dădăceală",
    "dădăcelii": "dădăceală",
    "dădăcelile": "dădăceală",
    "dădăcelilor": "dădăceală",
    "dădăcea": "dădăci",
    "dădăceai": "dădăci",
    "dădăceam": "dădăci",
    "dădăcească": "dădăci",
    "dădăceați": "dădăci",
    "dădăceau": "dădăci",
    "dădăcesc": "dădăci",
    "dădăcește": "dădăci",
    "dădăcești": "dădăci",
    "dădăcii": "dădăci",
    "dădăcim": "dădăci",
    "dădăcind": "dădăci",
    "dădăcindu": "dădăci",
    "dădăciră": "dădăci",
    "dădăcirăm": "dădăci",
    "dădăcirăți": "dădăci",
    "dădăcise": "dădăci",
    "dădăcisem": "dădăci",
    "dădăciseră": "dădăci",
    "dădăciserăm": "dădăci",
    "dădăciserăți": "dădăci",
    "dădăciseși": "dădăci",
    "dădăciși": "dădăci",
    "dădăcit": "dădăci",
    "dădăciți": "dădăci",
    "dădăcitu": "dădăci",
    "nedădăcind": "dădăci",
    "nedădăcindu": "dădăci",
    "nemaidădăcind": "dădăci",
    "nemaidădăcindu": "dădăci",
    "dădăcită": "dădăcit",
    "dădăcite": "dădăcit",
    "dădăciți": "dădăcit",
    "dadaismul": "dadaism",
    "dadaismule": "dadaism",
    "dadaismului": "dadaism",
    "dadaista": "dadaist",
    "dadaistă": "dadaist",
    "dadaiste": "dadaist",
    "dadaistei": "dadaist",
    "dadaistele": "dadaist",
    "dadaistelor": "dadaist",
    "dadaiști": "dadaist",
    "dadaiștii": "dadaist",
    "dadaiștilor": "dadaist",
    "dadaistul": "dadaist",
    "dadaistule": "dadaist",
    "dadaistului": "dadaist",
    "dadaista": "dadaistă",
    "dadaiste": "dadaistă",
    "dadaistei": "dadaistă",
    "dadaistele": "dadaistă",
    "dadaistelor": "dadaistă",
    "dadaisto": "dadaistă",
    "dafini": "dafin",
    "dafinii": "dafin",
    "dafinilor": "dafin",
    "dafinul": "dafin",
    "dafinule": "dafin",
    "dafinului": "dafin",
    "daghereotipul": "daghereotip",
    "daghereotipule": "daghereotip",
    "daghereotipului": "daghereotip",
    "daghereotipuri": "daghereotip",
    "daghereotipurile": "daghereotip",
    "daghereotipurilor": "daghereotip",
    "daimoni": "daimon",
    "daimonii": "daimon",
    "daimonilor": "daimon",
    "daimonul": "daimon",
    "daimonului": "daimon",
    "daimonici": "daimonic",
    "daimonicii": "daimonic",
    "daimonicilor": "daimonic",
    "daimonicul": "daimonic",
    "daimonicului": "daimonic",
    "dăinuia": "dăinui",
    "dăinuiai": "dăinui",
    "dăinuiam": "dăinui",
    "dăinuiască": "dăinui",
    "dăinuiați": "dăinui",
    "dăinuiau": "dăinui",
    "dăinuiesc": "dăinui",
    "dăinuiește": "dăinui",
    "dăinuiești": "dăinui",
    "dăinuii": "dăinui",
    "dăinuim": "dăinui",
    "dăinuind": "dăinui",
    "dăinuindu": "dăinui",
    "dăinuiră": "dăinui",
    "dăinuirăm": "dăinui",
    "dăinuirăți": "dăinui",
    "dăinuise": "dăinui",
    "dăinuisem": "dăinui",
    "dăinuiseră": "dăinui",
    "dăinuiserăm": "dăinui",
    "dăinuiserăți": "dăinui",
    "dăinuiseși": "dăinui",
    "dăinuiși": "dăinui",
    "dăinuit": "dăinui",
    "dăinuiți": "dăinui",
    "dăinuitu": "dăinui",
    "nedăinuind": "dăinui",
    "nedăinuindu": "dăinui",
    "nemaidăinuind": "dăinui",
    "nemaidăinuindu": "dăinui",
    "dăinuită": "dăinuit",
    "dăinuite": "dăinuit",
    "dăinuiți": "dăinuit",
    "dăinuitoare": "dăinuitor",
    "dăinuitoarea": "dăinuitor",
    "dăinuitoarei": "dăinuitor",
    "dăinuitoarele": "dăinuitor",
    "dăinuitoarelor": "dăinuitor",
    "dăinuitoareo": "dăinuitor",
    "dăinuitori": "dăinuitor",
    "dăinuitorii": "dăinuitor",
    "dăinuitorilor": "dăinuitor",
    "dăinuitorul": "dăinuitor",
    "dăinuitorule": "dăinuitor",
    "dăinuitorului": "dăinuitor",
    "D.S.": "dal_segno",
    "dala": "dală",
    "dale": "dală",
    "dalei": "dală",
    "dalele": "dală",
    "dalelor": "dală",
    "dalo": "dală",
    "dalacul": "dalac",
    "dalacule": "dalac",
    "dalacului": "dalac",
    "dalacuri": "dalac",
    "dalacurile": "dalac",
    "dalacurilor": "dalac",
    "dalba": "dalb",
    "dalbă": "dalb",
    "dalbe": "dalb",
    "dalbei": "dalb",
    "dalbele": "dalb",
    "dalbelor": "dalb",
    "dalbi": "dalb",
    "dalbii": "dalb",
    "dalbilor": "dalb",
    "dalbo": "dalb",
    "dalbul": "dalb",
    "dalbule": "dalb",
    "dalbului": "dalb",
    "dalia": "dalie",
    "daliei": "dalie",
    "dalii": "dalie",
    "daliile": "dalie",
    "daliilor": "dalie",
    "dalio": "dalie",
    "dalta": "daltă",
    "dălți": "daltă",
    "dălții": "daltă",
    "dălțile": "daltă",
    "dălților": "daltă",
    "dalto": "daltă",
    "dăltița": "dăltiță",
    "dăltițe": "dăltiță",
    "dăltiței": "dăltiță",
    "dăltițele": "dăltiță",
    "dăltițelor": "dăltiță",
    "dăltițo": "dăltiță",
    "daltonismul": "daltonism",
    "daltonismule": "daltonism",
    "daltonismului": "daltonism",
    "daltoniști": "daltonist",
    "daltoniștii": "daltonist",
    "daltoniștilor": "daltonist",
    "daltonistul": "daltonist",
    "daltonistule": "daltonist",
    "daltonistului": "daltonist",
    "daltonista": "daltonistă",
    "daltoniste": "daltonistă",
    "daltonistei": "daltonistă",
    "daltonistele": "daltonistă",
    "daltonistelor": "daltonistă",
    "daltonisto": "daltonistă",
    "dăltuia": "dăltui",
    "dăltuiai": "dăltui",
    "dăltuiam": "dăltui",
    "dăltuiască": "dăltui",
    "dăltuiați": "dăltui",
    "dăltuiau": "dăltui",
    "dăltuiesc": "dăltui",
    "dăltuiește": "dăltui",
    "dăltuiești": "dăltui",
    "dăltuii": "dăltui",
    "dăltuim": "dăltui",
    "dăltuind": "dăltui",
    "dăltuindu": "dăltui",
    "dăltuiră": "dăltui",
    "dăltuirăm": "dăltui",
    "dăltuirăți": "dăltui",
    "dăltuise": "dăltui",
    "dăltuisem": "dăltui",
    "dăltuiseră": "dăltui",
    "dăltuiserăm": "dăltui",
    "dăltuiserăți": "dăltui",
    "dăltuiseși": "dăltui",
    "dăltuiși": "dăltui",
    "dăltuit": "dăltui",
    "dăltuiți": "dăltui",
    "dăltuitu": "dăltui",
    "nedăltuind": "dăltui",
    "nedăltuindu": "dăltui",
    "nemaidăltuind": "dăltui",
    "nemaidăltuindu": "dăltui",
    "dăltuirea": "dăltuire",
    "dăltuireo": "dăltuire",
    "dăltuiri": "dăltuire",
    "dăltuirii": "dăltuire",
    "dăltuirile": "dăltuire",
    "dăltuirilor": "dăltuire",
    "dăltuita": "dăltuit",
    "dăltuită": "dăltuit",
    "dăltuite": "dăltuit",
    "dăltuitei": "dăltuit",
    "dăltuitele": "dăltuit",
    "dăltuitelor": "dăltuit",
    "dăltuiți": "dăltuit",
    "dăltuiții": "dăltuit",
    "dăltuiților": "dăltuit",
    "dăltuito": "dăltuit",
    "dăltuitul": "dăltuit",
    "dăltuitule": "dăltuit",
    "dăltuitului": "dăltuit",
    "dăltuitoarea": "dăltuitoare",
    "dăltuitoarei": "dăltuitoare",
    "dăltuitoarele": "dăltuitoare",
    "dăltuitoarelor": "dăltuitoare",
    "dăltuitoareo": "dăltuitoare",
    "dăltuitori": "dăltuitor",
    "dăltuitorii": "dăltuitor",
    "dăltuitorilor": "dăltuitor",
    "dăltuitorul": "dăltuitor",
    "dăltuitorule": "dăltuitor",
    "dăltuitorului": "dăltuitor",
    "dăltuitura": "dăltuitură",
    "dăltuituri": "dăltuitură",
    "dăltuiturii": "dăltuitură",
    "dăltuiturile": "dăltuitură",
    "dăltuiturilor": "dăltuitură",
    "dăltuituro": "dăltuitură",
    "dama": "damă",
    "dame": "damă",
    "damei": "damă",
    "damele": "damă",
    "damelor": "damă",
    "damo": "damă",
    "damascul": "damasc",
    "damascule": "damasc",
    "damascului": "damasc",
    "damascuri": "damasc",
    "damascurile": "damasc",
    "damascurilor": "damasc",
    "dâmbul": "dâmb",
    "dâmbule": "dâmb",
    "dâmbului": "dâmb",
    "dâmburi": "dâmb",
    "dâmburile": "dâmb",
    "dâmburilor": "dâmb",
    "damblale": "dambla",
    "damblalei": "dambla",
    "damblalele": "dambla",
    "damblalelor": "dambla",
    "damblao": "dambla",
    "damblaua": "dambla",
    "damblagea": "damblagi",
    "damblageai": "damblagi",
    "damblageam": "damblagi",
    "damblagească": "damblagi",
    "damblageați": "damblagi",
    "damblageau": "damblagi",
    "damblagesc": "damblagi",
    "damblagește": "damblagi",
    "damblagești": "damblagi",
    "damblagii": "damblagi",
    "damblagim": "damblagi",
    "damblagind": "damblagi",
    "damblagindu": "damblagi",
    "damblagiră": "damblagi",
    "damblagirăm": "damblagi",
    "damblagirăți": "damblagi",
    "damblagise": "damblagi",
    "damblagisem": "damblagi",
    "damblagiseră": "damblagi",
    "damblagiserăm": "damblagi",
    "damblagiserăți": "damblagi",
    "damblagiseși": "damblagi",
    "damblagiși": "damblagi",
    "damblagit": "damblagi",
    "damblagiți": "damblagi",
    "damblagitu": "damblagi",
    "nedamblagind": "damblagi",
    "nedamblagindu": "damblagi",
    "nemaidamblagind": "damblagi",
    "nemaidamblagindu": "damblagi",
    "damblagită": "damblagit",
    "damblagite": "damblagit",
    "damblagiți": "damblagit",
    "Dâmboviță": "Dâmbovița",
    "Dâmbovițe": "Dâmbovița",
    "Dâmboviței": "Dâmbovița",
    "damful": "damf",
    "damfule": "damf",
    "damfului": "damf",
    "damfuri": "damf",
    "damfurile": "damf",
    "damfurilor": "damf",
    "damigeana": "damigeană",
    "damigeano": "damigeană",
    "damigene": "damigeană",
    "damigenei": "damigeană",
    "damigenele": "damigeană",
    "damigenelor": "damigeană",
    "damnata": "damnat",
    "damnată": "damnat",
    "damnate": "damnat",
    "damnatei": "damnat",
    "damnatele": "damnat",
    "damnatelor": "damnat",
    "damnați": "damnat",
    "damnații": "damnat",
    "damnaților": "damnat",
    "damnato": "damnat",
    "damnatul": "damnat",
    "damnatule": "damnat",
    "damnatului": "damnat",
    "damnațiunea": "damnațiune",
    "damnațiuneo": "damnațiune",
    "damnațiuni": "damnațiune",
    "damnațiunii": "damnațiune",
    "damnațiunile": "damnațiune",
    "damnațiunilor": "damnațiune",
    "Danei": "Dana",
    "dana": "dană",
    "dane": "dană",
    "danei": "dană",
    "danele": "dană",
    "danelor": "dană",
    "dano": "dană",
    "dandanale": "dandana",
    "dandanalei": "dandana",
    "dandanalele": "dandana",
    "dandanalelor": "dandana",
    "dandanao": "dandana",
    "dandanaua": "dandana",
    "dăndănăi": "dăndănaie",
    "dăndănaia": "dăndănaie",
    "dăndănăii": "dăndănaie",
    "dăndănăile": "dăndănaie",
    "dăndănăilor": "dăndănaie",
    "dăndănaio": "dăndănaie",
    "Dan.": "Danemarca",
    "daneza": "danez",
    "daneză": "danez",
    "daneze": "danez",
    "danezei": "danez",
    "danezele": "danez",
    "danezelor": "danez",
    "danezi": "danez",
    "danezii": "danez",
    "danezilor": "danez",
    "danezul": "danez",
    "danezului": "danez",
    "daneza": "daneză",
    "daneze": "daneză",
    "danezei": "daneză",
    "danezele": "daneză",
    "danezelor": "daneză",
    "dăngănea": "dăngăni",
    "dăngăneai": "dăngăni",
    "dăngăneam": "dăngăni",
    "dăngănească": "dăngăni",
    "dăngăneați": "dăngăni",
    "dăngăneau": "dăngăni",
    "dăngănesc": "dăngăni",
    "dăngănește": "dăngăni",
    "dăngănești": "dăngăni",
    "dăngănii": "dăngăni",
    "dăngănim": "dăngăni",
    "dăngănind": "dăngăni",
    "dăngănindu": "dăngăni",
    "dăngăniră": "dăngăni",
    "dăngănirăm": "dăngăni",
    "dăngănirăți": "dăngăni",
    "dăngănise": "dăngăni",
    "dăngănisem": "dăngăni",
    "dăngăniseră": "dăngăni",
    "dăngăniserăm": "dăngăni",
    "dăngăniserăți": "dăngăni",
    "dăngăniseși": "dăngăni",
    "dăngăniși": "dăngăni",
    "dăngănit": "dăngăni",
    "dăngăniți": "dăngăni",
    "dăngănitu": "dăngăni",
    "nedăngănind": "dăngăni",
    "nedăngănindu": "dăngăni",
    "nemaidăngănind": "dăngăni",
    "nemaidăngănindu": "dăngăni",
    "dăngănită": "dăngănit",
    "dăngănite": "dăngănit",
    "dăngăniți": "dăngănit",
    "dăngănitul": "dăngănit",
    "dăngănitule": "dăngănit",
    "dăngănitului": "dăngănit",
    "dangăte": "dangăt",
    "dangătele": "dangăt",
    "dangătelor": "dangăt",
    "dangătul": "dangăt",
    "dangătule": "dangăt",
    "dangătului": "dangăt",
    "dania": "danie",
    "daniei": "danie",
    "danii": "danie",
    "daniile": "danie",
    "daniilor": "danie",
    "danio": "danie",
    "dansul": "dans",
    "dansule": "dans",
    "dansului": "dans",
    "dansuri": "dans",
    "dansurile": "dans",
    "dansurilor": "dans",
    "dansă": "dansa",
    "dansai": "dansa",
    "dansam": "dansa",
    "dansăm": "dansa",
    "dansând": "dansa",
    "dansându": "dansa",
    "dansară": "dansa",
    "dansarăm": "dansa",
    "dansarăți": "dansa",
    "dansase": "dansa",
    "dansasem": "dansa",
    "dansaseră": "dansa",
    "dansaserăm": "dansa",
    "dansaserăți": "dansa",
    "dansaseși": "dansa",
    "dansași": "dansa",
    "dansat": "dansa",
    "dansați": "dansa",
    "dansatu": "dansa",
    "dansau": "dansa",
    "dansează": "dansa",
    "dansez": "dansa",
    "danseze": "dansa",
    "dansezi": "dansa",
    "nedansând": "dansa",
    "nedansându": "dansa",
    "nemaidansând": "dansa",
    "nemaidansându": "dansa",
    "dansată": "dansat",
    "dansate": "dansat",
    "dansați": "dansat",
    "dansatoarea": "dansatoare",
    "dansatoarei": "dansatoare",
    "dansatoarele": "dansatoare",
    "dansatoarelor": "dansatoare",
    "dansatoareo": "dansatoare",
    "dansatori": "dansator",
    "dansatorii": "dansator",
    "dansatorilor": "dansator",
    "dansatorul": "dansator",
    "dansatorule": "dansator",
    "dansatorului": "dansator",
    "dânsa": "dânsul",
    "dânsei": "dânsul",
    "dânsele": "dânsul",
    "dânselor": "dânsul",
    "dânșii": "dânsul",
    "dânșilor": "dânsul",
    "dantelă": "dantela",
    "dantelai": "dantela",
    "dantelam": "dantela",
    "dantelăm": "dantela",
    "dantelând": "dantela",
    "dantelându": "dantela",
    "dantelară": "dantela",
    "dantelarăm": "dantela",
    "dantelarăți": "dantela",
    "dantelase": "dantela",
    "dantelasem": "dantela",
    "dantelaseră": "dantela",
    "dantelaserăm": "dantela",
    "dantelaserăți": "dantela",
    "dantelaseși": "dantela",
    "dantelași": "dantela",
    "dantelat": "dantela",
    "dantelați": "dantela",
    "dantelatu": "dantela",
    "dantelau": "dantela",
    "dantelează": "dantela",
    "dantelez": "dantela",
    "danteleze": "dantela",
    "dantelezi": "dantela",
    "nedantelând": "dantela",
    "nedantelându": "dantela",
    "nemaidantelând": "dantela",
    "nemaidantelându": "dantela",
    "dantela": "dantelă",
    "dantele": "dantelă",
    "dantelei": "dantelă",
    "dantelele": "dantelă",
    "dantelelor": "dantelă",
    "dantelo": "dantelă",
    "dantelata": "dantelat",
    "dantelată": "dantelat",
    "dantelate": "dantelat",
    "dantelatei": "dantelat",
    "dantelatele": "dantelat",
    "dantelatelor": "dantelat",
    "dantelați": "dantelat",
    "dantelații": "dantelat",
    "dantelaților": "dantelat",
    "dantelato": "dantelat",
    "dantelatul": "dantelat",
    "dantelatule": "dantelat",
    "dantelatului": "dantelat",
    "dantelura": "dantelură",
    "danteluri": "dantelură",
    "dantelurii": "dantelură",
    "dantelurile": "dantelură",
    "dantelurilor": "dantelură",
    "danteluro": "dantelură",
    "dănțuia": "dănțui",
    "dănțuiai": "dănțui",
    "dănțuiam": "dănțui",
    "dănțuiască": "dănțui",
    "dănțuiați": "dănțui",
    "dănțuiau": "dănțui",
    "dănțuiesc": "dănțui",
    "dănțuiește": "dănțui",
    "dănțuiești": "dănțui",
    "dănțuii": "dănțui",
    "dănțuim": "dănțui",
    "dănțuind": "dănțui",
    "dănțuindu": "dănțui",
    "dănțuiră": "dănțui",
    "dănțuirăm": "dănțui",
    "dănțuirăți": "dănțui",
    "dănțuise": "dănțui",
    "dănțuisem": "dănțui",
    "dănțuiseră": "dănțui",
    "dănțuiserăm": "dănțui",
    "dănțuiserăți": "dănțui",
    "dănțuiseși": "dănțui",
    "dănțuiși": "dănțui",
    "dănțuit": "dănțui",
    "dănțuiți": "dănțui",
    "dănțuitu": "dănțui",
    "nedănțuind": "dănțui",
    "nedănțuindu": "dănțui",
    "nemaidănțuind": "dănțui",
    "nemaidănțuindu": "dănțui",
    "dănțuită": "dănțuit",
    "dănțuite": "dănțuit",
    "dănțuiți": "dănțuit",
    "dănțuitoarea": "dănțuitoare",
    "dănțuitoarei": "dănțuitoare",
    "dănțuitoarele": "dănțuitoare",
    "dănțuitoarelor": "dănțuitoare",
    "dănțuitoareo": "dănțuitoare",
    "dănțuitori": "dănțuitor",
    "dănțuitorii": "dănțuitor",
    "dănțuitorilor": "dănțuitor",
    "dănțuitorul": "dănțuitor",
    "dănțuitorule": "dănțuitor",
    "dănțuitorului": "dănțuitor",
    "dantura": "dantură",
    "danturi": "dantură",
    "danturii": "dantură",
    "danturile": "dantură",
    "danturilor": "dantură",
    "danturo": "dantură",
    "danubiana": "danubian",
    "danubiană": "danubian",
    "danubiano": "danubian",
    "danubianul": "danubian",
    "danubianule": "danubian",
    "danubianului": "danubian",
    "danubiene": "danubian",
    "danubienei": "danubian",
    "danubienele": "danubian",
    "danubienelor": "danubian",
    "danubieni": "danubian",
    "danubienii": "danubian",
    "danubienilor": "danubian",
    "da'": "dar",
    "dară": "dar",
    "darul": "dar",
    "darule": "dar",
    "darului": "dar",
    "daruri": "dar",
    "darurile": "dar",
    "darurilor": "dar",
    "darale": "dara",
    "daralei": "dara",
    "daralele": "dara",
    "daralelor": "dara",
    "darao": "dara",
    "daraua": "dara",
    "dâra": "dâră",
    "dâre": "dâră",
    "dârei": "dâră",
    "dârele": "dâră",
    "dârelor": "dâră",
    "dâro": "dâră",
    "darabana": "darabană",
    "darabane": "darabană",
    "darabanei": "darabană",
    "darabanele": "darabană",
    "darabanelor": "darabană",
    "darabano": "darabană",
    "darace": "darac",
    "daracele": "darac",
    "daracelor": "darac",
    "daracul": "darac",
    "daracule": "darac",
    "daracului": "darac",
    "dărăcea": "dărăci",
    "dărăceai": "dărăci",
    "dărăceam": "dărăci",
    "dărăcească": "dărăci",
    "dărăceați": "dărăci",
    "dărăceau": "dărăci",
    "dărăcesc": "dărăci",
    "dărăcește": "dărăci",
    "dărăcești": "dărăci",
    "dărăcii": "dărăci",
    "dărăcim": "dărăci",
    "dărăcind": "dărăci",
    "dărăcindu": "dărăci",
    "dărăciră": "dărăci",
    "dărăcirăm": "dărăci",
    "dărăcirăți": "dărăci",
    "dărăcise": "dărăci",
    "dărăcisem": "dărăci",
    "dărăciseră": "dărăci",
    "dărăciserăm": "dărăci",
    "dărăciserăți": "dărăci",
    "dărăciseși": "dărăci",
    "dărăciși": "dărăci",
    "dărăcit": "dărăci",
    "dărăciți": "dărăci",
    "dărăcitu": "dărăci",
    "nedărăcind": "dărăci",
    "nedărăcindu": "dărăci",
    "nemaidărăcind": "dărăci",
    "nemaidărăcindu": "dărăci",
    "dărăcirea": "dărăcire",
    "dărăcireo": "dărăcire",
    "dărăciri": "dărăcire",
    "dărăcirii": "dărăcire",
    "dărăcirile": "dărăcire",
    "dărăcirilor": "dărăcire",
    "dărăcită": "dărăcit",
    "dărăcite": "dărăcit",
    "dărăciți": "dărăcit",
    "dărăcitul": "dărăcit",
    "dărăcitule": "dărăcit",
    "dărăcitului": "dărăcit",
    "dărăcitoarea": "dărăcitoare",
    "dărăcitoarei": "dărăcitoare",
    "dărăcitoarele": "dărăcitoare",
    "dărăcitoarelor": "dărăcitoare",
    "dărăcitoareo": "dărăcitoare",
    "dărăcitoare": "dărăcitor",
    "dărăcitoarele": "dărăcitor",
    "dărăcitoarelor": "dărăcitor",
    "dărăcitori": "dărăcitor",
    "dărăcitorii": "dărăcitor",
    "dărăcitorilor": "dărăcitor",
    "dărăcitorul": "dărăcitor",
    "dărăcitorule": "dărăcitor",
    "dărăcitorului": "dărăcitor",
    "dărăcitura": "dărăcitură",
    "dărăcituri": "dărăcitură",
    "dărăciturii": "dărăcitură",
    "dărăciturile": "dărăcitură",
    "dărăciturilor": "dărăcitură",
    "dărăcituro": "dărăcitură",
    "dărâm": "dărâma",
    "dărâmă": "dărâma",
    "dărâmai": "dărâma",
    "dărâmam": "dărâma",
    "dărâmăm": "dărâma",
    "dărâmând": "dărâma",
    "dărâmându": "dărâma",
    "dărâmară": "dărâma",
    "dărâmarăm": "dărâma",
    "dărâmarăți": "dărâma",
    "dărâmase": "dărâma",
    "dărâmasem": "dărâma",
    "dărâmaseră": "dărâma",
    "dărâmaserăm": "dărâma",
    "dărâmaserăți": "dărâma",
    "dărâmaseși": "dărâma",
    "dărâmași": "dărâma",
    "dărâmat": "dărâma",
    "dărâmați": "dărâma",
    "dărâmatu": "dărâma",
    "dărâmau": "dărâma",
    "dărâme": "dărâma",
    "dărâmi": "dărâma",
    "nedărâmând": "dărâma",
    "nedărâmându": "dărâma",
    "nemaidărâmând": "dărâma",
    "nemaidărâmându": "dărâma",
    "dărâmarea": "dărâmare",
    "dărâmareo": "dărâmare",
    "dărâmări": "dărâmare",
    "dărâmării": "dărâmare",
    "dărâmările": "dărâmare",
    "dărâmărilor": "dărâmare",
    "dărâmata": "dărâmat",
    "dărâmată": "dărâmat",
    "dărâmate": "dărâmat",
    "dărâmatei": "dărâmat",
    "dărâmatele": "dărâmat",
    "dărâmatelor": "dărâmat",
    "dărâmați": "dărâmat",
    "dărâmații": "dărâmat",
    "dărâmaților": "dărâmat",
    "dărâmato": "dărâmat",
    "dărâmatul": "dărâmat",
    "dărâmatule": "dărâmat",
    "dărâmatului": "dărâmat",
    "dărâmătoarea": "dărâmătoare",
    "dărâmătoarei": "dărâmătoare",
    "dărâmătoarele": "dărâmătoare",
    "dărâmătoarelor": "dărâmătoare",
    "dărâmătoareo": "dărâmătoare",
    "dărâmători": "dărâmător",
    "dărâmătorii": "dărâmător",
    "dărâmătorilor": "dărâmător",
    "dărâmătorul": "dărâmător",
    "dărâmătorule": "dărâmător",
    "dărâmătorului": "dărâmător",
    "dărâmătura": "dărâmătură",
    "dărâmături": "dărâmătură",
    "dărâmăturii": "dărâmătură",
    "dărâmăturile": "dărâmătură",
    "dărâmăturilor": "dărâmătură",
    "dărâmăturo": "dărâmătură",
    "dărapăn": "dărăpăna",
    "dărapănă": "dărăpăna",
    "dărăpănă": "dărăpăna",
    "dărăpănai": "dărăpăna",
    "dărăpănam": "dărăpăna",
    "dărăpănăm": "dărăpăna",
    "dărăpănând": "dărăpăna",
    "dărăpănându": "dărăpăna",
    "dărăpănară": "dărăpăna",
    "dărăpănarăm": "dărăpăna",
    "dărăpănarăți": "dărăpăna",
    "dărăpănase": "dărăpăna",
    "dărăpănasem": "dărăpăna",
    "dărăpănaseră": "dărăpăna",
    "dărăpănaserăm": "dărăpăna",
    "dărăpănaserăți": "dărăpăna",
    "dărăpănaseși": "dărăpăna",
    "dărăpănași": "dărăpăna",
    "dărăpănat": "dărăpăna",
    "dărăpănați": "dărăpăna",
    "dărăpănatu": "dărăpăna",
    "dărăpănau": "dărăpăna",
    "dărapene": "dărăpăna",
    "dărapeni": "dărăpăna",
    "nedărăpănând": "dărăpăna",
    "nedărăpănându": "dărăpăna",
    "nemaidărăpănând": "dărăpăna",
    "nemaidărăpănându": "dărăpăna",
    "dărăpănarea": "dărăpănare",
    "dărăpănareo": "dărăpănare",
    "dărăpănări": "dărăpănare",
    "dărăpănării": "dărăpănare",
    "dărăpănările": "dărăpănare",
    "dărăpănărilor": "dărăpănare",
    "dărăpănata": "dărăpănat",
    "dărăpănată": "dărăpănat",
    "dărăpănate": "dărăpănat",
    "dărăpănatei": "dărăpănat",
    "dărăpănatele": "dărăpănat",
    "dărăpănatelor": "dărăpănat",
    "dărăpănați": "dărăpănat",
    "dărăpănații": "dărăpănat",
    "dărăpănaților": "dărăpănat",
    "dărăpănato": "dărăpănat",
    "dărăpănatul": "dărăpănat",
    "dărăpănatule": "dărăpănat",
    "dărăpănatului": "dărăpănat",
    "dărăpănătoare": "dărăpănător",
    "dărăpănătoarea": "dărăpănător",
    "dărăpănătoarei": "dărăpănător",
    "dărăpănătoarele": "dărăpănător",
    "dărăpănătoarelor": "dărăpănător",
    "dărăpănătoareo": "dărăpănător",
    "dărăpănători": "dărăpănător",
    "dărăpănătorii": "dărăpănător",
    "dărăpănătorilor": "dărăpănător",
    "dărăpănătorul": "dărăpănător",
    "dărăpănătorule": "dărăpănător",
    "dărăpănătorului": "dărăpănător",
    "dărăpănătura": "dărăpănătură",
    "dărăpănături": "dărăpănătură",
    "dărăpănăturii": "dărăpănătură",
    "dărăpănăturile": "dărăpănătură",
    "dărăpănăturilor": "dărăpănătură",
    "dărăpănăturo": "dărăpănătură",
    "daravela": "daravelă",
    "daravele": "daravelă",
    "daravelei": "daravelă",
    "daravelele": "daravelă",
    "daravelelor": "daravelă",
    "daravelo": "daravelă",
    "dârdâia": "dârdâi",
    "dârdâiai": "dârdâi",
    "dârdâiam": "dârdâi",
    "dârdâiați": "dârdâi",
    "dârdâiau": "dârdâi",
    "dârdâie": "dârdâi",
    "dârdâii": "dârdâi",
    "dârdâim": "dârdâi",
    "dârdâind": "dârdâi",
    "dârdâindu": "dârdâi",
    "dârdâiră": "dârdâi",
    "dârdâirăm": "dârdâi",
    "dârdâirăți": "dârdâi",
    "dârdâise": "dârdâi",
    "dârdâisem": "dârdâi",
    "dârdâiseră": "dârdâi",
    "dârdâiserăm": "dârdâi",
    "dârdâiserăți": "dârdâi",
    "dârdâiseși": "dârdâi",
    "dârdâiși": "dârdâi",
    "dârdâit": "dârdâi",
    "dârdâiți": "dârdâi",
    "dârdâitu": "dârdâi",
    "nedârdâind": "dârdâi",
    "nedârdâindu": "dârdâi",
    "nemaidârdâind": "dârdâi",
    "nemaidârdâindu": "dârdâi",
    "dârdâiala": "dârdâială",
    "dârdâialo": "dârdâială",
    "dârdâieli": "dârdâială",
    "dârdâielii": "dârdâială",
    "dârdâielile": "dârdâială",
    "dârdâielilor": "dârdâială",
    "dârdâită": "dârdâit",
    "dârdâite": "dârdâit",
    "dârdâiți": "dârdâit",
    "dârdâitul": "dârdâit",
    "dârdâitule": "dârdâit",
    "dârdâitului": "dârdâit",
    "darea": "dare",
    "dareo": "dare",
    "dări": "dare",
    "dării": "dare",
    "dările": "dare",
    "dărilor": "dare",
    "dârlogi": "dârlog",
    "dârlogii": "dârlog",
    "dârlogilor": "dârlog",
    "dârlogul": "dârlog",
    "dârlogule": "dârlog",
    "dârlogului": "dârlog",
    "dârmoane": "dârmon",
    "dârmoanele": "dârmon",
    "dârmoanelor": "dârmon",
    "dârmonul": "dârmon",
    "dârmonule": "dârmon",
    "dârmonului": "dârmon",
    "darnica": "darnic",
    "darnică": "darnic",
    "darnice": "darnic",
    "darnicei": "darnic",
    "darnicele": "darnic",
    "darnicelor": "darnic",
    "darnici": "darnic",
    "darnicii": "darnic",
    "darnicilor": "darnic",
    "darnico": "darnic",
    "darnicul": "darnic",
    "darnicule": "darnic",
    "darnicului": "darnic",
    "dărnicia": "dărnicie",
    "dărniciei": "dărnicie",
    "dărnicii": "dărnicie",
    "dărniciile": "dărnicie",
    "dărniciilor": "dărnicie",
    "dărnicio": "dărnicie",
    "dăruia": "dărui",
    "dăruiai": "dărui",
    "dăruiam": "dărui",
    "dăruiască": "dărui",
    "dăruiați": "dărui",
    "dăruiau": "dărui",
    "dăruie": "dărui",
    "dăruiesc": "dărui",
    "dăruiește": "dărui",
    "dăruiești": "dărui",
    "dăruii": "dărui",
    "dăruim": "dărui",
    "dăruind": "dărui",
    "dăruindu": "dărui",
    "dăruiră": "dărui",
    "dăruirăm": "dărui",
    "dăruirăți": "dărui",
    "dăruise": "dărui",
    "dăruisem": "dărui",
    "dăruiseră": "dărui",
    "dăruiserăm": "dărui",
    "dăruiserăți": "dărui",
    "dăruiseși": "dărui",
    "dăruiși": "dărui",
    "dăruit": "dărui",
    "dăruiți": "dărui",
    "dăruitu": "dărui",
    "nedăruind": "dărui",
    "nedăruindu": "dărui",
    "nemaidăruind": "dărui",
    "nemaidăruindu": "dărui",
    "dăruirea": "dăruire",
    "dăruireo": "dăruire",
    "dăruiri": "dăruire",
    "dăruirii": "dăruire",
    "dăruirile": "dăruire",
    "dăruirilor": "dăruire",
    "dăruită": "dăruit",
    "dăruite": "dăruit",
    "dăruiți": "dăruit",
    "dăruitoarea": "dăruitoare",
    "dăruitoarei": "dăruitoare",
    "dăruitoarele": "dăruitoare",
    "dăruitoarelor": "dăruitoare",
    "dăruitoareo": "dăruitoare",
    "dăruitori": "dăruitor",
    "dăruitorii": "dăruitor",
    "dăruitorilor": "dăruitor",
    "dăruitorul": "dăruitor",
    "dăruitorule": "dăruitor",
    "dăruitorului": "dăruitor",
    "darwinismul": "darwinism",
    "darwinismule": "darwinism",
    "darwinismului": "darwinism",
    "darwinista": "darwinist",
    "darwinistă": "darwinist",
    "darwiniste": "darwinist",
    "darwinistei": "darwinist",
    "darwinistele": "darwinist",
    "darwinistelor": "darwinist",
    "darwiniști": "darwinist",
    "darwiniștii": "darwinist",
    "darwiniștilor": "darwinist",
    "darwinisto": "darwinist",
    "darwinistul": "darwinist",
    "darwinistule": "darwinist",
    "darwinistului": "darwinist",
    "darwinista": "darwinistă",
    "darwiniste": "darwinistă",
    "darwinistei": "darwinistă",
    "darwinistele": "darwinistă",
    "darwinistelor": "darwinistă",
    "darwinisto": "darwinistă",
    "dârji": "dârz",
    "dârjii": "dârz",
    "dârjilor": "dârz",
    "dârza": "dârz",
    "dârză": "dârz",
    "dârze": "dârz",
    "dârzei": "dârz",
    "dârzele": "dârz",
    "dârzelor": "dârz",
    "dârzo": "dârz",
    "dârzul": "dârz",
    "dârzule": "dârz",
    "dârzului": "dârz",
    "dârzenia": "dârzenie",
    "dârzeniei": "dârzenie",
    "dârzenii": "dârzenie",
    "dârzeniile": "dârzenie",
    "dârzeniilor": "dârzenie",
    "dârzenio": "dârzenie",
    "dascăli": "dascăl",
    "dascălii": "dascăl",
    "dascălilor": "dascăl",
    "dascălul": "dascăl",
    "dascălule": "dascăl",
    "dascălului": "dascăl",
    "dăscăleala": "dăscăleală",
    "dăscălealo": "dăscăleală",
    "dăscăleli": "dăscăleală",
    "dăscălelii": "dăscăleală",
    "dăscălelile": "dăscăleală",
    "dăscălelilor": "dăscăleală",
    "dăscălea": "dăscăli",
    "dăscăleai": "dăscăli",
    "dăscăleam": "dăscăli",
    "dăscălească": "dăscăli",
    "dăscăleați": "dăscăli",
    "dăscăleau": "dăscăli",
    "dăscălesc": "dăscăli",
    "dăscălește": "dăscăli",
    "dăscălești": "dăscăli",
    "dăscălii": "dăscăli",
    "dăscălim": "dăscăli",
    "dăscălind": "dăscăli",
    "dăscălindu": "dăscăli",
    "dăscăliră": "dăscăli",
    "dăscălirăm": "dăscăli",
    "dăscălirăți": "dăscăli",
    "dăscălise": "dăscăli",
    "dăscălisem": "dăscăli",
    "dăscăliseră": "dăscăli",
    "dăscăliserăm": "dăscăli",
    "dăscăliserăți": "dăscăli",
    "dăscăliseși": "dăscăli",
    "dăscăliși": "dăscăli",
    "dăscălit": "dăscăli",
    "dăscăliți": "dăscăli",
    "dăscălitu": "dăscăli",
    "nedăscălind": "dăscăli",
    "nedăscălindu": "dăscăli",
    "nemaidăscălind": "dăscăli",
    "nemaidăscălindu": "dăscăli",
    "dăscălirea": "dăscălire",
    "dăscălireo": "dăscălire",
    "dăscăliri": "dăscălire",
    "dăscălirii": "dăscălire",
    "dăscălirile": "dăscălire",
    "dăscălirilor": "dăscălire",
    "dăscălita": "dăscălit",
    "dăscălită": "dăscălit",
    "dăscălite": "dăscălit",
    "dăscălitei": "dăscălit",
    "dăscălitele": "dăscălit",
    "dăscălitelor": "dăscălit",
    "dăscăliți": "dăscălit",
    "dăscăliții": "dăscălit",
    "dăscăliților": "dăscălit",
    "dăscălito": "dăscălit",
    "dăscălitul": "dăscălit",
    "dăscălitule": "dăscălit",
    "dăscălitului": "dăscălit",
    "data": "dat",
    "dată": "dat",
    "date": "dat",
    "datei": "dat",
    "datele": "dat",
    "datelor": "dat",
    "dați": "dat",
    "dații": "dat",
    "daților": "dat",
    "dato": "dat",
    "datul": "dat",
    "datule": "dat",
    "datului": "dat",
    "daturi": "dat",
    "daturile": "dat",
    "daturilor": "dat",
    "dată": "data",
    "datai": "data",
    "datam": "data",
    "datăm": "data",
    "datând": "data",
    "datându": "data",
    "datară": "data",
    "datarăm": "data",
    "datarăți": "data",
    "datase": "data",
    "datasem": "data",
    "dataseră": "data",
    "dataserăm": "data",
    "dataserăți": "data",
    "dataseși": "data",
    "datași": "data",
    "datat": "data",
    "datați": "data",
    "datatu": "data",
    "datau": "data",
    "datează": "data",
    "datez": "data",
    "dateze": "data",
    "datezi": "data",
    "nedatând": "data",
    "nedatându": "data",
    "nemaidatând": "data",
    "nemaidatându": "data",
    "data": "dată",
    "date": "dată",
    "datei": "dată",
    "datele": "dată",
    "datelor": "dată",
    "dăți": "dată",
    "dății": "dată",
    "dățile": "dată",
    "dăților": "dată",
    "dato": "dată",
    "datarea": "datare",
    "datareo": "datare",
    "datări": "datare",
    "datării": "datare",
    "datările": "datare",
    "datărilor": "datare",
    "datata": "datat",
    "datată": "datat",
    "datate": "datat",
    "datatei": "datat",
    "datatele": "datat",
    "datatelor": "datat",
    "datați": "datat",
    "datații": "datat",
    "dataților": "datat",
    "datato": "datat",
    "datatul": "datat",
    "datatule": "datat",
    "datatului": "datat",
    "dătătoare": "dătător",
    "dătătoarea": "dătător",
    "dătătoarei": "dătător",
    "dătătoarele": "dătător",
    "dătătoarelor": "dătător",
    "dătătoareo": "dătător",
    "dătători": "dătător",
    "dătătorii": "dătător",
    "dătătorilor": "dătător",
    "dătătorul": "dătător",
    "dătătorule": "dătător",
    "dătătorului": "dătător",
    "datina": "datină",
    "datini": "datină",
    "datinii": "datină",
    "datinile": "datină",
    "datinilor": "datină",
    "datino": "datină",
    "d.": "dativ",
    "dat.": "dativ",
    "dative": "dativ",
    "dativele": "dativ",
    "dativelor": "dativ",
    "dativul": "dativ",
    "dativule": "dativ",
    "dativului": "dativ",
    "datoare": "dator",
    "datoarea": "dator",
    "datoarei": "dator",
    "datoarele": "dator",
    "datoarelor": "dator",
    "datoareo": "dator",
    "datori": "dator",
    "datorii": "dator",
    "datorilor": "dator",
    "datorul": "dator",
    "datorule": "dator",
    "datorului": "dator",
    "datoră": "datora",
    "datorai": "datora",
    "datoram": "datora",
    "datorăm": "datora",
    "datorând": "datora",
    "datorându": "datora",
    "datorară": "datora",
    "datorarăm": "datora",
    "datorarăți": "datora",
    "datorase": "datora",
    "datorasem": "datora",
    "datoraseră": "datora",
    "datoraserăm": "datora",
    "datoraserăți": "datora",
    "datoraseși": "datora",
    "datorași": "datora",
    "datorat": "datora",
    "datorați": "datora",
    "datoratu": "datora",
    "datorau": "datora",
    "datorează": "datora",
    "datorește": "datora",
    "datorez": "datora",
    "datoreze": "datora",
    "datorezi": "datora",
    "nedatorând": "datora",
    "nedatorându": "datora",
    "nemaidatorând": "datora",
    "nemaidatorându": "datora",
    "datorata": "datorat",
    "datorată": "datorat",
    "datorate": "datorat",
    "datoratei": "datorat",
    "datoratele": "datorat",
    "datoratelor": "datorat",
    "datorați": "datorat",
    "datorații": "datorat",
    "datoraților": "datorat",
    "datorato": "datorat",
    "datoratul": "datorat",
    "datoratule": "datorat",
    "datoratului": "datorat",
    "datoria": "datorie",
    "datoriei": "datorie",
    "datorii": "datorie",
    "datoriile": "datorie",
    "datoriilor": "datorie",
    "datorio": "datorie",
    "datornica": "datornic",
    "datornică": "datornic",
    "datornici": "datornic",
    "datornicii": "datornic",
    "datornicile": "datornic",
    "datornicilor": "datornic",
    "datornicul": "datornic",
    "datornicule": "datornic",
    "datornicului": "datornic",
    "datornica": "datornică",
    "datornici": "datornică",
    "datornicii": "datornică",
    "datornicile": "datornică",
    "datornicilor": "datornică",
    "datornico": "datornică",
    "dauna": "daună",
    "daune": "daună",
    "daunei": "daună",
    "daunele": "daună",
    "daunelor": "daună",
    "dauno": "daună",
    "dăună": "dăuna",
    "dăunai": "dăuna",
    "dăunam": "dăuna",
    "dăunăm": "dăuna",
    "dăunând": "dăuna",
    "dăunându": "dăuna",
    "dăunară": "dăuna",
    "dăunarăm": "dăuna",
    "dăunarăți": "dăuna",
    "dăunase": "dăuna",
    "dăunasem": "dăuna",
    "dăunaseră": "dăuna",
    "dăunaserăm": "dăuna",
    "dăunaserăți": "dăuna",
    "dăunaseși": "dăuna",
    "dăunași": "dăuna",
    "dăunat": "dăuna",
    "dăunați": "dăuna",
    "dăunatu": "dăuna",
    "dăunau": "dăuna",
    "dăunează": "dăuna",
    "dăunez": "dăuna",
    "dăuneze": "dăuna",
    "dăunezi": "dăuna",
    "nedăunând": "dăuna",
    "nedăunându": "dăuna",
    "nemaidăunând": "dăuna",
    "nemaidăunându": "dăuna",
    "dăunată": "dăunat",
    "dăunate": "dăunat",
    "dăunați": "dăunat",
    "dăunătoare": "dăunător",
    "dăunătoarea": "dăunător",
    "dăunătoarei": "dăunător",
    "dăunătoarele": "dăunător",
    "dăunătoarelor": "dăunător",
    "dăunătoareo": "dăunător",
    "dăunători": "dăunător",
    "dăunătorii": "dăunător",
    "dăunătorilor": "dăunător",
    "dăunătorul": "dăunător",
    "dăunătorule": "dăunător",
    "dăunătorului": "dăunător",
    "d'": "de",
    "d-": "de",
    "dă": "de",
    "dă-": "de",
    "de-": "de",
    "d.e.": "de_exemplu",
    "tv.": "de_televiziune",
    "dealul": "deal",
    "dealule": "deal",
    "dealului": "deal",
    "dealuri": "deal",
    "dealurile": "deal",
    "dealurilor": "deal",
    "deambularea": "deambulare",
    "deambulări": "deambulare",
    "deambulării": "deambulare",
    "deambulările": "deambulare",
    "deambulărilor": "deambulare",
    "debandada": "debandadă",
    "debandade": "debandadă",
    "debandadei": "debandadă",
    "debandadele": "debandadă",
    "debandadelor": "debandadă",
    "debandado": "debandadă",
    "debarale": "debara",
    "debaralei": "debara",
    "debaralele": "debara",
    "debaralelor": "debara",
    "debarao": "debara",
    "debaraua": "debara",
    "debarasă": "debarasa",
    "debarasai": "debarasa",
    "debarasam": "debarasa",
    "debarasăm": "debarasa",
    "debarasând": "debarasa",
    "debarasându": "debarasa",
    "debarasară": "debarasa",
    "debarasarăm": "debarasa",
    "debarasarăți": "debarasa",
    "debarasase": "debarasa",
    "debarasasem": "debarasa",
    "debarasaseră": "debarasa",
    "debarasaserăm": "debarasa",
    "debarasaserăți": "debarasa",
    "debarasaseși": "debarasa",
    "debarasași": "debarasa",
    "debarasat": "debarasa",
    "debarasați": "debarasa",
    "debarasatu": "debarasa",
    "debarasau": "debarasa",
    "debarasează": "debarasa",
    "debarasez": "debarasa",
    "debaraseze": "debarasa",
    "debarasezi": "debarasa",
    "nedebarasând": "debarasa",
    "nedebarasându": "debarasa",
    "nemaidebarasând": "debarasa",
    "nemaidebarasându": "debarasa",
    "debarasată": "debarasat",
    "debarasate": "debarasat",
    "debarasați": "debarasat",
    "debarc": "debarca",
    "debarcă": "debarca",
    "debarcai": "debarca",
    "debarcam": "debarca",
    "debarcăm": "debarca",
    "debarcând": "debarca",
    "debarcându": "debarca",
    "debarcară": "debarca",
    "debarcarăm": "debarca",
    "debarcarăți": "debarca",
    "debarcase": "debarca",
    "debarcasem": "debarca",
    "debarcaseră": "debarca",
    "debarcaserăm": "debarca",
    "debarcaserăți": "debarca",
    "debarcaseși": "debarca",
    "debarcași": "debarca",
    "debarcat": "debarca",
    "debarcați": "debarca",
    "debarcatu": "debarca",
    "debarcau": "debarca",
    "debarce": "debarca",
    "debarci": "debarca",
    "nedebarcând": "debarca",
    "nedebarcându": "debarca",
    "nemaidebarcând": "debarca",
    "nemaidebarcându": "debarca",
    "debarcadere": "debarcader",
    "debarcaderele": "debarcader",
    "debarcaderelor": "debarcader",
    "debarcaderul": "debarcader",
    "debarcaderule": "debarcader",
    "debarcaderului": "debarcader",
    "debarcarea": "debarcare",
    "debarcareo": "debarcare",
    "debarcări": "debarcare",
    "debarcării": "debarcare",
    "debarcările": "debarcare",
    "debarcărilor": "debarcare",
    "debarcată": "debarcat",
    "debarcate": "debarcat",
    "debarcați": "debarcat",
    "debila": "debil",
    "debilă": "debil",
    "debile": "debil",
    "debilei": "debil",
    "debilele": "debil",
    "debilelor": "debil",
    "debili": "debil",
    "debilii": "debil",
    "debililor": "debil",
    "debilo": "debil",
    "debilul": "debil",
    "debilule": "debil",
    "debilului": "debil",
    "debilită": "debilita",
    "debilitai": "debilita",
    "debilitam": "debilita",
    "debilităm": "debilita",
    "debilitând": "debilita",
    "debilitându": "debilita",
    "debilitară": "debilita",
    "debilitarăm": "debilita",
    "debilitarăți": "debilita",
    "debilitase": "debilita",
    "debilitasem": "debilita",
    "debilitaseră": "debilita",
    "debilitaserăm": "debilita",
    "debilitaserăți": "debilita",
    "debilitaseși": "debilita",
    "debilitași": "debilita",
    "debilitat": "debilita",
    "debilitați": "debilita",
    "debilitatu": "debilita",
    "debilitau": "debilita",
    "debilitează": "debilita",
    "debilitez": "debilita",
    "debiliteze": "debilita",
    "debilitezi": "debilita",
    "nedebilitând": "debilita",
    "nedebilitându": "debilita",
    "nemaidebilitând": "debilita",
    "nemaidebilitându": "debilita",
    "debilitarea": "debilitare",
    "debilitareo": "debilitare",
    "debilitări": "debilitare",
    "debilitării": "debilitare",
    "debilitările": "debilitare",
    "debilitărilor": "debilitare",
    "debilitată": "debilitat",
    "debilitate": "debilitat",
    "debilitați": "debilitat",
    "debilitatea": "debilitate",
    "debilitateo": "debilitate",
    "debilități": "debilitate",
    "debilității": "debilitate",
    "debilitățile": "debilitate",
    "debilităților": "debilitate",
    "debite": "debit",
    "debitele": "debit",
    "debitelor": "debit",
    "debitul": "debit",
    "debitule": "debit",
    "debitului": "debit",
    "debită": "debita",
    "debitai": "debita",
    "debitam": "debita",
    "debităm": "debita",
    "debitând": "debita",
    "debitându": "debita",
    "debitară": "debita",
    "debitarăm": "debita",
    "debitarăți": "debita",
    "debitase": "debita",
    "debitasem": "debita",
    "debitaseră": "debita",
    "debitaserăm": "debita",
    "debitaserăți": "debita",
    "debitaseși": "debita",
    "debitași": "debita",
    "debitat": "debita",
    "debitați": "debita",
    "debitatu": "debita",
    "debitau": "debita",
    "debitează": "debita",
    "debitez": "debita",
    "debiteze": "debita",
    "debitezi": "debita",
    "nedebitând": "debita",
    "nedebitându": "debita",
    "nemaidebitând": "debita",
    "nemaidebitându": "debita",
    "debitanți": "debitant",
    "debitanții": "debitant",
    "debitanților": "debitant",
    "debitantul": "debitant",
    "debitantule": "debitant",
    "debitantului": "debitant",
    "debitanta": "debitantă",
    "debitante": "debitantă",
    "debitantei": "debitantă",
    "debitantele": "debitantă",
    "debitantelor": "debitantă",
    "debitanto": "debitantă",
    "debitarea": "debitare",
    "debitareo": "debitare",
    "debitări": "debitare",
    "debitării": "debitare",
    "debitările": "debitare",
    "debitărilor": "debitare",
    "debitată": "debitat",
    "debitate": "debitat",
    "debitați": "debitat",
    "debitoarea": "debitoare",
    "debitoarei": "debitoare",
    "debitoarele": "debitoare",
    "debitoarelor": "debitoare",
    "debitoareo": "debitoare",
    "debitoare": "debitor",
    "debitoarea": "debitor",
    "debitoarei": "debitor",
    "debitoarele": "debitor",
    "debitoarelor": "debitor",
    "debitoareo": "debitor",
    "debitori": "debitor",
    "debitorii": "debitor",
    "debitorilor": "debitor",
    "debitorul": "debitor",
    "debitorule": "debitor",
    "debitorului": "debitor",
    "debleul": "debleu",
    "debleule": "debleu",
    "debleului": "debleu",
    "debleuri": "debleu",
    "debleurile": "debleu",
    "debleurilor": "debleu",
    "deblocă": "debloca",
    "deblocai": "debloca",
    "deblocam": "debloca",
    "deblocăm": "debloca",
    "deblocând": "debloca",
    "deblocându": "debloca",
    "deblocară": "debloca",
    "deblocarăm": "debloca",
    "deblocarăți": "debloca",
    "deblocase": "debloca",
    "deblocasem": "debloca",
    "deblocaseră": "debloca",
    "deblocaserăm": "debloca",
    "deblocaserăți": "debloca",
    "deblocaseși": "debloca",
    "deblocași": "debloca",
    "deblocat": "debloca",
    "deblocați": "debloca",
    "deblocatu": "debloca",
    "deblocau": "debloca",
    "deblochează": "debloca",
    "deblochez": "debloca",
    "deblocheze": "debloca",
    "deblochezi": "debloca",
    "nedeblocând": "debloca",
    "nedeblocându": "debloca",
    "nemaideblocând": "debloca",
    "nemaideblocându": "debloca",
    "deblocarea": "deblocare",
    "deblocareo": "deblocare",
    "deblocări": "deblocare",
    "deblocării": "deblocare",
    "deblocările": "deblocare",
    "deblocărilor": "deblocare",
    "deblocată": "deblocat",
    "deblocate": "deblocat",
    "deblocați": "deblocat",
    "debordă": "deborda",
    "debordai": "deborda",
    "debordam": "deborda",
    "debordăm": "deborda",
    "debordând": "deborda",
    "debordându": "deborda",
    "debordară": "deborda",
    "debordarăm": "deborda",
    "debordarăți": "deborda",
    "debordase": "deborda",
    "debordasem": "deborda",
    "debordaseră": "deborda",
    "debordaserăm": "deborda",
    "debordaserăți": "deborda",
    "debordaseși": "deborda",
    "debordași": "deborda",
    "debordat": "deborda",
    "debordați": "deborda",
    "debordatu": "deborda",
    "debordau": "deborda",
    "debordează": "deborda",
    "debordez": "deborda",
    "debordeze": "deborda",
    "debordezi": "deborda",
    "nedebordând": "deborda",
    "nedebordându": "deborda",
    "nemaidebordând": "deborda",
    "nemaidebordându": "deborda",
    "debordată": "debordat",
    "debordate": "debordat",
    "debordați": "debordat",
    "debreiă": "debreia",
    "debreiai": "debreia",
    "debreiam": "debreia",
    "debreiară": "debreia",
    "debreiarăm": "debreia",
    "debreiarăți": "debreia",
    "debreiase": "debreia",
    "debreiasem": "debreia",
    "debreiaseră": "debreia",
    "debreiaserăm": "debreia",
    "debreiaserăți": "debreia",
    "debreiaseși": "debreia",
    "debreiași": "debreia",
    "debreiat": "debreia",
    "debreiați": "debreia",
    "debreiatu": "debreia",
    "debreiau": "debreia",
    "debreiază": "debreia",
    "debreie": "debreia",
    "debreiează": "debreia",
    "debreiem": "debreia",
    "debreiez": "debreia",
    "debreieze": "debreia",
    "debreiezi": "debreia",
    "debreind": "debreia",
    "debreindu": "debreia",
    "nedebreind": "debreia",
    "nedebreindu": "debreia",
    "nemaidebreind": "debreia",
    "nemaidebreindu": "debreia",
    "debreiată": "debreiat",
    "debreiate": "debreiat",
    "debreiați": "debreiat",
    "debușee": "debușeu",
    "debușeele": "debușeu",
    "debușeelor": "debușeu",
    "debușeul": "debușeu",
    "debușeule": "debușeu",
    "debușeului": "debușeu",
    "debusolă": "debusola",
    "debusolai": "debusola",
    "debusolam": "debusola",
    "debusolăm": "debusola",
    "debusolând": "debusola",
    "debusolându": "debusola",
    "debusolară": "debusola",
    "debusolarăm": "debusola",
    "debusolarăți": "debusola",
    "debusolase": "debusola",
    "debusolasem": "debusola",
    "debusolaseră": "debusola",
    "debusolaserăm": "debusola",
    "debusolaserăți": "debusola",
    "debusolaseși": "debusola",
    "debusolași": "debusola",
    "debusolat": "debusola",
    "debusolați": "debusola",
    "debusolatu": "debusola",
    "debusolau": "debusola",
    "debusolează": "debusola",
    "debusolez": "debusola",
    "debusoleze": "debusola",
    "debusolezi": "debusola",
    "debusolarea": "debusolare",
    "debusolareo": "debusolare",
    "debusolări": "debusolare",
    "debusolării": "debusolare",
    "debusolările": "debusolare",
    "debusolărilor": "debusolare",
    "debusolata": "debusolat",
    "debusolată": "debusolat",
    "debusolate": "debusolat",
    "debusolatei": "debusolat",
    "debusolatele": "debusolat",
    "debusolatelor": "debusolat",
    "debusolați": "debusolat",
    "debusolații": "debusolat",
    "debusolaților": "debusolat",
    "debusolato": "debusolat",
    "debusolatul": "debusolat",
    "debusolatule": "debusolat",
    "debusolatului": "debusolat",
    "debutul": "debut",
    "debutule": "debut",
    "debutului": "debut",
    "debuturi": "debut",
    "debuturile": "debut",
    "debuturilor": "debut",
    "debută": "debuta",
    "debutai": "debuta",
    "debutam": "debuta",
    "debutăm": "debuta",
    "debutând": "debuta",
    "debutându": "debuta",
    "debutară": "debuta",
    "debutarăm": "debuta",
    "debutarăți": "debuta",
    "debutase": "debuta",
    "debutasem": "debuta",
    "debutaseră": "debuta",
    "debutaserăm": "debuta",
    "debutaserăți": "debuta",
    "debutaseși": "debuta",
    "debutași": "debuta",
    "debutat": "debuta",
    "debutați": "debuta",
    "debutatu": "debuta",
    "debutau": "debuta",
    "debutează": "debuta",
    "debutez": "debuta",
    "debuteze": "debuta",
    "debutezi": "debuta",
    "nedebutând": "debuta",
    "nedebutându": "debuta",
    "nemaidebutând": "debuta",
    "nemaidebutându": "debuta",
    "debutanți": "debutant",
    "debutanții": "debutant",
    "debutanților": "debutant",
    "debutantul": "debutant",
    "debutantule": "debutant",
    "debutantului": "debutant",
    "debutanta": "debutantă",
    "debutante": "debutantă",
    "debutantei": "debutantă",
    "debutantele": "debutantă",
    "debutantelor": "debutantă",
    "debutanto": "debutantă",
    "debutată": "debutat",
    "debutate": "debutat",
    "debutați": "debutat",
    "da": "deca",
    "decada": "decadă",
    "decade": "decadă",
    "decadei": "decadă",
    "decadele": "decadă",
    "decadelor": "decadă",
    "decado": "decadă",
    "decad": "decădea",
    "decadă": "decădea",
    "decade": "decădea",
    "decădeai": "decădea",
    "decădeam": "decădea",
    "decădeați": "decădea",
    "decădeau": "decădea",
    "decădem": "decădea",
    "decădeți": "decădea",
    "decăzând": "decădea",
    "decăzându": "decădea",
    "decazi": "decădea",
    "decăzu": "decădea",
    "decăzui": "decădea",
    "decăzură": "decădea",
    "decăzurăm": "decădea",
    "decăzurăți": "decădea",
    "decăzuse": "decădea",
    "decăzusem": "decădea",
    "decăzuseră": "decădea",
    "decăzuserăm": "decădea",
    "decăzuserăți": "decădea",
    "decăzuseși": "decădea",
    "decăzuși": "decădea",
    "decăzut": "decădea",
    "decăzutu": "decădea",
    "nedecăzând": "decădea",
    "nedecăzându": "decădea",
    "nemaidecăzând": "decădea",
    "nemaidecăzându": "decădea",
    "decadenta": "decadent",
    "decadentă": "decadent",
    "decadente": "decadent",
    "decadentei": "decadent",
    "decadentele": "decadent",
    "decadentelor": "decadent",
    "decadenți": "decadent",
    "decadenții": "decadent",
    "decadenților": "decadent",
    "decadento": "decadent",
    "decadentul": "decadent",
    "decadentule": "decadent",
    "decadentului": "decadent",
    "decadența": "decadență",
    "decadențe": "decadență",
    "decadenței": "decadență",
    "decadențele": "decadență",
    "decadențelor": "decadență",
    "decadențo": "decadență",
    "decăderea": "decădere",
    "decădereo": "decădere",
    "decăderi": "decădere",
    "decăderii": "decădere",
    "decăderile": "decădere",
    "decăderilor": "decădere",
    "decaedre": "decaedru",
    "decaedrele": "decaedru",
    "decaedrelor": "decaedru",
    "decaedrul": "decaedru",
    "decaedrule": "decaedru",
    "decaedrului": "decaedru",
    "decagoane": "decagon",
    "decagoanele": "decagon",
    "decagoanelor": "decagon",
    "decagonul": "decagon",
    "decagonule": "decagon",
    "decagonului": "decagon",
    "dag": "decagram",
    "decalaje": "decalaj",
    "decalajele": "decalaj",
    "decalajelor": "decalaj",
    "decalajul": "decalaj",
    "decalajule": "decalaj",
    "decalajului": "decalaj",
    "decalc": "decalca",
    "decalcă": "decalca",
    "decalcai": "decalca",
    "decalcam": "decalca",
    "decalcăm": "decalca",
    "decalcând": "decalca",
    "decalcându": "decalca",
    "decalcară": "decalca",
    "decalcarăm": "decalca",
    "decalcarăți": "decalca",
    "decalcase": "decalca",
    "decalcasem": "decalca",
    "decalcaseră": "decalca",
    "decalcaserăm": "decalca",
    "decalcaserăți": "decalca",
    "decalcaseși": "decalca",
    "decalcași": "decalca",
    "decalcat": "decalca",
    "decalcați": "decalca",
    "decalcatu": "decalca",
    "decalcau": "decalca",
    "decalce": "decalca",
    "decalci": "decalca",
    "nedecalcând": "decalca",
    "nedecalcându": "decalca",
    "nemaidecalcând": "decalca",
    "nemaidecalcându": "decalca",
    "decalcarea": "decalcare",
    "decalcareo": "decalcare",
    "decalcări": "decalcare",
    "decalcării": "decalcare",
    "decalcările": "decalcare",
    "decalcărilor": "decalcare",
    "decalcată": "decalcat",
    "decalcate": "decalcat",
    "decalcați": "decalcat",
    "decalcifiai": "decalcifia",
    "decalcifiam": "decalcifia",
    "decalcifiară": "decalcifia",
    "decalcifiarăm": "decalcifia",
    "decalcifiarăți": "decalcifia",
    "decalcifiase": "decalcifia",
    "decalcifiasem": "decalcifia",
    "decalcifiaseră": "decalcifia",
    "decalcifiaserăm": "decalcifia",
    "decalcifiaserăți": "decalcifia",
    "decalcifiaseși": "decalcifia",
    "decalcifiași": "decalcifia",
    "decalcifiat": "decalcifia",
    "decalcifiați": "decalcifia",
    "decalcifiatu": "decalcifia",
    "decalcifiau": "decalcifia",
    "decalcifiază": "decalcifia",
    "decalcifie": "decalcifia",
    "decalcifiem": "decalcifia",
    "decalcifiez": "decalcifia",
    "decalcifieze": "decalcifia",
    "decalcifiezi": "decalcifia",
    "decalcifiind": "decalcifia",
    "decalcifiindu": "decalcifia",
    "nedecalcifiind": "decalcifia",
    "nedecalcifiindu": "decalcifia",
    "nemaidecalcifiind": "decalcifia",
    "nemaidecalcifiindu": "decalcifia",
    "decalcifiată": "decalcifiat",
    "decalcifiate": "decalcifiat",
    "decalcifiați": "decalcifiat",
    "decalcific": "decalcifica",
    "decalcifică": "decalcifica",
    "decalcificai": "decalcifica",
    "decalcificam": "decalcifica",
    "decalcificăm": "decalcifica",
    "decalcificând": "decalcifica",
    "decalcificându": "decalcifica",
    "decalcificară": "decalcifica",
    "decalcificarăm": "decalcifica",
    "decalcificarăți": "decalcifica",
    "decalcificase": "decalcifica",
    "decalcificasem": "decalcifica",
    "decalcificaseră": "decalcifica",
    "decalcificaserăm": "decalcifica",
    "decalcificaserăți": "decalcifica",
    "decalcificaseși": "decalcifica",
    "decalcificași": "decalcifica",
    "decalcificat": "decalcifica",
    "decalcificați": "decalcifica",
    "decalcificatu": "decalcifica",
    "decalcificau": "decalcifica",
    "decalcifice": "decalcifica",
    "decalcifici": "decalcifica",
    "nedecalcificând": "decalcifica",
    "nedecalcificându": "decalcifica",
    "nemaidecalcificând": "decalcifica",
    "nemaidecalcificându": "decalcifica",
    "decalcificarea": "decalcificare",
    "decalcificareo": "decalcificare",
    "decalcificări": "decalcificare",
    "decalcificării": "decalcificare",
    "decalcificările": "decalcificare",
    "decalcificărilor": "decalcificare",
    "decalcificată": "decalcificat",
    "decalcificate": "decalcificat",
    "decalcificați": "decalcificat",
    "decalcifierea": "decalcifiere",
    "decalcifiereo": "decalcifiere",
    "decalcifieri": "decalcifiere",
    "decalcifierii": "decalcifiere",
    "decalcifierile": "decalcifiere",
    "decalcifierilor": "decalcifiere",
    "dal": "decalitru",
    "decalogul": "decalog",
    "decalogule": "decalog",
    "decalogului": "decalog",
    "decani": "decan",
    "decanii": "decan",
    "decanilor": "decan",
    "decanul": "decan",
    "decanule": "decan",
    "decanului": "decan",
    "decana": "decană",
    "decane": "decană",
    "decanei": "decană",
    "decanele": "decană",
    "decanelor": "decană",
    "decano": "decană",
    "decantă": "decanta",
    "decantai": "decanta",
    "decantam": "decanta",
    "decantăm": "decanta",
    "decantând": "decanta",
    "decantându": "decanta",
    "decantară": "decanta",
    "decantarăm": "decanta",
    "decantarăți": "decanta",
    "decantase": "decanta",
    "decantasem": "decanta",
    "decantaseră": "decanta",
    "decantaserăm": "decanta",
    "decantaserăți": "decanta",
    "decantaseși": "decanta",
    "decantași": "decanta",
    "decantat": "decanta",
    "decantați": "decanta",
    "decantatu": "decanta",
    "decantau": "decanta",
    "decantează": "decanta",
    "decantez": "decanta",
    "decanteze": "decanta",
    "decantezi": "decanta",
    "nedecantând": "decanta",
    "nedecantându": "decanta",
    "nemaidecantând": "decanta",
    "nemaidecantându": "decanta",
    "decantarea": "decantare",
    "decantareo": "decantare",
    "decantări": "decantare",
    "decantării": "decantare",
    "decantările": "decantare",
    "decantărilor": "decantare",
    "decantată": "decantat",
    "decantate": "decantat",
    "decantați": "decantat",
    "decantoare": "decantor",
    "decantoarele": "decantor",
    "decantoarelor": "decantor",
    "decantorul": "decantor",
    "decantorule": "decantor",
    "decantorului": "decantor",
    "decapă": "decapa",
    "decapai": "decapa",
    "decapam": "decapa",
    "decapăm": "decapa",
    "decapând": "decapa",
    "decapându": "decapa",
    "decapară": "decapa",
    "decaparăm": "decapa",
    "decaparăți": "decapa",
    "decapase": "decapa",
    "decapasem": "decapa",
    "decapaseră": "decapa",
    "decapaserăm": "decapa",
    "decapaserăți": "decapa",
    "decapaseși": "decapa",
    "decapași": "decapa",
    "decapat": "decapa",
    "decapați": "decapa",
    "decapatu": "decapa",
    "decapau": "decapa",
    "decapează": "decapa",
    "decapez": "decapa",
    "decapeze": "decapa",
    "decapezi": "decapa",
    "nedecapând": "decapa",
    "nedecapându": "decapa",
    "nemaidecapând": "decapa",
    "nemaidecapându": "decapa",
    "decaparea": "decapare",
    "decapareo": "decapare",
    "decapări": "decapare",
    "decapării": "decapare",
    "decapările": "decapare",
    "decapărilor": "decapare",
    "decapată": "decapat",
    "decapate": "decapat",
    "decapați": "decapat",
    "decapită": "decapita",
    "decapitai": "decapita",
    "decapitam": "decapita",
    "decapităm": "decapita",
    "decapitând": "decapita",
    "decapitându": "decapita",
    "decapitară": "decapita",
    "decapitarăm": "decapita",
    "decapitarăți": "decapita",
    "decapitase": "decapita",
    "decapitasem": "decapita",
    "decapitaseră": "decapita",
    "decapitaserăm": "decapita",
    "decapitaserăți": "decapita",
    "decapitaseși": "decapita",
    "decapitași": "decapita",
    "decapitat": "decapita",
    "decapitați": "decapita",
    "decapitatu": "decapita",
    "decapitau": "decapita",
    "decapitează": "decapita",
    "decapitez": "decapita",
    "decapiteze": "decapita",
    "decapitezi": "decapita",
    "nedecapitând": "decapita",
    "nedecapitându": "decapita",
    "nemaidecapitând": "decapita",
    "nemaidecapitându": "decapita",
    "decapitarea": "decapitare",
    "decapitareo": "decapitare",
    "decapitări": "decapitare",
    "decapitării": "decapitare",
    "decapitările": "decapitare",
    "decapitărilor": "decapitare",
    "decapitata": "decapitat",
    "decapitată": "decapitat",
    "decapitate": "decapitat",
    "decapitatei": "decapitat",
    "decapitatele": "decapitat",
    "decapitatelor": "decapitat",
    "decapitați": "decapitat",
    "decapitații": "decapitat",
    "decapitaților": "decapitat",
    "decapitato": "decapitat",
    "decapitatul": "decapitat",
    "decapitatule": "decapitat",
    "decapitatului": "decapitat",
    "decapode": "decapod",
    "decapodele": "decapod",
    "decapodelor": "decapod",
    "decapodul": "decapod",
    "decapodule": "decapod",
    "decapodului": "decapod",
    "decapotabila": "decapotabil",
    "decapotabilă": "decapotabil",
    "decapotabile": "decapotabil",
    "decapotabilei": "decapotabil",
    "decapotabilele": "decapotabil",
    "decapotabilelor": "decapotabil",
    "decapotabili": "decapotabil",
    "decapotabilii": "decapotabil",
    "decapotabililor": "decapotabil",
    "decapotabilo": "decapotabil",
    "decapotabilul": "decapotabil",
    "decapotabilule": "decapotabil",
    "decapotabilului": "decapotabil",
    "decari": "decar",
    "decarii": "decar",
    "decarilor": "decar",
    "decarul": "decar",
    "decarule": "decar",
    "decarului": "decar",
    "decarbură": "decarbura",
    "decarburai": "decarbura",
    "decarburam": "decarbura",
    "decarburăm": "decarbura",
    "decarburând": "decarbura",
    "decarburându": "decarbura",
    "decarburară": "decarbura",
    "decarburarăm": "decarbura",
    "decarburarăți": "decarbura",
    "decarburase": "decarbura",
    "decarburasem": "decarbura",
    "decarburaseră": "decarbura",
    "decarburaserăm": "decarbura",
    "decarburaserăți": "decarbura",
    "decarburaseși": "decarbura",
    "decarburași": "decarbura",
    "decarburat": "decarbura",
    "decarburați": "decarbura",
    "decarburatu": "decarbura",
    "decarburau": "decarbura",
    "decarburează": "decarbura",
    "decarburez": "decarbura",
    "decarbureze": "decarbura",
    "decarburezi": "decarbura",
    "nedecarburând": "decarbura",
    "nedecarburându": "decarbura",
    "nemaidecarburând": "decarbura",
    "nemaidecarburându": "decarbura",
    "decarburarea": "decarburare",
    "decarburareo": "decarburare",
    "decarburări": "decarburare",
    "decarburării": "decarburare",
    "decarburările": "decarburare",
    "decarburărilor": "decarburare",
    "decarburata": "decarburat",
    "decarburată": "decarburat",
    "decarburate": "decarburat",
    "decarburatei": "decarburat",
    "decarburatele": "decarburat",
    "decarburatelor": "decarburat",
    "decarburați": "decarburat",
    "decarburații": "decarburat",
    "decarburaților": "decarburat",
    "decarburato": "decarburat",
    "decarburatul": "decarburat",
    "decarburatule": "decarburat",
    "decarburatului": "decarburat",
    "decarcerarea": "decarcerare",
    "decarcerări": "decarcerare",
    "decarcerării": "decarcerare",
    "decarcerările": "decarcerare",
    "decarcerărilor": "decarcerare",
    "dăcât": "decât",
    "dicât": "decât",
    "decatloane": "decatlon",
    "decatloanele": "decatlon",
    "decatloanelor": "decatlon",
    "decatlonul": "decatlon",
    "decatlonule": "decatlon",
    "decatlonului": "decatlon",
    "decăzută": "decăzut",
    "decăzute": "decăzut",
    "decăzuți": "decăzut",
    "decedă": "deceda",
    "decedai": "deceda",
    "decedam": "deceda",
    "decedăm": "deceda",
    "decedând": "deceda",
    "decedându": "deceda",
    "decedară": "deceda",
    "decedarăm": "deceda",
    "decedarăți": "deceda",
    "decedase": "deceda",
    "decedasem": "deceda",
    "decedaseră": "deceda",
    "decedaserăm": "deceda",
    "decedaserăți": "deceda",
    "decedaseși": "deceda",
    "decedași": "deceda",
    "decedat": "deceda",
    "decedați": "deceda",
    "decedatu": "deceda",
    "decedau": "deceda",
    "decedează": "deceda",
    "decedez": "deceda",
    "decedeze": "deceda",
    "decedezi": "deceda",
    "nedecedând": "deceda",
    "nedecedându": "deceda",
    "nemaidecedând": "deceda",
    "nemaidecedându": "deceda",
    "dcd.": "decedat",
    "decedata": "decedat",
    "decedată": "decedat",
    "decedate": "decedat",
    "decedatei": "decedat",
    "decedatele": "decedat",
    "decedatelor": "decedat",
    "decedați": "decedat",
    "decedații": "decedat",
    "decedaților": "decedat",
    "decedato": "decedat",
    "decedatul": "decedat",
    "decedatule": "decedat",
    "decedatului": "decedat",
    "decedata": "decedată",
    "decedate": "decedată",
    "decedatei": "decedată",
    "decedatele": "decedată",
    "decedatelor": "decedată",
    "decedato": "decedată",
    "dec.": "decembrie",
    "decenii": "deceniu",
    "deceniile": "deceniu",
    "deceniilor": "deceniu",
    "deceniul": "deceniu",
    "deceniule": "deceniu",
    "deceniului": "deceniu",
    "decenta": "decent",
    "decentă": "decent",
    "decente": "decent",
    "decentei": "decent",
    "decentele": "decent",
    "decentelor": "decent",
    "decenți": "decent",
    "decenții": "decent",
    "decenților": "decent",
    "decento": "decent",
    "decentul": "decent",
    "decentule": "decent",
    "decentului": "decent",
    "decența": "decență",
    "decențe": "decență",
    "decenței": "decență",
    "decențele": "decență",
    "decențelor": "decență",
    "decențo": "decență",
    "decepția": "decepție",
    "decepției": "decepție",
    "decepții": "decepție",
    "decepțiile": "decepție",
    "decepțiilor": "decepție",
    "decepțio": "decepție",
    "decepționă": "decepționa",
    "decepționai": "decepționa",
    "decepționam": "decepționa",
    "decepționăm": "decepționa",
    "decepționând": "decepționa",
    "decepționându": "decepționa",
    "decepționară": "decepționa",
    "decepționarăm": "decepționa",
    "decepționarăți": "decepționa",
    "decepționase": "decepționa",
    "decepționasem": "decepționa",
    "decepționaseră": "decepționa",
    "decepționaserăm": "decepționa",
    "decepționaserăți": "decepționa",
    "decepționaseși": "decepționa",
    "decepționași": "decepționa",
    "decepționat": "decepționa",
    "decepționați": "decepționa",
    "decepționatu": "decepționa",
    "decepționau": "decepționa",
    "decepționează": "decepționa",
    "decepționez": "decepționa",
    "decepționeze": "decepționa",
    "decepționezi": "decepționa",
    "nedecepționând": "decepționa",
    "nedecepționându": "decepționa",
    "nemaidecepționând": "decepționa",
    "nemaidecepționându": "decepționa",
    "decepționata": "decepționat",
    "decepționată": "decepționat",
    "decepționate": "decepționat",
    "decepționatei": "decepționat",
    "decepționatele": "decepționat",
    "decepționatelor": "decepționat",
    "decepționați": "decepționat",
    "decepționații": "decepționat",
    "decepționaților": "decepționat",
    "decepționato": "decepționat",
    "decepționatul": "decepționat",
    "decepționatule": "decepționat",
    "decepționatului": "decepționat",
    "decepționismul": "decepționism",
    "decepționismule": "decepționism",
    "decepționismului": "decepționism",
    "decern": "decerna",
    "decernă": "decerna",
    "decernai": "decerna",
    "decernam": "decerna",
    "decernăm": "decerna",
    "decernând": "decerna",
    "decernându": "decerna",
    "decernară": "decerna",
    "decernarăm": "decerna",
    "decernarăți": "decerna",
    "decernase": "decerna",
    "decernasem": "decerna",
    "decernaseră": "decerna",
    "decernaserăm": "decerna",
    "decernaserăți": "decerna",
    "decernaseși": "decerna",
    "decernași": "decerna",
    "decernat": "decerna",
    "decernați": "decerna",
    "decernatu": "decerna",
    "decernau": "decerna",
    "decerne": "decerna",
    "decerni": "decerna",
    "nedecernând": "decerna",
    "nedecernându": "decerna",
    "nemaidecernând": "decerna",
    "nemaidecernându": "decerna",
    "decernarea": "decernare",
    "decernareo": "decernare",
    "decernări": "decernare",
    "decernării": "decernare",
    "decernările": "decernare",
    "decernărilor": "decernare",
    "decernată": "decernat",
    "decernate": "decernat",
    "decernați": "decernat",
    "decese": "deces",
    "decesele": "deces",
    "deceselor": "deces",
    "decesul": "deces",
    "decesule": "deces",
    "decesului": "deces",
    "dB": "decibel",
    "decibeli": "decibel",
    "decibelii": "decibel",
    "decid": "decide",
    "decidă": "decide",
    "decidea": "decide",
    "decideai": "decide",
    "decideam": "decide",
    "decideați": "decide",
    "decideau": "decide",
    "decidem": "decide",
    "decideți": "decide",
    "decis": "decide",
    "decise": "decide",
    "decisei": "decide",
    "deciseră": "decide",
    "deciserăm": "decide",
    "deciserăți": "decide",
    "decisese": "decide",
    "decisesem": "decide",
    "deciseseră": "decide",
    "deciseserăm": "decide",
    "deciseserăți": "decide",
    "deciseseși": "decide",
    "deciseși": "decide",
    "decisu": "decide",
    "decizând": "decide",
    "decizându": "decide",
    "decizi": "decide",
    "nedecizând": "decide",
    "nedecizându": "decide",
    "nemaidecizând": "decide",
    "nemaidecizându": "decide",
    "decimă": "decima",
    "decimai": "decima",
    "decimam": "decima",
    "decimăm": "decima",
    "decimând": "decima",
    "decimându": "decima",
    "decimară": "decima",
    "decimarăm": "decima",
    "decimarăți": "decima",
    "decimase": "decima",
    "decimasem": "decima",
    "decimaseră": "decima",
    "decimaserăm": "decima",
    "decimaserăți": "decima",
    "decimaseși": "decima",
    "decimași": "decima",
    "decimat": "decima",
    "decimați": "decima",
    "decimatu": "decima",
    "decimau": "decima",
    "decimează": "decima",
    "decimez": "decima",
    "decimeze": "decima",
    "decimezi": "decima",
    "nedecimând": "decima",
    "nedecimându": "decima",
    "nemaidecimând": "decima",
    "nemaidecimându": "decima",
    "decimala": "decimal",
    "decimală": "decimal",
    "decimale": "decimal",
    "decimalei": "decimal",
    "decimalele": "decimal",
    "decimalelor": "decimal",
    "decimali": "decimal",
    "decimalii": "decimal",
    "decimalilor": "decimal",
    "decimalo": "decimal",
    "decimalul": "decimal",
    "decimalule": "decimal",
    "decimalului": "decimal",
    "decimarea": "decimare",
    "decimareo": "decimare",
    "decimări": "decimare",
    "decimării": "decimare",
    "decimările": "decimare",
    "decimărilor": "decimare",
    "decimată": "decimat",
    "decimate": "decimat",
    "decimați": "decimat",
    "dm": "decimetru",
    "decisa": "decis",
    "decisă": "decis",
    "decise": "decis",
    "decisei": "decis",
    "decisele": "decis",
    "deciselor": "decis",
    "deciși": "decis",
    "decișii": "decis",
    "decișilor": "decis",
    "deciso": "decis",
    "decisul": "decis",
    "decisule": "decis",
    "decisului": "decis",
    "decisiva": "decisiv",
    "decisivă": "decisiv",
    "decisive": "decisiv",
    "decisivei": "decisiv",
    "decisivele": "decisiv",
    "decisivelor": "decisiv",
    "decisivi": "decisiv",
    "decisivii": "decisiv",
    "decisivilor": "decisiv",
    "decisivo": "decisiv",
    "decisivul": "decisiv",
    "decisivule": "decisiv",
    "decisivului": "decisiv",
    "d.civ.": "decizia_civilă",
    "d.": "decizie",
    "decizia": "decizie",
    "deciziei": "decizie",
    "decizii": "decizie",
    "deciziile": "decizie",
    "deciziilor": "decizie",
    "decizio": "decizie",
    "d.pen.": "decizie_penală",
    "decizionala": "decizional",
    "decizională": "decizional",
    "decizionale": "decizional",
    "decizionalei": "decizional",
    "decizionalele": "decizional",
    "decizionalelor": "decizional",
    "decizionali": "decizional",
    "decizionalii": "decizional",
    "decizionalilor": "decizional",
    "decizionalo": "decizional",
    "decizionalul": "decizional",
    "decizionalule": "decizional",
    "decizionalului": "decizional",
    "declam": "declama",
    "declamă": "declama",
    "declamai": "declama",
    "declamam": "declama",
    "declamăm": "declama",
    "declamând": "declama",
    "declamându": "declama",
    "declamară": "declama",
    "declamarăm": "declama",
    "declamarăți": "declama",
    "declamase": "declama",
    "declamasem": "declama",
    "declamaseră": "declama",
    "declamaserăm": "declama",
    "declamaserăți": "declama",
    "declamaseși": "declama",
    "declamași": "declama",
    "declamat": "declama",
    "declamați": "declama",
    "declamatu": "declama",
    "declamau": "declama",
    "declame": "declama",
    "declami": "declama",
    "nedeclamând": "declama",
    "nedeclamându": "declama",
    "nemaideclamând": "declama",
    "nemaideclamându": "declama",
    "declamarea": "declamare",
    "declamareo": "declamare",
    "declamări": "declamare",
    "declamării": "declamare",
    "declamările": "declamare",
    "declamărilor": "declamare",
    "declamată": "declamat",
    "declamate": "declamat",
    "declamați": "declamat",
    "declamația": "declamație",
    "declamației": "declamație",
    "declamații": "declamație",
    "declamațiile": "declamație",
    "declamațiilor": "declamație",
    "declamațio": "declamație",
    "declanșă": "declanșa",
    "declanșai": "declanșa",
    "declanșam": "declanșa",
    "declanșăm": "declanșa",
    "declanșând": "declanșa",
    "declanșându": "declanșa",
    "declanșară": "declanșa",
    "declanșarăm": "declanșa",
    "declanșarăți": "declanșa",
    "declanșase": "declanșa",
    "declanșasem": "declanșa",
    "declanșaseră": "declanșa",
    "declanșaserăm": "declanșa",
    "declanșaserăți": "declanșa",
    "declanșaseși": "declanșa",
    "declanșași": "declanșa",
    "declanșat": "declanșa",
    "declanșați": "declanșa",
    "declanșatu": "declanșa",
    "declanșau": "declanșa",
    "declanșează": "declanșa",
    "declanșez": "declanșa",
    "declanșeze": "declanșa",
    "declanșezi": "declanșa",
    "nedeclanșând": "declanșa",
    "nedeclanșându": "declanșa",
    "nemaideclanșând": "declanșa",
    "nemaideclanșându": "declanșa",
    "declanșarea": "declanșare",
    "declanșareo": "declanșare",
    "declanșări": "declanșare",
    "declanșării": "declanșare",
    "declanșările": "declanșare",
    "declanșărilor": "declanșare",
    "declanșată": "declanșat",
    "declanșate": "declanșat",
    "declanșați": "declanșat",
    "declanșatoare": "declanșator",
    "declanșatoarele": "declanșator",
    "declanșatoarelor": "declanșator",
    "declanșatorul": "declanșator",
    "declanșatorului": "declanșator",
    "declanșoare": "declanșor",
    "declanșoarele": "declanșor",
    "declanșoarelor": "declanșor",
    "declanșorul": "declanșor",
    "declanșorule": "declanșor",
    "declanșorului": "declanșor",
    "declar": "declara",
    "declară": "declara",
    "declarai": "declara",
    "declaram": "declara",
    "declarăm": "declara",
    "declarând": "declara",
    "declarându": "declara",
    "declarară": "declara",
    "declararăm": "declara",
    "declararăți": "declara",
    "declarase": "declara",
    "declarasem": "declara",
    "declaraseră": "declara",
    "declaraserăm": "declara",
    "declaraserăți": "declara",
    "declaraseși": "declara",
    "declarași": "declara",
    "declarat": "declara",
    "declarați": "declara",
    "declaratu": "declara",
    "declarau": "declara",
    "declare": "declara",
    "declari": "declara",
    "nedeclarând": "declara",
    "nedeclarându": "declara",
    "nemaideclarând": "declara",
    "nemaideclarându": "declara",
    "declararea": "declarare",
    "declarareo": "declarare",
    "declarări": "declarare",
    "declarării": "declarare",
    "declarările": "declarare",
    "declarărilor": "declarare",
    "declarata": "declarat",
    "declarată": "declarat",
    "declarate": "declarat",
    "declaratei": "declarat",
    "declaratele": "declarat",
    "declaratelor": "declarat",
    "declarați": "declarat",
    "declarații": "declarat",
    "declaraților": "declarat",
    "declarato": "declarat",
    "declaratul": "declarat",
    "declaratule": "declarat",
    "declaratului": "declarat",
    "declarația": "declarație",
    "declarației": "declarație",
    "declarații": "declarație",
    "declarațiile": "declarație",
    "declarațiilor": "declarație",
    "declarațio": "declarație",
    "declasă": "declasa",
    "declasai": "declasa",
    "declasam": "declasa",
    "declasăm": "declasa",
    "declasând": "declasa",
    "declasându": "declasa",
    "declasară": "declasa",
    "declasarăm": "declasa",
    "declasarăți": "declasa",
    "declasase": "declasa",
    "declasasem": "declasa",
    "declasaseră": "declasa",
    "declasaserăm": "declasa",
    "declasaserăți": "declasa",
    "declasaseși": "declasa",
    "declasași": "declasa",
    "declasat": "declasa",
    "declasați": "declasa",
    "declasatu": "declasa",
    "declasau": "declasa",
    "declasează": "declasa",
    "declasez": "declasa",
    "declaseze": "declasa",
    "declasezi": "declasa",
    "nedeclasând": "declasa",
    "nedeclasându": "declasa",
    "nemaideclasând": "declasa",
    "nemaideclasându": "declasa",
    "declasarea": "declasare",
    "declasareo": "declasare",
    "declasări": "declasare",
    "declasării": "declasare",
    "declasările": "declasare",
    "declasărilor": "declasare",
    "declasata": "declasat",
    "declasată": "declasat",
    "declasate": "declasat",
    "declasatei": "declasat",
    "declasatele": "declasat",
    "declasatelor": "declasat",
    "declasați": "declasat",
    "declasații": "declasat",
    "declasaților": "declasat",
    "declasato": "declasat",
    "declasatul": "declasat",
    "declasatule": "declasat",
    "declasatului": "declasat",
    "declicul": "declic",
    "declicule": "declic",
    "declicului": "declic",
    "declicuri": "declic",
    "declicurile": "declic",
    "declicurilor": "declic",
    "declinul": "declin",
    "declinule": "declin",
    "declinului": "declin",
    "declinuri": "declin",
    "declinurile": "declin",
    "declinurilor": "declin",
    "declin": "declina",
    "declină": "declina",
    "declinai": "declina",
    "declinam": "declina",
    "declinăm": "declina",
    "declinând": "declina",
    "declinându": "declina",
    "declinară": "declina",
    "declinarăm": "declina",
    "declinarăți": "declina",
    "declinase": "declina",
    "declinasem": "declina",
    "declinaseră": "declina",
    "declinaserăm": "declina",
    "declinaserăți": "declina",
    "declinaseși": "declina",
    "declinași": "declina",
    "declinat": "declina",
    "declinați": "declina",
    "declinatu": "declina",
    "declinau": "declina",
    "decline": "declina",
    "declini": "declina",
    "nedeclinând": "declina",
    "nedeclinându": "declina",
    "nemaideclinând": "declina",
    "nemaideclinându": "declina",
    "declinabila": "declinabil",
    "declinabilă": "declinabil",
    "declinabile": "declinabil",
    "declinabilei": "declinabil",
    "declinabilele": "declinabil",
    "declinabilelor": "declinabil",
    "declinabili": "declinabil",
    "declinabilii": "declinabil",
    "declinabililor": "declinabil",
    "declinabilo": "declinabil",
    "declinabilul": "declinabil",
    "declinabilule": "declinabil",
    "declinabilului": "declinabil",
    "declinarea": "declinare",
    "declinareo": "declinare",
    "declinări": "declinare",
    "declinării": "declinare",
    "declinările": "declinare",
    "declinărilor": "declinare",
    "declinată": "declinat",
    "declinate": "declinat",
    "declinați": "declinat",
    "declinația": "declinație",
    "declinației": "declinație",
    "declinații": "declinație",
    "declinațiile": "declinație",
    "declinațiilor": "declinație",
    "declinațio": "declinație",
    "declinatoria": "declinatoriu",
    "declinatorie": "declinatoriu",
    "declinatoriei": "declinatoriu",
    "declinatorii": "declinatoriu",
    "declinatoriii": "declinatoriu",
    "declinatoriile": "declinatoriu",
    "declinatoriilor": "declinatoriu",
    "declinatorio": "declinatoriu",
    "declinatoriul": "declinatoriu",
    "declinatoriule": "declinatoriu",
    "declinatoriului": "declinatoriu",
    "declivitatea": "declivitate",
    "declivitateo": "declivitate",
    "declivități": "declivitate",
    "declivității": "declivitate",
    "declivitățile": "declivitate",
    "declivităților": "declivitate",
    "decoctul": "decoct",
    "decoctule": "decoct",
    "decoctului": "decoct",
    "decocturi": "decoct",
    "decocturile": "decoct",
    "decocturilor": "decoct",
    "decodat": "decoda",
    "decodarea": "decodare",
    "decodări": "decodare",
    "decodării": "decodare",
    "decodările": "decodare",
    "decodărilor": "decodare",
    "decodată": "decodat",
    "decofră": "decofra",
    "decofrai": "decofra",
    "decofram": "decofra",
    "decofrăm": "decofra",
    "decofrând": "decofra",
    "decofrându": "decofra",
    "decofrară": "decofra",
    "decofrarăm": "decofra",
    "decofrarăți": "decofra",
    "decofrase": "decofra",
    "decofrasem": "decofra",
    "decofraseră": "decofra",
    "decofraserăm": "decofra",
    "decofraserăți": "decofra",
    "decofraseși": "decofra",
    "decofrași": "decofra",
    "decofrat": "decofra",
    "decofrați": "decofra",
    "decofratu": "decofra",
    "decofrau": "decofra",
    "decofrează": "decofra",
    "decofrez": "decofra",
    "decofreze": "decofra",
    "decofrezi": "decofra",
    "nedecofrând": "decofra",
    "nedecofrându": "decofra",
    "nemaidecofrând": "decofra",
    "nemaidecofrându": "decofra",
    "decofrarea": "decofrare",
    "decofrareo": "decofrare",
    "decofrări": "decofrare",
    "decofrării": "decofrare",
    "decofrările": "decofrare",
    "decofrărilor": "decofrare",
    "decofrată": "decofrat",
    "decofrate": "decofrat",
    "decofrați": "decofrat",
    "decolă": "decola",
    "decolai": "decola",
    "decolam": "decola",
    "decolăm": "decola",
    "decolând": "decola",
    "decolându": "decola",
    "decolară": "decola",
    "decolarăm": "decola",
    "decolarăți": "decola",
    "decolase": "decola",
    "decolasem": "decola",
    "decolaseră": "decola",
    "decolaserăm": "decola",
    "decolaserăți": "decola",
    "decolaseși": "decola",
    "decolași": "decola",
    "decolat": "decola",
    "decolați": "decola",
    "decolatu": "decola",
    "decolau": "decola",
    "decolează": "decola",
    "decolez": "decola",
    "decoleze": "decola",
    "decolezi": "decola",
    "nedecolând": "decola",
    "nedecolându": "decola",
    "nemaidecolând": "decola",
    "nemaidecolându": "decola",
    "decolarea": "decolare",
    "decolareo": "decolare",
    "decolări": "decolare",
    "decolării": "decolare",
    "decolările": "decolare",
    "decolărilor": "decolare",
    "decolată": "decolat",
    "decolate": "decolat",
    "decolați": "decolat",
    "decoloră": "decolora",
    "decolorai": "decolora",
    "decoloram": "decolora",
    "decolorăm": "decolora",
    "decolorând": "decolora",
    "decolorându": "decolora",
    "decolorară": "decolora",
    "decolorarăm": "decolora",
    "decolorarăți": "decolora",
    "decolorase": "decolora",
    "decolorasem": "decolora",
    "decoloraseră": "decolora",
    "decoloraserăm": "decolora",
    "decoloraserăți": "decolora",
    "decoloraseși": "decolora",
    "decolorași": "decolora",
    "decolorat": "decolora",
    "decolorați": "decolora",
    "decoloratu": "decolora",
    "decolorau": "decolora",
    "decolorează": "decolora",
    "decolorez": "decolora",
    "decoloreze": "decolora",
    "decolorezi": "decolora",
    "nedecolorând": "decolora",
    "nedecolorându": "decolora",
    "nemaidecolorând": "decolora",
    "nemaidecolorându": "decolora",
    "decolorarea": "decolorare",
    "decolorareo": "decolorare",
    "decolorări": "decolorare",
    "decolorării": "decolorare",
    "decolorările": "decolorare",
    "decolorărilor": "decolorare",
    "decolorata": "decolorat",
    "decolorată": "decolorat",
    "decolorate": "decolorat",
    "decoloratei": "decolorat",
    "decoloratele": "decolorat",
    "decoloratelor": "decolorat",
    "decolorați": "decolorat",
    "decolorații": "decolorat",
    "decoloraților": "decolorat",
    "decolorato": "decolorat",
    "decoloratul": "decolorat",
    "decoloratule": "decolorat",
    "decoloratului": "decolorat",
    "decoltă": "decolta",
    "decoltai": "decolta",
    "decoltam": "decolta",
    "decoltăm": "decolta",
    "decoltând": "decolta",
    "decoltându": "decolta",
    "decoltară": "decolta",
    "decoltarăm": "decolta",
    "decoltarăți": "decolta",
    "decoltase": "decolta",
    "decoltasem": "decolta",
    "decoltaseră": "decolta",
    "decoltaserăm": "decolta",
    "decoltaserăți": "decolta",
    "decoltaseși": "decolta",
    "decoltași": "decolta",
    "decoltat": "decolta",
    "decoltați": "decolta",
    "decoltatu": "decolta",
    "decoltau": "decolta",
    "decoltează": "decolta",
    "decoltez": "decolta",
    "decolteze": "decolta",
    "decoltezi": "decolta",
    "nedecoltând": "decolta",
    "nedecoltându": "decolta",
    "nemaidecoltând": "decolta",
    "nemaidecoltându": "decolta",
    "decoltata": "decoltat",
    "decoltată": "decoltat",
    "decoltate": "decoltat",
    "decoltatei": "decoltat",
    "decoltatele": "decoltat",
    "decoltatelor": "decoltat",
    "decoltați": "decoltat",
    "decoltații": "decoltat",
    "decoltaților": "decoltat",
    "decoltato": "decoltat",
    "decoltatul": "decoltat",
    "decoltatule": "decoltat",
    "decoltatului": "decoltat",
    "decoltee": "decolteu",
    "decolteele": "decolteu",
    "decolteelor": "decolteu",
    "decolteul": "decolteu",
    "decolteule": "decolteu",
    "decolteului": "decolteu",
    "decomand": "decomanda",
    "decomandă": "decomanda",
    "decomandai": "decomanda",
    "decomandam": "decomanda",
    "decomandăm": "decomanda",
    "decomandând": "decomanda",
    "decomandându": "decomanda",
    "decomandară": "decomanda",
    "decomandarăm": "decomanda",
    "decomandarăți": "decomanda",
    "decomandase": "decomanda",
    "decomandasem": "decomanda",
    "decomandaseră": "decomanda",
    "decomandaserăm": "decomanda",
    "decomandaserăți": "decomanda",
    "decomandaseși": "decomanda",
    "decomandași": "decomanda",
    "decomandat": "decomanda",
    "decomandați": "decomanda",
    "decomandatu": "decomanda",
    "decomandau": "decomanda",
    "decomande": "decomanda",
    "decomanzi": "decomanda",
    "nedecomandând": "decomanda",
    "nedecomandându": "decomanda",
    "nemaidecomandând": "decomanda",
    "nemaidecomandându": "decomanda",
    "decomandată": "decomandat",
    "decomandate": "decomandat",
    "decomandați": "decomandat",
    "deconcertă": "deconcerta",
    "deconcertai": "deconcerta",
    "deconcertam": "deconcerta",
    "deconcertăm": "deconcerta",
    "deconcertând": "deconcerta",
    "deconcertându": "deconcerta",
    "deconcertară": "deconcerta",
    "deconcertarăm": "deconcerta",
    "deconcertarăți": "deconcerta",
    "deconcertase": "deconcerta",
    "deconcertasem": "deconcerta",
    "deconcertaseră": "deconcerta",
    "deconcertaserăm": "deconcerta",
    "deconcertaserăți": "deconcerta",
    "deconcertaseși": "deconcerta",
    "deconcertași": "deconcerta",
    "deconcertat": "deconcerta",
    "deconcertați": "deconcerta",
    "deconcertatu": "deconcerta",
    "deconcertau": "deconcerta",
    "deconcertează": "deconcerta",
    "deconcertez": "deconcerta",
    "deconcerteze": "deconcerta",
    "deconcertezi": "deconcerta",
    "nedeconcertând": "deconcerta",
    "nedeconcertându": "deconcerta",
    "nemaideconcertând": "deconcerta",
    "nemaideconcertându": "deconcerta",
    "deconcertanta": "deconcertant",
    "deconcertantă": "deconcertant",
    "deconcertante": "deconcertant",
    "deconcertantei": "deconcertant",
    "deconcertantele": "deconcertant",
    "deconcertantelor": "deconcertant",
    "deconcertanți": "deconcertant",
    "deconcertanții": "deconcertant",
    "deconcertanților": "deconcertant",
    "deconcertanto": "deconcertant",
    "deconcertantul": "deconcertant",
    "deconcertantule": "deconcertant",
    "deconcertantului": "deconcertant",
    "deconcertată": "deconcertat",
    "deconcertate": "deconcertat",
    "deconcertați": "deconcertat",
    "deconectă": "deconecta",
    "deconectai": "deconecta",
    "deconectam": "deconecta",
    "deconectăm": "deconecta",
    "deconectând": "deconecta",
    "deconectându": "deconecta",
    "deconectară": "deconecta",
    "deconectarăm": "deconecta",
    "deconectarăți": "deconecta",
    "deconectase": "deconecta",
    "deconectasem": "deconecta",
    "deconectaseră": "deconecta",
    "deconectaserăm": "deconecta",
    "deconectaserăți": "deconecta",
    "deconectaseși": "deconecta",
    "deconectași": "deconecta",
    "deconectat": "deconecta",
    "deconectați": "deconecta",
    "deconectatu": "deconecta",
    "deconectau": "deconecta",
    "deconectează": "deconecta",
    "deconectez": "deconecta",
    "deconecteze": "deconecta",
    "deconectezi": "deconecta",
    "nedeconectând": "deconecta",
    "nedeconectându": "deconecta",
    "nemaideconectând": "deconecta",
    "nemaideconectându": "deconecta",
    "deconectarea": "deconectare",
    "deconectareo": "deconectare",
    "deconectări": "deconectare",
    "deconectării": "deconectare",
    "deconectările": "deconectare",
    "deconectărilor": "deconectare",
    "deconectată": "deconectat",
    "deconectate": "deconectat",
    "deconectați": "deconectat",
    "deconspir": "deconspira",
    "deconspiră": "deconspira",
    "deconspirai": "deconspira",
    "deconspiram": "deconspira",
    "deconspirăm": "deconspira",
    "deconspirând": "deconspira",
    "deconspirându": "deconspira",
    "deconspirară": "deconspira",
    "deconspirarăm": "deconspira",
    "deconspirarăți": "deconspira",
    "deconspirase": "deconspira",
    "deconspirasem": "deconspira",
    "deconspiraseră": "deconspira",
    "deconspiraserăm": "deconspira",
    "deconspiraserăți": "deconspira",
    "deconspiraseși": "deconspira",
    "deconspirași": "deconspira",
    "deconspirat": "deconspira",
    "deconspirați": "deconspira",
    "deconspiratu": "deconspira",
    "deconspirau": "deconspira",
    "deconspire": "deconspira",
    "deconspiri": "deconspira",
    "nedeconspirând": "deconspira",
    "nedeconspirându": "deconspira",
    "nemaideconspirând": "deconspira",
    "nemaideconspirându": "deconspira",
    "deconspirarea": "deconspirare",
    "deconspirări": "deconspirare",
    "deconspirării": "deconspirare",
    "deconspirările": "deconspirare",
    "deconspirărilor": "deconspirare",
    "deconspirată": "deconspirat",
    "deconspirate": "deconspirat",
    "deconspirați": "deconspirat",
    "decontul": "decont",
    "decontule": "decont",
    "decontului": "decont",
    "deconturi": "decont",
    "deconturile": "decont",
    "deconturilor": "decont",
    "decontă": "deconta",
    "decontai": "deconta",
    "decontam": "deconta",
    "decontăm": "deconta",
    "decontând": "deconta",
    "decontându": "deconta",
    "decontară": "deconta",
    "decontarăm": "deconta",
    "decontarăți": "deconta",
    "decontase": "deconta",
    "decontasem": "deconta",
    "decontaseră": "deconta",
    "decontaserăm": "deconta",
    "decontaserăți": "deconta",
    "decontaseși": "deconta",
    "decontași": "deconta",
    "decontat": "deconta",
    "decontați": "deconta",
    "decontatu": "deconta",
    "decontau": "deconta",
    "decontează": "deconta",
    "decontez": "deconta",
    "deconteze": "deconta",
    "decontezi": "deconta",
    "nedecontând": "deconta",
    "nedecontându": "deconta",
    "nemaidecontând": "deconta",
    "nemaidecontându": "deconta",
    "decontabilă": "decontabil",
    "decontabile": "decontabil",
    "decontabili": "decontabil",
    "decontarea": "decontare",
    "decontări": "decontare",
    "decontării": "decontare",
    "decontările": "decontare",
    "decontărilor": "decontare",
    "decontată": "decontat",
    "decontate": "decontat",
    "decontați": "decontat",
    "decorul": "decor",
    "decorule": "decor",
    "decorului": "decor",
    "decoruri": "decor",
    "decorurile": "decor",
    "decorurilor": "decor",
    "decoră": "decora",
    "decorai": "decora",
    "decoram": "decora",
    "decorăm": "decora",
    "decorând": "decora",
    "decorându": "decora",
    "decorară": "decora",
    "decorarăm": "decora",
    "decorarăți": "decora",
    "decorase": "decora",
    "decorasem": "decora",
    "decoraseră": "decora",
    "decoraserăm": "decora",
    "decoraserăți": "decora",
    "decoraseși": "decora",
    "decorași": "decora",
    "decorat": "decora",
    "decorați": "decora",
    "decoratu": "decora",
    "decorau": "decora",
    "decorează": "decora",
    "decorez": "decora",
    "decoreze": "decora",
    "decorezi": "decora",
    "nedecorând": "decora",
    "nedecorându": "decora",
    "nemaidecorând": "decora",
    "nemaidecorându": "decora",
    "decorarea": "decorare",
    "decorareo": "decorare",
    "decorări": "decorare",
    "decorării": "decorare",
    "decorările": "decorare",
    "decorărilor": "decorare",
    "decorata": "decorat",
    "decorată": "decorat",
    "decorate": "decorat",
    "decoratei": "decorat",
    "decoratele": "decorat",
    "decoratelor": "decorat",
    "decorați": "decorat",
    "decorații": "decorat",
    "decoraților": "decorat",
    "decorato": "decorat",
    "decoratul": "decorat",
    "decoratule": "decorat",
    "decoratului": "decorat",
    "decorația": "decorație",
    "decorației": "decorație",
    "decorații": "decorație",
    "decorațiile": "decorație",
    "decorațiilor": "decorație",
    "decorațio": "decorație",
    "decorativa": "decorativ",
    "decorativă": "decorativ",
    "decorative": "decorativ",
    "decorativei": "decorativ",
    "decorativele": "decorativ",
    "decorativelor": "decorativ",
    "decorativi": "decorativ",
    "decorativii": "decorativ",
    "decorativilor": "decorativ",
    "decorativo": "decorativ",
    "decorativul": "decorativ",
    "decorativule": "decorativ",
    "decorativului": "decorativ",
    "decoratoarea": "decoratoare",
    "decoratoarei": "decoratoare",
    "decoratoarele": "decoratoare",
    "decoratoarelor": "decoratoare",
    "decoratoareo": "decoratoare",
    "decoratori": "decorator",
    "decoratorii": "decorator",
    "decoratorilor": "decorator",
    "decoratorul": "decorator",
    "decoratorule": "decorator",
    "decoratorului": "decorator",
    "decortică": "decortica",
    "decorticai": "decortica",
    "decorticam": "decortica",
    "decorticăm": "decortica",
    "decorticând": "decortica",
    "decorticându": "decortica",
    "decorticară": "decortica",
    "decorticarăm": "decortica",
    "decorticarăți": "decortica",
    "decorticase": "decortica",
    "decorticasem": "decortica",
    "decorticaseră": "decortica",
    "decorticaserăm": "decortica",
    "decorticaserăți": "decortica",
    "decorticaseși": "decortica",
    "decorticași": "decortica",
    "decorticat": "decortica",
    "decorticați": "decortica",
    "decorticatu": "decortica",
    "decorticau": "decortica",
    "decortichează": "decortica",
    "decortichez": "decortica",
    "decorticheze": "decortica",
    "decortichezi": "decortica",
    "nedecorticând": "decortica",
    "nedecorticându": "decortica",
    "nemaidecorticând": "decortica",
    "nemaidecorticându": "decortica",
    "decorticarea": "decorticare",
    "decorticareo": "decorticare",
    "decorticări": "decorticare",
    "decorticării": "decorticare",
    "decorticările": "decorticare",
    "decorticărilor": "decorticare",
    "decorticata": "decorticat",
    "decorticată": "decorticat",
    "decorticate": "decorticat",
    "decorticatei": "decorticat",
    "decorticatele": "decorticat",
    "decorticatelor": "decorticat",
    "decorticați": "decorticat",
    "decorticații": "decorticat",
    "decorticaților": "decorticat",
    "decorticato": "decorticat",
    "decorticatul": "decorticat",
    "decorticatule": "decorticat",
    "decorticatului": "decorticat",
    "decovile": "decovil",
    "decovilele": "decovil",
    "decovilelor": "decovil",
    "decovilul": "decovil",
    "decovilule": "decovil",
    "decovilului": "decovil",
    "decrepita": "decrepit",
    "decrepită": "decrepit",
    "decrepite": "decrepit",
    "decrepitei": "decrepit",
    "decrepitele": "decrepit",
    "decrepitelor": "decrepit",
    "decrepiți": "decrepit",
    "decrepiții": "decrepit",
    "decrepiților": "decrepit",
    "decrepito": "decrepit",
    "decrepitul": "decrepit",
    "decrepitule": "decrepit",
    "decrepitului": "decrepit",
    "decrepitudinea": "decrepitudine",
    "decrepitudineo": "decrepitudine",
    "decrepitudini": "decrepitudine",
    "decrepitudinii": "decrepitudine",
    "decrepitudinile": "decrepitudine",
    "decrepitudinilor": "decrepitudine",
    "decrete": "decret",
    "decretele": "decret",
    "decretelor": "decret",
    "decretul": "decret",
    "decretule": "decret",
    "decretului": "decret",
    "decretă": "decreta",
    "decretai": "decreta",
    "decretam": "decreta",
    "decretăm": "decreta",
    "decretând": "decreta",
    "decretându": "decreta",
    "decretară": "decreta",
    "decretarăm": "decreta",
    "decretarăți": "decreta",
    "decretase": "decreta",
    "decretasem": "decreta",
    "decretaseră": "decreta",
    "decretaserăm": "decreta",
    "decretaserăți": "decreta",
    "decretaseși": "decreta",
    "decretași": "decreta",
    "decretat": "decreta",
    "decretați": "decreta",
    "decretatu": "decreta",
    "decretau": "decreta",
    "decretează": "decreta",
    "decretez": "decreta",
    "decreteze": "decreta",
    "decretezi": "decreta",
    "nedecretând": "decreta",
    "nedecretându": "decreta",
    "nemaidecretând": "decreta",
    "nemaidecretându": "decreta",
    "decretarea": "decretare",
    "decretareo": "decretare",
    "decretări": "decretare",
    "decretării": "decretare",
    "decretările": "decretare",
    "decretărilor": "decretare",
    "decretată": "decretat",
    "decretate": "decretat",
    "decretați": "decretat",
    "D.L.": "Decret-Lege",
    "decrete-lege": "decret-lege",
    "decretele-lege": "decret-lege",
    "decretelor-lege": "decret-lege",
    "decretul-lege": "decret-lege",
    "decretului-lege": "decret-lege",
    "decriptata": "decriptat",
    "decriptată": "decriptat",
    "decriptate": "decriptat",
    "decriptatei": "decriptat",
    "decriptatele": "decriptat",
    "decriptatelor": "decriptat",
    "decriptați": "decriptat",
    "decriptații": "decriptat",
    "decriptaților": "decriptat",
    "decriptato": "decriptat",
    "decriptatul": "decriptat",
    "decriptatule": "decriptat",
    "decriptatului": "decriptat",
    "decroșă": "decroșa",
    "decroșai": "decroșa",
    "decroșam": "decroșa",
    "decroșăm": "decroșa",
    "decroșând": "decroșa",
    "decroșându": "decroșa",
    "decroșară": "decroșa",
    "decroșarăm": "decroșa",
    "decroșarăți": "decroșa",
    "decroșase": "decroșa",
    "decroșasem": "decroșa",
    "decroșaseră": "decroșa",
    "decroșaserăm": "decroșa",
    "decroșaserăți": "decroșa",
    "decroșaseși": "decroșa",
    "decroșași": "decroșa",
    "decroșat": "decroșa",
    "decroșați": "decroșa",
    "decroșatu": "decroșa",
    "decroșau": "decroșa",
    "decroșează": "decroșa",
    "decroșez": "decroșa",
    "decroșeze": "decroșa",
    "decroșezi": "decroșa",
    "nedecroșând": "decroșa",
    "nedecroșându": "decroșa",
    "nemaidecroșând": "decroșa",
    "nemaidecroșându": "decroșa",
    "decroșarea": "decroșare",
    "decroșareo": "decroșare",
    "decroșări": "decroșare",
    "decroșării": "decroșare",
    "decroșările": "decroșare",
    "decroșărilor": "decroșare",
    "decroșată": "decroșat",
    "decroșate": "decroșat",
    "decroșați": "decroșat",
    "deculturalizarea": "deculturalizare",
    "deculturalizareo": "deculturalizare",
    "deculturalizări": "deculturalizare",
    "deculturalizării": "deculturalizare",
    "deculturalizările": "deculturalizare",
    "deculturalizărilor": "deculturalizare",
    "decupă": "decupa",
    "decupai": "decupa",
    "decupam": "decupa",
    "decupăm": "decupa",
    "decupând": "decupa",
    "decupându": "decupa",
    "decupară": "decupa",
    "decuparăm": "decupa",
    "decuparăți": "decupa",
    "decupase": "decupa",
    "decupasem": "decupa",
    "decupaseră": "decupa",
    "decupaserăm": "decupa",
    "decupaserăți": "decupa",
    "decupaseși": "decupa",
    "decupași": "decupa",
    "decupat": "decupa",
    "decupați": "decupa",
    "decupatu": "decupa",
    "decupau": "decupa",
    "decupează": "decupa",
    "decupez": "decupa",
    "decupeze": "decupa",
    "decupezi": "decupa",
    "nedecupând": "decupa",
    "nedecupându": "decupa",
    "nemaidecupând": "decupa",
    "nemaidecupându": "decupa",
    "decupaje": "decupaj",
    "decupajele": "decupaj",
    "decupajelor": "decupaj",
    "decupajul": "decupaj",
    "decupajule": "decupaj",
    "decupajului": "decupaj",
    "decuparea": "decupare",
    "decupareo": "decupare",
    "decupări": "decupare",
    "decupării": "decupare",
    "decupările": "decupare",
    "decupărilor": "decupare",
    "decupata": "decupat",
    "decupată": "decupat",
    "decupate": "decupat",
    "decupatei": "decupat",
    "decupatele": "decupat",
    "decupatelor": "decupat",
    "decupați": "decupat",
    "decupații": "decupat",
    "decupaților": "decupat",
    "decupato": "decupat",
    "decupatul": "decupat",
    "decupatule": "decupat",
    "decupatului": "decupat",
    "decuplă": "decupla",
    "decuplai": "decupla",
    "decuplam": "decupla",
    "decuplăm": "decupla",
    "decuplând": "decupla",
    "decuplându": "decupla",
    "decuplară": "decupla",
    "decuplarăm": "decupla",
    "decuplarăți": "decupla",
    "decuplase": "decupla",
    "decuplasem": "decupla",
    "decuplaseră": "decupla",
    "decuplaserăm": "decupla",
    "decuplaserăți": "decupla",
    "decuplaseși": "decupla",
    "decuplași": "decupla",
    "decuplat": "decupla",
    "decuplați": "decupla",
    "decuplatu": "decupla",
    "decuplau": "decupla",
    "decuplează": "decupla",
    "decuplez": "decupla",
    "decupleze": "decupla",
    "decuplezi": "decupla",
    "nedecuplând": "decupla",
    "nedecuplându": "decupla",
    "nemaidecuplând": "decupla",
    "nemaidecuplându": "decupla",
    "decuplarea": "decuplare",
    "decuplareo": "decuplare",
    "decuplări": "decuplare",
    "decuplării": "decuplare",
    "decuplările": "decuplare",
    "decuplărilor": "decuplare",
    "decuplată": "decuplat",
    "decuplate": "decuplat",
    "decuplați": "decuplat",
    "decurg": "decurge",
    "decurgă": "decurge",
    "decurgând": "decurge",
    "decurgându": "decurge",
    "decurgea": "decurge",
    "decurgeai": "decurge",
    "decurgeam": "decurge",
    "decurgeați": "decurge",
    "decurgeau": "decurge",
    "decurgem": "decurge",
    "decurgeți": "decurge",
    "decurgi": "decurge",
    "decurs": "decurge",
    "decurse": "decurge",
    "decursei": "decurge",
    "decurseră": "decurge",
    "decurserăm": "decurge",
    "decurserăți": "decurge",
    "decursese": "decurge",
    "decursesem": "decurge",
    "decurseseră": "decurge",
    "decurseserăm": "decurge",
    "decurseserăți": "decurge",
    "decurseseși": "decurge",
    "decurseși": "decurge",
    "decursu": "decurge",
    "decursă": "decurs",
    "decurse": "decurs",
    "decurși": "decurs",
    "decursul": "decurs",
    "decursule": "decurs",
    "decursului": "decurs",
    "decuvaje": "decuvaj",
    "decuvajele": "decuvaj",
    "decuvajelor": "decuvaj",
    "decuvajul": "decuvaj",
    "decuvajule": "decuvaj",
    "decuvajului": "decuvaj",
    "dedă": "deda",
    "dedai": "deda",
    "dedăm": "deda",
    "dedând": "deda",
    "dedându": "deda",
    "dedat": "deda",
    "dedați": "deda",
    "dedatu": "deda",
    "dedau": "deda",
    "dedesubtul": "dedesubt",
    "dedesubtule": "dedesubt",
    "dedesubtului": "dedesubt",
    "dedesubturi": "dedesubt",
    "dedesubturile": "dedesubt",
    "dedesubturilor": "dedesubt",
    "dedic": "dedica",
    "dedică": "dedica",
    "dedicai": "dedica",
    "dedicam": "dedica",
    "dedicăm": "dedica",
    "dedicând": "dedica",
    "dedicându": "dedica",
    "dedicară": "dedica",
    "dedicarăm": "dedica",
    "dedicarăți": "dedica",
    "dedicase": "dedica",
    "dedicasem": "dedica",
    "dedicaseră": "dedica",
    "dedicaserăm": "dedica",
    "dedicaserăți": "dedica",
    "dedicaseși": "dedica",
    "dedicași": "dedica",
    "dedicat": "dedica",
    "dedicați": "dedica",
    "dedicatu": "dedica",
    "dedicau": "dedica",
    "dedice": "dedica",
    "dedici": "dedica",
    "nededicând": "dedica",
    "nededicându": "dedica",
    "nemaidedicând": "dedica",
    "nemaidedicându": "dedica",
    "dedicarea": "dedicare",
    "dedicareo": "dedicare",
    "dedicări": "dedicare",
    "dedicării": "dedicare",
    "dedicările": "dedicare",
    "dedicărilor": "dedicare",
    "dedicată": "dedicat",
    "dedicate": "dedicat",
    "dedicați": "dedicat",
    "dedicația": "dedicație",
    "dedicației": "dedicație",
    "dedicații": "dedicație",
    "dedicațiile": "dedicație",
    "dedicațiilor": "dedicație",
    "dedicațio": "dedicație",
    "dediței": "dedițel",
    "dedițeii": "dedițel",
    "dedițeilor": "dedițel",
    "dedițelul": "dedițel",
    "dedițelule": "dedițel",
    "dedițelului": "dedițel",
    "dediței-de-mare": "dedițel-de-mare",
    "dedublă": "dedubla",
    "dedublai": "dedubla",
    "dedublam": "dedubla",
    "dedublăm": "dedubla",
    "dedublând": "dedubla",
    "dedublându": "dedubla",
    "dedublară": "dedubla",
    "dedublarăm": "dedubla",
    "dedublarăți": "dedubla",
    "dedublase": "dedubla",
    "dedublasem": "dedubla",
    "dedublaseră": "dedubla",
    "dedublaserăm": "dedubla",
    "dedublaserăți": "dedubla",
    "dedublaseși": "dedubla",
    "dedublași": "dedubla",
    "dedublat": "dedubla",
    "dedublați": "dedubla",
    "dedublatu": "dedubla",
    "dedublau": "dedubla",
    "dedublează": "dedubla",
    "dedublez": "dedubla",
    "dedubleze": "dedubla",
    "dedublezi": "dedubla",
    "nededublând": "dedubla",
    "nededublându": "dedubla",
    "nemaidedublând": "dedubla",
    "nemaidedublându": "dedubla",
    "dedublarea": "dedublare",
    "dedublareo": "dedublare",
    "dedublări": "dedublare",
    "dedublării": "dedublare",
    "dedublările": "dedublare",
    "dedublărilor": "dedublare",
    "dedublata": "dedublat",
    "dedublată": "dedublat",
    "dedublate": "dedublat",
    "dedublatei": "dedublat",
    "dedublatele": "dedublat",
    "dedublatelor": "dedublat",
    "dedublați": "dedublat",
    "dedublații": "dedublat",
    "dedublaților": "dedublat",
    "dedublato": "dedublat",
    "dedublatul": "dedublat",
    "dedublatule": "dedublat",
    "dedublatului": "dedublat",
    "dedu": "deduce",
    "deduc": "deduce",
    "deducă": "deduce",
    "deducând": "deduce",
    "deducându": "deduce",
    "deducea": "deduce",
    "deduceai": "deduce",
    "deduceam": "deduce",
    "deduceați": "deduce",
    "deduceau": "deduce",
    "deducem": "deduce",
    "deduceți": "deduce",
    "deduci": "deduce",
    "dedus": "deduce",
    "deduse": "deduce",
    "dedusei": "deduce",
    "deduseră": "deduce",
    "deduserăm": "deduce",
    "deduserăți": "deduce",
    "dedusese": "deduce",
    "dedusesem": "deduce",
    "deduseseră": "deduce",
    "deduseserăm": "deduce",
    "deduseserăți": "deduce",
    "deduseseși": "deduce",
    "deduseși": "deduce",
    "dedusu": "deduce",
    "nededucând": "deduce",
    "nededucându": "deduce",
    "nemaideducând": "deduce",
    "nemaideducându": "deduce",
    "deducerea": "deducere",
    "deducereo": "deducere",
    "deduceri": "deducere",
    "deducerii": "deducere",
    "deducerile": "deducere",
    "deducerilor": "deducere",
    "deductibila": "deductibil",
    "deductibilă": "deductibil",
    "deductibile": "deductibil",
    "deductibilei": "deductibil",
    "deductibilele": "deductibil",
    "deductibilelor": "deductibil",
    "deductibili": "deductibil",
    "deductibilii": "deductibil",
    "deductibililor": "deductibil",
    "deductibilo": "deductibil",
    "deductibilul": "deductibil",
    "deductibilule": "deductibil",
    "deductibilului": "deductibil",
    "deducția": "deducție",
    "deducției": "deducție",
    "deducții": "deducție",
    "deducțiile": "deducție",
    "deducțiilor": "deducție",
    "deducțio": "deducție",
    "dedulcea": "dedulci",
    "dedulceai": "dedulci",
    "dedulceam": "dedulci",
    "dedulcească": "dedulci",
    "dedulceați": "dedulci",
    "dedulceau": "dedulci",
    "dedulcesc": "dedulci",
    "dedulcește": "dedulci",
    "dedulcești": "dedulci",
    "dedulcii": "dedulci",
    "dedulcim": "dedulci",
    "dedulcind": "dedulci",
    "dedulcindu": "dedulci",
    "dedulciră": "dedulci",
    "dedulcirăm": "dedulci",
    "dedulcirăți": "dedulci",
    "dedulcise": "dedulci",
    "dedulcisem": "dedulci",
    "dedulciseră": "dedulci",
    "dedulciserăm": "dedulci",
    "dedulciserăți": "dedulci",
    "dedulciseși": "dedulci",
    "dedulciși": "dedulci",
    "dedulcit": "dedulci",
    "dedulciți": "dedulci",
    "dedulcitu": "dedulci",
    "nededulcind": "dedulci",
    "nededulcindu": "dedulci",
    "nemaidedulcind": "dedulci",
    "nemaidedulcindu": "dedulci",
    "dedulcită": "dedulcit",
    "dedulcite": "dedulcit",
    "dedulciți": "dedulcit",
    "dedusa": "dedus",
    "dedusă": "dedus",
    "deduse": "dedus",
    "dedusei": "dedus",
    "dedusele": "dedus",
    "deduselor": "dedus",
    "deduși": "dedus",
    "dedușii": "dedus",
    "dedușilor": "dedus",
    "deduso": "dedus",
    "dedusul": "dedus",
    "dedusule": "dedus",
    "dedusului": "dedus",
    "defăimă": "defăima",
    "defăimai": "defăima",
    "defăimam": "defăima",
    "defăimăm": "defăima",
    "defăimând": "defăima",
    "defăimându": "defăima",
    "defăimară": "defăima",
    "defăimarăm": "defăima",
    "defăimarăți": "defăima",
    "defăimase": "defăima",
    "defăimasem": "defăima",
    "defăimaseră": "defăima",
    "defăimaserăm": "defăima",
    "defăimaserăți": "defăima",
    "defăimaseși": "defăima",
    "defăimași": "defăima",
    "defăimat": "defăima",
    "defăimați": "defăima",
    "defăimatu": "defăima",
    "defăimau": "defăima",
    "defăimează": "defăima",
    "defăimez": "defăima",
    "defăimeze": "defăima",
    "defăimezi": "defăima",
    "nedefăimând": "defăima",
    "nedefăimându": "defăima",
    "nemaidefăimând": "defăima",
    "nemaidefăimându": "defăima",
    "defăimarea": "defăimare",
    "defăimareo": "defăimare",
    "defăimări": "defăimare",
    "defăimării": "defăimare",
    "defăimările": "defăimare",
    "defăimărilor": "defăimare",
    "defăimată": "defăimat",
    "defăimate": "defăimat",
    "defăimați": "defăimat",
    "defăimătoarea": "defăimătoare",
    "defăimătoarei": "defăimătoare",
    "defăimătoarele": "defăimătoare",
    "defăimătoarelor": "defăimătoare",
    "defăimătoareo": "defăimătoare",
    "defăimătoare": "defăimător",
    "defăimătoarea": "defăimător",
    "defăimătoarei": "defăimător",
    "defăimătoarele": "defăimător",
    "defăimătoarelor": "defăimător",
    "defăimătoareo": "defăimător",
    "defăimători": "defăimător",
    "defăimătorii": "defăimător",
    "defăimătorilor": "defăimător",
    "defăimătorul": "defăimător",
    "defăimătorule": "defăimător",
    "defăimătorului": "defăimător",
    "defalcă": "defalca",
    "defalcai": "defalca",
    "defalcam": "defalca",
    "defalcăm": "defalca",
    "defalcând": "defalca",
    "defalcându": "defalca",
    "defalcară": "defalca",
    "defalcarăm": "defalca",
    "defalcarăți": "defalca",
    "defalcase": "defalca",
    "defalcasem": "defalca",
    "defalcaseră": "defalca",
    "defalcaserăm": "defalca",
    "defalcaserăți": "defalca",
    "defalcaseși": "defalca",
    "defalcași": "defalca",
    "defalcat": "defalca",
    "defalcați": "defalca",
    "defalcatu": "defalca",
    "defalcau": "defalca",
    "defalchează": "defalca",
    "defalchez": "defalca",
    "defalcheze": "defalca",
    "defalchezi": "defalca",
    "nedefalcând": "defalca",
    "nedefalcându": "defalca",
    "nemaidefalcând": "defalca",
    "nemaidefalcându": "defalca",
    "defalcarea": "defalcare",
    "defalcareo": "defalcare",
    "defalcări": "defalcare",
    "defalcării": "defalcare",
    "defalcările": "defalcare",
    "defalcărilor": "defalcare",
    "defalcată": "defalcat",
    "defalcate": "defalcat",
    "defalcați": "defalcat",
    "defavoarea": "defavoare",
    "defavoareo": "defavoare",
    "defavorabila": "defavorabil",
    "defavorabilă": "defavorabil",
    "defavorabile": "defavorabil",
    "defavorabilei": "defavorabil",
    "defavorabilele": "defavorabil",
    "defavorabilelor": "defavorabil",
    "defavorabili": "defavorabil",
    "defavorabilii": "defavorabil",
    "defavorabililor": "defavorabil",
    "defavorabilo": "defavorabil",
    "defavorabilul": "defavorabil",
    "defavorabilule": "defavorabil",
    "defavorabilului": "defavorabil",
    "defavoriză": "defavoriza",
    "defavorizai": "defavoriza",
    "defavorizam": "defavoriza",
    "defavorizăm": "defavoriza",
    "defavorizând": "defavoriza",
    "defavorizându": "defavoriza",
    "defavorizară": "defavoriza",
    "defavorizarăm": "defavoriza",
    "defavorizarăți": "defavoriza",
    "defavorizase": "defavoriza",
    "defavorizasem": "defavoriza",
    "defavorizaseră": "defavoriza",
    "defavorizaserăm": "defavoriza",
    "defavorizaserăți": "defavoriza",
    "defavorizaseși": "defavoriza",
    "defavorizași": "defavoriza",
    "defavorizat": "defavoriza",
    "defavorizați": "defavoriza",
    "defavorizatu": "defavoriza",
    "defavorizau": "defavoriza",
    "defavorizează": "defavoriza",
    "defavorizez": "defavoriza",
    "defavorizeze": "defavoriza",
    "defavorizezi": "defavoriza",
    "defavorizata": "defavorizat",
    "defavorizată": "defavorizat",
    "defavorizate": "defavorizat",
    "defavorizatei": "defavorizat",
    "defavorizatele": "defavorizat",
    "defavorizatelor": "defavorizat",
    "defavorizați": "defavorizat",
    "defavorizații": "defavorizat",
    "defavorizaților": "defavorizat",
    "defavorizato": "defavorizat",
    "defavorizatul": "defavorizat",
    "defavorizatule": "defavorizat",
    "defavorizatului": "defavorizat",
    "defecă": "defeca",
    "defecai": "defeca",
    "defecam": "defeca",
    "defecăm": "defeca",
    "defecând": "defeca",
    "defecându": "defeca",
    "defecară": "defeca",
    "defecarăm": "defeca",
    "defecarăți": "defeca",
    "defecase": "defeca",
    "defecasem": "defeca",
    "defecaseră": "defeca",
    "defecaserăm": "defeca",
    "defecaserăți": "defeca",
    "defecaseși": "defeca",
    "defecași": "defeca",
    "defecat": "defeca",
    "defecați": "defeca",
    "defecatu": "defeca",
    "defecau": "defeca",
    "defechează": "defeca",
    "defechez": "defeca",
    "defecheze": "defeca",
    "defechezi": "defeca",
    "nedefecând": "defeca",
    "nedefecându": "defeca",
    "nemaidefecând": "defeca",
    "nemaidefecându": "defeca",
    "defecarea": "defecare",
    "defecareo": "defecare",
    "defecări": "defecare",
    "defecării": "defecare",
    "defecările": "defecare",
    "defecărilor": "defecare",
    "defecată": "defecat",
    "defecate": "defecat",
    "defecați": "defecat",
    "defecta": "defect",
    "defectă": "defect",
    "defecte": "defect",
    "defectei": "defect",
    "defectele": "defect",
    "defectelor": "defect",
    "defecți": "defect",
    "defecții": "defect",
    "defecților": "defect",
    "defecto": "defect",
    "defectul": "defect",
    "defectule": "defect",
    "defectului": "defect",
    "defectă": "defecta",
    "defectai": "defecta",
    "defectam": "defecta",
    "defectăm": "defecta",
    "defectând": "defecta",
    "defectându": "defecta",
    "defectară": "defecta",
    "defectarăm": "defecta",
    "defectarăți": "defecta",
    "defectase": "defecta",
    "defectasem": "defecta",
    "defectaseră": "defecta",
    "defectaserăm": "defecta",
    "defectaserăți": "defecta",
    "defectaseși": "defecta",
    "defectași": "defecta",
    "defectat": "defecta",
    "defectați": "defecta",
    "defectatu": "defecta",
    "defectau": "defecta",
    "defectează": "defecta",
    "defectez": "defecta",
    "defecteze": "defecta",
    "defectezi": "defecta",
    "nedefectând": "defecta",
    "nedefectându": "defecta",
    "nemaidefectând": "defecta",
    "nemaidefectându": "defecta",
    "defectarea": "defectare",
    "defectareo": "defectare",
    "defectări": "defectare",
    "defectării": "defectare",
    "defectările": "defectare",
    "defectărilor": "defectare",
    "defectata": "defectat",
    "defectată": "defectat",
    "defectate": "defectat",
    "defectatei": "defectat",
    "defectatele": "defectat",
    "defectatelor": "defectat",
    "defectați": "defectat",
    "defectații": "defectat",
    "defectaților": "defectat",
    "defectato": "defectat",
    "defectatul": "defectat",
    "defectatule": "defectat",
    "defectatului": "defectat",
    "defecțiunea": "defecțiune",
    "defecțiuneo": "defecțiune",
    "defecțiuni": "defecțiune",
    "defecțiunii": "defecțiune",
    "defecțiunile": "defecțiune",
    "defecțiunilor": "defecțiune",
    "defectiva": "defectiv",
    "defectivă": "defectiv",
    "defective": "defectiv",
    "defectivei": "defectiv",
    "defectivele": "defectiv",
    "defectivelor": "defectiv",
    "defectivi": "defectiv",
    "defectivii": "defectiv",
    "defectivilor": "defectiv",
    "defectivo": "defectiv",
    "defectivul": "defectiv",
    "defectivule": "defectiv",
    "defectivului": "defectiv",
    "defectoscoape": "defectoscop",
    "defectoscoapele": "defectoscop",
    "defectoscoapelor": "defectoscop",
    "defectoscopul": "defectoscop",
    "defectoscopule": "defectoscop",
    "defectoscopului": "defectoscop",
    "defectuoasa": "defectuos",
    "defectuoasă": "defectuos",
    "defectuoase": "defectuos",
    "defectuoasei": "defectuos",
    "defectuoasele": "defectuos",
    "defectuoaselor": "defectuos",
    "defectuoaso": "defectuos",
    "defectuoși": "defectuos",
    "defectuoșii": "defectuos",
    "defectuoșilor": "defectuos",
    "defectuosul": "defectuos",
    "defectuosule": "defectuos",
    "defectuosului": "defectuos",
    "defensiva": "defensiv",
    "defensivă": "defensiv",
    "defensive": "defensiv",
    "defensivei": "defensiv",
    "defensivele": "defensiv",
    "defensivelor": "defensiv",
    "defensivi": "defensiv",
    "defensivii": "defensiv",
    "defensivilor": "defensiv",
    "defensivo": "defensiv",
    "defensivul": "defensiv",
    "defensivule": "defensiv",
    "defensivului": "defensiv",
    "defensori": "defensor",
    "defensorii": "defensor",
    "defensorilor": "defensor",
    "defensorul": "defensor",
    "defensorule": "defensor",
    "defensorului": "defensor",
    "deferenta": "deferent",
    "deferentă": "deferent",
    "deferente": "deferent",
    "deferentei": "deferent",
    "deferentele": "deferent",
    "deferentelor": "deferent",
    "deferenți": "deferent",
    "deferenții": "deferent",
    "deferenților": "deferent",
    "deferento": "deferent",
    "deferentul": "deferent",
    "deferentule": "deferent",
    "deferentului": "deferent",
    "deferența": "deferență",
    "deferențe": "deferență",
    "deferenței": "deferență",
    "deferențele": "deferență",
    "deferențelor": "deferență",
    "deferențo": "deferență",
    "defer": "deferi",
    "deferă": "deferi",
    "defere": "deferi",
    "deferea": "deferi",
    "defereai": "deferi",
    "defeream": "deferi",
    "defereați": "deferi",
    "defereau": "deferi",
    "deferii": "deferi",
    "deferim": "deferi",
    "deferind": "deferi",
    "deferindu": "deferi",
    "deferiră": "deferi",
    "deferirăm": "deferi",
    "deferirăți": "deferi",
    "deferise": "deferi",
    "deferisem": "deferi",
    "deferiseră": "deferi",
    "deferiserăm": "deferi",
    "deferiserăți": "deferi",
    "deferiseși": "deferi",
    "deferiși": "deferi",
    "deferit": "deferi",
    "deferiți": "deferi",
    "deferitu": "deferi",
    "nedeferind": "deferi",
    "nedeferindu": "deferi",
    "nemaideferind": "deferi",
    "nemaideferindu": "deferi",
    "deferită": "deferit",
    "deferite": "deferit",
    "deferiți": "deferit",
    "deferiză": "deferiza",
    "deferizai": "deferiza",
    "deferizam": "deferiza",
    "deferizăm": "deferiza",
    "deferizând": "deferiza",
    "deferizându": "deferiza",
    "deferizară": "deferiza",
    "deferizarăm": "deferiza",
    "deferizarăți": "deferiza",
    "deferizase": "deferiza",
    "deferizasem": "deferiza",
    "deferizaseră": "deferiza",
    "deferizaserăm": "deferiza",
    "deferizaserăți": "deferiza",
    "deferizaseși": "deferiza",
    "deferizași": "deferiza",
    "deferizat": "deferiza",
    "deferizați": "deferiza",
    "deferizatu": "deferiza",
    "deferizau": "deferiza",
    "deferizează": "deferiza",
    "deferizez": "deferiza",
    "deferizeze": "deferiza",
    "deferizezi": "deferiza",
    "nedeferizând": "deferiza",
    "nedeferizându": "deferiza",
    "nemaideferizând": "deferiza",
    "nemaideferizându": "deferiza",
    "deferizată": "deferizat",
    "deferizate": "deferizat",
    "deferizați": "deferizat",
    "defertiliză": "defertiliza",
    "defertilizai": "defertiliza",
    "defertilizam": "defertiliza",
    "defertilizăm": "defertiliza",
    "defertilizând": "defertiliza",
    "defertilizându": "defertiliza",
    "defertilizară": "defertiliza",
    "defertilizarăm": "defertiliza",
    "defertilizarăți": "defertiliza",
    "defertilizase": "defertiliza",
    "defertilizasem": "defertiliza",
    "defertilizaseră": "defertiliza",
    "defertilizaserăm": "defertiliza",
    "defertilizaserăți": "defertiliza",
    "defertilizaseși": "defertiliza",
    "defertilizași": "defertiliza",
    "defertilizat": "defertiliza",
    "defertilizați": "defertiliza",
    "defertilizatu": "defertiliza",
    "defertilizau": "defertiliza",
    "defertilizează": "defertiliza",
    "defertilizez": "defertiliza",
    "defertilizeze": "defertiliza",
    "defertilizezi": "defertiliza",
    "nedefertilizând": "defertiliza",
    "nedefertilizându": "defertiliza",
    "nemaidefertilizând": "defertiliza",
    "nemaidefertilizându": "defertiliza",
    "defertilizarea": "defertilizare",
    "defertilizareo": "defertilizare",
    "defertilizări": "defertilizare",
    "defertilizării": "defertilizare",
    "defertilizările": "defertilizare",
    "defertilizărilor": "defertilizare",
    "defertilizată": "defertilizat",
    "defertilizate": "defertilizat",
    "defertilizați": "defertilizat",
    "defetismul": "defetism",
    "defetismule": "defetism",
    "defetismului": "defetism",
    "defetista": "defetist",
    "defetistă": "defetist",
    "defetiste": "defetist",
    "defetistei": "defetist",
    "defetistele": "defetist",
    "defetistelor": "defetist",
    "defetiști": "defetist",
    "defetiștii": "defetist",
    "defetiștilor": "defetist",
    "defetisto": "defetist",
    "defetistul": "defetist",
    "defetistule": "defetist",
    "defetistului": "defetist",
    "defetista": "defetistă",
    "defetiste": "defetistă",
    "defetistei": "defetistă",
    "defetistele": "defetistă",
    "defetistelor": "defetistă",
    "defetisto": "defetistă",
    "defibră": "defibra",
    "defibrai": "defibra",
    "defibram": "defibra",
    "defibrăm": "defibra",
    "defibrând": "defibra",
    "defibrându": "defibra",
    "defibrară": "defibra",
    "defibrarăm": "defibra",
    "defibrarăți": "defibra",
    "defibrase": "defibra",
    "defibrasem": "defibra",
    "defibraseră": "defibra",
    "defibraserăm": "defibra",
    "defibraserăți": "defibra",
    "defibraseși": "defibra",
    "defibrași": "defibra",
    "defibrat": "defibra",
    "defibrați": "defibra",
    "defibratu": "defibra",
    "defibrau": "defibra",
    "defibrează": "defibra",
    "defibrez": "defibra",
    "defibreze": "defibra",
    "defibrezi": "defibra",
    "nedefibrând": "defibra",
    "nedefibrându": "defibra",
    "nemaidefibrând": "defibra",
    "nemaidefibrându": "defibra",
    "defibrarea": "defibrare",
    "defibrareo": "defibrare",
    "defibrări": "defibrare",
    "defibrării": "defibrare",
    "defibrările": "defibrare",
    "defibrărilor": "defibrare",
    "defibrată": "defibrat",
    "defibrate": "defibrat",
    "defibrați": "defibrat",
    "defibratoare": "defibrator",
    "defibratoarele": "defibrator",
    "defibratoarelor": "defibrator",
    "defibratorul": "defibrator",
    "defibratorule": "defibrator",
    "defibratorului": "defibrator",
    "deficienta": "deficient",
    "deficientă": "deficient",
    "deficiente": "deficient",
    "deficientei": "deficient",
    "deficientele": "deficient",
    "deficientelor": "deficient",
    "deficienți": "deficient",
    "deficienții": "deficient",
    "deficienților": "deficient",
    "deficiento": "deficient",
    "deficientul": "deficient",
    "deficientule": "deficient",
    "deficientului": "deficient",
    "deficiența": "deficiență",
    "deficiențe": "deficiență",
    "deficienței": "deficiență",
    "deficiențele": "deficiență",
    "deficiențelor": "deficiență",
    "deficiențo": "deficiență",
    "deficite": "deficit",
    "deficitele": "deficit",
    "deficitelor": "deficit",
    "deficitul": "deficit",
    "deficitule": "deficit",
    "deficitului": "deficit",
    "deficitara": "deficitar",
    "deficitară": "deficitar",
    "deficitare": "deficitar",
    "deficitarei": "deficitar",
    "deficitarele": "deficitar",
    "deficitarelor": "deficitar",
    "deficitari": "deficitar",
    "deficitarii": "deficitar",
    "deficitarilor": "deficitar",
    "deficitaro": "deficitar",
    "deficitarul": "deficitar",
    "deficitarule": "deficitar",
    "deficitarului": "deficitar",
    "defilă": "defila",
    "defilai": "defila",
    "defilam": "defila",
    "defilăm": "defila",
    "defilând": "defila",
    "defilându": "defila",
    "defilară": "defila",
    "defilarăm": "defila",
    "defilarăți": "defila",
    "defilase": "defila",
    "defilasem": "defila",
    "defilaseră": "defila",
    "defilaserăm": "defila",
    "defilaserăți": "defila",
    "defilaseși": "defila",
    "defilași": "defila",
    "defilat": "defila",
    "defilați": "defila",
    "defilatu": "defila",
    "defilau": "defila",
    "defilează": "defila",
    "defilez": "defila",
    "defileze": "defila",
    "defilezi": "defila",
    "nedefilând": "defila",
    "nedefilându": "defila",
    "nemaidefilând": "defila",
    "nemaidefilându": "defila",
    "defilarea": "defilare",
    "defilareo": "defilare",
    "defilări": "defilare",
    "defilării": "defilare",
    "defilările": "defilare",
    "defilărilor": "defilare",
    "defilată": "defilat",
    "defilate": "defilat",
    "defilați": "defilat",
    "defilee": "defileu",
    "defileele": "defileu",
    "defileelor": "defileu",
    "defileul": "defileu",
    "defileule": "defileu",
    "defileului": "defileu",
    "definea": "defini",
    "defineai": "defini",
    "defineam": "defini",
    "definească": "defini",
    "defineați": "defini",
    "defineau": "defini",
    "definesc": "defini",
    "definește": "defini",
    "definești": "defini",
    "definii": "defini",
    "definim": "defini",
    "definind": "defini",
    "definindu": "defini",
    "definiră": "defini",
    "definirăm": "defini",
    "definirăți": "defini",
    "definise": "defini",
    "definisem": "defini",
    "definiseră": "defini",
    "definiserăm": "defini",
    "definiserăți": "defini",
    "definiseși": "defini",
    "definiși": "defini",
    "definit": "defini",
    "definiți": "defini",
    "definitu": "defini",
    "nedefinind": "defini",
    "nedefinindu": "defini",
    "nemaidefinind": "defini",
    "nemaidefinindu": "defini",
    "definibila": "definibil",
    "definibilă": "definibil",
    "definibile": "definibil",
    "definibilei": "definibil",
    "definibilele": "definibil",
    "definibilelor": "definibil",
    "definibili": "definibil",
    "definibilii": "definibil",
    "definibililor": "definibil",
    "definibilo": "definibil",
    "definibilul": "definibil",
    "definibilule": "definibil",
    "definibilului": "definibil",
    "definirea": "definire",
    "definireo": "definire",
    "definiri": "definire",
    "definirii": "definire",
    "definirile": "definire",
    "definirilor": "definire",
    "definita": "definit",
    "definită": "definit",
    "definite": "definit",
    "definitei": "definit",
    "definitele": "definit",
    "definitelor": "definit",
    "definiți": "definit",
    "definiții": "definit",
    "definiților": "definit",
    "definito": "definit",
    "definitul": "definit",
    "definitule": "definit",
    "definitului": "definit",
    "def.": "definiție",
    "definiția": "definiție",
    "definiției": "definiție",
    "definiții": "definiție",
    "definițiile": "definiție",
    "definițiilor": "definiție",
    "definițio": "definiție",
    "definitiva": "definitiv",
    "definitivă": "definitiv",
    "definitive": "definitiv",
    "definitivei": "definitiv",
    "definitivele": "definitiv",
    "definitivelor": "definitiv",
    "definitivi": "definitiv",
    "definitivii": "definitiv",
    "definitivilor": "definitiv",
    "definitivo": "definitiv",
    "definitivul": "definitiv",
    "definitivule": "definitiv",
    "definitivului": "definitiv",
    "definitivă": "definitiva",
    "definitivai": "definitiva",
    "definitivam": "definitiva",
    "definitivăm": "definitiva",
    "definitivând": "definitiva",
    "definitivându": "definitiva",
    "definitivară": "definitiva",
    "definitivarăm": "definitiva",
    "definitivarăți": "definitiva",
    "definitivase": "definitiva",
    "definitivasem": "definitiva",
    "definitivaseră": "definitiva",
    "definitivaserăm": "definitiva",
    "definitivaserăți": "definitiva",
    "definitivaseși": "definitiva",
    "definitivași": "definitiva",
    "definitivat": "definitiva",
    "definitivați": "definitiva",
    "definitivatu": "definitiva",
    "definitivau": "definitiva",
    "definitivează": "definitiva",
    "definitivez": "definitiva",
    "definitiveze": "definitiva",
    "definitivezi": "definitiva",
    "nedefinitivând": "definitiva",
    "nedefinitivându": "definitiva",
    "nemaidefinitivând": "definitiva",
    "nemaidefinitivându": "definitiva",
    "definitivarea": "definitivare",
    "definitivareo": "definitivare",
    "definitivări": "definitivare",
    "definitivării": "definitivare",
    "definitivările": "definitivare",
    "definitivărilor": "definitivare",
    "definitivată": "definitivat",
    "definitivate": "definitivat",
    "definitivatele": "definitivat",
    "definitivatelor": "definitivat",
    "definitivați": "definitivat",
    "definitivatul": "definitivat",
    "definitivatule": "definitivat",
    "definitivatului": "definitivat",
    "definitoria": "definitoriu",
    "definitorie": "definitoriu",
    "definitoriei": "definitoriu",
    "definitorii": "definitoriu",
    "definitoriii": "definitoriu",
    "definitoriile": "definitoriu",
    "definitoriilor": "definitoriu",
    "definitorio": "definitoriu",
    "definitoriul": "definitoriu",
    "definitoriule": "definitoriu",
    "definitoriului": "definitoriu",
    "deflagrația": "deflagrație",
    "deflagrației": "deflagrație",
    "deflagrații": "deflagrație",
    "deflagrațiile": "deflagrație",
    "deflagrațiilor": "deflagrație",
    "deflagrațio": "deflagrație",
    "deflectoare": "deflector",
    "deflectoarele": "deflector",
    "deflectoarelor": "deflector",
    "deflectorul": "deflector",
    "deflectorule": "deflector",
    "deflectorului": "deflector",
    "deflexiunea": "deflexiune",
    "deflexiuneo": "deflexiune",
    "deflexiuni": "deflexiune",
    "deflexiunii": "deflexiune",
    "deflexiunile": "deflexiune",
    "deflexiunilor": "deflexiune",
    "defloră": "deflora",
    "deflorai": "deflora",
    "defloram": "deflora",
    "deflorăm": "deflora",
    "deflorând": "deflora",
    "deflorându": "deflora",
    "deflorară": "deflora",
    "deflorarăm": "deflora",
    "deflorarăți": "deflora",
    "deflorase": "deflora",
    "deflorasem": "deflora",
    "defloraseră": "deflora",
    "defloraserăm": "deflora",
    "defloraserăți": "deflora",
    "defloraseși": "deflora",
    "deflorași": "deflora",
    "deflorat": "deflora",
    "deflorați": "deflora",
    "defloratu": "deflora",
    "deflorau": "deflora",
    "deflorează": "deflora",
    "deflorez": "deflora",
    "defloreze": "deflora",
    "deflorezi": "deflora",
    "nedeflorând": "deflora",
    "nedeflorându": "deflora",
    "nemaideflorând": "deflora",
    "nemaideflorându": "deflora",
    "deflorarea": "deflorare",
    "deflorareo": "deflorare",
    "deflorări": "deflorare",
    "deflorării": "deflorare",
    "deflorările": "deflorare",
    "deflorărilor": "deflorare",
    "deflorată": "deflorat",
    "deflorate": "deflorat",
    "deflorați": "deflorat",
    "deformă": "deforma",
    "deformai": "deforma",
    "deformam": "deforma",
    "deformăm": "deforma",
    "deformând": "deforma",
    "deformându": "deforma",
    "deformară": "deforma",
    "deformarăm": "deforma",
    "deformarăți": "deforma",
    "deformase": "deforma",
    "deformasem": "deforma",
    "deformaseră": "deforma",
    "deformaserăm": "deforma",
    "deformaserăți": "deforma",
    "deformaseși": "deforma",
    "deformași": "deforma",
    "deformat": "deforma",
    "deformați": "deforma",
    "deformatu": "deforma",
    "deformau": "deforma",
    "deformează": "deforma",
    "deformez": "deforma",
    "deformeze": "deforma",
    "deformezi": "deforma",
    "nedeformând": "deforma",
    "nedeformându": "deforma",
    "nemaideformând": "deforma",
    "nemaideformându": "deforma",
    "deformabila": "deformabil",
    "deformabilă": "deformabil",
    "deformabile": "deformabil",
    "deformabilei": "deformabil",
    "deformabilele": "deformabil",
    "deformabilelor": "deformabil",
    "deformabili": "deformabil",
    "deformabilii": "deformabil",
    "deformabililor": "deformabil",
    "deformabilo": "deformabil",
    "deformabilul": "deformabil",
    "deformabilule": "deformabil",
    "deformabilului": "deformabil",
    "deformarea": "deformare",
    "deformareo": "deformare",
    "deformări": "deformare",
    "deformării": "deformare",
    "deformările": "deformare",
    "deformărilor": "deformare",
    "deformata": "deformat",
    "deformată": "deformat",
    "deformate": "deformat",
    "deformatei": "deformat",
    "deformatele": "deformat",
    "deformatelor": "deformat",
    "deformați": "deformat",
    "deformații": "deformat",
    "deformaților": "deformat",
    "deformato": "deformat",
    "deformatul": "deformat",
    "deformatule": "deformat",
    "deformatului": "deformat",
    "deformația": "deformație",
    "deformației": "deformație",
    "deformații": "deformație",
    "deformațiile": "deformație",
    "deformațiilor": "deformație",
    "deformațio": "deformație",
    "defraudă": "defrauda",
    "defraudai": "defrauda",
    "defraudam": "defrauda",
    "defraudăm": "defrauda",
    "defraudând": "defrauda",
    "defraudându": "defrauda",
    "defraudară": "defrauda",
    "defraudarăm": "defrauda",
    "defraudarăți": "defrauda",
    "defraudase": "defrauda",
    "defraudasem": "defrauda",
    "defraudaseră": "defrauda",
    "defraudaserăm": "defrauda",
    "defraudaserăți": "defrauda",
    "defraudaseși": "defrauda",
    "defraudași": "defrauda",
    "defraudat": "defrauda",
    "defraudați": "defrauda",
    "defraudatu": "defrauda",
    "defraudau": "defrauda",
    "defraudează": "defrauda",
    "defraudez": "defrauda",
    "defraudeze": "defrauda",
    "defraudezi": "defrauda",
    "nedefraudând": "defrauda",
    "nedefraudându": "defrauda",
    "nemaidefraudând": "defrauda",
    "nemaidefraudându": "defrauda",
    "defraudarea": "defraudare",
    "defraudareo": "defraudare",
    "defraudări": "defraudare",
    "defraudării": "defraudare",
    "defraudările": "defraudare",
    "defraudărilor": "defraudare",
    "defraudata": "defraudat",
    "defraudată": "defraudat",
    "defraudate": "defraudat",
    "defraudatei": "defraudat",
    "defraudatele": "defraudat",
    "defraudatelor": "defraudat",
    "defraudați": "defraudat",
    "defraudații": "defraudat",
    "defraudaților": "defraudat",
    "defraudato": "defraudat",
    "defraudatul": "defraudat",
    "defraudatule": "defraudat",
    "defraudatului": "defraudat",
    "defraudatoarea": "defraudatoare",
    "defraudatoarei": "defraudatoare",
    "defraudatoarele": "defraudatoare",
    "defraudatoarelor": "defraudatoare",
    "defraudatoareo": "defraudatoare",
    "defraudatori": "defraudator",
    "defraudatorii": "defraudator",
    "defraudatorilor": "defraudator",
    "defraudatorul": "defraudator",
    "defraudatorule": "defraudator",
    "defraudatorului": "defraudator",
    "defrișă": "defrișa",
    "defrișai": "defrișa",
    "defrișam": "defrișa",
    "defrișăm": "defrișa",
    "defrișând": "defrișa",
    "defrișându": "defrișa",
    "defrișară": "defrișa",
    "defrișarăm": "defrișa",
    "defrișarăți": "defrișa",
    "defrișase": "defrișa",
    "defrișasem": "defrișa",
    "defrișaseră": "defrișa",
    "defrișaserăm": "defrișa",
    "defrișaserăți": "defrișa",
    "defrișaseși": "defrișa",
    "defrișași": "defrișa",
    "defrișat": "defrișa",
    "defrișați": "defrișa",
    "defrișatu": "defrișa",
    "defrișau": "defrișa",
    "defrișează": "defrișa",
    "defrișez": "defrișa",
    "defrișeze": "defrișa",
    "defrișezi": "defrișa",
    "nedefrișând": "defrișa",
    "nedefrișându": "defrișa",
    "nemaidefrișând": "defrișa",
    "nemaidefrișându": "defrișa",
    "defrișarea": "defrișare",
    "defrișareo": "defrișare",
    "defrișări": "defrișare",
    "defrișării": "defrișare",
    "defrișările": "defrișare",
    "defrișărilor": "defrișare",
    "defrișata": "defrișat",
    "defrișată": "defrișat",
    "defrișate": "defrișat",
    "defrișatei": "defrișat",
    "defrișatele": "defrișat",
    "defrișatelor": "defrișat",
    "defrișați": "defrișat",
    "defrișații": "defrișat",
    "defrișaților": "defrișat",
    "defrișato": "defrișat",
    "defrișatul": "defrișat",
    "defrișatule": "defrișat",
    "defrișatului": "defrișat",
    "defuncta": "defunct",
    "defunctă": "defunct",
    "defuncte": "defunct",
    "defunctei": "defunct",
    "defunctele": "defunct",
    "defunctelor": "defunct",
    "defuncți": "defunct",
    "defuncții": "defunct",
    "defuncților": "defunct",
    "defuncto": "defunct",
    "defunctul": "defunct",
    "defunctule": "defunct",
    "defunctului": "defunct",
    "degajă": "degaja",
    "degajai": "degaja",
    "degajam": "degaja",
    "degajăm": "degaja",
    "degajând": "degaja",
    "degajându": "degaja",
    "degajară": "degaja",
    "degajarăm": "degaja",
    "degajarăți": "degaja",
    "degajase": "degaja",
    "degajasem": "degaja",
    "degajaseră": "degaja",
    "degajaserăm": "degaja",
    "degajaserăți": "degaja",
    "degajaseși": "degaja",
    "degajași": "degaja",
    "degajat": "degaja",
    "degajați": "degaja",
    "degajatu": "degaja",
    "degajau": "degaja",
    "degajează": "degaja",
    "degajez": "degaja",
    "degajeze": "degaja",
    "degajezi": "degaja",
    "nedegajând": "degaja",
    "nedegajându": "degaja",
    "nemaidegajând": "degaja",
    "nemaidegajându": "degaja",
    "degajarea": "degajare",
    "degajareo": "degajare",
    "degajări": "degajare",
    "degajării": "degajare",
    "degajările": "degajare",
    "degajărilor": "degajare",
    "degajata": "degajat",
    "degajată": "degajat",
    "degajate": "degajat",
    "degajatei": "degajat",
    "degajatele": "degajat",
    "degajatelor": "degajat",
    "degajați": "degajat",
    "degajații": "degajat",
    "degajaților": "degajat",
    "degajato": "degajat",
    "degajatul": "degajat",
    "degajatule": "degajat",
    "degajatului": "degajat",
    "degeneră": "degenera",
    "degenerai": "degenera",
    "degeneram": "degenera",
    "degenerăm": "degenera",
    "degenerând": "degenera",
    "degenerându": "degenera",
    "degenerară": "degenera",
    "degenerarăm": "degenera",
    "degenerarăți": "degenera",
    "degenerase": "degenera",
    "degenerasem": "degenera",
    "degeneraseră": "degenera",
    "degeneraserăm": "degenera",
    "degeneraserăți": "degenera",
    "degeneraseși": "degenera",
    "degenerași": "degenera",
    "degenerat": "degenera",
    "degenerați": "degenera",
    "degeneratu": "degenera",
    "degenerau": "degenera",
    "degenerează": "degenera",
    "degenerez": "degenera",
    "degenereze": "degenera",
    "degenerezi": "degenera",
    "degenerata": "degenerat",
    "degenerată": "degenerat",
    "degenerate": "degenerat",
    "degeneratei": "degenerat",
    "degeneratele": "degenerat",
    "degeneratelor": "degenerat",
    "degenerați": "degenerat",
    "degenerații": "degenerat",
    "degeneraților": "degenerat",
    "degenerato": "degenerat",
    "degeneratul": "degenerat",
    "degeneratule": "degenerat",
    "degeneratului": "degenerat",
    "degenerata": "degenerată",
    "degenerate": "degenerată",
    "degeneratei": "degenerată",
    "degeneratele": "degenerată",
    "degeneratelor": "degenerată",
    "degenerato": "degenerată",
    "degenerescența": "degenerescență",
    "degenerescențe": "degenerescență",
    "degenerescenței": "degenerescență",
    "degenerescențele": "degenerescență",
    "degenerescențelor": "degenerescență",
    "degenerescențo": "degenerescență",
    "deger": "degera",
    "degeră": "degera",
    "degerai": "degera",
    "degeram": "degera",
    "degerăm": "degera",
    "degerând": "degera",
    "degerându": "degera",
    "degerară": "degera",
    "degerarăm": "degera",
    "degerarăți": "degera",
    "degerase": "degera",
    "degerasem": "degera",
    "degeraseră": "degera",
    "degeraserăm": "degera",
    "degeraserăți": "degera",
    "degeraseși": "degera",
    "degerași": "degera",
    "degerat": "degera",
    "degerați": "degera",
    "degeratu": "degera",
    "degerau": "degera",
    "degere": "degera",
    "degeri": "degera",
    "nedegerând": "degera",
    "nedegerându": "degera",
    "nemaidegerând": "degera",
    "nemaidegerându": "degera",
    "degerarea": "degerare",
    "degerareo": "degerare",
    "degerări": "degerare",
    "degerării": "degerare",
    "degerările": "degerare",
    "degerărilor": "degerare",
    "degerata": "degerat",
    "degerată": "degerat",
    "degerate": "degerat",
    "degeratei": "degerat",
    "degeratele": "degerat",
    "degeratelor": "degerat",
    "degerați": "degerat",
    "degerații": "degerat",
    "degeraților": "degerat",
    "degerato": "degerat",
    "degeratul": "degerat",
    "degeratule": "degerat",
    "degeratului": "degerat",
    "degerătura": "degerătură",
    "degerături": "degerătură",
    "degerăturii": "degerătură",
    "degerăturile": "degerătură",
    "degerăturilor": "degerătură",
    "degerăturo": "degerătură",
    "degete": "deget",
    "degetele": "deget",
    "degetelor": "deget",
    "degetul": "deget",
    "degetule": "deget",
    "degetului": "deget",
    "degetare": "degetar",
    "degetarele": "degetar",
    "degetarelor": "degetar",
    "degetarul": "degetar",
    "degetarule": "degetar",
    "degetarului": "degetar",
    "deghiză": "deghiza",
    "deghizai": "deghiza",
    "deghizam": "deghiza",
    "deghizăm": "deghiza",
    "deghizând": "deghiza",
    "deghizându": "deghiza",
    "deghizară": "deghiza",
    "deghizarăm": "deghiza",
    "deghizarăți": "deghiza",
    "deghizase": "deghiza",
    "deghizasem": "deghiza",
    "deghizaseră": "deghiza",
    "deghizaserăm": "deghiza",
    "deghizaserăți": "deghiza",
    "deghizaseși": "deghiza",
    "deghizași": "deghiza",
    "deghizat": "deghiza",
    "deghizați": "deghiza",
    "deghizatu": "deghiza",
    "deghizau": "deghiza",
    "deghizează": "deghiza",
    "deghizez": "deghiza",
    "deghizeze": "deghiza",
    "deghizezi": "deghiza",
    "nedeghizând": "deghiza",
    "nedeghizându": "deghiza",
    "nemaideghizând": "deghiza",
    "nemaideghizându": "deghiza",
    "deghizarea": "deghizare",
    "deghizareo": "deghizare",
    "deghizări": "deghizare",
    "deghizării": "deghizare",
    "deghizările": "deghizare",
    "deghizărilor": "deghizare",
    "deghizata": "deghizat",
    "deghizată": "deghizat",
    "deghizate": "deghizat",
    "deghizatei": "deghizat",
    "deghizatele": "deghizat",
    "deghizatelor": "deghizat",
    "deghizați": "deghizat",
    "deghizații": "deghizat",
    "deghizaților": "deghizat",
    "deghizato": "deghizat",
    "deghizatul": "deghizat",
    "deghizatule": "deghizat",
    "deghizatului": "deghizat",
    "deglutiția": "deglutiție",
    "deglutiției": "deglutiție",
    "deglutiții": "deglutiție",
    "deglutițiile": "deglutiție",
    "deglutițiilor": "deglutiție",
    "deglutițio": "deglutiție",
    "degrab": "degrabă",
    "degradă": "degrada",
    "degradai": "degrada",
    "degradam": "degrada",
    "degradăm": "degrada",
    "degradând": "degrada",
    "degradându": "degrada",
    "degradară": "degrada",
    "degradarăm": "degrada",
    "degradarăți": "degrada",
    "degradase": "degrada",
    "degradasem": "degrada",
    "degradaseră": "degrada",
    "degradaserăm": "degrada",
    "degradaserăți": "degrada",
    "degradaseși": "degrada",
    "degradași": "degrada",
    "degradat": "degrada",
    "degradați": "degrada",
    "degradatu": "degrada",
    "degradau": "degrada",
    "degradează": "degrada",
    "degradez": "degrada",
    "degradeze": "degrada",
    "degradezi": "degrada",
    "nedegradând": "degrada",
    "nedegradându": "degrada",
    "nemaidegradând": "degrada",
    "nemaidegradându": "degrada",
    "degradarea": "degradare",
    "degradareo": "degradare",
    "degradări": "degradare",
    "degradării": "degradare",
    "degradările": "degradare",
    "degradărilor": "degradare",
    "degradata": "degradat",
    "degradată": "degradat",
    "degradate": "degradat",
    "degradatei": "degradat",
    "degradatele": "degradat",
    "degradatelor": "degradat",
    "degradați": "degradat",
    "degradații": "degradat",
    "degradaților": "degradat",
    "degradato": "degradat",
    "degradatul": "degradat",
    "degradatule": "degradat",
    "degradatului": "degradat",
    "degradatoarea": "degradatoare",
    "degradatoarei": "degradatoare",
    "degradatoarele": "degradatoare",
    "degradatoarelor": "degradatoare",
    "degradatoareo": "degradatoare",
    "degradatori": "degradator",
    "degradatorii": "degradator",
    "degradatorilor": "degradator",
    "degradatorul": "degradator",
    "degradatorule": "degradator",
    "degradatorului": "degradator",
    "degresă": "degresa",
    "degresai": "degresa",
    "degresam": "degresa",
    "degresăm": "degresa",
    "degresând": "degresa",
    "degresându": "degresa",
    "degresară": "degresa",
    "degresarăm": "degresa",
    "degresarăți": "degresa",
    "degresase": "degresa",
    "degresasem": "degresa",
    "degresaseră": "degresa",
    "degresaserăm": "degresa",
    "degresaserăți": "degresa",
    "degresaseși": "degresa",
    "degresași": "degresa",
    "degresat": "degresa",
    "degresați": "degresa",
    "degresatu": "degresa",
    "degresau": "degresa",
    "degresează": "degresa",
    "degresez": "degresa",
    "degreseze": "degresa",
    "degresezi": "degresa",
    "nedegresând": "degresa",
    "nedegresându": "degresa",
    "nemaidegresând": "degresa",
    "nemaidegresându": "degresa",
    "degresanți": "degresant",
    "degresanții": "degresant",
    "degresanților": "degresant",
    "degresantul": "degresant",
    "degresantule": "degresant",
    "degresantului": "degresant",
    "degresarea": "degresare",
    "degresareo": "degresare",
    "degresări": "degresare",
    "degresării": "degresare",
    "degresările": "degresare",
    "degresărilor": "degresare",
    "degresată": "degresat",
    "degresate": "degresat",
    "degresați": "degresat",
    "degrevă": "degreva",
    "degrevai": "degreva",
    "degrevam": "degreva",
    "degrevăm": "degreva",
    "degrevând": "degreva",
    "degrevându": "degreva",
    "degrevară": "degreva",
    "degrevarăm": "degreva",
    "degrevarăți": "degreva",
    "degrevase": "degreva",
    "degrevasem": "degreva",
    "degrevaseră": "degreva",
    "degrevaserăm": "degreva",
    "degrevaserăți": "degreva",
    "degrevaseși": "degreva",
    "degrevași": "degreva",
    "degrevat": "degreva",
    "degrevați": "degreva",
    "degrevatu": "degreva",
    "degrevau": "degreva",
    "degrevează": "degreva",
    "degrevez": "degreva",
    "degreveze": "degreva",
    "degrevezi": "degreva",
    "nedegrevând": "degreva",
    "nedegrevându": "degreva",
    "nemaidegrevând": "degreva",
    "nemaidegrevându": "degreva",
    "degrevanta": "degrevant",
    "degrevantă": "degrevant",
    "degrevante": "degrevant",
    "degrevantei": "degrevant",
    "degrevantele": "degrevant",
    "degrevantelor": "degrevant",
    "degrevanți": "degrevant",
    "degrevanții": "degrevant",
    "degrevanților": "degrevant",
    "degrevanto": "degrevant",
    "degrevantul": "degrevant",
    "degrevantule": "degrevant",
    "degrevantului": "degrevant",
    "degrevarea": "degrevare",
    "degrevareo": "degrevare",
    "degrevări": "degrevare",
    "degrevării": "degrevare",
    "degrevările": "degrevare",
    "degrevărilor": "degrevare",
    "degrevata": "degrevat",
    "degrevată": "degrevat",
    "degrevate": "degrevat",
    "degrevatei": "degrevat",
    "degrevatele": "degrevat",
    "degrevatelor": "degrevat",
    "degrevați": "degrevat",
    "degrevații": "degrevat",
    "degrevaților": "degrevat",
    "degrevato": "degrevat",
    "degrevatul": "degrevat",
    "degrevatule": "degrevat",
    "degrevatului": "degrevat",
    "degringolada": "degringoladă",
    "degringolade": "degringoladă",
    "degringoladei": "degringoladă",
    "degringoladele": "degringoladă",
    "degringoladelor": "degringoladă",
    "degringolado": "degringoladă",
    "degringolarea": "degringolare",
    "degringolareo": "degringolare",
    "degringolări": "degringolare",
    "degringolării": "degringolare",
    "degringolările": "degringolare",
    "degringolărilor": "degringolare",
    "degust": "degusta",
    "degustă": "degusta",
    "degustai": "degusta",
    "degustam": "degusta",
    "degustăm": "degusta",
    "degustând": "degusta",
    "degustându": "degusta",
    "degustară": "degusta",
    "degustarăm": "degusta",
    "degustarăți": "degusta",
    "degustase": "degusta",
    "degustasem": "degusta",
    "degustaseră": "degusta",
    "degustaserăm": "degusta",
    "degustaserăți": "degusta",
    "degustaseși": "degusta",
    "degustași": "degusta",
    "degustat": "degusta",
    "degustați": "degusta",
    "degustatu": "degusta",
    "degustau": "degusta",
    "deguste": "degusta",
    "deguști": "degusta",
    "nedegustând": "degusta",
    "nedegustându": "degusta",
    "nemaidegustând": "degusta",
    "nemaidegustându": "degusta",
    "degustată": "degustat",
    "degustate": "degustat",
    "degustați": "degustat",
    "deific": "deifica",
    "deifică": "deifica",
    "deificai": "deifica",
    "deificam": "deifica",
    "deificăm": "deifica",
    "deificând": "deifica",
    "deificându": "deifica",
    "deificară": "deifica",
    "deificarăm": "deifica",
    "deificarăți": "deifica",
    "deificase": "deifica",
    "deificasem": "deifica",
    "deificaseră": "deifica",
    "deificaserăm": "deifica",
    "deificaserăți": "deifica",
    "deificaseși": "deifica",
    "deificași": "deifica",
    "deificat": "deifica",
    "deificați": "deifica",
    "deificatu": "deifica",
    "deificau": "deifica",
    "deifice": "deifica",
    "deifici": "deifica",
    "nedeificând": "deifica",
    "nedeificându": "deifica",
    "nemaideificând": "deifica",
    "nemaideificându": "deifica",
    "deificarea": "deificare",
    "deificareo": "deificare",
    "deificări": "deificare",
    "deificării": "deificare",
    "deificările": "deificare",
    "deificărilor": "deificare",
    "deificată": "deificat",
    "deificate": "deificat",
    "deificați": "deificat",
    "deîmpărțitul": "deîmpărțit",
    "deîmpărțitule": "deîmpărțit",
    "deîmpărțitului": "deîmpărțit",
    "deîmpărțituri": "deîmpărțit",
    "deîmpărțiturile": "deîmpărțit",
    "deîmpărțiturilor": "deîmpărțit",
    "deînmulțitul": "deînmulțit",
    "deînmulțitule": "deînmulțit",
    "deînmulțitului": "deînmulțit",
    "deînmulțituri": "deînmulțit",
    "deînmulțiturile": "deînmulțit",
    "deînmulțiturilor": "deînmulțit",
    "deismul": "deism",
    "deismule": "deism",
    "deismului": "deism",
    "deista": "deist",
    "deistă": "deist",
    "deiste": "deist",
    "deistei": "deist",
    "deistele": "deist",
    "deistelor": "deist",
    "deiști": "deist",
    "deiștii": "deist",
    "deiștilor": "deist",
    "deisto": "deist",
    "deistul": "deist",
    "deistule": "deist",
    "deistului": "deist",
    "deista": "deistă",
    "deiste": "deistă",
    "deistei": "deistă",
    "deistele": "deistă",
    "deistelor": "deistă",
    "deisto": "deistă",
    "Dejul": "Dej",
    "Dejului": "Dej",
    "dejecția": "dejecție",
    "dejecției": "dejecție",
    "dejecții": "dejecție",
    "dejecțiile": "dejecție",
    "dejecțiilor": "dejecție",
    "dejecțio": "dejecție",
    "dejista": "dejist",
    "dejistă": "dejist",
    "dejiste": "dejist",
    "dejistei": "dejist",
    "dejistele": "dejist",
    "dejistelor": "dejist",
    "dejiști": "dejist",
    "dejiștii": "dejist",
    "dejiștilor": "dejist",
    "dejisto": "dejist",
    "dejistul": "dejist",
    "dejistule": "dejist",
    "dejistului": "dejist",
    "dejista": "dejistă",
    "dejiste": "dejistă",
    "dejistei": "dejistă",
    "dejistele": "dejistă",
    "dejistelor": "dejistă",
    "dejisto": "dejistă",
    "dejug": "dejuga",
    "dejugă": "dejuga",
    "dejugai": "dejuga",
    "dejugam": "dejuga",
    "dejugăm": "dejuga",
    "dejugând": "dejuga",
    "dejugându": "dejuga",
    "dejugară": "dejuga",
    "dejugarăm": "dejuga",
    "dejugarăți": "dejuga",
    "dejugase": "dejuga",
    "dejugasem": "dejuga",
    "dejugaseră": "dejuga",
    "dejugaserăm": "dejuga",
    "dejugaserăți": "dejuga",
    "dejugaseși": "dejuga",
    "dejugași": "dejuga",
    "dejugat": "dejuga",
    "dejugați": "dejuga",
    "dejugatu": "dejuga",
    "dejugau": "dejuga",
    "dejuge": "dejuga",
    "dejugi": "dejuga",
    "nedejugând": "dejuga",
    "nedejugându": "dejuga",
    "nemaidejugând": "dejuga",
    "nemaidejugându": "dejuga",
    "dejugată": "dejugat",
    "dejugate": "dejugat",
    "dejugați": "dejugat",
    "dejugatul": "dejugat",
    "dejugatule": "dejugat",
    "dejugatului": "dejugat",
    "dejunul": "dejun",
    "dejunule": "dejun",
    "dejunului": "dejun",
    "dejunuri": "dejun",
    "dejunurile": "dejun",
    "dejunurilor": "dejun",
    "dejună": "dejuna",
    "dejunai": "dejuna",
    "dejunam": "dejuna",
    "dejunăm": "dejuna",
    "dejunând": "dejuna",
    "dejunându": "dejuna",
    "dejunară": "dejuna",
    "dejunarăm": "dejuna",
    "dejunarăți": "dejuna",
    "dejunase": "dejuna",
    "dejunasem": "dejuna",
    "dejunaseră": "dejuna",
    "dejunaserăm": "dejuna",
    "dejunaserăți": "dejuna",
    "dejunaseși": "dejuna",
    "dejunași": "dejuna",
    "dejunat": "dejuna",
    "dejunați": "dejuna",
    "dejunatu": "dejuna",
    "dejunau": "dejuna",
    "dejunează": "dejuna",
    "dejunez": "dejuna",
    "dejuneze": "dejuna",
    "dejunezi": "dejuna",
    "nedejunând": "dejuna",
    "nedejunându": "dejuna",
    "nemaidejunând": "dejuna",
    "nemaidejunându": "dejuna",
    "dejunată": "dejunat",
    "dejunate": "dejunat",
    "dejunați": "dejunat",
    "delapidă": "delapida",
    "delapidai": "delapida",
    "delapidam": "delapida",
    "delapidăm": "delapida",
    "delapidând": "delapida",
    "delapidându": "delapida",
    "delapidară": "delapida",
    "delapidarăm": "delapida",
    "delapidarăți": "delapida",
    "delapidase": "delapida",
    "delapidasem": "delapida",
    "delapidaseră": "delapida",
    "delapidaserăm": "delapida",
    "delapidaserăți": "delapida",
    "delapidaseși": "delapida",
    "delapidași": "delapida",
    "delapidat": "delapida",
    "delapidați": "delapida",
    "delapidatu": "delapida",
    "delapidau": "delapida",
    "delapidează": "delapida",
    "delapidez": "delapida",
    "delapideze": "delapida",
    "delapidezi": "delapida",
    "nedelapidând": "delapida",
    "nedelapidându": "delapida",
    "nemaidelapidând": "delapida",
    "nemaidelapidându": "delapida",
    "delapidarea": "delapidare",
    "delapidareo": "delapidare",
    "delapidări": "delapidare",
    "delapidării": "delapidare",
    "delapidările": "delapidare",
    "delapidărilor": "delapidare",
    "delapidată": "delapidat",
    "delapidate": "delapidat",
    "delapidați": "delapidat",
    "delapidatoarea": "delapidatoare",
    "delapidatoarei": "delapidatoare",
    "delapidatoarele": "delapidatoare",
    "delapidatoarelor": "delapidatoare",
    "delapidatoareo": "delapidatoare",
    "delapidatori": "delapidator",
    "delapidatorii": "delapidator",
    "delapidatorilor": "delapidator",
    "delapidatorul": "delapidator",
    "delapidatorule": "delapidator",
    "delapidatorului": "delapidator",
    "delas": "delăsa",
    "delasă": "delăsa",
    "delăsă": "delăsa",
    "delăsai": "delăsa",
    "delăsam": "delăsa",
    "delăsăm": "delăsa",
    "delăsând": "delăsa",
    "delăsându": "delăsa",
    "delăsară": "delăsa",
    "delăsarăm": "delăsa",
    "delăsarăți": "delăsa",
    "delăsase": "delăsa",
    "delăsasem": "delăsa",
    "delăsaseră": "delăsa",
    "delăsaserăm": "delăsa",
    "delăsaserăți": "delăsa",
    "delăsaseși": "delăsa",
    "delăsași": "delăsa",
    "delăsat": "delăsa",
    "delăsați": "delăsa",
    "delăsatu": "delăsa",
    "delăsau": "delăsa",
    "delase": "delăsa",
    "delași": "delăsa",
    "nedelăsând": "delăsa",
    "nedelăsându": "delăsa",
    "nemaidelăsând": "delăsa",
    "nemaidelăsându": "delăsa",
    "delăsarea": "delăsare",
    "delăsareo": "delăsare",
    "delăsări": "delăsare",
    "delăsării": "delăsare",
    "delăsările": "delăsare",
    "delăsărilor": "delăsare",
    "delăsată": "delăsat",
    "delăsate": "delăsat",
    "delăsați": "delăsat",
    "delăsătoare": "delăsător",
    "delăsătoarea": "delăsător",
    "delăsătoarei": "delăsător",
    "delăsătoarele": "delăsător",
    "delăsătoarelor": "delăsător",
    "delăsători": "delăsător",
    "delăsătorii": "delăsător",
    "delăsătorilor": "delăsător",
    "delăsătorul": "delăsător",
    "delăsătorului": "delăsător",
    "delațiunea": "delațiune",
    "delațiuni": "delațiune",
    "delațiunii": "delațiune",
    "delațiunile": "delațiune",
    "delațiunilor": "delațiune",
    "delatoarea": "delatoare",
    "delatoarei": "delatoare",
    "delatoarele": "delatoare",
    "delatoarelor": "delatoare",
    "delatoareo": "delatoare",
    "delatori": "delator",
    "delatorii": "delator",
    "delatorilor": "delator",
    "delatorul": "delator",
    "delatorule": "delator",
    "delatorului": "delator",
    "delectă": "delecta",
    "delectai": "delecta",
    "delectam": "delecta",
    "delectăm": "delecta",
    "delectând": "delecta",
    "delectându": "delecta",
    "delectară": "delecta",
    "delectarăm": "delecta",
    "delectarăți": "delecta",
    "delectase": "delecta",
    "delectasem": "delecta",
    "delectaseră": "delecta",
    "delectaserăm": "delecta",
    "delectaserăți": "delecta",
    "delectaseși": "delecta",
    "delectași": "delecta",
    "delectat": "delecta",
    "delectați": "delecta",
    "delectatu": "delecta",
    "delectau": "delecta",
    "delectează": "delecta",
    "delectez": "delecta",
    "delecteze": "delecta",
    "delectezi": "delecta",
    "nedelectând": "delecta",
    "nedelectându": "delecta",
    "nemaidelectând": "delecta",
    "nemaidelectându": "delecta",
    "delectarea": "delectare",
    "delectareo": "delectare",
    "delectări": "delectare",
    "delectării": "delectare",
    "delectările": "delectare",
    "delectărilor": "delectare",
    "delectată": "delectat",
    "delectate": "delectat",
    "delectați": "delectat",
    "deleagă": "delega",
    "deleg": "delega",
    "delegă": "delega",
    "delegai": "delega",
    "delegam": "delega",
    "delegăm": "delega",
    "delegând": "delega",
    "delegându": "delega",
    "delegară": "delega",
    "delegarăm": "delega",
    "delegarăți": "delega",
    "delegase": "delega",
    "delegasem": "delega",
    "delegaseră": "delega",
    "delegaserăm": "delega",
    "delegaserăți": "delega",
    "delegaseși": "delega",
    "delegași": "delega",
    "delegat": "delega",
    "delegați": "delega",
    "delegatu": "delega",
    "delegau": "delega",
    "delege": "delega",
    "delegi": "delega",
    "nedelegând": "delega",
    "nedelegându": "delega",
    "nemaidelegând": "delega",
    "nemaidelegându": "delega",
    "delegarea": "delegare",
    "delegareo": "delegare",
    "delegări": "delegare",
    "delegării": "delegare",
    "delegările": "delegare",
    "delegărilor": "delegare",
    "delegată": "delegat",
    "delegate": "delegat",
    "delegați": "delegat",
    "delegații": "delegat",
    "delegaților": "delegat",
    "delegatul": "delegat",
    "delegatule": "delegat",
    "delegatului": "delegat",
    "delegata": "delegată",
    "delegate": "delegată",
    "delegatei": "delegată",
    "delegatele": "delegată",
    "delegatelor": "delegată",
    "delegato": "delegată",
    "delegația": "delegație",
    "delegației": "delegație",
    "delegații": "delegație",
    "delegațiile": "delegație",
    "delegațiilor": "delegație",
    "delegațio": "delegație",
    "delfini": "delfin",
    "delfinii": "delfin",
    "delfinilor": "delfin",
    "delfinul": "delfin",
    "delfinule": "delfin",
    "delfinului": "delfin",
    "Deliei": "Delia",
    "deliberă": "delibera",
    "deliberai": "delibera",
    "deliberam": "delibera",
    "deliberăm": "delibera",
    "deliberând": "delibera",
    "deliberându": "delibera",
    "deliberară": "delibera",
    "deliberarăm": "delibera",
    "deliberarăți": "delibera",
    "deliberase": "delibera",
    "deliberasem": "delibera",
    "deliberaseră": "delibera",
    "deliberaserăm": "delibera",
    "deliberaserăți": "delibera",
    "deliberaseși": "delibera",
    "deliberași": "delibera",
    "deliberat": "delibera",
    "deliberați": "delibera",
    "deliberatu": "delibera",
    "deliberau": "delibera",
    "deliberează": "delibera",
    "deliberez": "delibera",
    "delibereze": "delibera",
    "deliberezi": "delibera",
    "nedeliberând": "delibera",
    "nedeliberându": "delibera",
    "nemaideliberând": "delibera",
    "nemaideliberându": "delibera",
    "deliberarea": "deliberare",
    "deliberareo": "deliberare",
    "deliberări": "deliberare",
    "deliberării": "deliberare",
    "deliberările": "deliberare",
    "deliberărilor": "deliberare",
    "deliberata": "deliberat",
    "deliberată": "deliberat",
    "deliberate": "deliberat",
    "deliberatei": "deliberat",
    "deliberatele": "deliberat",
    "deliberatelor": "deliberat",
    "deliberați": "deliberat",
    "deliberații": "deliberat",
    "deliberaților": "deliberat",
    "deliberato": "deliberat",
    "deliberatul": "deliberat",
    "deliberatule": "deliberat",
    "deliberatului": "deliberat",
    "deliberativa": "deliberativ",
    "deliberativă": "deliberativ",
    "deliberative": "deliberativ",
    "deliberativei": "deliberativ",
    "deliberativele": "deliberativ",
    "deliberativelor": "deliberativ",
    "deliberativi": "deliberativ",
    "deliberativii": "deliberativ",
    "deliberativilor": "deliberativ",
    "deliberativo": "deliberativ",
    "deliberativul": "deliberativ",
    "deliberativule": "deliberativ",
    "deliberativului": "deliberativ",
    "delicata": "delicat",
    "delicată": "delicat",
    "delicate": "delicat",
    "delicatei": "delicat",
    "delicatele": "delicat",
    "delicatelor": "delicat",
    "delicați": "delicat",
    "delicații": "delicat",
    "delicaților": "delicat",
    "delicato": "delicat",
    "delicatul": "delicat",
    "delicatule": "delicat",
    "delicatului": "delicat",
    "delicatesa": "delicatesă",
    "delicatese": "delicatesă",
    "delicatesei": "delicatesă",
    "delicatesele": "delicatesă",
    "delicateselor": "delicatesă",
    "delicateso": "delicatesă",
    "delicatețea": "delicatețe",
    "delicateței": "delicatețe",
    "delicatețele": "delicatețe",
    "delicatețelor": "delicatețe",
    "delicatețeo": "delicatețe",
    "delicateți": "delicatețe",
    "delicioasa": "delicios",
    "delicioasă": "delicios",
    "delicioase": "delicios",
    "delicioasei": "delicios",
    "delicioasele": "delicios",
    "delicioaselor": "delicios",
    "delicioaso": "delicios",
    "delicioși": "delicios",
    "delicioșii": "delicios",
    "delicioșilor": "delicios",
    "deliciosul": "delicios",
    "deliciosule": "delicios",
    "deliciosului": "delicios",
    "delicii": "deliciu",
    "deliciile": "deliciu",
    "deliciilor": "deliciu",
    "deliciul": "deliciu",
    "deliciule": "deliciu",
    "deliciului": "deliciu",
    "delicte": "delict",
    "delictele": "delict",
    "delictelor": "delict",
    "delictul": "delict",
    "delictule": "delict",
    "delictului": "delict",
    "delicvenți": "delicvent",
    "delicvenții": "delicvent",
    "delicvenților": "delicvent",
    "delicventul": "delicvent",
    "delicventule": "delicvent",
    "delicventului": "delicvent",
    "delicventa": "delicventă",
    "delicvente": "delicventă",
    "delicventei": "delicventă",
    "delicventele": "delicventă",
    "delicventelor": "delicventă",
    "delicvento": "delicventă",
    "delimită": "delimita",
    "delimitai": "delimita",
    "delimitam": "delimita",
    "delimităm": "delimita",
    "delimitând": "delimita",
    "delimitându": "delimita",
    "delimitară": "delimita",
    "delimitarăm": "delimita",
    "delimitarăți": "delimita",
    "delimitase": "delimita",
    "delimitasem": "delimita",
    "delimitaseră": "delimita",
    "delimitaserăm": "delimita",
    "delimitaserăți": "delimita",
    "delimitaseși": "delimita",
    "delimitași": "delimita",
    "delimitat": "delimita",
    "delimitați": "delimita",
    "delimitatu": "delimita",
    "delimitau": "delimita",
    "delimitează": "delimita",
    "delimitez": "delimita",
    "delimiteze": "delimita",
    "delimitezi": "delimita",
    "nedelimitând": "delimita",
    "nedelimitându": "delimita",
    "nemaidelimitând": "delimita",
    "nemaidelimitându": "delimita",
    "delimitarea": "delimitare",
    "delimitareo": "delimitare",
    "delimitări": "delimitare",
    "delimitării": "delimitare",
    "delimitările": "delimitare",
    "delimitărilor": "delimitare",
    "delimitată": "delimitat",
    "delimitate": "delimitat",
    "delimitați": "delimitat",
    "delimitativa": "delimitativ",
    "delimitativă": "delimitativ",
    "delimitative": "delimitativ",
    "delimitativei": "delimitativ",
    "delimitativele": "delimitativ",
    "delimitativelor": "delimitativ",
    "delimitativi": "delimitativ",
    "delimitativii": "delimitativ",
    "delimitativilor": "delimitativ",
    "delimitativo": "delimitativ",
    "delimitativul": "delimitativ",
    "delimitativule": "delimitativ",
    "delimitativului": "delimitativ",
    "delincvenți": "delincvent",
    "delincvenții": "delincvent",
    "delincvenților": "delincvent",
    "delincventul": "delincvent",
    "delincventule": "delincvent",
    "delincventului": "delincvent",
    "delincventa": "delincventă",
    "delincvente": "delincventă",
    "delincventei": "delincventă",
    "delincventele": "delincventă",
    "delincventelor": "delincventă",
    "delincvento": "delincventă",
    "delirul": "delir",
    "delirule": "delir",
    "delirului": "delir",
    "deliruri": "delir",
    "delirurile": "delir",
    "delirurilor": "delir",
    "deliră": "delira",
    "delirai": "delira",
    "deliram": "delira",
    "delirăm": "delira",
    "delirând": "delira",
    "delirându": "delira",
    "delirară": "delira",
    "delirarăm": "delira",
    "delirarăți": "delira",
    "delirase": "delira",
    "delirasem": "delira",
    "deliraseră": "delira",
    "deliraserăm": "delira",
    "deliraserăți": "delira",
    "deliraseși": "delira",
    "delirași": "delira",
    "delirat": "delira",
    "delirați": "delira",
    "deliratu": "delira",
    "delirau": "delira",
    "delirează": "delira",
    "delirez": "delira",
    "delireze": "delira",
    "delirezi": "delira",
    "nedelirând": "delira",
    "nedelirându": "delira",
    "nemaidelirând": "delira",
    "nemaidelirându": "delira",
    "deliranta": "delirant",
    "delirantă": "delirant",
    "delirante": "delirant",
    "delirantei": "delirant",
    "delirantele": "delirant",
    "delirantelor": "delirant",
    "deliranți": "delirant",
    "deliranții": "delirant",
    "deliranților": "delirant",
    "deliranto": "delirant",
    "delirantul": "delirant",
    "delirantule": "delirant",
    "delirantului": "delirant",
    "delirarea": "delirare",
    "delirareo": "delirare",
    "delirări": "delirare",
    "delirării": "delirare",
    "delirările": "delirare",
    "delirărilor": "delirare",
    "delirată": "delirat",
    "delirate": "delirat",
    "delirați": "delirat",
    "delnița": "delniță",
    "delnițe": "delniță",
    "delniței": "delniță",
    "delnițele": "delniță",
    "delnițelor": "delniță",
    "delnițo": "delniță",
    "Deltă": "Delta",
    "Delte": "Delta",
    "Deltei": "Delta",
    "delta": "deltă",
    "delte": "deltă",
    "deltei": "deltă",
    "deltele": "deltă",
    "deltelor": "deltă",
    "delto": "deltă",
    "deltoidul": "deltoid",
    "deltoidule": "deltoid",
    "deltoidului": "deltoid",
    "deltoizi": "deltoid",
    "deltoizii": "deltoid",
    "deltoizilor": "deltoid",
    "demul": "dem",
    "demagnetiză": "demagnetiza",
    "demagnetizai": "demagnetiza",
    "demagnetizam": "demagnetiza",
    "demagnetizăm": "demagnetiza",
    "demagnetizând": "demagnetiza",
    "demagnetizându": "demagnetiza",
    "demagnetizară": "demagnetiza",
    "demagnetizarăm": "demagnetiza",
    "demagnetizarăți": "demagnetiza",
    "demagnetizase": "demagnetiza",
    "demagnetizasem": "demagnetiza",
    "demagnetizaseră": "demagnetiza",
    "demagnetizaserăm": "demagnetiza",
    "demagnetizaserăți": "demagnetiza",
    "demagnetizaseși": "demagnetiza",
    "demagnetizași": "demagnetiza",
    "demagnetizat": "demagnetiza",
    "demagnetizați": "demagnetiza",
    "demagnetizatu": "demagnetiza",
    "demagnetizau": "demagnetiza",
    "demagnetizează": "demagnetiza",
    "demagnetizez": "demagnetiza",
    "demagnetizeze": "demagnetiza",
    "demagnetizezi": "demagnetiza",
    "nedemagnetizând": "demagnetiza",
    "nedemagnetizându": "demagnetiza",
    "nemaidemagnetizând": "demagnetiza",
    "nemaidemagnetizându": "demagnetiza",
    "demagnetizată": "demagnetizat",
    "demagnetizate": "demagnetizat",
    "demagnetizați": "demagnetizat",
    "demagogi": "demagog",
    "demagogii": "demagog",
    "demagogilor": "demagog",
    "demagogul": "demagog",
    "demagogule": "demagog",
    "demagogului": "demagog",
    "demagogica": "demagogic",
    "demagogică": "demagogic",
    "demagogice": "demagogic",
    "demagogicei": "demagogic",
    "demagogicele": "demagogic",
    "demagogicelor": "demagogic",
    "demagogici": "demagogic",
    "demagogicii": "demagogic",
    "demagogicilor": "demagogic",
    "demagogico": "demagogic",
    "demagogicul": "demagogic",
    "demagogicule": "demagogic",
    "demagogicului": "demagogic",
    "demară": "demara",
    "demarai": "demara",
    "demaram": "demara",
    "demarăm": "demara",
    "demarând": "demara",
    "demarându": "demara",
    "demarară": "demara",
    "demararăm": "demara",
    "demararăți": "demara",
    "demarase": "demara",
    "demarasem": "demara",
    "demaraseră": "demara",
    "demaraserăm": "demara",
    "demaraserăți": "demara",
    "demaraseși": "demara",
    "demarași": "demara",
    "demarat": "demara",
    "demarați": "demara",
    "demaratu": "demara",
    "demarau": "demara",
    "demarează": "demara",
    "demarez": "demara",
    "demareze": "demara",
    "demarezi": "demara",
    "nedemarând": "demara",
    "nedemarându": "demara",
    "nemaidemarând": "demara",
    "nemaidemarându": "demara",
    "demaraje": "demaraj",
    "demarajele": "demaraj",
    "demarajelor": "demaraj",
    "demarajul": "demaraj",
    "demarajule": "demaraj",
    "demarajului": "demaraj",
    "demararea": "demarare",
    "demarareo": "demarare",
    "demarări": "demarare",
    "demarării": "demarare",
    "demarările": "demarare",
    "demarărilor": "demarare",
    "demarată": "demarat",
    "demarate": "demarat",
    "demarați": "demarat",
    "demarcă": "demarca",
    "demarcai": "demarca",
    "demarcam": "demarca",
    "demarcăm": "demarca",
    "demarcând": "demarca",
    "demarcându": "demarca",
    "demarcară": "demarca",
    "demarcarăm": "demarca",
    "demarcarăți": "demarca",
    "demarcase": "demarca",
    "demarcasem": "demarca",
    "demarcaseră": "demarca",
    "demarcaserăm": "demarca",
    "demarcaserăți": "demarca",
    "demarcaseși": "demarca",
    "demarcași": "demarca",
    "demarcat": "demarca",
    "demarcați": "demarca",
    "demarcatu": "demarca",
    "demarcau": "demarca",
    "demarchează": "demarca",
    "demarchez": "demarca",
    "demarcheze": "demarca",
    "demarchezi": "demarca",
    "nedemarcând": "demarca",
    "nedemarcându": "demarca",
    "nemaidemarcând": "demarca",
    "nemaidemarcându": "demarca",
    "demarcarea": "demarcare",
    "demarcareo": "demarcare",
    "demarcări": "demarcare",
    "demarcării": "demarcare",
    "demarcările": "demarcare",
    "demarcărilor": "demarcare",
    "demarcată": "demarcat",
    "demarcate": "demarcat",
    "demarcați": "demarcat",
    "demarcația": "demarcație",
    "demarcației": "demarcație",
    "demarcații": "demarcație",
    "demarcațiile": "demarcație",
    "demarcațiilor": "demarcație",
    "demarcațio": "demarcație",
    "demaroare": "demaror",
    "demaroarele": "demaror",
    "demaroarelor": "demaror",
    "demarorul": "demaror",
    "demarorule": "demaror",
    "demarorului": "demaror",
    "demasc": "demasca",
    "demască": "demasca",
    "demascai": "demasca",
    "demascam": "demasca",
    "demascăm": "demasca",
    "demascând": "demasca",
    "demascându": "demasca",
    "demascară": "demasca",
    "demascarăm": "demasca",
    "demascarăți": "demasca",
    "demascase": "demasca",
    "demascasem": "demasca",
    "demascaseră": "demasca",
    "demascaserăm": "demasca",
    "demascaserăți": "demasca",
    "demascaseși": "demasca",
    "demascași": "demasca",
    "demascat": "demasca",
    "demascați": "demasca",
    "demascatu": "demasca",
    "demascau": "demasca",
    "demaște": "demasca",
    "demaști": "demasca",
    "nedemascând": "demasca",
    "nedemascându": "demasca",
    "nemaidemascând": "demasca",
    "nemaidemascându": "demasca",
    "demascarea": "demascare",
    "demascareo": "demascare",
    "demascări": "demascare",
    "demascării": "demascare",
    "demascările": "demascare",
    "demascărilor": "demascare",
    "demascată": "demascat",
    "demascate": "demascat",
    "demascați": "demascat",
    "demascatoarea": "demascatoare",
    "demascatoarei": "demascatoare",
    "demascatoarele": "demascatoare",
    "demascatoarelor": "demascatoare",
    "demascatoareo": "demascatoare",
    "demascatoare": "demascator",
    "demascatoarea": "demascator",
    "demascatoarei": "demascator",
    "demascatoarele": "demascator",
    "demascatoarelor": "demascator",
    "demascatoareo": "demascator",
    "demascatori": "demascator",
    "demascatorii": "demascator",
    "demascatorilor": "demascator",
    "demascatorul": "demascator",
    "demascatorule": "demascator",
    "demascatorului": "demascator",
    "dementa": "dement",
    "dementă": "dement",
    "demente": "dement",
    "dementei": "dement",
    "dementele": "dement",
    "dementelor": "dement",
    "demenți": "dement",
    "demenții": "dement",
    "demenților": "dement",
    "demento": "dement",
    "dementul": "dement",
    "dementule": "dement",
    "dementului": "dement",
    "dementa": "dementă",
    "demente": "dementă",
    "dementei": "dementă",
    "dementele": "dementă",
    "dementelor": "dementă",
    "demento": "dementă",
    "demența": "demență",
    "demențe": "demență",
    "demenței": "demență",
    "demențele": "demență",
    "demențelor": "demență",
    "demențo": "demență",
    "demersul": "demers",
    "demersule": "demers",
    "demersului": "demers",
    "demersuri": "demers",
    "demersurile": "demers",
    "demersurilor": "demers",
    "demilitariză": "demilitariza",
    "demilitarizai": "demilitariza",
    "demilitarizam": "demilitariza",
    "demilitarizăm": "demilitariza",
    "demilitarizând": "demilitariza",
    "demilitarizându": "demilitariza",
    "demilitarizară": "demilitariza",
    "demilitarizarăm": "demilitariza",
    "demilitarizarăți": "demilitariza",
    "demilitarizase": "demilitariza",
    "demilitarizasem": "demilitariza",
    "demilitarizaseră": "demilitariza",
    "demilitarizaserăm": "demilitariza",
    "demilitarizaserăți": "demilitariza",
    "demilitarizaseși": "demilitariza",
    "demilitarizași": "demilitariza",
    "demilitarizat": "demilitariza",
    "demilitarizați": "demilitariza",
    "demilitarizatu": "demilitariza",
    "demilitarizau": "demilitariza",
    "demilitarizează": "demilitariza",
    "demilitarizez": "demilitariza",
    "demilitarizeze": "demilitariza",
    "demilitarizezi": "demilitariza",
    "nedemilitarizând": "demilitariza",
    "nedemilitarizându": "demilitariza",
    "nemaidemilitarizând": "demilitariza",
    "nemaidemilitarizându": "demilitariza",
    "demilitarizarea": "demilitarizare",
    "demilitarizareo": "demilitarizare",
    "demilitarizări": "demilitarizare",
    "demilitarizării": "demilitarizare",
    "demilitarizările": "demilitarizare",
    "demilitarizărilor": "demilitarizare",
    "demilitarizata": "demilitarizat",
    "demilitarizată": "demilitarizat",
    "demilitarizate": "demilitarizat",
    "demilitarizatei": "demilitarizat",
    "demilitarizatele": "demilitarizat",
    "demilitarizatelor": "demilitarizat",
    "demilitarizați": "demilitarizat",
    "demilitarizații": "demilitarizat",
    "demilitarizaților": "demilitarizat",
    "demilitarizato": "demilitarizat",
    "demilitarizatul": "demilitarizat",
    "demilitarizatule": "demilitarizat",
    "demilitarizatului": "demilitarizat",
    "demineraliză": "demineraliza",
    "demineralizai": "demineraliza",
    "demineralizam": "demineraliza",
    "demineralizăm": "demineraliza",
    "demineralizând": "demineraliza",
    "demineralizându": "demineraliza",
    "demineralizară": "demineraliza",
    "demineralizarăm": "demineraliza",
    "demineralizarăți": "demineraliza",
    "demineralizase": "demineraliza",
    "demineralizasem": "demineraliza",
    "demineralizaseră": "demineraliza",
    "demineralizaserăm": "demineraliza",
    "demineralizaserăți": "demineraliza",
    "demineralizaseși": "demineraliza",
    "demineralizași": "demineraliza",
    "demineralizat": "demineraliza",
    "demineralizați": "demineraliza",
    "demineralizatu": "demineraliza",
    "demineralizau": "demineraliza",
    "demineralizează": "demineraliza",
    "demineralizez": "demineraliza",
    "demineralizeze": "demineraliza",
    "demineralizezi": "demineraliza",
    "nedemineralizând": "demineraliza",
    "nedemineralizându": "demineraliza",
    "nemaidemineralizând": "demineraliza",
    "nemaidemineralizându": "demineraliza",
    "demineralizarea": "demineralizare",
    "demineralizareo": "demineralizare",
    "demineralizări": "demineralizare",
    "demineralizării": "demineralizare",
    "demineralizările": "demineralizare",
    "demineralizărilor": "demineralizare",
    "demineralizată": "demineralizat",
    "demineralizate": "demineralizat",
    "demineralizați": "demineralizat",
    "demisă": "demis",
    "demise": "demis",
    "demiși": "demis",
    "demisia": "demisie",
    "demisiei": "demisie",
    "demisii": "demisie",
    "demisiile": "demisie",
    "demisiilor": "demisie",
    "demisio": "demisie",
    "demisionă": "demisiona",
    "demisionai": "demisiona",
    "demisionam": "demisiona",
    "demisionăm": "demisiona",
    "demisionând": "demisiona",
    "demisionându": "demisiona",
    "demisionară": "demisiona",
    "demisionarăm": "demisiona",
    "demisionarăți": "demisiona",
    "demisionase": "demisiona",
    "demisionasem": "demisiona",
    "demisionaseră": "demisiona",
    "demisionaserăm": "demisiona",
    "demisionaserăți": "demisiona",
    "demisionaseși": "demisiona",
    "demisionași": "demisiona",
    "demisionat": "demisiona",
    "demisionați": "demisiona",
    "demisionatu": "demisiona",
    "demisionau": "demisiona",
    "demisionează": "demisiona",
    "demisionez": "demisiona",
    "demisioneze": "demisiona",
    "demisionezi": "demisiona",
    "nedemisionând": "demisiona",
    "nedemisionându": "demisiona",
    "nemaidemisionând": "demisiona",
    "nemaidemisionându": "demisiona",
    "demisionată": "demisionat",
    "demisionate": "demisionat",
    "demisionați": "demisionat",
    "demisolul": "demisol",
    "demisolule": "demisol",
    "demisolului": "demisol",
    "demisoluri": "demisol",
    "demisolurile": "demisol",
    "demisolurilor": "demisol",
    "demis": "demite",
    "demise": "demite",
    "demisei": "demite",
    "demiseră": "demite",
    "demiserăm": "demite",
    "demiserăți": "demite",
    "demisese": "demite",
    "demisesem": "demite",
    "demiseseră": "demite",
    "demiseserăm": "demite",
    "demiseserăți": "demite",
    "demiseseși": "demite",
    "demiseși": "demite",
    "demisu": "demite",
    "demit": "demite",
    "demită": "demite",
    "demițând": "demite",
    "demițându": "demite",
    "demitea": "demite",
    "demiteai": "demite",
    "demiteam": "demite",
    "demiteați": "demite",
    "demiteau": "demite",
    "demitem": "demite",
    "demiteți": "demite",
    "demiți": "demite",
    "nedemițând": "demite",
    "nedemițându": "demite",
    "nemaidemițând": "demite",
    "nemaidemițându": "demite",
    "demiterea": "demitere",
    "demitereo": "demitere",
    "demiteri": "demitere",
    "demiterii": "demitere",
    "demiterile": "demitere",
    "demiterilor": "demitere",
    "demiurgi": "demiurg",
    "demiurgii": "demiurg",
    "demiurgilor": "demiurg",
    "demiurgul": "demiurg",
    "demiurgule": "demiurg",
    "demiurgului": "demiurg",
    "demna": "demn",
    "demnă": "demn",
    "demne": "demn",
    "demnei": "demn",
    "demnele": "demn",
    "demnelor": "demn",
    "demni": "demn",
    "demnii": "demn",
    "demnilor": "demn",
    "demno": "demn",
    "demnul": "demn",
    "demnule": "demn",
    "demnului": "demn",
    "demnitari": "demnitar",
    "demnitarii": "demnitar",
    "demnitarilor": "demnitar",
    "demnitarul": "demnitar",
    "demnitarule": "demnitar",
    "demnitarului": "demnitar",
    "demnitatea": "demnitate",
    "demnitateo": "demnitate",
    "demnități": "demnitate",
    "demnității": "demnitate",
    "demnitățile": "demnitate",
    "demnităților": "demnitate",
    "demoazela": "demoazelă",
    "demoazele": "demoazelă",
    "demoazelei": "demoazelă",
    "demoazelele": "demoazelă",
    "demoazelelor": "demoazelă",
    "demoazelo": "demoazelă",
    "demobiliză": "demobiliza",
    "demobilizai": "demobiliza",
    "demobilizam": "demobiliza",
    "demobilizăm": "demobiliza",
    "demobilizând": "demobiliza",
    "demobilizându": "demobiliza",
    "demobilizară": "demobiliza",
    "demobilizarăm": "demobiliza",
    "demobilizarăți": "demobiliza",
    "demobilizase": "demobiliza",
    "demobilizasem": "demobiliza",
    "demobilizaseră": "demobiliza",
    "demobilizaserăm": "demobiliza",
    "demobilizaserăți": "demobiliza",
    "demobilizaseși": "demobiliza",
    "demobilizași": "demobiliza",
    "demobilizat": "demobiliza",
    "demobilizați": "demobiliza",
    "demobilizatu": "demobiliza",
    "demobilizau": "demobiliza",
    "demobilizează": "demobiliza",
    "demobilizez": "demobiliza",
    "demobilizeze": "demobiliza",
    "demobilizezi": "demobiliza",
    "nedemobilizând": "demobiliza",
    "nedemobilizându": "demobiliza",
    "nemaidemobilizând": "demobiliza",
    "nemaidemobilizându": "demobiliza",
    "demobilizarea": "demobilizare",
    "demobilizareo": "demobilizare",
    "demobilizări": "demobilizare",
    "demobilizării": "demobilizare",
    "demobilizările": "demobilizare",
    "demobilizărilor": "demobilizare",
    "demobilizata": "demobilizat",
    "demobilizată": "demobilizat",
    "demobilizate": "demobilizat",
    "demobilizatei": "demobilizat",
    "demobilizatele": "demobilizat",
    "demobilizatelor": "demobilizat",
    "demobilizați": "demobilizat",
    "demobilizații": "demobilizat",
    "demobilizaților": "demobilizat",
    "demobilizato": "demobilizat",
    "demobilizatul": "demobilizat",
    "demobilizatule": "demobilizat",
    "demobilizatului": "demobilizat",
    "demobilizata": "demobilizată",
    "demobilizate": "demobilizată",
    "demobilizatei": "demobilizată",
    "demobilizatele": "demobilizată",
    "demobilizatelor": "demobilizată",
    "demobilizato": "demobilizată",
    "demobilizatoare": "demobilizator",
    "demobilizatoarea": "demobilizator",
    "demobilizatoarei": "demobilizator",
    "demobilizatoarele": "demobilizator",
    "demobilizatoarelor": "demobilizator",
    "demobilizatoareo": "demobilizator",
    "demobilizatori": "demobilizator",
    "demobilizatorii": "demobilizator",
    "demobilizatorilor": "demobilizator",
    "demobilizatorul": "demobilizator",
    "demobilizatorule": "demobilizator",
    "demobilizatorului": "demobilizator",
    "democrata": "democrat",
    "democrată": "democrat",
    "democrate": "democrat",
    "democratei": "democrat",
    "democratele": "democrat",
    "democratelor": "democrat",
    "democrați": "democrat",
    "democrații": "democrat",
    "democraților": "democrat",
    "democrato": "democrat",
    "democratul": "democrat",
    "democratule": "democrat",
    "democratului": "democrat",
    "democratica": "democratic",
    "democratică": "democratic",
    "democratice": "democratic",
    "democraticei": "democratic",
    "democraticele": "democratic",
    "democraticelor": "democratic",
    "democratici": "democratic",
    "democraticii": "democratic",
    "democraticilor": "democratic",
    "democratico": "democratic",
    "democraticul": "democratic",
    "democraticule": "democratic",
    "democraticului": "democratic",
    "democrația": "democrație",
    "democrației": "democrație",
    "democrații": "democrație",
    "democrațiile": "democrație",
    "democrațiilor": "democrație",
    "democrațio": "democrație",
    "democratismul": "democratism",
    "democratismule": "democratism",
    "democratismului": "democratism",
    "democratiză": "democratiza",
    "democratizai": "democratiza",
    "democratizam": "democratiza",
    "democratizăm": "democratiza",
    "democratizând": "democratiza",
    "democratizându": "democratiza",
    "democratizară": "democratiza",
    "democratizarăm": "democratiza",
    "democratizarăți": "democratiza",
    "democratizase": "democratiza",
    "democratizasem": "democratiza",
    "democratizaseră": "democratiza",
    "democratizaserăm": "democratiza",
    "democratizaserăți": "democratiza",
    "democratizaseși": "democratiza",
    "democratizași": "democratiza",
    "democratizat": "democratiza",
    "democratizați": "democratiza",
    "democratizatu": "democratiza",
    "democratizau": "democratiza",
    "democratizează": "democratiza",
    "democratizez": "democratiza",
    "democratizeze": "democratiza",
    "democratizezi": "democratiza",
    "nedemocratizând": "democratiza",
    "nedemocratizându": "democratiza",
    "nemaidemocratizând": "democratiza",
    "nemaidemocratizându": "democratiza",
    "democratizarea": "democratizare",
    "democratizareo": "democratizare",
    "democratizări": "democratizare",
    "democratizării": "democratizare",
    "democratizările": "democratizare",
    "democratizărilor": "democratizare",
    "democratizată": "democratizat",
    "democratizate": "democratizat",
    "democratizați": "democratizat",
    "demodă": "demoda",
    "demodai": "demoda",
    "demodam": "demoda",
    "demodăm": "demoda",
    "demodând": "demoda",
    "demodându": "demoda",
    "demodară": "demoda",
    "demodarăm": "demoda",
    "demodarăți": "demoda",
    "demodase": "demoda",
    "demodasem": "demoda",
    "demodaseră": "demoda",
    "demodaserăm": "demoda",
    "demodaserăți": "demoda",
    "demodaseși": "demoda",
    "demodași": "demoda",
    "demodat": "demoda",
    "demodați": "demoda",
    "demodatu": "demoda",
    "demodau": "demoda",
    "demodează": "demoda",
    "demodez": "demoda",
    "demodeze": "demoda",
    "demodezi": "demoda",
    "nedemodând": "demoda",
    "nedemodându": "demoda",
    "nemaidemodând": "demoda",
    "nemaidemodându": "demoda",
    "demodarea": "demodare",
    "demodareo": "demodare",
    "demodări": "demodare",
    "demodării": "demodare",
    "demodările": "demodare",
    "demodărilor": "demodare",
    "demodata": "demodat",
    "demodată": "demodat",
    "demodate": "demodat",
    "demodatei": "demodat",
    "demodatele": "demodat",
    "demodatelor": "demodat",
    "demodați": "demodat",
    "demodații": "demodat",
    "demodaților": "demodat",
    "demodato": "demodat",
    "demodatul": "demodat",
    "demodatule": "demodat",
    "demodatului": "demodat",
    "demografi": "demograf",
    "demografii": "demograf",
    "demografilor": "demograf",
    "demograful": "demograf",
    "demografule": "demograf",
    "demografului": "demograf",
    "demografica": "demografic",
    "demografică": "demografic",
    "demografice": "demografic",
    "demograficei": "demografic",
    "demograficele": "demografic",
    "demograficelor": "demografic",
    "demografici": "demografic",
    "demograficii": "demografic",
    "demograficilor": "demografic",
    "demografico": "demografic",
    "demograficul": "demografic",
    "demograficule": "demografic",
    "demograficului": "demografic",
    "demolă": "demola",
    "demolai": "demola",
    "demolam": "demola",
    "demolăm": "demola",
    "demolând": "demola",
    "demolându": "demola",
    "demolară": "demola",
    "demolarăm": "demola",
    "demolarăți": "demola",
    "demolase": "demola",
    "demolasem": "demola",
    "demolaseră": "demola",
    "demolaserăm": "demola",
    "demolaserăți": "demola",
    "demolaseși": "demola",
    "demolași": "demola",
    "demolat": "demola",
    "demolați": "demola",
    "demolatu": "demola",
    "demolau": "demola",
    "demolează": "demola",
    "demolez": "demola",
    "demoleze": "demola",
    "demolezi": "demola",
    "nedemolând": "demola",
    "nedemolându": "demola",
    "nemaidemolând": "demola",
    "nemaidemolându": "demola",
    "demolarea": "demolare",
    "demolareo": "demolare",
    "demolări": "demolare",
    "demolării": "demolare",
    "demolările": "demolare",
    "demolărilor": "demolare",
    "demolată": "demolat",
    "demolate": "demolat",
    "demolați": "demolat",
    "demolatoarea": "demolatoare",
    "demolatoarei": "demolatoare",
    "demolatoarele": "demolatoare",
    "demolatoarelor": "demolatoare",
    "demolatoareo": "demolatoare",
    "demolatoare": "demolator",
    "demolatoarea": "demolator",
    "demolatoarei": "demolator",
    "demolatoarele": "demolator",
    "demolatoarelor": "demolator",
    "demolatoareo": "demolator",
    "demolatori": "demolator",
    "demolatorii": "demolator",
    "demolatorilor": "demolator",
    "demolatorul": "demolator",
    "demolatorule": "demolator",
    "demolatorului": "demolator",
    "demoni": "demon",
    "demonii": "demon",
    "demonilor": "demon",
    "demonul": "demon",
    "demonule": "demon",
    "demonului": "demon",
    "demonetiză": "demonetiza",
    "demonetizai": "demonetiza",
    "demonetizam": "demonetiza",
    "demonetizăm": "demonetiza",
    "demonetizând": "demonetiza",
    "demonetizându": "demonetiza",
    "demonetizară": "demonetiza",
    "demonetizarăm": "demonetiza",
    "demonetizarăți": "demonetiza",
    "demonetizase": "demonetiza",
    "demonetizasem": "demonetiza",
    "demonetizaseră": "demonetiza",
    "demonetizaserăm": "demonetiza",
    "demonetizaserăți": "demonetiza",
    "demonetizaseși": "demonetiza",
    "demonetizași": "demonetiza",
    "demonetizat": "demonetiza",
    "demonetizați": "demonetiza",
    "demonetizatu": "demonetiza",
    "demonetizau": "demonetiza",
    "demonetizează": "demonetiza",
    "demonetizez": "demonetiza",
    "demonetizeze": "demonetiza",
    "demonetizezi": "demonetiza",
    "nedemonetizând": "demonetiza",
    "nedemonetizându": "demonetiza",
    "nemaidemonetizând": "demonetiza",
    "nemaidemonetizându": "demonetiza",
    "demonetizarea": "demonetizare",
    "demonetizareo": "demonetizare",
    "demonetizări": "demonetizare",
    "demonetizării": "demonetizare",
    "demonetizările": "demonetizare",
    "demonetizărilor": "demonetizare",
    "demonetizată": "demonetizat",
    "demonetizate": "demonetizat",
    "demonetizați": "demonetizat",
    "demoniaca": "demoniac",
    "demoniacă": "demoniac",
    "demoniace": "demoniac",
    "demoniacei": "demoniac",
    "demoniacele": "demoniac",
    "demoniacelor": "demoniac",
    "demoniaci": "demoniac",
    "demoniacii": "demoniac",
    "demoniacilor": "demoniac",
    "demoniaco": "demoniac",
    "demoniacul": "demoniac",
    "demoniacule": "demoniac",
    "demoniacului": "demoniac",
    "demonica": "demonic",
    "demonică": "demonic",
    "demonice": "demonic",
    "demonicei": "demonic",
    "demonicele": "demonic",
    "demonicelor": "demonic",
    "demonici": "demonic",
    "demonicii": "demonic",
    "demonicilor": "demonic",
    "demonico": "demonic",
    "demonicul": "demonic",
    "demonicule": "demonic",
    "demonicului": "demonic",
    "demonizarea": "demonizare",
    "demonizări": "demonizare",
    "demonizării": "demonizare",
    "demonizările": "demonizare",
    "demonizărilor": "demonizare",
    "demonstră": "demonstra",
    "demonstrai": "demonstra",
    "demonstram": "demonstra",
    "demonstrăm": "demonstra",
    "demonstrând": "demonstra",
    "demonstrându": "demonstra",
    "demonstrară": "demonstra",
    "demonstrarăm": "demonstra",
    "demonstrarăți": "demonstra",
    "demonstrase": "demonstra",
    "demonstrasem": "demonstra",
    "demonstraseră": "demonstra",
    "demonstraserăm": "demonstra",
    "demonstraserăți": "demonstra",
    "demonstraseși": "demonstra",
    "demonstrași": "demonstra",
    "demonstrat": "demonstra",
    "demonstrați": "demonstra",
    "demonstratu": "demonstra",
    "demonstrau": "demonstra",
    "demonstrează": "demonstra",
    "demonstrez": "demonstra",
    "demonstreze": "demonstra",
    "demonstrezi": "demonstra",
    "nedemonstrând": "demonstra",
    "nedemonstrându": "demonstra",
    "nemaidemonstrând": "demonstra",
    "nemaidemonstrându": "demonstra",
    "demonstrabila": "demonstrabil",
    "demonstrabilă": "demonstrabil",
    "demonstrabile": "demonstrabil",
    "demonstrabilei": "demonstrabil",
    "demonstrabilele": "demonstrabil",
    "demonstrabilelor": "demonstrabil",
    "demonstrabili": "demonstrabil",
    "demonstrabilii": "demonstrabil",
    "demonstrabililor": "demonstrabil",
    "demonstrabilo": "demonstrabil",
    "demonstrabilul": "demonstrabil",
    "demonstrabilule": "demonstrabil",
    "demonstrabilului": "demonstrabil",
    "demonstranți": "demonstrant",
    "demonstranții": "demonstrant",
    "demonstranților": "demonstrant",
    "demonstrantul": "demonstrant",
    "demonstrantule": "demonstrant",
    "demonstrantului": "demonstrant",
    "demonstranta": "demonstrantă",
    "demonstrante": "demonstrantă",
    "demonstrantei": "demonstrantă",
    "demonstrantele": "demonstrantă",
    "demonstrantelor": "demonstrantă",
    "demonstranto": "demonstrantă",
    "demonstrarea": "demonstrare",
    "demonstrareo": "demonstrare",
    "demonstrări": "demonstrare",
    "demonstrării": "demonstrare",
    "demonstrările": "demonstrare",
    "demonstrărilor": "demonstrare",
    "demonstrată": "demonstrat",
    "demonstrate": "demonstrat",
    "demonstrați": "demonstrat",
    "demonstrația": "demonstrație",
    "demonstrației": "demonstrație",
    "demonstrații": "demonstrație",
    "demonstrațiile": "demonstrație",
    "demonstrațiilor": "demonstrație",
    "demonstrațio": "demonstrație",
    "demonstrativa": "demonstrativ",
    "demonstrativă": "demonstrativ",
    "demonstrative": "demonstrativ",
    "demonstrativei": "demonstrativ",
    "demonstrativele": "demonstrativ",
    "demonstrativelor": "demonstrativ",
    "demonstrativi": "demonstrativ",
    "demonstrativii": "demonstrativ",
    "demonstrativilor": "demonstrativ",
    "demonstrativo": "demonstrativ",
    "demonstrativul": "demonstrativ",
    "demonstrativule": "demonstrativ",
    "demonstrativului": "demonstrativ",
    "demontă": "demonta",
    "demontai": "demonta",
    "demontam": "demonta",
    "demontăm": "demonta",
    "demontând": "demonta",
    "demontându": "demonta",
    "demontară": "demonta",
    "demontarăm": "demonta",
    "demontarăți": "demonta",
    "demontase": "demonta",
    "demontasem": "demonta",
    "demontaseră": "demonta",
    "demontaserăm": "demonta",
    "demontaserăți": "demonta",
    "demontaseși": "demonta",
    "demontași": "demonta",
    "demontat": "demonta",
    "demontați": "demonta",
    "demontatu": "demonta",
    "demontau": "demonta",
    "demontează": "demonta",
    "demontez": "demonta",
    "demonteze": "demonta",
    "demontezi": "demonta",
    "nedemontând": "demonta",
    "nedemontându": "demonta",
    "nemaidemontând": "demonta",
    "nemaidemontându": "demonta",
    "demontabila": "demontabil",
    "demontabilă": "demontabil",
    "demontabile": "demontabil",
    "demontabilei": "demontabil",
    "demontabilele": "demontabil",
    "demontabilelor": "demontabil",
    "demontabili": "demontabil",
    "demontabilii": "demontabil",
    "demontabililor": "demontabil",
    "demontabilo": "demontabil",
    "demontabilul": "demontabil",
    "demontabilule": "demontabil",
    "demontabilului": "demontabil",
    "demontarea": "demontare",
    "demontareo": "demontare",
    "demontări": "demontare",
    "demontării": "demontare",
    "demontările": "demontare",
    "demontărilor": "demontare",
    "demontată": "demontat",
    "demontate": "demontat",
    "demontați": "demontat",
    "demontatul": "demontat",
    "demontatule": "demontat",
    "demontatului": "demontat",
    "demoraliză": "demoraliza",
    "demoralizai": "demoraliza",
    "demoralizam": "demoraliza",
    "demoralizăm": "demoraliza",
    "demoralizând": "demoraliza",
    "demoralizându": "demoraliza",
    "demoralizară": "demoraliza",
    "demoralizarăm": "demoraliza",
    "demoralizarăți": "demoraliza",
    "demoralizase": "demoraliza",
    "demoralizasem": "demoraliza",
    "demoralizaseră": "demoraliza",
    "demoralizaserăm": "demoraliza",
    "demoralizaserăți": "demoraliza",
    "demoralizaseși": "demoraliza",
    "demoralizași": "demoraliza",
    "demoralizat": "demoraliza",
    "demoralizați": "demoraliza",
    "demoralizatu": "demoraliza",
    "demoralizau": "demoraliza",
    "demoralizează": "demoraliza",
    "demoralizez": "demoraliza",
    "demoralizeze": "demoraliza",
    "demoralizezi": "demoraliza",
    "nedemoralizând": "demoraliza",
    "nedemoralizându": "demoraliza",
    "nemaidemoralizând": "demoraliza",
    "nemaidemoralizându": "demoraliza",
    "demoralizarea": "demoralizare",
    "demoralizareo": "demoralizare",
    "demoralizări": "demoralizare",
    "demoralizării": "demoralizare",
    "demoralizările": "demoralizare",
    "demoralizărilor": "demoralizare",
    "demoralizata": "demoralizat",
    "demoralizată": "demoralizat",
    "demoralizate": "demoralizat",
    "demoralizatei": "demoralizat",
    "demoralizatele": "demoralizat",
    "demoralizatelor": "demoralizat",
    "demoralizați": "demoralizat",
    "demoralizații": "demoralizat",
    "demoralizaților": "demoralizat",
    "demoralizato": "demoralizat",
    "demoralizatul": "demoralizat",
    "demoralizatule": "demoralizat",
    "demoralizatului": "demoralizat",
    "demoralizatoare": "demoralizator",
    "demoralizatoarea": "demoralizator",
    "demoralizatoarei": "demoralizator",
    "demoralizatoarele": "demoralizator",
    "demoralizatoarelor": "demoralizator",
    "demoralizatoareo": "demoralizator",
    "demoralizatori": "demoralizator",
    "demoralizatorii": "demoralizator",
    "demoralizatorilor": "demoralizator",
    "demoralizatorul": "demoralizator",
    "demoralizatorule": "demoralizator",
    "demoralizatorului": "demoralizator",
    "demotică": "demotic",
    "demotice": "demotic",
    "demotica": "demotică",
    "demotice": "demotică",
    "demoticei": "demotică",
    "demultiplic": "demultiplica",
    "demultiplică": "demultiplica",
    "demultiplicai": "demultiplica",
    "demultiplicam": "demultiplica",
    "demultiplicăm": "demultiplica",
    "demultiplicând": "demultiplica",
    "demultiplicându": "demultiplica",
    "demultiplicară": "demultiplica",
    "demultiplicarăm": "demultiplica",
    "demultiplicarăți": "demultiplica",
    "demultiplicase": "demultiplica",
    "demultiplicasem": "demultiplica",
    "demultiplicaseră": "demultiplica",
    "demultiplicaserăm": "demultiplica",
    "demultiplicaserăți": "demultiplica",
    "demultiplicaseși": "demultiplica",
    "demultiplicași": "demultiplica",
    "demultiplicat": "demultiplica",
    "demultiplicați": "demultiplica",
    "demultiplicatu": "demultiplica",
    "demultiplicau": "demultiplica",
    "demultiplice": "demultiplica",
    "demultiplici": "demultiplica",
    "nedemultiplicând": "demultiplica",
    "nedemultiplicându": "demultiplica",
    "nemaidemultiplicând": "demultiplica",
    "nemaidemultiplicându": "demultiplica",
    "demultiplicarea": "demultiplicare",
    "demultiplicareo": "demultiplicare",
    "demultiplicări": "demultiplicare",
    "demultiplicării": "demultiplicare",
    "demultiplicările": "demultiplicare",
    "demultiplicărilor": "demultiplicare",
    "demultiplicată": "demultiplicat",
    "demultiplicate": "demultiplicat",
    "demultiplicați": "demultiplicat",
    "denatură": "denatura",
    "denaturai": "denatura",
    "denaturam": "denatura",
    "denaturăm": "denatura",
    "denaturând": "denatura",
    "denaturându": "denatura",
    "denaturară": "denatura",
    "denaturarăm": "denatura",
    "denaturarăți": "denatura",
    "denaturase": "denatura",
    "denaturasem": "denatura",
    "denaturaseră": "denatura",
    "denaturaserăm": "denatura",
    "denaturaserăți": "denatura",
    "denaturaseși": "denatura",
    "denaturași": "denatura",
    "denaturat": "denatura",
    "denaturați": "denatura",
    "denaturatu": "denatura",
    "denaturau": "denatura",
    "denaturează": "denatura",
    "denaturez": "denatura",
    "denatureze": "denatura",
    "denaturezi": "denatura",
    "nedenaturând": "denatura",
    "nedenaturându": "denatura",
    "nemaidenaturând": "denatura",
    "nemaidenaturându": "denatura",
    "denaturante": "denaturant",
    "denaturantele": "denaturant",
    "denaturantelor": "denaturant",
    "denaturantul": "denaturant",
    "denaturantule": "denaturant",
    "denaturantului": "denaturant",
    "denaturarea": "denaturare",
    "denaturareo": "denaturare",
    "denaturări": "denaturare",
    "denaturării": "denaturare",
    "denaturările": "denaturare",
    "denaturărilor": "denaturare",
    "denaturata": "denaturat",
    "denaturată": "denaturat",
    "denaturate": "denaturat",
    "denaturatei": "denaturat",
    "denaturatele": "denaturat",
    "denaturatelor": "denaturat",
    "denaturați": "denaturat",
    "denaturații": "denaturat",
    "denaturaților": "denaturat",
    "denaturato": "denaturat",
    "denaturatul": "denaturat",
    "denaturatule": "denaturat",
    "denaturatului": "denaturat",
    "dendrita": "dendrită",
    "dendrite": "dendrită",
    "dendritei": "dendrită",
    "dendritele": "dendrită",
    "dendritelor": "dendrită",
    "dendrito": "dendrită",
    "dendritica": "dendritic",
    "dendritică": "dendritic",
    "dendritice": "dendritic",
    "dendriticei": "dendritic",
    "dendriticele": "dendritic",
    "dendriticelor": "dendritic",
    "dendritici": "dendritic",
    "dendriticii": "dendritic",
    "dendriticilor": "dendritic",
    "dendritico": "dendritic",
    "dendriticul": "dendritic",
    "dendriticule": "dendritic",
    "dendriticului": "dendritic",
    "dendrografica": "dendrografic",
    "dendrografică": "dendrografic",
    "dendrografice": "dendrografic",
    "dendrograficei": "dendrografic",
    "dendrograficele": "dendrografic",
    "dendrograficelor": "dendrografic",
    "dendrografici": "dendrografic",
    "dendrograficii": "dendrografic",
    "dendrograficilor": "dendrografic",
    "dendrografico": "dendrografic",
    "dendrograficul": "dendrografic",
    "dendrograficule": "dendrografic",
    "dendrograficului": "dendrografic",
    "dendrografia": "dendrografie",
    "dendrografiei": "dendrografie",
    "dendrografii": "dendrografie",
    "dendrografiile": "dendrografie",
    "dendrografiilor": "dendrografie",
    "dendrografio": "dendrografie",
    "denicotiniză": "denicotiniza",
    "denicotinizai": "denicotiniza",
    "denicotinizam": "denicotiniza",
    "denicotinizăm": "denicotiniza",
    "denicotinizând": "denicotiniza",
    "denicotinizându": "denicotiniza",
    "denicotinizară": "denicotiniza",
    "denicotinizarăm": "denicotiniza",
    "denicotinizarăți": "denicotiniza",
    "denicotinizase": "denicotiniza",
    "denicotinizasem": "denicotiniza",
    "denicotinizaseră": "denicotiniza",
    "denicotinizaserăm": "denicotiniza",
    "denicotinizaserăți": "denicotiniza",
    "denicotinizaseși": "denicotiniza",
    "denicotinizași": "denicotiniza",
    "denicotinizat": "denicotiniza",
    "denicotinizați": "denicotiniza",
    "denicotinizatu": "denicotiniza",
    "denicotinizau": "denicotiniza",
    "denicotinizează": "denicotiniza",
    "denicotinizez": "denicotiniza",
    "denicotinizeze": "denicotiniza",
    "denicotinizezi": "denicotiniza",
    "nedenicotinizând": "denicotiniza",
    "nedenicotinizându": "denicotiniza",
    "nemaidenicotinizând": "denicotiniza",
    "nemaidenicotinizându": "denicotiniza",
    "denicotinizarea": "denicotinizare",
    "denicotinizareo": "denicotinizare",
    "denicotinizări": "denicotinizare",
    "denicotinizării": "denicotinizare",
    "denicotinizările": "denicotinizare",
    "denicotinizărilor": "denicotinizare",
    "denicotinizata": "denicotinizat",
    "denicotinizată": "denicotinizat",
    "denicotinizate": "denicotinizat",
    "denicotinizatei": "denicotinizat",
    "denicotinizatele": "denicotinizat",
    "denicotinizatelor": "denicotinizat",
    "denicotinizați": "denicotinizat",
    "denicotinizații": "denicotinizat",
    "denicotinizaților": "denicotinizat",
    "denicotinizato": "denicotinizat",
    "denicotinizatul": "denicotinizat",
    "denicotinizatule": "denicotinizat",
    "denicotinizatului": "denicotinizat",
    "denia": "denie",
    "deniei": "denie",
    "denii": "denie",
    "deniile": "denie",
    "deniilor": "denie",
    "denio": "denie",
    "denigră": "denigra",
    "denigrai": "denigra",
    "denigram": "denigra",
    "denigrăm": "denigra",
    "denigrând": "denigra",
    "denigrându": "denigra",
    "denigrară": "denigra",
    "denigrarăm": "denigra",
    "denigrarăți": "denigra",
    "denigrase": "denigra",
    "denigrasem": "denigra",
    "denigraseră": "denigra",
    "denigraserăm": "denigra",
    "denigraserăți": "denigra",
    "denigraseși": "denigra",
    "denigrași": "denigra",
    "denigrat": "denigra",
    "denigrați": "denigra",
    "denigratu": "denigra",
    "denigrau": "denigra",
    "denigrează": "denigra",
    "denigrez": "denigra",
    "denigreze": "denigra",
    "denigrezi": "denigra",
    "nedenigrând": "denigra",
    "nedenigrându": "denigra",
    "nemaidenigrând": "denigra",
    "nemaidenigrându": "denigra",
    "denigrarea": "denigrare",
    "denigrareo": "denigrare",
    "denigrări": "denigrare",
    "denigrării": "denigrare",
    "denigrările": "denigrare",
    "denigrărilor": "denigrare",
    "denigrată": "denigrat",
    "denigrate": "denigrat",
    "denigrați": "denigrat",
    "denigratoarea": "denigratoare",
    "denigratoarei": "denigratoare",
    "denigratoarele": "denigratoare",
    "denigratoarelor": "denigratoare",
    "denigratoareo": "denigratoare",
    "denigratori": "denigrator",
    "denigratorii": "denigrator",
    "denigratorilor": "denigrator",
    "denigratorul": "denigrator",
    "denigratorule": "denigrator",
    "denigratorului": "denigrator",
    "denivelă": "denivela",
    "denivelai": "denivela",
    "denivelam": "denivela",
    "denivelăm": "denivela",
    "denivelând": "denivela",
    "denivelându": "denivela",
    "denivelară": "denivela",
    "denivelarăm": "denivela",
    "denivelarăți": "denivela",
    "denivelase": "denivela",
    "denivelasem": "denivela",
    "denivelaseră": "denivela",
    "denivelaserăm": "denivela",
    "denivelaserăți": "denivela",
    "denivelaseși": "denivela",
    "denivelași": "denivela",
    "denivelat": "denivela",
    "denivelați": "denivela",
    "denivelatu": "denivela",
    "denivelau": "denivela",
    "denivelează": "denivela",
    "denivelez": "denivela",
    "deniveleze": "denivela",
    "denivelezi": "denivela",
    "nedenivelând": "denivela",
    "nedenivelându": "denivela",
    "nemaidenivelând": "denivela",
    "nemaidenivelându": "denivela",
    "denivelarea": "denivelare",
    "denivelareo": "denivelare",
    "denivelări": "denivelare",
    "denivelării": "denivelare",
    "denivelările": "denivelare",
    "denivelărilor": "denivelare",
    "denivelată": "denivelat",
    "denivelate": "denivelat",
    "denivelați": "denivelat",
    "denominativa": "denominativ",
    "denominativă": "denominativ",
    "denominative": "denominativ",
    "denominativei": "denominativ",
    "denominativele": "denominativ",
    "denominativelor": "denominativ",
    "denominativi": "denominativ",
    "denominativii": "denominativ",
    "denominativilor": "denominativ",
    "denominativo": "denominativ",
    "denominativul": "denominativ",
    "denominativule": "denominativ",
    "denominativului": "denominativ",
    "denotă": "denota",
    "denotai": "denota",
    "denotam": "denota",
    "denotăm": "denota",
    "denotând": "denota",
    "denotându": "denota",
    "denotară": "denota",
    "denotarăm": "denota",
    "denotarăți": "denota",
    "denotase": "denota",
    "denotasem": "denota",
    "denotaseră": "denota",
    "denotaserăm": "denota",
    "denotaserăți": "denota",
    "denotaseși": "denota",
    "denotași": "denota",
    "denotat": "denota",
    "denotați": "denota",
    "denotatu": "denota",
    "denotau": "denota",
    "denotează": "denota",
    "denotez": "denota",
    "denoteze": "denota",
    "denotezi": "denota",
    "nedenotând": "denota",
    "nedenotându": "denota",
    "nemaidenotând": "denota",
    "nemaidenotându": "denota",
    "denotată": "denotat",
    "denotate": "denotat",
    "denotați": "denotat",
    "densa": "dens",
    "densă": "dens",
    "dense": "dens",
    "densei": "dens",
    "densele": "dens",
    "denselor": "dens",
    "denși": "dens",
    "denșii": "dens",
    "denșilor": "dens",
    "denso": "dens",
    "densul": "dens",
    "densule": "dens",
    "densului": "dens",
    "densimetre": "densimetru",
    "densimetrele": "densimetru",
    "densimetrelor": "densimetru",
    "densimetrul": "densimetru",
    "densimetrule": "densimetru",
    "densimetrului": "densimetru",
    "densitatea": "densitate",
    "densitateo": "densitate",
    "densități": "densitate",
    "densității": "densitate",
    "densitățile": "densitate",
    "densităților": "densitate",
    "dentara": "dentar",
    "dentară": "dentar",
    "dentare": "dentar",
    "dentarei": "dentar",
    "dentarele": "dentar",
    "dentarelor": "dentar",
    "dentari": "dentar",
    "dentarii": "dentar",
    "dentarilor": "dentar",
    "dentaro": "dentar",
    "dentarul": "dentar",
    "dentarule": "dentar",
    "dentarului": "dentar",
    "dentiști": "dentist",
    "dentiștii": "dentist",
    "dentiștilor": "dentist",
    "dentistul": "dentist",
    "dentistule": "dentist",
    "dentistului": "dentist",
    "dentista": "dentistă",
    "dentiste": "dentistă",
    "dentistei": "dentistă",
    "dentistele": "dentistă",
    "dentistelor": "dentistă",
    "dentisto": "dentistă",
    "dentiția": "dentiție",
    "dentiției": "dentiție",
    "dentiții": "dentiție",
    "dentițiile": "dentiție",
    "dentițiilor": "dentiție",
    "dentițio": "dentiție",
    "denumea": "denumi",
    "denumeai": "denumi",
    "denumeam": "denumi",
    "denumească": "denumi",
    "denumeați": "denumi",
    "denumeau": "denumi",
    "denumesc": "denumi",
    "denumește": "denumi",
    "denumești": "denumi",
    "denumii": "denumi",
    "denumim": "denumi",
    "denumind": "denumi",
    "denumindu": "denumi",
    "denumiră": "denumi",
    "denumirăm": "denumi",
    "denumirăți": "denumi",
    "denumise": "denumi",
    "denumisem": "denumi",
    "denumiseră": "denumi",
    "denumiserăm": "denumi",
    "denumiserăți": "denumi",
    "denumiseși": "denumi",
    "denumiși": "denumi",
    "denumit": "denumi",
    "denumiți": "denumi",
    "denumitu": "denumi",
    "nedenumind": "denumi",
    "nedenumindu": "denumi",
    "nemaidenumind": "denumi",
    "nemaidenumindu": "denumi",
    "denumirea": "denumire",
    "denumireo": "denumire",
    "denumiri": "denumire",
    "denumirii": "denumire",
    "denumirile": "denumire",
    "denumirilor": "denumire",
    "denumita": "denumit",
    "denumită": "denumit",
    "denumite": "denumit",
    "denumitei": "denumit",
    "denumitele": "denumit",
    "denumitelor": "denumit",
    "denumiți": "denumit",
    "denumiții": "denumit",
    "denumiților": "denumit",
    "denumito": "denumit",
    "denumitul": "denumit",
    "denumitule": "denumit",
    "denumitului": "denumit",
    "denunțul": "denunț",
    "denunțule": "denunț",
    "denunțului": "denunț",
    "denunțuri": "denunț",
    "denunțurile": "denunț",
    "denunțurilor": "denunț",
    "denunț": "denunța",
    "denunță": "denunța",
    "denunțai": "denunța",
    "denunțam": "denunța",
    "denunțăm": "denunța",
    "denunțând": "denunța",
    "denunțându": "denunța",
    "denunțară": "denunța",
    "denunțarăm": "denunța",
    "denunțarăți": "denunța",
    "denunțase": "denunța",
    "denunțasem": "denunța",
    "denunțaseră": "denunța",
    "denunțaserăm": "denunța",
    "denunțaserăți": "denunța",
    "denunțaseși": "denunța",
    "denunțași": "denunța",
    "denunțat": "denunța",
    "denunțați": "denunța",
    "denunțatu": "denunța",
    "denunțau": "denunța",
    "denunțe": "denunța",
    "denunți": "denunța",
    "nedenunțând": "denunța",
    "nedenunțându": "denunța",
    "nemaidenunțând": "denunța",
    "nemaidenunțându": "denunța",
    "denunțarea": "denunțare",
    "denunțareo": "denunțare",
    "denunțări": "denunțare",
    "denunțării": "denunțare",
    "denunțările": "denunțare",
    "denunțărilor": "denunțare",
    "denunțată": "denunțat",
    "denunțate": "denunțat",
    "denunțați": "denunțat",
    "denunțătoarea": "denunțătoare",
    "denunțătoarei": "denunțătoare",
    "denunțătoarele": "denunțătoare",
    "denunțătoarelor": "denunțătoare",
    "denunțătoareo": "denunțătoare",
    "denunțători": "denunțător",
    "denunțătorii": "denunțător",
    "denunțătorilor": "denunțător",
    "denunțătorul": "denunțător",
    "denunțătorule": "denunțător",
    "denunțătorului": "denunțător",
    "Denverul": "Denver",
    "deoache": "deochea",
    "deoche": "deochea",
    "deocheai": "deochea",
    "deocheam": "deochea",
    "deocheară": "deochea",
    "deochearăm": "deochea",
    "deochearăți": "deochea",
    "deochease": "deochea",
    "deocheasem": "deochea",
    "deocheaseră": "deochea",
    "deocheaserăm": "deochea",
    "deocheaserăți": "deochea",
    "deocheaseși": "deochea",
    "deocheași": "deochea",
    "deocheat": "deochea",
    "deocheați": "deochea",
    "deocheatu": "deochea",
    "deocheau": "deochea",
    "deochem": "deochea",
    "deochi": "deochea",
    "deochind": "deochea",
    "deochindu": "deochea",
    "nedeochind": "deochea",
    "nedeochindu": "deochea",
    "nemaideochind": "deochea",
    "nemaideochindu": "deochea",
    "deocheata": "deocheat",
    "deocheată": "deocheat",
    "deocheate": "deocheat",
    "deocheatei": "deocheat",
    "deocheatele": "deocheat",
    "deocheatelor": "deocheat",
    "deocheați": "deocheat",
    "deocheații": "deocheat",
    "deocheaților": "deocheat",
    "deocheato": "deocheat",
    "deocheatul": "deocheat",
    "deocheatule": "deocheat",
    "deocheatului": "deocheat",
    "deochiul": "deochi",
    "deochiule": "deochi",
    "deochiului": "deochi",
    "deochiuri": "deochi",
    "deochiurile": "deochi",
    "deochiurilor": "deochi",
    "deosebea": "deosebi",
    "deosebeai": "deosebi",
    "deosebeam": "deosebi",
    "deosebească": "deosebi",
    "deosebeați": "deosebi",
    "deosebeau": "deosebi",
    "deosebesc": "deosebi",
    "deosebește": "deosebi",
    "deosebești": "deosebi",
    "deosebii": "deosebi",
    "deosebim": "deosebi",
    "deosebind": "deosebi",
    "deosebindu": "deosebi",
    "deosebiră": "deosebi",
    "deosebirăm": "deosebi",
    "deosebirăți": "deosebi",
    "deosebise": "deosebi",
    "deosebisem": "deosebi",
    "deosebiseră": "deosebi",
    "deosebiserăm": "deosebi",
    "deosebiserăți": "deosebi",
    "deosebiseși": "deosebi",
    "deosebiși": "deosebi",
    "deosebit": "deosebi",
    "deosebiți": "deosebi",
    "deosebitu": "deosebi",
    "nedeosebind": "deosebi",
    "nedeosebindu": "deosebi",
    "nemaideosebind": "deosebi",
    "nemaideosebindu": "deosebi",
    "deosebirea": "deosebire",
    "deosebireo": "deosebire",
    "deosebiri": "deosebire",
    "deosebirii": "deosebire",
    "deosebirile": "deosebire",
    "deosebirilor": "deosebire",
    "deosebita": "deosebit",
    "deosebită": "deosebit",
    "deosebite": "deosebit",
    "deosebitei": "deosebit",
    "deosebitele": "deosebit",
    "deosebitelor": "deosebit",
    "deosebiți": "deosebit",
    "deosebiții": "deosebit",
    "deosebiților": "deosebit",
    "deosebito": "deosebit",
    "deosebitul": "deosebit",
    "deosebitule": "deosebit",
    "deosebitului": "deosebit",
    "depană": "depana",
    "depanai": "depana",
    "depanam": "depana",
    "depanăm": "depana",
    "depanând": "depana",
    "depanându": "depana",
    "depanară": "depana",
    "depanarăm": "depana",
    "depanarăți": "depana",
    "depanase": "depana",
    "depanasem": "depana",
    "depanaseră": "depana",
    "depanaserăm": "depana",
    "depanaserăți": "depana",
    "depanaseși": "depana",
    "depanași": "depana",
    "depanat": "depana",
    "depanați": "depana",
    "depanatu": "depana",
    "depanau": "depana",
    "depanează": "depana",
    "depanez": "depana",
    "depaneze": "depana",
    "depanezi": "depana",
    "nedepanând": "depana",
    "nedepanându": "depana",
    "nemaidepanând": "depana",
    "nemaidepanându": "depana",
    "deapăn": "depăna",
    "deapănă": "depăna",
    "depănă": "depăna",
    "depănai": "depăna",
    "depănam": "depăna",
    "depănăm": "depăna",
    "depănând": "depăna",
    "depănându": "depăna",
    "depănară": "depăna",
    "depănarăm": "depăna",
    "depănarăți": "depăna",
    "depănase": "depăna",
    "depănasem": "depăna",
    "depănaseră": "depăna",
    "depănaserăm": "depăna",
    "depănaserăți": "depăna",
    "depănaseși": "depăna",
    "depănași": "depăna",
    "depănat": "depăna",
    "depănați": "depăna",
    "depănatu": "depăna",
    "depănau": "depăna",
    "depene": "depăna",
    "depeni": "depăna",
    "nedepănând": "depăna",
    "nedepănându": "depăna",
    "nemaidepănând": "depăna",
    "nemaidepănându": "depăna",
    "depanarea": "depanare",
    "depanareo": "depanare",
    "depanări": "depanare",
    "depanării": "depanare",
    "depanările": "depanare",
    "depanărilor": "depanare",
    "depănarea": "depănare",
    "depănareo": "depănare",
    "depănări": "depănare",
    "depănării": "depănare",
    "depănările": "depănare",
    "depănărilor": "depănare",
    "depanată": "depanat",
    "depanate": "depanat",
    "depanați": "depanat",
    "depănata": "depănat",
    "depănată": "depănat",
    "depănate": "depănat",
    "depănatei": "depănat",
    "depănatele": "depănat",
    "depănatelor": "depănat",
    "depănați": "depănat",
    "depănații": "depănat",
    "depănaților": "depănat",
    "depănato": "depănat",
    "depănatul": "depănat",
    "depănatule": "depănat",
    "depănatului": "depănat",
    "depănătoarea": "depănătoare",
    "depănătoarei": "depănătoare",
    "depănătoarele": "depănătoare",
    "depănătoarelor": "depănătoare",
    "depănătoareo": "depănătoare",
    "depănătoare": "depănător",
    "depănătoarele": "depănător",
    "depănătoarelor": "depănător",
    "depănători": "depănător",
    "depănătorii": "depănător",
    "depănătorilor": "depănător",
    "depănătorul": "depănător",
    "depănătorule": "depănător",
    "depănătorului": "depănător",
    "deparafină": "deparafina",
    "deparafinai": "deparafina",
    "deparafinam": "deparafina",
    "deparafinăm": "deparafina",
    "deparafinând": "deparafina",
    "deparafinându": "deparafina",
    "deparafinară": "deparafina",
    "deparafinarăm": "deparafina",
    "deparafinarăți": "deparafina",
    "deparafinase": "deparafina",
    "deparafinasem": "deparafina",
    "deparafinaseră": "deparafina",
    "deparafinaserăm": "deparafina",
    "deparafinaserăți": "deparafina",
    "deparafinaseși": "deparafina",
    "deparafinași": "deparafina",
    "deparafinat": "deparafina",
    "deparafinați": "deparafina",
    "deparafinatu": "deparafina",
    "deparafinau": "deparafina",
    "deparafinează": "deparafina",
    "deparafinez": "deparafina",
    "deparafineze": "deparafina",
    "deparafinezi": "deparafina",
    "nedeparafinând": "deparafina",
    "nedeparafinându": "deparafina",
    "nemaideparafinând": "deparafina",
    "nemaideparafinându": "deparafina",
    "deparafinarea": "deparafinare",
    "deparafinareo": "deparafinare",
    "deparafinări": "deparafinare",
    "deparafinării": "deparafinare",
    "deparafinările": "deparafinare",
    "deparafinărilor": "deparafinare",
    "deparafinata": "deparafinat",
    "deparafinată": "deparafinat",
    "deparafinate": "deparafinat",
    "deparafinatei": "deparafinat",
    "deparafinatele": "deparafinat",
    "deparafinatelor": "deparafinat",
    "deparafinați": "deparafinat",
    "deparafinații": "deparafinat",
    "deparafinaților": "deparafinat",
    "deparafinato": "deparafinat",
    "deparafinatul": "deparafinat",
    "deparafinatule": "deparafinat",
    "deparafinatului": "deparafinat",
    "deparazită": "deparazita",
    "deparazitai": "deparazita",
    "deparazitam": "deparazita",
    "deparazităm": "deparazita",
    "deparazitând": "deparazita",
    "deparazitându": "deparazita",
    "deparazitară": "deparazita",
    "deparazitarăm": "deparazita",
    "deparazitarăți": "deparazita",
    "deparazitase": "deparazita",
    "deparazitasem": "deparazita",
    "deparazitaseră": "deparazita",
    "deparazitaserăm": "deparazita",
    "deparazitaserăți": "deparazita",
    "deparazitaseși": "deparazita",
    "deparazitași": "deparazita",
    "deparazitat": "deparazita",
    "deparazitați": "deparazita",
    "deparazitatu": "deparazita",
    "deparazitau": "deparazita",
    "deparazitează": "deparazita",
    "deparazitez": "deparazita",
    "deparaziteze": "deparazita",
    "deparazitezi": "deparazita",
    "nedeparazitând": "deparazita",
    "nedeparazitându": "deparazita",
    "nemaideparazitând": "deparazita",
    "nemaideparazitându": "deparazita",
    "deparazitarea": "deparazitare",
    "deparazitareo": "deparazitare",
    "deparazitări": "deparazitare",
    "deparazitării": "deparazitare",
    "deparazitările": "deparazitare",
    "deparazitărilor": "deparazitare",
    "deparazitată": "deparazitat",
    "deparazitate": "deparazitat",
    "deparazitați": "deparazitat",
    "depărtă": "depărta",
    "depărtai": "depărta",
    "depărtam": "depărta",
    "depărtăm": "depărta",
    "depărtând": "depărta",
    "depărtându": "depărta",
    "depărtară": "depărta",
    "depărtarăm": "depărta",
    "depărtarăți": "depărta",
    "depărtase": "depărta",
    "depărtasem": "depărta",
    "depărtaseră": "depărta",
    "depărtaserăm": "depărta",
    "depărtaserăți": "depărta",
    "depărtaseși": "depărta",
    "depărtași": "depărta",
    "depărtat": "depărta",
    "depărtați": "depărta",
    "depărtatu": "depărta",
    "depărtau": "depărta",
    "depărtează": "depărta",
    "depărtez": "depărta",
    "depărteze": "depărta",
    "depărtezi": "depărta",
    "nedepărtând": "depărta",
    "nedepărtându": "depărta",
    "nemaidepărtând": "depărta",
    "nemaidepărtându": "depărta",
    "departajarea": "departajare",
    "departajareo": "departajare",
    "departajări": "departajare",
    "departajării": "departajare",
    "departajările": "departajare",
    "departajărilor": "departajare",
    "departamente": "departament",
    "departamentele": "departament",
    "departamentelor": "departament",
    "departamentul": "departament",
    "departamentule": "departament",
    "departamentului": "departament",
    "depărtarea": "depărtare",
    "depărtareo": "depărtare",
    "depărtări": "depărtare",
    "depărtării": "depărtare",
    "depărtările": "depărtare",
    "depărtărilor": "depărtare",
    "depărtata": "depărtat",
    "depărtată": "depărtat",
    "depărtate": "depărtat",
    "depărtatei": "depărtat",
    "depărtatele": "depărtat",
    "depărtatelor": "depărtat",
    "depărtați": "depărtat",
    "depărtații": "depărtat",
    "depărtaților": "depărtat",
    "depărtato": "depărtat",
    "depărtatul": "depărtat",
    "depărtatule": "depărtat",
    "depărtatului": "depărtat",
    "depășea": "depăși",
    "depășeai": "depăși",
    "depășeam": "depăși",
    "depășească": "depăși",
    "depășeați": "depăși",
    "depășeau": "depăși",
    "depășesc": "depăși",
    "depășește": "depăși",
    "depășești": "depăși",
    "depășii": "depăși",
    "depășim": "depăși",
    "depășind": "depăși",
    "depășindu": "depăși",
    "depășiră": "depăși",
    "depășirăm": "depăși",
    "depășirăți": "depăși",
    "depășise": "depăși",
    "depășisei": "depăși",
    "depășisem": "depăși",
    "depășiseră": "depăși",
    "depășiserăm": "depăși",
    "depășiserăți": "depăși",
    "depășiseși": "depăși",
    "depășiși": "depăși",
    "depășit": "depăși",
    "depășiți": "depăși",
    "depășitu": "depăși",
    "nedepășind": "depăși",
    "nedepășindu": "depăși",
    "nemaidepășind": "depăși",
    "nemaidepășindu": "depăși",
    "depășirea": "depășire",
    "depășireo": "depășire",
    "depășiri": "depășire",
    "depășirii": "depășire",
    "depășirile": "depășire",
    "depășirilor": "depășire",
    "depășita": "depășit",
    "depășită": "depășit",
    "depășite": "depășit",
    "depășitei": "depășit",
    "depășitele": "depășit",
    "depășitelor": "depășit",
    "depășiți": "depășit",
    "depășiții": "depășit",
    "depășiților": "depășit",
    "depășito": "depășit",
    "depășitul": "depășit",
    "depășitule": "depășit",
    "depășitului": "depășit",
    "dependenta": "dependent",
    "dependentă": "dependent",
    "dependente": "dependent",
    "dependentei": "dependent",
    "dependentele": "dependent",
    "dependentelor": "dependent",
    "dependenți": "dependent",
    "dependenții": "dependent",
    "dependenților": "dependent",
    "dependento": "dependent",
    "dependentul": "dependent",
    "dependentule": "dependent",
    "dependentului": "dependent",
    "dependența": "dependență",
    "dependențe": "dependență",
    "dependenței": "dependență",
    "dependențele": "dependență",
    "dependențelor": "dependență",
    "dependențo": "dependență",
    "dependința": "dependință",
    "dependințe": "dependință",
    "dependinței": "dependință",
    "dependințele": "dependință",
    "dependințelor": "dependință",
    "dependințo": "dependință",
    "depersonaliză": "depersonaliza",
    "depersonalizai": "depersonaliza",
    "depersonalizam": "depersonaliza",
    "depersonalizăm": "depersonaliza",
    "depersonalizând": "depersonaliza",
    "depersonalizându": "depersonaliza",
    "depersonalizară": "depersonaliza",
    "depersonalizarăm": "depersonaliza",
    "depersonalizarăți": "depersonaliza",
    "depersonalizase": "depersonaliza",
    "depersonalizasem": "depersonaliza",
    "depersonalizaseră": "depersonaliza",
    "depersonalizaserăm": "depersonaliza",
    "depersonalizaserăți": "depersonaliza",
    "depersonalizaseși": "depersonaliza",
    "depersonalizași": "depersonaliza",
    "depersonalizat": "depersonaliza",
    "depersonalizați": "depersonaliza",
    "depersonalizatu": "depersonaliza",
    "depersonalizau": "depersonaliza",
    "depersonalizează": "depersonaliza",
    "depersonalizez": "depersonaliza",
    "depersonalizeze": "depersonaliza",
    "depersonalizezi": "depersonaliza",
    "depersonalizarea": "depersonalizare",
    "depersonalizareo": "depersonalizare",
    "depersonalizări": "depersonalizare",
    "depersonalizării": "depersonalizare",
    "depersonalizările": "depersonalizare",
    "depersonalizărilor": "depersonalizare",
    "depersonalizata": "depersonalizat",
    "depersonalizată": "depersonalizat",
    "depersonalizate": "depersonalizat",
    "depersonalizatei": "depersonalizat",
    "depersonalizatele": "depersonalizat",
    "depersonalizatelor": "depersonalizat",
    "depersonalizați": "depersonalizat",
    "depersonalizații": "depersonalizat",
    "depersonalizaților": "depersonalizat",
    "depersonalizato": "depersonalizat",
    "depersonalizatul": "depersonalizat",
    "depersonalizatule": "depersonalizat",
    "depersonalizatului": "depersonalizat",
    "depeșa": "depeșă",
    "depeșe": "depeșă",
    "depeșei": "depeșă",
    "depeșele": "depeșă",
    "depeșelor": "depeșă",
    "depeșo": "depeșă",
    "depilă": "depila",
    "depilai": "depila",
    "depilam": "depila",
    "depilăm": "depila",
    "depilând": "depila",
    "depilându": "depila",
    "depilară": "depila",
    "depilarăm": "depila",
    "depilarăți": "depila",
    "depilase": "depila",
    "depilasem": "depila",
    "depilaseră": "depila",
    "depilaserăm": "depila",
    "depilaserăți": "depila",
    "depilaseși": "depila",
    "depilași": "depila",
    "depilat": "depila",
    "depilați": "depila",
    "depilatu": "depila",
    "depilau": "depila",
    "depilează": "depila",
    "depilez": "depila",
    "depileze": "depila",
    "depilezi": "depila",
    "nedepilând": "depila",
    "nedepilându": "depila",
    "nemaidepilând": "depila",
    "nemaidepilându": "depila",
    "depilarea": "depilare",
    "depilareo": "depilare",
    "depilări": "depilare",
    "depilării": "depilare",
    "depilările": "depilare",
    "depilărilor": "depilare",
    "depilată": "depilat",
    "depilate": "depilat",
    "depilați": "depilat",
    "depilatoare": "depilator",
    "depilatoarele": "depilator",
    "depilatoarelor": "depilator",
    "depilatorul": "depilator",
    "depilatorule": "depilator",
    "depilatorului": "depilator",
    "depind": "depinde",
    "depindă": "depinde",
    "depindea": "depinde",
    "depindeai": "depinde",
    "depindeam": "depinde",
    "depindeați": "depinde",
    "depindeau": "depinde",
    "depindem": "depinde",
    "depindeți": "depinde",
    "depins": "depinde",
    "depinse": "depinde",
    "depinsei": "depinde",
    "depinseră": "depinde",
    "depinserăm": "depinde",
    "depinserăți": "depinde",
    "depinsese": "depinde",
    "depinsesem": "depinde",
    "depinseseră": "depinde",
    "depinseserăm": "depinde",
    "depinseserăți": "depinde",
    "depinseseși": "depinde",
    "depinseși": "depinde",
    "depinsu": "depinde",
    "depinzând": "depinde",
    "depinzându": "depinde",
    "depinzi": "depinde",
    "nedepinzând": "depinde",
    "nedepinzându": "depinde",
    "nemaidepinzând": "depinde",
    "nemaidepinzându": "depinde",
    "depinsă": "depins",
    "depinse": "depins",
    "depinși": "depins",
    "depistă": "depista",
    "depistai": "depista",
    "depistam": "depista",
    "depistăm": "depista",
    "depistând": "depista",
    "depistându": "depista",
    "depistară": "depista",
    "depistarăm": "depista",
    "depistarăți": "depista",
    "depistase": "depista",
    "depistasem": "depista",
    "depistaseră": "depista",
    "depistaserăm": "depista",
    "depistaserăți": "depista",
    "depistaseși": "depista",
    "depistași": "depista",
    "depistat": "depista",
    "depistați": "depista",
    "depistatu": "depista",
    "depistau": "depista",
    "depistează": "depista",
    "depistez": "depista",
    "depisteze": "depista",
    "depistezi": "depista",
    "nedepistând": "depista",
    "nedepistându": "depista",
    "nemaidepistând": "depista",
    "nemaidepistându": "depista",
    "depistarea": "depistare",
    "depistareo": "depistare",
    "depistări": "depistare",
    "depistării": "depistare",
    "depistările": "depistare",
    "depistărilor": "depistare",
    "depistată": "depistat",
    "depistate": "depistat",
    "depistați": "depistat",
    "deplâng": "deplânge",
    "deplângă": "deplânge",
    "deplângând": "deplânge",
    "deplângându": "deplânge",
    "deplângea": "deplânge",
    "deplângeai": "deplânge",
    "deplângeam": "deplânge",
    "deplângeați": "deplânge",
    "deplângeau": "deplânge",
    "deplângem": "deplânge",
    "deplângeți": "deplânge",
    "deplângi": "deplânge",
    "deplâns": "deplânge",
    "deplânse": "deplânge",
    "deplânsei": "deplânge",
    "deplânseră": "deplânge",
    "deplânserăm": "deplânge",
    "deplânserăți": "deplânge",
    "deplânsese": "deplânge",
    "deplânsesem": "deplânge",
    "deplânseseră": "deplânge",
    "deplânseserăm": "deplânge",
    "deplânseserăți": "deplânge",
    "deplânseseși": "deplânge",
    "deplânseși": "deplânge",
    "deplânsu": "deplânge",
    "deplânsă": "deplâns",
    "deplânse": "deplâns",
    "deplânși": "deplâns",
    "deplasă": "deplasa",
    "deplasai": "deplasa",
    "deplasam": "deplasa",
    "deplasăm": "deplasa",
    "deplasând": "deplasa",
    "deplasându": "deplasa",
    "deplasară": "deplasa",
    "deplasarăm": "deplasa",
    "deplasarăți": "deplasa",
    "deplasase": "deplasa",
    "deplasasem": "deplasa",
    "deplasaseră": "deplasa",
    "deplasaserăm": "deplasa",
    "deplasaserăți": "deplasa",
    "deplasaseși": "deplasa",
    "deplasași": "deplasa",
    "deplasat": "deplasa",
    "deplasați": "deplasa",
    "deplasatu": "deplasa",
    "deplasau": "deplasa",
    "deplasează": "deplasa",
    "deplasez": "deplasa",
    "deplaseze": "deplasa",
    "deplasezi": "deplasa",
    "nedeplasând": "deplasa",
    "nedeplasându": "deplasa",
    "nemaideplasând": "deplasa",
    "nemaideplasându": "deplasa",
    "deplasamente": "deplasament",
    "deplasamentele": "deplasament",
    "deplasamentelor": "deplasament",
    "deplasamentul": "deplasament",
    "deplasamentule": "deplasament",
    "deplasamentului": "deplasament",
    "deplasarea": "deplasare",
    "deplasareo": "deplasare",
    "deplasări": "deplasare",
    "deplasării": "deplasare",
    "deplasările": "deplasare",
    "deplasărilor": "deplasare",
    "deplasata": "deplasat",
    "deplasată": "deplasat",
    "deplasate": "deplasat",
    "deplasatei": "deplasat",
    "deplasatele": "deplasat",
    "deplasatelor": "deplasat",
    "deplasați": "deplasat",
    "deplasații": "deplasat",
    "deplasaților": "deplasat",
    "deplasato": "deplasat",
    "deplasatul": "deplasat",
    "deplasatule": "deplasat",
    "deplasatului": "deplasat",
    "deplina": "deplin",
    "deplină": "deplin",
    "depline": "deplin",
    "deplinei": "deplin",
    "deplinele": "deplin",
    "deplinelor": "deplin",
    "deplini": "deplin",
    "deplinii": "deplin",
    "deplinilor": "deplin",
    "deplino": "deplin",
    "deplinul": "deplin",
    "deplinule": "deplin",
    "deplinului": "deplin",
    "deplinătatea": "deplinătate",
    "deplinătateo": "deplinătate",
    "deplinătăți": "deplinătate",
    "deplinătății": "deplinătate",
    "deplinătățile": "deplinătate",
    "deplinătăților": "deplinătate",
    "deplor": "deplora",
    "deploră": "deplora",
    "deplorai": "deplora",
    "deploram": "deplora",
    "deplorăm": "deplora",
    "deplorând": "deplora",
    "deplorându": "deplora",
    "deplorară": "deplora",
    "deplorarăm": "deplora",
    "deplorarăți": "deplora",
    "deplorase": "deplora",
    "deplorasem": "deplora",
    "deploraseră": "deplora",
    "deploraserăm": "deplora",
    "deploraserăți": "deplora",
    "deploraseși": "deplora",
    "deplorași": "deplora",
    "deplorat": "deplora",
    "deplorați": "deplora",
    "deploratu": "deplora",
    "deplorau": "deplora",
    "deplore": "deplora",
    "deplori": "deplora",
    "nedeplorând": "deplora",
    "nedeplorându": "deplora",
    "nemaideplorând": "deplora",
    "nemaideplorându": "deplora",
    "deplorabila": "deplorabil",
    "deplorabilă": "deplorabil",
    "deplorabile": "deplorabil",
    "deplorabilei": "deplorabil",
    "deplorabilele": "deplorabil",
    "deplorabilelor": "deplorabil",
    "deplorabili": "deplorabil",
    "deplorabilii": "deplorabil",
    "deplorabililor": "deplorabil",
    "deplorabilo": "deplorabil",
    "deplorabilul": "deplorabil",
    "deplorabilule": "deplorabil",
    "deplorabilului": "deplorabil",
    "deplorată": "deplorat",
    "deplorate": "deplorat",
    "deplorați": "deplorat",
    "depolariză": "depolariza",
    "depolarizai": "depolariza",
    "depolarizam": "depolariza",
    "depolarizăm": "depolariza",
    "depolarizând": "depolariza",
    "depolarizându": "depolariza",
    "depolarizară": "depolariza",
    "depolarizarăm": "depolariza",
    "depolarizarăți": "depolariza",
    "depolarizase": "depolariza",
    "depolarizasem": "depolariza",
    "depolarizaseră": "depolariza",
    "depolarizaserăm": "depolariza",
    "depolarizaserăți": "depolariza",
    "depolarizaseși": "depolariza",
    "depolarizași": "depolariza",
    "depolarizat": "depolariza",
    "depolarizați": "depolariza",
    "depolarizatu": "depolariza",
    "depolarizau": "depolariza",
    "depolarizează": "depolariza",
    "depolarizez": "depolariza",
    "depolarizeze": "depolariza",
    "depolarizezi": "depolariza",
    "nedepolarizând": "depolariza",
    "nedepolarizându": "depolariza",
    "nemaidepolarizând": "depolariza",
    "nemaidepolarizându": "depolariza",
    "depolarizarea": "depolarizare",
    "depolarizareo": "depolarizare",
    "depolarizări": "depolarizare",
    "depolarizării": "depolarizare",
    "depolarizările": "depolarizare",
    "depolarizărilor": "depolarizare",
    "depolarizată": "depolarizat",
    "depolarizate": "depolarizat",
    "depolarizați": "depolarizat",
    "deponenta": "deponent",
    "deponentă": "deponent",
    "deponente": "deponent",
    "deponentei": "deponent",
    "deponentele": "deponent",
    "deponentelor": "deponent",
    "deponenți": "deponent",
    "deponenții": "deponent",
    "deponenților": "deponent",
    "deponento": "deponent",
    "deponentul": "deponent",
    "deponentule": "deponent",
    "deponentului": "deponent",
    "deponenta": "deponentă",
    "deponente": "deponentă",
    "deponentei": "deponentă",
    "deponentele": "deponentă",
    "deponentelor": "deponentă",
    "deponento": "deponentă",
    "depopulă": "depopula",
    "depopulai": "depopula",
    "depopulam": "depopula",
    "depopulăm": "depopula",
    "depopulând": "depopula",
    "depopulându": "depopula",
    "depopulară": "depopula",
    "depopularăm": "depopula",
    "depopularăți": "depopula",
    "depopulase": "depopula",
    "depopulasem": "depopula",
    "depopulaseră": "depopula",
    "depopulaserăm": "depopula",
    "depopulaserăți": "depopula",
    "depopulaseși": "depopula",
    "depopulași": "depopula",
    "depopulat": "depopula",
    "depopulați": "depopula",
    "depopulatu": "depopula",
    "depopulau": "depopula",
    "depopulează": "depopula",
    "depopulez": "depopula",
    "depopuleze": "depopula",
    "depopulezi": "depopula",
    "nedepopulând": "depopula",
    "nedepopulându": "depopula",
    "nemaidepopulând": "depopula",
    "nemaidepopulându": "depopula",
    "depopularea": "depopulare",
    "depopulareo": "depopulare",
    "depopulări": "depopulare",
    "depopulării": "depopulare",
    "depopulările": "depopulare",
    "depopulărilor": "depopulare",
    "depopulată": "depopulat",
    "depopulate": "depopulat",
    "depopulați": "depopulat",
    "deportă": "deporta",
    "deportai": "deporta",
    "deportam": "deporta",
    "deportăm": "deporta",
    "deportând": "deporta",
    "deportându": "deporta",
    "deportară": "deporta",
    "deportarăm": "deporta",
    "deportarăți": "deporta",
    "deportase": "deporta",
    "deportasem": "deporta",
    "deportaseră": "deporta",
    "deportaserăm": "deporta",
    "deportaserăți": "deporta",
    "deportaseși": "deporta",
    "deportași": "deporta",
    "deportat": "deporta",
    "deportați": "deporta",
    "deportatu": "deporta",
    "deportau": "deporta",
    "deportează": "deporta",
    "deportez": "deporta",
    "deporteze": "deporta",
    "deportezi": "deporta",
    "nedeportând": "deporta",
    "nedeportându": "deporta",
    "nemaideportând": "deporta",
    "nemaideportându": "deporta",
    "deportarea": "deportare",
    "deportareo": "deportare",
    "deportări": "deportare",
    "deportării": "deportare",
    "deportările": "deportare",
    "deportărilor": "deportare",
    "deportata": "deportat",
    "deportată": "deportat",
    "deportate": "deportat",
    "deportatei": "deportat",
    "deportatele": "deportat",
    "deportatelor": "deportat",
    "deportați": "deportat",
    "deportații": "deportat",
    "deportaților": "deportat",
    "deportato": "deportat",
    "deportatul": "deportat",
    "deportatule": "deportat",
    "deportatului": "deportat",
    "deportata": "deportată",
    "deportate": "deportată",
    "deportatei": "deportată",
    "deportatele": "deportată",
    "deportatelor": "deportată",
    "deportato": "deportată",
    "deposedă": "deposeda",
    "deposedai": "deposeda",
    "deposedam": "deposeda",
    "deposedăm": "deposeda",
    "deposedând": "deposeda",
    "deposedându": "deposeda",
    "deposedară": "deposeda",
    "deposedarăm": "deposeda",
    "deposedarăți": "deposeda",
    "deposedase": "deposeda",
    "deposedasem": "deposeda",
    "deposedaseră": "deposeda",
    "deposedaserăm": "deposeda",
    "deposedaserăți": "deposeda",
    "deposedaseși": "deposeda",
    "deposedași": "deposeda",
    "deposedat": "deposeda",
    "deposedați": "deposeda",
    "deposedatu": "deposeda",
    "deposedau": "deposeda",
    "deposedează": "deposeda",
    "deposedez": "deposeda",
    "deposedeze": "deposeda",
    "deposedezi": "deposeda",
    "nedeposedând": "deposeda",
    "nedeposedându": "deposeda",
    "nemaideposedând": "deposeda",
    "nemaideposedându": "deposeda",
    "deposedarea": "deposedare",
    "deposedareo": "deposedare",
    "deposedări": "deposedare",
    "deposedării": "deposedare",
    "deposedările": "deposedare",
    "deposedărilor": "deposedare",
    "deposedată": "deposedat",
    "deposedate": "deposedat",
    "deposedați": "deposedat",
    "depoul": "depou",
    "depoule": "depou",
    "depoului": "depou",
    "depouri": "depou",
    "depourile": "depou",
    "depourilor": "depou",
    "dep.": "depozit",
    "depozite": "depozit",
    "depozitele": "depozit",
    "depozitelor": "depozit",
    "depozitul": "depozit",
    "depozitule": "depozit",
    "depozitului": "depozit",
    "depozită": "depozita",
    "depozitai": "depozita",
    "depozitam": "depozita",
    "depozităm": "depozita",
    "depozitând": "depozita",
    "depozitându": "depozita",
    "depozitară": "depozita",
    "depozitarăm": "depozita",
    "depozitarăți": "depozita",
    "depozitase": "depozita",
    "depozitasem": "depozita",
    "depozitaseră": "depozita",
    "depozitaserăm": "depozita",
    "depozitaserăți": "depozita",
    "depozitaseși": "depozita",
    "depozitași": "depozita",
    "depozitat": "depozita",
    "depozitați": "depozita",
    "depozitatu": "depozita",
    "depozitau": "depozita",
    "depozitează": "depozita",
    "depozitez": "depozita",
    "depoziteze": "depozita",
    "depozitezi": "depozita",
    "nedepozitând": "depozita",
    "nedepozitându": "depozita",
    "nemaidepozitând": "depozita",
    "nemaidepozitându": "depozita",
    "depozitari": "depozitar",
    "depozitarii": "depozitar",
    "depozitarilor": "depozitar",
    "depozitarul": "depozitar",
    "depozitarule": "depozitar",
    "depozitarului": "depozitar",
    "depozitara": "depozitară",
    "depozitare": "depozitară",
    "depozitarei": "depozitară",
    "depozitarele": "depozitară",
    "depozitarelor": "depozitară",
    "depozitaro": "depozitară",
    "depozitarea": "depozitare",
    "depozitareo": "depozitare",
    "depozitări": "depozitare",
    "depozitării": "depozitare",
    "depozitările": "depozitare",
    "depozitărilor": "depozitare",
    "depozitată": "depozitat",
    "depozitate": "depozitat",
    "depozitați": "depozitat",
    "depoziția": "depoziție",
    "depoziției": "depoziție",
    "depoziții": "depoziție",
    "depozițiile": "depoziție",
    "depozițiilor": "depoziție",
    "depozițio": "depoziție",
    "depravă": "deprava",
    "depravai": "deprava",
    "depravam": "deprava",
    "depravăm": "deprava",
    "depravând": "deprava",
    "depravându": "deprava",
    "depravară": "deprava",
    "depravarăm": "deprava",
    "depravarăți": "deprava",
    "depravase": "deprava",
    "depravasem": "deprava",
    "depravaseră": "deprava",
    "depravaserăm": "deprava",
    "depravaserăți": "deprava",
    "depravaseși": "deprava",
    "depravași": "deprava",
    "depravat": "deprava",
    "depravați": "deprava",
    "depravatu": "deprava",
    "depravau": "deprava",
    "depravează": "deprava",
    "depravez": "deprava",
    "depraveze": "deprava",
    "depravezi": "deprava",
    "nedepravând": "deprava",
    "nedepravându": "deprava",
    "nemaidepravând": "deprava",
    "nemaidepravându": "deprava",
    "depravarea": "depravare",
    "depravareo": "depravare",
    "depravări": "depravare",
    "depravării": "depravare",
    "depravările": "depravare",
    "depravărilor": "depravare",
    "depravata": "depravat",
    "depravată": "depravat",
    "depravate": "depravat",
    "depravatei": "depravat",
    "depravatele": "depravat",
    "depravatelor": "depravat",
    "depravați": "depravat",
    "depravații": "depravat",
    "depravaților": "depravat",
    "depravato": "depravat",
    "depravatul": "depravat",
    "depravatule": "depravat",
    "depravatului": "depravat",
    "depravata": "depravată",
    "depravate": "depravată",
    "depravatei": "depravată",
    "depravatele": "depravată",
    "depravatelor": "depravată",
    "depravato": "depravată",
    "depreciai": "deprecia",
    "depreciam": "deprecia",
    "depreciară": "deprecia",
    "depreciarăm": "deprecia",
    "depreciarăți": "deprecia",
    "depreciase": "deprecia",
    "depreciasem": "deprecia",
    "depreciaseră": "deprecia",
    "depreciaserăm": "deprecia",
    "depreciaserăți": "deprecia",
    "depreciaseși": "deprecia",
    "depreciași": "deprecia",
    "depreciat": "deprecia",
    "depreciați": "deprecia",
    "depreciatu": "deprecia",
    "depreciau": "deprecia",
    "depreciază": "deprecia",
    "deprecie": "deprecia",
    "depreciem": "deprecia",
    "depreciez": "deprecia",
    "deprecieze": "deprecia",
    "depreciezi": "deprecia",
    "depreciind": "deprecia",
    "depreciindu": "deprecia",
    "nedepreciind": "deprecia",
    "nedepreciindu": "deprecia",
    "nemaidepreciind": "deprecia",
    "nemaidepreciindu": "deprecia",
    "depreciată": "depreciat",
    "depreciate": "depreciat",
    "depreciați": "depreciat",
    "depr.": "depreciativ",
    "depreciativa": "depreciativ",
    "depreciativă": "depreciativ",
    "depreciative": "depreciativ",
    "depreciativei": "depreciativ",
    "depreciativele": "depreciativ",
    "depreciativelor": "depreciativ",
    "depreciativi": "depreciativ",
    "depreciativii": "depreciativ",
    "depreciativilor": "depreciativ",
    "depreciativo": "depreciativ",
    "depreciativul": "depreciativ",
    "depreciativule": "depreciativ",
    "depreciativului": "depreciativ",
    "deprecierea": "depreciere",
    "depreciereo": "depreciere",
    "deprecieri": "depreciere",
    "deprecierii": "depreciere",
    "deprecierile": "depreciere",
    "deprecierilor": "depreciere",
    "depresă": "depresa",
    "depresai": "depresa",
    "depresam": "depresa",
    "depresăm": "depresa",
    "depresând": "depresa",
    "depresându": "depresa",
    "depresară": "depresa",
    "depresarăm": "depresa",
    "depresarăți": "depresa",
    "depresase": "depresa",
    "depresasem": "depresa",
    "depresaseră": "depresa",
    "depresaserăm": "depresa",
    "depresaserăți": "depresa",
    "depresaseși": "depresa",
    "depresași": "depresa",
    "depresat": "depresa",
    "depresați": "depresa",
    "depresatu": "depresa",
    "depresau": "depresa",
    "depresează": "depresa",
    "depresez": "depresa",
    "depreseze": "depresa",
    "depresezi": "depresa",
    "nedepresând": "depresa",
    "nedepresându": "depresa",
    "nemaidepresând": "depresa",
    "nemaidepresându": "depresa",
    "depresante": "depresant",
    "depresantele": "depresant",
    "depresantelor": "depresant",
    "depresantul": "depresant",
    "depresantule": "depresant",
    "depresantului": "depresant",
    "depresată": "depresat",
    "depresate": "depresat",
    "depresați": "depresat",
    "depresiunea": "depresiune",
    "depresiuneo": "depresiune",
    "depresiuni": "depresiune",
    "depresiunii": "depresiune",
    "depresiunile": "depresiune",
    "depresiunilor": "depresiune",
    "depresiva": "depresiv",
    "depresivă": "depresiv",
    "depresive": "depresiv",
    "depresivei": "depresiv",
    "depresivele": "depresiv",
    "depresivelor": "depresiv",
    "depresivi": "depresiv",
    "depresivii": "depresiv",
    "depresivilor": "depresiv",
    "depresivo": "depresiv",
    "depresivul": "depresiv",
    "depresivule": "depresiv",
    "depresivului": "depresiv",
    "deprim": "deprima",
    "deprimă": "deprima",
    "deprimai": "deprima",
    "deprimam": "deprima",
    "deprimăm": "deprima",
    "deprimând": "deprima",
    "deprimându": "deprima",
    "deprimară": "deprima",
    "deprimarăm": "deprima",
    "deprimarăți": "deprima",
    "deprimase": "deprima",
    "deprimasem": "deprima",
    "deprimaseră": "deprima",
    "deprimaserăm": "deprima",
    "deprimaserăți": "deprima",
    "deprimaseși": "deprima",
    "deprimași": "deprima",
    "deprimat": "deprima",
    "deprimați": "deprima",
    "deprimatu": "deprima",
    "deprimau": "deprima",
    "deprime": "deprima",
    "deprimi": "deprima",
    "nedeprimând": "deprima",
    "nedeprimându": "deprima",
    "nemaideprimând": "deprima",
    "nemaideprimându": "deprima",
    "deprimarea": "deprimare",
    "deprimareo": "deprimare",
    "deprimări": "deprimare",
    "deprimării": "deprimare",
    "deprimările": "deprimare",
    "deprimărilor": "deprimare",
    "deprimata": "deprimat",
    "deprimată": "deprimat",
    "deprimate": "deprimat",
    "deprimatei": "deprimat",
    "deprimatele": "deprimat",
    "deprimatelor": "deprimat",
    "deprimați": "deprimat",
    "deprimații": "deprimat",
    "deprimaților": "deprimat",
    "deprimato": "deprimat",
    "deprimatul": "deprimat",
    "deprimatule": "deprimat",
    "deprimatului": "deprimat",
    "deprind": "deprinde",
    "deprindă": "deprinde",
    "deprindea": "deprinde",
    "deprindeai": "deprinde",
    "deprindeam": "deprinde",
    "deprindeați": "deprinde",
    "deprindeau": "deprinde",
    "deprindem": "deprinde",
    "deprindeți": "deprinde",
    "deprins": "deprinde",
    "deprinse": "deprinde",
    "deprinsei": "deprinde",
    "deprinseră": "deprinde",
    "deprinserăm": "deprinde",
    "deprinserăți": "deprinde",
    "deprinsese": "deprinde",
    "deprinsesem": "deprinde",
    "deprinseseră": "deprinde",
    "deprinseserăm": "deprinde",
    "deprinseserăți": "deprinde",
    "deprinseseși": "deprinde",
    "deprinseși": "deprinde",
    "deprinsu": "deprinde",
    "deprinzând": "deprinde",
    "deprinzându": "deprinde",
    "deprinzi": "deprinde",
    "nedeprinzând": "deprinde",
    "nedeprinzându": "deprinde",
    "nemaideprinzând": "deprinde",
    "nemaideprinzându": "deprinde",
    "deprinderea": "deprindere",
    "deprindereo": "deprindere",
    "deprinderi": "deprindere",
    "deprinderii": "deprindere",
    "deprinderile": "deprindere",
    "deprinderilor": "deprindere",
    "deprinsa": "deprins",
    "deprinsă": "deprins",
    "deprinse": "deprins",
    "deprinsei": "deprins",
    "deprinsele": "deprins",
    "deprinselor": "deprins",
    "deprinși": "deprins",
    "deprinșii": "deprins",
    "deprinșilor": "deprins",
    "deprinso": "deprins",
    "deprinsul": "deprins",
    "deprinsule": "deprins",
    "deprinsului": "deprins",
    "depunătoarea": "depunătoare",
    "depunătoarei": "depunătoare",
    "depunătoarele": "depunătoare",
    "depunătoarelor": "depunătoare",
    "depunătoareo": "depunătoare",
    "depunători": "depunător",
    "depunătorii": "depunător",
    "depunătorilor": "depunător",
    "depunătorul": "depunător",
    "depunătorule": "depunător",
    "depunătorului": "depunător",
    "depunctă": "depuncta",
    "depunctai": "depuncta",
    "depunctam": "depuncta",
    "depunctăm": "depuncta",
    "depunctând": "depuncta",
    "depunctându": "depuncta",
    "depunctară": "depuncta",
    "depunctarăm": "depuncta",
    "depunctarăți": "depuncta",
    "depunctase": "depuncta",
    "depunctasem": "depuncta",
    "depunctaseră": "depuncta",
    "depunctaserăm": "depuncta",
    "depunctaserăți": "depuncta",
    "depunctaseși": "depuncta",
    "depunctași": "depuncta",
    "depunctat": "depuncta",
    "depunctați": "depuncta",
    "depunctau": "depuncta",
    "depunctează": "depuncta",
    "depunctez": "depuncta",
    "depuncteze": "depuncta",
    "depunctezi": "depuncta",
    "depunctata": "depunctat",
    "depunctată": "depunctat",
    "depunctate": "depunctat",
    "depunctatei": "depunctat",
    "depunctatele": "depunctat",
    "depunctatelor": "depunctat",
    "depunctați": "depunctat",
    "depunctații": "depunctat",
    "depunctaților": "depunctat",
    "depunctatul": "depunctat",
    "depunctatului": "depunctat",
    "depui": "depune",
    "depun": "depune",
    "depună": "depune",
    "depunând": "depune",
    "depunându": "depune",
    "depunea": "depune",
    "depuneai": "depune",
    "depuneam": "depune",
    "depuneați": "depune",
    "depuneau": "depune",
    "depunem": "depune",
    "depuneți": "depune",
    "depus": "depune",
    "depuse": "depune",
    "depusei": "depune",
    "depuseră": "depune",
    "depuserăm": "depune",
    "depuserăți": "depune",
    "depusese": "depune",
    "depusesem": "depune",
    "depuseseră": "depune",
    "depuseserăm": "depune",
    "depuseserăți": "depune",
    "depuseseși": "depune",
    "depuseși": "depune",
    "depusu": "depune",
    "nedepunând": "depune",
    "nedepunându": "depune",
    "nemaidepunând": "depune",
    "nemaidepunându": "depune",
    "depunerea": "depunere",
    "depunereo": "depunere",
    "depuneri": "depunere",
    "depunerii": "depunere",
    "depunerile": "depunere",
    "depunerilor": "depunere",
    "depusă": "depus",
    "depuse": "depus",
    "depuși": "depus",
    "deputați": "deputat",
    "deputații": "deputat",
    "deputaților": "deputat",
    "deputatul": "deputat",
    "deputatule": "deputat",
    "deputatului": "deputat",
    "deputata": "deputată",
    "deputate": "deputată",
    "deputatei": "deputată",
    "deputatele": "deputată",
    "deputatelor": "deputată",
    "deputato": "deputată",
    "derâderea": "derâdere",
    "derâdereo": "derâdere",
    "derâderi": "derâdere",
    "derâderii": "derâdere",
    "deraiai": "deraia",
    "deraiam": "deraia",
    "deraiară": "deraia",
    "deraiarăm": "deraia",
    "deraiarăți": "deraia",
    "deraiase": "deraia",
    "deraiasem": "deraia",
    "deraiaseră": "deraia",
    "deraiaserăm": "deraia",
    "deraiaserăți": "deraia",
    "deraiaseși": "deraia",
    "deraiași": "deraia",
    "deraiat": "deraia",
    "deraiați": "deraia",
    "deraiatu": "deraia",
    "deraiau": "deraia",
    "deraiază": "deraia",
    "deraie": "deraia",
    "deraiem": "deraia",
    "deraiez": "deraia",
    "deraieze": "deraia",
    "deraiezi": "deraia",
    "deraind": "deraia",
    "deraindu": "deraia",
    "nederaind": "deraia",
    "nederaindu": "deraia",
    "nemaideraind": "deraia",
    "nemaideraindu": "deraia",
    "deraiată": "deraiat",
    "deraiate": "deraiat",
    "deraiați": "deraiat",
    "deraierea": "deraiere",
    "deraiereo": "deraiere",
    "deraieri": "deraiere",
    "deraierii": "deraiere",
    "deraierile": "deraiere",
    "deraierilor": "deraiere",
    "deranjul": "deranj",
    "deranjule": "deranj",
    "deranjului": "deranj",
    "deranjuri": "deranj",
    "deranjurile": "deranj",
    "deranjurilor": "deranj",
    "deranjă": "deranja",
    "deranjai": "deranja",
    "deranjam": "deranja",
    "deranjăm": "deranja",
    "deranjând": "deranja",
    "deranjându": "deranja",
    "deranjară": "deranja",
    "deranjarăm": "deranja",
    "deranjarăți": "deranja",
    "deranjase": "deranja",
    "deranjasem": "deranja",
    "deranjaseră": "deranja",
    "deranjaserăm": "deranja",
    "deranjaserăți": "deranja",
    "deranjaseși": "deranja",
    "deranjași": "deranja",
    "deranjat": "deranja",
    "deranjați": "deranja",
    "deranjatu": "deranja",
    "deranjau": "deranja",
    "deranjează": "deranja",
    "deranjez": "deranja",
    "deranjeze": "deranja",
    "deranjezi": "deranja",
    "nederanjând": "deranja",
    "nederanjându": "deranja",
    "nemaideranjând": "deranja",
    "nemaideranjându": "deranja",
    "deranjamente": "deranjament",
    "deranjamentele": "deranjament",
    "deranjamentelor": "deranjament",
    "deranjamentul": "deranjament",
    "deranjamentule": "deranjament",
    "deranjamentului": "deranjament",
    "deranjarea": "deranjare",
    "deranjareo": "deranjare",
    "deranjări": "deranjare",
    "deranjării": "deranjare",
    "deranjările": "deranjare",
    "deranjărilor": "deranjare",
    "deranjată": "deranjat",
    "deranjate": "deranjat",
    "deranjați": "deranjat",
    "derapă": "derapa",
    "derapai": "derapa",
    "derapam": "derapa",
    "derapăm": "derapa",
    "derapând": "derapa",
    "derapându": "derapa",
    "derapară": "derapa",
    "deraparăm": "derapa",
    "deraparăți": "derapa",
    "derapase": "derapa",
    "derapasem": "derapa",
    "derapaseră": "derapa",
    "derapaserăm": "derapa",
    "derapaserăți": "derapa",
    "derapaseși": "derapa",
    "derapași": "derapa",
    "derapat": "derapa",
    "derapați": "derapa",
    "derapatu": "derapa",
    "derapau": "derapa",
    "derapează": "derapa",
    "derapez": "derapa",
    "derapeze": "derapa",
    "derapezi": "derapa",
    "nederapând": "derapa",
    "nederapându": "derapa",
    "nemaiderapând": "derapa",
    "nemaiderapându": "derapa",
    "deraparea": "derapare",
    "derapareo": "derapare",
    "derapări": "derapare",
    "derapării": "derapare",
    "derapările": "derapare",
    "derapărilor": "derapare",
    "derapată": "derapat",
    "derapate": "derapat",
    "derapați": "derapat",
    "deratiză": "deratiza",
    "deratizai": "deratiza",
    "deratizam": "deratiza",
    "deratizăm": "deratiza",
    "deratizând": "deratiza",
    "deratizându": "deratiza",
    "deratizară": "deratiza",
    "deratizarăm": "deratiza",
    "deratizarăți": "deratiza",
    "deratizase": "deratiza",
    "deratizasem": "deratiza",
    "deratizaseră": "deratiza",
    "deratizaserăm": "deratiza",
    "deratizaserăți": "deratiza",
    "deratizaseși": "deratiza",
    "deratizași": "deratiza",
    "deratizat": "deratiza",
    "deratizați": "deratiza",
    "deratizatu": "deratiza",
    "deratizau": "deratiza",
    "deratizează": "deratiza",
    "deratizez": "deratiza",
    "deratizeze": "deratiza",
    "deratizezi": "deratiza",
    "nederatizând": "deratiza",
    "nederatizându": "deratiza",
    "nemaideratizând": "deratiza",
    "nemaideratizându": "deratiza",
    "deratizarea": "deratizare",
    "deratizareo": "deratizare",
    "deratizări": "deratizare",
    "deratizării": "deratizare",
    "deratizările": "deratizare",
    "deratizărilor": "deratizare",
    "deratizată": "deratizat",
    "deratizate": "deratizat",
    "deratizați": "deratizat",
    "derbedei": "derbedeu",
    "derbedeii": "derbedeu",
    "derbedeilor": "derbedeu",
    "derbedeul": "derbedeu",
    "derbedeule": "derbedeu",
    "derbedeului": "derbedeu",
    "derdelușul": "derdeluș",
    "derdelușule": "derdeluș",
    "derdelușului": "derdeluș",
    "derdelușuri": "derdeluș",
    "derdelușurile": "derdeluș",
    "derdelușurilor": "derdeluș",
    "deretic": "deretica",
    "deretică": "deretica",
    "dereticai": "deretica",
    "dereticam": "deretica",
    "dereticăm": "deretica",
    "dereticând": "deretica",
    "dereticându": "deretica",
    "dereticară": "deretica",
    "dereticarăm": "deretica",
    "dereticarăți": "deretica",
    "dereticase": "deretica",
    "dereticasem": "deretica",
    "dereticaseră": "deretica",
    "dereticaserăm": "deretica",
    "dereticaserăți": "deretica",
    "dereticaseși": "deretica",
    "dereticași": "deretica",
    "dereticat": "deretica",
    "dereticați": "deretica",
    "dereticatu": "deretica",
    "dereticau": "deretica",
    "deretice": "deretica",
    "deretici": "deretica",
    "nedereticând": "deretica",
    "nedereticându": "deretica",
    "nemaidereticând": "deretica",
    "nemaidereticându": "deretica",
    "dereticarea": "dereticare",
    "dereticareo": "dereticare",
    "dereticări": "dereticare",
    "dereticării": "dereticare",
    "dereticările": "dereticare",
    "dereticărilor": "dereticare",
    "dereticată": "dereticat",
    "dereticate": "dereticat",
    "dereticați": "dereticat",
    "deriv": "deriva",
    "derivă": "deriva",
    "derivai": "deriva",
    "derivam": "deriva",
    "derivăm": "deriva",
    "derivând": "deriva",
    "derivându": "deriva",
    "derivară": "deriva",
    "derivarăm": "deriva",
    "derivarăți": "deriva",
    "derivase": "deriva",
    "derivasem": "deriva",
    "derivaseră": "deriva",
    "derivaserăm": "deriva",
    "derivaserăți": "deriva",
    "derivaseși": "deriva",
    "derivași": "deriva",
    "derivat": "deriva",
    "derivați": "deriva",
    "derivatu": "deriva",
    "derivau": "deriva",
    "derive": "deriva",
    "derivi": "deriva",
    "nederivând": "deriva",
    "nederivându": "deriva",
    "nemaiderivând": "deriva",
    "nemaiderivându": "deriva",
    "deriva": "derivă",
    "derive": "derivă",
    "derivei": "derivă",
    "derivele": "derivă",
    "derivelor": "derivă",
    "derivo": "derivă",
    "derivarea": "derivare",
    "derivareo": "derivare",
    "derivări": "derivare",
    "derivării": "derivare",
    "derivările": "derivare",
    "derivărilor": "derivare",
    "derivata": "derivat",
    "derivată": "derivat",
    "derivate": "derivat",
    "derivatei": "derivat",
    "derivatele": "derivat",
    "derivatelor": "derivat",
    "derivați": "derivat",
    "derivații": "derivat",
    "derivaților": "derivat",
    "derivato": "derivat",
    "derivatul": "derivat",
    "derivatule": "derivat",
    "derivatului": "derivat",
    "derivata": "derivată",
    "derivate": "derivată",
    "derivatei": "derivată",
    "derivatele": "derivată",
    "derivatelor": "derivată",
    "derivato": "derivată",
    "derivația": "derivație",
    "derivației": "derivație",
    "derivații": "derivație",
    "derivațiile": "derivație",
    "derivațiilor": "derivație",
    "derivațio": "derivație",
    "derivativa": "derivativ",
    "derivativă": "derivativ",
    "derivative": "derivativ",
    "derivativei": "derivativ",
    "derivativele": "derivativ",
    "derivativelor": "derivativ",
    "derivativi": "derivativ",
    "derivativii": "derivativ",
    "derivativilor": "derivativ",
    "derivativo": "derivativ",
    "derivativul": "derivativ",
    "derivativule": "derivativ",
    "derivativului": "derivativ",
    "derizoria": "derizoriu",
    "derizorie": "derizoriu",
    "derizoriei": "derizoriu",
    "derizorii": "derizoriu",
    "derizoriii": "derizoriu",
    "derizoriile": "derizoriu",
    "derizoriilor": "derizoriu",
    "derizorio": "derizoriu",
    "derizoriul": "derizoriu",
    "derizoriule": "derizoriu",
    "derizoriului": "derizoriu",
    "derma": "dermă",
    "derme": "dermă",
    "dermei": "dermă",
    "dermele": "dermă",
    "dermelor": "dermă",
    "dermo": "dermă",
    "dermatita": "dermatită",
    "dermatite": "dermatită",
    "dermatitei": "dermatită",
    "dermatitele": "dermatită",
    "dermatitelor": "dermatită",
    "dermatito": "dermatită",
    "dermatologi": "dermatolog",
    "dermatologii": "dermatolog",
    "dermatologilor": "dermatolog",
    "dermatologul": "dermatolog",
    "dermatologule": "dermatolog",
    "dermatologului": "dermatolog",
    "dermatologa": "dermatologă",
    "dermatologe": "dermatologă",
    "dermatologei": "dermatologă",
    "dermatologele": "dermatologă",
    "dermatologelor": "dermatologă",
    "dermatologo": "dermatologă",
    "dermatologica": "dermatologic",
    "dermatologică": "dermatologic",
    "dermatologice": "dermatologic",
    "dermatologicei": "dermatologic",
    "dermatologicele": "dermatologic",
    "dermatologicelor": "dermatologic",
    "dermatologici": "dermatologic",
    "dermatologicii": "dermatologic",
    "dermatologicilor": "dermatologic",
    "dermatologico": "dermatologic",
    "dermatologicul": "dermatologic",
    "dermatologicule": "dermatologic",
    "dermatologicului": "dermatologic",
    "dermatologia": "dermatologie",
    "dermatologiei": "dermatologie",
    "dermatologii": "dermatologie",
    "dermatologio": "dermatologie",
    "dermatoza": "dermatoză",
    "dermatoze": "dermatoză",
    "dermatozei": "dermatoză",
    "dermatozele": "dermatoză",
    "dermatozelor": "dermatoză",
    "dermatozo": "dermatoză",
    "dermica": "dermic",
    "dermică": "dermic",
    "dermice": "dermic",
    "dermicei": "dermic",
    "dermicele": "dermic",
    "dermicelor": "dermic",
    "dermici": "dermic",
    "dermicii": "dermic",
    "dermicilor": "dermic",
    "dermico": "dermic",
    "dermicul": "dermic",
    "dermicule": "dermic",
    "dermicului": "dermic",
    "derobă": "deroba",
    "derobai": "deroba",
    "derobam": "deroba",
    "derobăm": "deroba",
    "derobând": "deroba",
    "derobându": "deroba",
    "derobară": "deroba",
    "derobarăm": "deroba",
    "derobarăți": "deroba",
    "derobase": "deroba",
    "derobasem": "deroba",
    "derobaseră": "deroba",
    "derobaserăm": "deroba",
    "derobaserăți": "deroba",
    "derobaseși": "deroba",
    "derobași": "deroba",
    "derobat": "deroba",
    "derobați": "deroba",
    "derobatu": "deroba",
    "derobau": "deroba",
    "derobează": "deroba",
    "derobez": "deroba",
    "derobeze": "deroba",
    "derobezi": "deroba",
    "derobată": "derobat",
    "derobate": "derobat",
    "derobați": "derobat",
    "derog": "deroga",
    "derogă": "deroga",
    "derogai": "deroga",
    "derogam": "deroga",
    "derogăm": "deroga",
    "derogând": "deroga",
    "derogându": "deroga",
    "derogară": "deroga",
    "derogarăm": "deroga",
    "derogarăți": "deroga",
    "derogase": "deroga",
    "derogasem": "deroga",
    "derogaseră": "deroga",
    "derogaserăm": "deroga",
    "derogaserăți": "deroga",
    "derogaseși": "deroga",
    "derogași": "deroga",
    "derogat": "deroga",
    "derogați": "deroga",
    "derogatu": "deroga",
    "derogau": "deroga",
    "deroge": "deroga",
    "derogi": "deroga",
    "nederogând": "deroga",
    "nederogându": "deroga",
    "nemaiderogând": "deroga",
    "nemaiderogându": "deroga",
    "derogarea": "derogare",
    "derogareo": "derogare",
    "derogări": "derogare",
    "derogării": "derogare",
    "derogările": "derogare",
    "derogărilor": "derogare",
    "derogată": "derogat",
    "derogate": "derogat",
    "derogați": "derogat",
    "derogatoria": "derogatoriu",
    "derogatorie": "derogatoriu",
    "derogatoriei": "derogatoriu",
    "derogatorii": "derogatoriu",
    "derogatoriii": "derogatoriu",
    "derogatoriile": "derogatoriu",
    "derogatoriilor": "derogatoriu",
    "derogatorio": "derogatoriu",
    "derogatoriul": "derogatoriu",
    "derogatoriule": "derogatoriu",
    "derogatoriului": "derogatoriu",
    "derulă": "derula",
    "derulai": "derula",
    "derulam": "derula",
    "derulăm": "derula",
    "derulând": "derula",
    "derulându": "derula",
    "derulară": "derula",
    "derularăm": "derula",
    "derularăți": "derula",
    "derulase": "derula",
    "derulasem": "derula",
    "derulaseră": "derula",
    "derulaserăm": "derula",
    "derulaserăți": "derula",
    "derulaseși": "derula",
    "derulași": "derula",
    "derulat": "derula",
    "derulați": "derula",
    "derulatu": "derula",
    "derulau": "derula",
    "derulează": "derula",
    "derulez": "derula",
    "deruleze": "derula",
    "derulezi": "derula",
    "nederulând": "derula",
    "nederulându": "derula",
    "nemaiderulând": "derula",
    "nemaiderulându": "derula",
    "derularea": "derulare",
    "derulareo": "derulare",
    "derulări": "derulare",
    "derulării": "derulare",
    "derulările": "derulare",
    "derulărilor": "derulare",
    "derulată": "derulat",
    "derulate": "derulat",
    "derulați": "derulat",
    "derută": "deruta",
    "derutai": "deruta",
    "derutam": "deruta",
    "derutăm": "deruta",
    "derutând": "deruta",
    "derutându": "deruta",
    "derutară": "deruta",
    "derutarăm": "deruta",
    "derutarăți": "deruta",
    "derutase": "deruta",
    "derutasem": "deruta",
    "derutaseră": "deruta",
    "derutaserăm": "deruta",
    "derutaserăți": "deruta",
    "derutaseși": "deruta",
    "derutași": "deruta",
    "derutat": "deruta",
    "derutați": "deruta",
    "derutatu": "deruta",
    "derutau": "deruta",
    "derutează": "deruta",
    "derutez": "deruta",
    "deruteze": "deruta",
    "derutezi": "deruta",
    "nederutând": "deruta",
    "nederutându": "deruta",
    "nemaiderutând": "deruta",
    "nemaiderutându": "deruta",
    "deruta": "derută",
    "derute": "derută",
    "derutei": "derută",
    "derutele": "derută",
    "derutelor": "derută",
    "deruto": "derută",
    "derutarea": "derutare",
    "derutareo": "derutare",
    "derutări": "derutare",
    "derutării": "derutare",
    "derutările": "derutare",
    "derutărilor": "derutare",
    "derutata": "derutat",
    "derutată": "derutat",
    "derutate": "derutat",
    "derutatei": "derutat",
    "derutatele": "derutat",
    "derutatelor": "derutat",
    "derutați": "derutat",
    "derutații": "derutat",
    "derutaților": "derutat",
    "derutato": "derutat",
    "derutatul": "derutat",
    "derutatule": "derutat",
    "derutatului": "derutat",
    "derviși": "derviș",
    "dervișii": "derviș",
    "dervișilor": "derviș",
    "dervișul": "derviș",
    "dervișule": "derviș",
    "dervișului": "derviș",
    "deasa": "des",
    "deasă": "des",
    "deaso": "des",
    "dese": "des",
    "desei": "des",
    "desele": "des",
    "deselor": "des",
    "deși": "des",
    "deșii": "des",
    "deșilor": "des",
    "desul": "des",
    "desule": "des",
    "desului": "des",
    "desagi": "desag",
    "desagii": "desag",
    "desagilor": "desag",
    "desagul": "desag",
    "desagule": "desag",
    "desagului": "desag",
    "desaga": "desagă",
    "desage": "desagă",
    "desagei": "desagă",
    "desagele": "desagă",
    "desagelor": "desagă",
    "desago": "desagă",
    "deșănță": "deșănța",
    "deșănțai": "deșănța",
    "deșănțam": "deșănța",
    "deșănțăm": "deșănța",
    "deșănțând": "deșănța",
    "deșănțându": "deșănța",
    "deșănțară": "deșănța",
    "deșănțarăm": "deșănța",
    "deșănțarăți": "deșănța",
    "deșănțase": "deșănța",
    "deșănțasem": "deșănța",
    "deșănțaseră": "deșănța",
    "deșănțaserăm": "deșănța",
    "deșănțaserăți": "deșănța",
    "deșănțaseși": "deșănța",
    "deșănțași": "deșănța",
    "deșănțat": "deșănța",
    "deșănțați": "deșănța",
    "deșănțatu": "deșănța",
    "deșănțau": "deșănța",
    "deșănțează": "deșănța",
    "deșănțez": "deșănța",
    "deșănțeze": "deșănța",
    "deșănțezi": "deșănța",
    "nedeșănțând": "deșănța",
    "nedeșănțându": "deșănța",
    "nemaideșănțând": "deșănța",
    "nemaideșănțându": "deșănța",
    "deșănțarea": "deșănțare",
    "deșănțareo": "deșănțare",
    "deșănțări": "deșănțare",
    "deșănțării": "deșănțare",
    "deșănțările": "deșănțare",
    "deșănțărilor": "deșănțare",
    "deșănțata": "deșănțat",
    "deșănțată": "deșănțat",
    "deșănțate": "deșănțat",
    "deșănțatei": "deșănțat",
    "deșănțatele": "deșănțat",
    "deșănțatelor": "deșănțat",
    "deșănțați": "deșănțat",
    "deșănțații": "deșănțat",
    "deșănțaților": "deșănțat",
    "deșănțato": "deșănțat",
    "deșănțatul": "deșănțat",
    "deșănțatule": "deșănțat",
    "deșănțatului": "deșănțat",
    "deșănțata": "deșănțată",
    "deșănțate": "deșănțată",
    "deșănțatei": "deșănțată",
    "deșănțatele": "deșănțată",
    "deșănțatelor": "deșănțată",
    "deșănțato": "deșănțată",
    "desărcină": "desărcina",
    "desărcinai": "desărcina",
    "desărcinam": "desărcina",
    "desărcinăm": "desărcina",
    "desărcinând": "desărcina",
    "desărcinându": "desărcina",
    "desărcinară": "desărcina",
    "desărcinarăm": "desărcina",
    "desărcinarăți": "desărcina",
    "desărcinase": "desărcina",
    "desărcinasem": "desărcina",
    "desărcinaseră": "desărcina",
    "desărcinaserăm": "desărcina",
    "desărcinaserăți": "desărcina",
    "desărcinaseși": "desărcina",
    "desărcinași": "desărcina",
    "desărcinat": "desărcina",
    "desărcinați": "desărcina",
    "desărcinatu": "desărcina",
    "desărcinau": "desărcina",
    "desărcinează": "desărcina",
    "desărcinez": "desărcina",
    "desărcineze": "desărcina",
    "desărcinezi": "desărcina",
    "nedesărcinând": "desărcina",
    "nedesărcinându": "desărcina",
    "nemaidesărcinând": "desărcina",
    "nemaidesărcinându": "desărcina",
    "desărcinată": "desărcinat",
    "desărcinate": "desărcinat",
    "desărcinați": "desărcinat",
    "desăvârșea": "desăvârși",
    "desăvârșeai": "desăvârși",
    "desăvârșeam": "desăvârși",
    "desăvârșească": "desăvârși",
    "desăvârșeați": "desăvârși",
    "desăvârșeau": "desăvârși",
    "desăvârșesc": "desăvârși",
    "desăvârșește": "desăvârși",
    "desăvârșești": "desăvârși",
    "desăvârșii": "desăvârși",
    "desăvârșim": "desăvârși",
    "desăvârșind": "desăvârși",
    "desăvârșindu": "desăvârși",
    "desăvârșiră": "desăvârși",
    "desăvârșirăm": "desăvârși",
    "desăvârșirăți": "desăvârși",
    "desăvârșise": "desăvârși",
    "desăvârșisem": "desăvârși",
    "desăvârșiseră": "desăvârși",
    "desăvârșiserăm": "desăvârși",
    "desăvârșiserăți": "desăvârși",
    "desăvârșiseși": "desăvârși",
    "desăvârșiși": "desăvârși",
    "desăvârșit": "desăvârși",
    "desăvârșiți": "desăvârși",
    "desăvârșitu": "desăvârși",
    "nedesăvârșind": "desăvârși",
    "nedesăvârșindu": "desăvârși",
    "nemaidesăvârșind": "desăvârși",
    "nemaidesăvârșindu": "desăvârși",
    "desăvârșirea": "desăvârșire",
    "desăvârșireo": "desăvârșire",
    "desăvârșiri": "desăvârșire",
    "desăvârșirii": "desăvârșire",
    "desăvârșirile": "desăvârșire",
    "desăvârșirilor": "desăvârșire",
    "desăvârșita": "desăvârșit",
    "desăvârșită": "desăvârșit",
    "desăvârșite": "desăvârșit",
    "desăvârșitei": "desăvârșit",
    "desăvârșitele": "desăvârșit",
    "desăvârșitelor": "desăvârșit",
    "desăvârșiți": "desăvârșit",
    "desăvârșiții": "desăvârșit",
    "desăvârșiților": "desăvârșit",
    "desăvârșito": "desăvârșit",
    "desăvârșitul": "desăvârșit",
    "desăvârșitule": "desăvârșit",
    "desăvârșitului": "desăvârșit",
    "descâlcea": "descâlci",
    "descâlceai": "descâlci",
    "descâlceam": "descâlci",
    "descâlcească": "descâlci",
    "descâlceați": "descâlci",
    "descâlceau": "descâlci",
    "descâlcesc": "descâlci",
    "descâlcește": "descâlci",
    "descâlcești": "descâlci",
    "descâlcii": "descâlci",
    "descâlcim": "descâlci",
    "descâlcind": "descâlci",
    "descâlcindu": "descâlci",
    "descâlciră": "descâlci",
    "descâlcirăm": "descâlci",
    "descâlcirăți": "descâlci",
    "descâlcise": "descâlci",
    "descâlcisem": "descâlci",
    "descâlciseră": "descâlci",
    "descâlciserăm": "descâlci",
    "descâlciserăți": "descâlci",
    "descâlciseși": "descâlci",
    "descâlciși": "descâlci",
    "descâlcit": "descâlci",
    "descâlciți": "descâlci",
    "descâlcitu": "descâlci",
    "nedescâlcind": "descâlci",
    "nedescâlcindu": "descâlci",
    "nemaidescâlcind": "descâlci",
    "nemaidescâlcindu": "descâlci",
    "descâlcirea": "descâlcire",
    "descâlcireo": "descâlcire",
    "descâlciri": "descâlcire",
    "descâlcirii": "descâlcire",
    "descâlcirile": "descâlcire",
    "descâlcirilor": "descâlcire",
    "descâlcită": "descâlcit",
    "descâlcite": "descâlcit",
    "descâlciți": "descâlcit",
    "descalec": "descăleca",
    "descalecă": "descăleca",
    "descălecă": "descăleca",
    "descălecai": "descăleca",
    "descălecam": "descăleca",
    "descălecăm": "descăleca",
    "descălecând": "descăleca",
    "descălecându": "descăleca",
    "descălecară": "descăleca",
    "descălecarăm": "descăleca",
    "descălecarăți": "descăleca",
    "descălecase": "descăleca",
    "descălecasem": "descăleca",
    "descălecaseră": "descăleca",
    "descălecaserăm": "descăleca",
    "descălecaserăți": "descăleca",
    "descălecaseși": "descăleca",
    "descălecași": "descăleca",
    "descălecat": "descăleca",
    "descălecați": "descăleca",
    "descălecatu": "descăleca",
    "descălecau": "descăleca",
    "descalece": "descăleca",
    "descaleci": "descăleca",
    "nedescălecând": "descăleca",
    "nedescălecându": "descăleca",
    "nemaidescălecând": "descăleca",
    "nemaidescălecându": "descăleca",
    "descălecarea": "descălecare",
    "descălecareo": "descălecare",
    "descălecări": "descălecare",
    "descălecării": "descălecare",
    "descălecările": "descălecare",
    "descălecărilor": "descălecare",
    "descălecată": "descălecat",
    "descălecate": "descălecat",
    "descălecați": "descălecat",
    "descălecatul": "descălecat",
    "descălecatule": "descălecat",
    "descălecatului": "descălecat",
    "descălecaturi": "descălecat",
    "descălecaturile": "descălecat",
    "descălecaturilor": "descălecat",
    "descalț": "descălța",
    "descalță": "descălța",
    "descălță": "descălța",
    "descălțai": "descălța",
    "descălțam": "descălța",
    "descălțăm": "descălța",
    "descălțând": "descălța",
    "descălțându": "descălța",
    "descălțară": "descălța",
    "descălțarăm": "descălța",
    "descălțarăți": "descălța",
    "descălțase": "descălța",
    "descălțasem": "descălța",
    "descălțaseră": "descălța",
    "descălțaserăm": "descălța",
    "descălțaserăți": "descălța",
    "descălțaseși": "descălța",
    "descălțași": "descălța",
    "descălțat": "descălța",
    "descălțați": "descălța",
    "descălțatu": "descălța",
    "descălțau": "descălța",
    "descalțe": "descălța",
    "descalți": "descălța",
    "nedescălțând": "descălța",
    "nedescălțându": "descălța",
    "nemaidescălțând": "descălța",
    "nemaidescălțându": "descălța",
    "descălțarea": "descălțare",
    "descălțareo": "descălțare",
    "descălțări": "descălțare",
    "descălțării": "descălțare",
    "descălțările": "descălțare",
    "descălțărilor": "descălțare",
    "descălțata": "descălțat",
    "descălțată": "descălțat",
    "descălțate": "descălțat",
    "descălțatei": "descălțat",
    "descălțatele": "descălțat",
    "descălțatelor": "descălțat",
    "descălțați": "descălțat",
    "descălțații": "descălțat",
    "descălțaților": "descălțat",
    "descălțato": "descălțat",
    "descălțatul": "descălțat",
    "descălțatule": "descălțat",
    "descălțatului": "descălțat",
    "descânt": "descânta",
    "descântă": "descânta",
    "descântai": "descânta",
    "descântam": "descânta",
    "descântăm": "descânta",
    "descântând": "descânta",
    "descântându": "descânta",
    "descântară": "descânta",
    "descântarăm": "descânta",
    "descântarăți": "descânta",
    "descântase": "descânta",
    "descântasem": "descânta",
    "descântaseră": "descânta",
    "descântaserăm": "descânta",
    "descântaserăți": "descânta",
    "descântaseși": "descânta",
    "descântași": "descânta",
    "descântat": "descânta",
    "descântați": "descânta",
    "descântatu": "descânta",
    "descânți": "descânta",
    "descântată": "descântat",
    "descântate": "descântat",
    "descântați": "descântat",
    "descântece": "descântec",
    "descântecele": "descântec",
    "descântecelor": "descântec",
    "descântecul": "descântec",
    "descântecule": "descântec",
    "descântecului": "descântec",
    "descarc": "descărca",
    "descarcă": "descărca",
    "descărcă": "descărca",
    "descărcai": "descărca",
    "descărcam": "descărca",
    "descărcăm": "descărca",
    "descărcând": "descărca",
    "descărcându": "descărca",
    "descărcară": "descărca",
    "descărcarăm": "descărca",
    "descărcarăți": "descărca",
    "descărcase": "descărca",
    "descărcasem": "descărca",
    "descărcaseră": "descărca",
    "descărcaserăm": "descărca",
    "descărcaserăți": "descărca",
    "descărcaseși": "descărca",
    "descărcași": "descărca",
    "descărcat": "descărca",
    "descărcați": "descărca",
    "descărcatu": "descărca",
    "descărcau": "descărca",
    "descarce": "descărca",
    "descarci": "descărca",
    "nedescărcând": "descărca",
    "nedescărcându": "descărca",
    "nemaidescărcând": "descărca",
    "nemaidescărcându": "descărca",
    "descărcarea": "descărcare",
    "descărcareo": "descărcare",
    "descărcări": "descărcare",
    "descărcării": "descărcare",
    "descărcările": "descărcare",
    "descărcărilor": "descărcare",
    "descărcată": "descărcat",
    "descărcate": "descărcat",
    "descărcați": "descărcat",
    "descărcătoarea": "descărcătoare",
    "descărcătoarei": "descărcătoare",
    "descărcătoarele": "descărcătoare",
    "descărcătoarelor": "descărcătoare",
    "descărcătoareo": "descărcătoare",
    "descărcătoare": "descărcător",
    "descărcătoarea": "descărcător",
    "descărcătoarei": "descărcător",
    "descărcătoarele": "descărcător",
    "descărcătoarelor": "descărcător",
    "descărcătoareo": "descărcător",
    "descărcători": "descărcător",
    "descărcătorii": "descărcător",
    "descărcătorilor": "descărcător",
    "descărcătorul": "descărcător",
    "descărcătorule": "descărcător",
    "descărcătorului": "descărcător",
    "descărcătura": "descărcătură",
    "descărcături": "descărcătură",
    "descărcăturii": "descărcătură",
    "descărcăturile": "descărcătură",
    "descărcăturilor": "descărcătură",
    "descărcăturo": "descărcătură",
    "descarcerarea": "descarcerare",
    "descarcerări": "descarcerare",
    "descarcerării": "descarcerare",
    "descarcerările": "descarcerare",
    "descarcerărilor": "descarcerare",
    "descărnă": "descărna",
    "descărnai": "descărna",
    "descărnam": "descărna",
    "descărnăm": "descărna",
    "descărnând": "descărna",
    "descărnându": "descărna",
    "descărnară": "descărna",
    "descărnarăm": "descărna",
    "descărnarăți": "descărna",
    "descărnase": "descărna",
    "descărnasem": "descărna",
    "descărnaseră": "descărna",
    "descărnaserăm": "descărna",
    "descărnaserăți": "descărna",
    "descărnaseși": "descărna",
    "descărnași": "descărna",
    "descărnat": "descărna",
    "descărnați": "descărna",
    "descărnatu": "descărna",
    "descărnau": "descărna",
    "descărnează": "descărna",
    "descărnez": "descărna",
    "descărneze": "descărna",
    "descărnezi": "descărna",
    "nedescărnând": "descărna",
    "nedescărnându": "descărna",
    "nemaidescărnând": "descărna",
    "nemaidescărnându": "descărna",
    "descarnata": "descarnat",
    "descarnată": "descarnat",
    "descarnate": "descarnat",
    "descarnatei": "descarnat",
    "descarnatele": "descarnat",
    "descarnatelor": "descarnat",
    "descarnați": "descarnat",
    "descarnații": "descarnat",
    "descarnaților": "descarnat",
    "descarnato": "descarnat",
    "descarnatul": "descarnat",
    "descarnatule": "descarnat",
    "descarnatului": "descarnat",
    "descărnata": "descărnat",
    "descărnată": "descărnat",
    "descărnate": "descărnat",
    "descărnatei": "descărnat",
    "descărnatele": "descărnat",
    "descărnatelor": "descărnat",
    "descărnați": "descărnat",
    "descărnații": "descărnat",
    "descărnaților": "descărnat",
    "descărnato": "descărnat",
    "descărnatul": "descărnat",
    "descărnatule": "descărnat",
    "descărnatului": "descărnat",
    "descătărămă": "descătărăma",
    "descătărămai": "descătărăma",
    "descătărămam": "descătărăma",
    "descătărămăm": "descătărăma",
    "descătărămând": "descătărăma",
    "descătărămându": "descătărăma",
    "descătărămară": "descătărăma",
    "descătărămarăm": "descătărăma",
    "descătărămarăți": "descătărăma",
    "descătărămase": "descătărăma",
    "descătărămasem": "descătărăma",
    "descătărămaseră": "descătărăma",
    "descătărămaserăm": "descătărăma",
    "descătărămaserăți": "descătărăma",
    "descătărămaseși": "descătărăma",
    "descătărămași": "descătărăma",
    "descătărămat": "descătărăma",
    "descătărămați": "descătărăma",
    "descătărămatu": "descătărăma",
    "descătărămau": "descătărăma",
    "descătărămează": "descătărăma",
    "descătărămez": "descătărăma",
    "descătărămeze": "descătărăma",
    "descătărămezi": "descătărăma",
    "nedescătărămând": "descătărăma",
    "nedescătărămându": "descătărăma",
    "nemaidescătărămând": "descătărăma",
    "nemaidescătărămându": "descătărăma",
    "descătărămată": "descătărămat",
    "descătărămate": "descătărămat",
    "descătărămați": "descătărămat",
    "descătușă": "descătușa",
    "descătușai": "descătușa",
    "descătușam": "descătușa",
    "descătușăm": "descătușa",
    "descătușând": "descătușa",
    "descătușându": "descătușa",
    "descătușară": "descătușa",
    "descătușarăm": "descătușa",
    "descătușarăți": "descătușa",
    "descătușase": "descătușa",
    "descătușasem": "descătușa",
    "descătușaseră": "descătușa",
    "descătușaserăm": "descătușa",
    "descătușaserăți": "descătușa",
    "descătușaseși": "descătușa",
    "descătușași": "descătușa",
    "descătușat": "descătușa",
    "descătușați": "descătușa",
    "descătușatu": "descătușa",
    "descătușau": "descătușa",
    "descătușează": "descătușa",
    "descătușez": "descătușa",
    "descătușeze": "descătușa",
    "descătușezi": "descătușa",
    "nedescătușând": "descătușa",
    "nedescătușându": "descătușa",
    "nemaidescătușând": "descătușa",
    "nemaidescătușându": "descătușa",
    "descătușarea": "descătușare",
    "descătușareo": "descătușare",
    "descătușări": "descătușare",
    "descătușării": "descătușare",
    "descătușările": "descătușare",
    "descătușărilor": "descătușare",
    "descătușată": "descătușat",
    "descătușate": "descătușat",
    "descătușați": "descătușat",
    "descăzutul": "descăzut",
    "descăzutule": "descăzut",
    "descăzutului": "descăzut",
    "descăzuturi": "descăzut",
    "descăzuturile": "descăzut",
    "descăzuturilor": "descăzut",
    "descendenta": "descendent",
    "descendentă": "descendent",
    "descendente": "descendent",
    "descendentei": "descendent",
    "descendentele": "descendent",
    "descendentelor": "descendent",
    "descendenți": "descendent",
    "descendenții": "descendent",
    "descendenților": "descendent",
    "descendento": "descendent",
    "descendentul": "descendent",
    "descendentule": "descendent",
    "descendentului": "descendent",
    "descendenta": "descendentă",
    "descendente": "descendentă",
    "descendentei": "descendentă",
    "descendentele": "descendentă",
    "descendentelor": "descendentă",
    "descendența": "descendență",
    "descendențe": "descendență",
    "descendenței": "descendență",
    "descendențele": "descendență",
    "descendențelor": "descendență",
    "descendențo": "descendență",
    "descentră": "descentra",
    "descentrai": "descentra",
    "descentram": "descentra",
    "descentrăm": "descentra",
    "descentrând": "descentra",
    "descentrându": "descentra",
    "descentrară": "descentra",
    "descentrarăm": "descentra",
    "descentrarăți": "descentra",
    "descentrase": "descentra",
    "descentrasem": "descentra",
    "descentraseră": "descentra",
    "descentraserăm": "descentra",
    "descentraserăți": "descentra",
    "descentraseși": "descentra",
    "descentrași": "descentra",
    "descentrat": "descentra",
    "descentrați": "descentra",
    "descentratu": "descentra",
    "descentrau": "descentra",
    "descentrează": "descentra",
    "descentrez": "descentra",
    "descentreze": "descentra",
    "descentrezi": "descentra",
    "nedescentrând": "descentra",
    "nedescentrându": "descentra",
    "nemaidescentrând": "descentra",
    "nemaidescentrându": "descentra",
    "descentraliză": "descentraliza",
    "descentralizai": "descentraliza",
    "descentralizam": "descentraliza",
    "descentralizăm": "descentraliza",
    "descentralizând": "descentraliza",
    "descentralizându": "descentraliza",
    "descentralizară": "descentraliza",
    "descentralizarăm": "descentraliza",
    "descentralizarăți": "descentraliza",
    "descentralizase": "descentraliza",
    "descentralizasem": "descentraliza",
    "descentralizaseră": "descentraliza",
    "descentralizaserăm": "descentraliza",
    "descentralizaserăți": "descentraliza",
    "descentralizaseși": "descentraliza",
    "descentralizași": "descentraliza",
    "descentralizat": "descentraliza",
    "descentralizați": "descentraliza",
    "descentralizatu": "descentraliza",
    "descentralizau": "descentraliza",
    "descentralizează": "descentraliza",
    "descentralizez": "descentraliza",
    "descentralizeze": "descentraliza",
    "descentralizezi": "descentraliza",
    "nedescentralizând": "descentraliza",
    "nedescentralizându": "descentraliza",
    "nemaidescentralizând": "descentraliza",
    "nemaidescentralizându": "descentraliza",
    "descentralizarea": "descentralizare",
    "descentralizareo": "descentralizare",
    "descentralizări": "descentralizare",
    "descentralizării": "descentralizare",
    "descentralizările": "descentralizare",
    "descentralizărilor": "descentralizare",
    "descentralizată": "descentralizat",
    "descentralizate": "descentralizat",
    "descentralizați": "descentralizat",
    "descentrată": "descentrat",
    "descentrate": "descentrat",
    "descentrați": "descentrat",
    "deschei": "descheia",
    "descheiai": "descheia",
    "descheiam": "descheia",
    "descheiară": "descheia",
    "descheiarăm": "descheia",
    "descheiarăți": "descheia",
    "descheiase": "descheia",
    "descheiasem": "descheia",
    "descheiaseră": "descheia",
    "descheiaserăm": "descheia",
    "descheiaserăți": "descheia",
    "descheiaseși": "descheia",
    "descheiași": "descheia",
    "descheiat": "descheia",
    "descheiați": "descheia",
    "descheiatu": "descheia",
    "descheiau": "descheia",
    "descheie": "descheia",
    "descheiem": "descheia",
    "descheind": "descheia",
    "descheindu": "descheia",
    "nedescheind": "descheia",
    "nedescheindu": "descheia",
    "nemaidescheind": "descheia",
    "nemaidescheindu": "descheia",
    "descheiata": "descheiat",
    "descheiată": "descheiat",
    "descheiate": "descheiat",
    "descheiatei": "descheiat",
    "descheiatele": "descheiat",
    "descheiatelor": "descheiat",
    "descheiați": "descheiat",
    "descheiații": "descheiat",
    "descheiaților": "descheiat",
    "descheiato": "descheiat",
    "descheiatul": "descheiat",
    "descheiatule": "descheiat",
    "descheiatului": "descheiat",
    "deschid": "deschide",
    "deschidă": "deschide",
    "deschidea": "deschide",
    "deschideai": "deschide",
    "deschideam": "deschide",
    "deschideați": "deschide",
    "deschideau": "deschide",
    "deschidem": "deschide",
    "deschideți": "deschide",
    "deschis": "deschide",
    "deschise": "deschide",
    "deschisei": "deschide",
    "deschiseră": "deschide",
    "deschiserăm": "deschide",
    "deschiserăți": "deschide",
    "deschisese": "deschide",
    "deschisesem": "deschide",
    "deschiseseră": "deschide",
    "deschiseserăm": "deschide",
    "deschiseserăți": "deschide",
    "deschiseseși": "deschide",
    "deschiseși": "deschide",
    "deschisu": "deschide",
    "deschizând": "deschide",
    "deschizându": "deschide",
    "deschizi": "deschide",
    "nedeschizând": "deschide",
    "nedeschizându": "deschide",
    "nemaideschizând": "deschide",
    "nemaideschizându": "deschide",
    "deschiderea": "deschidere",
    "deschidereo": "deschidere",
    "deschideri": "deschidere",
    "deschiderii": "deschidere",
    "deschiderile": "deschidere",
    "deschiderilor": "deschidere",
    "desching": "deschinga",
    "deschingă": "deschinga",
    "deschingai": "deschinga",
    "deschingam": "deschinga",
    "deschingăm": "deschinga",
    "deschingând": "deschinga",
    "deschingându": "deschinga",
    "deschingară": "deschinga",
    "deschingarăm": "deschinga",
    "deschingarăți": "deschinga",
    "deschingase": "deschinga",
    "deschingasem": "deschinga",
    "deschingaseră": "deschinga",
    "deschingaserăm": "deschinga",
    "deschingaserăți": "deschinga",
    "deschingaseși": "deschinga",
    "deschingași": "deschinga",
    "deschingat": "deschinga",
    "deschingați": "deschinga",
    "deschingatu": "deschinga",
    "deschingau": "deschinga",
    "deschinge": "deschinga",
    "deschingi": "deschinga",
    "nedeschingând": "deschinga",
    "nedeschingându": "deschinga",
    "nemaideschingând": "deschinga",
    "nemaideschingându": "deschinga",
    "deschingată": "deschingat",
    "deschingate": "deschingat",
    "deschingați": "deschingat",
    "deschisa": "deschis",
    "deschisă": "deschis",
    "deschise": "deschis",
    "deschisei": "deschis",
    "deschisele": "deschis",
    "deschiselor": "deschis",
    "deschiși": "deschis",
    "deschișii": "deschis",
    "deschișilor": "deschis",
    "deschiso": "deschis",
    "deschisul": "deschis",
    "deschisule": "deschis",
    "deschisului": "deschis",
    "deschizătoarea": "deschizătoare",
    "deschizătoarei": "deschizătoare",
    "deschizătoarele": "deschizătoare",
    "deschizătoarelor": "deschizătoare",
    "deschizătoareo": "deschizătoare",
    "deschizătoare": "deschizător",
    "deschizătoarele": "deschizător",
    "deschizătoarelor": "deschizător",
    "deschizători": "deschizător",
    "deschizătorii": "deschizător",
    "deschizătorilor": "deschizător",
    "deschizătorul": "deschizător",
    "deschizătorule": "deschizător",
    "deschizătorului": "deschizător",
    "deschizătura": "deschizătură",
    "deschizături": "deschizătură",
    "deschizăturii": "deschizătură",
    "deschizăturile": "deschizătură",
    "deschizăturilor": "deschizătură",
    "deschizăturo": "deschizătură",
    "descifră": "descifra",
    "descifrai": "descifra",
    "descifram": "descifra",
    "descifrăm": "descifra",
    "descifrând": "descifra",
    "descifrându": "descifra",
    "descifrară": "descifra",
    "descifrarăm": "descifra",
    "descifrarăți": "descifra",
    "descifrase": "descifra",
    "descifrasem": "descifra",
    "descifraseră": "descifra",
    "descifraserăm": "descifra",
    "descifraserăți": "descifra",
    "descifraseși": "descifra",
    "descifrași": "descifra",
    "descifrat": "descifra",
    "descifrați": "descifra",
    "descifratu": "descifra",
    "descifrau": "descifra",
    "descifrează": "descifra",
    "descifrez": "descifra",
    "descifreze": "descifra",
    "descifrezi": "descifra",
    "nedescifrând": "descifra",
    "nedescifrându": "descifra",
    "nemaidescifrând": "descifra",
    "nemaidescifrându": "descifra",
    "descifrabila": "descifrabil",
    "descifrabilă": "descifrabil",
    "descifrabile": "descifrabil",
    "descifrabilei": "descifrabil",
    "descifrabilele": "descifrabil",
    "descifrabilelor": "descifrabil",
    "descifrabili": "descifrabil",
    "descifrabilii": "descifrabil",
    "descifrabililor": "descifrabil",
    "descifrabilo": "descifrabil",
    "descifrabilul": "descifrabil",
    "descifrabilule": "descifrabil",
    "descifrabilului": "descifrabil",
    "descifrarea": "descifrare",
    "descifrareo": "descifrare",
    "descifrări": "descifrare",
    "descifrării": "descifrare",
    "descifrările": "descifrare",
    "descifrărilor": "descifrare",
    "descifrată": "descifrat",
    "descifrate": "descifrat",
    "descifrați": "descifrat",
    "descind": "descinde",
    "descindă": "descinde",
    "descindea": "descinde",
    "descindeai": "descinde",
    "descindeam": "descinde",
    "descindeați": "descinde",
    "descindeau": "descinde",
    "descindem": "descinde",
    "descindeți": "descinde",
    "descins": "descinde",
    "descinse": "descinde",
    "descinsei": "descinde",
    "descinseră": "descinde",
    "descinserăm": "descinde",
    "descinserăți": "descinde",
    "descinsese": "descinde",
    "descinsesem": "descinde",
    "descinseseră": "descinde",
    "descinseserăm": "descinde",
    "descinseserăți": "descinde",
    "descinseseși": "descinde",
    "descinseși": "descinde",
    "descinsu": "descinde",
    "descinzând": "descinde",
    "descinzându": "descinde",
    "descinzi": "descinde",
    "nedescinzând": "descinde",
    "nedescinzându": "descinde",
    "nemaidescinzând": "descinde",
    "nemaidescinzându": "descinde",
    "descinderea": "descindere",
    "descindereo": "descindere",
    "descinderi": "descindere",
    "descinderii": "descindere",
    "descinderile": "descindere",
    "descinderilor": "descindere",
    "descing": "descinge",
    "descingă": "descinge",
    "descingând": "descinge",
    "descingându": "descinge",
    "descingea": "descinge",
    "descingeai": "descinge",
    "descingeam": "descinge",
    "descingeați": "descinge",
    "descingeau": "descinge",
    "descingem": "descinge",
    "descingeți": "descinge",
    "descingi": "descinge",
    "descins": "descinge",
    "descinse": "descinge",
    "descinsei": "descinge",
    "descinseră": "descinge",
    "descinserăm": "descinge",
    "descinserăți": "descinge",
    "descinsese": "descinge",
    "descinsesem": "descinge",
    "descinseseră": "descinge",
    "descinseserăm": "descinge",
    "descinseserăți": "descinge",
    "descinseseși": "descinge",
    "descinseși": "descinge",
    "descinsu": "descinge",
    "nedescingând": "descinge",
    "nedescingându": "descinge",
    "nemaidescingând": "descinge",
    "nemaidescingându": "descinge",
    "descinsa": "descins",
    "descinsă": "descins",
    "descinse": "descins",
    "descinsei": "descins",
    "descinsele": "descins",
    "descinselor": "descins",
    "descinși": "descins",
    "descinșii": "descins",
    "descinșilor": "descins",
    "descinso": "descins",
    "descinsul": "descins",
    "descinsule": "descins",
    "descinsului": "descins",
    "descleiai": "descleia",
    "descleiam": "descleia",
    "descleiară": "descleia",
    "descleiarăm": "descleia",
    "descleiarăți": "descleia",
    "descleiase": "descleia",
    "descleiasem": "descleia",
    "descleiaseră": "descleia",
    "descleiaserăm": "descleia",
    "descleiaserăți": "descleia",
    "descleiaseși": "descleia",
    "descleiași": "descleia",
    "descleiat": "descleia",
    "descleiați": "descleia",
    "descleiatu": "descleia",
    "descleiau": "descleia",
    "descleiază": "descleia",
    "descleie": "descleia",
    "descleiem": "descleia",
    "descleiez": "descleia",
    "descleieze": "descleia",
    "descleiezi": "descleia",
    "descleind": "descleia",
    "descleindu": "descleia",
    "nedescleind": "descleia",
    "nedescleindu": "descleia",
    "nemaidescleind": "descleia",
    "nemaidescleindu": "descleia",
    "descleiată": "descleiat",
    "descleiate": "descleiat",
    "descleiați": "descleiat",
    "descleierea": "descleiere",
    "descleiereo": "descleiere",
    "descleieri": "descleiere",
    "descleierii": "descleiere",
    "descleierile": "descleiere",
    "descleierilor": "descleiere",
    "descleștă": "descleșta",
    "descleștai": "descleșta",
    "descleștam": "descleșta",
    "descleștăm": "descleșta",
    "descleștând": "descleșta",
    "descleștându": "descleșta",
    "descleștară": "descleșta",
    "descleștarăm": "descleșta",
    "descleștarăți": "descleșta",
    "descleștase": "descleșta",
    "descleștasem": "descleșta",
    "descleștaseră": "descleșta",
    "descleștaserăm": "descleșta",
    "descleștaserăți": "descleșta",
    "descleștaseși": "descleșta",
    "descleștași": "descleșta",
    "descleștat": "descleșta",
    "descleștați": "descleșta",
    "descleștatu": "descleșta",
    "descleștau": "descleșta",
    "descleștează": "descleșta",
    "descleștez": "descleșta",
    "descleșteze": "descleșta",
    "descleștezi": "descleșta",
    "nedescleștând": "descleșta",
    "nedescleștându": "descleșta",
    "nemaidescleștând": "descleșta",
    "nemaidescleștându": "descleșta",
    "descleștarea": "descleștare",
    "descleștareo": "descleștare",
    "descleștări": "descleștare",
    "descleștării": "descleștare",
    "descleștările": "descleștare",
    "descleștărilor": "descleștare",
    "descleștată": "descleștat",
    "descleștate": "descleștat",
    "descleștați": "descleștat",
    "descoasă": "descoase",
    "descoasem": "descoase",
    "descoaseți": "descoase",
    "descos": "descoase",
    "descosând": "descoase",
    "descosându": "descoase",
    "descosea": "descoase",
    "descoseai": "descoase",
    "descoseam": "descoase",
    "descoseați": "descoase",
    "descoseau": "descoase",
    "descoși": "descoase",
    "descusu": "descoase",
    "descusui": "descoase",
    "descusură": "descoase",
    "descusurăm": "descoase",
    "descusurăți": "descoase",
    "descususe": "descoase",
    "descususem": "descoase",
    "descususeră": "descoase",
    "descususerăm": "descoase",
    "descususerăți": "descoase",
    "descususeși": "descoase",
    "descusuși": "descoase",
    "descusut": "descoase",
    "descusutu": "descoase",
    "descolăcea": "descolăci",
    "descolăceai": "descolăci",
    "descolăceam": "descolăci",
    "descolăcească": "descolăci",
    "descolăceați": "descolăci",
    "descolăceau": "descolăci",
    "descolăcesc": "descolăci",
    "descolăcește": "descolăci",
    "descolăcești": "descolăci",
    "descolăcii": "descolăci",
    "descolăcim": "descolăci",
    "descolăcind": "descolăci",
    "descolăcindu": "descolăci",
    "descolăciră": "descolăci",
    "descolăcirăm": "descolăci",
    "descolăcirăți": "descolăci",
    "descolăcise": "descolăci",
    "descolăcisem": "descolăci",
    "descolăciseră": "descolăci",
    "descolăciserăm": "descolăci",
    "descolăciserăți": "descolăci",
    "descolăciseși": "descolăci",
    "descolăciși": "descolăci",
    "descolăcit": "descolăci",
    "descolăciți": "descolăci",
    "descolăcitu": "descolăci",
    "nedescolăcind": "descolăci",
    "nedescolăcindu": "descolăci",
    "nemaidescolăcind": "descolăci",
    "nemaidescolăcindu": "descolăci",
    "descolăcită": "descolăcit",
    "descolăcite": "descolăcit",
    "descolăciți": "descolăcit",
    "descompletă": "descompleta",
    "descompletai": "descompleta",
    "descompletam": "descompleta",
    "descompletăm": "descompleta",
    "descompletând": "descompleta",
    "descompletându": "descompleta",
    "descompletară": "descompleta",
    "descompletarăm": "descompleta",
    "descompletarăți": "descompleta",
    "descompletase": "descompleta",
    "descompletasem": "descompleta",
    "descompletaseră": "descompleta",
    "descompletaserăm": "descompleta",
    "descompletaserăți": "descompleta",
    "descompletaseși": "descompleta",
    "descompletași": "descompleta",
    "descompletat": "descompleta",
    "descompletați": "descompleta",
    "descompletatu": "descompleta",
    "descompletau": "descompleta",
    "descompletarea": "descompletare",
    "descompletări": "descompletare",
    "descompletării": "descompletare",
    "descompletările": "descompletare",
    "descompletărilor": "descompletare",
    "descompletată": "descompletat",
    "descompletate": "descompletat",
    "descompletați": "descompletat",
    "descompui": "descompune",
    "descompun": "descompune",
    "descompună": "descompune",
    "descompunând": "descompune",
    "descompunându": "descompune",
    "descompunea": "descompune",
    "descompuneai": "descompune",
    "descompuneam": "descompune",
    "descompuneați": "descompune",
    "descompuneau": "descompune",
    "descompunem": "descompune",
    "descompuneți": "descompune",
    "descompus": "descompune",
    "descompuse": "descompune",
    "descompusei": "descompune",
    "descompuseră": "descompune",
    "descompuserăm": "descompune",
    "descompuserăți": "descompune",
    "descompusese": "descompune",
    "descompusesem": "descompune",
    "descompuseseră": "descompune",
    "descompuseserăm": "descompune",
    "descompuseserăți": "descompune",
    "descompuseseși": "descompune",
    "descompuseși": "descompune",
    "descompusu": "descompune",
    "descompunerea": "descompunere",
    "descompunereo": "descompunere",
    "descompuneri": "descompunere",
    "descompunerii": "descompunere",
    "descompunerile": "descompunere",
    "descompunerilor": "descompunere",
    "descompusa": "descompus",
    "descompusă": "descompus",
    "descompuse": "descompus",
    "descompusei": "descompus",
    "descompusele": "descompus",
    "descompuselor": "descompus",
    "descompuși": "descompus",
    "descompușii": "descompus",
    "descompușilor": "descompus",
    "descompuso": "descompus",
    "descompusul": "descompus",
    "descompusule": "descompus",
    "descompusului": "descompus",
    "desconsider": "desconsidera",
    "desconsideră": "desconsidera",
    "desconsiderai": "desconsidera",
    "desconsideram": "desconsidera",
    "desconsiderăm": "desconsidera",
    "desconsiderând": "desconsidera",
    "desconsiderându": "desconsidera",
    "desconsiderară": "desconsidera",
    "desconsiderarăm": "desconsidera",
    "desconsiderarăți": "desconsidera",
    "desconsiderase": "desconsidera",
    "desconsiderasem": "desconsidera",
    "desconsideraseră": "desconsidera",
    "desconsideraserăm": "desconsidera",
    "desconsideraserăți": "desconsidera",
    "desconsideraseși": "desconsidera",
    "desconsiderași": "desconsidera",
    "desconsiderat": "desconsidera",
    "desconsiderați": "desconsidera",
    "desconsideratu": "desconsidera",
    "desconsiderau": "desconsidera",
    "desconsidere": "desconsidera",
    "desconsideri": "desconsidera",
    "desconsiderarea": "desconsiderare",
    "desconsiderareo": "desconsiderare",
    "desconsiderări": "desconsiderare",
    "desconsiderării": "desconsiderare",
    "desconsiderările": "desconsiderare",
    "desconsiderărilor": "desconsiderare",
    "desconsiderată": "desconsiderat",
    "desconsiderate": "desconsiderat",
    "desconsiderați": "desconsiderat",
    "desconsiderația": "desconsiderație",
    "desconsiderației": "desconsiderație",
    "desconsiderații": "desconsiderație",
    "desconsiderațiile": "desconsiderație",
    "desconsiderațiilor": "desconsiderație",
    "desconsiderațio": "desconsiderație",
    "desconsiderațiunea": "desconsiderațiune",
    "desconsiderațiuneo": "desconsiderațiune",
    "desconsiderațiuni": "desconsiderațiune",
    "desconsiderațiunii": "desconsiderațiune",
    "desconsiderațiunile": "desconsiderațiune",
    "desconsiderațiunilor": "desconsiderațiune",
    "descopăr": "descoperi",
    "descoperă": "descoperi",
    "descopere": "descoperi",
    "descoperea": "descoperi",
    "descopereai": "descoperi",
    "descopeream": "descoperi",
    "descopereați": "descoperi",
    "descopereau": "descoperi",
    "descoperii": "descoperi",
    "descoperim": "descoperi",
    "descoperind": "descoperi",
    "descoperindu": "descoperi",
    "descoperiră": "descoperi",
    "descoperirăm": "descoperi",
    "descoperirăți": "descoperi",
    "descoperise": "descoperi",
    "descoperisem": "descoperi",
    "descoperiseră": "descoperi",
    "descoperiserăm": "descoperi",
    "descoperiserăți": "descoperi",
    "descoperiseși": "descoperi",
    "descoperiși": "descoperi",
    "descoperit": "descoperi",
    "descoperiți": "descoperi",
    "descoperitu": "descoperi",
    "nedescoperind": "descoperi",
    "nedescoperindu": "descoperi",
    "nemaidescoperind": "descoperi",
    "nemaidescoperindu": "descoperi",
    "descoperirea": "descoperire",
    "descoperireo": "descoperire",
    "descoperiri": "descoperire",
    "descoperirii": "descoperire",
    "descoperirile": "descoperire",
    "descoperirilor": "descoperire",
    "descoperita": "descoperit",
    "descoperită": "descoperit",
    "descoperite": "descoperit",
    "descoperitei": "descoperit",
    "descoperitele": "descoperit",
    "descoperitelor": "descoperit",
    "descoperiți": "descoperit",
    "descoperiții": "descoperit",
    "descoperiților": "descoperit",
    "descoperito": "descoperit",
    "descoperitul": "descoperit",
    "descoperitule": "descoperit",
    "descoperitului": "descoperit",
    "descoperitoarea": "descoperitoare",
    "descoperitoarei": "descoperitoare",
    "descoperitoarele": "descoperitoare",
    "descoperitoarelor": "descoperitoare",
    "descoperitoareo": "descoperitoare",
    "descoperitori": "descoperitor",
    "descoperitorii": "descoperitor",
    "descoperitorilor": "descoperitor",
    "descoperitorul": "descoperitor",
    "descoperitorule": "descoperitor",
    "descoperitorului": "descoperitor",
    "descotorosea": "descotorosi",
    "descotoroseai": "descotorosi",
    "descotoroseam": "descotorosi",
    "descotorosească": "descotorosi",
    "descotoroseați": "descotorosi",
    "descotoroseau": "descotorosi",
    "descotorosesc": "descotorosi",
    "descotorosește": "descotorosi",
    "descotorosești": "descotorosi",
    "descotorosii": "descotorosi",
    "descotorosim": "descotorosi",
    "descotorosind": "descotorosi",
    "descotorosindu": "descotorosi",
    "descotorosiră": "descotorosi",
    "descotorosirăm": "descotorosi",
    "descotorosirăți": "descotorosi",
    "descotorosise": "descotorosi",
    "descotorosisem": "descotorosi",
    "descotorosiseră": "descotorosi",
    "descotorosiserăm": "descotorosi",
    "descotorosiserăți": "descotorosi",
    "descotorosiseși": "descotorosi",
    "descotorosiși": "descotorosi",
    "descotorosit": "descotorosi",
    "descotorosiți": "descotorosi",
    "descotorositu": "descotorosi",
    "nedescotorosind": "descotorosi",
    "nedescotorosindu": "descotorosi",
    "nemaidescotorosind": "descotorosi",
    "nemaidescotorosindu": "descotorosi",
    "descotorosită": "descotorosit",
    "descotorosite": "descotorosit",
    "descotorosiți": "descotorosit",
    "descotoșmănea": "descotoșmăni",
    "descotoșmăneai": "descotoșmăni",
    "descotoșmăneam": "descotoșmăni",
    "descotoșmănească": "descotoșmăni",
    "descotoșmăneați": "descotoșmăni",
    "descotoșmăneau": "descotoșmăni",
    "descotoșmănesc": "descotoșmăni",
    "descotoșmănește": "descotoșmăni",
    "descotoșmănești": "descotoșmăni",
    "descotoșmănii": "descotoșmăni",
    "descotoșmănim": "descotoșmăni",
    "descotoșmănind": "descotoșmăni",
    "descotoșmănindu": "descotoșmăni",
    "descotoșmăniră": "descotoșmăni",
    "descotoșmănirăm": "descotoșmăni",
    "descotoșmănirăți": "descotoșmăni",
    "descotoșmănise": "descotoșmăni",
    "descotoșmănisem": "descotoșmăni",
    "descotoșmăniseră": "descotoșmăni",
    "descotoșmăniserăm": "descotoșmăni",
    "descotoșmăniserăți": "descotoșmăni",
    "descotoșmăniseși": "descotoșmăni",
    "descotoșmăniși": "descotoșmăni",
    "descotoșmănit": "descotoșmăni",
    "descotoșmăniți": "descotoșmăni",
    "descotoșmănitu": "descotoșmăni",
    "nedescotoșmănind": "descotoșmăni",
    "nedescotoșmănindu": "descotoșmăni",
    "nemaidescotoșmănind": "descotoșmăni",
    "nemaidescotoșmănindu": "descotoșmăni",
    "descotoșmănită": "descotoșmănit",
    "descotoșmănite": "descotoșmănit",
    "descotoșmăniți": "descotoșmănit",
    "descovoaie": "descovoia",
    "descovoi": "descovoia",
    "descovoiai": "descovoia",
    "descovoiam": "descovoia",
    "descovoiară": "descovoia",
    "descovoiarăm": "descovoia",
    "descovoiarăți": "descovoia",
    "descovoiase": "descovoia",
    "descovoiasem": "descovoia",
    "descovoiaseră": "descovoia",
    "descovoiaserăm": "descovoia",
    "descovoiaserăți": "descovoia",
    "descovoiaseși": "descovoia",
    "descovoiași": "descovoia",
    "descovoiat": "descovoia",
    "descovoiați": "descovoia",
    "descovoiatu": "descovoia",
    "descovoiau": "descovoia",
    "descovoie": "descovoia",
    "descovoiem": "descovoia",
    "descovoind": "descovoia",
    "descovoindu": "descovoia",
    "nedescovoind": "descovoia",
    "nedescovoindu": "descovoia",
    "nemaidescovoind": "descovoia",
    "nemaidescovoindu": "descovoia",
    "descovoiată": "descovoiat",
    "descovoiate": "descovoiat",
    "descovoiați": "descovoiat",
    "descreierarea": "descreierare",
    "descreierări": "descreierare",
    "descreierării": "descreierare",
    "descreierările": "descreierare",
    "descreierărilor": "descreierare",
    "descreierata": "descreierat",
    "descreierată": "descreierat",
    "descreierate": "descreierat",
    "descreieratei": "descreierat",
    "descreieratele": "descreierat",
    "descreieratelor": "descreierat",
    "descreierați": "descreierat",
    "descreierații": "descreierat",
    "descreieraților": "descreierat",
    "descreierato": "descreierat",
    "descreieratul": "descreierat",
    "descreieratule": "descreierat",
    "descreieratului": "descreierat",
    "descrescută": "descrescut",
    "descrescute": "descrescut",
    "descrescuți": "descrescut",
    "descrească": "descrește",
    "descresc": "descrește",
    "descrescând": "descrește",
    "descrescându": "descrește",
    "descrescu": "descrește",
    "descrescui": "descrește",
    "descrescură": "descrește",
    "descrescurăm": "descrește",
    "descrescurăți": "descrește",
    "descrescuse": "descrește",
    "descrescusem": "descrește",
    "descrescuseră": "descrește",
    "descrescuserăm": "descrește",
    "descrescuserăți": "descrește",
    "descrescuseși": "descrește",
    "descrescuși": "descrește",
    "descrescut": "descrește",
    "descrescutu": "descrește",
    "descreștea": "descrește",
    "descreșteai": "descrește",
    "descreșteam": "descrește",
    "descreșteați": "descrește",
    "descreșteau": "descrește",
    "descreștem": "descrește",
    "descreșteți": "descrește",
    "descrești": "descrește",
    "descreșterea": "descreștere",
    "descreștereo": "descreștere",
    "descreșteri": "descreștere",
    "descreșterii": "descreștere",
    "descreșterile": "descreștere",
    "descreșterilor": "descreștere",
    "descrețea": "descreți",
    "descrețeai": "descreți",
    "descrețeam": "descreți",
    "descrețească": "descreți",
    "descrețeați": "descreți",
    "descrețeau": "descreți",
    "descrețesc": "descreți",
    "descrețește": "descreți",
    "descrețești": "descreți",
    "descreții": "descreți",
    "descrețim": "descreți",
    "descrețind": "descreți",
    "descrețindu": "descreți",
    "descrețiră": "descreți",
    "descrețirăm": "descreți",
    "descrețirăți": "descreți",
    "descrețise": "descreți",
    "descrețisem": "descreți",
    "descrețiseră": "descreți",
    "descrețiserăm": "descreți",
    "descrețiserăți": "descreți",
    "descrețiseși": "descreți",
    "descrețiși": "descreți",
    "descrețit": "descreți",
    "descrețiți": "descreți",
    "descrețitu": "descreți",
    "nedescrețind": "descreți",
    "nedescrețindu": "descreți",
    "nemaidescrețind": "descreți",
    "nemaidescrețindu": "descreți",
    "descrețirea": "descrețire",
    "descrețireo": "descrețire",
    "descrețiri": "descrețire",
    "descrețirii": "descrețire",
    "descrețirile": "descrețire",
    "descrețirilor": "descrețire",
    "descrețita": "descrețit",
    "descrețită": "descrețit",
    "descrețite": "descrețit",
    "descrețitei": "descrețit",
    "descrețitele": "descrețit",
    "descrețitelor": "descrețit",
    "descrețiți": "descrețit",
    "descrețiții": "descrețit",
    "descrețiților": "descrețit",
    "descrețito": "descrețit",
    "descrețitul": "descrețit",
    "descrețitule": "descrețit",
    "descrețitului": "descrețit",
    "descria": "descrie",
    "descriai": "descrie",
    "descriam": "descrie",
    "descriați": "descrie",
    "descriau": "descrie",
    "descriem": "descrie",
    "descrieți": "descrie",
    "descrii": "descrie",
    "descriind": "descrie",
    "descriindu": "descrie",
    "descris": "descrie",
    "descrise": "descrie",
    "descrisei": "descrie",
    "descriseră": "descrie",
    "descriserăm": "descrie",
    "descriserăți": "descrie",
    "descrisese": "descrie",
    "descrisesem": "descrie",
    "descriseseră": "descrie",
    "descriseserăm": "descrie",
    "descriseserăți": "descrie",
    "descriseseși": "descrie",
    "descriseși": "descrie",
    "descrisu": "descrie",
    "descriu": "descrie",
    "nedescriind": "descrie",
    "nedescriindu": "descrie",
    "nemaidescriind": "descrie",
    "nemaidescriindu": "descrie",
    "descrierea": "descriere",
    "descriereo": "descriere",
    "descrieri": "descriere",
    "descrierii": "descriere",
    "descrierile": "descriere",
    "descrierilor": "descriere",
    "descriptiva": "descriptiv",
    "descriptivă": "descriptiv",
    "descriptive": "descriptiv",
    "descriptivei": "descriptiv",
    "descriptivele": "descriptiv",
    "descriptivelor": "descriptiv",
    "descriptivi": "descriptiv",
    "descriptivii": "descriptiv",
    "descriptivilor": "descriptiv",
    "descriptivo": "descriptiv",
    "descriptivul": "descriptiv",
    "descriptivule": "descriptiv",
    "descriptivului": "descriptiv",
    "descrisa": "descris",
    "descrisă": "descris",
    "descrise": "descris",
    "descrisei": "descris",
    "descrisele": "descris",
    "descriselor": "descris",
    "descriși": "descris",
    "descrișii": "descris",
    "descrișilor": "descris",
    "descriso": "descris",
    "descrisul": "descris",
    "descrisule": "descris",
    "descrisului": "descris",
    "descrucișă": "descrucișa",
    "descrucișai": "descrucișa",
    "descrucișam": "descrucișa",
    "descrucișăm": "descrucișa",
    "descrucișând": "descrucișa",
    "descrucișându": "descrucișa",
    "descrucișară": "descrucișa",
    "descrucișarăm": "descrucișa",
    "descrucișarăți": "descrucișa",
    "descrucișase": "descrucișa",
    "descrucișasem": "descrucișa",
    "descrucișaseră": "descrucișa",
    "descrucișaserăm": "descrucișa",
    "descrucișaserăți": "descrucișa",
    "descrucișaseși": "descrucișa",
    "descrucișași": "descrucișa",
    "descrucișat": "descrucișa",
    "descrucișați": "descrucișa",
    "descrucișatu": "descrucișa",
    "descrucișau": "descrucișa",
    "descrucișează": "descrucișa",
    "descrucișez": "descrucișa",
    "descrucișeze": "descrucișa",
    "descrucișezi": "descrucișa",
    "nedescrucișând": "descrucișa",
    "nedescrucișându": "descrucișa",
    "nemaidescrucișând": "descrucișa",
    "nemaidescrucișându": "descrucișa",
    "descrucișată": "descrucișat",
    "descrucișate": "descrucișat",
    "descrucișați": "descrucișat",
    "descrunt": "descrunta",
    "descruntă": "descrunta",
    "descruntai": "descrunta",
    "descruntam": "descrunta",
    "descruntăm": "descrunta",
    "descruntând": "descrunta",
    "descruntându": "descrunta",
    "descruntară": "descrunta",
    "descruntarăm": "descrunta",
    "descruntarăți": "descrunta",
    "descruntase": "descrunta",
    "descruntasem": "descrunta",
    "descruntaseră": "descrunta",
    "descruntaserăm": "descrunta",
    "descruntaserăți": "descrunta",
    "descruntaseși": "descrunta",
    "descruntași": "descrunta",
    "descruntat": "descrunta",
    "descruntați": "descrunta",
    "descruntatu": "descrunta",
    "descruntau": "descrunta",
    "descrunte": "descrunta",
    "descrunți": "descrunta",
    "nedescruntând": "descrunta",
    "nedescruntându": "descrunta",
    "nemaidescruntând": "descrunta",
    "nemaidescruntându": "descrunta",
    "descruntată": "descruntat",
    "descruntate": "descruntat",
    "descruntați": "descruntat",
    "descuamarea": "descuamare",
    "descuamareo": "descuamare",
    "descuamări": "descuamare",
    "descuamării": "descuamare",
    "descuamările": "descuamare",
    "descuamărilor": "descuamare",
    "descui": "descuia",
    "descuiai": "descuia",
    "descuiam": "descuia",
    "descuiară": "descuia",
    "descuiarăm": "descuia",
    "descuiarăți": "descuia",
    "descuiase": "descuia",
    "descuiasem": "descuia",
    "descuiaseră": "descuia",
    "descuiaserăm": "descuia",
    "descuiaserăți": "descuia",
    "descuiaseși": "descuia",
    "descuiași": "descuia",
    "descuiat": "descuia",
    "descuiați": "descuia",
    "descuiatu": "descuia",
    "descuiau": "descuia",
    "descuie": "descuia",
    "descuiem": "descuia",
    "descuind": "descuia",
    "descuindu": "descuia",
    "nedescuind": "descuia",
    "nedescuindu": "descuia",
    "nemaidescuind": "descuia",
    "nemaidescuindu": "descuia",
    "descuiata": "descuiat",
    "descuiată": "descuiat",
    "descuiate": "descuiat",
    "descuiatei": "descuiat",
    "descuiatele": "descuiat",
    "descuiatelor": "descuiat",
    "descuiați": "descuiat",
    "descuiații": "descuiat",
    "descuiaților": "descuiat",
    "descuiato": "descuiat",
    "descuiatul": "descuiat",
    "descuiatule": "descuiat",
    "descuiatului": "descuiat",
    "desculța": "desculț",
    "desculță": "desculț",
    "desculțe": "desculț",
    "desculței": "desculț",
    "desculțele": "desculț",
    "desculțelor": "desculț",
    "desculți": "desculț",
    "desculții": "desculț",
    "desculților": "desculț",
    "desculțo": "desculț",
    "desculțul": "desculț",
    "desculțule": "desculț",
    "desculțului": "desculț",
    "descumpănea": "descumpăni",
    "descumpăneai": "descumpăni",
    "descumpăneam": "descumpăni",
    "descumpănească": "descumpăni",
    "descumpăneați": "descumpăni",
    "descumpăneau": "descumpăni",
    "descumpănesc": "descumpăni",
    "descumpănește": "descumpăni",
    "descumpănești": "descumpăni",
    "descumpănii": "descumpăni",
    "descumpănim": "descumpăni",
    "descumpănind": "descumpăni",
    "descumpănindu": "descumpăni",
    "descumpăniră": "descumpăni",
    "descumpănirăm": "descumpăni",
    "descumpănirăți": "descumpăni",
    "descumpănise": "descumpăni",
    "descumpănisem": "descumpăni",
    "descumpăniseră": "descumpăni",
    "descumpăniserăm": "descumpăni",
    "descumpăniserăți": "descumpăni",
    "descumpăniseși": "descumpăni",
    "descumpăniși": "descumpăni",
    "descumpănit": "descumpăni",
    "descumpăniți": "descumpăni",
    "descumpănitu": "descumpăni",
    "descumpănirea": "descumpănire",
    "descumpăniri": "descumpănire",
    "descumpănirii": "descumpănire",
    "descumpănirile": "descumpănire",
    "descumpănirilor": "descumpănire",
    "descumpănita": "descumpănit",
    "descumpănită": "descumpănit",
    "descumpănite": "descumpănit",
    "descumpănitei": "descumpănit",
    "descumpănitele": "descumpănit",
    "descumpănitelor": "descumpănit",
    "descumpăniți": "descumpănit",
    "descumpăniții": "descumpănit",
    "descumpăniților": "descumpănit",
    "descumpănito": "descumpănit",
    "descumpănitul": "descumpănit",
    "descumpănitule": "descumpănit",
    "descumpănitului": "descumpănit",
    "descurajă": "descuraja",
    "descurajai": "descuraja",
    "descurajam": "descuraja",
    "descurajăm": "descuraja",
    "descurajând": "descuraja",
    "descurajându": "descuraja",
    "descurajară": "descuraja",
    "descurajarăm": "descuraja",
    "descurajarăți": "descuraja",
    "descurajase": "descuraja",
    "descurajasem": "descuraja",
    "descurajaseră": "descuraja",
    "descurajaserăm": "descuraja",
    "descurajaserăți": "descuraja",
    "descurajaseși": "descuraja",
    "descurajași": "descuraja",
    "descurajat": "descuraja",
    "descurajați": "descuraja",
    "descurajatu": "descuraja",
    "descurajau": "descuraja",
    "descurajează": "descuraja",
    "descurajez": "descuraja",
    "descurajeze": "descuraja",
    "descurajezi": "descuraja",
    "nedescurajând": "descuraja",
    "nedescurajându": "descuraja",
    "nemaidescurajând": "descuraja",
    "nemaidescurajându": "descuraja",
    "descurajanta": "descurajant",
    "descurajantă": "descurajant",
    "descurajante": "descurajant",
    "descurajantei": "descurajant",
    "descurajantele": "descurajant",
    "descurajantelor": "descurajant",
    "descurajanți": "descurajant",
    "descurajanții": "descurajant",
    "descurajanților": "descurajant",
    "descurajanto": "descurajant",
    "descurajantul": "descurajant",
    "descurajantule": "descurajant",
    "descurajantului": "descurajant",
    "descurajarea": "descurajare",
    "descurajareo": "descurajare",
    "descurajări": "descurajare",
    "descurajării": "descurajare",
    "descurajările": "descurajare",
    "descurajărilor": "descurajare",
    "descurajata": "descurajat",
    "descurajată": "descurajat",
    "descurajate": "descurajat",
    "descurajatei": "descurajat",
    "descurajatele": "descurajat",
    "descurajatelor": "descurajat",
    "descurajați": "descurajat",
    "descurajații": "descurajat",
    "descurajaților": "descurajat",
    "descurajato": "descurajat",
    "descurajatul": "descurajat",
    "descurajatule": "descurajat",
    "descurajatului": "descurajat",
    "descurajatoare": "descurajator",
    "descurajatoarea": "descurajator",
    "descurajatoarei": "descurajator",
    "descurajatoarele": "descurajator",
    "descurajatoarelor": "descurajator",
    "descurajatoareo": "descurajator",
    "descurajatori": "descurajator",
    "descurajatorii": "descurajator",
    "descurajatorilor": "descurajator",
    "descurajatorul": "descurajator",
    "descurajatorule": "descurajator",
    "descurajatorului": "descurajator",
    "descurc": "descurca",
    "descurcă": "descurca",
    "descurcai": "descurca",
    "descurcam": "descurca",
    "descurcăm": "descurca",
    "descurcând": "descurca",
    "descurcându": "descurca",
    "descurcară": "descurca",
    "descurcarăm": "descurca",
    "descurcarăți": "descurca",
    "descurcase": "descurca",
    "descurcasem": "descurca",
    "descurcaseră": "descurca",
    "descurcaserăm": "descurca",
    "descurcaserăți": "descurca",
    "descurcaseși": "descurca",
    "descurcași": "descurca",
    "descurcat": "descurca",
    "descurcați": "descurca",
    "descurcatu": "descurca",
    "descurcau": "descurca",
    "descurce": "descurca",
    "descurci": "descurca",
    "nedescurcând": "descurca",
    "nedescurcându": "descurca",
    "nemaidescurcând": "descurca",
    "nemaidescurcându": "descurca",
    "descurcăreața": "descurcăreață",
    "descurcăreațo": "descurcăreață",
    "descurcărețe": "descurcăreață",
    "descurcăreței": "descurcăreață",
    "descurcărețele": "descurcăreață",
    "descurcărețelor": "descurcăreață",
    "descurcăreața": "descurcăreț",
    "descurcăreață": "descurcăreț",
    "descurcăreațo": "descurcăreț",
    "descurcărețe": "descurcăreț",
    "descurcăreței": "descurcăreț",
    "descurcărețele": "descurcăreț",
    "descurcărețelor": "descurcăreț",
    "descurcăreți": "descurcăreț",
    "descurcăreții": "descurcăreț",
    "descurcăreților": "descurcăreț",
    "descurcărețul": "descurcăreț",
    "descurcărețule": "descurcăreț",
    "descurcărețului": "descurcăreț",
    "descurcată": "descurcat",
    "descurcate": "descurcat",
    "descurcați": "descurcat",
    "descusuta": "descusut",
    "descusută": "descusut",
    "descusute": "descusut",
    "descusutei": "descusut",
    "descusutele": "descusut",
    "descusutelor": "descusut",
    "descusuți": "descusut",
    "descusuții": "descusut",
    "descusuților": "descusut",
    "descusuto": "descusut",
    "descusutul": "descusut",
    "descusutule": "descusut",
    "descusutului": "descusut",
    "desecarea": "desecare",
    "desecareo": "desecare",
    "desecări": "desecare",
    "desecării": "desecare",
    "desecările": "desecare",
    "desecărilor": "desecare",
    "deșeală": "deșela",
    "deșel": "deșela",
    "deșelă": "deșela",
    "deșelai": "deșela",
    "deșelam": "deșela",
    "deșelăm": "deșela",
    "deșelând": "deșela",
    "deșelându": "deșela",
    "deșelară": "deșela",
    "deșelarăm": "deșela",
    "deșelarăți": "deșela",
    "deșelase": "deșela",
    "deșelasem": "deșela",
    "deșelaseră": "deșela",
    "deșelaserăm": "deșela",
    "deșelaserăți": "deșela",
    "deșelaseși": "deșela",
    "deșelași": "deșela",
    "deșelat": "deșela",
    "deșelați": "deșela",
    "deșelatu": "deșela",
    "deșelau": "deșela",
    "deșele": "deșela",
    "deșeli": "deșela",
    "nedeșelând": "deșela",
    "nedeșelându": "deșela",
    "nemaideșelând": "deșela",
    "nemaideșelându": "deșela",
    "deșelata": "deșelat",
    "deșelată": "deșelat",
    "deșelate": "deșelat",
    "deșelatei": "deșelat",
    "deșelatele": "deșelat",
    "deșelatelor": "deșelat",
    "deșelați": "deșelat",
    "deșelații": "deșelat",
    "deșelaților": "deșelat",
    "deșelato": "deșelat",
    "deșelatul": "deșelat",
    "deșelatule": "deșelat",
    "deșelatului": "deșelat",
    "desemnă": "desemna",
    "desemnai": "desemna",
    "desemnam": "desemna",
    "desemnăm": "desemna",
    "desemnând": "desemna",
    "desemnându": "desemna",
    "desemnară": "desemna",
    "desemnarăm": "desemna",
    "desemnarăți": "desemna",
    "desemnase": "desemna",
    "desemnasem": "desemna",
    "desemnaseră": "desemna",
    "desemnaserăm": "desemna",
    "desemnaserăți": "desemna",
    "desemnaseși": "desemna",
    "desemnași": "desemna",
    "desemnat": "desemna",
    "desemnați": "desemna",
    "desemnatu": "desemna",
    "desemnau": "desemna",
    "desemnează": "desemna",
    "desemnez": "desemna",
    "desemneze": "desemna",
    "desemnezi": "desemna",
    "nedesemnând": "desemna",
    "nedesemnându": "desemna",
    "nemaidesemnând": "desemna",
    "nemaidesemnându": "desemna",
    "desemnarea": "desemnare",
    "desemnareo": "desemnare",
    "desemnări": "desemnare",
    "desemnării": "desemnare",
    "desemnările": "desemnare",
    "desemnărilor": "desemnare",
    "desemnată": "desemnat",
    "desemnate": "desemnat",
    "desemnați": "desemnat",
    "desene": "desen",
    "desenele": "desen",
    "desenelor": "desen",
    "desenul": "desen",
    "desenule": "desen",
    "desenului": "desen",
    "desenă": "desena",
    "desenai": "desena",
    "desenam": "desena",
    "desenăm": "desena",
    "desenând": "desena",
    "desenându": "desena",
    "desenară": "desena",
    "desenarăm": "desena",
    "desenarăți": "desena",
    "desenase": "desena",
    "desenasem": "desena",
    "desenaseră": "desena",
    "desenaserăm": "desena",
    "desenaserăți": "desena",
    "desenaseși": "desena",
    "desenași": "desena",
    "desenat": "desena",
    "desenați": "desena",
    "desenatu": "desena",
    "desenau": "desena",
    "desenează": "desena",
    "desenez": "desena",
    "deseneze": "desena",
    "desenezi": "desena",
    "nedesenând": "desena",
    "nedesenându": "desena",
    "nemaidesenând": "desena",
    "nemaidesenându": "desena",
    "desenarea": "desenare",
    "desenareo": "desenare",
    "desenări": "desenare",
    "desenării": "desenare",
    "desenările": "desenare",
    "desenărilor": "desenare",
    "desenată": "desenat",
    "desenate": "desenat",
    "desenați": "desenat",
    "desenatul": "desenat",
    "desenatule": "desenat",
    "desenatului": "desenat",
    "desenatoarea": "desenatoare",
    "desenatoarei": "desenatoare",
    "desenatoarele": "desenatoare",
    "desenatoarelor": "desenatoare",
    "desenatoareo": "desenatoare",
    "desenatori": "desenator",
    "desenatorii": "desenator",
    "desenatorilor": "desenator",
    "desenatorul": "desenator",
    "desenatorule": "desenator",
    "desenatorului": "desenator",
    "desertul": "desert",
    "desertule": "desert",
    "desertului": "desert",
    "deserturi": "desert",
    "deserturile": "desert",
    "deserturilor": "desert",
    "deșarta": "deșert",
    "deșartă": "deșert",
    "deșarte": "deșert",
    "deșarto": "deșert",
    "deșertei": "deșert",
    "deșertele": "deșert",
    "deșertelor": "deșert",
    "deșerți": "deșert",
    "deșerții": "deșert",
    "deșerților": "deșert",
    "deșertul": "deșert",
    "deșertule": "deșert",
    "deșertului": "deșert",
    "deșerturi": "deșert",
    "deșerturile": "deșert",
    "deșerturilor": "deșert",
    "deșeartă": "deșerta",
    "deșert": "deșerta",
    "deșertă": "deșerta",
    "deșertai": "deșerta",
    "deșertam": "deșerta",
    "deșertăm": "deșerta",
    "deșertând": "deșerta",
    "deșertându": "deșerta",
    "deșertară": "deșerta",
    "deșertarăm": "deșerta",
    "deșertarăți": "deșerta",
    "deșertase": "deșerta",
    "deșertasem": "deșerta",
    "deșertaseră": "deșerta",
    "deșertaserăm": "deșerta",
    "deșertaserăți": "deșerta",
    "deșertaseși": "deșerta",
    "deșertași": "deșerta",
    "deșertat": "deșerta",
    "deșertați": "deșerta",
    "deșertatu": "deșerta",
    "deșertau": "deșerta",
    "deșerte": "deșerta",
    "deșerți": "deșerta",
    "nedeșertând": "deșerta",
    "nedeșertându": "deșerta",
    "nemaideșertând": "deșerta",
    "nemaideșertându": "deșerta",
    "deșertăciunea": "deșertăciune",
    "deșertăciuneo": "deșertăciune",
    "deșertăciuni": "deșertăciune",
    "deșertăciunii": "deșertăciune",
    "deșertăciunile": "deșertăciune",
    "deșertăciunilor": "deșertăciune",
    "deșertarea": "deșertare",
    "deșertareo": "deșertare",
    "deșertări": "deșertare",
    "deșertării": "deșertare",
    "deșertările": "deșertare",
    "deșertărilor": "deșertare",
    "deșertata": "deșertat",
    "deșertată": "deșertat",
    "deșertate": "deșertat",
    "deșertatei": "deșertat",
    "deșertatele": "deșertat",
    "deșertatelor": "deșertat",
    "deșertați": "deșertat",
    "deșertații": "deșertat",
    "deșertaților": "deșertat",
    "deșertato": "deșertat",
    "deșertatul": "deșertat",
    "deșertatule": "deșertat",
    "deșertatului": "deșertat",
    "deserventa": "deservent",
    "deserventă": "deservent",
    "deservente": "deservent",
    "deserventei": "deservent",
    "deserventele": "deservent",
    "deserventelor": "deservent",
    "deservenți": "deservent",
    "deservenții": "deservent",
    "deservenților": "deservent",
    "deservento": "deservent",
    "deserventul": "deservent",
    "deserventule": "deservent",
    "deserventului": "deservent",
    "deservea": "deservi",
    "deserveai": "deservi",
    "deserveam": "deservi",
    "deservească": "deservi",
    "deserveați": "deservi",
    "deserveau": "deservi",
    "deservesc": "deservi",
    "deservește": "deservi",
    "deservești": "deservi",
    "deservii": "deservi",
    "deservim": "deservi",
    "deservind": "deservi",
    "deservindu": "deservi",
    "deserviră": "deservi",
    "deservirăm": "deservi",
    "deservirăți": "deservi",
    "deservise": "deservi",
    "deservisem": "deservi",
    "deserviseră": "deservi",
    "deserviserăm": "deservi",
    "deserviserăți": "deservi",
    "deserviseși": "deservi",
    "deserviși": "deservi",
    "deservit": "deservi",
    "deserviți": "deservi",
    "deservitu": "deservi",
    "nedeservind": "deservi",
    "nedeservindu": "deservi",
    "nemaideservind": "deservi",
    "nemaideservindu": "deservi",
    "deservirea": "deservire",
    "deservireo": "deservire",
    "deserviri": "deservire",
    "deservirii": "deservire",
    "deservirile": "deservire",
    "deservirilor": "deservire",
    "deservită": "deservit",
    "deservite": "deservit",
    "deserviți": "deservit",
    "desesiză": "desesiza",
    "desesizai": "desesiza",
    "desesizam": "desesiza",
    "desesizăm": "desesiza",
    "desesizând": "desesiza",
    "desesizându": "desesiza",
    "desesizară": "desesiza",
    "desesizarăm": "desesiza",
    "desesizarăți": "desesiza",
    "desesizase": "desesiza",
    "desesizasem": "desesiza",
    "desesizaseră": "desesiza",
    "desesizaserăm": "desesiza",
    "desesizaserăți": "desesiza",
    "desesizaseși": "desesiza",
    "desesizași": "desesiza",
    "desesizat": "desesiza",
    "desesizați": "desesiza",
    "desesizatu": "desesiza",
    "desesizau": "desesiza",
    "desesizează": "desesiza",
    "desesizez": "desesiza",
    "desesizeze": "desesiza",
    "desesizezi": "desesiza",
    "nedesesizând": "desesiza",
    "nedesesizându": "desesiza",
    "nemaidesesizând": "desesiza",
    "nemaidesesizându": "desesiza",
    "desesizarea": "desesizare",
    "desesizareo": "desesizare",
    "desesizări": "desesizare",
    "desesizării": "desesizare",
    "desesizările": "desesizare",
    "desesizărilor": "desesizare",
    "desesizată": "desesizat",
    "desesizate": "desesizat",
    "desesizați": "desesizat",
    "deșeul": "deșeu",
    "deșeule": "deșeu",
    "deșeului": "deșeu",
    "deșeuri": "deșeu",
    "deșeurile": "deșeu",
    "deșeurilor": "deșeu",
    "deșeuă": "deșeua",
    "deșeuai": "deșeua",
    "deșeuam": "deșeua",
    "deșeuăm": "deșeua",
    "deșeuând": "deșeua",
    "deșeuându": "deșeua",
    "deșeuară": "deșeua",
    "deșeuarăm": "deșeua",
    "deșeuarăți": "deșeua",
    "deșeuase": "deșeua",
    "deșeuasem": "deșeua",
    "deșeuaseră": "deșeua",
    "deșeuaserăm": "deșeua",
    "deșeuaserăți": "deșeua",
    "deșeuaseși": "deșeua",
    "deșeuași": "deșeua",
    "deșeuat": "deșeua",
    "deșeuați": "deșeua",
    "deșeuatu": "deșeua",
    "deșeuau": "deșeua",
    "deșeuează": "deșeua",
    "deșeuez": "deșeua",
    "deșeueze": "deșeua",
    "deșeuezi": "deșeua",
    "nedeșeuând": "deșeua",
    "nedeșeuându": "deșeua",
    "nemaideșeuând": "deșeua",
    "nemaideșeuându": "deșeua",
    "deșeuata": "deșeuat",
    "deșeuată": "deșeuat",
    "deșeuate": "deșeuat",
    "deșeuatei": "deșeuat",
    "deșeuatele": "deșeuat",
    "deșeuatelor": "deșeuat",
    "deșeuați": "deșeuat",
    "deșeuații": "deșeuat",
    "deșeuaților": "deșeuat",
    "deșeuato": "deșeuat",
    "deșeuatul": "deșeuat",
    "deșeuatule": "deșeuat",
    "deșeuatului": "deșeuat",
    "desfă": "desface",
    "desfac": "desface",
    "desfacă": "desface",
    "desfăcând": "desface",
    "desfăcându": "desface",
    "desfăcea": "desface",
    "desfăceai": "desface",
    "desfăceam": "desface",
    "desfăceați": "desface",
    "desfăceau": "desface",
    "desfacem": "desface",
    "desfaceți": "desface",
    "desfaci": "desface",
    "desfăcu": "desface",
    "desfăcui": "desface",
    "desfăcură": "desface",
    "desfăcurăm": "desface",
    "desfăcurăți": "desface",
    "desfăcuse": "desface",
    "desfăcusem": "desface",
    "desfăcuseră": "desface",
    "desfăcuserăm": "desface",
    "desfăcuserăți": "desface",
    "desfăcuseși": "desface",
    "desfăcuși": "desface",
    "desfăcut": "desface",
    "desfăcutu": "desface",
    "nedesfăcând": "desface",
    "nedesfăcându": "desface",
    "nemaidesfăcând": "desface",
    "nemaidesfăcându": "desface",
    "desfac.": "desfacere",
    "desfacerea": "desfacere",
    "desfacereo": "desfacere",
    "desfaceri": "desfacere",
    "desfacerii": "desfacere",
    "desfacerile": "desfacere",
    "desfacerilor": "desfacere",
    "desfăcută": "desfăcut",
    "desfăcute": "desfăcut",
    "desfăcuți": "desfăcut",
    "desfăș": "desfășa",
    "desfașă": "desfășa",
    "desfășă": "desfășa",
    "desfășai": "desfășa",
    "desfășam": "desfășa",
    "desfășăm": "desfășa",
    "desfășând": "desfășa",
    "desfășându": "desfășa",
    "desfășară": "desfășa",
    "desfășarăm": "desfășa",
    "desfășarăți": "desfășa",
    "desfășase": "desfășa",
    "desfășasem": "desfășa",
    "desfășaseră": "desfășa",
    "desfășaserăm": "desfășa",
    "desfășaserăți": "desfășa",
    "desfășaseși": "desfășa",
    "desfășași": "desfășa",
    "desfășat": "desfășa",
    "desfășați": "desfășa",
    "desfășatu": "desfășa",
    "desfășau": "desfășa",
    "desfașe": "desfășa",
    "desfeși": "desfășa",
    "nedesfășând": "desfășa",
    "nedesfășându": "desfășa",
    "nemaidesfășând": "desfășa",
    "nemaidesfășându": "desfășa",
    "desfășata": "desfășat",
    "desfășată": "desfășat",
    "desfășate": "desfășat",
    "desfășatei": "desfășat",
    "desfășatele": "desfășat",
    "desfășatelor": "desfășat",
    "desfășați": "desfășat",
    "desfășații": "desfășat",
    "desfășaților": "desfășat",
    "desfășato": "desfășat",
    "desfășatul": "desfășat",
    "desfășatule": "desfășat",
    "desfășatului": "desfășat",
    "desfășoară": "desfășura",
    "desfășoare": "desfășura",
    "desfășor": "desfășura",
    "desfășori": "desfășura",
    "desfășură": "desfășura",
    "desfășurai": "desfășura",
    "desfășuram": "desfășura",
    "desfășurăm": "desfășura",
    "desfășurând": "desfășura",
    "desfășurându": "desfășura",
    "desfășurară": "desfășura",
    "desfășurarăm": "desfășura",
    "desfășurarăți": "desfășura",
    "desfășurase": "desfășura",
    "desfășurasem": "desfășura",
    "desfășuraseră": "desfășura",
    "desfășuraserăm": "desfășura",
    "desfășuraserăți": "desfășura",
    "desfășuraseși": "desfășura",
    "desfășurași": "desfășura",
    "desfășurat": "desfășura",
    "desfășurați": "desfășura",
    "desfășuratu": "desfășura",
    "desfășurau": "desfășura",
    "nedesfășurând": "desfășura",
    "nedesfășurându": "desfășura",
    "nemaidesfășurând": "desfășura",
    "nemaidesfășurându": "desfășura",
    "desfășurarea": "desfășurare",
    "desfășurareo": "desfășurare",
    "desfășurări": "desfășurare",
    "desfășurării": "desfășurare",
    "desfășurările": "desfășurare",
    "desfășurărilor": "desfășurare",
    "desfășurata": "desfășurat",
    "desfășurată": "desfășurat",
    "desfășurate": "desfășurat",
    "desfășuratei": "desfășurat",
    "desfășuratele": "desfășurat",
    "desfășuratelor": "desfășurat",
    "desfășurați": "desfășurat",
    "desfășurații": "desfășurat",
    "desfășuraților": "desfășurat",
    "desfășurato": "desfășurat",
    "desfășuratul": "desfășurat",
    "desfășuratule": "desfășurat",
    "desfășuratului": "desfășurat",
    "desfăt": "desfăta",
    "desfată": "desfăta",
    "desfătă": "desfăta",
    "desfătai": "desfăta",
    "desfătam": "desfăta",
    "desfătăm": "desfăta",
    "desfătând": "desfăta",
    "desfătându": "desfăta",
    "desfătară": "desfăta",
    "desfătarăm": "desfăta",
    "desfătarăți": "desfăta",
    "desfătase": "desfăta",
    "desfătasem": "desfăta",
    "desfătaseră": "desfăta",
    "desfătaserăm": "desfăta",
    "desfătaserăți": "desfăta",
    "desfătaseși": "desfăta",
    "desfătași": "desfăta",
    "desfătat": "desfăta",
    "desfătați": "desfăta",
    "desfătatu": "desfăta",
    "desfătau": "desfăta",
    "desfete": "desfăta",
    "desfeți": "desfăta",
    "nedesfătând": "desfăta",
    "nedesfătându": "desfăta",
    "nemaidesfătând": "desfăta",
    "nemaidesfătându": "desfăta",
    "desfăț": "desfăța",
    "desfață": "desfăța",
    "desfăță": "desfăța",
    "desfățai": "desfăța",
    "desfățam": "desfăța",
    "desfățăm": "desfăța",
    "desfățând": "desfăța",
    "desfățându": "desfăța",
    "desfățară": "desfăța",
    "desfățarăm": "desfăța",
    "desfățarăți": "desfăța",
    "desfățase": "desfăța",
    "desfățasem": "desfăța",
    "desfățaseră": "desfăța",
    "desfățaserăm": "desfăța",
    "desfățaserăți": "desfăța",
    "desfățaseși": "desfăța",
    "desfățași": "desfăța",
    "desfățat": "desfăța",
    "desfățați": "desfăța",
    "desfățatu": "desfăța",
    "desfățau": "desfăța",
    "desfețe": "desfăța",
    "desfeți": "desfăța",
    "nedesfățând": "desfăța",
    "nedesfățându": "desfăța",
    "nemaidesfățând": "desfăța",
    "nemaidesfățându": "desfăța",
    "desfătarea": "desfătare",
    "desfătareo": "desfătare",
    "desfătări": "desfătare",
    "desfătării": "desfătare",
    "desfătările": "desfătare",
    "desfătărilor": "desfătare",
    "desfătată": "desfătat",
    "desfătate": "desfătat",
    "desfătați": "desfătat",
    "desfățata": "desfățat",
    "desfățată": "desfățat",
    "desfățate": "desfățat",
    "desfățatei": "desfățat",
    "desfățatele": "desfățat",
    "desfățatelor": "desfățat",
    "desfățați": "desfățat",
    "desfățații": "desfățat",
    "desfățaților": "desfățat",
    "desfățato": "desfățat",
    "desfățatul": "desfățat",
    "desfățatule": "desfățat",
    "desfățatului": "desfățat",
    "desfătătoare": "desfătător",
    "desfătătoarea": "desfătător",
    "desfătătoarei": "desfătător",
    "desfătătoarele": "desfătător",
    "desfătătoarelor": "desfătător",
    "desfătătoareo": "desfătător",
    "desfătători": "desfătător",
    "desfătătorii": "desfătător",
    "desfătătorilor": "desfătător",
    "desfătătorul": "desfătător",
    "desfătătorule": "desfătător",
    "desfătătorului": "desfătător",
    "desfid": "desfide",
    "desfidă": "desfide",
    "desfidea": "desfide",
    "desfideai": "desfide",
    "desfideam": "desfide",
    "desfideați": "desfide",
    "desfideau": "desfide",
    "desfidem": "desfide",
    "desfideți": "desfide",
    "desfizi": "desfide",
    "desfigură": "desfigura",
    "desfigurai": "desfigura",
    "desfiguram": "desfigura",
    "desfigurăm": "desfigura",
    "desfigurând": "desfigura",
    "desfigurându": "desfigura",
    "desfigurară": "desfigura",
    "desfigurarăm": "desfigura",
    "desfigurarăți": "desfigura",
    "desfigurase": "desfigura",
    "desfigurasem": "desfigura",
    "desfiguraseră": "desfigura",
    "desfiguraserăm": "desfigura",
    "desfiguraserăți": "desfigura",
    "desfiguraseși": "desfigura",
    "desfigurași": "desfigura",
    "desfigurat": "desfigura",
    "desfigurați": "desfigura",
    "desfiguratu": "desfigura",
    "desfigurau": "desfigura",
    "desfigurează": "desfigura",
    "desfigurez": "desfigura",
    "desfigureze": "desfigura",
    "desfigurezi": "desfigura",
    "nedesfigurând": "desfigura",
    "nedesfigurându": "desfigura",
    "nemaidesfigurând": "desfigura",
    "nemaidesfigurându": "desfigura",
    "desfigurarea": "desfigurare",
    "desfigurareo": "desfigurare",
    "desfigurări": "desfigurare",
    "desfigurării": "desfigurare",
    "desfigurările": "desfigurare",
    "desfigurărilor": "desfigurare",
    "desfigurata": "desfigurat",
    "desfigurată": "desfigurat",
    "desfigurate": "desfigurat",
    "desfiguratei": "desfigurat",
    "desfiguratele": "desfigurat",
    "desfiguratelor": "desfigurat",
    "desfigurați": "desfigurat",
    "desfigurații": "desfigurat",
    "desfiguraților": "desfigurat",
    "desfigurato": "desfigurat",
    "desfiguratul": "desfigurat",
    "desfiguratule": "desfigurat",
    "desfiguratului": "desfigurat",
    "desființă": "desființa",
    "desființai": "desființa",
    "desființam": "desființa",
    "desființăm": "desființa",
    "desființând": "desființa",
    "desființându": "desființa",
    "desființară": "desființa",
    "desființarăm": "desființa",
    "desființarăți": "desființa",
    "desființase": "desființa",
    "desființasem": "desființa",
    "desființaseră": "desființa",
    "desființaserăm": "desființa",
    "desființaserăți": "desființa",
    "desființaseși": "desființa",
    "desființași": "desființa",
    "desființat": "desființa",
    "desființați": "desființa",
    "desființatu": "desființa",
    "desființau": "desființa",
    "desființează": "desființa",
    "desființez": "desființa",
    "desființeze": "desființa",
    "desființezi": "desființa",
    "nedesființând": "desființa",
    "nedesființându": "desființa",
    "nemaidesființând": "desființa",
    "nemaidesființându": "desființa",
    "desființarea": "desființare",
    "desființareo": "desființare",
    "desființări": "desființare",
    "desființării": "desființare",
    "desființările": "desființare",
    "desființărilor": "desființare",
    "desființata": "desființat",
    "desființată": "desființat",
    "desființate": "desființat",
    "desființatei": "desființat",
    "desființatele": "desființat",
    "desființatelor": "desființat",
    "desființați": "desființat",
    "desființații": "desființat",
    "desființaților": "desființat",
    "desființato": "desființat",
    "desființatul": "desființat",
    "desființatule": "desființat",
    "desființatului": "desființat",
    "desfoaie": "desfoia",
    "desfoi": "desfoia",
    "desfoiai": "desfoia",
    "desfoiam": "desfoia",
    "desfoiară": "desfoia",
    "desfoiarăm": "desfoia",
    "desfoiarăți": "desfoia",
    "desfoiase": "desfoia",
    "desfoiasem": "desfoia",
    "desfoiaseră": "desfoia",
    "desfoiaserăm": "desfoia",
    "desfoiaserăți": "desfoia",
    "desfoiaseși": "desfoia",
    "desfoiași": "desfoia",
    "desfoiat": "desfoia",
    "desfoiați": "desfoia",
    "desfoiatu": "desfoia",
    "desfoiau": "desfoia",
    "desfoie": "desfoia",
    "desfoiem": "desfoia",
    "desfoind": "desfoia",
    "desfoindu": "desfoia",
    "nedesfoind": "desfoia",
    "nedesfoindu": "desfoia",
    "nemaidesfoind": "desfoia",
    "nemaidesfoindu": "desfoia",
    "desfoiata": "desfoiat",
    "desfoiată": "desfoiat",
    "desfoiate": "desfoiat",
    "desfoiatei": "desfoiat",
    "desfoiatele": "desfoiat",
    "desfoiatelor": "desfoiat",
    "desfoiați": "desfoiat",
    "desfoiații": "desfoiat",
    "desfoiaților": "desfoiat",
    "desfoiato": "desfoiat",
    "desfoiatul": "desfoiat",
    "desfoiatule": "desfoiat",
    "desfoiatului": "desfoiat",
    "desfrână": "desfrâna",
    "desfrânai": "desfrâna",
    "desfrânam": "desfrâna",
    "desfrânăm": "desfrâna",
    "desfrânând": "desfrâna",
    "desfrânându": "desfrâna",
    "desfrânară": "desfrâna",
    "desfrânarăm": "desfrâna",
    "desfrânarăți": "desfrâna",
    "desfrânase": "desfrâna",
    "desfrânasem": "desfrâna",
    "desfrânaseră": "desfrâna",
    "desfrânaserăm": "desfrâna",
    "desfrânaserăți": "desfrâna",
    "desfrânaseși": "desfrâna",
    "desfrânași": "desfrâna",
    "desfrânat": "desfrâna",
    "desfrânați": "desfrâna",
    "desfrânatu": "desfrâna",
    "desfrânau": "desfrâna",
    "desfrânează": "desfrâna",
    "desfrânez": "desfrâna",
    "desfrâneze": "desfrâna",
    "desfrânezi": "desfrâna",
    "nedesfrânând": "desfrâna",
    "nedesfrânându": "desfrâna",
    "nemaidesfrânând": "desfrâna",
    "nemaidesfrânându": "desfrâna",
    "desfrânarea": "desfrânare",
    "desfrânareo": "desfrânare",
    "desfrânări": "desfrânare",
    "desfrânării": "desfrânare",
    "desfrânările": "desfrânare",
    "desfrânărilor": "desfrânare",
    "desfrânata": "desfrânat",
    "desfrânată": "desfrânat",
    "desfrânate": "desfrânat",
    "desfrânatei": "desfrânat",
    "desfrânatele": "desfrânat",
    "desfrânatelor": "desfrânat",
    "desfrânați": "desfrânat",
    "desfrânații": "desfrânat",
    "desfrânaților": "desfrânat",
    "desfrânato": "desfrânat",
    "desfrânatul": "desfrânat",
    "desfrânatule": "desfrânat",
    "desfrânatului": "desfrânat",
    "desfrâul": "desfrâu",
    "desfrâule": "desfrâu",
    "desfrâului": "desfrâu",
    "desfrâuri": "desfrâu",
    "desfrâurile": "desfrâu",
    "desfrâurilor": "desfrâu",
    "desfrunzea": "desfrunzi",
    "desfrunzeai": "desfrunzi",
    "desfrunzeam": "desfrunzi",
    "desfrunzească": "desfrunzi",
    "desfrunzeați": "desfrunzi",
    "desfrunzeau": "desfrunzi",
    "desfrunzesc": "desfrunzi",
    "desfrunzește": "desfrunzi",
    "desfrunzești": "desfrunzi",
    "desfrunzii": "desfrunzi",
    "desfrunzim": "desfrunzi",
    "desfrunzind": "desfrunzi",
    "desfrunzindu": "desfrunzi",
    "desfrunziră": "desfrunzi",
    "desfrunzirăm": "desfrunzi",
    "desfrunzirăți": "desfrunzi",
    "desfrunzise": "desfrunzi",
    "desfrunzisem": "desfrunzi",
    "desfrunziseră": "desfrunzi",
    "desfrunziserăm": "desfrunzi",
    "desfrunziserăți": "desfrunzi",
    "desfrunziseși": "desfrunzi",
    "desfrunziși": "desfrunzi",
    "desfrunzit": "desfrunzi",
    "desfrunziți": "desfrunzi",
    "desfrunzitu": "desfrunzi",
    "nedesfrunzind": "desfrunzi",
    "nedesfrunzindu": "desfrunzi",
    "nemaidesfrunzind": "desfrunzi",
    "nemaidesfrunzindu": "desfrunzi",
    "desfrunzirea": "desfrunzire",
    "desfrunzireo": "desfrunzire",
    "desfrunziri": "desfrunzire",
    "desfrunzirii": "desfrunzire",
    "desfrunzirile": "desfrunzire",
    "desfrunzirilor": "desfrunzire",
    "desfrunzita": "desfrunzit",
    "desfrunzită": "desfrunzit",
    "desfrunzite": "desfrunzit",
    "desfrunzitei": "desfrunzit",
    "desfrunzitele": "desfrunzit",
    "desfrunzitelor": "desfrunzit",
    "desfrunziți": "desfrunzit",
    "desfrunziții": "desfrunzit",
    "desfrunziților": "desfrunzit",
    "desfrunzito": "desfrunzit",
    "desfrunzitul": "desfrunzit",
    "desfrunzitule": "desfrunzit",
    "desfrunzitului": "desfrunzit",
    "desfund": "desfunda",
    "desfundă": "desfunda",
    "desfundai": "desfunda",
    "desfundam": "desfunda",
    "desfundăm": "desfunda",
    "desfundând": "desfunda",
    "desfundându": "desfunda",
    "desfundară": "desfunda",
    "desfundarăm": "desfunda",
    "desfundarăți": "desfunda",
    "desfundase": "desfunda",
    "desfundasem": "desfunda",
    "desfundaseră": "desfunda",
    "desfundaserăm": "desfunda",
    "desfundaserăți": "desfunda",
    "desfundaseși": "desfunda",
    "desfundași": "desfunda",
    "desfundat": "desfunda",
    "desfundați": "desfunda",
    "desfundatu": "desfunda",
    "desfundau": "desfunda",
    "desfunde": "desfunda",
    "desfunzi": "desfunda",
    "nedesfundând": "desfunda",
    "nedesfundându": "desfunda",
    "nemaidesfundând": "desfunda",
    "nemaidesfundându": "desfunda",
    "desfundarea": "desfundare",
    "desfundareo": "desfundare",
    "desfundări": "desfundare",
    "desfundării": "desfundare",
    "desfundările": "desfundare",
    "desfundărilor": "desfundare",
    "desfundata": "desfundat",
    "desfundată": "desfundat",
    "desfundate": "desfundat",
    "desfundatei": "desfundat",
    "desfundatele": "desfundat",
    "desfundatelor": "desfundat",
    "desfundați": "desfundat",
    "desfundații": "desfundat",
    "desfundaților": "desfundat",
    "desfundato": "desfundat",
    "desfundatul": "desfundat",
    "desfundatule": "desfundat",
    "desfundatului": "desfundat",
    "desham": "deshăma",
    "deshamă": "deshăma",
    "deshămă": "deshăma",
    "deshămai": "deshăma",
    "deshămam": "deshăma",
    "deshămăm": "deshăma",
    "deshămând": "deshăma",
    "deshămându": "deshăma",
    "deshămară": "deshăma",
    "deshămarăm": "deshăma",
    "deshămarăți": "deshăma",
    "deshămase": "deshăma",
    "deshămasem": "deshăma",
    "deshămaseră": "deshăma",
    "deshămaserăm": "deshăma",
    "deshămaserăți": "deshăma",
    "deshămaseși": "deshăma",
    "deshămași": "deshăma",
    "deshămat": "deshăma",
    "deshămați": "deshăma",
    "deshămatu": "deshăma",
    "deshămau": "deshăma",
    "deshame": "deshăma",
    "deshami": "deshăma",
    "nedeshămând": "deshăma",
    "nedeshămându": "deshăma",
    "nemaideshămând": "deshăma",
    "nemaideshămându": "deshăma",
    "deshămarea": "deshămare",
    "deshămareo": "deshămare",
    "deshămări": "deshămare",
    "deshămării": "deshămare",
    "deshămările": "deshămare",
    "deshămărilor": "deshămare",
    "deshămată": "deshămat",
    "deshămate": "deshămat",
    "deshămați": "deshămat",
    "deshidrată": "deshidrata",
    "deshidratai": "deshidrata",
    "deshidratam": "deshidrata",
    "deshidratăm": "deshidrata",
    "deshidratând": "deshidrata",
    "deshidratându": "deshidrata",
    "deshidratară": "deshidrata",
    "deshidratarăm": "deshidrata",
    "deshidratarăți": "deshidrata",
    "deshidratase": "deshidrata",
    "deshidratasem": "deshidrata",
    "deshidrataseră": "deshidrata",
    "deshidrataserăm": "deshidrata",
    "deshidrataserăți": "deshidrata",
    "deshidrataseși": "deshidrata",
    "deshidratași": "deshidrata",
    "deshidratat": "deshidrata",
    "deshidratați": "deshidrata",
    "deshidratatu": "deshidrata",
    "deshidratau": "deshidrata",
    "deshidratează": "deshidrata",
    "deshidratez": "deshidrata",
    "deshidrateze": "deshidrata",
    "deshidratezi": "deshidrata",
    "nedeshidratând": "deshidrata",
    "nedeshidratându": "deshidrata",
    "nemaideshidratând": "deshidrata",
    "nemaideshidratându": "deshidrata",
    "deshidratarea": "deshidratare",
    "deshidratareo": "deshidratare",
    "deshidratări": "deshidratare",
    "deshidratării": "deshidratare",
    "deshidratările": "deshidratare",
    "deshidratărilor": "deshidratare",
    "deshidratată": "deshidratat",
    "deshidratate": "deshidratat",
    "deshidratați": "deshidratat",
    "deshidratatoare": "deshidratator",
    "deshidratatoarele": "deshidratator",
    "deshidratatoarelor": "deshidratator",
    "deshidratatorul": "deshidratator",
    "deshidratatorule": "deshidratator",
    "deshidratatorului": "deshidratator",
    "deshumă": "deshuma",
    "deshumai": "deshuma",
    "deshumam": "deshuma",
    "deshumăm": "deshuma",
    "deshumând": "deshuma",
    "deshumându": "deshuma",
    "deshumară": "deshuma",
    "deshumarăm": "deshuma",
    "deshumarăți": "deshuma",
    "deshumase": "deshuma",
    "deshumasem": "deshuma",
    "deshumaseră": "deshuma",
    "deshumaserăm": "deshuma",
    "deshumaserăți": "deshuma",
    "deshumaseși": "deshuma",
    "deshumași": "deshuma",
    "deshumat": "deshuma",
    "deshumați": "deshuma",
    "deshumatu": "deshuma",
    "deshumau": "deshuma",
    "deshumează": "deshuma",
    "deshumez": "deshuma",
    "deshumeze": "deshuma",
    "deshumezi": "deshuma",
    "nedeshumând": "deshuma",
    "nedeshumându": "deshuma",
    "nemaideshumând": "deshuma",
    "nemaideshumându": "deshuma",
    "deshumarea": "deshumare",
    "deshumareo": "deshumare",
    "deshumări": "deshumare",
    "deshumării": "deshumare",
    "deshumările": "deshumare",
    "deshumărilor": "deshumare",
    "deshumată": "deshumat",
    "deshumate": "deshumat",
    "deshumați": "deshumat",
    "designul": "design",
    "designule": "design",
    "designului": "design",
    "designuri": "design",
    "designurile": "design",
    "designurilor": "design",
    "desimea": "desime",
    "desimeo": "desime",
    "desimi": "desime",
    "desimii": "desime",
    "desimile": "desime",
    "desimilor": "desime",
    "desinența": "desinență",
    "desinențe": "desinență",
    "desinenței": "desinență",
    "desinențele": "desinență",
    "desinențelor": "desinență",
    "desinențo": "desinență",
    "deșir": "deșira",
    "deșiră": "deșira",
    "deșirai": "deșira",
    "deșiram": "deșira",
    "deșirăm": "deșira",
    "deșirând": "deșira",
    "deșirându": "deșira",
    "deșirară": "deșira",
    "deșirarăm": "deșira",
    "deșirarăți": "deșira",
    "deșirase": "deșira",
    "deșirasem": "deșira",
    "deșiraseră": "deșira",
    "deșiraserăm": "deșira",
    "deșiraserăți": "deșira",
    "deșiraseși": "deșira",
    "deșirași": "deșira",
    "deșirat": "deșira",
    "deșirați": "deșira",
    "deșiratu": "deșira",
    "deșirau": "deșira",
    "deșire": "deșira",
    "deșiri": "deșira",
    "nedeșirând": "deșira",
    "nedeșirându": "deșira",
    "nemaideșirând": "deșira",
    "nemaideșirându": "deșira",
    "deșirata": "deșirat",
    "deșirată": "deșirat",
    "deșirate": "deșirat",
    "deșiratei": "deșirat",
    "deșiratele": "deșirat",
    "deșiratelor": "deșirat",
    "deșirați": "deșirat",
    "deșirații": "deșirat",
    "deșiraților": "deșirat",
    "deșirato": "deșirat",
    "deșiratul": "deșirat",
    "deșiratule": "deșirat",
    "deșiratului": "deșirat",
    "desișul": "desiș",
    "desișule": "desiș",
    "desișului": "desiș",
    "desișuri": "desiș",
    "desișurile": "desiș",
    "desișurilor": "desiș",
    "deslușea": "desluși",
    "deslușeai": "desluși",
    "deslușeam": "desluși",
    "deslușească": "desluși",
    "deslușeați": "desluși",
    "deslușeau": "desluși",
    "deslușesc": "desluși",
    "deslușește": "desluși",
    "deslușești": "desluși",
    "deslușii": "desluși",
    "deslușim": "desluși",
    "deslușind": "desluși",
    "deslușindu": "desluși",
    "deslușiră": "desluși",
    "deslușirăm": "desluși",
    "deslușirăți": "desluși",
    "deslușise": "desluși",
    "deslușisem": "desluși",
    "deslușiseră": "desluși",
    "deslușiserăm": "desluși",
    "deslușiserăți": "desluși",
    "deslușiseși": "desluși",
    "deslușiși": "desluși",
    "deslușit": "desluși",
    "deslușiți": "desluși",
    "deslușitu": "desluși",
    "nedeslușind": "desluși",
    "nedeslușindu": "desluși",
    "nemaideslușind": "desluși",
    "nemaideslușindu": "desluși",
    "deslușirea": "deslușire",
    "deslușireo": "deslușire",
    "deslușiri": "deslușire",
    "deslușirii": "deslușire",
    "deslușirile": "deslușire",
    "deslușirilor": "deslușire",
    "deslușita": "deslușit",
    "deslușită": "deslușit",
    "deslușite": "deslușit",
    "deslușitei": "deslușit",
    "deslușitele": "deslușit",
    "deslușitelor": "deslușit",
    "deslușiți": "deslușit",
    "deslușiții": "deslușit",
    "deslușiților": "deslușit",
    "deslușito": "deslușit",
    "deslușitul": "deslușit",
    "deslușitule": "deslușit",
    "deslușitului": "deslușit",
    "deslușitoare": "deslușitor",
    "deslușitoarea": "deslușitor",
    "deslușitoarei": "deslușitor",
    "deslușitoarele": "deslușitor",
    "deslușitoarelor": "deslușitor",
    "deslușitoareo": "deslușitor",
    "deslușitori": "deslușitor",
    "deslușitorii": "deslușitor",
    "deslușitorilor": "deslușitor",
    "deslușitorul": "deslușitor",
    "deslușitorule": "deslușitor",
    "deslușitorului": "deslușitor",
    "desolidariză": "desolidariza",
    "desolidarizai": "desolidariza",
    "desolidarizam": "desolidariza",
    "desolidarizăm": "desolidariza",
    "desolidarizând": "desolidariza",
    "desolidarizându": "desolidariza",
    "desolidarizară": "desolidariza",
    "desolidarizarăm": "desolidariza",
    "desolidarizarăți": "desolidariza",
    "desolidarizase": "desolidariza",
    "desolidarizasem": "desolidariza",
    "desolidarizaseră": "desolidariza",
    "desolidarizaserăm": "desolidariza",
    "desolidarizaserăți": "desolidariza",
    "desolidarizaseși": "desolidariza",
    "desolidarizași": "desolidariza",
    "desolidarizat": "desolidariza",
    "desolidarizați": "desolidariza",
    "desolidarizatu": "desolidariza",
    "desolidarizau": "desolidariza",
    "desolidarizează": "desolidariza",
    "desolidarizez": "desolidariza",
    "desolidarizeze": "desolidariza",
    "desolidarizezi": "desolidariza",
    "nedesolidarizând": "desolidariza",
    "nedesolidarizându": "desolidariza",
    "nemaidesolidarizând": "desolidariza",
    "nemaidesolidarizându": "desolidariza",
    "desolidarizarea": "desolidarizare",
    "desolidarizareo": "desolidarizare",
    "desolidarizări": "desolidarizare",
    "desolidarizării": "desolidarizare",
    "desolidarizările": "desolidarizare",
    "desolidarizărilor": "desolidarizare",
    "desolidarizată": "desolidarizat",
    "desolidarizate": "desolidarizat",
    "desolidarizați": "desolidarizat",
    "despachetă": "despacheta",
    "despachetai": "despacheta",
    "despachetam": "despacheta",
    "despachetăm": "despacheta",
    "despachetând": "despacheta",
    "despachetându": "despacheta",
    "despachetară": "despacheta",
    "despachetarăm": "despacheta",
    "despachetarăți": "despacheta",
    "despachetase": "despacheta",
    "despachetasem": "despacheta",
    "despachetaseră": "despacheta",
    "despachetaserăm": "despacheta",
    "despachetaserăți": "despacheta",
    "despachetaseși": "despacheta",
    "despachetași": "despacheta",
    "despachetat": "despacheta",
    "despachetați": "despacheta",
    "despachetatu": "despacheta",
    "despachetau": "despacheta",
    "despachetează": "despacheta",
    "despachetez": "despacheta",
    "despacheteze": "despacheta",
    "despachetezi": "despacheta",
    "nedespachetând": "despacheta",
    "nedespachetându": "despacheta",
    "nemaidespachetând": "despacheta",
    "nemaidespachetându": "despacheta",
    "despachetarea": "despachetare",
    "despachetareo": "despachetare",
    "despachetări": "despachetare",
    "despachetării": "despachetare",
    "despachetările": "despachetare",
    "despachetărilor": "despachetare",
    "despachetată": "despachetat",
    "despachetate": "despachetat",
    "despachetați": "despachetat",
    "despăduche": "despăduchea",
    "despăducheai": "despăduchea",
    "despăducheam": "despăduchea",
    "despăducheară": "despăduchea",
    "despăduchearăm": "despăduchea",
    "despăduchearăți": "despăduchea",
    "despăduchease": "despăduchea",
    "despăducheasem": "despăduchea",
    "despăducheaseră": "despăduchea",
    "despăducheaserăm": "despăduchea",
    "despăducheaserăți": "despăduchea",
    "despăducheaseși": "despăduchea",
    "despăducheași": "despăduchea",
    "despăducheat": "despăduchea",
    "despăducheați": "despăduchea",
    "despăducheatu": "despăduchea",
    "despăducheau": "despăduchea",
    "despăduchează": "despăduchea",
    "despăduchem": "despăduchea",
    "despăduchez": "despăduchea",
    "despăducheze": "despăduchea",
    "despăduchezi": "despăduchea",
    "despăduchind": "despăduchea",
    "despăduchindu": "despăduchea",
    "nedespăduchind": "despăduchea",
    "nedespăduchindu": "despăduchea",
    "nemaidespăduchind": "despăduchea",
    "nemaidespăduchindu": "despăduchea",
    "despăducheată": "despăducheat",
    "despăducheate": "despăducheat",
    "despăducheați": "despăducheat",
    "despăducherea": "despăduchere",
    "despăduchereo": "despăduchere",
    "despăducheri": "despăduchere",
    "despăducherii": "despăduchere",
    "despăducherile": "despăduchere",
    "despăducherilor": "despăduchere",
    "despădurea": "despăduri",
    "despădureai": "despăduri",
    "despăduream": "despăduri",
    "despădurească": "despăduri",
    "despădureați": "despăduri",
    "despădureau": "despăduri",
    "despăduresc": "despăduri",
    "despădurește": "despăduri",
    "despădurești": "despăduri",
    "despădurii": "despăduri",
    "despădurim": "despăduri",
    "despădurind": "despăduri",
    "despădurindu": "despăduri",
    "despăduriră": "despăduri",
    "despădurirăm": "despăduri",
    "despădurirăți": "despăduri",
    "despădurise": "despăduri",
    "despădurisem": "despăduri",
    "despăduriseră": "despăduri",
    "despăduriserăm": "despăduri",
    "despăduriserăți": "despăduri",
    "despăduriseși": "despăduri",
    "despăduriși": "despăduri",
    "despădurit": "despăduri",
    "despăduriți": "despăduri",
    "despăduritu": "despăduri",
    "nedespădurind": "despăduri",
    "nedespădurindu": "despăduri",
    "nemaidespădurind": "despăduri",
    "nemaidespădurindu": "despăduri",
    "despădurirea": "despădurire",
    "despădurireo": "despădurire",
    "despăduriri": "despădurire",
    "despăduririi": "despădurire",
    "despăduririle": "despădurire",
    "despăduririlor": "despădurire",
    "despădurita": "despădurit",
    "despădurită": "despădurit",
    "despădurite": "despădurit",
    "despăduritei": "despădurit",
    "despăduritele": "despădurit",
    "despăduritelor": "despădurit",
    "despăduriți": "despădurit",
    "despăduriții": "despădurit",
    "despăduriților": "despădurit",
    "despădurito": "despădurit",
    "despăduritul": "despădurit",
    "despăduritule": "despădurit",
    "despăduritului": "despădurit",
    "despăgubirea": "despăgubire",
    "despăgubireo": "despăgubire",
    "despăgubiri": "despăgubire",
    "despăgubirii": "despăgubire",
    "despăgubirile": "despăgubire",
    "despăgubirilor": "despăgubire",
    "despăgubită": "despăgubit",
    "despăienjenea": "despăienjeni",
    "despăienjeneai": "despăienjeni",
    "despăienjeneam": "despăienjeni",
    "despăienjenească": "despăienjeni",
    "despăienjeneați": "despăienjeni",
    "despăienjeneau": "despăienjeni",
    "despăienjenesc": "despăienjeni",
    "despăienjenește": "despăienjeni",
    "despăienjenești": "despăienjeni",
    "despăienjenii": "despăienjeni",
    "despăienjenim": "despăienjeni",
    "despăienjenind": "despăienjeni",
    "despăienjenindu": "despăienjeni",
    "despăienjeniră": "despăienjeni",
    "despăienjenirăm": "despăienjeni",
    "despăienjenirăți": "despăienjeni",
    "despăienjenise": "despăienjeni",
    "despăienjenisem": "despăienjeni",
    "despăienjeniseră": "despăienjeni",
    "despăienjeniserăm": "despăienjeni",
    "despăienjeniserăți": "despăienjeni",
    "despăienjeniseși": "despăienjeni",
    "despăienjeniși": "despăienjeni",
    "despăienjenit": "despăienjeni",
    "despăienjeniți": "despăienjeni",
    "despăienjenitu": "despăienjeni",
    "nedespăienjenind": "despăienjeni",
    "nedespăienjenindu": "despăienjeni",
    "nemaidespăienjenind": "despăienjeni",
    "nemaidespăienjenindu": "despăienjeni",
    "despăienjenită": "despăienjenit",
    "despăienjenite": "despăienjenit",
    "despăienjeniți": "despăienjenit",
    "despart": "despărți",
    "despartă": "despărți",
    "desparte": "despărți",
    "despărțea": "despărți",
    "despărțeai": "despărți",
    "despărțeam": "despărți",
    "despărțeați": "despărți",
    "despărțeau": "despărți",
    "desparți": "despărți",
    "despărții": "despărți",
    "despărțim": "despărți",
    "despărțind": "despărți",
    "despărțindu": "despărți",
    "despărțiră": "despărți",
    "despărțirăm": "despărți",
    "despărțirăți": "despărți",
    "despărțise": "despărți",
    "despărțisem": "despărți",
    "despărțiseră": "despărți",
    "despărțiserăm": "despărți",
    "despărțiserăți": "despărți",
    "despărțiseși": "despărți",
    "despărțiși": "despărți",
    "despărțit": "despărți",
    "despărțiți": "despărți",
    "despărțitu": "despărți",
    "nedespărțind": "despărți",
    "nedespărțindu": "despărți",
    "nemaidespărțind": "despărți",
    "nemaidespărțindu": "despărți",
    "despărțirea": "despărțire",
    "despărțireo": "despărțire",
    "despărțiri": "despărțire",
    "despărțirii": "despărțire",
    "despărțirile": "despărțire",
    "despărțirilor": "despărțire",
    "despărțita": "despărțit",
    "despărțită": "despărțit",
    "despărțite": "despărțit",
    "despărțitei": "despărțit",
    "despărțitele": "despărțit",
    "despărțitelor": "despărțit",
    "despărțiți": "despărțit",
    "despărțiții": "despărțit",
    "despărțiților": "despărțit",
    "despărțito": "despărțit",
    "despărțitul": "despărțit",
    "despărțitule": "despărțit",
    "despărțitului": "despărțit",
    "despărțitoare": "despărțitor",
    "despărțitoarea": "despărțitor",
    "despărțitoarei": "despărțitor",
    "despărțitoarele": "despărțitor",
    "despărțitoarelor": "despărțitor",
    "despărțitoareo": "despărțitor",
    "despărțitori": "despărțitor",
    "despărțitorii": "despărțitor",
    "despărțitorilor": "despărțitor",
    "despărțitorul": "despărțitor",
    "despărțitorule": "despărțitor",
    "despărțitorului": "despărțitor",
    "despărțitura": "despărțitură",
    "despărțituri": "despărțitură",
    "despărțiturii": "despărțitură",
    "despărțiturile": "despărțitură",
    "despărțiturilor": "despărțitură",
    "despărțituro": "despărțitură",
    "despăturea": "despături",
    "despătureai": "despături",
    "despătuream": "despături",
    "despăturească": "despături",
    "despătureați": "despături",
    "despătureau": "despături",
    "despăturesc": "despături",
    "despăturește": "despături",
    "despăturești": "despături",
    "despăturii": "despături",
    "despăturim": "despături",
    "despăturind": "despături",
    "despăturindu": "despături",
    "despăturiră": "despături",
    "despăturirăm": "despături",
    "despăturirăți": "despături",
    "despăturise": "despături",
    "despăturisem": "despături",
    "despăturiseră": "despături",
    "despăturiserăm": "despături",
    "despăturiserăți": "despături",
    "despăturiseși": "despături",
    "despăturiși": "despături",
    "despăturit": "despături",
    "despăturiți": "despături",
    "despăturitu": "despături",
    "nedespăturind": "despături",
    "nedespăturindu": "despături",
    "nemaidespăturind": "despături",
    "nemaidespăturindu": "despături",
    "despăturirea": "despăturire",
    "despăturireo": "despăturire",
    "despăturiri": "despăturire",
    "despăturirii": "despăturire",
    "despăturirile": "despăturire",
    "despăturirilor": "despăturire",
    "despăturită": "despăturit",
    "despăturite": "despăturit",
    "despăturiți": "despăturit",
    "desper": "despera",
    "desperă": "despera",
    "desperai": "despera",
    "desperam": "despera",
    "desperăm": "despera",
    "desperând": "despera",
    "desperându": "despera",
    "desperară": "despera",
    "desperarăm": "despera",
    "desperarăți": "despera",
    "desperase": "despera",
    "desperasem": "despera",
    "desperaseră": "despera",
    "desperaserăm": "despera",
    "desperaserăți": "despera",
    "desperaseși": "despera",
    "desperași": "despera",
    "desperat": "despera",
    "desperați": "despera",
    "desperatu": "despera",
    "desperau": "despera",
    "despere": "despera",
    "desperi": "despera",
    "nedesperând": "despera",
    "nedesperându": "despera",
    "nemaidesperând": "despera",
    "nemaidesperându": "despera",
    "desperarea": "desperare",
    "desperareo": "desperare",
    "desperări": "desperare",
    "desperării": "desperare",
    "desperările": "desperare",
    "desperărilor": "desperare",
    "desperata": "desperat",
    "desperată": "desperat",
    "desperate": "desperat",
    "desperatei": "desperat",
    "desperatele": "desperat",
    "desperatelor": "desperat",
    "desperați": "desperat",
    "desperații": "desperat",
    "desperaților": "desperat",
    "desperato": "desperat",
    "desperatul": "desperat",
    "desperatule": "desperat",
    "desperatului": "desperat",
    "despereche": "desperechea",
    "desperecheai": "desperechea",
    "desperecheam": "desperechea",
    "desperecheară": "desperechea",
    "desperechearăm": "desperechea",
    "desperechearăți": "desperechea",
    "desperechease": "desperechea",
    "desperecheasem": "desperechea",
    "desperecheaseră": "desperechea",
    "desperecheaserăm": "desperechea",
    "desperecheaserăți": "desperechea",
    "desperecheaseși": "desperechea",
    "desperecheași": "desperechea",
    "desperecheat": "desperechea",
    "desperecheați": "desperechea",
    "desperecheatu": "desperechea",
    "desperecheau": "desperechea",
    "desperechează": "desperechea",
    "desperechem": "desperechea",
    "desperechez": "desperechea",
    "desperecheze": "desperechea",
    "desperechezi": "desperechea",
    "desperechind": "desperechea",
    "desperechindu": "desperechea",
    "nedesperechind": "desperechea",
    "nedesperechindu": "desperechea",
    "nemaidesperechind": "desperechea",
    "nemaidesperechindu": "desperechea",
    "desperecheata": "desperecheat",
    "desperecheată": "desperecheat",
    "desperecheate": "desperecheat",
    "desperecheatei": "desperecheat",
    "desperecheatele": "desperecheat",
    "desperecheatelor": "desperecheat",
    "desperecheați": "desperecheat",
    "desperecheații": "desperecheat",
    "desperecheaților": "desperecheat",
    "desperecheato": "desperecheat",
    "desperecheatul": "desperecheat",
    "desperecheatule": "desperecheat",
    "desperecheatului": "desperecheat",
    "desperecherea": "desperechere",
    "desperechereo": "desperechere",
    "desperecheri": "desperechere",
    "desperecherii": "desperechere",
    "desperecherile": "desperechere",
    "desperecherilor": "desperechere",
    "despersonalizata": "despersonalizat",
    "despersonalizată": "despersonalizat",
    "despersonalizate": "despersonalizat",
    "despersonalizatei": "despersonalizat",
    "despersonalizatele": "despersonalizat",
    "despersonalizatelor": "despersonalizat",
    "despersonalizați": "despersonalizat",
    "despersonalizații": "despersonalizat",
    "despersonalizaților": "despersonalizat",
    "despersonalizato": "despersonalizat",
    "despersonalizatul": "despersonalizat",
    "despersonalizatule": "despersonalizat",
    "despersonalizatului": "despersonalizat",
    "despic": "despica",
    "despică": "despica",
    "despicai": "despica",
    "despicam": "despica",
    "despicăm": "despica",
    "despicând": "despica",
    "despicându": "despica",
    "despicară": "despica",
    "despicarăm": "despica",
    "despicarăți": "despica",
    "despicase": "despica",
    "despicasem": "despica",
    "despicaseră": "despica",
    "despicaserăm": "despica",
    "despicaserăți": "despica",
    "despicaseși": "despica",
    "despicași": "despica",
    "despicat": "despica",
    "despicați": "despica",
    "despicatu": "despica",
    "despicau": "despica",
    "despice": "despica",
    "despici": "despica",
    "nedespicând": "despica",
    "nedespicându": "despica",
    "nemaidespicând": "despica",
    "nemaidespicându": "despica",
    "despicarea": "despicare",
    "despicareo": "despicare",
    "despicări": "despicare",
    "despicării": "despicare",
    "despicările": "despicare",
    "despicărilor": "despicare",
    "despicata": "despicat",
    "despicată": "despicat",
    "despicate": "despicat",
    "despicatei": "despicat",
    "despicatele": "despicat",
    "despicatelor": "despicat",
    "despicați": "despicat",
    "despicații": "despicat",
    "despicaților": "despicat",
    "despicato": "despicat",
    "despicatul": "despicat",
    "despicatule": "despicat",
    "despicatului": "despicat",
    "despicătura": "despicătură",
    "despicături": "despicătură",
    "despicăturii": "despicătură",
    "despicăturile": "despicătură",
    "despicăturilor": "despicătură",
    "despicăturo": "despicătură",
    "despiedic": "despiedica",
    "despiedică": "despiedica",
    "despiedicai": "despiedica",
    "despiedicam": "despiedica",
    "despiedicăm": "despiedica",
    "despiedicând": "despiedica",
    "despiedicându": "despiedica",
    "despiedicară": "despiedica",
    "despiedicarăm": "despiedica",
    "despiedicarăți": "despiedica",
    "despiedicase": "despiedica",
    "despiedicasem": "despiedica",
    "despiedicaseră": "despiedica",
    "despiedicaserăm": "despiedica",
    "despiedicaserăți": "despiedica",
    "despiedicaseși": "despiedica",
    "despiedicași": "despiedica",
    "despiedicat": "despiedica",
    "despiedicați": "despiedica",
    "despiedicatu": "despiedica",
    "despiedicau": "despiedica",
    "despiedice": "despiedica",
    "despiedici": "despiedica",
    "nedespiedicând": "despiedica",
    "nedespiedicându": "despiedica",
    "nemaidespiedicând": "despiedica",
    "nemaidespiedicându": "despiedica",
    "despiedicată": "despiedicat",
    "despiedicate": "despiedicat",
    "despiedicați": "despiedicat",
    "despletea": "despleti",
    "despleteai": "despleti",
    "despleteam": "despleti",
    "despletească": "despleti",
    "despleteați": "despleti",
    "despleteau": "despleti",
    "despletesc": "despleti",
    "despletește": "despleti",
    "despletești": "despleti",
    "despletii": "despleti",
    "despletim": "despleti",
    "despletind": "despleti",
    "despletindu": "despleti",
    "despletiră": "despleti",
    "despletirăm": "despleti",
    "despletirăți": "despleti",
    "despletise": "despleti",
    "despletisem": "despleti",
    "despletiseră": "despleti",
    "despletiserăm": "despleti",
    "despletiserăți": "despleti",
    "despletiseși": "despleti",
    "despletiși": "despleti",
    "despletit": "despleti",
    "despletiți": "despleti",
    "despletitu": "despleti",
    "nedespletind": "despleti",
    "nedespletindu": "despleti",
    "nemaidespletind": "despleti",
    "nemaidespletindu": "despleti",
    "despletirea": "despletire",
    "despletireo": "despletire",
    "despletiri": "despletire",
    "despletirii": "despletire",
    "despletirile": "despletire",
    "despletirilor": "despletire",
    "despletita": "despletit",
    "despletită": "despletit",
    "despletite": "despletit",
    "despletitei": "despletit",
    "despletitele": "despletit",
    "despletitelor": "despletit",
    "despletiți": "despletit",
    "despletiții": "despletit",
    "despletiților": "despletit",
    "despletito": "despletit",
    "despletitul": "despletit",
    "despletitule": "despletit",
    "despletitului": "despletit",
    "despodobea": "despodobi",
    "despodobeai": "despodobi",
    "despodobeam": "despodobi",
    "despodobească": "despodobi",
    "despodobeați": "despodobi",
    "despodobeau": "despodobi",
    "despodobesc": "despodobi",
    "despodobește": "despodobi",
    "despodobești": "despodobi",
    "despodobii": "despodobi",
    "despodobim": "despodobi",
    "despodobind": "despodobi",
    "despodobindu": "despodobi",
    "despodobiră": "despodobi",
    "despodobirăm": "despodobi",
    "despodobirăți": "despodobi",
    "despodobise": "despodobi",
    "despodobisem": "despodobi",
    "despodobiseră": "despodobi",
    "despodobiserăm": "despodobi",
    "despodobiserăți": "despodobi",
    "despodobiseși": "despodobi",
    "despodobiși": "despodobi",
    "despodobit": "despodobi",
    "despodobiți": "despodobi",
    "despodobitu": "despodobi",
    "nedespodobind": "despodobi",
    "nedespodobindu": "despodobi",
    "nemaidespodobind": "despodobi",
    "nemaidespodobindu": "despodobi",
    "despodobită": "despodobit",
    "despodobite": "despodobit",
    "despodobiți": "despodobit",
    "despoți": "despot",
    "despoții": "despot",
    "despoților": "despot",
    "despotul": "despot",
    "despotule": "despot",
    "despotului": "despot",
    "despotica": "despotic",
    "despotică": "despotic",
    "despotice": "despotic",
    "despoticei": "despotic",
    "despoticele": "despotic",
    "despoticelor": "despotic",
    "despotici": "despotic",
    "despoticii": "despotic",
    "despoticilor": "despotic",
    "despotico": "despotic",
    "despoticul": "despotic",
    "despoticule": "despotic",
    "despoticului": "despotic",
    "despoția": "despoție",
    "despoției": "despoție",
    "despoții": "despoție",
    "despoțiile": "despoție",
    "despoțiilor": "despoție",
    "despotmolea": "despotmoli",
    "despotmoleai": "despotmoli",
    "despotmoleam": "despotmoli",
    "despotmolească": "despotmoli",
    "despotmoleați": "despotmoli",
    "despotmoleau": "despotmoli",
    "despotmolesc": "despotmoli",
    "despotmolește": "despotmoli",
    "despotmolești": "despotmoli",
    "despotmolii": "despotmoli",
    "despotmolim": "despotmoli",
    "despotmolind": "despotmoli",
    "despotmolindu": "despotmoli",
    "despotmoliră": "despotmoli",
    "despotmolirăm": "despotmoli",
    "despotmolirăți": "despotmoli",
    "despotmolise": "despotmoli",
    "despotmolisem": "despotmoli",
    "despotmoliseră": "despotmoli",
    "despotmoliserăm": "despotmoli",
    "despotmoliserăți": "despotmoli",
    "despotmoliseși": "despotmoli",
    "despotmoliși": "despotmoli",
    "despotmolit": "despotmoli",
    "despotmoliți": "despotmoli",
    "despotmolitu": "despotmoli",
    "nedespotmolind": "despotmoli",
    "nedespotmolindu": "despotmoli",
    "nemaidespotmolind": "despotmoli",
    "nemaidespotmolindu": "despotmoli",
    "despotmolită": "despotmolit",
    "despotmolite": "despotmolit",
    "despotmoliți": "despotmolit",
    "despovără": "despovăra",
    "despovărai": "despovăra",
    "despovăram": "despovăra",
    "despovărăm": "despovăra",
    "despovărând": "despovăra",
    "despovărându": "despovăra",
    "despovărară": "despovăra",
    "despovărarăm": "despovăra",
    "despovărarăți": "despovăra",
    "despovărase": "despovăra",
    "despovărasem": "despovăra",
    "despovăraseră": "despovăra",
    "despovăraserăm": "despovăra",
    "despovăraserăți": "despovăra",
    "despovăraseși": "despovăra",
    "despovărași": "despovăra",
    "despovărat": "despovăra",
    "despovărați": "despovăra",
    "despovăratu": "despovăra",
    "despovărau": "despovăra",
    "despovărează": "despovăra",
    "despovărez": "despovăra",
    "despovăreze": "despovăra",
    "despovărezi": "despovăra",
    "nedespovărând": "despovăra",
    "nedespovărându": "despovăra",
    "nemaidespovărând": "despovăra",
    "nemaidespovărându": "despovăra",
    "despovărată": "despovărat",
    "despovărate": "despovărat",
    "despovărați": "despovărat",
    "desprejmuia": "desprejmui",
    "desprejmuiai": "desprejmui",
    "desprejmuiam": "desprejmui",
    "desprejmuiască": "desprejmui",
    "desprejmuiați": "desprejmui",
    "desprejmuiau": "desprejmui",
    "desprejmuiesc": "desprejmui",
    "desprejmuiește": "desprejmui",
    "desprejmuiești": "desprejmui",
    "desprejmuii": "desprejmui",
    "desprejmuim": "desprejmui",
    "desprejmuind": "desprejmui",
    "desprejmuindu": "desprejmui",
    "desprejmuiră": "desprejmui",
    "desprejmuirăm": "desprejmui",
    "desprejmuirăți": "desprejmui",
    "desprejmuise": "desprejmui",
    "desprejmuisem": "desprejmui",
    "desprejmuiseră": "desprejmui",
    "desprejmuiserăm": "desprejmui",
    "desprejmuiserăți": "desprejmui",
    "desprejmuiseși": "desprejmui",
    "desprejmuiși": "desprejmui",
    "desprejmuit": "desprejmui",
    "desprejmuiți": "desprejmui",
    "desprejmuitu": "desprejmui",
    "nedesprejmuind": "desprejmui",
    "nedesprejmuindu": "desprejmui",
    "nemaidesprejmuind": "desprejmui",
    "nemaidesprejmuindu": "desprejmui",
    "desprejmuită": "desprejmuit",
    "desprejmuite": "desprejmuit",
    "desprejmuiți": "desprejmuit",
    "despresoară": "despresura",
    "despresoare": "despresura",
    "despresor": "despresura",
    "despresori": "despresura",
    "despresură": "despresura",
    "despresurai": "despresura",
    "despresuram": "despresura",
    "despresurăm": "despresura",
    "despresurând": "despresura",
    "despresurându": "despresura",
    "despresurară": "despresura",
    "despresurarăm": "despresura",
    "despresurarăți": "despresura",
    "despresurase": "despresura",
    "despresurasem": "despresura",
    "despresuraseră": "despresura",
    "despresuraserăm": "despresura",
    "despresuraserăți": "despresura",
    "despresuraseși": "despresura",
    "despresurași": "despresura",
    "despresurat": "despresura",
    "despresurați": "despresura",
    "despresuratu": "despresura",
    "despresurau": "despresura",
    "nedespresurând": "despresura",
    "nedespresurându": "despresura",
    "nemaidespresurând": "despresura",
    "nemaidespresurându": "despresura",
    "despresurarea": "despresurare",
    "despresurareo": "despresurare",
    "despresurări": "despresurare",
    "despresurării": "despresurare",
    "despresurările": "despresurare",
    "despresurărilor": "despresurare",
    "despresurată": "despresurat",
    "despresurate": "despresurat",
    "despresurați": "despresurat",
    "desprimăvără": "desprimăvăra",
    "desprimăvărai": "desprimăvăra",
    "desprimăvăram": "desprimăvăra",
    "desprimăvărăm": "desprimăvăra",
    "desprimăvărând": "desprimăvăra",
    "desprimăvărându": "desprimăvăra",
    "desprimăvărară": "desprimăvăra",
    "desprimăvărarăm": "desprimăvăra",
    "desprimăvărarăți": "desprimăvăra",
    "desprimăvărase": "desprimăvăra",
    "desprimăvărasem": "desprimăvăra",
    "desprimăvăraseră": "desprimăvăra",
    "desprimăvăraserăm": "desprimăvăra",
    "desprimăvăraserăți": "desprimăvăra",
    "desprimăvăraseși": "desprimăvăra",
    "desprimăvărași": "desprimăvăra",
    "desprimăvărat": "desprimăvăra",
    "desprimăvărați": "desprimăvăra",
    "desprimăvăratu": "desprimăvăra",
    "desprimăvărau": "desprimăvăra",
    "desprimăvărează": "desprimăvăra",
    "desprimăvărez": "desprimăvăra",
    "desprimăvăreze": "desprimăvăra",
    "desprimăvărezi": "desprimăvăra",
    "nedesprimăvărând": "desprimăvăra",
    "nedesprimăvărându": "desprimăvăra",
    "nemaidesprimăvărând": "desprimăvăra",
    "nemaidesprimăvărându": "desprimăvăra",
    "desprimăvărarea": "desprimăvărare",
    "desprimăvărareo": "desprimăvărare",
    "desprimăvărări": "desprimăvărare",
    "desprimăvărării": "desprimăvărare",
    "desprimăvărările": "desprimăvărare",
    "desprimăvărărilor": "desprimăvărare",
    "desprimăvărată": "desprimăvărat",
    "desprimăvărate": "desprimăvărat",
    "desprimăvărați": "desprimăvărat",
    "desprind": "desprinde",
    "desprindă": "desprinde",
    "desprindea": "desprinde",
    "desprindeai": "desprinde",
    "desprindeam": "desprinde",
    "desprindeați": "desprinde",
    "desprindeau": "desprinde",
    "desprindem": "desprinde",
    "desprindeți": "desprinde",
    "desprins": "desprinde",
    "desprinse": "desprinde",
    "desprinsei": "desprinde",
    "desprinseră": "desprinde",
    "desprinserăm": "desprinde",
    "desprinserăți": "desprinde",
    "desprinsese": "desprinde",
    "desprinsesem": "desprinde",
    "desprinseseră": "desprinde",
    "desprinseserăm": "desprinde",
    "desprinseserăți": "desprinde",
    "desprinseseși": "desprinde",
    "desprinseși": "desprinde",
    "desprinsu": "desprinde",
    "desprinzând": "desprinde",
    "desprinzându": "desprinde",
    "desprinzi": "desprinde",
    "nedesprinzând": "desprinde",
    "nedesprinzându": "desprinde",
    "nemaidesprinzând": "desprinde",
    "nemaidesprinzându": "desprinde",
    "desprinderea": "desprindere",
    "desprindereo": "desprindere",
    "desprinderi": "desprindere",
    "desprinderii": "desprindere",
    "desprinderile": "desprindere",
    "desprinderilor": "desprindere",
    "desprinsă": "desprins",
    "desprinse": "desprins",
    "desprinși": "desprins",
    "despoaie": "despuia",
    "despoi": "despuia",
    "despuiai": "despuia",
    "despuiam": "despuia",
    "despuiară": "despuia",
    "despuiarăm": "despuia",
    "despuiarăți": "despuia",
    "despuiase": "despuia",
    "despuiasem": "despuia",
    "despuiaseră": "despuia",
    "despuiaserăm": "despuia",
    "despuiaserăți": "despuia",
    "despuiaseși": "despuia",
    "despuiași": "despuia",
    "despuiat": "despuia",
    "despuiați": "despuia",
    "despuiatu": "despuia",
    "despuiau": "despuia",
    "despuie": "despuia",
    "despuiem": "despuia",
    "despuind": "despuia",
    "despuindu": "despuia",
    "nedespuind": "despuia",
    "nedespuindu": "despuia",
    "nemaidespuind": "despuia",
    "nemaidespuindu": "despuia",
    "despuiata": "despuiat",
    "despuiată": "despuiat",
    "despuiate": "despuiat",
    "despuiatei": "despuiat",
    "despuiatele": "despuiat",
    "despuiatelor": "despuiat",
    "despuiați": "despuiat",
    "despuiații": "despuiat",
    "despuiaților": "despuiat",
    "despuiato": "despuiat",
    "despuiatul": "despuiat",
    "despuiatule": "despuiat",
    "despuiatului": "despuiat",
    "despuierea": "despuiere",
    "despuiereo": "despuiere",
    "despuieri": "despuiere",
    "despuierii": "despuiere",
    "despuierile": "despuiere",
    "despuierilor": "despuiere",
    "destabiliză": "destabiliza",
    "destabilizai": "destabiliza",
    "destabilizam": "destabiliza",
    "destabilizăm": "destabiliza",
    "destabilizând": "destabiliza",
    "destabilizându": "destabiliza",
    "destabilizară": "destabiliza",
    "destabilizarăm": "destabiliza",
    "destabilizarăți": "destabiliza",
    "destabilizase": "destabiliza",
    "destabilizasem": "destabiliza",
    "destabilizaseră": "destabiliza",
    "destabilizaserăm": "destabiliza",
    "destabilizaserăți": "destabiliza",
    "destabilizaseși": "destabiliza",
    "destabilizași": "destabiliza",
    "destabilizat": "destabiliza",
    "destabilizați": "destabiliza",
    "destabilizatu": "destabiliza",
    "destabilizau": "destabiliza",
    "destabilizează": "destabiliza",
    "destabilizez": "destabiliza",
    "destabilizeze": "destabiliza",
    "destabilizezi": "destabiliza",
    "destabilizarea": "destabilizare",
    "destabilizareo": "destabilizare",
    "destabilizări": "destabilizare",
    "destabilizării": "destabilizare",
    "destabilizările": "destabilizare",
    "destabilizărilor": "destabilizare",
    "destabilizată": "destabilizat",
    "destabilizate": "destabilizat",
    "destabilizați": "destabilizat",
    "destăinuia": "destăinui",
    "destăinuiai": "destăinui",
    "destăinuiam": "destăinui",
    "destăinuiască": "destăinui",
    "destăinuiați": "destăinui",
    "destăinuiau": "destăinui",
    "destăinuiesc": "destăinui",
    "destăinuiește": "destăinui",
    "destăinuiești": "destăinui",
    "destăinuii": "destăinui",
    "destăinuim": "destăinui",
    "destăinuind": "destăinui",
    "destăinuindu": "destăinui",
    "destăinuiră": "destăinui",
    "destăinuirăm": "destăinui",
    "destăinuirăți": "destăinui",
    "destăinuise": "destăinui",
    "destăinuisem": "destăinui",
    "destăinuiseră": "destăinui",
    "destăinuiserăm": "destăinui",
    "destăinuiserăți": "destăinui",
    "destăinuiseși": "destăinui",
    "destăinuiși": "destăinui",
    "destăinuit": "destăinui",
    "destăinuiți": "destăinui",
    "destăinuitu": "destăinui",
    "destăinuirea": "destăinuire",
    "destăinuireo": "destăinuire",
    "destăinuiri": "destăinuire",
    "destăinuirii": "destăinuire",
    "destăinuirile": "destăinuire",
    "destăinuirilor": "destăinuire",
    "destăinuita": "destăinuit",
    "destăinuită": "destăinuit",
    "destăinuite": "destăinuit",
    "destăinuitei": "destăinuit",
    "destăinuitele": "destăinuit",
    "destăinuitelor": "destăinuit",
    "destăinuiți": "destăinuit",
    "destăinuiții": "destăinuit",
    "destăinuiților": "destăinuit",
    "destăinuito": "destăinuit",
    "destăinuitul": "destăinuit",
    "destăinuitule": "destăinuit",
    "destăinuitului": "destăinuit",
    "desțelenea": "desțeleni",
    "desțeleneai": "desțeleni",
    "desțeleneam": "desțeleni",
    "desțelenească": "desțeleni",
    "desțeleneați": "desțeleni",
    "desțeleneau": "desțeleni",
    "desțelenesc": "desțeleni",
    "desțelenește": "desțeleni",
    "desțelenești": "desțeleni",
    "desțelenii": "desțeleni",
    "desțelenim": "desțeleni",
    "desțelenind": "desțeleni",
    "desțelenindu": "desțeleni",
    "desțeleniră": "desțeleni",
    "desțelenirăm": "desțeleni",
    "desțelenirăți": "desțeleni",
    "desțelenise": "desțeleni",
    "desțelenisem": "desțeleni",
    "desțeleniseră": "desțeleni",
    "desțeleniserăm": "desțeleni",
    "desțeleniserăți": "desțeleni",
    "desțeleniseși": "desțeleni",
    "desțeleniși": "desțeleni",
    "desțelenit": "desțeleni",
    "desțeleniți": "desțeleni",
    "desțelenitu": "desțeleni",
    "nedesțelenind": "desțeleni",
    "nedesțelenindu": "desțeleni",
    "nemaidesțelenind": "desțeleni",
    "nemaidesțelenindu": "desțeleni",
    "desțelenirea": "desțelenire",
    "desțelenireo": "desțelenire",
    "desțeleniri": "desțelenire",
    "desțelenirii": "desțelenire",
    "desțelenirile": "desțelenire",
    "desțelenirilor": "desțelenire",
    "desțelenită": "desțelenit",
    "desțelenite": "desțelenit",
    "desțeleniți": "desțelenit",
    "desțepenea": "desțepeni",
    "desțepeneai": "desțepeni",
    "desțepeneam": "desțepeni",
    "desțepenească": "desțepeni",
    "desțepeneați": "desțepeni",
    "desțepeneau": "desțepeni",
    "desțepenesc": "desțepeni",
    "desțepenește": "desțepeni",
    "desțepenești": "desțepeni",
    "desțepenii": "desțepeni",
    "desțepenim": "desțepeni",
    "desțepenind": "desțepeni",
    "desțepenindu": "desțepeni",
    "desțepeniră": "desțepeni",
    "desțepenirăm": "desțepeni",
    "desțepenirăți": "desțepeni",
    "desțepenise": "desțepeni",
    "desțepenisem": "desțepeni",
    "desțepeniseră": "desțepeni",
    "desțepeniserăm": "desțepeni",
    "desțepeniserăți": "desțepeni",
    "desțepeniseși": "desțepeni",
    "desțepeniși": "desțepeni",
    "desțepenit": "desțepeni",
    "desțepeniți": "desțepeni",
    "desțepenitu": "desțepeni",
    "nedesțepenind": "desțepeni",
    "nedesțepenindu": "desțepeni",
    "nemaidesțepenind": "desțepeni",
    "nemaidesțepenindu": "desțepeni",
    "desțepenită": "desțepenit",
    "desțepenite": "desțepenit",
    "desțepeniți": "desțepenit",
    "deșteapta": "deștept",
    "deșteaptă": "deștept",
    "deșteapto": "deștept",
    "deștepte": "deștept",
    "deșteptei": "deștept",
    "deșteptele": "deștept",
    "deșteptelor": "deștept",
    "deștepți": "deștept",
    "deștepții": "deștept",
    "deștepților": "deștept",
    "deșteptul": "deștept",
    "deșteptule": "deștept",
    "deșteptului": "deștept",
    "deșteaptă": "deștepta",
    "deștept": "deștepta",
    "deșteptă": "deștepta",
    "deșteptai": "deștepta",
    "deșteptam": "deștepta",
    "deșteptăm": "deștepta",
    "deșteptând": "deștepta",
    "deșteptându": "deștepta",
    "deșteptară": "deștepta",
    "deșteptarăm": "deștepta",
    "deșteptarăți": "deștepta",
    "deșteptase": "deștepta",
    "deșteptasem": "deștepta",
    "deșteptaseră": "deștepta",
    "deșteptaserăm": "deștepta",
    "deșteptaserăți": "deștepta",
    "deșteptaseși": "deștepta",
    "deșteptași": "deștepta",
    "deșteptat": "deștepta",
    "deșteptați": "deștepta",
    "deșteptatu": "deștepta",
    "deșteptau": "deștepta",
    "deștepte": "deștepta",
    "deștepți": "deștepta",
    "nedeșteptând": "deștepta",
    "nedeșteptându": "deștepta",
    "nemaideșteptând": "deștepta",
    "nemaideșteptându": "deștepta",
    "deșteptăciunea": "deșteptăciune",
    "deșteptăciuneo": "deșteptăciune",
    "deșteptăciuni": "deșteptăciune",
    "deșteptăciunii": "deșteptăciune",
    "deșteptăciunile": "deșteptăciune",
    "deșteptăciunilor": "deșteptăciune",
    "deșteptarea": "deșteptare",
    "deșteptareo": "deșteptare",
    "deșteptări": "deșteptare",
    "deșteptării": "deșteptare",
    "deșteptările": "deșteptare",
    "deșteptărilor": "deșteptare",
    "deșteptată": "deșteptat",
    "deșteptate": "deșteptat",
    "deșteptați": "deșteptat",
    "deșteptatul": "deșteptat",
    "deșteptatule": "deșteptat",
    "deșteptatului": "deșteptat",
    "deșteptătoare": "deșteptător",
    "deșteptătoarea": "deșteptător",
    "deșteptătoarei": "deșteptător",
    "deșteptătoarele": "deșteptător",
    "deșteptătoarelor": "deșteptător",
    "deșteptătoareo": "deșteptător",
    "deșteptători": "deșteptător",
    "deșteptătorii": "deșteptător",
    "deșteptătorilor": "deșteptător",
    "deșteptătorul": "deșteptător",
    "deșteptătorule": "deșteptător",
    "deșteptătorului": "deșteptător",
    "destine": "destin",
    "destinele": "destin",
    "destinelor": "destin",
    "destinul": "destin",
    "destinule": "destin",
    "destinului": "destin",
    "destină": "destina",
    "destinai": "destina",
    "destinam": "destina",
    "destinăm": "destina",
    "destinând": "destina",
    "destinându": "destina",
    "destinară": "destina",
    "destinarăm": "destina",
    "destinarăți": "destina",
    "destinase": "destina",
    "destinasem": "destina",
    "destinaseră": "destina",
    "destinaserăm": "destina",
    "destinaserăți": "destina",
    "destinaseși": "destina",
    "destinași": "destina",
    "destinat": "destina",
    "destinați": "destina",
    "destinatu": "destina",
    "destinau": "destina",
    "destinează": "destina",
    "destinez": "destina",
    "destineze": "destina",
    "destinezi": "destina",
    "nedestinând": "destina",
    "nedestinându": "destina",
    "nemaidestinând": "destina",
    "nemaidestinându": "destina",
    "destinată": "destinat",
    "destinate": "destinat",
    "destinați": "destinat",
    "destinatari": "destinatar",
    "destinatarii": "destinatar",
    "destinatarilor": "destinatar",
    "destinatarul": "destinatar",
    "destinatarule": "destinatar",
    "destinatarului": "destinatar",
    "destinatara": "destinatară",
    "destinatare": "destinatară",
    "destinatarei": "destinatară",
    "destinatarele": "destinatară",
    "destinatarelor": "destinatară",
    "destinataro": "destinatară",
    "destinația": "destinație",
    "destinației": "destinație",
    "destinații": "destinație",
    "destinațiile": "destinație",
    "destinațiilor": "destinație",
    "destinațio": "destinație",
    "destind": "destinde",
    "destindă": "destinde",
    "destindea": "destinde",
    "destindeai": "destinde",
    "destindeam": "destinde",
    "destindeați": "destinde",
    "destindeau": "destinde",
    "destindem": "destinde",
    "destindeți": "destinde",
    "destins": "destinde",
    "destinse": "destinde",
    "destinsei": "destinde",
    "destinseră": "destinde",
    "destinserăm": "destinde",
    "destinserăți": "destinde",
    "destinsese": "destinde",
    "destinsesem": "destinde",
    "destinseseră": "destinde",
    "destinseserăm": "destinde",
    "destinseserăți": "destinde",
    "destinseseși": "destinde",
    "destinseși": "destinde",
    "destinsu": "destinde",
    "destinzând": "destinde",
    "destinzându": "destinde",
    "destinzi": "destinde",
    "nedestinzând": "destinde",
    "nedestinzându": "destinde",
    "nemaidestinzând": "destinde",
    "nemaidestinzându": "destinde",
    "destinderea": "destindere",
    "destindereo": "destindere",
    "destinderi": "destindere",
    "destinderii": "destindere",
    "destinderile": "destindere",
    "destinderilor": "destindere",
    "destinsa": "destins",
    "destinsă": "destins",
    "destinse": "destins",
    "destinsei": "destins",
    "destinsele": "destins",
    "destinselor": "destins",
    "destinși": "destins",
    "destinșii": "destins",
    "destinșilor": "destins",
    "destinso": "destins",
    "destinsul": "destins",
    "destinsule": "destins",
    "destinsului": "destins",
    "destituia": "destitui",
    "destituiai": "destitui",
    "destituiam": "destitui",
    "destituiați": "destitui",
    "destituiau": "destitui",
    "destituie": "destitui",
    "destituii": "destitui",
    "destituim": "destitui",
    "destituind": "destitui",
    "destituindu": "destitui",
    "destituiră": "destitui",
    "destituirăm": "destitui",
    "destituirăți": "destitui",
    "destituise": "destitui",
    "destituisem": "destitui",
    "destituiseră": "destitui",
    "destituiserăm": "destitui",
    "destituiserăți": "destitui",
    "destituiseși": "destitui",
    "destituiși": "destitui",
    "destituit": "destitui",
    "destituiți": "destitui",
    "destituitu": "destitui",
    "nedestituind": "destitui",
    "nedestituindu": "destitui",
    "nemaidestituind": "destitui",
    "nemaidestituindu": "destitui",
    "destituirea": "destituire",
    "destituireo": "destituire",
    "destituiri": "destituire",
    "destituirii": "destituire",
    "destituirile": "destituire",
    "destituirilor": "destituire",
    "destituită": "destituit",
    "destituite": "destituit",
    "destituiți": "destituit",
    "destoinica": "destoinic",
    "destoinică": "destoinic",
    "destoinice": "destoinic",
    "destoinicei": "destoinic",
    "destoinicele": "destoinic",
    "destoinicelor": "destoinic",
    "destoinici": "destoinic",
    "destoinicii": "destoinic",
    "destoinicilor": "destoinic",
    "destoinico": "destoinic",
    "destoinicul": "destoinic",
    "destoinicule": "destoinic",
    "destoinicului": "destoinic",
    "destrăbălă": "destrăbăla",
    "destrăbălai": "destrăbăla",
    "destrăbălam": "destrăbăla",
    "destrăbălăm": "destrăbăla",
    "destrăbălând": "destrăbăla",
    "destrăbălându": "destrăbăla",
    "destrăbălară": "destrăbăla",
    "destrăbălarăm": "destrăbăla",
    "destrăbălarăți": "destrăbăla",
    "destrăbălase": "destrăbăla",
    "destrăbălasem": "destrăbăla",
    "destrăbălaseră": "destrăbăla",
    "destrăbălaserăm": "destrăbăla",
    "destrăbălaserăți": "destrăbăla",
    "destrăbălaseși": "destrăbăla",
    "destrăbălași": "destrăbăla",
    "destrăbălat": "destrăbăla",
    "destrăbălați": "destrăbăla",
    "destrăbălatu": "destrăbăla",
    "destrăbălau": "destrăbăla",
    "destrăbălează": "destrăbăla",
    "destrăbălez": "destrăbăla",
    "destrăbăleze": "destrăbăla",
    "destrăbălezi": "destrăbăla",
    "nedestrăbălând": "destrăbăla",
    "nedestrăbălându": "destrăbăla",
    "nemaidestrăbălând": "destrăbăla",
    "nemaidestrăbălându": "destrăbăla",
    "destrăbălarea": "destrăbălare",
    "destrăbălareo": "destrăbălare",
    "destrăbălări": "destrăbălare",
    "destrăbălării": "destrăbălare",
    "destrăbălările": "destrăbălare",
    "destrăbălărilor": "destrăbălare",
    "destrăbălata": "destrăbălat",
    "destrăbălată": "destrăbălat",
    "destrăbălate": "destrăbălat",
    "destrăbălatei": "destrăbălat",
    "destrăbălatele": "destrăbălat",
    "destrăbălatelor": "destrăbălat",
    "destrăbălați": "destrăbălat",
    "destrăbălații": "destrăbălat",
    "destrăbălaților": "destrăbălat",
    "destrăbălato": "destrăbălat",
    "destrăbălatul": "destrăbălat",
    "destrăbălatule": "destrăbălat",
    "destrăbălatului": "destrăbălat",
    "destrăbălata": "destrăbălată",
    "destrăbălate": "destrăbălată",
    "destrăbălatei": "destrăbălată",
    "destrăbălatele": "destrăbălată",
    "destrăbălatelor": "destrăbălată",
    "destrăbălato": "destrăbălată",
    "destram": "destrăma",
    "destramă": "destrăma",
    "destrămă": "destrăma",
    "destrămai": "destrăma",
    "destrămam": "destrăma",
    "destrămăm": "destrăma",
    "destrămând": "destrăma",
    "destrămându": "destrăma",
    "destrămară": "destrăma",
    "destrămarăm": "destrăma",
    "destrămarăți": "destrăma",
    "destrămase": "destrăma",
    "destrămasem": "destrăma",
    "destrămaseră": "destrăma",
    "destrămaserăm": "destrăma",
    "destrămaserăți": "destrăma",
    "destrămaseși": "destrăma",
    "destrămași": "destrăma",
    "destrămat": "destrăma",
    "destrămați": "destrăma",
    "destrămatu": "destrăma",
    "destrămau": "destrăma",
    "destrame": "destrăma",
    "destrami": "destrăma",
    "nedestrămând": "destrăma",
    "nedestrămându": "destrăma",
    "nemaidestrămând": "destrăma",
    "nemaidestrămându": "destrăma",
    "destrămarea": "destrămare",
    "destrămareo": "destrămare",
    "destrămări": "destrămare",
    "destrămării": "destrămare",
    "destrămările": "destrămare",
    "destrămărilor": "destrămare",
    "destrămata": "destrămat",
    "destrămată": "destrămat",
    "destrămate": "destrămat",
    "destrămatei": "destrămat",
    "destrămatele": "destrămat",
    "destrămatelor": "destrămat",
    "destrămați": "destrămat",
    "destrămații": "destrămat",
    "destrămaților": "destrămat",
    "destrămato": "destrămat",
    "destrămatul": "destrămat",
    "destrămatule": "destrămat",
    "destrămatului": "destrămat",
    "destrămătoare": "destrămător",
    "destrămătoarele": "destrămător",
    "destrămătoarelor": "destrămător",
    "destrămătorul": "destrămător",
    "destrămătorule": "destrămător",
    "destrămătorului": "destrămător",
    "destrămătura": "destrămătură",
    "destrămături": "destrămătură",
    "destrămăturii": "destrămătură",
    "destrămăturile": "destrămătură",
    "destrămăturilor": "destrămătură",
    "destrămăturo": "destrămătură",
    "destroienea": "destroieni",
    "destroieneai": "destroieni",
    "destroieneam": "destroieni",
    "destroienească": "destroieni",
    "destroieneați": "destroieni",
    "destroieneau": "destroieni",
    "destroienesc": "destroieni",
    "destroienește": "destroieni",
    "destroienești": "destroieni",
    "destroienii": "destroieni",
    "destroienim": "destroieni",
    "destroienind": "destroieni",
    "destroienindu": "destroieni",
    "destroieniră": "destroieni",
    "destroienirăm": "destroieni",
    "destroienirăți": "destroieni",
    "destroienise": "destroieni",
    "destroienisem": "destroieni",
    "destroieniseră": "destroieni",
    "destroieniserăm": "destroieni",
    "destroieniserăți": "destroieni",
    "destroieniseși": "destroieni",
    "destroieniși": "destroieni",
    "destroienit": "destroieni",
    "destroieniți": "destroieni",
    "destroienitu": "destroieni",
    "nedestroienind": "destroieni",
    "nedestroienindu": "destroieni",
    "nemaidestroienind": "destroieni",
    "nemaidestroienindu": "destroieni",
    "destroienirea": "destroienire",
    "destroienireo": "destroienire",
    "destroieniri": "destroienire",
    "destroienirii": "destroienire",
    "destroienirile": "destroienire",
    "destroienirilor": "destroienire",
    "destroienita": "destroienit",
    "destroienită": "destroienit",
    "destroienite": "destroienit",
    "destroienitei": "destroienit",
    "destroienitele": "destroienit",
    "destroienitelor": "destroienit",
    "destroieniți": "destroienit",
    "destroieniții": "destroienit",
    "destroieniților": "destroienit",
    "destroienito": "destroienit",
    "destroienitul": "destroienit",
    "destroienitule": "destroienit",
    "destroienitului": "destroienit",
    "destructiva": "destructiv",
    "destructivă": "destructiv",
    "destructive": "destructiv",
    "destructivei": "destructiv",
    "destructivele": "destructiv",
    "destructivelor": "destructiv",
    "destructivi": "destructiv",
    "destructivii": "destructiv",
    "destructivilor": "destructiv",
    "destructivo": "destructiv",
    "destructivul": "destructiv",
    "destructivule": "destructiv",
    "destructivului": "destructiv",
    "destructoarea": "destructoare",
    "destructoarei": "destructoare",
    "destructoarele": "destructoare",
    "destructoarelor": "destructoare",
    "destructoareo": "destructoare",
    "destructori": "destructor",
    "destructorii": "destructor",
    "destructorilor": "destructor",
    "destructorul": "destructor",
    "destructorule": "destructor",
    "destructorului": "destructor",
    "dăstul": "destul",
    "dăstule": "destul",
    "destui": "destul",
    "destuii": "destul",
    "destuilor": "destul",
    "destula": "destul",
    "destulă": "destul",
    "destule": "destul",
    "destulei": "destul",
    "destulele": "destul",
    "destulelor": "destul",
    "destulo": "destul",
    "destulul": "destul",
    "destulule": "destul",
    "destulului": "destul",
    "destup": "destupa",
    "destupă": "destupa",
    "destupai": "destupa",
    "destupam": "destupa",
    "destupăm": "destupa",
    "destupând": "destupa",
    "destupându": "destupa",
    "destupară": "destupa",
    "destuparăm": "destupa",
    "destuparăți": "destupa",
    "destupase": "destupa",
    "destupasem": "destupa",
    "destupaseră": "destupa",
    "destupaserăm": "destupa",
    "destupaserăți": "destupa",
    "destupaseși": "destupa",
    "destupași": "destupa",
    "destupat": "destupa",
    "destupați": "destupa",
    "destupatu": "destupa",
    "destupau": "destupa",
    "destupe": "destupa",
    "destupi": "destupa",
    "nedestupând": "destupa",
    "nedestupându": "destupa",
    "nemaidestupând": "destupa",
    "nemaidestupându": "destupa",
    "destuparea": "destupare",
    "destupareo": "destupare",
    "destupări": "destupare",
    "destupării": "destupare",
    "destupările": "destupare",
    "destupărilor": "destupare",
    "destupată": "destupat",
    "destupate": "destupat",
    "destupați": "destupat",
    "deșucheata": "deșucheat",
    "deșucheată": "deșucheat",
    "deșucheate": "deșucheat",
    "deșucheatei": "deșucheat",
    "deșucheatele": "deșucheat",
    "deșucheatelor": "deșucheat",
    "deșucheați": "deșucheat",
    "deșucheații": "deșucheat",
    "deșucheaților": "deșucheat",
    "deșucheato": "deșucheat",
    "deșucheatul": "deșucheat",
    "deșucheatule": "deșucheat",
    "deșucheatului": "deșucheat",
    "desueta": "desuet",
    "desuetă": "desuet",
    "desuete": "desuet",
    "desuetei": "desuet",
    "desuetele": "desuet",
    "desuetelor": "desuet",
    "desueți": "desuet",
    "desueții": "desuet",
    "desueților": "desuet",
    "desueto": "desuet",
    "desuetul": "desuet",
    "desuetule": "desuet",
    "desuetului": "desuet",
    "desuetudinea": "desuetudine",
    "desuetudineo": "desuetudine",
    "desuetudini": "desuetudine",
    "desuetudinii": "desuetudine",
    "desuetudinile": "desuetudine",
    "desuetudinilor": "desuetudine",
    "deșurubă": "deșuruba",
    "deșurubai": "deșuruba",
    "deșurubam": "deșuruba",
    "deșurubăm": "deșuruba",
    "deșurubând": "deșuruba",
    "deșurubându": "deșuruba",
    "deșurubară": "deșuruba",
    "deșurubarăm": "deșuruba",
    "deșurubarăți": "deșuruba",
    "deșurubase": "deșuruba",
    "deșurubasem": "deșuruba",
    "deșurubaseră": "deșuruba",
    "deșurubaserăm": "deșuruba",
    "deșurubaserăți": "deșuruba",
    "deșurubaseși": "deșuruba",
    "deșurubași": "deșuruba",
    "deșurubat": "deșuruba",
    "deșurubați": "deșuruba",
    "deșurubatu": "deșuruba",
    "deșurubau": "deșuruba",
    "deșurubează": "deșuruba",
    "deșurubez": "deșuruba",
    "deșurubeze": "deșuruba",
    "deșurubezi": "deșuruba",
    "nedeșurubând": "deșuruba",
    "nedeșurubându": "deșuruba",
    "nemaideșurubând": "deșuruba",
    "nemaideșurubându": "deșuruba",
    "deșurubarea": "deșurubare",
    "deșurubareo": "deșurubare",
    "deșurubări": "deșurubare",
    "deșurubării": "deșurubare",
    "deșurubările": "deșurubare",
    "deșurubărilor": "deșurubare",
    "deșurubata": "deșurubat",
    "deșurubată": "deșurubat",
    "deșurubate": "deșurubat",
    "deșurubatei": "deșurubat",
    "deșurubatele": "deșurubat",
    "deșurubatelor": "deșurubat",
    "deșurubați": "deșurubat",
    "deșurubații": "deșurubat",
    "deșurubaților": "deșurubat",
    "deșurubato": "deșurubat",
    "deșurubatul": "deșurubat",
    "deșurubatule": "deșurubat",
    "deșurubatului": "deșurubat",
    "deszăpezea": "deszăpezi",
    "deszăpezeai": "deszăpezi",
    "deszăpezeam": "deszăpezi",
    "deszăpezească": "deszăpezi",
    "deszăpezeați": "deszăpezi",
    "deszăpezeau": "deszăpezi",
    "deszăpezesc": "deszăpezi",
    "deszăpezește": "deszăpezi",
    "deszăpezești": "deszăpezi",
    "deszăpezii": "deszăpezi",
    "deszăpezim": "deszăpezi",
    "deszăpezind": "deszăpezi",
    "deszăpezindu": "deszăpezi",
    "deszăpeziră": "deszăpezi",
    "deszăpezirăm": "deszăpezi",
    "deszăpezirăți": "deszăpezi",
    "deszăpezise": "deszăpezi",
    "deszăpezisem": "deszăpezi",
    "deszăpeziseră": "deszăpezi",
    "deszăpeziserăm": "deszăpezi",
    "deszăpeziserăți": "deszăpezi",
    "deszăpeziseși": "deszăpezi",
    "deszăpeziși": "deszăpezi",
    "deszăpezit": "deszăpezi",
    "deszăpeziți": "deszăpezi",
    "deszăpezitu": "deszăpezi",
    "nedeszăpezind": "deszăpezi",
    "nedeszăpezindu": "deszăpezi",
    "nemaideszăpezind": "deszăpezi",
    "nemaideszăpezindu": "deszăpezi",
    "deszăpezirea": "deszăpezire",
    "deszăpezireo": "deszăpezire",
    "deszăpeziri": "deszăpezire",
    "deszăpezirii": "deszăpezire",
    "deszăpezirile": "deszăpezire",
    "deszăpezirilor": "deszăpezire",
    "deszăpezita": "deszăpezit",
    "deszăpezită": "deszăpezit",
    "deszăpezite": "deszăpezit",
    "deszăpezitei": "deszăpezit",
    "deszăpezitele": "deszăpezit",
    "deszăpezitelor": "deszăpezit",
    "deszăpeziți": "deszăpezit",
    "deszăpeziții": "deszăpezit",
    "deszăpeziților": "deszăpezit",
    "deszăpezito": "deszăpezit",
    "deszăpezitul": "deszăpezit",
    "deszăpezitule": "deszăpezit",
    "deszăpezitului": "deszăpezit",
    "detailata": "detailat",
    "detailată": "detailat",
    "detailate": "detailat",
    "detailatei": "detailat",
    "detailatele": "detailat",
    "detailatelor": "detailat",
    "detailați": "detailat",
    "detailații": "detailat",
    "detailaților": "detailat",
    "detailato": "detailat",
    "detailatul": "detailat",
    "detailatule": "detailat",
    "detailatului": "detailat",
    "detaliai": "detalia",
    "detaliam": "detalia",
    "detaliară": "detalia",
    "detaliarăm": "detalia",
    "detaliarăți": "detalia",
    "detaliase": "detalia",
    "detaliasem": "detalia",
    "detaliaseră": "detalia",
    "detaliaserăm": "detalia",
    "detaliaserăți": "detalia",
    "detaliaseși": "detalia",
    "detaliași": "detalia",
    "detaliat": "detalia",
    "detaliați": "detalia",
    "detaliatu": "detalia",
    "detaliau": "detalia",
    "detaliază": "detalia",
    "detalie": "detalia",
    "detaliem": "detalia",
    "detaliez": "detalia",
    "detalieze": "detalia",
    "detaliezi": "detalia",
    "detaliind": "detalia",
    "detaliindu": "detalia",
    "nedetaliind": "detalia",
    "nedetaliindu": "detalia",
    "nemaidetaliind": "detalia",
    "nemaidetaliindu": "detalia",
    "detaliata": "detaliat",
    "detaliată": "detaliat",
    "detaliate": "detaliat",
    "detaliatei": "detaliat",
    "detaliatele": "detaliat",
    "detaliatelor": "detaliat",
    "detaliați": "detaliat",
    "detaliații": "detaliat",
    "detaliaților": "detaliat",
    "detaliato": "detaliat",
    "detaliatul": "detaliat",
    "detaliatule": "detaliat",
    "detaliatului": "detaliat",
    "detalii": "detaliu",
    "detaliile": "detaliu",
    "detaliilor": "detaliu",
    "detaliul": "detaliu",
    "detaliule": "detaliu",
    "detaliului": "detaliu",
    "detașă": "detașa",
    "detașai": "detașa",
    "detașam": "detașa",
    "detașăm": "detașa",
    "detașând": "detașa",
    "detașându": "detașa",
    "detașară": "detașa",
    "detașarăm": "detașa",
    "detașarăți": "detașa",
    "detașase": "detașa",
    "detașasem": "detașa",
    "detașaseră": "detașa",
    "detașaserăm": "detașa",
    "detașaserăți": "detașa",
    "detașaseși": "detașa",
    "detașași": "detașa",
    "detașat": "detașa",
    "detașați": "detașa",
    "detașatu": "detașa",
    "detașau": "detașa",
    "detașează": "detașa",
    "detașez": "detașa",
    "detașeze": "detașa",
    "detașezi": "detașa",
    "nedetașând": "detașa",
    "nedetașându": "detașa",
    "nemaidetașând": "detașa",
    "nemaidetașându": "detașa",
    "detașabila": "detașabil",
    "detașabilă": "detașabil",
    "detașabile": "detașabil",
    "detașabilei": "detașabil",
    "detașabilele": "detașabil",
    "detașabilelor": "detașabil",
    "detașabili": "detașabil",
    "detașabilii": "detașabil",
    "detașabililor": "detașabil",
    "detașabilo": "detașabil",
    "detașabilul": "detașabil",
    "detașabilule": "detașabil",
    "detașabilului": "detașabil",
    "detașamente": "detașament",
    "detașamentele": "detașament",
    "detașamentelor": "detașament",
    "detașamentul": "detașament",
    "detașamentule": "detașament",
    "detașamentului": "detașament",
    "detașarea": "detașare",
    "detașareo": "detașare",
    "detașări": "detașare",
    "detașării": "detașare",
    "detașările": "detașare",
    "detașărilor": "detașare",
    "detașata": "detașat",
    "detașată": "detașat",
    "detașate": "detașat",
    "detașatei": "detașat",
    "detașatele": "detașat",
    "detașatelor": "detașat",
    "detașați": "detașat",
    "detașații": "detașat",
    "detașaților": "detașat",
    "detașato": "detașat",
    "detașatul": "detașat",
    "detașatule": "detașat",
    "detașatului": "detașat",
    "detectă": "detecta",
    "detectai": "detecta",
    "detectam": "detecta",
    "detectăm": "detecta",
    "detectând": "detecta",
    "detectându": "detecta",
    "detectară": "detecta",
    "detectarăm": "detecta",
    "detectarăți": "detecta",
    "detectase": "detecta",
    "detectasem": "detecta",
    "detectaseră": "detecta",
    "detectaserăm": "detecta",
    "detectaserăți": "detecta",
    "detectaseși": "detecta",
    "detectași": "detecta",
    "detectat": "detecta",
    "detectați": "detecta",
    "detectatu": "detecta",
    "detectau": "detecta",
    "detectează": "detecta",
    "detectez": "detecta",
    "detecteze": "detecta",
    "detectezi": "detecta",
    "nedetectând": "detecta",
    "nedetectându": "detecta",
    "nemaidetectând": "detecta",
    "nemaidetectându": "detecta",
    "detectarea": "detectare",
    "detectareo": "detectare",
    "detectări": "detectare",
    "detectării": "detectare",
    "detectările": "detectare",
    "detectărilor": "detectare",
    "detectată": "detectat",
    "detectate": "detectat",
    "detectați": "detectat",
    "detecția": "detecție",
    "detecției": "detecție",
    "detecții": "detecție",
    "detecțiile": "detecție",
    "detecțiilor": "detecție",
    "detecțio": "detecție",
    "detectivi": "detectiv",
    "detectivii": "detectiv",
    "detectivilor": "detectiv",
    "detectivul": "detectiv",
    "detectivule": "detectiv",
    "detectivului": "detectiv",
    "detectiva": "detectivă",
    "detective": "detectivă",
    "detectivei": "detectivă",
    "detectivele": "detectivă",
    "detectivelor": "detectivă",
    "detectivo": "detectivă",
    "detectoare": "detector",
    "detectoarele": "detector",
    "detectoarelor": "detector",
    "detectorul": "detector",
    "detectorule": "detector",
    "detectorului": "detector",
    "detenția": "detenție",
    "detenției": "detenție",
    "detenții": "detenție",
    "detențiile": "detenție",
    "detențiilor": "detenție",
    "detențio": "detenție",
    "detergenți": "detergent",
    "detergenții": "detergent",
    "detergenților": "detergent",
    "detergentul": "detergent",
    "detergentului": "detergent",
    "deterioră": "deteriora",
    "deteriorai": "deteriora",
    "deterioram": "deteriora",
    "deteriorăm": "deteriora",
    "deteriorând": "deteriora",
    "deteriorându": "deteriora",
    "deteriorară": "deteriora",
    "deteriorarăm": "deteriora",
    "deteriorarăți": "deteriora",
    "deteriorase": "deteriora",
    "deteriorasem": "deteriora",
    "deterioraseră": "deteriora",
    "deterioraserăm": "deteriora",
    "deterioraserăți": "deteriora",
    "deterioraseși": "deteriora",
    "deteriorași": "deteriora",
    "deteriorat": "deteriora",
    "deteriorați": "deteriora",
    "deterioratu": "deteriora",
    "deteriorau": "deteriora",
    "deteriorează": "deteriora",
    "deteriorez": "deteriora",
    "deterioreze": "deteriora",
    "deteriorezi": "deteriora",
    "nedeteriorând": "deteriora",
    "nedeteriorându": "deteriora",
    "nemaideteriorând": "deteriora",
    "nemaideteriorându": "deteriora",
    "deteriorarea": "deteriorare",
    "deteriorareo": "deteriorare",
    "deteriorări": "deteriorare",
    "deteriorării": "deteriorare",
    "deteriorările": "deteriorare",
    "deteriorărilor": "deteriorare",
    "deteriorata": "deteriorat",
    "deteriorată": "deteriorat",
    "deteriorate": "deteriorat",
    "deterioratei": "deteriorat",
    "deterioratele": "deteriorat",
    "deterioratelor": "deteriorat",
    "deteriorați": "deteriorat",
    "deteriorații": "deteriorat",
    "deterioraților": "deteriorat",
    "deteriorato": "deteriorat",
    "deterioratul": "deteriorat",
    "deterioratule": "deteriorat",
    "deterioratului": "deteriorat",
    "determin": "determina",
    "determină": "determina",
    "determinai": "determina",
    "determinam": "determina",
    "determinăm": "determina",
    "determinând": "determina",
    "determinându": "determina",
    "determinară": "determina",
    "determinarăm": "determina",
    "determinarăți": "determina",
    "determinase": "determina",
    "determinasem": "determina",
    "determinaseră": "determina",
    "determinaserăm": "determina",
    "determinaserăți": "determina",
    "determinaseși": "determina",
    "determinași": "determina",
    "determinat": "determina",
    "determinați": "determina",
    "determinatu": "determina",
    "determinau": "determina",
    "determine": "determina",
    "determini": "determina",
    "nedeterminând": "determina",
    "nedeterminându": "determina",
    "nemaideterminând": "determina",
    "nemaideterminându": "determina",
    "determinabila": "determinabil",
    "determinabilă": "determinabil",
    "determinabile": "determinabil",
    "determinabilei": "determinabil",
    "determinabilele": "determinabil",
    "determinabilelor": "determinabil",
    "determinabili": "determinabil",
    "determinabilii": "determinabil",
    "determinabililor": "determinabil",
    "determinabilo": "determinabil",
    "determinabilul": "determinabil",
    "determinabilule": "determinabil",
    "determinabilului": "determinabil",
    "determinantă": "determinant",
    "determinante": "determinant",
    "determinantele": "determinant",
    "determinantelor": "determinant",
    "determinanți": "determinant",
    "determinanții": "determinant",
    "determinanților": "determinant",
    "determinantul": "determinant",
    "determinantule": "determinant",
    "determinantului": "determinant",
    "determinarea": "determinare",
    "determinareo": "determinare",
    "determinări": "determinare",
    "determinării": "determinare",
    "determinările": "determinare",
    "determinărilor": "determinare",
    "determinata": "determinat",
    "determinată": "determinat",
    "determinate": "determinat",
    "determinatei": "determinat",
    "determinatele": "determinat",
    "determinatelor": "determinat",
    "determinați": "determinat",
    "determinații": "determinat",
    "determinaților": "determinat",
    "determinato": "determinat",
    "determinatul": "determinat",
    "determinatule": "determinat",
    "determinatului": "determinat",
    "determinativa": "determinativ",
    "determinativă": "determinativ",
    "determinative": "determinativ",
    "determinativei": "determinativ",
    "determinativele": "determinativ",
    "determinativelor": "determinativ",
    "determinativi": "determinativ",
    "determinativii": "determinativ",
    "determinativilor": "determinativ",
    "determinativo": "determinativ",
    "determinativul": "determinativ",
    "determinativule": "determinativ",
    "determinativului": "determinativ",
    "determinismul": "determinism",
    "determinismule": "determinism",
    "determinismului": "determinism",
    "determinista": "determinist",
    "deterministă": "determinist",
    "deterministe": "determinist",
    "deterministei": "determinist",
    "deterministele": "determinist",
    "deterministelor": "determinist",
    "determiniști": "determinist",
    "determiniștii": "determinist",
    "determiniștilor": "determinist",
    "deterministo": "determinist",
    "deterministul": "determinist",
    "deterministule": "determinist",
    "deterministului": "determinist",
    "determinista": "deterministă",
    "deterministe": "deterministă",
    "deterministei": "deterministă",
    "deterministele": "deterministă",
    "deterministelor": "deterministă",
    "deterministo": "deterministă",
    "detest": "detesta",
    "detestă": "detesta",
    "detestai": "detesta",
    "detestam": "detesta",
    "detestăm": "detesta",
    "detestând": "detesta",
    "detestându": "detesta",
    "detestară": "detesta",
    "detestarăm": "detesta",
    "detestarăți": "detesta",
    "detestase": "detesta",
    "detestasem": "detesta",
    "detestaseră": "detesta",
    "detestaserăm": "detesta",
    "detestaserăți": "detesta",
    "detestaseși": "detesta",
    "detestași": "detesta",
    "detestat": "detesta",
    "detestați": "detesta",
    "detestatu": "detesta",
    "detestau": "detesta",
    "deteste": "detesta",
    "detești": "detesta",
    "nedetestând": "detesta",
    "nedetestându": "detesta",
    "nemaidetestând": "detesta",
    "nemaidetestându": "detesta",
    "detestabila": "detestabil",
    "detestabilă": "detestabil",
    "detestabile": "detestabil",
    "detestabilei": "detestabil",
    "detestabilele": "detestabil",
    "detestabilelor": "detestabil",
    "detestabili": "detestabil",
    "detestabilii": "detestabil",
    "detestabililor": "detestabil",
    "detestabilo": "detestabil",
    "detestabilul": "detestabil",
    "detestabilule": "detestabil",
    "detestabilului": "detestabil",
    "detestată": "detestat",
    "detestate": "detestat",
    "detestați": "detestat",
    "deținătoarea": "deținătoare",
    "deținătoarei": "deținătoare",
    "deținătoarele": "deținătoare",
    "deținătoarelor": "deținătoare",
    "deținătoareo": "deținătoare",
    "deținătoare": "deținător",
    "deținătoarea": "deținător",
    "deținătoarei": "deținător",
    "deținătoarele": "deținător",
    "deținătoarelor": "deținător",
    "deținătoareo": "deținător",
    "deținători": "deținător",
    "deținătorii": "deținător",
    "deținătorilor": "deținător",
    "deținătorul": "deținător",
    "deținătorule": "deținător",
    "deținătorului": "deținător",
    "deții": "deține",
    "dețin": "deține",
    "dețină": "deține",
    "deținând": "deține",
    "deținându": "deține",
    "deținea": "deține",
    "dețineai": "deține",
    "dețineam": "deține",
    "dețineați": "deține",
    "dețineau": "deține",
    "deținem": "deține",
    "dețineți": "deține",
    "deținu": "deține",
    "deținui": "deține",
    "deținură": "deține",
    "deținurăm": "deține",
    "deținurăți": "deține",
    "deținuse": "deține",
    "deținusem": "deține",
    "deținuseră": "deține",
    "deținuserăm": "deține",
    "deținuserăți": "deține",
    "deținuseși": "deține",
    "deținuși": "deține",
    "deținut": "deține",
    "deținutu": "deține",
    "nedeținând": "deține",
    "nedeținându": "deține",
    "nemaideținând": "deține",
    "nemaideținându": "deține",
    "deținerea": "deținere",
    "deținereo": "deținere",
    "dețineri": "deținere",
    "deținerii": "deținere",
    "deținerile": "deținere",
    "deținerilor": "deținere",
    "deținuta": "deținut",
    "deținută": "deținut",
    "deținute": "deținut",
    "deținutei": "deținut",
    "deținutele": "deținut",
    "deținutelor": "deținut",
    "deținuți": "deținut",
    "deținuții": "deținut",
    "deținuților": "deținut",
    "deținutul": "deținut",
    "deținutule": "deținut",
    "deținutului": "deținut",
    "deținuta": "deținută",
    "deținute": "deținută",
    "deținutei": "deținută",
    "deținutele": "deținută",
    "deținutelor": "deținută",
    "deținuto": "deținută",
    "detonai": "detona",
    "detonam": "detona",
    "detonând": "detona",
    "detonându": "detona",
    "detonară": "detona",
    "detonarăm": "detona",
    "detonarăți": "detona",
    "detonase": "detona",
    "detonasem": "detona",
    "detonaseră": "detona",
    "detonaserăm": "detona",
    "detonaserăți": "detona",
    "detonaseși": "detona",
    "detonași": "detona",
    "detonat": "detona",
    "detonați": "detona",
    "detonatu": "detona",
    "detonau": "detona",
    "detonanta": "detonant",
    "detonantă": "detonant",
    "detonante": "detonant",
    "detonantei": "detonant",
    "detonantele": "detonant",
    "detonantelor": "detonant",
    "detonanți": "detonant",
    "detonanții": "detonant",
    "detonanților": "detonant",
    "detonanto": "detonant",
    "detonantul": "detonant",
    "detonantule": "detonant",
    "detonantului": "detonant",
    "detonarea": "detonare",
    "detonareo": "detonare",
    "detonata": "detonat",
    "detonată": "detonat",
    "detonate": "detonat",
    "detonați": "detonat",
    "detonații": "detonat",
    "detonaților": "detonat",
    "detonația": "detonație",
    "detonației": "detonație",
    "detonații": "detonație",
    "detonațiile": "detonație",
    "detonațiilor": "detonație",
    "detonațio": "detonație",
    "detonatoare": "detonator",
    "detonatoarele": "detonator",
    "detonatoarelor": "detonator",
    "detonatorul": "detonator",
    "detonatorule": "detonator",
    "detonatorului": "detonator",
    "detractă": "detracta",
    "detractai": "detracta",
    "detractam": "detracta",
    "detractăm": "detracta",
    "detractând": "detracta",
    "detractându": "detracta",
    "detractară": "detracta",
    "detractarăm": "detracta",
    "detractarăți": "detracta",
    "detractase": "detracta",
    "detractasem": "detracta",
    "detractaseră": "detracta",
    "detractaserăm": "detracta",
    "detractaserăți": "detracta",
    "detractaseși": "detracta",
    "detractași": "detracta",
    "detractat": "detracta",
    "detractați": "detracta",
    "detractatu": "detracta",
    "detractau": "detracta",
    "detractează": "detracta",
    "detractez": "detracta",
    "detracteze": "detracta",
    "detractezi": "detracta",
    "nedetractând": "detracta",
    "nedetractându": "detracta",
    "nemaidetractând": "detracta",
    "nemaidetractându": "detracta",
    "detractată": "detractat",
    "detractate": "detractat",
    "detractați": "detractat",
    "detractoarea": "detractoare",
    "detractoarei": "detractoare",
    "detractoarele": "detractoare",
    "detractoarelor": "detractoare",
    "detractoareo": "detractoare",
    "detractori": "detractor",
    "detractorii": "detractor",
    "detractorilor": "detractor",
    "detractorul": "detractor",
    "detractorule": "detractor",
    "detractorului": "detractor",
    "detronă": "detrona",
    "detronai": "detrona",
    "detronam": "detrona",
    "detronăm": "detrona",
    "detronând": "detrona",
    "detronându": "detrona",
    "detronară": "detrona",
    "detronarăm": "detrona",
    "detronarăți": "detrona",
    "detronase": "detrona",
    "detronasem": "detrona",
    "detronaseră": "detrona",
    "detronaserăm": "detrona",
    "detronaserăți": "detrona",
    "detronaseși": "detrona",
    "detronași": "detrona",
    "detronat": "detrona",
    "detronați": "detrona",
    "detronatu": "detrona",
    "detronau": "detrona",
    "detronează": "detrona",
    "detronez": "detrona",
    "detroneze": "detrona",
    "detronezi": "detrona",
    "nedetronând": "detrona",
    "nedetronându": "detrona",
    "nemaidetronând": "detrona",
    "nemaidetronându": "detrona",
    "detronarea": "detronare",
    "detronareo": "detronare",
    "detronări": "detronare",
    "detronării": "detronare",
    "detronările": "detronare",
    "detronărilor": "detronare",
    "detronata": "detronat",
    "detronată": "detronat",
    "detronate": "detronat",
    "detronatei": "detronat",
    "detronatele": "detronat",
    "detronatelor": "detronat",
    "detronați": "detronat",
    "detronații": "detronat",
    "detronaților": "detronat",
    "detronato": "detronat",
    "detronatul": "detronat",
    "detronatule": "detronat",
    "detronatului": "detronat",
    "detun": "detuna",
    "detună": "detuna",
    "detunai": "detuna",
    "detunam": "detuna",
    "detunăm": "detuna",
    "detunând": "detuna",
    "detunându": "detuna",
    "detunară": "detuna",
    "detunarăm": "detuna",
    "detunarăți": "detuna",
    "detunase": "detuna",
    "detunasem": "detuna",
    "detunaseră": "detuna",
    "detunaserăm": "detuna",
    "detunaserăți": "detuna",
    "detunaseși": "detuna",
    "detunași": "detuna",
    "detunat": "detuna",
    "detunați": "detuna",
    "detunatu": "detuna",
    "detunau": "detuna",
    "detune": "detuna",
    "detuni": "detuna",
    "nedetunând": "detuna",
    "nedetunându": "detuna",
    "nemaidetunând": "detuna",
    "nemaidetunându": "detuna",
    "detunarea": "detunare",
    "detunareo": "detunare",
    "detunări": "detunare",
    "detunării": "detunare",
    "detunările": "detunare",
    "detunărilor": "detunare",
    "detunata": "detunat",
    "detunată": "detunat",
    "detunate": "detunat",
    "detunatei": "detunat",
    "detunatele": "detunat",
    "detunatelor": "detunat",
    "detunați": "detunat",
    "detunații": "detunat",
    "detunaților": "detunat",
    "detunato": "detunat",
    "detunatul": "detunat",
    "detunatule": "detunat",
    "detunatului": "detunat",
    "detunătoare": "detunător",
    "detunătoarea": "detunător",
    "detunătoarei": "detunător",
    "detunătoarele": "detunător",
    "detunătoarelor": "detunător",
    "detunătoareo": "detunător",
    "detunători": "detunător",
    "detunătorii": "detunător",
    "detunătorilor": "detunător",
    "detunătorul": "detunător",
    "detunătorule": "detunător",
    "detunătorului": "detunător",
    "detunătura": "detunătură",
    "detunături": "detunătură",
    "detunăturii": "detunătură",
    "detunăturile": "detunătură",
    "detunăturilor": "detunătură",
    "detunăturo": "detunătură",
    "deturnă": "deturna",
    "deturnai": "deturna",
    "deturnam": "deturna",
    "deturnăm": "deturna",
    "deturnând": "deturna",
    "deturnându": "deturna",
    "deturnară": "deturna",
    "deturnarăm": "deturna",
    "deturnarăți": "deturna",
    "deturnase": "deturna",
    "deturnasem": "deturna",
    "deturnaseră": "deturna",
    "deturnaserăm": "deturna",
    "deturnaserăți": "deturna",
    "deturnaseși": "deturna",
    "deturnași": "deturna",
    "deturnat": "deturna",
    "deturnați": "deturna",
    "deturnatu": "deturna",
    "deturnau": "deturna",
    "deturnează": "deturna",
    "deturnez": "deturna",
    "deturneze": "deturna",
    "deturnezi": "deturna",
    "nedeturnând": "deturna",
    "nedeturnându": "deturna",
    "nemaideturnând": "deturna",
    "nemaideturnându": "deturna",
    "deturnarea": "deturnare",
    "deturnareo": "deturnare",
    "deturnări": "deturnare",
    "deturnării": "deturnare",
    "deturnările": "deturnare",
    "deturnărilor": "deturnare",
    "deturnată": "deturnat",
    "deturnate": "deturnat",
    "deturnați": "deturnat",
    "DM": "Deusch_Mark",
    "devaliză": "devaliza",
    "devalizai": "devaliza",
    "devalizam": "devaliza",
    "devalizăm": "devaliza",
    "devalizând": "devaliza",
    "devalizându": "devaliza",
    "devalizară": "devaliza",
    "devalizarăm": "devaliza",
    "devalizarăți": "devaliza",
    "devalizase": "devaliza",
    "devalizasem": "devaliza",
    "devalizaseră": "devaliza",
    "devalizaserăm": "devaliza",
    "devalizaserăți": "devaliza",
    "devalizaseși": "devaliza",
    "devalizași": "devaliza",
    "devalizat": "devaliza",
    "devalizați": "devaliza",
    "devalizatu": "devaliza",
    "devalizau": "devaliza",
    "devalizează": "devaliza",
    "devalizez": "devaliza",
    "devalizeze": "devaliza",
    "devalizezi": "devaliza",
    "nedevalizând": "devaliza",
    "nedevalizându": "devaliza",
    "nemaidevalizând": "devaliza",
    "nemaidevalizându": "devaliza",
    "devalizată": "devalizat",
    "devalizate": "devalizat",
    "devalizați": "devalizat",
    "devaloriză": "devaloriza",
    "devalorizai": "devaloriza",
    "devalorizam": "devaloriza",
    "devalorizăm": "devaloriza",
    "devalorizând": "devaloriza",
    "devalorizându": "devaloriza",
    "devalorizară": "devaloriza",
    "devalorizarăm": "devaloriza",
    "devalorizarăți": "devaloriza",
    "devalorizase": "devaloriza",
    "devalorizasem": "devaloriza",
    "devalorizaseră": "devaloriza",
    "devalorizaserăm": "devaloriza",
    "devalorizaserăți": "devaloriza",
    "devalorizaseși": "devaloriza",
    "devalorizași": "devaloriza",
    "devalorizat": "devaloriza",
    "devalorizați": "devaloriza",
    "devalorizatu": "devaloriza",
    "devalorizau": "devaloriza",
    "devalorizează": "devaloriza",
    "devalorizez": "devaloriza",
    "devalorizeze": "devaloriza",
    "devalorizezi": "devaloriza",
    "nedevalorizând": "devaloriza",
    "nedevalorizându": "devaloriza",
    "nemaidevalorizând": "devaloriza",
    "nemaidevalorizându": "devaloriza",
    "devalorizarea": "devalorizare",
    "devalorizareo": "devalorizare",
    "devalorizări": "devalorizare",
    "devalorizării": "devalorizare",
    "devalorizările": "devalorizare",
    "devalorizărilor": "devalorizare",
    "devalorizata": "devalorizat",
    "devalorizată": "devalorizat",
    "devalorizate": "devalorizat",
    "devalorizatei": "devalorizat",
    "devalorizatele": "devalorizat",
    "devalorizatelor": "devalorizat",
    "devalorizați": "devalorizat",
    "devalorizații": "devalorizat",
    "devalorizaților": "devalorizat",
    "devalorizato": "devalorizat",
    "devalorizatul": "devalorizat",
    "devalorizatule": "devalorizat",
    "devalorizatului": "devalorizat",
    "devansă": "devansa",
    "devansai": "devansa",
    "devansam": "devansa",
    "devansăm": "devansa",
    "devansând": "devansa",
    "devansându": "devansa",
    "devansară": "devansa",
    "devansarăm": "devansa",
    "devansarăți": "devansa",
    "devansase": "devansa",
    "devansasem": "devansa",
    "devansaseră": "devansa",
    "devansaserăm": "devansa",
    "devansaserăți": "devansa",
    "devansaseși": "devansa",
    "devansași": "devansa",
    "devansat": "devansa",
    "devansați": "devansa",
    "devansatu": "devansa",
    "devansau": "devansa",
    "devansează": "devansa",
    "devansez": "devansa",
    "devanseze": "devansa",
    "devansezi": "devansa",
    "nedevansând": "devansa",
    "nedevansându": "devansa",
    "nemaidevansând": "devansa",
    "nemaidevansându": "devansa",
    "devansată": "devansat",
    "devansate": "devansat",
    "devansați": "devansat",
    "devastă": "devasta",
    "devastai": "devasta",
    "devastam": "devasta",
    "devastăm": "devasta",
    "devastând": "devasta",
    "devastându": "devasta",
    "devastară": "devasta",
    "devastarăm": "devasta",
    "devastarăți": "devasta",
    "devastase": "devasta",
    "devastasem": "devasta",
    "devastaseră": "devasta",
    "devastaserăm": "devasta",
    "devastaserăți": "devasta",
    "devastaseși": "devasta",
    "devastași": "devasta",
    "devastat": "devasta",
    "devastați": "devasta",
    "devastatu": "devasta",
    "devastau": "devasta",
    "devastează": "devasta",
    "devastez": "devasta",
    "devasteze": "devasta",
    "devastezi": "devasta",
    "nedevastând": "devasta",
    "nedevastându": "devasta",
    "nemaidevastând": "devasta",
    "nemaidevastându": "devasta",
    "devastarea": "devastare",
    "devastareo": "devastare",
    "devastări": "devastare",
    "devastării": "devastare",
    "devastările": "devastare",
    "devastărilor": "devastare",
    "devastata": "devastat",
    "devastată": "devastat",
    "devastate": "devastat",
    "devastatei": "devastat",
    "devastatele": "devastat",
    "devastatelor": "devastat",
    "devastați": "devastat",
    "devastații": "devastat",
    "devastaților": "devastat",
    "devastato": "devastat",
    "devastatul": "devastat",
    "devastatule": "devastat",
    "devastatului": "devastat",
    "devastatoare": "devastator",
    "devastatoarea": "devastator",
    "devastatoarei": "devastator",
    "devastatoarele": "devastator",
    "devastatoarelor": "devastator",
    "devastatoareo": "devastator",
    "devastatori": "devastator",
    "devastatorii": "devastator",
    "devastatorilor": "devastator",
    "devastatorul": "devastator",
    "devastatorule": "devastator",
    "devastatorului": "devastator",
    "developă": "developa",
    "developai": "developa",
    "developam": "developa",
    "developăm": "developa",
    "developând": "developa",
    "developându": "developa",
    "developară": "developa",
    "developarăm": "developa",
    "developarăți": "developa",
    "developase": "developa",
    "developasem": "developa",
    "developaseră": "developa",
    "developaserăm": "developa",
    "developaserăți": "developa",
    "developaseși": "developa",
    "developași": "developa",
    "developat": "developa",
    "developați": "developa",
    "developatu": "developa",
    "developau": "developa",
    "developează": "developa",
    "developez": "developa",
    "developeze": "developa",
    "developezi": "developa",
    "nedevelopând": "developa",
    "nedevelopându": "developa",
    "nemaidevelopând": "developa",
    "nemaidevelopându": "developa",
    "developarea": "developare",
    "developareo": "developare",
    "developări": "developare",
    "developării": "developare",
    "developările": "developare",
    "developărilor": "developare",
    "developata": "developat",
    "developată": "developat",
    "developate": "developat",
    "developatei": "developat",
    "developatele": "developat",
    "developatelor": "developat",
    "developați": "developat",
    "developații": "developat",
    "developaților": "developat",
    "developato": "developat",
    "developatul": "developat",
    "developatule": "developat",
    "developatului": "developat",
    "developatoare": "developator",
    "developatoarele": "developator",
    "developatoarelor": "developator",
    "developatorul": "developator",
    "developatorule": "developator",
    "developatorului": "developator",
    "devenea": "deveni",
    "deveneai": "deveni",
    "deveneam": "deveni",
    "deveneați": "deveni",
    "deveneau": "deveni",
    "devenii": "deveni",
    "devenim": "deveni",
    "devenind": "deveni",
    "devenindu": "deveni",
    "deveniră": "deveni",
    "devenirăm": "deveni",
    "devenirăți": "deveni",
    "devenise": "deveni",
    "devenisem": "deveni",
    "deveniseră": "deveni",
    "deveniserăm": "deveni",
    "deveniserăți": "deveni",
    "deveniseși": "deveni",
    "deveniși": "deveni",
    "devenit": "deveni",
    "deveniți": "deveni",
    "devenitu": "deveni",
    "devii": "deveni",
    "devin": "deveni",
    "devină": "deveni",
    "devine": "deveni",
    "devino": "deveni",
    "nedevenind": "deveni",
    "nedevenindu": "deveni",
    "nemaidevenind": "deveni",
    "nemaidevenindu": "deveni",
    "devenirea": "devenire",
    "devenireo": "devenire",
    "deveniri": "devenire",
    "devenirii": "devenire",
    "devenirile": "devenire",
    "devenirilor": "devenire",
    "devenită": "devenit",
    "devenite": "devenit",
    "deveniți": "devenit",
    "deverul": "dever",
    "deverule": "dever",
    "deverului": "dever",
    "deversă": "deversa",
    "deversai": "deversa",
    "deversam": "deversa",
    "deversăm": "deversa",
    "deversând": "deversa",
    "deversându": "deversa",
    "deversară": "deversa",
    "deversarăm": "deversa",
    "deversarăți": "deversa",
    "deversase": "deversa",
    "deversasem": "deversa",
    "deversaseră": "deversa",
    "deversaserăm": "deversa",
    "deversaserăți": "deversa",
    "deversaseși": "deversa",
    "deversași": "deversa",
    "deversat": "deversa",
    "deversați": "deversa",
    "deversatu": "deversa",
    "deversau": "deversa",
    "deversează": "deversa",
    "deversez": "deversa",
    "deverseze": "deversa",
    "deversezi": "deversa",
    "deversată": "deversat",
    "deversate": "deversat",
    "deversați": "deversat",
    "deversoare": "deversor",
    "deversoarele": "deversor",
    "deversoarelor": "deversor",
    "deversorul": "deversor",
    "deversorule": "deversor",
    "deversorului": "deversor",
    "deviai": "devia",
    "deviam": "devia",
    "deviară": "devia",
    "deviarăm": "devia",
    "deviarăți": "devia",
    "deviase": "devia",
    "deviasem": "devia",
    "deviaseră": "devia",
    "deviaserăm": "devia",
    "deviaserăți": "devia",
    "deviaseși": "devia",
    "deviași": "devia",
    "deviat": "devia",
    "deviați": "devia",
    "deviatu": "devia",
    "deviau": "devia",
    "deviază": "devia",
    "devie": "devia",
    "deviem": "devia",
    "deviez": "devia",
    "devieze": "devia",
    "deviezi": "devia",
    "deviind": "devia",
    "deviindu": "devia",
    "nedeviind": "devia",
    "nedeviindu": "devia",
    "nemaideviind": "devia",
    "nemaideviindu": "devia",
    "deviată": "deviat",
    "deviate": "deviat",
    "deviați": "deviat",
    "deviația": "deviație",
    "deviației": "deviație",
    "deviații": "deviație",
    "deviațiile": "deviație",
    "deviațiilor": "deviație",
    "deviaționista": "deviaționist",
    "deviaționistă": "deviaționist",
    "deviaționiste": "deviaționist",
    "deviaționistei": "deviaționist",
    "deviaționistele": "deviaționist",
    "deviaționistelor": "deviaționist",
    "deviaționiști": "deviaționist",
    "deviaționiștii": "deviaționist",
    "deviaționiștilor": "deviaționist",
    "deviaționisto": "deviaționist",
    "deviaționistul": "deviaționist",
    "deviaționistule": "deviaționist",
    "deviaționistului": "deviaționist",
    "deviaționista": "deviaționistă",
    "deviaționiste": "deviaționistă",
    "deviaționistei": "deviaționistă",
    "deviaționistele": "deviaționistă",
    "deviaționistelor": "deviaționistă",
    "deviaționisto": "deviaționistă",
    "deviatoarea": "deviatoare",
    "deviatoarei": "deviatoare",
    "deviatoarele": "deviatoare",
    "deviatoarelor": "deviatoare",
    "deviatoareo": "deviatoare",
    "deviatori": "deviator",
    "deviatorii": "deviator",
    "deviatorilor": "deviator",
    "deviatorul": "deviator",
    "deviatorule": "deviator",
    "deviatorului": "deviator",
    "devierea": "deviere",
    "deviereo": "deviere",
    "devieri": "deviere",
    "devierii": "deviere",
    "devierile": "deviere",
    "devierilor": "deviere",
    "devize": "deviz",
    "devizele": "deviz",
    "devizelor": "deviz",
    "devizul": "deviz",
    "devizule": "deviz",
    "devizului": "deviz",
    "deviza": "deviză",
    "devize": "deviză",
    "devizei": "deviză",
    "devizele": "deviză",
    "devizelor": "deviză",
    "devizo": "deviză",
    "devizele": "devize",
    "devizelor": "devize",
    "devoră": "devora",
    "devorai": "devora",
    "devoram": "devora",
    "devorăm": "devora",
    "devorând": "devora",
    "devorându": "devora",
    "devorară": "devora",
    "devorarăm": "devora",
    "devorarăți": "devora",
    "devorase": "devora",
    "devorasem": "devora",
    "devoraseră": "devora",
    "devoraserăm": "devora",
    "devoraserăți": "devora",
    "devoraseși": "devora",
    "devorași": "devora",
    "devorat": "devora",
    "devorați": "devora",
    "devoratu": "devora",
    "devorau": "devora",
    "devorează": "devora",
    "devorez": "devora",
    "devoreze": "devora",
    "devorezi": "devora",
    "nedevorând": "devora",
    "nedevorându": "devora",
    "nemaidevorând": "devora",
    "nemaidevorându": "devora",
    "devorată": "devorat",
    "devorate": "devorat",
    "devorați": "devorat",
    "devotă": "devota",
    "devotai": "devota",
    "devotam": "devota",
    "devotăm": "devota",
    "devotând": "devota",
    "devotându": "devota",
    "devotară": "devota",
    "devotarăm": "devota",
    "devotarăți": "devota",
    "devotase": "devota",
    "devotasem": "devota",
    "devotaseră": "devota",
    "devotaserăm": "devota",
    "devotaserăți": "devota",
    "devotaseși": "devota",
    "devotași": "devota",
    "devotat": "devota",
    "devotați": "devota",
    "devotatu": "devota",
    "devotau": "devota",
    "devotează": "devota",
    "devotez": "devota",
    "devoteze": "devota",
    "devotezi": "devota",
    "nedevotând": "devota",
    "nedevotându": "devota",
    "nemaidevotând": "devota",
    "nemaidevotându": "devota",
    "devotamente": "devotament",
    "devotamentele": "devotament",
    "devotamentelor": "devotament",
    "devotamentul": "devotament",
    "devotamentule": "devotament",
    "devotamentului": "devotament",
    "devotata": "devotat",
    "devotată": "devotat",
    "devotate": "devotat",
    "devotatei": "devotat",
    "devotatele": "devotat",
    "devotatelor": "devotat",
    "devotați": "devotat",
    "devotații": "devotat",
    "devotaților": "devotat",
    "devotato": "devotat",
    "devotatul": "devotat",
    "devotatule": "devotat",
    "devotatului": "devotat",
    "dexteritatea": "dexteritate",
    "dexteritateo": "dexteritate",
    "dexterități": "dexteritate",
    "dexterității": "dexteritate",
    "dexteritățile": "dexteritate",
    "dexterităților": "dexteritate",
    "dextrina": "dextrină",
    "dextrine": "dextrină",
    "dextrinei": "dextrină",
    "dextrinele": "dextrină",
    "dextrinelor": "dextrină",
    "dextrino": "dextrină",
    "dezacordul": "dezacord",
    "dezacordule": "dezacord",
    "dezacordului": "dezacord",
    "dezacorduri": "dezacord",
    "dezacordurile": "dezacord",
    "dezacordurilor": "dezacord",
    "dezacordă": "dezacorda",
    "dezacordai": "dezacorda",
    "dezacordam": "dezacorda",
    "dezacordăm": "dezacorda",
    "dezacordând": "dezacorda",
    "dezacordându": "dezacorda",
    "dezacordară": "dezacorda",
    "dezacordarăm": "dezacorda",
    "dezacordarăți": "dezacorda",
    "dezacordase": "dezacorda",
    "dezacordasem": "dezacorda",
    "dezacordaseră": "dezacorda",
    "dezacordaserăm": "dezacorda",
    "dezacordaserăți": "dezacorda",
    "dezacordaseși": "dezacorda",
    "dezacordași": "dezacorda",
    "dezacordat": "dezacorda",
    "dezacordați": "dezacorda",
    "dezacordatu": "dezacorda",
    "dezacordau": "dezacorda",
    "dezacordează": "dezacorda",
    "dezacordez": "dezacorda",
    "dezacordeze": "dezacorda",
    "dezacordezi": "dezacorda",
    "nedezacordând": "dezacorda",
    "nedezacordându": "dezacorda",
    "nemaidezacordând": "dezacorda",
    "nemaidezacordându": "dezacorda",
    "dezacordarea": "dezacordare",
    "dezacordareo": "dezacordare",
    "dezacordări": "dezacordare",
    "dezacordării": "dezacordare",
    "dezacordările": "dezacordare",
    "dezacordărilor": "dezacordare",
    "dezacordata": "dezacordat",
    "dezacordată": "dezacordat",
    "dezacordate": "dezacordat",
    "dezacordatei": "dezacordat",
    "dezacordatele": "dezacordat",
    "dezacordatelor": "dezacordat",
    "dezacordați": "dezacordat",
    "dezacordații": "dezacordat",
    "dezacordaților": "dezacordat",
    "dezacordato": "dezacordat",
    "dezacordatul": "dezacordat",
    "dezacordatule": "dezacordat",
    "dezacordatului": "dezacordat",
    "dezactivarea": "dezactivare",
    "dezactivareo": "dezactivare",
    "dezactivări": "dezactivare",
    "dezactivării": "dezactivare",
    "dezactivările": "dezactivare",
    "dezactivărilor": "dezactivare",
    "dezafectă": "dezafecta",
    "dezafectai": "dezafecta",
    "dezafectam": "dezafecta",
    "dezafectăm": "dezafecta",
    "dezafectând": "dezafecta",
    "dezafectându": "dezafecta",
    "dezafectară": "dezafecta",
    "dezafectarăm": "dezafecta",
    "dezafectarăți": "dezafecta",
    "dezafectase": "dezafecta",
    "dezafectasem": "dezafecta",
    "dezafectaseră": "dezafecta",
    "dezafectaserăm": "dezafecta",
    "dezafectaserăți": "dezafecta",
    "dezafectaseși": "dezafecta",
    "dezafectași": "dezafecta",
    "dezafectat": "dezafecta",
    "dezafectați": "dezafecta",
    "dezafectatu": "dezafecta",
    "dezafectau": "dezafecta",
    "dezafectează": "dezafecta",
    "dezafectez": "dezafecta",
    "dezafecteze": "dezafecta",
    "dezafectezi": "dezafecta",
    "dezafectata": "dezafectat",
    "dezafectată": "dezafectat",
    "dezafectate": "dezafectat",
    "dezafectatei": "dezafectat",
    "dezafectatele": "dezafectat",
    "dezafectatelor": "dezafectat",
    "dezafectați": "dezafectat",
    "dezafectații": "dezafectat",
    "dezafectaților": "dezafectat",
    "dezafectato": "dezafectat",
    "dezafectatul": "dezafectat",
    "dezafectatule": "dezafectat",
    "dezafectatului": "dezafectat",
    "dezagreabila": "dezagreabil",
    "dezagreabilă": "dezagreabil",
    "dezagreabile": "dezagreabil",
    "dezagreabilei": "dezagreabil",
    "dezagreabilele": "dezagreabil",
    "dezagreabilelor": "dezagreabil",
    "dezagreabili": "dezagreabil",
    "dezagreabilii": "dezagreabil",
    "dezagreabililor": "dezagreabil",
    "dezagreabilo": "dezagreabil",
    "dezagreabilul": "dezagreabil",
    "dezagreabilule": "dezagreabil",
    "dezagreabilului": "dezagreabil",
    "dezagreg": "dezagrega",
    "dezagregă": "dezagrega",
    "dezagregai": "dezagrega",
    "dezagregam": "dezagrega",
    "dezagregăm": "dezagrega",
    "dezagregând": "dezagrega",
    "dezagregându": "dezagrega",
    "dezagregară": "dezagrega",
    "dezagregarăm": "dezagrega",
    "dezagregarăți": "dezagrega",
    "dezagregase": "dezagrega",
    "dezagregasem": "dezagrega",
    "dezagregaseră": "dezagrega",
    "dezagregaserăm": "dezagrega",
    "dezagregaserăți": "dezagrega",
    "dezagregaseși": "dezagrega",
    "dezagregași": "dezagrega",
    "dezagregat": "dezagrega",
    "dezagregați": "dezagrega",
    "dezagregatu": "dezagrega",
    "dezagregau": "dezagrega",
    "dezagrege": "dezagrega",
    "dezagregi": "dezagrega",
    "nedezagregând": "dezagrega",
    "nedezagregându": "dezagrega",
    "nemaidezagregând": "dezagrega",
    "nemaidezagregându": "dezagrega",
    "dezagregarea": "dezagregare",
    "dezagregareo": "dezagregare",
    "dezagregări": "dezagregare",
    "dezagregării": "dezagregare",
    "dezagregările": "dezagregare",
    "dezagregărilor": "dezagregare",
    "dezagregata": "dezagregat",
    "dezagregată": "dezagregat",
    "dezagregate": "dezagregat",
    "dezagregatei": "dezagregat",
    "dezagregatele": "dezagregat",
    "dezagregatelor": "dezagregat",
    "dezagregați": "dezagregat",
    "dezagregații": "dezagregat",
    "dezagregaților": "dezagregat",
    "dezagregato": "dezagregat",
    "dezagregatul": "dezagregat",
    "dezagregatule": "dezagregat",
    "dezagregatului": "dezagregat",
    "dezamăgea": "dezamăgi",
    "dezamăgeai": "dezamăgi",
    "dezamăgeam": "dezamăgi",
    "dezamăgească": "dezamăgi",
    "dezamăgeați": "dezamăgi",
    "dezamăgeau": "dezamăgi",
    "dezamăgesc": "dezamăgi",
    "dezamăgește": "dezamăgi",
    "dezamăgești": "dezamăgi",
    "dezamăgii": "dezamăgi",
    "dezamăgim": "dezamăgi",
    "dezamăgind": "dezamăgi",
    "dezamăgindu": "dezamăgi",
    "dezamăgiră": "dezamăgi",
    "dezamăgirăm": "dezamăgi",
    "dezamăgirăți": "dezamăgi",
    "dezamăgise": "dezamăgi",
    "dezamăgisem": "dezamăgi",
    "dezamăgiseră": "dezamăgi",
    "dezamăgiserăm": "dezamăgi",
    "dezamăgiserăți": "dezamăgi",
    "dezamăgiseși": "dezamăgi",
    "dezamăgiși": "dezamăgi",
    "dezamăgit": "dezamăgi",
    "dezamăgiți": "dezamăgi",
    "dezamăgitu": "dezamăgi",
    "nedezamăgind": "dezamăgi",
    "nedezamăgindu": "dezamăgi",
    "nemaidezamăgind": "dezamăgi",
    "nemaidezamăgindu": "dezamăgi",
    "dezamăgirea": "dezamăgire",
    "dezamăgireo": "dezamăgire",
    "dezamăgiri": "dezamăgire",
    "dezamăgirii": "dezamăgire",
    "dezamăgirile": "dezamăgire",
    "dezamăgirilor": "dezamăgire",
    "dezamăgită": "dezamăgit",
    "dezamăgite": "dezamăgit",
    "dezamăgiți": "dezamăgit",
    "dezambală": "dezambala",
    "dezambalai": "dezambala",
    "dezambalam": "dezambala",
    "dezambalăm": "dezambala",
    "dezambalând": "dezambala",
    "dezambalându": "dezambala",
    "dezambalară": "dezambala",
    "dezambalarăm": "dezambala",
    "dezambalarăți": "dezambala",
    "dezambalase": "dezambala",
    "dezambalasem": "dezambala",
    "dezambalaseră": "dezambala",
    "dezambalaserăm": "dezambala",
    "dezambalaserăți": "dezambala",
    "dezambalaseși": "dezambala",
    "dezambalași": "dezambala",
    "dezambalat": "dezambala",
    "dezambalați": "dezambala",
    "dezambalatu": "dezambala",
    "dezambalau": "dezambala",
    "dezambalează": "dezambala",
    "dezambalez": "dezambala",
    "dezambaleze": "dezambala",
    "dezambalezi": "dezambala",
    "dezambalarea": "dezambalare",
    "dezambalareo": "dezambalare",
    "dezambalări": "dezambalare",
    "dezambalării": "dezambalare",
    "dezambalările": "dezambalare",
    "dezambalărilor": "dezambalare",
    "dezambalata": "dezambalat",
    "dezambalată": "dezambalat",
    "dezambalate": "dezambalat",
    "dezambalatei": "dezambalat",
    "dezambalatele": "dezambalat",
    "dezambalatelor": "dezambalat",
    "dezambalați": "dezambalat",
    "dezambalații": "dezambalat",
    "dezambalaților": "dezambalat",
    "dezambalato": "dezambalat",
    "dezambalatul": "dezambalat",
    "dezambalatule": "dezambalat",
    "dezambalatului": "dezambalat",
    "dezaprob": "dezaproba",
    "dezaprobă": "dezaproba",
    "dezaprobai": "dezaproba",
    "dezaprobam": "dezaproba",
    "dezaprobăm": "dezaproba",
    "dezaprobând": "dezaproba",
    "dezaprobându": "dezaproba",
    "dezaprobară": "dezaproba",
    "dezaprobarăm": "dezaproba",
    "dezaprobarăți": "dezaproba",
    "dezaprobase": "dezaproba",
    "dezaprobasem": "dezaproba",
    "dezaprobaseră": "dezaproba",
    "dezaprobaserăm": "dezaproba",
    "dezaprobaserăți": "dezaproba",
    "dezaprobaseși": "dezaproba",
    "dezaprobași": "dezaproba",
    "dezaprobat": "dezaproba",
    "dezaprobați": "dezaproba",
    "dezaprobatu": "dezaproba",
    "dezaprobau": "dezaproba",
    "dezaprobe": "dezaproba",
    "dezaprobi": "dezaproba",
    "nedezaprobând": "dezaproba",
    "nedezaprobându": "dezaproba",
    "nemaidezaprobând": "dezaproba",
    "nemaidezaprobându": "dezaproba",
    "dezaprobarea": "dezaprobare",
    "dezaprobareo": "dezaprobare",
    "dezaprobări": "dezaprobare",
    "dezaprobării": "dezaprobare",
    "dezaprobările": "dezaprobare",
    "dezaprobărilor": "dezaprobare",
    "dezaprobată": "dezaprobat",
    "dezaprobate": "dezaprobat",
    "dezaprobați": "dezaprobat",
    "dezarmă": "dezarma",
    "dezarmai": "dezarma",
    "dezarmam": "dezarma",
    "dezarmăm": "dezarma",
    "dezarmând": "dezarma",
    "dezarmându": "dezarma",
    "dezarmară": "dezarma",
    "dezarmarăm": "dezarma",
    "dezarmarăți": "dezarma",
    "dezarmase": "dezarma",
    "dezarmasem": "dezarma",
    "dezarmaseră": "dezarma",
    "dezarmaserăm": "dezarma",
    "dezarmaserăți": "dezarma",
    "dezarmaseși": "dezarma",
    "dezarmași": "dezarma",
    "dezarmat": "dezarma",
    "dezarmați": "dezarma",
    "dezarmatu": "dezarma",
    "dezarmau": "dezarma",
    "dezarmează": "dezarma",
    "dezarmez": "dezarma",
    "dezarmeze": "dezarma",
    "dezarmezi": "dezarma",
    "nedezarmând": "dezarma",
    "nedezarmându": "dezarma",
    "nemaidezarmând": "dezarma",
    "nemaidezarmându": "dezarma",
    "dezarmanta": "dezarmant",
    "dezarmantă": "dezarmant",
    "dezarmante": "dezarmant",
    "dezarmantei": "dezarmant",
    "dezarmantele": "dezarmant",
    "dezarmantelor": "dezarmant",
    "dezarmanți": "dezarmant",
    "dezarmanții": "dezarmant",
    "dezarmanților": "dezarmant",
    "dezarmanto": "dezarmant",
    "dezarmantul": "dezarmant",
    "dezarmantule": "dezarmant",
    "dezarmantului": "dezarmant",
    "dezarmarea": "dezarmare",
    "dezarmareo": "dezarmare",
    "dezarmări": "dezarmare",
    "dezarmării": "dezarmare",
    "dezarmările": "dezarmare",
    "dezarmărilor": "dezarmare",
    "dezarmata": "dezarmat",
    "dezarmată": "dezarmat",
    "dezarmate": "dezarmat",
    "dezarmatei": "dezarmat",
    "dezarmatele": "dezarmat",
    "dezarmatelor": "dezarmat",
    "dezarmați": "dezarmat",
    "dezarmații": "dezarmat",
    "dezarmaților": "dezarmat",
    "dezarmato": "dezarmat",
    "dezarmatul": "dezarmat",
    "dezarmatule": "dezarmat",
    "dezarmatului": "dezarmat",
    "dezarticulă": "dezarticula",
    "dezarticulai": "dezarticula",
    "dezarticulam": "dezarticula",
    "dezarticulăm": "dezarticula",
    "dezarticulând": "dezarticula",
    "dezarticulându": "dezarticula",
    "dezarticulară": "dezarticula",
    "dezarticularăm": "dezarticula",
    "dezarticularăți": "dezarticula",
    "dezarticulase": "dezarticula",
    "dezarticulasem": "dezarticula",
    "dezarticulaseră": "dezarticula",
    "dezarticulaserăm": "dezarticula",
    "dezarticulaserăți": "dezarticula",
    "dezarticulaseși": "dezarticula",
    "dezarticulași": "dezarticula",
    "dezarticulat": "dezarticula",
    "dezarticulați": "dezarticula",
    "dezarticulatu": "dezarticula",
    "dezarticulau": "dezarticula",
    "dezarticulează": "dezarticula",
    "dezarticulez": "dezarticula",
    "dezarticuleze": "dezarticula",
    "dezarticulezi": "dezarticula",
    "nedezarticulând": "dezarticula",
    "nedezarticulându": "dezarticula",
    "nemaidezarticulând": "dezarticula",
    "nemaidezarticulându": "dezarticula",
    "dezarticularea": "dezarticulare",
    "dezarticulareo": "dezarticulare",
    "dezarticulări": "dezarticulare",
    "dezarticulării": "dezarticulare",
    "dezarticulările": "dezarticulare",
    "dezarticulărilor": "dezarticulare",
    "dezarticulata": "dezarticulat",
    "dezarticulată": "dezarticulat",
    "dezarticulate": "dezarticulat",
    "dezarticulatei": "dezarticulat",
    "dezarticulatele": "dezarticulat",
    "dezarticulatelor": "dezarticulat",
    "dezarticulați": "dezarticulat",
    "dezarticulații": "dezarticulat",
    "dezarticulaților": "dezarticulat",
    "dezarticulato": "dezarticulat",
    "dezarticulatul": "dezarticulat",
    "dezarticulatule": "dezarticulat",
    "dezarticulatului": "dezarticulat",
    "dezarticulația": "dezarticulație",
    "dezarticulației": "dezarticulație",
    "dezarticulații": "dezarticulație",
    "dezarticulațiile": "dezarticulație",
    "dezarticulațiilor": "dezarticulație",
    "dezarticulațio": "dezarticulație",
    "dezasimilația": "dezasimilație",
    "dezasimilației": "dezasimilație",
    "dezasimilații": "dezasimilație",
    "dezasimilațiile": "dezasimilație",
    "dezasimilațiilor": "dezasimilație",
    "dezasimilațio": "dezasimilație",
    "dezastre": "dezastru",
    "dezastrele": "dezastru",
    "dezastrelor": "dezastru",
    "dezastrul": "dezastru",
    "dezastrule": "dezastru",
    "dezastrului": "dezastru",
    "dezastruoasa": "dezastruos",
    "dezastruoasă": "dezastruos",
    "dezastruoase": "dezastruos",
    "dezastruoasei": "dezastruos",
    "dezastruoasele": "dezastruos",
    "dezastruoaselor": "dezastruos",
    "dezastruoaso": "dezastruos",
    "dezastruoși": "dezastruos",
    "dezastruoșii": "dezastruos",
    "dezastruoșilor": "dezastruos",
    "dezastruosul": "dezastruos",
    "dezastruosule": "dezastruos",
    "dezastruosului": "dezastruos",
    "dezavantaje": "dezavantaj",
    "dezavantajele": "dezavantaj",
    "dezavantajelor": "dezavantaj",
    "dezavantajul": "dezavantaj",
    "dezavantajule": "dezavantaj",
    "dezavantajului": "dezavantaj",
    "dezavantajă": "dezavantaja",
    "dezavantajai": "dezavantaja",
    "dezavantajam": "dezavantaja",
    "dezavantajăm": "dezavantaja",
    "dezavantajând": "dezavantaja",
    "dezavantajându": "dezavantaja",
    "dezavantajară": "dezavantaja",
    "dezavantajarăm": "dezavantaja",
    "dezavantajarăți": "dezavantaja",
    "dezavantajase": "dezavantaja",
    "dezavantajasem": "dezavantaja",
    "dezavantajaseră": "dezavantaja",
    "dezavantajaserăm": "dezavantaja",
    "dezavantajaserăți": "dezavantaja",
    "dezavantajaseși": "dezavantaja",
    "dezavantajași": "dezavantaja",
    "dezavantajat": "dezavantaja",
    "dezavantajați": "dezavantaja",
    "dezavantajatu": "dezavantaja",
    "dezavantajau": "dezavantaja",
    "dezavantajează": "dezavantaja",
    "dezavantajez": "dezavantaja",
    "dezavantajeze": "dezavantaja",
    "dezavantajezi": "dezavantaja",
    "nedezavantajând": "dezavantaja",
    "nedezavantajându": "dezavantaja",
    "nemaidezavantajând": "dezavantaja",
    "nemaidezavantajându": "dezavantaja",
    "dezavantajată": "dezavantajat",
    "dezavantajate": "dezavantajat",
    "dezavantajați": "dezavantajat",
    "dezavuă": "dezavua",
    "dezavuai": "dezavua",
    "dezavuam": "dezavua",
    "dezavuăm": "dezavua",
    "dezavuând": "dezavua",
    "dezavuându": "dezavua",
    "dezavuară": "dezavua",
    "dezavuarăm": "dezavua",
    "dezavuarăți": "dezavua",
    "dezavuase": "dezavua",
    "dezavuasem": "dezavua",
    "dezavuaseră": "dezavua",
    "dezavuaserăm": "dezavua",
    "dezavuaserăți": "dezavua",
    "dezavuaseși": "dezavua",
    "dezavuași": "dezavua",
    "dezavuat": "dezavua",
    "dezavuați": "dezavua",
    "dezavuatu": "dezavua",
    "dezavuau": "dezavua",
    "dezavuează": "dezavua",
    "dezavuez": "dezavua",
    "dezavueze": "dezavua",
    "dezavuezi": "dezavua",
    "nedezavuând": "dezavua",
    "nedezavuându": "dezavua",
    "nemaidezavuând": "dezavua",
    "nemaidezavuându": "dezavua",
    "dezavuarea": "dezavuare",
    "dezavuareo": "dezavuare",
    "dezavuări": "dezavuare",
    "dezavuării": "dezavuare",
    "dezavuările": "dezavuare",
    "dezavuărilor": "dezavuare",
    "dezavuată": "dezavuat",
    "dezavuate": "dezavuat",
    "dezavuați": "dezavuat",
    "dezaxă": "dezaxa",
    "dezaxai": "dezaxa",
    "dezaxam": "dezaxa",
    "dezaxăm": "dezaxa",
    "dezaxând": "dezaxa",
    "dezaxându": "dezaxa",
    "dezaxară": "dezaxa",
    "dezaxarăm": "dezaxa",
    "dezaxarăți": "dezaxa",
    "dezaxase": "dezaxa",
    "dezaxasem": "dezaxa",
    "dezaxaseră": "dezaxa",
    "dezaxaserăm": "dezaxa",
    "dezaxaserăți": "dezaxa",
    "dezaxaseși": "dezaxa",
    "dezaxași": "dezaxa",
    "dezaxat": "dezaxa",
    "dezaxați": "dezaxa",
    "dezaxatu": "dezaxa",
    "dezaxau": "dezaxa",
    "dezaxează": "dezaxa",
    "dezaxez": "dezaxa",
    "dezaxeze": "dezaxa",
    "dezaxezi": "dezaxa",
    "nedezaxând": "dezaxa",
    "nedezaxându": "dezaxa",
    "nemaidezaxând": "dezaxa",
    "nemaidezaxându": "dezaxa",
    "dezaxarea": "dezaxare",
    "dezaxareo": "dezaxare",
    "dezaxări": "dezaxare",
    "dezaxării": "dezaxare",
    "dezaxările": "dezaxare",
    "dezaxărilor": "dezaxare",
    "dezaxata": "dezaxat",
    "dezaxată": "dezaxat",
    "dezaxate": "dezaxat",
    "dezaxatei": "dezaxat",
    "dezaxatele": "dezaxat",
    "dezaxatelor": "dezaxat",
    "dezaxați": "dezaxat",
    "dezaxații": "dezaxat",
    "dezaxaților": "dezaxat",
    "dezaxato": "dezaxat",
    "dezaxatul": "dezaxat",
    "dezaxatule": "dezaxat",
    "dezaxatului": "dezaxat",
    "dezbar": "dezbăra",
    "dezbară": "dezbăra",
    "dezbără": "dezbăra",
    "dezbărai": "dezbăra",
    "dezbăram": "dezbăra",
    "dezbărăm": "dezbăra",
    "dezbărând": "dezbăra",
    "dezbărându": "dezbăra",
    "dezbărară": "dezbăra",
    "dezbărarăm": "dezbăra",
    "dezbărarăți": "dezbăra",
    "dezbărase": "dezbăra",
    "dezbărasem": "dezbăra",
    "dezbăraseră": "dezbăra",
    "dezbăraserăm": "dezbăra",
    "dezbăraserăți": "dezbăra",
    "dezbăraseși": "dezbăra",
    "dezbărași": "dezbăra",
    "dezbărat": "dezbăra",
    "dezbărați": "dezbăra",
    "dezbăratu": "dezbăra",
    "dezbărau": "dezbăra",
    "dezbare": "dezbăra",
    "dezbari": "dezbăra",
    "nedezbărând": "dezbăra",
    "nedezbărându": "dezbăra",
    "nemaidezbărând": "dezbăra",
    "nemaidezbărându": "dezbăra",
    "dezbărarea": "dezbărare",
    "dezbărareo": "dezbărare",
    "dezbărări": "dezbărare",
    "dezbărării": "dezbărare",
    "dezbărările": "dezbărare",
    "dezbărărilor": "dezbărare",
    "dezbărată": "dezbărat",
    "dezbărate": "dezbărat",
    "dezbărați": "dezbărat",
    "dezbat": "dezbate",
    "dezbată": "dezbate",
    "dezbătând": "dezbate",
    "dezbătându": "dezbate",
    "dezbătea": "dezbate",
    "dezbăteai": "dezbate",
    "dezbăteam": "dezbate",
    "dezbăteați": "dezbate",
    "dezbăteau": "dezbate",
    "dezbatem": "dezbate",
    "dezbateți": "dezbate",
    "dezbați": "dezbate",
    "dezbătu": "dezbate",
    "dezbătui": "dezbate",
    "dezbătură": "dezbate",
    "dezbăturăm": "dezbate",
    "dezbăturăți": "dezbate",
    "dezbătuse": "dezbate",
    "dezbătusem": "dezbate",
    "dezbătuseră": "dezbate",
    "dezbătuserăm": "dezbate",
    "dezbătuserăți": "dezbate",
    "dezbătuseși": "dezbate",
    "dezbătuși": "dezbate",
    "dezbătut": "dezbate",
    "dezbătutu": "dezbate",
    "nedezbătând": "dezbate",
    "nedezbătându": "dezbate",
    "nemaidezbătând": "dezbate",
    "nemaidezbătându": "dezbate",
    "dezbaterea": "dezbatere",
    "dezbatereo": "dezbatere",
    "dezbateri": "dezbatere",
    "dezbaterii": "dezbatere",
    "dezbaterile": "dezbatere",
    "dezbaterilor": "dezbatere",
    "dezbătută": "dezbătut",
    "dezbătute": "dezbătut",
    "dezbătuți": "dezbătut",
    "dezbin": "dezbina",
    "dezbină": "dezbina",
    "dezbinai": "dezbina",
    "dezbinam": "dezbina",
    "dezbinăm": "dezbina",
    "dezbinând": "dezbina",
    "dezbinându": "dezbina",
    "dezbinară": "dezbina",
    "dezbinarăm": "dezbina",
    "dezbinarăți": "dezbina",
    "dezbinase": "dezbina",
    "dezbinasem": "dezbina",
    "dezbinaseră": "dezbina",
    "dezbinaserăm": "dezbina",
    "dezbinaserăți": "dezbina",
    "dezbinaseși": "dezbina",
    "dezbinași": "dezbina",
    "dezbinat": "dezbina",
    "dezbinați": "dezbina",
    "dezbinatu": "dezbina",
    "dezbinau": "dezbina",
    "dezbine": "dezbina",
    "dezbini": "dezbina",
    "nedezbinând": "dezbina",
    "nedezbinându": "dezbina",
    "nemaidezbinând": "dezbina",
    "nemaidezbinându": "dezbina",
    "dezbinarea": "dezbinare",
    "dezbinareo": "dezbinare",
    "dezbinări": "dezbinare",
    "dezbinării": "dezbinare",
    "dezbinările": "dezbinare",
    "dezbinărilor": "dezbinare",
    "dezbinata": "dezbinat",
    "dezbinată": "dezbinat",
    "dezbinate": "dezbinat",
    "dezbinatei": "dezbinat",
    "dezbinatele": "dezbinat",
    "dezbinatelor": "dezbinat",
    "dezbinați": "dezbinat",
    "dezbinații": "dezbinat",
    "dezbinaților": "dezbinat",
    "dezbinato": "dezbinat",
    "dezbinatul": "dezbinat",
    "dezbinatule": "dezbinat",
    "dezbinatului": "dezbinat",
    "dezbrac": "dezbrăca",
    "dezbracă": "dezbrăca",
    "dezbrăcă": "dezbrăca",
    "dezbrăcai": "dezbrăca",
    "dezbrăcam": "dezbrăca",
    "dezbrăcăm": "dezbrăca",
    "dezbrăcând": "dezbrăca",
    "dezbrăcându": "dezbrăca",
    "dezbrăcară": "dezbrăca",
    "dezbrăcarăm": "dezbrăca",
    "dezbrăcarăți": "dezbrăca",
    "dezbrăcase": "dezbrăca",
    "dezbrăcasem": "dezbrăca",
    "dezbrăcaseră": "dezbrăca",
    "dezbrăcaserăm": "dezbrăca",
    "dezbrăcaserăți": "dezbrăca",
    "dezbrăcaseși": "dezbrăca",
    "dezbrăcași": "dezbrăca",
    "dezbrăcat": "dezbrăca",
    "dezbrăcați": "dezbrăca",
    "dezbrăcatu": "dezbrăca",
    "dezbrăcau": "dezbrăca",
    "dezbrace": "dezbrăca",
    "dezbraci": "dezbrăca",
    "nedezbrăcând": "dezbrăca",
    "nedezbrăcându": "dezbrăca",
    "nemaidezbrăcând": "dezbrăca",
    "nemaidezbrăcându": "dezbrăca",
    "dezbrăcarea": "dezbrăcare",
    "dezbrăcareo": "dezbrăcare",
    "dezbrăcări": "dezbrăcare",
    "dezbrăcării": "dezbrăcare",
    "dezbrăcările": "dezbrăcare",
    "dezbrăcărilor": "dezbrăcare",
    "dezbrăcata": "dezbrăcat",
    "dezbrăcată": "dezbrăcat",
    "dezbrăcate": "dezbrăcat",
    "dezbrăcatei": "dezbrăcat",
    "dezbrăcatele": "dezbrăcat",
    "dezbrăcatelor": "dezbrăcat",
    "dezbrăcați": "dezbrăcat",
    "dezbrăcații": "dezbrăcat",
    "dezbrăcaților": "dezbrăcat",
    "dezbrăcato": "dezbrăcat",
    "dezbrăcatul": "dezbrăcat",
    "dezbrăcatule": "dezbrăcat",
    "dezbrăcatului": "dezbrăcat",
    "dezbrobodea": "dezbrobodi",
    "dezbrobodeai": "dezbrobodi",
    "dezbrobodeam": "dezbrobodi",
    "dezbrobodească": "dezbrobodi",
    "dezbrobodeați": "dezbrobodi",
    "dezbrobodeau": "dezbrobodi",
    "dezbrobodesc": "dezbrobodi",
    "dezbrobodește": "dezbrobodi",
    "dezbrobodești": "dezbrobodi",
    "dezbrobodii": "dezbrobodi",
    "dezbrobodim": "dezbrobodi",
    "dezbrobodind": "dezbrobodi",
    "dezbrobodindu": "dezbrobodi",
    "dezbrobodiră": "dezbrobodi",
    "dezbrobodirăm": "dezbrobodi",
    "dezbrobodirăți": "dezbrobodi",
    "dezbrobodise": "dezbrobodi",
    "dezbrobodisem": "dezbrobodi",
    "dezbrobodiseră": "dezbrobodi",
    "dezbrobodiserăm": "dezbrobodi",
    "dezbrobodiserăți": "dezbrobodi",
    "dezbrobodiseși": "dezbrobodi",
    "dezbrobodiși": "dezbrobodi",
    "dezbrobodit": "dezbrobodi",
    "dezbrobodiți": "dezbrobodi",
    "dezbroboditu": "dezbrobodi",
    "nedezbrobodind": "dezbrobodi",
    "nedezbrobodindu": "dezbrobodi",
    "nemaidezbrobodind": "dezbrobodi",
    "nemaidezbrobodindu": "dezbrobodi",
    "dezbrobodirea": "dezbrobodire",
    "dezbrobodireo": "dezbrobodire",
    "dezbrobodiri": "dezbrobodire",
    "dezbrobodirii": "dezbrobodire",
    "dezbrobodirile": "dezbrobodire",
    "dezbrobodirilor": "dezbrobodire",
    "dezbrobodita": "dezbrobodit",
    "dezbrobodită": "dezbrobodit",
    "dezbrobodite": "dezbrobodit",
    "dezbroboditei": "dezbrobodit",
    "dezbroboditele": "dezbrobodit",
    "dezbroboditelor": "dezbrobodit",
    "dezbrobodiți": "dezbrobodit",
    "dezbrobodiții": "dezbrobodit",
    "dezbrobodiților": "dezbrobodit",
    "dezbrobodito": "dezbrobodit",
    "dezbroboditul": "dezbrobodit",
    "dezbroboditule": "dezbrobodit",
    "dezbroboditului": "dezbrobodit",
    "dezbumb": "dezbumba",
    "dezbumbă": "dezbumba",
    "dezbumbai": "dezbumba",
    "dezbumbam": "dezbumba",
    "dezbumbăm": "dezbumba",
    "dezbumbând": "dezbumba",
    "dezbumbându": "dezbumba",
    "dezbumbară": "dezbumba",
    "dezbumbarăm": "dezbumba",
    "dezbumbarăți": "dezbumba",
    "dezbumbase": "dezbumba",
    "dezbumbasem": "dezbumba",
    "dezbumbaseră": "dezbumba",
    "dezbumbaserăm": "dezbumba",
    "dezbumbaserăți": "dezbumba",
    "dezbumbaseși": "dezbumba",
    "dezbumbași": "dezbumba",
    "dezbumbat": "dezbumba",
    "dezbumbați": "dezbumba",
    "dezbumbatu": "dezbumba",
    "dezbumbau": "dezbumba",
    "dezbumbe": "dezbumba",
    "dezbumbi": "dezbumba",
    "dezbumbarea": "dezbumbare",
    "dezbumbări": "dezbumbare",
    "dezbumbării": "dezbumbare",
    "dezbumbările": "dezbumbare",
    "dezbumbărilor": "dezbumbare",
    "dezbumbată": "dezbumbat",
    "dezbumbate": "dezbumbat",
    "dezbumbați": "dezbumbat",
    "dezdoaie": "dezdoi",
    "dezdoia": "dezdoi",
    "dezdoiai": "dezdoi",
    "dezdoiam": "dezdoi",
    "dezdoiați": "dezdoi",
    "dezdoiau": "dezdoi",
    "dezdoii": "dezdoi",
    "dezdoim": "dezdoi",
    "dezdoind": "dezdoi",
    "dezdoindu": "dezdoi",
    "dezdoiră": "dezdoi",
    "dezdoirăm": "dezdoi",
    "dezdoirăți": "dezdoi",
    "dezdoise": "dezdoi",
    "dezdoisem": "dezdoi",
    "dezdoiseră": "dezdoi",
    "dezdoiserăm": "dezdoi",
    "dezdoiserăți": "dezdoi",
    "dezdoiseși": "dezdoi",
    "dezdoiși": "dezdoi",
    "dezdoit": "dezdoi",
    "dezdoiți": "dezdoi",
    "dezdoitu": "dezdoi",
    "nedezdoind": "dezdoi",
    "nedezdoindu": "dezdoi",
    "nemaidezdoind": "dezdoi",
    "nemaidezdoindu": "dezdoi",
    "dezdoirea": "dezdoire",
    "dezdoireo": "dezdoire",
    "dezdoiri": "dezdoire",
    "dezdoirii": "dezdoire",
    "dezdoirile": "dezdoire",
    "dezdoirilor": "dezdoire",
    "dezdoită": "dezdoit",
    "dezdoite": "dezdoit",
    "dezdoiți": "dezdoit",
    "dezechilibră": "dezechilibra",
    "dezechilibrai": "dezechilibra",
    "dezechilibram": "dezechilibra",
    "dezechilibrăm": "dezechilibra",
    "dezechilibrând": "dezechilibra",
    "dezechilibrându": "dezechilibra",
    "dezechilibrară": "dezechilibra",
    "dezechilibrarăm": "dezechilibra",
    "dezechilibrarăți": "dezechilibra",
    "dezechilibrase": "dezechilibra",
    "dezechilibrasem": "dezechilibra",
    "dezechilibraseră": "dezechilibra",
    "dezechilibraserăm": "dezechilibra",
    "dezechilibraserăți": "dezechilibra",
    "dezechilibraseși": "dezechilibra",
    "dezechilibrași": "dezechilibra",
    "dezechilibrat": "dezechilibra",
    "dezechilibrați": "dezechilibra",
    "dezechilibratu": "dezechilibra",
    "dezechilibrau": "dezechilibra",
    "dezechilibrează": "dezechilibra",
    "dezechilibrez": "dezechilibra",
    "dezechilibreze": "dezechilibra",
    "dezechilibrezi": "dezechilibra",
    "nedezechilibrând": "dezechilibra",
    "nedezechilibrându": "dezechilibra",
    "nemaidezechilibrând": "dezechilibra",
    "nemaidezechilibrându": "dezechilibra",
    "dezechilibrarea": "dezechilibrare",
    "dezechilibrareo": "dezechilibrare",
    "dezechilibrări": "dezechilibrare",
    "dezechilibrării": "dezechilibrare",
    "dezechilibrările": "dezechilibrare",
    "dezechilibrărilor": "dezechilibrare",
    "dezechilibrata": "dezechilibrat",
    "dezechilibrată": "dezechilibrat",
    "dezechilibrate": "dezechilibrat",
    "dezechilibratei": "dezechilibrat",
    "dezechilibratele": "dezechilibrat",
    "dezechilibratelor": "dezechilibrat",
    "dezechilibrați": "dezechilibrat",
    "dezechilibrații": "dezechilibrat",
    "dezechilibraților": "dezechilibrat",
    "dezechilibrato": "dezechilibrat",
    "dezechilibratul": "dezechilibrat",
    "dezechilibratule": "dezechilibrat",
    "dezechilibratului": "dezechilibrat",
    "dezechilibre": "dezechilibru",
    "dezechilibrele": "dezechilibru",
    "dezechilibrelor": "dezechilibru",
    "dezechilibrul": "dezechilibru",
    "dezechilibrule": "dezechilibru",
    "dezechilibrului": "dezechilibru",
    "dezechipă": "dezechipa",
    "dezechipai": "dezechipa",
    "dezechipam": "dezechipa",
    "dezechipăm": "dezechipa",
    "dezechipând": "dezechipa",
    "dezechipându": "dezechipa",
    "dezechipară": "dezechipa",
    "dezechiparăm": "dezechipa",
    "dezechiparăți": "dezechipa",
    "dezechipase": "dezechipa",
    "dezechipasem": "dezechipa",
    "dezechipaseră": "dezechipa",
    "dezechipaserăm": "dezechipa",
    "dezechipaserăți": "dezechipa",
    "dezechipaseși": "dezechipa",
    "dezechipași": "dezechipa",
    "dezechipat": "dezechipa",
    "dezechipați": "dezechipa",
    "dezechipatu": "dezechipa",
    "dezechipau": "dezechipa",
    "dezechipează": "dezechipa",
    "dezechipez": "dezechipa",
    "dezechipeze": "dezechipa",
    "dezechipezi": "dezechipa",
    "nedezechipând": "dezechipa",
    "nedezechipându": "dezechipa",
    "nemaidezechipând": "dezechipa",
    "nemaidezechipându": "dezechipa",
    "dezechiparea": "dezechipare",
    "dezechipareo": "dezechipare",
    "dezechipări": "dezechipare",
    "dezechipării": "dezechipare",
    "dezechipările": "dezechipare",
    "dezechipărilor": "dezechipare",
    "dezechipata": "dezechipat",
    "dezechipată": "dezechipat",
    "dezechipate": "dezechipat",
    "dezechipatei": "dezechipat",
    "dezechipatele": "dezechipat",
    "dezechipatelor": "dezechipat",
    "dezechipați": "dezechipat",
    "dezechipații": "dezechipat",
    "dezechipaților": "dezechipat",
    "dezechipato": "dezechipat",
    "dezechipatul": "dezechipat",
    "dezechipatule": "dezechipat",
    "dezechipatului": "dezechipat",
    "dezertă": "dezerta",
    "dezertai": "dezerta",
    "dezertam": "dezerta",
    "dezertăm": "dezerta",
    "dezertând": "dezerta",
    "dezertându": "dezerta",
    "dezertară": "dezerta",
    "dezertarăm": "dezerta",
    "dezertarăți": "dezerta",
    "dezertase": "dezerta",
    "dezertasem": "dezerta",
    "dezertaseră": "dezerta",
    "dezertaserăm": "dezerta",
    "dezertaserăți": "dezerta",
    "dezertaseși": "dezerta",
    "dezertași": "dezerta",
    "dezertat": "dezerta",
    "dezertați": "dezerta",
    "dezertatu": "dezerta",
    "dezertau": "dezerta",
    "dezertează": "dezerta",
    "dezertez": "dezerta",
    "dezerteze": "dezerta",
    "dezertezi": "dezerta",
    "nedezertând": "dezerta",
    "nedezertându": "dezerta",
    "nemaidezertând": "dezerta",
    "nemaidezertându": "dezerta",
    "dezertarea": "dezertare",
    "dezertareo": "dezertare",
    "dezertări": "dezertare",
    "dezertării": "dezertare",
    "dezertările": "dezertare",
    "dezertărilor": "dezertare",
    "dezertată": "dezertat",
    "dezertate": "dezertat",
    "dezertați": "dezertat",
    "dezertori": "dezertor",
    "dezertorii": "dezertor",
    "dezertorilor": "dezertor",
    "dezertorul": "dezertor",
    "dezertorule": "dezertor",
    "dezertorului": "dezertor",
    "dezghețul": "dezgheț",
    "dezghețule": "dezgheț",
    "dezghețului": "dezgheț",
    "dezghețuri": "dezgheț",
    "dezghețurile": "dezgheț",
    "dezghețurilor": "dezgheț",
    "dezgheață": "dezgheța",
    "dezgheț": "dezgheța",
    "dezgheță": "dezgheța",
    "dezghețai": "dezgheța",
    "dezghețam": "dezgheța",
    "dezghețăm": "dezgheța",
    "dezghețând": "dezgheța",
    "dezghețându": "dezgheța",
    "dezghețară": "dezgheța",
    "dezghețarăm": "dezgheța",
    "dezghețarăți": "dezgheța",
    "dezghețase": "dezgheța",
    "dezghețasem": "dezgheța",
    "dezghețaseră": "dezgheța",
    "dezghețaserăm": "dezgheța",
    "dezghețaserăți": "dezgheța",
    "dezghețaseși": "dezgheța",
    "dezghețași": "dezgheța",
    "dezghețat": "dezgheța",
    "dezghețați": "dezgheța",
    "dezghețatu": "dezgheța",
    "dezghețau": "dezgheța",
    "dezghețe": "dezgheța",
    "dezgheți": "dezgheța",
    "nedezghețând": "dezgheța",
    "nedezghețându": "dezgheța",
    "nemaidezghețând": "dezgheța",
    "nemaidezghețându": "dezgheța",
    "dezghețata": "dezghețat",
    "dezghețată": "dezghețat",
    "dezghețate": "dezghețat",
    "dezghețatei": "dezghețat",
    "dezghețatele": "dezghețat",
    "dezghețatelor": "dezghețat",
    "dezghețați": "dezghețat",
    "dezghețații": "dezghețat",
    "dezghețaților": "dezghețat",
    "dezghețato": "dezghețat",
    "dezghețatul": "dezghețat",
    "dezghețatule": "dezghețat",
    "dezghețatului": "dezghețat",
    "dezghioacă": "dezghioca",
    "dezghioace": "dezghioca",
    "dezghioc": "dezghioca",
    "dezghiocă": "dezghioca",
    "dezghiocai": "dezghioca",
    "dezghiocam": "dezghioca",
    "dezghiocăm": "dezghioca",
    "dezghiocând": "dezghioca",
    "dezghiocându": "dezghioca",
    "dezghiocară": "dezghioca",
    "dezghiocarăm": "dezghioca",
    "dezghiocarăți": "dezghioca",
    "dezghiocase": "dezghioca",
    "dezghiocasem": "dezghioca",
    "dezghiocaseră": "dezghioca",
    "dezghiocaserăm": "dezghioca",
    "dezghiocaserăți": "dezghioca",
    "dezghiocaseși": "dezghioca",
    "dezghiocași": "dezghioca",
    "dezghiocat": "dezghioca",
    "dezghiocați": "dezghioca",
    "dezghiocatu": "dezghioca",
    "dezghiocau": "dezghioca",
    "dezghioci": "dezghioca",
    "nedezghiocând": "dezghioca",
    "nedezghiocându": "dezghioca",
    "nemaidezghiocând": "dezghioca",
    "nemaidezghiocându": "dezghioca",
    "dezghiocarea": "dezghiocare",
    "dezghiocareo": "dezghiocare",
    "dezghiocări": "dezghiocare",
    "dezghiocării": "dezghiocare",
    "dezghiocările": "dezghiocare",
    "dezghiocărilor": "dezghiocare",
    "dezghiocata": "dezghiocat",
    "dezghiocată": "dezghiocat",
    "dezghiocate": "dezghiocat",
    "dezghiocatei": "dezghiocat",
    "dezghiocatele": "dezghiocat",
    "dezghiocatelor": "dezghiocat",
    "dezghiocați": "dezghiocat",
    "dezghiocații": "dezghiocat",
    "dezghiocaților": "dezghiocat",
    "dezghiocato": "dezghiocat",
    "dezghiocatul": "dezghiocat",
    "dezghiocatule": "dezghiocat",
    "dezghiocatului": "dezghiocat",
    "dezgolea": "dezgoli",
    "dezgoleai": "dezgoli",
    "dezgoleam": "dezgoli",
    "dezgolească": "dezgoli",
    "dezgoleați": "dezgoli",
    "dezgoleau": "dezgoli",
    "dezgolesc": "dezgoli",
    "dezgolește": "dezgoli",
    "dezgolești": "dezgoli",
    "dezgolii": "dezgoli",
    "dezgolim": "dezgoli",
    "dezgolind": "dezgoli",
    "dezgolindu": "dezgoli",
    "dezgoliră": "dezgoli",
    "dezgolirăm": "dezgoli",
    "dezgolirăți": "dezgoli",
    "dezgolise": "dezgoli",
    "dezgolisem": "dezgoli",
    "dezgoliseră": "dezgoli",
    "dezgoliserăm": "dezgoli",
    "dezgoliserăți": "dezgoli",
    "dezgoliseși": "dezgoli",
    "dezgoliși": "dezgoli",
    "dezgolit": "dezgoli",
    "dezgoliți": "dezgoli",
    "dezgolitu": "dezgoli",
    "dezgolirea": "dezgolire",
    "dezgoliri": "dezgolire",
    "dezgolirii": "dezgolire",
    "dezgolirile": "dezgolire",
    "dezgolirilor": "dezgolire",
    "dezgolită": "dezgolit",
    "dezgolite": "dezgolit",
    "dezgoliți": "dezgolit",
    "dezgrădea": "dezgrădi",
    "dezgrădeai": "dezgrădi",
    "dezgrădeam": "dezgrădi",
    "dezgrădească": "dezgrădi",
    "dezgrădeați": "dezgrădi",
    "dezgrădeau": "dezgrădi",
    "dezgrădesc": "dezgrădi",
    "dezgrădește": "dezgrădi",
    "dezgrădești": "dezgrădi",
    "dezgrădii": "dezgrădi",
    "dezgrădim": "dezgrădi",
    "dezgrădind": "dezgrădi",
    "dezgrădindu": "dezgrădi",
    "dezgrădiră": "dezgrădi",
    "dezgrădirăm": "dezgrădi",
    "dezgrădirăți": "dezgrădi",
    "dezgrădise": "dezgrădi",
    "dezgrădisem": "dezgrădi",
    "dezgrădiseră": "dezgrădi",
    "dezgrădiserăm": "dezgrădi",
    "dezgrădiserăți": "dezgrădi",
    "dezgrădiseși": "dezgrădi",
    "dezgrădiși": "dezgrădi",
    "dezgrădit": "dezgrădi",
    "dezgrădiți": "dezgrădi",
    "dezgrăditu": "dezgrădi",
    "nedezgrădind": "dezgrădi",
    "nedezgrădindu": "dezgrădi",
    "nemaidezgrădind": "dezgrădi",
    "nemaidezgrădindu": "dezgrădi",
    "dezgrădirea": "dezgrădire",
    "dezgrădireo": "dezgrădire",
    "dezgrădiri": "dezgrădire",
    "dezgrădirii": "dezgrădire",
    "dezgrădirile": "dezgrădire",
    "dezgrădirilor": "dezgrădire",
    "dezgrădită": "dezgrădit",
    "dezgrădite": "dezgrădit",
    "dezgrădiți": "dezgrădit",
    "dezgroapă": "dezgropa",
    "dezgroape": "dezgropa",
    "dezgrop": "dezgropa",
    "dezgropă": "dezgropa",
    "dezgropai": "dezgropa",
    "dezgropam": "dezgropa",
    "dezgropăm": "dezgropa",
    "dezgropând": "dezgropa",
    "dezgropându": "dezgropa",
    "dezgropară": "dezgropa",
    "dezgroparăm": "dezgropa",
    "dezgroparăți": "dezgropa",
    "dezgropase": "dezgropa",
    "dezgropasem": "dezgropa",
    "dezgropaseră": "dezgropa",
    "dezgropaserăm": "dezgropa",
    "dezgropaserăți": "dezgropa",
    "dezgropaseși": "dezgropa",
    "dezgropași": "dezgropa",
    "dezgropat": "dezgropa",
    "dezgropați": "dezgropa",
    "dezgropatu": "dezgropa",
    "dezgropau": "dezgropa",
    "dezgropi": "dezgropa",
    "nedezgropând": "dezgropa",
    "nedezgropându": "dezgropa",
    "nemaidezgropând": "dezgropa",
    "nemaidezgropându": "dezgropa",
    "dezgroparea": "dezgropare",
    "dezgropareo": "dezgropare",
    "dezgropări": "dezgropare",
    "dezgropării": "dezgropare",
    "dezgropările": "dezgropare",
    "dezgropărilor": "dezgropare",
    "dezgropată": "dezgropat",
    "dezgropate": "dezgropat",
    "dezgropați": "dezgropat",
    "dezgropatul": "dezgropat",
    "dezgropatule": "dezgropat",
    "dezgropatului": "dezgropat",
    "dezgustul": "dezgust",
    "dezgustule": "dezgust",
    "dezgustului": "dezgust",
    "dezgust": "dezgusta",
    "dezgustă": "dezgusta",
    "dezgustai": "dezgusta",
    "dezgustam": "dezgusta",
    "dezgustăm": "dezgusta",
    "dezgustând": "dezgusta",
    "dezgustându": "dezgusta",
    "dezgustară": "dezgusta",
    "dezgustarăm": "dezgusta",
    "dezgustarăți": "dezgusta",
    "dezgustase": "dezgusta",
    "dezgustasem": "dezgusta",
    "dezgustaseră": "dezgusta",
    "dezgustaserăm": "dezgusta",
    "dezgustaserăți": "dezgusta",
    "dezgustaseși": "dezgusta",
    "dezgustași": "dezgusta",
    "dezgustat": "dezgusta",
    "dezgustați": "dezgusta",
    "dezgustatu": "dezgusta",
    "dezgustau": "dezgusta",
    "dezguste": "dezgusta",
    "dezguști": "dezgusta",
    "nedezgustând": "dezgusta",
    "nedezgustându": "dezgusta",
    "nemaidezgustând": "dezgusta",
    "nemaidezgustându": "dezgusta",
    "dezgustata": "dezgustat",
    "dezgustată": "dezgustat",
    "dezgustate": "dezgustat",
    "dezgustatei": "dezgustat",
    "dezgustatele": "dezgustat",
    "dezgustatelor": "dezgustat",
    "dezgustați": "dezgustat",
    "dezgustații": "dezgustat",
    "dezgustaților": "dezgustat",
    "dezgustato": "dezgustat",
    "dezgustatul": "dezgustat",
    "dezgustatule": "dezgustat",
    "dezgustatului": "dezgustat",
    "dezgustătoare": "dezgustător",
    "dezgustătoarea": "dezgustător",
    "dezgustătoarei": "dezgustător",
    "dezgustătoarele": "dezgustător",
    "dezgustătoarelor": "dezgustător",
    "dezgustătoareo": "dezgustător",
    "dezgustători": "dezgustător",
    "dezgustătorii": "dezgustător",
    "dezgustătorilor": "dezgustător",
    "dezgustătorul": "dezgustător",
    "dezgustătorule": "dezgustător",
    "dezgustătorului": "dezgustător",
    "dezic": "dezice",
    "dezică": "dezice",
    "dezicând": "dezice",
    "dezicându": "dezice",
    "dezicea": "dezice",
    "deziceai": "dezice",
    "deziceam": "dezice",
    "deziceați": "dezice",
    "deziceau": "dezice",
    "dezicem": "dezice",
    "deziceți": "dezice",
    "dezici": "dezice",
    "dezis": "dezice",
    "dezise": "dezice",
    "dezisei": "dezice",
    "deziseră": "dezice",
    "deziserăm": "dezice",
    "deziserăți": "dezice",
    "dezisese": "dezice",
    "dezisesem": "dezice",
    "deziseseră": "dezice",
    "deziseserăm": "dezice",
    "deziseserăți": "dezice",
    "deziseseși": "dezice",
    "deziseși": "dezice",
    "dezisu": "dezice",
    "dezicerea": "dezicere",
    "dezicereo": "dezicere",
    "deziceri": "dezicere",
    "dezicerii": "dezicere",
    "dezicerile": "dezicere",
    "dezicerilor": "dezicere",
    "deziderate": "deziderat",
    "dezideratele": "deziderat",
    "dezideratelor": "deziderat",
    "dezideratul": "deziderat",
    "dezideratule": "deziderat",
    "dezideratului": "deziderat",
    "deziluzia": "deziluzie",
    "deziluziei": "deziluzie",
    "deziluzii": "deziluzie",
    "deziluziile": "deziluzie",
    "deziluziilor": "deziluzie",
    "deziluzio": "deziluzie",
    "deziluzionă": "deziluziona",
    "deziluzionai": "deziluziona",
    "deziluzionam": "deziluziona",
    "deziluzionăm": "deziluziona",
    "deziluzionând": "deziluziona",
    "deziluzionându": "deziluziona",
    "deziluzionară": "deziluziona",
    "deziluzionarăm": "deziluziona",
    "deziluzionarăți": "deziluziona",
    "deziluzionase": "deziluziona",
    "deziluzionasem": "deziluziona",
    "deziluzionaseră": "deziluziona",
    "deziluzionaserăm": "deziluziona",
    "deziluzionaserăți": "deziluziona",
    "deziluzionaseși": "deziluziona",
    "deziluzionași": "deziluziona",
    "deziluzionat": "deziluziona",
    "deziluzionați": "deziluziona",
    "deziluzionatu": "deziluziona",
    "deziluzionau": "deziluziona",
    "deziluzionează": "deziluziona",
    "deziluzionez": "deziluziona",
    "deziluzioneze": "deziluziona",
    "deziluzionezi": "deziluziona",
    "nedeziluzionând": "deziluziona",
    "nedeziluzionându": "deziluziona",
    "nemaideziluzionând": "deziluziona",
    "nemaideziluzionându": "deziluziona",
    "deziluzionata": "deziluzionat",
    "deziluzionată": "deziluzionat",
    "deziluzionate": "deziluzionat",
    "deziluzionatei": "deziluzionat",
    "deziluzionatele": "deziluzionat",
    "deziluzionatelor": "deziluzionat",
    "deziluzionați": "deziluzionat",
    "deziluzionații": "deziluzionat",
    "deziluzionaților": "deziluzionat",
    "deziluzionato": "deziluzionat",
    "deziluzionatul": "deziluzionat",
    "deziluzionatule": "deziluzionat",
    "deziluzionatului": "deziluzionat",
    "dezincrimină": "dezincrimina",
    "dezincriminai": "dezincrimina",
    "dezincriminam": "dezincrimina",
    "dezincriminăm": "dezincrimina",
    "dezincriminând": "dezincrimina",
    "dezincriminându": "dezincrimina",
    "dezincriminară": "dezincrimina",
    "dezincriminarăm": "dezincrimina",
    "dezincriminarăți": "dezincrimina",
    "dezincriminase": "dezincrimina",
    "dezincriminasem": "dezincrimina",
    "dezincriminaseră": "dezincrimina",
    "dezincriminaserăm": "dezincrimina",
    "dezincriminaserăți": "dezincrimina",
    "dezincriminaseși": "dezincrimina",
    "dezincriminași": "dezincrimina",
    "dezincriminat": "dezincrimina",
    "dezincriminați": "dezincrimina",
    "dezincriminatu": "dezincrimina",
    "dezincriminau": "dezincrimina",
    "dezincriminează": "dezincrimina",
    "dezincriminez": "dezincrimina",
    "dezincrimineze": "dezincrimina",
    "dezincriminezi": "dezincrimina",
    "dezincriminarea": "dezincriminare",
    "dezincriminareo": "dezincriminare",
    "dezincriminări": "dezincriminare",
    "dezincriminării": "dezincriminare",
    "dezincriminările": "dezincriminare",
    "dezincriminărilor": "dezincriminare",
    "dezincriminată": "dezincriminat",
    "dezincriminate": "dezincriminat",
    "dezincriminați": "dezincriminat",
    "dezincrustă": "dezincrusta",
    "dezincrustai": "dezincrusta",
    "dezincrustam": "dezincrusta",
    "dezincrustăm": "dezincrusta",
    "dezincrustând": "dezincrusta",
    "dezincrustându": "dezincrusta",
    "dezincrustară": "dezincrusta",
    "dezincrustarăm": "dezincrusta",
    "dezincrustarăți": "dezincrusta",
    "dezincrustase": "dezincrusta",
    "dezincrustasem": "dezincrusta",
    "dezincrustaseră": "dezincrusta",
    "dezincrustaserăm": "dezincrusta",
    "dezincrustaserăți": "dezincrusta",
    "dezincrustaseși": "dezincrusta",
    "dezincrustași": "dezincrusta",
    "dezincrustat": "dezincrusta",
    "dezincrustați": "dezincrusta",
    "dezincrustatu": "dezincrusta",
    "dezincrustau": "dezincrusta",
    "dezincrustează": "dezincrusta",
    "dezincrustez": "dezincrusta",
    "dezincrusteze": "dezincrusta",
    "dezincrustezi": "dezincrusta",
    "nedezincrustând": "dezincrusta",
    "nedezincrustându": "dezincrusta",
    "nemaidezincrustând": "dezincrusta",
    "nemaidezincrustându": "dezincrusta",
    "dezincrustante": "dezincrustant",
    "dezincrustantele": "dezincrustant",
    "dezincrustantelor": "dezincrustant",
    "dezincrustantul": "dezincrustant",
    "dezincrustantule": "dezincrustant",
    "dezincrustantului": "dezincrustant",
    "dezincrustată": "dezincrustat",
    "dezincrustate": "dezincrustat",
    "dezincrustați": "dezincrustat",
    "dezinfectă": "dezinfecta",
    "dezinfectai": "dezinfecta",
    "dezinfectam": "dezinfecta",
    "dezinfectăm": "dezinfecta",
    "dezinfectând": "dezinfecta",
    "dezinfectându": "dezinfecta",
    "dezinfectară": "dezinfecta",
    "dezinfectarăm": "dezinfecta",
    "dezinfectarăți": "dezinfecta",
    "dezinfectase": "dezinfecta",
    "dezinfectasem": "dezinfecta",
    "dezinfectaseră": "dezinfecta",
    "dezinfectaserăm": "dezinfecta",
    "dezinfectaserăți": "dezinfecta",
    "dezinfectaseși": "dezinfecta",
    "dezinfectași": "dezinfecta",
    "dezinfectat": "dezinfecta",
    "dezinfectați": "dezinfecta",
    "dezinfectatu": "dezinfecta",
    "dezinfectau": "dezinfecta",
    "dezinfectează": "dezinfecta",
    "dezinfectez": "dezinfecta",
    "dezinfecteze": "dezinfecta",
    "dezinfectezi": "dezinfecta",
    "nedezinfectând": "dezinfecta",
    "nedezinfectându": "dezinfecta",
    "nemaidezinfectând": "dezinfecta",
    "nemaidezinfectându": "dezinfecta",
    "dezinfectante": "dezinfectant",
    "dezinfectantele": "dezinfectant",
    "dezinfectantelor": "dezinfectant",
    "dezinfectantul": "dezinfectant",
    "dezinfectantule": "dezinfectant",
    "dezinfectantului": "dezinfectant",
    "dezinfectarea": "dezinfectare",
    "dezinfectareo": "dezinfectare",
    "dezinfectări": "dezinfectare",
    "dezinfectării": "dezinfectare",
    "dezinfectările": "dezinfectare",
    "dezinfectărilor": "dezinfectare",
    "dezinfectată": "dezinfectat",
    "dezinfectate": "dezinfectat",
    "dezinfectați": "dezinfectat",
    "dezinfecția": "dezinfecție",
    "dezinfecției": "dezinfecție",
    "dezinfecții": "dezinfecție",
    "dezinfecțiile": "dezinfecție",
    "dezinfecțiilor": "dezinfecție",
    "dezinfecțio": "dezinfecție",
    "dezinformă": "dezinforma",
    "dezinformai": "dezinforma",
    "dezinformam": "dezinforma",
    "dezinformăm": "dezinforma",
    "dezinformând": "dezinforma",
    "dezinformându": "dezinforma",
    "dezinformară": "dezinforma",
    "dezinformarăm": "dezinforma",
    "dezinformarăți": "dezinforma",
    "dezinformase": "dezinforma",
    "dezinformasem": "dezinforma",
    "dezinformaseră": "dezinforma",
    "dezinformaserăm": "dezinforma",
    "dezinformaserăți": "dezinforma",
    "dezinformaseși": "dezinforma",
    "dezinformași": "dezinforma",
    "dezinformat": "dezinforma",
    "dezinformați": "dezinforma",
    "dezinformatu": "dezinforma",
    "dezinformau": "dezinforma",
    "dezinformează": "dezinforma",
    "dezinformez": "dezinforma",
    "dezinformeze": "dezinforma",
    "dezinformezi": "dezinforma",
    "dezinformarea": "dezinformare",
    "dezinformareo": "dezinformare",
    "dezinformări": "dezinformare",
    "dezinformării": "dezinformare",
    "dezinformările": "dezinformare",
    "dezinformărilor": "dezinformare",
    "dezinformata": "dezinformat",
    "dezinformată": "dezinformat",
    "dezinformate": "dezinformat",
    "dezinformatei": "dezinformat",
    "dezinformatele": "dezinformat",
    "dezinformatelor": "dezinformat",
    "dezinformați": "dezinformat",
    "dezinformații": "dezinformat",
    "dezinformaților": "dezinformat",
    "dezinformato": "dezinformat",
    "dezinformatul": "dezinformat",
    "dezinformatule": "dezinformat",
    "dezinformatului": "dezinformat",
    "dezintegră": "dezintegra",
    "dezintegrai": "dezintegra",
    "dezintegram": "dezintegra",
    "dezintegrăm": "dezintegra",
    "dezintegrând": "dezintegra",
    "dezintegrându": "dezintegra",
    "dezintegrară": "dezintegra",
    "dezintegrarăm": "dezintegra",
    "dezintegrarăți": "dezintegra",
    "dezintegrase": "dezintegra",
    "dezintegrasem": "dezintegra",
    "dezintegraseră": "dezintegra",
    "dezintegraserăm": "dezintegra",
    "dezintegraserăți": "dezintegra",
    "dezintegraseși": "dezintegra",
    "dezintegrași": "dezintegra",
    "dezintegrat": "dezintegra",
    "dezintegrați": "dezintegra",
    "dezintegratu": "dezintegra",
    "dezintegrau": "dezintegra",
    "dezintegrează": "dezintegra",
    "dezintegrez": "dezintegra",
    "dezintegreze": "dezintegra",
    "dezintegrezi": "dezintegra",
    "nedezintegrând": "dezintegra",
    "nedezintegrându": "dezintegra",
    "nemaidezintegrând": "dezintegra",
    "nemaidezintegrându": "dezintegra",
    "dezintegrarea": "dezintegrare",
    "dezintegrareo": "dezintegrare",
    "dezintegrări": "dezintegrare",
    "dezintegrării": "dezintegrare",
    "dezintegrările": "dezintegrare",
    "dezintegrărilor": "dezintegrare",
    "dezintegrata": "dezintegrat",
    "dezintegrată": "dezintegrat",
    "dezintegrate": "dezintegrat",
    "dezintegratei": "dezintegrat",
    "dezintegratele": "dezintegrat",
    "dezintegratelor": "dezintegrat",
    "dezintegrați": "dezintegrat",
    "dezintegrații": "dezintegrat",
    "dezintegraților": "dezintegrat",
    "dezintegrato": "dezintegrat",
    "dezintegratul": "dezintegrat",
    "dezintegratule": "dezintegrat",
    "dezintegratului": "dezintegrat",
    "dezinterese": "dezinteres",
    "dezinteresele": "dezinteres",
    "dezintereselor": "dezinteres",
    "dezinteresul": "dezinteres",
    "dezinteresule": "dezinteres",
    "dezinteresului": "dezinteres",
    "dezinteresă": "dezinteresa",
    "dezinteresai": "dezinteresa",
    "dezinteresam": "dezinteresa",
    "dezinteresăm": "dezinteresa",
    "dezinteresând": "dezinteresa",
    "dezinteresându": "dezinteresa",
    "dezinteresară": "dezinteresa",
    "dezinteresarăm": "dezinteresa",
    "dezinteresarăți": "dezinteresa",
    "dezinteresase": "dezinteresa",
    "dezinteresasem": "dezinteresa",
    "dezinteresaseră": "dezinteresa",
    "dezinteresaserăm": "dezinteresa",
    "dezinteresaserăți": "dezinteresa",
    "dezinteresaseși": "dezinteresa",
    "dezinteresași": "dezinteresa",
    "dezinteresat": "dezinteresa",
    "dezinteresați": "dezinteresa",
    "dezinteresatu": "dezinteresa",
    "dezinteresau": "dezinteresa",
    "dezinteresează": "dezinteresa",
    "dezinteresez": "dezinteresa",
    "dezintereseze": "dezinteresa",
    "dezinteresezi": "dezinteresa",
    "nedezinteresând": "dezinteresa",
    "nedezinteresându": "dezinteresa",
    "nemaidezinteresând": "dezinteresa",
    "nemaidezinteresându": "dezinteresa",
    "dezinteresarea": "dezinteresare",
    "dezinteresareo": "dezinteresare",
    "dezinteresări": "dezinteresare",
    "dezinteresării": "dezinteresare",
    "dezinteresările": "dezinteresare",
    "dezinteresărilor": "dezinteresare",
    "dezinteresata": "dezinteresat",
    "dezinteresată": "dezinteresat",
    "dezinteresate": "dezinteresat",
    "dezinteresatei": "dezinteresat",
    "dezinteresatele": "dezinteresat",
    "dezinteresatelor": "dezinteresat",
    "dezinteresați": "dezinteresat",
    "dezinteresații": "dezinteresat",
    "dezinteresaților": "dezinteresat",
    "dezinteresato": "dezinteresat",
    "dezinteresatul": "dezinteresat",
    "dezinteresatule": "dezinteresat",
    "dezinteresatului": "dezinteresat",
    "dezintoxic": "dezintoxica",
    "dezintoxică": "dezintoxica",
    "dezintoxicai": "dezintoxica",
    "dezintoxicam": "dezintoxica",
    "dezintoxicăm": "dezintoxica",
    "dezintoxicând": "dezintoxica",
    "dezintoxicându": "dezintoxica",
    "dezintoxicară": "dezintoxica",
    "dezintoxicarăm": "dezintoxica",
    "dezintoxicarăți": "dezintoxica",
    "dezintoxicase": "dezintoxica",
    "dezintoxicasem": "dezintoxica",
    "dezintoxicaseră": "dezintoxica",
    "dezintoxicaserăm": "dezintoxica",
    "dezintoxicaserăți": "dezintoxica",
    "dezintoxicaseși": "dezintoxica",
    "dezintoxicași": "dezintoxica",
    "dezintoxicat": "dezintoxica",
    "dezintoxicați": "dezintoxica",
    "dezintoxicatu": "dezintoxica",
    "dezintoxicau": "dezintoxica",
    "dezintoxice": "dezintoxica",
    "dezintoxici": "dezintoxica",
    "nedezintoxicând": "dezintoxica",
    "nedezintoxicându": "dezintoxica",
    "nemaidezintoxicând": "dezintoxica",
    "nemaidezintoxicându": "dezintoxica",
    "dezintoxicarea": "dezintoxicare",
    "dezintoxicareo": "dezintoxicare",
    "dezintoxicări": "dezintoxicare",
    "dezintoxicării": "dezintoxicare",
    "dezintoxicările": "dezintoxicare",
    "dezintoxicărilor": "dezintoxicare",
    "dezintoxicată": "dezintoxicat",
    "dezintoxicate": "dezintoxicat",
    "dezintoxicați": "dezintoxicat",
    "dezinvolta": "dezinvolt",
    "dezinvoltă": "dezinvolt",
    "dezinvolte": "dezinvolt",
    "dezinvoltei": "dezinvolt",
    "dezinvoltele": "dezinvolt",
    "dezinvoltelor": "dezinvolt",
    "dezinvolți": "dezinvolt",
    "dezinvolții": "dezinvolt",
    "dezinvolților": "dezinvolt",
    "dezinvolto": "dezinvolt",
    "dezinvoltul": "dezinvolt",
    "dezinvoltule": "dezinvolt",
    "dezinvoltului": "dezinvolt",
    "dezinvoltura": "dezinvoltură",
    "dezinvolturi": "dezinvoltură",
    "dezinvolturii": "dezinvoltură",
    "dezinvolturile": "dezinvoltură",
    "dezinvolturilor": "dezinvoltură",
    "dezinvolturo": "dezinvoltură",
    "dezirabila": "dezirabil",
    "dezirabilă": "dezirabil",
    "dezirabile": "dezirabil",
    "dezirabilei": "dezirabil",
    "dezirabilele": "dezirabil",
    "dezirabilelor": "dezirabil",
    "dezirabili": "dezirabil",
    "dezirabilii": "dezirabil",
    "dezirabililor": "dezirabil",
    "dezirabilo": "dezirabil",
    "dezirabilul": "dezirabil",
    "dezirabilule": "dezirabil",
    "dezirabilului": "dezirabil",
    "dezisa": "dezis",
    "dezisă": "dezis",
    "dezise": "dezis",
    "dezisei": "dezis",
    "dezisele": "dezis",
    "deziselor": "dezis",
    "deziși": "dezis",
    "dezișii": "dezis",
    "dezișilor": "dezis",
    "deziso": "dezis",
    "dezisul": "dezis",
    "dezisule": "dezis",
    "dezisului": "dezis",
    "dezlână": "dezlâna",
    "dezlânai": "dezlâna",
    "dezlânam": "dezlâna",
    "dezlânăm": "dezlâna",
    "dezlânând": "dezlâna",
    "dezlânându": "dezlâna",
    "dezlânară": "dezlâna",
    "dezlânarăm": "dezlâna",
    "dezlânarăți": "dezlâna",
    "dezlânase": "dezlâna",
    "dezlânasem": "dezlâna",
    "dezlânaseră": "dezlâna",
    "dezlânaserăm": "dezlâna",
    "dezlânaserăți": "dezlâna",
    "dezlânaseși": "dezlâna",
    "dezlânași": "dezlâna",
    "dezlânat": "dezlâna",
    "dezlânați": "dezlâna",
    "dezlânatu": "dezlâna",
    "dezlânau": "dezlâna",
    "dezlânează": "dezlâna",
    "dezlânez": "dezlâna",
    "dezlâneze": "dezlâna",
    "dezlânezi": "dezlâna",
    "nedezlânând": "dezlâna",
    "nedezlânându": "dezlâna",
    "nemaidezlânând": "dezlâna",
    "nemaidezlânându": "dezlâna",
    "dezlânarea": "dezlânare",
    "dezlânareo": "dezlânare",
    "dezlânări": "dezlânare",
    "dezlânării": "dezlânare",
    "dezlânările": "dezlânare",
    "dezlânărilor": "dezlânare",
    "dezlânata": "dezlânat",
    "dezlânată": "dezlânat",
    "dezlânate": "dezlânat",
    "dezlânatei": "dezlânat",
    "dezlânatele": "dezlânat",
    "dezlânatelor": "dezlânat",
    "dezlânați": "dezlânat",
    "dezlânații": "dezlânat",
    "dezlânaților": "dezlânat",
    "dezlânato": "dezlânat",
    "dezlânatul": "dezlânat",
    "dezlânatule": "dezlânat",
    "dezlânatului": "dezlânat",
    "dezlănțuia": "dezlănțui",
    "dezlănțuiai": "dezlănțui",
    "dezlănțuiam": "dezlănțui",
    "dezlănțuiați": "dezlănțui",
    "dezlănțuiau": "dezlănțui",
    "dezlănțuie": "dezlănțui",
    "dezlănțuii": "dezlănțui",
    "dezlănțuim": "dezlănțui",
    "dezlănțuind": "dezlănțui",
    "dezlănțuindu": "dezlănțui",
    "dezlănțuiră": "dezlănțui",
    "dezlănțuirăm": "dezlănțui",
    "dezlănțuirăți": "dezlănțui",
    "dezlănțuise": "dezlănțui",
    "dezlănțuisem": "dezlănțui",
    "dezlănțuiseră": "dezlănțui",
    "dezlănțuiserăm": "dezlănțui",
    "dezlănțuiserăți": "dezlănțui",
    "dezlănțuiseși": "dezlănțui",
    "dezlănțuiși": "dezlănțui",
    "dezlănțuit": "dezlănțui",
    "dezlănțuiți": "dezlănțui",
    "dezlănțuitu": "dezlănțui",
    "nedezlănțuind": "dezlănțui",
    "nedezlănțuindu": "dezlănțui",
    "nemaidezlănțuind": "dezlănțui",
    "nemaidezlănțuindu": "dezlănțui",
    "dezlănțuirea": "dezlănțuire",
    "dezlănțuireo": "dezlănțuire",
    "dezlănțuiri": "dezlănțuire",
    "dezlănțuirii": "dezlănțuire",
    "dezlănțuirile": "dezlănțuire",
    "dezlănțuirilor": "dezlănțuire",
    "dezlănțuita": "dezlănțuit",
    "dezlănțuită": "dezlănțuit",
    "dezlănțuite": "dezlănțuit",
    "dezlănțuitei": "dezlănțuit",
    "dezlănțuitele": "dezlănțuit",
    "dezlănțuitelor": "dezlănțuit",
    "dezlănțuiți": "dezlănțuit",
    "dezlănțuiții": "dezlănțuit",
    "dezlănțuiților": "dezlănțuit",
    "dezlănțuito": "dezlănțuit",
    "dezlănțuitul": "dezlănțuit",
    "dezlănțuitule": "dezlănțuit",
    "dezlănțuitului": "dezlănțuit",
    "dezleagă": "dezlega",
    "dezleg": "dezlega",
    "dezlegă": "dezlega",
    "dezlegai": "dezlega",
    "dezlegam": "dezlega",
    "dezlegăm": "dezlega",
    "dezlegând": "dezlega",
    "dezlegându": "dezlega",
    "dezlegară": "dezlega",
    "dezlegarăm": "dezlega",
    "dezlegarăți": "dezlega",
    "dezlegase": "dezlega",
    "dezlegasem": "dezlega",
    "dezlegaseră": "dezlega",
    "dezlegaserăm": "dezlega",
    "dezlegaserăți": "dezlega",
    "dezlegaseși": "dezlega",
    "dezlegași": "dezlega",
    "dezlegat": "dezlega",
    "dezlegați": "dezlega",
    "dezlegatu": "dezlega",
    "dezlegau": "dezlega",
    "dezlege": "dezlega",
    "dezlegi": "dezlega",
    "nedezlegând": "dezlega",
    "nedezlegându": "dezlega",
    "nemaidezlegând": "dezlega",
    "nemaidezlegându": "dezlega",
    "dezlegarea": "dezlegare",
    "dezlegareo": "dezlegare",
    "dezlegări": "dezlegare",
    "dezlegării": "dezlegare",
    "dezlegările": "dezlegare",
    "dezlegărilor": "dezlegare",
    "dezlegata": "dezlegat",
    "dezlegată": "dezlegat",
    "dezlegate": "dezlegat",
    "dezlegatei": "dezlegat",
    "dezlegatele": "dezlegat",
    "dezlegatelor": "dezlegat",
    "dezlegați": "dezlegat",
    "dezlegații": "dezlegat",
    "dezlegaților": "dezlegat",
    "dezlegato": "dezlegat",
    "dezlegatul": "dezlegat",
    "dezlegatule": "dezlegat",
    "dezlegatului": "dezlegat",
    "dezlegătoare": "dezlegător",
    "dezlegătoarea": "dezlegător",
    "dezlegătoarei": "dezlegător",
    "dezlegătoarele": "dezlegător",
    "dezlegătoarelor": "dezlegător",
    "dezlegătoareo": "dezlegător",
    "dezlegători": "dezlegător",
    "dezlegătorii": "dezlegător",
    "dezlegătorilor": "dezlegător",
    "dezlegătorul": "dezlegător",
    "dezlegătorule": "dezlegător",
    "dezlegătorului": "dezlegător",
    "dezmățul": "dezmăț",
    "dezmățule": "dezmăț",
    "dezmățului": "dezmăț",
    "dezmățuri": "dezmăț",
    "dezmățurile": "dezmăț",
    "dezmățurilor": "dezmăț",
    "dezmăț": "dezmăța",
    "dezmață": "dezmăța",
    "dezmăță": "dezmăța",
    "dezmățai": "dezmăța",
    "dezmățam": "dezmăța",
    "dezmățăm": "dezmăța",
    "dezmățând": "dezmăța",
    "dezmățându": "dezmăța",
    "dezmățară": "dezmăța",
    "dezmățarăm": "dezmăța",
    "dezmățarăți": "dezmăța",
    "dezmățase": "dezmăța",
    "dezmățasem": "dezmăța",
    "dezmățaseră": "dezmăța",
    "dezmățaserăm": "dezmăța",
    "dezmățaserăți": "dezmăța",
    "dezmățaseși": "dezmăța",
    "dezmățași": "dezmăța",
    "dezmățat": "dezmăța",
    "dezmățați": "dezmăța",
    "dezmățatu": "dezmăța",
    "dezmățau": "dezmăța",
    "dezmețe": "dezmăța",
    "dezmeți": "dezmăța",
    "nedezmățând": "dezmăța",
    "nedezmățându": "dezmăța",
    "nemaidezmățând": "dezmăța",
    "nemaidezmățându": "dezmăța",
    "dezmățarea": "dezmățare",
    "dezmățareo": "dezmățare",
    "dezmățări": "dezmățare",
    "dezmățării": "dezmățare",
    "dezmățările": "dezmățare",
    "dezmățărilor": "dezmățare",
    "dezmățata": "dezmățat",
    "dezmățată": "dezmățat",
    "dezmățate": "dezmățat",
    "dezmățatei": "dezmățat",
    "dezmățatele": "dezmățat",
    "dezmățatelor": "dezmățat",
    "dezmățați": "dezmățat",
    "dezmățații": "dezmățat",
    "dezmățaților": "dezmățat",
    "dezmățato": "dezmățat",
    "dezmățatul": "dezmățat",
    "dezmățatule": "dezmățat",
    "dezmățatului": "dezmățat",
    "dezmembră": "dezmembra",
    "dezmembrai": "dezmembra",
    "dezmembram": "dezmembra",
    "dezmembrăm": "dezmembra",
    "dezmembrând": "dezmembra",
    "dezmembrându": "dezmembra",
    "dezmembrară": "dezmembra",
    "dezmembrarăm": "dezmembra",
    "dezmembrarăți": "dezmembra",
    "dezmembrase": "dezmembra",
    "dezmembrasem": "dezmembra",
    "dezmembraseră": "dezmembra",
    "dezmembraserăm": "dezmembra",
    "dezmembraserăți": "dezmembra",
    "dezmembraseși": "dezmembra",
    "dezmembrași": "dezmembra",
    "dezmembrat": "dezmembra",
    "dezmembrați": "dezmembra",
    "dezmembratu": "dezmembra",
    "dezmembrau": "dezmembra",
    "dezmembrează": "dezmembra",
    "dezmembrez": "dezmembra",
    "dezmembreze": "dezmembra",
    "dezmembrezi": "dezmembra",
    "nedezmembrând": "dezmembra",
    "nedezmembrându": "dezmembra",
    "nemaidezmembrând": "dezmembra",
    "nemaidezmembrându": "dezmembra",
    "dezmembrarea": "dezmembrare",
    "dezmembrareo": "dezmembrare",
    "dezmembrări": "dezmembrare",
    "dezmembrării": "dezmembrare",
    "dezmembrările": "dezmembrare",
    "dezmembrărilor": "dezmembrare",
    "dezmembrată": "dezmembrat",
    "dezmembrate": "dezmembrat",
    "dezmembrați": "dezmembrat",
    "dezmeticea": "dezmetici",
    "dezmeticeai": "dezmetici",
    "dezmeticeam": "dezmetici",
    "dezmeticească": "dezmetici",
    "dezmeticeați": "dezmetici",
    "dezmeticeau": "dezmetici",
    "dezmeticesc": "dezmetici",
    "dezmeticește": "dezmetici",
    "dezmeticești": "dezmetici",
    "dezmeticii": "dezmetici",
    "dezmeticim": "dezmetici",
    "dezmeticind": "dezmetici",
    "dezmeticindu": "dezmetici",
    "dezmeticiră": "dezmetici",
    "dezmeticirăm": "dezmetici",
    "dezmeticirăți": "dezmetici",
    "dezmeticise": "dezmetici",
    "dezmeticisem": "dezmetici",
    "dezmeticiseră": "dezmetici",
    "dezmeticiserăm": "dezmetici",
    "dezmeticiserăți": "dezmetici",
    "dezmeticiseși": "dezmetici",
    "dezmeticiși": "dezmetici",
    "dezmeticit": "dezmetici",
    "dezmeticiți": "dezmetici",
    "dezmeticitu": "dezmetici",
    "nedezmeticind": "dezmetici",
    "nedezmeticindu": "dezmetici",
    "nemaidezmeticind": "dezmetici",
    "nemaidezmeticindu": "dezmetici",
    "dezmeticirea": "dezmeticire",
    "dezmeticireo": "dezmeticire",
    "dezmeticiri": "dezmeticire",
    "dezmeticirii": "dezmeticire",
    "dezmeticirile": "dezmeticire",
    "dezmeticirilor": "dezmeticire",
    "dezmeticita": "dezmeticit",
    "dezmeticită": "dezmeticit",
    "dezmeticite": "dezmeticit",
    "dezmeticitei": "dezmeticit",
    "dezmeticitele": "dezmeticit",
    "dezmeticitelor": "dezmeticit",
    "dezmeticiți": "dezmeticit",
    "dezmeticiții": "dezmeticit",
    "dezmeticiților": "dezmeticit",
    "dezmeticito": "dezmeticit",
    "dezmeticitul": "dezmeticit",
    "dezmeticitule": "dezmeticit",
    "dezmeticitului": "dezmeticit",
    "dezmiardă": "dezmierda",
    "dezmierd": "dezmierda",
    "dezmierdă": "dezmierda",
    "dezmierdai": "dezmierda",
    "dezmierdam": "dezmierda",
    "dezmierdăm": "dezmierda",
    "dezmierdând": "dezmierda",
    "dezmierdându": "dezmierda",
    "dezmierdară": "dezmierda",
    "dezmierdarăm": "dezmierda",
    "dezmierdarăți": "dezmierda",
    "dezmierdase": "dezmierda",
    "dezmierdasem": "dezmierda",
    "dezmierdaseră": "dezmierda",
    "dezmierdaserăm": "dezmierda",
    "dezmierdaserăți": "dezmierda",
    "dezmierdaseși": "dezmierda",
    "dezmierdași": "dezmierda",
    "dezmierdat": "dezmierda",
    "dezmierdați": "dezmierda",
    "dezmierdatu": "dezmierda",
    "dezmierdau": "dezmierda",
    "dezmierde": "dezmierda",
    "dezmierzi": "dezmierda",
    "nedezmierdând": "dezmierda",
    "nedezmierdându": "dezmierda",
    "nemaidezmierdând": "dezmierda",
    "nemaidezmierdându": "dezmierda",
    "dezmierdarea": "dezmierdare",
    "dezmierdareo": "dezmierdare",
    "dezmierdări": "dezmierdare",
    "dezmierdării": "dezmierdare",
    "dezmierdările": "dezmierdare",
    "dezmierdărilor": "dezmierdare",
    "dezmierdata": "dezmierdat",
    "dezmierdată": "dezmierdat",
    "dezmierdate": "dezmierdat",
    "dezmierdatei": "dezmierdat",
    "dezmierdatele": "dezmierdat",
    "dezmierdatelor": "dezmierdat",
    "dezmierdați": "dezmierdat",
    "dezmierdații": "dezmierdat",
    "dezmierdaților": "dezmierdat",
    "dezmierdato": "dezmierdat",
    "dezmierdatul": "dezmierdat",
    "dezmierdatule": "dezmierdat",
    "dezmierdatului": "dezmierdat",
    "dezmierdătoare": "dezmierdător",
    "dezmierdătoarea": "dezmierdător",
    "dezmierdătoarei": "dezmierdător",
    "dezmierdătoarele": "dezmierdător",
    "dezmierdătoarelor": "dezmierdător",
    "dezmierdătoareo": "dezmierdător",
    "dezmierdători": "dezmierdător",
    "dezmierdătorii": "dezmierdător",
    "dezmierdătorilor": "dezmierdător",
    "dezmierdătorul": "dezmierdător",
    "dezmierdătorule": "dezmierdător",
    "dezmierdătorului": "dezmierdător",
    "dezmint": "dezminți",
    "dezmintă": "dezminți",
    "dezminte": "dezminți",
    "dezmințea": "dezminți",
    "dezmințeai": "dezminți",
    "dezmințeam": "dezminți",
    "dezmințeați": "dezminți",
    "dezmințeau": "dezminți",
    "dezmințim": "dezminți",
    "dezmințind": "dezminți",
    "dezmințindu": "dezminți",
    "dezmințiră": "dezminți",
    "dezmințirăm": "dezminți",
    "dezmințirăți": "dezminți",
    "dezmințise": "dezminți",
    "dezmințisem": "dezminți",
    "dezmințiseră": "dezminți",
    "dezmințiserăm": "dezminți",
    "dezmințiserăți": "dezminți",
    "dezmințiseși": "dezminți",
    "dezmințiși": "dezminți",
    "dezmințit": "dezminți",
    "dezmințiți": "dezminți",
    "dezmințitu": "dezminți",
    "dezmințiri": "dezmințire",
    "dezmințită": "dezmințit",
    "dezmințite": "dezmințit",
    "dezmințiți": "dezmințit",
    "dezmiriștea": "dezmiriști",
    "dezmirișteai": "dezmiriști",
    "dezmirișteam": "dezmiriști",
    "dezmiriștească": "dezmiriști",
    "dezmirișteați": "dezmiriști",
    "dezmirișteau": "dezmiriști",
    "dezmiriștesc": "dezmiriști",
    "dezmiriștește": "dezmiriști",
    "dezmiriștești": "dezmiriști",
    "dezmiriștii": "dezmiriști",
    "dezmiriștim": "dezmiriști",
    "dezmiriștind": "dezmiriști",
    "dezmiriștindu": "dezmiriști",
    "dezmiriștiră": "dezmiriști",
    "dezmiriștirăm": "dezmiriști",
    "dezmiriștirăți": "dezmiriști",
    "dezmiriștise": "dezmiriști",
    "dezmiriștisem": "dezmiriști",
    "dezmiriștiseră": "dezmiriști",
    "dezmiriștiserăm": "dezmiriști",
    "dezmiriștiserăți": "dezmiriști",
    "dezmiriștiseși": "dezmiriști",
    "dezmiriștiși": "dezmiriști",
    "dezmiriștit": "dezmiriști",
    "dezmiriștiți": "dezmiriști",
    "dezmiriștitu": "dezmiriști",
    "nedezmiriștind": "dezmiriști",
    "nedezmiriștindu": "dezmiriști",
    "nemaidezmiriștind": "dezmiriști",
    "nemaidezmiriștindu": "dezmiriști",
    "dezmiriștirea": "dezmiriștire",
    "dezmiriștireo": "dezmiriștire",
    "dezmiriștiri": "dezmiriștire",
    "dezmiriștirii": "dezmiriștire",
    "dezmiriștirile": "dezmiriștire",
    "dezmiriștirilor": "dezmiriștire",
    "dezmiriștită": "dezmiriștit",
    "dezmiriștite": "dezmiriștit",
    "dezmiriștiți": "dezmiriștit",
    "dezmiriștitul": "dezmiriștit",
    "dezmiriștitule": "dezmiriștit",
    "dezmiriștitului": "dezmiriștit",
    "dezmorțeala": "dezmorțeală",
    "dezmorțealo": "dezmorțeală",
    "dezmorțeli": "dezmorțeală",
    "dezmorțelii": "dezmorțeală",
    "dezmorțelile": "dezmorțeală",
    "dezmorțelilor": "dezmorțeală",
    "dezmorțirilor": "dezmorțeală",
    "dezmorțea": "dezmorți",
    "dezmorțeai": "dezmorți",
    "dezmorțeam": "dezmorți",
    "dezmorțească": "dezmorți",
    "dezmorțeați": "dezmorți",
    "dezmorțeau": "dezmorți",
    "dezmorțesc": "dezmorți",
    "dezmorțește": "dezmorți",
    "dezmorțești": "dezmorți",
    "dezmorții": "dezmorți",
    "dezmorțim": "dezmorți",
    "dezmorțind": "dezmorți",
    "dezmorțindu": "dezmorți",
    "dezmorțiră": "dezmorți",
    "dezmorțirăm": "dezmorți",
    "dezmorțirăți": "dezmorți",
    "dezmorțise": "dezmorți",
    "dezmorțisem": "dezmorți",
    "dezmorțiseră": "dezmorți",
    "dezmorțiserăm": "dezmorți",
    "dezmorțiserăți": "dezmorți",
    "dezmorțiseși": "dezmorți",
    "dezmorțiși": "dezmorți",
    "dezmorțit": "dezmorți",
    "dezmorțiți": "dezmorți",
    "dezmorțitu": "dezmorți",
    "nedezmorțind": "dezmorți",
    "nedezmorțindu": "dezmorți",
    "nemaidezmorțind": "dezmorți",
    "nemaidezmorțindu": "dezmorți",
    "dezmorțirea": "dezmorțire",
    "dezmorțireo": "dezmorțire",
    "dezmorțiri": "dezmorțire",
    "dezmorțirii": "dezmorțire",
    "dezmorțirile": "dezmorțire",
    "dezmorțita": "dezmorțit",
    "dezmorțită": "dezmorțit",
    "dezmorțite": "dezmorțit",
    "dezmorțitei": "dezmorțit",
    "dezmorțitele": "dezmorțit",
    "dezmorțitelor": "dezmorțit",
    "dezmorțiți": "dezmorțit",
    "dezmorțiții": "dezmorțit",
    "dezmorțiților": "dezmorțit",
    "dezmorțito": "dezmorțit",
    "dezmorțitul": "dezmorțit",
    "dezmorțitule": "dezmorțit",
    "dezmorțitului": "dezmorțit",
    "deznădăjduita": "deznădăjduit",
    "deznădăjduită": "deznădăjduit",
    "deznădăjduite": "deznădăjduit",
    "deznădăjduitei": "deznădăjduit",
    "deznădăjduitele": "deznădăjduit",
    "deznădăjduitelor": "deznădăjduit",
    "deznădăjduiți": "deznădăjduit",
    "deznădăjduiții": "deznădăjduit",
    "deznădăjduiților": "deznădăjduit",
    "deznădăjduito": "deznădăjduit",
    "deznădăjduitul": "deznădăjduit",
    "deznădăjduitule": "deznădăjduit",
    "deznădăjduitului": "deznădăjduit",
    "deznădejdea": "deznădejde",
    "deznădejdeo": "deznădejde",
    "deznădejdi": "deznădejde",
    "deznădejdii": "deznădejde",
    "deznădejdile": "deznădejde",
    "deznădejdilor": "deznădejde",
    "deznaționaliză": "deznaționaliza",
    "deznaționalizai": "deznaționaliza",
    "deznaționalizam": "deznaționaliza",
    "deznaționalizăm": "deznaționaliza",
    "deznaționalizând": "deznaționaliza",
    "deznaționalizându": "deznaționaliza",
    "deznaționalizară": "deznaționaliza",
    "deznaționalizarăm": "deznaționaliza",
    "deznaționalizarăți": "deznaționaliza",
    "deznaționalizase": "deznaționaliza",
    "deznaționalizasem": "deznaționaliza",
    "deznaționalizaseră": "deznaționaliza",
    "deznaționalizaserăm": "deznaționaliza",
    "deznaționalizaserăți": "deznaționaliza",
    "deznaționalizaseși": "deznaționaliza",
    "deznaționalizași": "deznaționaliza",
    "deznaționalizat": "deznaționaliza",
    "deznaționalizați": "deznaționaliza",
    "deznaționalizatu": "deznaționaliza",
    "deznaționalizau": "deznaționaliza",
    "deznaționalizează": "deznaționaliza",
    "deznaționalizez": "deznaționaliza",
    "deznaționalizeze": "deznaționaliza",
    "deznaționalizezi": "deznaționaliza",
    "nedeznaționalizând": "deznaționaliza",
    "nedeznaționalizându": "deznaționaliza",
    "nemaideznaționalizând": "deznaționaliza",
    "nemaideznaționalizându": "deznaționaliza",
    "deznaționalizarea": "deznaționalizare",
    "deznaționalizareo": "deznaționalizare",
    "deznaționalizări": "deznaționalizare",
    "deznaționalizării": "deznaționalizare",
    "deznaționalizările": "deznaționalizare",
    "deznaționalizărilor": "deznaționalizare",
    "deznaționalizata": "deznaționalizat",
    "deznaționalizată": "deznaționalizat",
    "deznaționalizate": "deznaționalizat",
    "deznaționalizatei": "deznaționalizat",
    "deznaționalizatele": "deznaționalizat",
    "deznaționalizatelor": "deznaționalizat",
    "deznaționalizați": "deznaționalizat",
    "deznaționalizații": "deznaționalizat",
    "deznaționalizaților": "deznaționalizat",
    "deznaționalizato": "deznaționalizat",
    "deznaționalizatul": "deznaționalizat",
    "deznaționalizatule": "deznaționalizat",
    "deznaționalizatului": "deznaționalizat",
    "deznoadă": "deznoda",
    "deznoade": "deznoda",
    "deznod": "deznoda",
    "deznodă": "deznoda",
    "deznodai": "deznoda",
    "deznodam": "deznoda",
    "deznodăm": "deznoda",
    "deznodând": "deznoda",
    "deznodându": "deznoda",
    "deznodară": "deznoda",
    "deznodarăm": "deznoda",
    "deznodarăți": "deznoda",
    "deznodase": "deznoda",
    "deznodasem": "deznoda",
    "deznodaseră": "deznoda",
    "deznodaserăm": "deznoda",
    "deznodaserăți": "deznoda",
    "deznodaseși": "deznoda",
    "deznodași": "deznoda",
    "deznodat": "deznoda",
    "deznodați": "deznoda",
    "deznodatu": "deznoda",
    "deznodau": "deznoda",
    "deznozi": "deznoda",
    "nedeznodând": "deznoda",
    "nedeznodându": "deznoda",
    "nemaideznodând": "deznoda",
    "nemaideznodându": "deznoda",
    "deznodământul": "deznodământ",
    "deznodământule": "deznodământ",
    "deznodământului": "deznodământ",
    "deznodăminte": "deznodământ",
    "deznodămintele": "deznodământ",
    "deznodămintelor": "deznodământ",
    "deznodarea": "deznodare",
    "deznodareo": "deznodare",
    "deznodări": "deznodare",
    "deznodării": "deznodare",
    "deznodările": "deznodare",
    "deznodărilor": "deznodare",
    "deznodata": "deznodat",
    "deznodată": "deznodat",
    "deznodate": "deznodat",
    "deznodatei": "deznodat",
    "deznodatele": "deznodat",
    "deznodatelor": "deznodat",
    "deznodați": "deznodat",
    "deznodații": "deznodat",
    "deznodaților": "deznodat",
    "deznodato": "deznodat",
    "deznodatul": "deznodat",
    "deznodatule": "deznodat",
    "deznodatului": "deznodat",
    "dezodoriză": "dezodoriza",
    "dezodorizai": "dezodoriza",
    "dezodorizam": "dezodoriza",
    "dezodorizăm": "dezodoriza",
    "dezodorizând": "dezodoriza",
    "dezodorizându": "dezodoriza",
    "dezodorizară": "dezodoriza",
    "dezodorizarăm": "dezodoriza",
    "dezodorizarăți": "dezodoriza",
    "dezodorizase": "dezodoriza",
    "dezodorizasem": "dezodoriza",
    "dezodorizaseră": "dezodoriza",
    "dezodorizaserăm": "dezodoriza",
    "dezodorizaserăți": "dezodoriza",
    "dezodorizaseși": "dezodoriza",
    "dezodorizași": "dezodoriza",
    "dezodorizat": "dezodoriza",
    "dezodorizați": "dezodoriza",
    "dezodorizatu": "dezodoriza",
    "dezodorizau": "dezodoriza",
    "dezodorizează": "dezodoriza",
    "dezodorizez": "dezodoriza",
    "dezodorizeze": "dezodoriza",
    "dezodorizezi": "dezodoriza",
    "nedezodorizând": "dezodoriza",
    "nedezodorizându": "dezodoriza",
    "nemaidezodorizând": "dezodoriza",
    "nemaidezodorizându": "dezodoriza",
    "dezodorizarea": "dezodorizare",
    "dezodorizareo": "dezodorizare",
    "dezodorizări": "dezodorizare",
    "dezodorizării": "dezodorizare",
    "dezodorizările": "dezodorizare",
    "dezodorizărilor": "dezodorizare",
    "dezodorizată": "dezodorizat",
    "dezodorizate": "dezodorizat",
    "dezodorizați": "dezodorizat",
    "dezolă": "dezola",
    "dezolai": "dezola",
    "dezolam": "dezola",
    "dezolăm": "dezola",
    "dezolând": "dezola",
    "dezolându": "dezola",
    "dezolară": "dezola",
    "dezolarăm": "dezola",
    "dezolarăți": "dezola",
    "dezolase": "dezola",
    "dezolasem": "dezola",
    "dezolaseră": "dezola",
    "dezolaserăm": "dezola",
    "dezolaserăți": "dezola",
    "dezolaseși": "dezola",
    "dezolași": "dezola",
    "dezolat": "dezola",
    "dezolați": "dezola",
    "dezolatu": "dezola",
    "dezolau": "dezola",
    "dezolează": "dezola",
    "dezolez": "dezola",
    "dezoleze": "dezola",
    "dezolezi": "dezola",
    "nedezolând": "dezola",
    "nedezolându": "dezola",
    "nemaidezolând": "dezola",
    "nemaidezolându": "dezola",
    "dezolarea": "dezolare",
    "dezolareo": "dezolare",
    "dezolări": "dezolare",
    "dezolării": "dezolare",
    "dezolările": "dezolare",
    "dezolărilor": "dezolare",
    "dezolata": "dezolat",
    "dezolată": "dezolat",
    "dezolate": "dezolat",
    "dezolatei": "dezolat",
    "dezolatele": "dezolat",
    "dezolatelor": "dezolat",
    "dezolați": "dezolat",
    "dezolații": "dezolat",
    "dezolaților": "dezolat",
    "dezolato": "dezolat",
    "dezolatul": "dezolat",
    "dezolatule": "dezolat",
    "dezolatului": "dezolat",
    "dezonoarea": "dezonoare",
    "dezonoarei": "dezonoare",
    "dezonoareo": "dezonoare",
    "dezonoră": "dezonora",
    "dezonorai": "dezonora",
    "dezonoram": "dezonora",
    "dezonorăm": "dezonora",
    "dezonorând": "dezonora",
    "dezonorându": "dezonora",
    "dezonorară": "dezonora",
    "dezonorarăm": "dezonora",
    "dezonorarăți": "dezonora",
    "dezonorase": "dezonora",
    "dezonorasem": "dezonora",
    "dezonoraseră": "dezonora",
    "dezonoraserăm": "dezonora",
    "dezonoraserăți": "dezonora",
    "dezonoraseși": "dezonora",
    "dezonorași": "dezonora",
    "dezonorat": "dezonora",
    "dezonorați": "dezonora",
    "dezonoratu": "dezonora",
    "dezonorau": "dezonora",
    "dezonorează": "dezonora",
    "dezonorez": "dezonora",
    "dezonoreze": "dezonora",
    "dezonorezi": "dezonora",
    "nedezonorând": "dezonora",
    "nedezonorându": "dezonora",
    "nemaidezonorând": "dezonora",
    "nemaidezonorându": "dezonora",
    "dezonoranta": "dezonorant",
    "dezonorantă": "dezonorant",
    "dezonorante": "dezonorant",
    "dezonorantei": "dezonorant",
    "dezonorantele": "dezonorant",
    "dezonorantelor": "dezonorant",
    "dezonoranți": "dezonorant",
    "dezonoranții": "dezonorant",
    "dezonoranților": "dezonorant",
    "dezonoranto": "dezonorant",
    "dezonorantul": "dezonorant",
    "dezonorantule": "dezonorant",
    "dezonorantului": "dezonorant",
    "dezonorata": "dezonorat",
    "dezonorată": "dezonorat",
    "dezonorate": "dezonorat",
    "dezonoratei": "dezonorat",
    "dezonoratele": "dezonorat",
    "dezonoratelor": "dezonorat",
    "dezonorați": "dezonorat",
    "dezonorații": "dezonorat",
    "dezonoraților": "dezonorat",
    "dezonorato": "dezonorat",
    "dezonoratul": "dezonorat",
    "dezonoratule": "dezonorat",
    "dezonoratului": "dezonorat",
    "dezordinea": "dezordine",
    "dezordineo": "dezordine",
    "dezordini": "dezordine",
    "dezordinii": "dezordine",
    "dezordinile": "dezordine",
    "dezordinilor": "dezordine",
    "dezordonata": "dezordonat",
    "dezordonată": "dezordonat",
    "dezordonate": "dezordonat",
    "dezordonatei": "dezordonat",
    "dezordonatele": "dezordonat",
    "dezordonatelor": "dezordonat",
    "dezordonați": "dezordonat",
    "dezordonații": "dezordonat",
    "dezordonaților": "dezordonat",
    "dezordonato": "dezordonat",
    "dezordonatul": "dezordonat",
    "dezordonatule": "dezordonat",
    "dezordonatului": "dezordonat",
    "dezorganiză": "dezorganiza",
    "dezorganizai": "dezorganiza",
    "dezorganizam": "dezorganiza",
    "dezorganizăm": "dezorganiza",
    "dezorganizând": "dezorganiza",
    "dezorganizându": "dezorganiza",
    "dezorganizară": "dezorganiza",
    "dezorganizarăm": "dezorganiza",
    "dezorganizarăți": "dezorganiza",
    "dezorganizase": "dezorganiza",
    "dezorganizasem": "dezorganiza",
    "dezorganizaseră": "dezorganiza",
    "dezorganizaserăm": "dezorganiza",
    "dezorganizaserăți": "dezorganiza",
    "dezorganizaseși": "dezorganiza",
    "dezorganizași": "dezorganiza",
    "dezorganizat": "dezorganiza",
    "dezorganizați": "dezorganiza",
    "dezorganizatu": "dezorganiza",
    "dezorganizau": "dezorganiza",
    "dezorganizează": "dezorganiza",
    "dezorganizez": "dezorganiza",
    "dezorganizeze": "dezorganiza",
    "dezorganizezi": "dezorganiza",
    "nedezorganizând": "dezorganiza",
    "nedezorganizându": "dezorganiza",
    "nemaidezorganizând": "dezorganiza",
    "nemaidezorganizându": "dezorganiza",
    "dezorganizarea": "dezorganizare",
    "dezorganizareo": "dezorganizare",
    "dezorganizări": "dezorganizare",
    "dezorganizării": "dezorganizare",
    "dezorganizările": "dezorganizare",
    "dezorganizărilor": "dezorganizare",
    "dezorganizata": "dezorganizat",
    "dezorganizată": "dezorganizat",
    "dezorganizate": "dezorganizat",
    "dezorganizatei": "dezorganizat",
    "dezorganizatele": "dezorganizat",
    "dezorganizatelor": "dezorganizat",
    "dezorganizați": "dezorganizat",
    "dezorganizații": "dezorganizat",
    "dezorganizaților": "dezorganizat",
    "dezorganizato": "dezorganizat",
    "dezorganizatul": "dezorganizat",
    "dezorganizatule": "dezorganizat",
    "dezorganizatului": "dezorganizat",
    "dezorientă": "dezorienta",
    "dezorientai": "dezorienta",
    "dezorientam": "dezorienta",
    "dezorientăm": "dezorienta",
    "dezorientând": "dezorienta",
    "dezorientându": "dezorienta",
    "dezorientară": "dezorienta",
    "dezorientarăm": "dezorienta",
    "dezorientarăți": "dezorienta",
    "dezorientase": "dezorienta",
    "dezorientasem": "dezorienta",
    "dezorientaseră": "dezorienta",
    "dezorientaserăm": "dezorienta",
    "dezorientaserăți": "dezorienta",
    "dezorientaseși": "dezorienta",
    "dezorientași": "dezorienta",
    "dezorientat": "dezorienta",
    "dezorientați": "dezorienta",
    "dezorientatu": "dezorienta",
    "dezorientau": "dezorienta",
    "dezorientează": "dezorienta",
    "dezorientez": "dezorienta",
    "dezorienteze": "dezorienta",
    "dezorientezi": "dezorienta",
    "nedezorientând": "dezorienta",
    "nedezorientându": "dezorienta",
    "nemaidezorientând": "dezorienta",
    "nemaidezorientându": "dezorienta",
    "dezorientarea": "dezorientare",
    "dezorientareo": "dezorientare",
    "dezorientări": "dezorientare",
    "dezorientării": "dezorientare",
    "dezorientările": "dezorientare",
    "dezorientărilor": "dezorientare",
    "dezorientata": "dezorientat",
    "dezorientată": "dezorientat",
    "dezorientate": "dezorientat",
    "dezorientatei": "dezorientat",
    "dezorientatele": "dezorientat",
    "dezorientatelor": "dezorientat",
    "dezorientați": "dezorientat",
    "dezorientații": "dezorientat",
    "dezorientaților": "dezorientat",
    "dezorientato": "dezorientat",
    "dezorientatul": "dezorientat",
    "dezorientatule": "dezorientat",
    "dezorientatului": "dezorientat",
    "dezoxidă": "dezoxida",
    "dezoxidai": "dezoxida",
    "dezoxidam": "dezoxida",
    "dezoxidăm": "dezoxida",
    "dezoxidând": "dezoxida",
    "dezoxidându": "dezoxida",
    "dezoxidară": "dezoxida",
    "dezoxidarăm": "dezoxida",
    "dezoxidarăți": "dezoxida",
    "dezoxidase": "dezoxida",
    "dezoxidasem": "dezoxida",
    "dezoxidaseră": "dezoxida",
    "dezoxidaserăm": "dezoxida",
    "dezoxidaserăți": "dezoxida",
    "dezoxidaseși": "dezoxida",
    "dezoxidași": "dezoxida",
    "dezoxidat": "dezoxida",
    "dezoxidați": "dezoxida",
    "dezoxidatu": "dezoxida",
    "dezoxidau": "dezoxida",
    "dezoxidează": "dezoxida",
    "dezoxidez": "dezoxida",
    "dezoxideze": "dezoxida",
    "dezoxidezi": "dezoxida",
    "nedezoxidând": "dezoxida",
    "nedezoxidându": "dezoxida",
    "nemaidezoxidând": "dezoxida",
    "nemaidezoxidându": "dezoxida",
    "dezoxidată": "dezoxidat",
    "dezoxidate": "dezoxidat",
    "dezoxidați": "dezoxidat",
    "dezrădăcină": "dezrădăcina",
    "dezrădăcinai": "dezrădăcina",
    "dezrădăcinam": "dezrădăcina",
    "dezrădăcinăm": "dezrădăcina",
    "dezrădăcinând": "dezrădăcina",
    "dezrădăcinându": "dezrădăcina",
    "dezrădăcinară": "dezrădăcina",
    "dezrădăcinarăm": "dezrădăcina",
    "dezrădăcinarăți": "dezrădăcina",
    "dezrădăcinase": "dezrădăcina",
    "dezrădăcinasem": "dezrădăcina",
    "dezrădăcinaseră": "dezrădăcina",
    "dezrădăcinaserăm": "dezrădăcina",
    "dezrădăcinaserăți": "dezrădăcina",
    "dezrădăcinaseși": "dezrădăcina",
    "dezrădăcinași": "dezrădăcina",
    "dezrădăcinat": "dezrădăcina",
    "dezrădăcinați": "dezrădăcina",
    "dezrădăcinatu": "dezrădăcina",
    "dezrădăcinau": "dezrădăcina",
    "dezrădăcinează": "dezrădăcina",
    "dezrădăcinez": "dezrădăcina",
    "dezrădăcineze": "dezrădăcina",
    "dezrădăcinezi": "dezrădăcina",
    "nedezrădăcinând": "dezrădăcina",
    "nedezrădăcinându": "dezrădăcina",
    "nemaidezrădăcinând": "dezrădăcina",
    "nemaidezrădăcinându": "dezrădăcina",
    "dezrădăcinarea": "dezrădăcinare",
    "dezrădăcinareo": "dezrădăcinare",
    "dezrădăcinări": "dezrădăcinare",
    "dezrădăcinării": "dezrădăcinare",
    "dezrădăcinările": "dezrădăcinare",
    "dezrădăcinărilor": "dezrădăcinare",
    "dezrădăcinata": "dezrădăcinat",
    "dezrădăcinată": "dezrădăcinat",
    "dezrădăcinate": "dezrădăcinat",
    "dezrădăcinatei": "dezrădăcinat",
    "dezrădăcinatele": "dezrădăcinat",
    "dezrădăcinatelor": "dezrădăcinat",
    "dezrădăcinați": "dezrădăcinat",
    "dezrădăcinații": "dezrădăcinat",
    "dezrădăcinaților": "dezrădăcinat",
    "dezrădăcinato": "dezrădăcinat",
    "dezrădăcinatul": "dezrădăcinat",
    "dezrădăcinatule": "dezrădăcinat",
    "dezrădăcinatului": "dezrădăcinat",
    "dezrobirea": "dezrobire",
    "dezrobireo": "dezrobire",
    "dezrobiri": "dezrobire",
    "dezrobirii": "dezrobire",
    "dezrobirile": "dezrobire",
    "dezrobirilor": "dezrobire",
    "dezumaniză": "dezumaniza",
    "dezumanizai": "dezumaniza",
    "dezumanizam": "dezumaniza",
    "dezumanizăm": "dezumaniza",
    "dezumanizând": "dezumaniza",
    "dezumanizându": "dezumaniza",
    "dezumanizară": "dezumaniza",
    "dezumanizarăm": "dezumaniza",
    "dezumanizarăți": "dezumaniza",
    "dezumanizase": "dezumaniza",
    "dezumanizasem": "dezumaniza",
    "dezumanizaseră": "dezumaniza",
    "dezumanizaserăm": "dezumaniza",
    "dezumanizaserăți": "dezumaniza",
    "dezumanizaseși": "dezumaniza",
    "dezumanizași": "dezumaniza",
    "dezumanizat": "dezumaniza",
    "dezumanizați": "dezumaniza",
    "dezumanizatu": "dezumaniza",
    "dezumanizau": "dezumaniza",
    "dezumanizează": "dezumaniza",
    "dezumanizez": "dezumaniza",
    "dezumanizeze": "dezumaniza",
    "dezumanizezi": "dezumaniza",
    "nedezumanizând": "dezumaniza",
    "nedezumanizându": "dezumaniza",
    "nemaidezumanizând": "dezumaniza",
    "nemaidezumanizându": "dezumaniza",
    "dezumanizarea": "dezumanizare",
    "dezumanizareo": "dezumanizare",
    "dezumanizări": "dezumanizare",
    "dezumanizării": "dezumanizare",
    "dezumanizările": "dezumanizare",
    "dezumanizărilor": "dezumanizare",
    "dezumanizată": "dezumanizat",
    "dezumanizate": "dezumanizat",
    "dezumanizați": "dezumanizat",
    "dezvăluia": "dezvălui",
    "dezvăluiai": "dezvălui",
    "dezvăluiam": "dezvălui",
    "dezvăluiați": "dezvălui",
    "dezvăluiau": "dezvălui",
    "dezvăluie": "dezvălui",
    "dezvăluii": "dezvălui",
    "dezvăluim": "dezvălui",
    "dezvăluind": "dezvălui",
    "dezvăluindu": "dezvălui",
    "dezvăluiră": "dezvălui",
    "dezvăluirăm": "dezvălui",
    "dezvăluirăți": "dezvălui",
    "dezvăluise": "dezvălui",
    "dezvăluisem": "dezvălui",
    "dezvăluiseră": "dezvălui",
    "dezvăluiserăm": "dezvălui",
    "dezvăluiserăți": "dezvălui",
    "dezvăluiseși": "dezvălui",
    "dezvăluiși": "dezvălui",
    "dezvăluit": "dezvălui",
    "dezvăluiți": "dezvălui",
    "dezvăluitu": "dezvălui",
    "nedezvăluind": "dezvălui",
    "nedezvăluindu": "dezvălui",
    "nemaidezvăluind": "dezvălui",
    "nemaidezvăluindu": "dezvălui",
    "dezvăluirea": "dezvăluire",
    "dezvăluireo": "dezvăluire",
    "dezvăluiri": "dezvăluire",
    "dezvăluirii": "dezvăluire",
    "dezvăluirile": "dezvăluire",
    "dezvăluirilor": "dezvăluire",
    "dezvăluită": "dezvăluit",
    "dezvăluite": "dezvăluit",
    "dezvăluiți": "dezvăluit",
    "dezvăluitoare": "dezvăluitor",
    "dezvăluitoarea": "dezvăluitor",
    "dezvăluitoarei": "dezvăluitor",
    "dezvăluitoarele": "dezvăluitor",
    "dezvăluitoarelor": "dezvăluitor",
    "dezvăluitoareo": "dezvăluitor",
    "dezvăluitori": "dezvăluitor",
    "dezvăluitorii": "dezvăluitor",
    "dezvăluitorilor": "dezvăluitor",
    "dezvăluitorul": "dezvăluitor",
    "dezvăluitorule": "dezvăluitor",
    "dezvăluitorului": "dezvăluitor",
    "dezvățul": "dezvăț",
    "dezvățule": "dezvăț",
    "dezvățului": "dezvăț",
    "dezvăț": "dezvăța",
    "dezvață": "dezvăța",
    "dezvăță": "dezvăța",
    "dezvățai": "dezvăța",
    "dezvățam": "dezvăța",
    "dezvățăm": "dezvăța",
    "dezvățând": "dezvăța",
    "dezvățându": "dezvăța",
    "dezvățară": "dezvăța",
    "dezvățarăm": "dezvăța",
    "dezvățarăți": "dezvăța",
    "dezvățase": "dezvăța",
    "dezvățasem": "dezvăța",
    "dezvățaseră": "dezvăța",
    "dezvățaserăm": "dezvăța",
    "dezvățaserăți": "dezvăța",
    "dezvățaseși": "dezvăța",
    "dezvățași": "dezvăța",
    "dezvățat": "dezvăța",
    "dezvățați": "dezvăța",
    "dezvățatu": "dezvăța",
    "dezvățau": "dezvăța",
    "dezvețe": "dezvăța",
    "dezveți": "dezvăța",
    "nedezvățând": "dezvăța",
    "nedezvățându": "dezvăța",
    "nemaidezvățând": "dezvăța",
    "nemaidezvățându": "dezvăța",
    "dezvățarea": "dezvățare",
    "dezvățări": "dezvățare",
    "dezvățării": "dezvățare",
    "dezvățările": "dezvățare",
    "dezvățărilor": "dezvățare",
    "dezvățată": "dezvățat",
    "dezvățate": "dezvățat",
    "dezvățați": "dezvățat",
    "dezvelea": "dezveli",
    "dezveleai": "dezveli",
    "dezveleam": "dezveli",
    "dezvelească": "dezveli",
    "dezveleați": "dezveli",
    "dezveleau": "dezveli",
    "dezvelesc": "dezveli",
    "dezvelește": "dezveli",
    "dezvelești": "dezveli",
    "dezvelii": "dezveli",
    "dezvelim": "dezveli",
    "dezvelind": "dezveli",
    "dezvelindu": "dezveli",
    "dezveliră": "dezveli",
    "dezvelirăm": "dezveli",
    "dezvelirăți": "dezveli",
    "dezvelise": "dezveli",
    "dezvelisem": "dezveli",
    "dezveliseră": "dezveli",
    "dezveliserăm": "dezveli",
    "dezveliserăți": "dezveli",
    "dezveliseși": "dezveli",
    "dezveliși": "dezveli",
    "dezvelit": "dezveli",
    "dezveliți": "dezveli",
    "dezvelitu": "dezveli",
    "nedezvelind": "dezveli",
    "nedezvelindu": "dezveli",
    "nemaidezvelind": "dezveli",
    "nemaidezvelindu": "dezveli",
    "dezvelirea": "dezvelire",
    "dezvelireo": "dezvelire",
    "dezveliri": "dezvelire",
    "dezvelirii": "dezvelire",
    "dezvelirile": "dezvelire",
    "dezvelirilor": "dezvelire",
    "dezvelită": "dezvelit",
    "dezvelite": "dezvelit",
    "dezveliți": "dezvelit",
    "dezvinovățea": "dezvinovăți",
    "dezvinovățeai": "dezvinovăți",
    "dezvinovățeam": "dezvinovăți",
    "dezvinovățească": "dezvinovăți",
    "dezvinovățeați": "dezvinovăți",
    "dezvinovățeau": "dezvinovăți",
    "dezvinovățesc": "dezvinovăți",
    "dezvinovățește": "dezvinovăți",
    "dezvinovățești": "dezvinovăți",
    "dezvinovății": "dezvinovăți",
    "dezvinovățim": "dezvinovăți",
    "dezvinovățind": "dezvinovăți",
    "dezvinovățindu": "dezvinovăți",
    "dezvinovățiră": "dezvinovăți",
    "dezvinovățirăm": "dezvinovăți",
    "dezvinovățirăți": "dezvinovăți",
    "dezvinovățise": "dezvinovăți",
    "dezvinovățisem": "dezvinovăți",
    "dezvinovățiseră": "dezvinovăți",
    "dezvinovățiserăm": "dezvinovăți",
    "dezvinovățiserăți": "dezvinovăți",
    "dezvinovățiseși": "dezvinovăți",
    "dezvinovățiși": "dezvinovăți",
    "dezvinovățit": "dezvinovăți",
    "dezvinovățiți": "dezvinovăți",
    "dezvinovățitu": "dezvinovăți",
    "nedezvinovățind": "dezvinovăți",
    "nedezvinovățindu": "dezvinovăți",
    "nemaidezvinovățind": "dezvinovăți",
    "nemaidezvinovățindu": "dezvinovăți",
    "dezvinovățirea": "dezvinovățire",
    "dezvinovățireo": "dezvinovățire",
    "dezvinovățiri": "dezvinovățire",
    "dezvinovățirii": "dezvinovățire",
    "dezvinovățirile": "dezvinovățire",
    "dezvinovățirilor": "dezvinovățire",
    "dezvinovățită": "dezvinovățit",
    "dezvinovățite": "dezvinovățit",
    "dezvinovățiți": "dezvinovățit",
    "dezvinuia": "dezvinui",
    "dezvinuiai": "dezvinui",
    "dezvinuiam": "dezvinui",
    "dezvinuiască": "dezvinui",
    "dezvinuiați": "dezvinui",
    "dezvinuiau": "dezvinui",
    "dezvinuiesc": "dezvinui",
    "dezvinuiește": "dezvinui",
    "dezvinuiești": "dezvinui",
    "dezvinuii": "dezvinui",
    "dezvinuim": "dezvinui",
    "dezvinuind": "dezvinui",
    "dezvinuindu": "dezvinui",
    "dezvinuiră": "dezvinui",
    "dezvinuirăm": "dezvinui",
    "dezvinuirăți": "dezvinui",
    "dezvinuise": "dezvinui",
    "dezvinuisem": "dezvinui",
    "dezvinuiseră": "dezvinui",
    "dezvinuiserăm": "dezvinui",
    "dezvinuiserăți": "dezvinui",
    "dezvinuiseși": "dezvinui",
    "dezvinuiși": "dezvinui",
    "dezvinuit": "dezvinui",
    "dezvinuiți": "dezvinui",
    "dezvinuitu": "dezvinui",
    "nedezvinuind": "dezvinui",
    "nedezvinuindu": "dezvinui",
    "nemaidezvinuind": "dezvinui",
    "nemaidezvinuindu": "dezvinui",
    "dezvinuirea": "dezvinuire",
    "dezvinuireo": "dezvinuire",
    "dezvinuiri": "dezvinuire",
    "dezvinuirii": "dezvinuire",
    "dezvinuirile": "dezvinuire",
    "dezvinuirilor": "dezvinuire",
    "dezvinuită": "dezvinuit",
    "dezvinuite": "dezvinuit",
    "dezvinuiți": "dezvinuit",
    "dezvolt": "dezvolta",
    "dezvoltă": "dezvolta",
    "dezvoltai": "dezvolta",
    "dezvoltam": "dezvolta",
    "dezvoltăm": "dezvolta",
    "dezvoltând": "dezvolta",
    "dezvoltându": "dezvolta",
    "dezvoltară": "dezvolta",
    "dezvoltarăm": "dezvolta",
    "dezvoltarăți": "dezvolta",
    "dezvoltase": "dezvolta",
    "dezvoltasem": "dezvolta",
    "dezvoltaseră": "dezvolta",
    "dezvoltaserăm": "dezvolta",
    "dezvoltaserăți": "dezvolta",
    "dezvoltaseși": "dezvolta",
    "dezvoltași": "dezvolta",
    "dezvoltat": "dezvolta",
    "dezvoltați": "dezvolta",
    "dezvoltatu": "dezvolta",
    "dezvoltau": "dezvolta",
    "dezvolte": "dezvolta",
    "dezvolți": "dezvolta",
    "nedezvoltând": "dezvolta",
    "nedezvoltându": "dezvolta",
    "nemaidezvoltând": "dezvolta",
    "nemaidezvoltându": "dezvolta",
    "dezvoltarea": "dezvoltare",
    "dezvoltareo": "dezvoltare",
    "dezvoltări": "dezvoltare",
    "dezvoltării": "dezvoltare",
    "dezvoltările": "dezvoltare",
    "dezvoltărilor": "dezvoltare",
    "dezvoltata": "dezvoltat",
    "dezvoltată": "dezvoltat",
    "dezvoltate": "dezvoltat",
    "dezvoltatei": "dezvoltat",
    "dezvoltatele": "dezvoltat",
    "dezvoltatelor": "dezvoltat",
    "dezvoltați": "dezvoltat",
    "dezvoltații": "dezvoltat",
    "dezvoltaților": "dezvoltat",
    "dezvoltato": "dezvoltat",
    "dezvoltatul": "dezvoltat",
    "dezvoltatule": "dezvoltat",
    "dezvoltatului": "dezvoltat",
    "diabetul": "diabet",
    "diabetule": "diabet",
    "diabetului": "diabet",
    "diabeturi": "diabet",
    "diabeturile": "diabet",
    "diabeturilor": "diabet",
    "diabetica": "diabetic",
    "diabetică": "diabetic",
    "diabetice": "diabetic",
    "diabeticei": "diabetic",
    "diabeticele": "diabetic",
    "diabeticelor": "diabetic",
    "diabetici": "diabetic",
    "diabeticii": "diabetic",
    "diabeticilor": "diabetic",
    "diabetico": "diabetic",
    "diabeticul": "diabetic",
    "diabeticule": "diabetic",
    "diabeticului": "diabetic",
    "diabolica": "diabolic",
    "diabolică": "diabolic",
    "diabolice": "diabolic",
    "diabolicei": "diabolic",
    "diabolicele": "diabolic",
    "diabolicelor": "diabolic",
    "diabolici": "diabolic",
    "diabolicii": "diabolic",
    "diabolicilor": "diabolic",
    "diabolico": "diabolic",
    "diabolicul": "diabolic",
    "diabolicule": "diabolic",
    "diabolicului": "diabolic",
    "diaconi": "diacon",
    "diaconii": "diacon",
    "diaconilor": "diacon",
    "diaconul": "diacon",
    "diaconule": "diacon",
    "diaconului": "diacon",
    "diacritice": "diacritic",
    "diacriticele": "diacritic",
    "diacriticelor": "diacritic",
    "diacriticul": "diacritic",
    "diacriticule": "diacritic",
    "diacriticului": "diacritic",
    "diacronica": "diacronic",
    "diacronică": "diacronic",
    "diacronice": "diacronic",
    "diacronicei": "diacronic",
    "diacronicele": "diacronic",
    "diacronicelor": "diacronic",
    "diacronici": "diacronic",
    "diacronicii": "diacronic",
    "diacronicilor": "diacronic",
    "diacronico": "diacronic",
    "diacronicul": "diacronic",
    "diacronicule": "diacronic",
    "diacronicului": "diacronic",
    "diadema": "diademă",
    "diademe": "diademă",
    "diademei": "diademă",
    "diademele": "diademă",
    "diademelor": "diademă",
    "diademo": "diademă",
    "diafana": "diafan",
    "diafană": "diafan",
    "diafane": "diafan",
    "diafanei": "diafan",
    "diafanele": "diafan",
    "diafanelor": "diafan",
    "diafani": "diafan",
    "diafanii": "diafan",
    "diafanilor": "diafan",
    "diafano": "diafan",
    "diafanul": "diafan",
    "diafanule": "diafan",
    "diafanului": "diafan",
    "diafaniză": "diafaniza",
    "diafanizai": "diafaniza",
    "diafanizam": "diafaniza",
    "diafanizăm": "diafaniza",
    "diafanizând": "diafaniza",
    "diafanizându": "diafaniza",
    "diafanizară": "diafaniza",
    "diafanizarăm": "diafaniza",
    "diafanizarăți": "diafaniza",
    "diafanizase": "diafaniza",
    "diafanizasem": "diafaniza",
    "diafanizaseră": "diafaniza",
    "diafanizaserăm": "diafaniza",
    "diafanizaserăți": "diafaniza",
    "diafanizaseși": "diafaniza",
    "diafanizași": "diafaniza",
    "diafanizat": "diafaniza",
    "diafanizați": "diafaniza",
    "diafanizatu": "diafaniza",
    "diafanizau": "diafaniza",
    "diafanizează": "diafaniza",
    "diafanizez": "diafaniza",
    "diafanizeze": "diafaniza",
    "diafanizezi": "diafaniza",
    "nediafanizând": "diafaniza",
    "nediafanizându": "diafaniza",
    "nemaidiafanizând": "diafaniza",
    "nemaidiafanizându": "diafaniza",
    "diafanizată": "diafanizat",
    "diafanizate": "diafanizat",
    "diafanizați": "diafanizat",
    "diafragma": "diafragmă",
    "diafragme": "diafragmă",
    "diafragmei": "diafragmă",
    "diafragmele": "diafragmă",
    "diafragmelor": "diafragmă",
    "diafragmo": "diafragmă",
    "diagnostice": "diagnostic",
    "diagnosticele": "diagnostic",
    "diagnosticelor": "diagnostic",
    "diagnosticul": "diagnostic",
    "diagnosticule": "diagnostic",
    "diagnosticului": "diagnostic",
    "diagnostică": "diagnostica",
    "diagnosticai": "diagnostica",
    "diagnosticam": "diagnostica",
    "diagnosticăm": "diagnostica",
    "diagnosticând": "diagnostica",
    "diagnosticându": "diagnostica",
    "diagnosticară": "diagnostica",
    "diagnosticarăm": "diagnostica",
    "diagnosticarăți": "diagnostica",
    "diagnosticase": "diagnostica",
    "diagnosticasem": "diagnostica",
    "diagnosticaseră": "diagnostica",
    "diagnosticaserăm": "diagnostica",
    "diagnosticaserăți": "diagnostica",
    "diagnosticaseși": "diagnostica",
    "diagnosticași": "diagnostica",
    "diagnosticat": "diagnostica",
    "diagnosticați": "diagnostica",
    "diagnosticatu": "diagnostica",
    "diagnosticau": "diagnostica",
    "diagnostichează": "diagnostica",
    "diagnostichez": "diagnostica",
    "diagnosticheze": "diagnostica",
    "diagnostichezi": "diagnostica",
    "nediagnosticând": "diagnostica",
    "nediagnosticându": "diagnostica",
    "nemaidiagnosticând": "diagnostica",
    "nemaidiagnosticându": "diagnostica",
    "diagnosticată": "diagnosticat",
    "diagnosticate": "diagnosticat",
    "diagnosticați": "diagnosticat",
    "diagnosticianul": "diagnostician",
    "diagnosticianule": "diagnostician",
    "diagnosticianului": "diagnostician",
    "diagnosticieni": "diagnostician",
    "diagnosticienii": "diagnostician",
    "diagnosticienilor": "diagnostician",
    "diagnosticiana": "diagnosticiană",
    "diagnosticiano": "diagnosticiană",
    "diagnosticiene": "diagnosticiană",
    "diagnosticienei": "diagnosticiană",
    "diagnosticienele": "diagnosticiană",
    "diagnosticienelor": "diagnosticiană",
    "diagnoza": "diagnoză",
    "diagnoze": "diagnoză",
    "diagnozei": "diagnoză",
    "diagnozele": "diagnoză",
    "diagnozelor": "diagnoză",
    "diagnozo": "diagnoză",
    "diagonala": "diagonal",
    "diagonală": "diagonal",
    "diagonale": "diagonal",
    "diagonalei": "diagonal",
    "diagonalele": "diagonal",
    "diagonalelor": "diagonal",
    "diagonali": "diagonal",
    "diagonalii": "diagonal",
    "diagonalilor": "diagonal",
    "diagonalo": "diagonal",
    "diagonalul": "diagonal",
    "diagonalule": "diagonal",
    "diagonalului": "diagonal",
    "diagonala": "diagonală",
    "diagonale": "diagonală",
    "diagonalei": "diagonală",
    "diagonalele": "diagonală",
    "diagonalelor": "diagonală",
    "diagonalo": "diagonală",
    "diagrama": "diagramă",
    "diagrame": "diagramă",
    "diagramei": "diagramă",
    "diagramele": "diagramă",
    "diagramelor": "diagramă",
    "diagramo": "diagramă",
    "dial.": "dialect",
    "dialecte": "dialect",
    "dialectele": "dialect",
    "dialectelor": "dialect",
    "dialectul": "dialect",
    "dialectule": "dialect",
    "dialectului": "dialect",
    "dialectică": "dialectic",
    "dialectice": "dialectic",
    "dialecticei": "dialectic",
    "dialecticele": "dialectic",
    "dialecticelor": "dialectic",
    "dialectici": "dialectic",
    "dialectica": "dialectică",
    "dialecticele": "dialectică",
    "dialectici": "dialectică",
    "dialecticii": "dialectică",
    "dialecticilor": "dialectică",
    "dialecticianul": "dialectician",
    "dialecticianului": "dialectician",
    "dialecticieni": "dialectician",
    "dialecticienii": "dialectician",
    "dialecticienilor": "dialectician",
    "dialectologi": "dialectolog",
    "dialectologii": "dialectolog",
    "dialectologilor": "dialectolog",
    "dialectologul": "dialectolog",
    "dialectologule": "dialectolog",
    "dialectologului": "dialectolog",
    "dialectologa": "dialectologă",
    "dialectologe": "dialectologă",
    "dialectologei": "dialectologă",
    "dialectologele": "dialectologă",
    "dialectologelor": "dialectologă",
    "dialectologo": "dialectologă",
    "dialectologica": "dialectologic",
    "dialectologică": "dialectologic",
    "dialectologice": "dialectologic",
    "dialectologicei": "dialectologic",
    "dialectologicele": "dialectologic",
    "dialectologicelor": "dialectologic",
    "dialectologici": "dialectologic",
    "dialectologicii": "dialectologic",
    "dialectologicilor": "dialectologic",
    "dialectologico": "dialectologic",
    "dialectologicul": "dialectologic",
    "dialectologicule": "dialectologic",
    "dialectologicului": "dialectologic",
    "dialipetala": "dialipetal",
    "dialipetală": "dialipetal",
    "dialipetale": "dialipetal",
    "dialipetalei": "dialipetal",
    "dialipetalele": "dialipetal",
    "dialipetalelor": "dialipetal",
    "dialipetali": "dialipetal",
    "dialipetalii": "dialipetal",
    "dialipetalilor": "dialipetal",
    "dialipetalo": "dialipetal",
    "dialipetalul": "dialipetal",
    "dialipetalule": "dialipetal",
    "dialipetalului": "dialipetal",
    "dialisepala": "dialisepal",
    "dialisepală": "dialisepal",
    "dialisepale": "dialisepal",
    "dialisepalei": "dialisepal",
    "dialisepalele": "dialisepal",
    "dialisepalelor": "dialisepal",
    "dialisepali": "dialisepal",
    "dialisepalii": "dialisepal",
    "dialisepalilor": "dialisepal",
    "dialisepalo": "dialisepal",
    "dialisepalul": "dialisepal",
    "dialisepalule": "dialisepal",
    "dialisepalului": "dialisepal",
    "dializa": "dializă",
    "dialize": "dializă",
    "dializei": "dializă",
    "dializele": "dializă",
    "dializelor": "dializă",
    "dializo": "dializă",
    "dialogul": "dialog",
    "dialogule": "dialog",
    "dialogului": "dialog",
    "dialoguri": "dialog",
    "dialogurile": "dialog",
    "dialogurilor": "dialog",
    "dialogă": "dialoga",
    "dialogai": "dialoga",
    "dialogam": "dialoga",
    "dialogăm": "dialoga",
    "dialogând": "dialoga",
    "dialogându": "dialoga",
    "dialogară": "dialoga",
    "dialogarăm": "dialoga",
    "dialogarăți": "dialoga",
    "dialogase": "dialoga",
    "dialogasem": "dialoga",
    "dialogaseră": "dialoga",
    "dialogaserăm": "dialoga",
    "dialogaserăți": "dialoga",
    "dialogaseși": "dialoga",
    "dialogași": "dialoga",
    "dialogat": "dialoga",
    "dialogați": "dialoga",
    "dialogatu": "dialoga",
    "dialogau": "dialoga",
    "dialoghează": "dialoga",
    "dialoghez": "dialoga",
    "dialogheze": "dialoga",
    "dialoghezi": "dialoga",
    "nedialogând": "dialoga",
    "nedialogându": "dialoga",
    "nemaidialogând": "dialoga",
    "nemaidialogându": "dialoga",
    "dialogata": "dialogat",
    "dialogată": "dialogat",
    "dialogate": "dialogat",
    "dialogatei": "dialogat",
    "dialogatele": "dialogat",
    "dialogatelor": "dialogat",
    "dialogați": "dialogat",
    "dialogații": "dialogat",
    "dialogaților": "dialogat",
    "dialogato": "dialogat",
    "dialogatul": "dialogat",
    "dialogatule": "dialogat",
    "dialogatului": "dialogat",
    "diamagnetica": "diamagnetic",
    "diamagnetică": "diamagnetic",
    "diamagnetice": "diamagnetic",
    "diamagneticei": "diamagnetic",
    "diamagneticele": "diamagnetic",
    "diamagneticelor": "diamagnetic",
    "diamagnetici": "diamagnetic",
    "diamagneticii": "diamagnetic",
    "diamagneticilor": "diamagnetic",
    "diamagnetico": "diamagnetic",
    "diamagneticul": "diamagnetic",
    "diamagneticule": "diamagnetic",
    "diamagneticului": "diamagnetic",
    "diamante": "diamant",
    "diamantele": "diamant",
    "diamantelor": "diamant",
    "diamantul": "diamant",
    "diamantule": "diamant",
    "diamantului": "diamant",
    "diamantifera": "diamantifer",
    "diamantiferă": "diamantifer",
    "diamantifere": "diamantifer",
    "diamantiferei": "diamantifer",
    "diamantiferele": "diamantifer",
    "diamantiferelor": "diamantifer",
    "diamantiferi": "diamantifer",
    "diamantiferii": "diamantifer",
    "diamantiferilor": "diamantifer",
    "diamantifero": "diamantifer",
    "diamantiferul": "diamantifer",
    "diamantiferule": "diamantifer",
    "diamantiferului": "diamantifer",
    "diamantina": "diamantin",
    "diamantină": "diamantin",
    "diamantine": "diamantin",
    "diamantinei": "diamantin",
    "diamantinele": "diamantin",
    "diamantinelor": "diamantin",
    "diamantini": "diamantin",
    "diamantinii": "diamantin",
    "diamantinilor": "diamantin",
    "diamantino": "diamantin",
    "diamantinul": "diamantin",
    "diamantinule": "diamantin",
    "diamantinului": "diamantin",
    "diametrala": "diametral",
    "diametrală": "diametral",
    "diametrale": "diametral",
    "diametralei": "diametral",
    "diametralele": "diametral",
    "diametralelor": "diametral",
    "diametrali": "diametral",
    "diametralii": "diametral",
    "diametralilor": "diametral",
    "diametralo": "diametral",
    "diametralul": "diametral",
    "diametralule": "diametral",
    "diametralului": "diametral",
    "diametre": "diametru",
    "diametrele": "diametru",
    "diametrelor": "diametru",
    "diametrul": "diametru",
    "diametrule": "diametru",
    "diametrului": "diametru",
    "Dianei": "Diana",
    "diapazoane": "diapazon",
    "diapazoanele": "diapazon",
    "diapazoanelor": "diapazon",
    "diapazonul": "diapazon",
    "diapazonule": "diapazon",
    "diapazonului": "diapazon",
    "diapozitive": "diapozitiv",
    "diapozitivele": "diapozitiv",
    "diapozitivelor": "diapozitiv",
    "diapozitivul": "diapozitiv",
    "diapozitivule": "diapozitiv",
    "diapozitivului": "diapozitiv",
    "diareea": "diaree",
    "diareei": "diaree",
    "diareeo": "diaree",
    "diareii": "diaree",
    "diareile": "diaree",
    "diareilor": "diaree",
    "diastaza": "diastază",
    "diastaze": "diastază",
    "diastazei": "diastază",
    "diastazele": "diastază",
    "diastazelor": "diastază",
    "diastazo": "diastază",
    "diastola": "diastolă",
    "diastole": "diastolă",
    "diastolei": "diastolă",
    "diastolele": "diastolă",
    "diastolelor": "diastolă",
    "diastolo": "diastolă",
    "diastolica": "diastolic",
    "diastolică": "diastolic",
    "diastolice": "diastolic",
    "diastolicei": "diastolic",
    "diastolicele": "diastolic",
    "diastolicelor": "diastolic",
    "diastolici": "diastolic",
    "diastolicii": "diastolic",
    "diastolicilor": "diastolic",
    "diastolico": "diastolic",
    "diastolicul": "diastolic",
    "diastolicule": "diastolic",
    "diastolicului": "diastolic",
    "diata": "diată",
    "diate": "diată",
    "diatei": "diată",
    "diatele": "diată",
    "diatelor": "diată",
    "diato": "diată",
    "diatermia": "diatermie",
    "diatermiei": "diatermie",
    "diatermii": "diatermie",
    "diatermiile": "diatermie",
    "diatermiilor": "diatermie",
    "diatermio": "diatermie",
    "diateza": "diateză",
    "diateze": "diateză",
    "diatezei": "diateză",
    "diatezele": "diateză",
    "diatezelor": "diateză",
    "diatezo": "diateză",
    "diatomeea": "diatomee",
    "diatomeei": "diatomee",
    "diatomeele": "diatomee",
    "diatomeelor": "diatomee",
    "diatomeeo": "diatomee",
    "diavoli": "diavol",
    "diavolii": "diavol",
    "diavolilor": "diavol",
    "diavolul": "diavol",
    "diavolule": "diavol",
    "diavolului": "diavol",
    "dibace": "dibaci",
    "dibacea": "dibaci",
    "dibacei": "dibaci",
    "dibacele": "dibaci",
    "dibacelor": "dibaci",
    "dibaceo": "dibaci",
    "dibacii": "dibaci",
    "dibacilor": "dibaci",
    "dibaciul": "dibaci",
    "dibaciule": "dibaci",
    "dibaciului": "dibaci",
    "dibăcea": "dibăci",
    "dibăceai": "dibăci",
    "dibăceam": "dibăci",
    "dibăcească": "dibăci",
    "dibăceați": "dibăci",
    "dibăceau": "dibăci",
    "dibăcesc": "dibăci",
    "dibăcește": "dibăci",
    "dibăcești": "dibăci",
    "dibăcii": "dibăci",
    "dibăcim": "dibăci",
    "dibăcind": "dibăci",
    "dibăcindu": "dibăci",
    "dibăciră": "dibăci",
    "dibăcirăm": "dibăci",
    "dibăcirăți": "dibăci",
    "dibăcise": "dibăci",
    "dibăcisem": "dibăci",
    "dibăciseră": "dibăci",
    "dibăciserăm": "dibăci",
    "dibăciserăți": "dibăci",
    "dibăciseși": "dibăci",
    "dibăciși": "dibăci",
    "dibăcit": "dibăci",
    "dibăciți": "dibăci",
    "dibăcitu": "dibăci",
    "nedibăcind": "dibăci",
    "nedibăcindu": "dibăci",
    "nemaidibăcind": "dibăci",
    "nemaidibăcindu": "dibăci",
    "dibăcia": "dibăcie",
    "dibăciei": "dibăcie",
    "dibăcii": "dibăcie",
    "dibăciile": "dibăcie",
    "dibăciilor": "dibăcie",
    "dibăcio": "dibăcie",
    "dibăcită": "dibăcit",
    "dibăcite": "dibăcit",
    "dibăciți": "dibăcit",
    "dibla": "diblă",
    "dible": "diblă",
    "diblei": "diblă",
    "diblele": "diblă",
    "diblelor": "diblă",
    "diblo": "diblă",
    "diblul": "diblu",
    "diblule": "diblu",
    "diblului": "diblu",
    "dibluri": "diblu",
    "diblurile": "diblu",
    "diblurilor": "diblu",
    "dibuia": "dibui",
    "dibuiai": "dibui",
    "dibuiam": "dibui",
    "dibuiați": "dibui",
    "dibuiau": "dibui",
    "dibuie": "dibui",
    "dibuii": "dibui",
    "dibuim": "dibui",
    "dibuind": "dibui",
    "dibuindu": "dibui",
    "dibuiră": "dibui",
    "dibuirăm": "dibui",
    "dibuirăți": "dibui",
    "dibuise": "dibui",
    "dibuisem": "dibui",
    "dibuiseră": "dibui",
    "dibuiserăm": "dibui",
    "dibuiserăți": "dibui",
    "dibuiseși": "dibui",
    "dibuiși": "dibui",
    "dibuit": "dibui",
    "dibuiți": "dibui",
    "dibuitu": "dibui",
    "nedibuind": "dibui",
    "nedibuindu": "dibui",
    "nemaidibuind": "dibui",
    "nemaidibuindu": "dibui",
    "dibuiala": "dibuială",
    "dibuialo": "dibuială",
    "dibuieli": "dibuială",
    "dibuielii": "dibuială",
    "dibuielile": "dibuială",
    "dibuielilor": "dibuială",
    "dibuirea": "dibuire",
    "dibuireo": "dibuire",
    "dibuiri": "dibuire",
    "dibuirii": "dibuire",
    "dibuirile": "dibuire",
    "dibuirilor": "dibuire",
    "dibuită": "dibuit",
    "dibuite": "dibuit",
    "dibuitele": "dibuit",
    "dibuitelor": "dibuit",
    "dibuiți": "dibuit",
    "dibuitul": "dibuit",
    "dibuitule": "dibuit",
    "dibuitului": "dibuit",
    "dichisul": "dichis",
    "dichisule": "dichis",
    "dichisului": "dichis",
    "dichisuri": "dichis",
    "dichisurile": "dichis",
    "dichisurilor": "dichis",
    "dichiseala": "dichiseală",
    "dichisealo": "dichiseală",
    "dichiseli": "dichiseală",
    "dichiselii": "dichiseală",
    "dichiselile": "dichiseală",
    "dichiselilor": "dichiseală",
    "dichisea": "dichisi",
    "dichiseai": "dichisi",
    "dichiseam": "dichisi",
    "dichisească": "dichisi",
    "dichiseați": "dichisi",
    "dichiseau": "dichisi",
    "dichisesc": "dichisi",
    "dichisește": "dichisi",
    "dichisești": "dichisi",
    "dichisii": "dichisi",
    "dichisim": "dichisi",
    "dichisind": "dichisi",
    "dichisindu": "dichisi",
    "dichisiră": "dichisi",
    "dichisirăm": "dichisi",
    "dichisirăți": "dichisi",
    "dichisise": "dichisi",
    "dichisisem": "dichisi",
    "dichisiseră": "dichisi",
    "dichisiserăm": "dichisi",
    "dichisiserăți": "dichisi",
    "dichisiseși": "dichisi",
    "dichisiși": "dichisi",
    "dichisit": "dichisi",
    "dichisiți": "dichisi",
    "dichisitu": "dichisi",
    "nedichisind": "dichisi",
    "nedichisindu": "dichisi",
    "nemaidichisind": "dichisi",
    "nemaidichisindu": "dichisi",
    "dichisirea": "dichisire",
    "dichisireo": "dichisire",
    "dichisiri": "dichisire",
    "dichisirii": "dichisire",
    "dichisirile": "dichisire",
    "dichisirilor": "dichisire",
    "dichisita": "dichisit",
    "dichisită": "dichisit",
    "dichisite": "dichisit",
    "dichisitei": "dichisit",
    "dichisitele": "dichisit",
    "dichisitelor": "dichisit",
    "dichisiți": "dichisit",
    "dichisiții": "dichisit",
    "dichisiților": "dichisit",
    "dichisito": "dichisit",
    "dichisitul": "dichisit",
    "dichisitule": "dichisit",
    "dichisitului": "dichisit",
    "diciplinara": "diciplinar",
    "diciplinară": "diciplinar",
    "diciplinare": "diciplinar",
    "diciplinarei": "diciplinar",
    "diciplinarele": "diciplinar",
    "diciplinarelor": "diciplinar",
    "diciplinari": "diciplinar",
    "diciplinarii": "diciplinar",
    "diciplinarilor": "diciplinar",
    "diciplinaro": "diciplinar",
    "diciplinarul": "diciplinar",
    "diciplinarule": "diciplinar",
    "diciplinarului": "diciplinar",
    "dicotiledonata": "dicotiledonat",
    "dicotiledonată": "dicotiledonat",
    "dicotiledonate": "dicotiledonat",
    "dicotiledonatei": "dicotiledonat",
    "dicotiledonatele": "dicotiledonat",
    "dicotiledonatelor": "dicotiledonat",
    "dicotiledonați": "dicotiledonat",
    "dicotiledonații": "dicotiledonat",
    "dicotiledonaților": "dicotiledonat",
    "dicotiledonato": "dicotiledonat",
    "dicotiledonatul": "dicotiledonat",
    "dicotiledonatule": "dicotiledonat",
    "dicotiledonatului": "dicotiledonat",
    "dictă": "dicta",
    "dictai": "dicta",
    "dictam": "dicta",
    "dictăm": "dicta",
    "dictând": "dicta",
    "dictându": "dicta",
    "dictară": "dicta",
    "dictarăm": "dicta",
    "dictarăți": "dicta",
    "dictase": "dicta",
    "dictasem": "dicta",
    "dictaseră": "dicta",
    "dictaserăm": "dicta",
    "dictaserăți": "dicta",
    "dictaseși": "dicta",
    "dictași": "dicta",
    "dictat": "dicta",
    "dictați": "dicta",
    "dictatu": "dicta",
    "dictau": "dicta",
    "dictează": "dicta",
    "dictez": "dicta",
    "dicteze": "dicta",
    "dictezi": "dicta",
    "nedictând": "dicta",
    "nedictându": "dicta",
    "nemaidictând": "dicta",
    "nemaidictându": "dicta",
    "dictarea": "dictare",
    "dictareo": "dictare",
    "dictări": "dictare",
    "dictării": "dictare",
    "dictările": "dictare",
    "dictărilor": "dictare",
    "dictată": "dictat",
    "dictate": "dictat",
    "dictatele": "dictat",
    "dictatelor": "dictat",
    "dictați": "dictat",
    "dictatul": "dictat",
    "dictatule": "dictat",
    "dictatului": "dictat",
    "dictatori": "dictator",
    "dictatorii": "dictator",
    "dictatorilor": "dictator",
    "dictatorul": "dictator",
    "dictatorule": "dictator",
    "dictatorului": "dictator",
    "dictatoriala": "dictatorial",
    "dictatorială": "dictatorial",
    "dictatoriale": "dictatorial",
    "dictatorialei": "dictatorial",
    "dictatorialele": "dictatorial",
    "dictatorialelor": "dictatorial",
    "dictatoriali": "dictatorial",
    "dictatorialii": "dictatorial",
    "dictatorialilor": "dictatorial",
    "dictatorialo": "dictatorial",
    "dictatorialul": "dictatorial",
    "dictatorialule": "dictatorial",
    "dictatorialului": "dictatorial",
    "dictatura": "dictatură",
    "dictaturi": "dictatură",
    "dictaturii": "dictatură",
    "dictaturile": "dictatură",
    "dictaturilor": "dictatură",
    "dictaturo": "dictatură",
    "dicteul": "dicteu",
    "dicteule": "dicteu",
    "dicteului": "dicteu",
    "dicteuri": "dicteu",
    "dicteurile": "dicteu",
    "dicteurilor": "dicteu",
    "dicția": "dicție",
    "dicției": "dicție",
    "dicții": "dicție",
    "dicțiile": "dicție",
    "dicțiilor": "dicție",
    "dicțio": "dicție",
    "dicționare": "dicționar",
    "dicționarele": "dicționar",
    "dicționarelor": "dicționar",
    "dicționarul": "dicționar",
    "dicționarule": "dicționar",
    "dicționarului": "dicționar",
    "dicțiunea": "dicțiune",
    "dicțiuneo": "dicțiune",
    "dicțiuni": "dicțiune",
    "dicțiunii": "dicțiune",
    "dicțiunile": "dicțiune",
    "dicțiunilor": "dicțiune",
    "dictoane": "dicton",
    "dictoanele": "dicton",
    "dictoanelor": "dicton",
    "dictonul": "dicton",
    "dictonule": "dicton",
    "dictonului": "dicton",
    "Didei": "Dida",
    "didactica": "didactic",
    "didactică": "didactic",
    "didactice": "didactic",
    "didacticei": "didactic",
    "didacticele": "didactic",
    "didacticelor": "didactic",
    "didactici": "didactic",
    "didacticii": "didactic",
    "didacticilor": "didactic",
    "didactico": "didactic",
    "didacticul": "didactic",
    "didacticule": "didactic",
    "didacticului": "didactic",
    "didactica": "didactică",
    "didacticele": "didactică",
    "didactici": "didactică",
    "didacticii": "didactică",
    "didacticilor": "didactică",
    "didactico": "didactică",
    "Didaskaliile": "Didaskalie",
    "dieceza": "dieceză",
    "dieceze": "dieceză",
    "diecezei": "dieceză",
    "diecezele": "dieceză",
    "diecezelor": "dieceză",
    "diecezo": "dieceză",
    "diedre": "diedru",
    "diedrele": "diedru",
    "diedrelor": "diedru",
    "diedrul": "diedru",
    "diedrule": "diedru",
    "diedrului": "diedru",
    "dielectrica": "dielectric",
    "dielectrică": "dielectric",
    "dielectrice": "dielectric",
    "dielectricei": "dielectric",
    "dielectricele": "dielectric",
    "dielectricelor": "dielectric",
    "dielectrici": "dielectric",
    "dielectricii": "dielectric",
    "dielectricilor": "dielectric",
    "dielectrico": "dielectric",
    "dielectricul": "dielectric",
    "dielectricule": "dielectric",
    "dielectricului": "dielectric",
    "diereza": "diereză",
    "diereze": "diereză",
    "dierezei": "diereză",
    "dierezele": "diereză",
    "dierezelor": "diereză",
    "dierezo": "diereză",
    "diesele": "diesel",
    "dieselele": "diesel",
    "dieselelor": "diesel",
    "dieselul": "diesel",
    "dieselule": "diesel",
    "dieselului": "diesel",
    "dieta": "dietă",
    "diete": "dietă",
    "dietei": "dietă",
    "dietele": "dietă",
    "dietelor": "dietă",
    "dieto": "dietă",
    "dietetica": "dietetic",
    "dietetică": "dietetic",
    "dietetice": "dietetic",
    "dieteticei": "dietetic",
    "dieteticele": "dietetic",
    "dieteticelor": "dietetic",
    "dietetici": "dietetic",
    "dieteticii": "dietetic",
    "dieteticilor": "dietetic",
    "dietetico": "dietetic",
    "dieteticul": "dietetic",
    "dieteticule": "dietetic",
    "dieteticului": "dietetic",
    "dietetica": "dietetică",
    "dieteticele": "dietetică",
    "dietetici": "dietetică",
    "dieteticii": "dietetică",
    "dieteticilor": "dietetică",
    "dietetico": "dietetică",
    "diezi": "diez",
    "diezii": "diez",
    "diezilor": "diez",
    "diezul": "diez",
    "diezule": "diez",
    "diezului": "diez",
    "diferende": "diferend",
    "diferendele": "diferend",
    "diferendelor": "diferend",
    "diferendul": "diferend",
    "diferendule": "diferend",
    "diferendului": "diferend",
    "diferența": "diferență",
    "diferențe": "diferență",
    "diferenței": "diferență",
    "diferențele": "diferență",
    "diferențelor": "diferență",
    "diferențo": "diferență",
    "diferențiai": "diferenția",
    "diferențiam": "diferenția",
    "diferențiară": "diferenția",
    "diferențiarăm": "diferenția",
    "diferențiarăți": "diferenția",
    "diferențiase": "diferenția",
    "diferențiasem": "diferenția",
    "diferențiaseră": "diferenția",
    "diferențiaserăm": "diferenția",
    "diferențiaserăți": "diferenția",
    "diferențiaseși": "diferenția",
    "diferențiași": "diferenția",
    "diferențiat": "diferenția",
    "diferențiați": "diferenția",
    "diferențiatu": "diferenția",
    "diferențiau": "diferenția",
    "diferențiază": "diferenția",
    "diferenție": "diferenția",
    "diferențiem": "diferenția",
    "diferențiez": "diferenția",
    "diferențieze": "diferenția",
    "diferențiezi": "diferenția",
    "diferențiind": "diferenția",
    "diferențiindu": "diferenția",
    "nediferențiind": "diferenția",
    "nediferențiindu": "diferenția",
    "nemaidiferențiind": "diferenția",
    "nemaidiferențiindu": "diferenția",
    "diferențiala": "diferențial",
    "diferențială": "diferențial",
    "diferențiale": "diferențial",
    "diferențialei": "diferențial",
    "diferențialele": "diferențial",
    "diferențialelor": "diferențial",
    "diferențiali": "diferențial",
    "diferențialii": "diferențial",
    "diferențialilor": "diferențial",
    "diferențialo": "diferențial",
    "diferențialul": "diferențial",
    "diferențialule": "diferențial",
    "diferențialului": "diferențial",
    "diferențiala": "diferențială",
    "diferențiale": "diferențială",
    "diferențialei": "diferențială",
    "diferențialele": "diferențială",
    "diferențialelor": "diferențială",
    "diferențialo": "diferențială",
    "diferențiată": "diferențiat",
    "diferențiate": "diferențiat",
    "diferențiați": "diferențiat",
    "diferențierea": "diferențiere",
    "diferențiereo": "diferențiere",
    "diferențieri": "diferențiere",
    "diferențierii": "diferențiere",
    "diferențierile": "diferențiere",
    "diferențierilor": "diferențiere",
    "difer": "diferi",
    "diferă": "diferi",
    "difere": "diferi",
    "diferea": "diferi",
    "difereai": "diferi",
    "difeream": "diferi",
    "difereați": "diferi",
    "difereau": "diferi",
    "diferii": "diferi",
    "diferim": "diferi",
    "diferind": "diferi",
    "diferindu": "diferi",
    "diferiră": "diferi",
    "diferirăm": "diferi",
    "diferirăți": "diferi",
    "diferise": "diferi",
    "diferisem": "diferi",
    "diferiseră": "diferi",
    "diferiserăm": "diferi",
    "diferiserăți": "diferi",
    "diferiseși": "diferi",
    "diferiși": "diferi",
    "diferit": "diferi",
    "diferiți": "diferi",
    "diferitu": "diferi",
    "nediferind": "diferi",
    "nediferindu": "diferi",
    "nemaidiferind": "diferi",
    "nemaidiferindu": "diferi",
    "diferita": "diferit",
    "diferită": "diferit",
    "diferite": "diferit",
    "diferitei": "diferit",
    "diferitele": "diferit",
    "diferitelor": "diferit",
    "diferiți": "diferit",
    "diferiții": "diferit",
    "diferiților": "diferit",
    "diferito": "diferit",
    "diferitul": "diferit",
    "diferitule": "diferit",
    "diferitului": "diferit",
    "dificila": "dificil",
    "dificilă": "dificil",
    "dificile": "dificil",
    "dificilei": "dificil",
    "dificilele": "dificil",
    "dificilelor": "dificil",
    "dificili": "dificil",
    "dificilii": "dificil",
    "dificililor": "dificil",
    "dificilo": "dificil",
    "dificilul": "dificil",
    "dificilule": "dificil",
    "dificilului": "dificil",
    "dificultatea": "dificultate",
    "dificultateo": "dificultate",
    "dificultăți": "dificultate",
    "dificultății": "dificultate",
    "dificultățile": "dificultate",
    "dificultăților": "dificultate",
    "diforma": "diform",
    "diformă": "diform",
    "diforme": "diform",
    "diformei": "diform",
    "diformele": "diform",
    "diformelor": "diform",
    "diformi": "diform",
    "diformii": "diform",
    "diformilor": "diform",
    "diformo": "diform",
    "diformul": "diform",
    "diformule": "diform",
    "diformului": "diform",
    "difract": "difracta",
    "difractă": "difracta",
    "difractai": "difracta",
    "difractam": "difracta",
    "difractăm": "difracta",
    "difractând": "difracta",
    "difractându": "difracta",
    "difractară": "difracta",
    "difractarăm": "difracta",
    "difractarăți": "difracta",
    "difractase": "difracta",
    "difractasem": "difracta",
    "difractaseră": "difracta",
    "difractaserăm": "difracta",
    "difractaserăți": "difracta",
    "difractaseși": "difracta",
    "difractași": "difracta",
    "difractat": "difracta",
    "difractați": "difracta",
    "difractatu": "difracta",
    "difractau": "difracta",
    "difracte": "difracta",
    "difracți": "difracta",
    "nedifractând": "difracta",
    "nedifractându": "difracta",
    "nemaidifractând": "difracta",
    "nemaidifractându": "difracta",
    "difractată": "difractat",
    "difractate": "difractat",
    "difractați": "difractat",
    "difracția": "difracție",
    "difracției": "difracție",
    "difracții": "difracție",
    "difracțiile": "difracție",
    "difracțiilor": "difracție",
    "difracțio": "difracție",
    "difterica": "difteric",
    "difterică": "difteric",
    "difterice": "difteric",
    "diftericei": "difteric",
    "diftericele": "difteric",
    "diftericelor": "difteric",
    "difterici": "difteric",
    "diftericii": "difteric",
    "diftericilor": "difteric",
    "difterico": "difteric",
    "diftericul": "difteric",
    "diftericule": "difteric",
    "diftericului": "difteric",
    "difteria": "difterie",
    "difteriei": "difterie",
    "difterii": "difterie",
    "difteriile": "difterie",
    "difteriilor": "difterie",
    "difterio": "difterie",
    "diftina": "diftină",
    "diftine": "diftină",
    "diftinei": "diftină",
    "diftinele": "diftină",
    "diftinelor": "diftină",
    "diftino": "diftină",
    "diftongi": "diftong",
    "diftongii": "diftong",
    "diftongilor": "diftong",
    "diftongul": "diftong",
    "diftongule": "diftong",
    "diftongului": "diftong",
    "diftongă": "diftonga",
    "diftongai": "diftonga",
    "diftongam": "diftonga",
    "diftongăm": "diftonga",
    "diftongând": "diftonga",
    "diftongându": "diftonga",
    "diftongară": "diftonga",
    "diftongarăm": "diftonga",
    "diftongarăți": "diftonga",
    "diftongase": "diftonga",
    "diftongasem": "diftonga",
    "diftongaseră": "diftonga",
    "diftongaserăm": "diftonga",
    "diftongaserăți": "diftonga",
    "diftongaseși": "diftonga",
    "diftongași": "diftonga",
    "diftongat": "diftonga",
    "diftongați": "diftonga",
    "diftongatu": "diftonga",
    "diftongau": "diftonga",
    "diftonghează": "diftonga",
    "diftonghez": "diftonga",
    "diftongheze": "diftonga",
    "diftonghezi": "diftonga",
    "nediftongând": "diftonga",
    "nediftongându": "diftonga",
    "nemaidiftongând": "diftonga",
    "nemaidiftongându": "diftonga",
    "diftongarea": "diftongare",
    "diftongareo": "diftongare",
    "diftongări": "diftongare",
    "diftongării": "diftongare",
    "diftongările": "diftongare",
    "diftongărilor": "diftongare",
    "diftongata": "diftongat",
    "diftongată": "diftongat",
    "diftongate": "diftongat",
    "diftongatei": "diftongat",
    "diftongatele": "diftongat",
    "diftongatelor": "diftongat",
    "diftongați": "diftongat",
    "diftongații": "diftongat",
    "diftongaților": "diftongat",
    "diftongato": "diftongat",
    "diftongatul": "diftongat",
    "diftongatule": "diftongat",
    "diftongatului": "diftongat",
    "difuza": "difuz",
    "difuză": "difuz",
    "difuze": "difuz",
    "difuzei": "difuz",
    "difuzele": "difuz",
    "difuzelor": "difuz",
    "difuzi": "difuz",
    "difuzii": "difuz",
    "difuzilor": "difuz",
    "difuzo": "difuz",
    "difuzul": "difuz",
    "difuzule": "difuz",
    "difuzului": "difuz",
    "difuză": "difuza",
    "difuzai": "difuza",
    "difuzam": "difuza",
    "difuzăm": "difuza",
    "difuzând": "difuza",
    "difuzându": "difuza",
    "difuzară": "difuza",
    "difuzarăm": "difuza",
    "difuzarăți": "difuza",
    "difuzase": "difuza",
    "difuzasem": "difuza",
    "difuzaseră": "difuza",
    "difuzaserăm": "difuza",
    "difuzaserăți": "difuza",
    "difuzaseși": "difuza",
    "difuzași": "difuza",
    "difuzat": "difuza",
    "difuzați": "difuza",
    "difuzatu": "difuza",
    "difuzau": "difuza",
    "difuzează": "difuza",
    "difuzez": "difuza",
    "difuzeze": "difuza",
    "difuzezi": "difuza",
    "nedifuzând": "difuza",
    "nedifuzându": "difuza",
    "nemaidifuzând": "difuza",
    "nemaidifuzându": "difuza",
    "difuzabila": "difuzabil",
    "difuzabilă": "difuzabil",
    "difuzabile": "difuzabil",
    "difuzabilei": "difuzabil",
    "difuzabilele": "difuzabil",
    "difuzabilelor": "difuzabil",
    "difuzabili": "difuzabil",
    "difuzabilii": "difuzabil",
    "difuzabililor": "difuzabil",
    "difuzabilo": "difuzabil",
    "difuzabilul": "difuzabil",
    "difuzabilule": "difuzabil",
    "difuzabilului": "difuzabil",
    "difuzarea": "difuzare",
    "difuzareo": "difuzare",
    "difuzări": "difuzare",
    "difuzării": "difuzare",
    "difuzările": "difuzare",
    "difuzărilor": "difuzare",
    "difuzată": "difuzat",
    "difuzate": "difuzat",
    "difuzați": "difuzat",
    "difuziunea": "difuziune",
    "difuziuneo": "difuziune",
    "difuziuni": "difuziune",
    "difuziunii": "difuziune",
    "difuziunile": "difuziune",
    "difuziunilor": "difuziune",
    "difuzoare": "difuzor",
    "difuzoarele": "difuzor",
    "difuzoarelor": "difuzor",
    "difuzori": "difuzor",
    "difuzorii": "difuzor",
    "difuzorilor": "difuzor",
    "difuzorul": "difuzor",
    "difuzorule": "difuzor",
    "difuzorului": "difuzor",
    "digul": "dig",
    "digule": "dig",
    "digului": "dig",
    "diguri": "dig",
    "digurile": "dig",
    "digurilor": "dig",
    "diger": "digera",
    "digeră": "digera",
    "digerai": "digera",
    "digeram": "digera",
    "digerăm": "digera",
    "digerând": "digera",
    "digerându": "digera",
    "digerară": "digera",
    "digerarăm": "digera",
    "digerarăți": "digera",
    "digerase": "digera",
    "digerasem": "digera",
    "digeraseră": "digera",
    "digeraserăm": "digera",
    "digeraserăți": "digera",
    "digeraseși": "digera",
    "digerași": "digera",
    "digerat": "digera",
    "digerați": "digera",
    "digeratu": "digera",
    "digerau": "digera",
    "digere": "digera",
    "digeri": "digera",
    "nedigerând": "digera",
    "nedigerându": "digera",
    "nemaidigerând": "digera",
    "nemaidigerându": "digera",
    "digerabila": "digerabil",
    "digerabilă": "digerabil",
    "digerabile": "digerabil",
    "digerabilei": "digerabil",
    "digerabilele": "digerabil",
    "digerabilelor": "digerabil",
    "digerabili": "digerabil",
    "digerabilii": "digerabil",
    "digerabililor": "digerabil",
    "digerabilo": "digerabil",
    "digerabilul": "digerabil",
    "digerabilule": "digerabil",
    "digerabilului": "digerabil",
    "digerarea": "digerare",
    "digerareo": "digerare",
    "digerări": "digerare",
    "digerării": "digerare",
    "digerările": "digerare",
    "digerărilor": "digerare",
    "digerată": "digerat",
    "digerate": "digerat",
    "digerați": "digerat",
    "digestia": "digestie",
    "digestiei": "digestie",
    "digestii": "digestie",
    "digestiile": "digestie",
    "digestiilor": "digestie",
    "digestio": "digestie",
    "digestiva": "digestiv",
    "digestivă": "digestiv",
    "digestive": "digestiv",
    "digestivei": "digestiv",
    "digestivele": "digestiv",
    "digestivelor": "digestiv",
    "digestivi": "digestiv",
    "digestivii": "digestiv",
    "digestivilor": "digestiv",
    "digestivo": "digestiv",
    "digestivul": "digestiv",
    "digestivule": "digestiv",
    "digestivului": "digestiv",
    "digitala": "digital",
    "digitală": "digital",
    "digitale": "digital",
    "digitalei": "digital",
    "digitalele": "digital",
    "digitalelor": "digital",
    "digitali": "digital",
    "digitalii": "digital",
    "digitalilor": "digital",
    "digitalo": "digital",
    "digitalul": "digital",
    "digitalule": "digital",
    "digitalului": "digital",
    "digitata": "digitat",
    "digitată": "digitat",
    "digitate": "digitat",
    "digitatei": "digitat",
    "digitatele": "digitat",
    "digitatelor": "digitat",
    "digitați": "digitat",
    "digitații": "digitat",
    "digitaților": "digitat",
    "digitato": "digitat",
    "digitatul": "digitat",
    "digitatule": "digitat",
    "digitatului": "digitat",
    "digitația": "digitație",
    "digitației": "digitație",
    "digitații": "digitație",
    "digitațiile": "digitație",
    "digitațiilor": "digitație",
    "digitațio": "digitație",
    "digitigrade": "digitigrad",
    "digitigradele": "digitigrad",
    "digitigradelor": "digitigrad",
    "digitigradul": "digitigrad",
    "digitigradule": "digitigrad",
    "digitigradului": "digitigrad",
    "digresiunea": "digresiune",
    "digresiuneo": "digresiune",
    "digresiuni": "digresiune",
    "digresiunii": "digresiune",
    "digresiunile": "digresiune",
    "digresiunilor": "digresiune",
    "dihania": "dihanie",
    "dihaniei": "dihanie",
    "dihăniei": "dihanie",
    "dihănii": "dihanie",
    "dihăniile": "dihanie",
    "dihăniilor": "dihanie",
    "dihanio": "dihanie",
    "dihonia": "dihonie",
    "dihoniei": "dihonie",
    "dihonii": "dihonie",
    "dihoniile": "dihonie",
    "dihoniilor": "dihonie",
    "dihonio": "dihonie",
    "dihori": "dihor",
    "dihorii": "dihor",
    "dihorilor": "dihor",
    "dihorul": "dihor",
    "dihorule": "dihor",
    "dihorului": "dihor",
    "dihotomica": "dihotomic",
    "dihotomică": "dihotomic",
    "dihotomice": "dihotomic",
    "dihotomicei": "dihotomic",
    "dihotomicele": "dihotomic",
    "dihotomicelor": "dihotomic",
    "dihotomici": "dihotomic",
    "dihotomicii": "dihotomic",
    "dihotomicilor": "dihotomic",
    "dihotomico": "dihotomic",
    "dihotomicul": "dihotomic",
    "dihotomicule": "dihotomic",
    "dihotomicului": "dihotomic",
    "dihotomică-antonimica": "dihotomic-antonimic",
    "dihotomică-antonimică": "dihotomic-antonimic",
    "dihotomică-antonimico": "dihotomic-antonimic",
    "dihotomic-antonimicul": "dihotomic-antonimic",
    "dihotomic-antonimicule": "dihotomic-antonimic",
    "dihotomic-antonimicului": "dihotomic-antonimic",
    "dihotomice-antonimice": "dihotomic-antonimic",
    "dihotomice-antonimicei": "dihotomic-antonimic",
    "dihotomice-antonimicele": "dihotomic-antonimic",
    "dihotomice-antonimicelor": "dihotomic-antonimic",
    "dihotomici-antonimici": "dihotomic-antonimic",
    "dihotomici-antonimicii": "dihotomic-antonimic",
    "dihotomici-antonimicilor": "dihotomic-antonimic",
    "dihotomia-antonimică": "dihotomie-antonimică",
    "dihotomiei-antonimice": "dihotomie-antonimică",
    "dihotomii-antonimice": "dihotomie-antonimică",
    "dihotomiile-antonimice": "dihotomie-antonimică",
    "dihotomiilor-antonimice": "dihotomie-antonimică",
    "dihotomio-antonimico": "dihotomie-antonimică",
    "dijma": "dijmă",
    "dijme": "dijmă",
    "dijmei": "dijmă",
    "dijmele": "dijmă",
    "dijmelor": "dijmă",
    "dijmo": "dijmă",
    "dijmuia": "dijmui",
    "dijmuiai": "dijmui",
    "dijmuiam": "dijmui",
    "dijmuiască": "dijmui",
    "dijmuiați": "dijmui",
    "dijmuiau": "dijmui",
    "dijmuiesc": "dijmui",
    "dijmuiește": "dijmui",
    "dijmuiești": "dijmui",
    "dijmuii": "dijmui",
    "dijmuim": "dijmui",
    "dijmuind": "dijmui",
    "dijmuindu": "dijmui",
    "dijmuiră": "dijmui",
    "dijmuirăm": "dijmui",
    "dijmuirăți": "dijmui",
    "dijmuise": "dijmui",
    "dijmuisem": "dijmui",
    "dijmuiseră": "dijmui",
    "dijmuiserăm": "dijmui",
    "dijmuiserăți": "dijmui",
    "dijmuiseși": "dijmui",
    "dijmuiși": "dijmui",
    "dijmuit": "dijmui",
    "dijmuiți": "dijmui",
    "dijmuitu": "dijmui",
    "nedijmuind": "dijmui",
    "nedijmuindu": "dijmui",
    "nemaidijmuind": "dijmui",
    "nemaidijmuindu": "dijmui",
    "dijmuiala": "dijmuială",
    "dijmuialo": "dijmuială",
    "dijmuieli": "dijmuială",
    "dijmuielii": "dijmuială",
    "dijmuielile": "dijmuială",
    "dijmuielilor": "dijmuială",
    "dijmuirea": "dijmuire",
    "dijmuireo": "dijmuire",
    "dijmuiri": "dijmuire",
    "dijmuirii": "dijmuire",
    "dijmuirile": "dijmuire",
    "dijmuirilor": "dijmuire",
    "dijmuită": "dijmuit",
    "dijmuite": "dijmuit",
    "dijmuiți": "dijmuit",
    "dijmuitul": "dijmuit",
    "dijmuitule": "dijmuit",
    "dijmuitului": "dijmuit",
    "dilat": "dilata",
    "dilată": "dilata",
    "dilatai": "dilata",
    "dilatam": "dilata",
    "dilatăm": "dilata",
    "dilatând": "dilata",
    "dilatându": "dilata",
    "dilatară": "dilata",
    "dilatarăm": "dilata",
    "dilatarăți": "dilata",
    "dilatase": "dilata",
    "dilatasem": "dilata",
    "dilataseră": "dilata",
    "dilataserăm": "dilata",
    "dilataserăți": "dilata",
    "dilataseși": "dilata",
    "dilatași": "dilata",
    "dilatat": "dilata",
    "dilatați": "dilata",
    "dilatatu": "dilata",
    "dilatau": "dilata",
    "dilate": "dilata",
    "dilatează": "dilata",
    "dilatez": "dilata",
    "dilateze": "dilata",
    "dilatezi": "dilata",
    "dilați": "dilata",
    "nedilatând": "dilata",
    "nedilatându": "dilata",
    "nemaidilatând": "dilata",
    "nemaidilatându": "dilata",
    "dilatabila": "dilatabil",
    "dilatabilă": "dilatabil",
    "dilatabile": "dilatabil",
    "dilatabilei": "dilatabil",
    "dilatabilele": "dilatabil",
    "dilatabilelor": "dilatabil",
    "dilatabili": "dilatabil",
    "dilatabilii": "dilatabil",
    "dilatabililor": "dilatabil",
    "dilatabilo": "dilatabil",
    "dilatabilul": "dilatabil",
    "dilatabilule": "dilatabil",
    "dilatabilului": "dilatabil",
    "dilatarea": "dilatare",
    "dilatareo": "dilatare",
    "dilatări": "dilatare",
    "dilatării": "dilatare",
    "dilatările": "dilatare",
    "dilatărilor": "dilatare",
    "dilatata": "dilatat",
    "dilatată": "dilatat",
    "dilatate": "dilatat",
    "dilatatei": "dilatat",
    "dilatatele": "dilatat",
    "dilatatelor": "dilatat",
    "dilatați": "dilatat",
    "dilatații": "dilatat",
    "dilataților": "dilatat",
    "dilatato": "dilatat",
    "dilatatul": "dilatat",
    "dilatatule": "dilatat",
    "dilatatului": "dilatat",
    "dilatația": "dilatație",
    "dilatației": "dilatație",
    "dilatații": "dilatație",
    "dilatațiile": "dilatație",
    "dilatațiilor": "dilatație",
    "dilatațio": "dilatație",
    "dilatatoare": "dilatator",
    "dilatatoarea": "dilatator",
    "dilatatoarei": "dilatator",
    "dilatatoarele": "dilatator",
    "dilatatoarelor": "dilatator",
    "dilatatoareo": "dilatator",
    "dilatatori": "dilatator",
    "dilatatorii": "dilatator",
    "dilatatorilor": "dilatator",
    "dilatatorul": "dilatator",
    "dilatatorule": "dilatator",
    "dilatatorului": "dilatator",
    "dilatometre": "dilatometru",
    "dilatometrele": "dilatometru",
    "dilatometrelor": "dilatometru",
    "dilatometrul": "dilatometru",
    "dilatometrule": "dilatometru",
    "dilatometrului": "dilatometru",
    "dilatoria": "dilatoriu",
    "dilatorie": "dilatoriu",
    "dilatoriei": "dilatoriu",
    "dilatorii": "dilatoriu",
    "dilatoriii": "dilatoriu",
    "dilatoriile": "dilatoriu",
    "dilatoriilor": "dilatoriu",
    "dilatorio": "dilatoriu",
    "dilatoriul": "dilatoriu",
    "dilatoriule": "dilatoriu",
    "dilatoriului": "dilatoriu",
    "dilema": "dilemă",
    "dileme": "dilemă",
    "dilemei": "dilemă",
    "dilemele": "dilemă",
    "dilemelor": "dilemă",
    "dilemo": "dilemă",
    "dilematica": "dilematic",
    "dilematică": "dilematic",
    "dilematice": "dilematic",
    "dilematicei": "dilematic",
    "dilematicele": "dilematic",
    "dilematicelor": "dilematic",
    "dilematici": "dilematic",
    "dilematicii": "dilematic",
    "dilematicilor": "dilematic",
    "dilematico": "dilematic",
    "dilematicul": "dilematic",
    "dilematicule": "dilematic",
    "dilematicului": "dilematic",
    "diletanți": "diletant",
    "diletanții": "diletant",
    "diletanților": "diletant",
    "diletantul": "diletant",
    "diletantule": "diletant",
    "diletantului": "diletant",
    "diletanta": "diletantă",
    "diletante": "diletantă",
    "diletantei": "diletantă",
    "diletantele": "diletantă",
    "diletantelor": "diletantă",
    "diletanto": "diletantă",
    "diligenta": "diligent",
    "diligentă": "diligent",
    "diligente": "diligent",
    "diligentei": "diligent",
    "diligentele": "diligent",
    "diligentelor": "diligent",
    "diligenți": "diligent",
    "diligenții": "diligent",
    "diligenților": "diligent",
    "diligento": "diligent",
    "diligentul": "diligent",
    "diligentule": "diligent",
    "diligentului": "diligent",
    "diligența": "diligență",
    "diligențe": "diligență",
    "diligenței": "diligență",
    "diligențele": "diligență",
    "diligențelor": "diligență",
    "diligențo": "diligență",
    "diluă": "dilua",
    "diluai": "dilua",
    "diluam": "dilua",
    "diluăm": "dilua",
    "diluând": "dilua",
    "diluându": "dilua",
    "diluară": "dilua",
    "diluarăm": "dilua",
    "diluarăți": "dilua",
    "diluase": "dilua",
    "diluasem": "dilua",
    "diluaseră": "dilua",
    "diluaserăm": "dilua",
    "diluaserăți": "dilua",
    "diluaseși": "dilua",
    "diluași": "dilua",
    "diluat": "dilua",
    "diluați": "dilua",
    "diluatu": "dilua",
    "diluau": "dilua",
    "diluează": "dilua",
    "diluez": "dilua",
    "dilueze": "dilua",
    "diluezi": "dilua",
    "nediluând": "dilua",
    "nediluându": "dilua",
    "nemaidiluând": "dilua",
    "nemaidiluându": "dilua",
    "diluanți": "diluant",
    "diluanții": "diluant",
    "diluanților": "diluant",
    "diluantul": "diluant",
    "diluantule": "diluant",
    "diluantului": "diluant",
    "diluarea": "diluare",
    "diluareo": "diluare",
    "diluări": "diluare",
    "diluării": "diluare",
    "diluările": "diluare",
    "diluărilor": "diluare",
    "diluata": "diluat",
    "diluată": "diluat",
    "diluate": "diluat",
    "diluatei": "diluat",
    "diluatele": "diluat",
    "diluatelor": "diluat",
    "diluați": "diluat",
    "diluații": "diluat",
    "diluaților": "diluat",
    "diluato": "diluat",
    "diluatul": "diluat",
    "diluatule": "diluat",
    "diluatului": "diluat",
    "diluția": "diluție",
    "diluției": "diluție",
    "diluții": "diluție",
    "diluțiile": "diluție",
    "diluțiilor": "diluție",
    "diluțio": "diluție",
    "diluviana": "diluvian",
    "diluviană": "diluvian",
    "diluviano": "diluvian",
    "diluvianul": "diluvian",
    "diluvianule": "diluvian",
    "diluvianului": "diluvian",
    "diluviene": "diluvian",
    "diluvienei": "diluvian",
    "diluvienele": "diluvian",
    "diluvienelor": "diluvian",
    "diluvieni": "diluvian",
    "diluvienii": "diluvian",
    "diluvienilor": "diluvian",
    "diluvii": "diluviu",
    "diluviile": "diluviu",
    "diluviilor": "diluviu",
    "diluviul": "diluviu",
    "diluviule": "diluviu",
    "diluviului": "diluviu",
    "dimensionă": "dimensiona",
    "dimensionai": "dimensiona",
    "dimensionam": "dimensiona",
    "dimensionăm": "dimensiona",
    "dimensionând": "dimensiona",
    "dimensionându": "dimensiona",
    "dimensionară": "dimensiona",
    "dimensionarăm": "dimensiona",
    "dimensionarăți": "dimensiona",
    "dimensionase": "dimensiona",
    "dimensionasem": "dimensiona",
    "dimensionaseră": "dimensiona",
    "dimensionaserăm": "dimensiona",
    "dimensionaserăți": "dimensiona",
    "dimensionaseși": "dimensiona",
    "dimensionași": "dimensiona",
    "dimensionat": "dimensiona",
    "dimensionați": "dimensiona",
    "dimensionatu": "dimensiona",
    "dimensionau": "dimensiona",
    "dimensionează": "dimensiona",
    "dimensionez": "dimensiona",
    "dimensioneze": "dimensiona",
    "dimensionezi": "dimensiona",
    "nedimensionând": "dimensiona",
    "nedimensionându": "dimensiona",
    "nemaidimensionând": "dimensiona",
    "nemaidimensionându": "dimensiona",
    "dimensionabila": "dimensionabil",
    "dimensionabilă": "dimensionabil",
    "dimensionabile": "dimensionabil",
    "dimensionabilei": "dimensionabil",
    "dimensionabilele": "dimensionabil",
    "dimensionabilelor": "dimensionabil",
    "dimensionabili": "dimensionabil",
    "dimensionabilii": "dimensionabil",
    "dimensionabililor": "dimensionabil",
    "dimensionabilul": "dimensionabil",
    "dimensionabilului": "dimensionabil",
    "dimensionala": "dimensional",
    "dimensională": "dimensional",
    "dimensionale": "dimensional",
    "dimensionalei": "dimensional",
    "dimensionalele": "dimensional",
    "dimensionalelor": "dimensional",
    "dimensionali": "dimensional",
    "dimensionalii": "dimensional",
    "dimensionalilor": "dimensional",
    "dimensionalul": "dimensional",
    "dimensionalului": "dimensional",
    "dimensionarea": "dimensionare",
    "dimensionareo": "dimensionare",
    "dimensionări": "dimensionare",
    "dimensionării": "dimensionare",
    "dimensionările": "dimensionare",
    "dimensionărilor": "dimensionare",
    "dimensionată": "dimensionat",
    "dimensionate": "dimensionat",
    "dimensionați": "dimensionat",
    "dimensiunea": "dimensiune",
    "dimensiuneo": "dimensiune",
    "dimensiuni": "dimensiune",
    "dimensiunii": "dimensiune",
    "dimensiunile": "dimensiune",
    "dimensiunilor": "dimensiune",
    "dimia": "dimie",
    "dimiei": "dimie",
    "dimii": "dimie",
    "dimiile": "dimie",
    "dimiilor": "dimie",
    "dimio": "dimie",
    "dimineața": "dimineață",
    "dimineațo": "dimineață",
    "dimineți": "dimineață",
    "dimineții": "dimineață",
    "diminețile": "dimineață",
    "dimineților": "dimineață",
    "diminuă": "diminua",
    "diminuai": "diminua",
    "diminuam": "diminua",
    "diminuăm": "diminua",
    "diminuând": "diminua",
    "diminuându": "diminua",
    "diminuară": "diminua",
    "diminuarăm": "diminua",
    "diminuarăți": "diminua",
    "diminuase": "diminua",
    "diminuasem": "diminua",
    "diminuaseră": "diminua",
    "diminuaserăm": "diminua",
    "diminuaserăți": "diminua",
    "diminuaseși": "diminua",
    "diminuași": "diminua",
    "diminuat": "diminua",
    "diminuați": "diminua",
    "diminuatu": "diminua",
    "diminuau": "diminua",
    "diminuează": "diminua",
    "diminuez": "diminua",
    "diminueze": "diminua",
    "diminuezi": "diminua",
    "nediminuând": "diminua",
    "nediminuându": "diminua",
    "nemaidiminuând": "diminua",
    "nemaidiminuându": "diminua",
    "diminuarea": "diminuare",
    "diminuareo": "diminuare",
    "diminuări": "diminuare",
    "diminuării": "diminuare",
    "diminuările": "diminuare",
    "diminuărilor": "diminuare",
    "diminuată": "diminuat",
    "diminuate": "diminuat",
    "diminuați": "diminuat",
    "diminutive": "diminutiv",
    "diminutivele": "diminutiv",
    "diminutivelor": "diminutiv",
    "diminutivul": "diminutiv",
    "diminutivule": "diminutiv",
    "diminutivului": "diminutiv",
    "dimorfa": "dimorf",
    "dimorfă": "dimorf",
    "dimorfe": "dimorf",
    "dimorfei": "dimorf",
    "dimorfele": "dimorf",
    "dimorfelor": "dimorf",
    "dimorfi": "dimorf",
    "dimorfii": "dimorf",
    "dimorfilor": "dimorf",
    "dimorfo": "dimorf",
    "dimorful": "dimorf",
    "dimorfule": "dimorf",
    "dimorfului": "dimorf",
    "dân": "din",
    "Dinei": "Dina",
    "dina": "dină",
    "dine": "dină",
    "dinei": "dină",
    "dinele": "dină",
    "dinelor": "dină",
    "dino": "dină",
    "dinamul": "dinam",
    "dinamule": "dinam",
    "dinamului": "dinam",
    "dinamuri": "dinam",
    "dinamurile": "dinam",
    "dinamurilor": "dinam",
    "dinamica": "dinamic",
    "dinamică": "dinamic",
    "dinamice": "dinamic",
    "dinamicei": "dinamic",
    "dinamicele": "dinamic",
    "dinamicelor": "dinamic",
    "dinamici": "dinamic",
    "dinamicii": "dinamic",
    "dinamicilor": "dinamic",
    "dinamico": "dinamic",
    "dinamicul": "dinamic",
    "dinamicule": "dinamic",
    "dinamicului": "dinamic",
    "dinamica": "dinamică",
    "dinamicele": "dinamică",
    "dinamici": "dinamică",
    "dinamicii": "dinamică",
    "dinamicilor": "dinamică",
    "dinamico": "dinamică",
    "dinamisme": "dinamism",
    "dinamismele": "dinamism",
    "dinamismelor": "dinamism",
    "dinamismul": "dinamism",
    "dinamismule": "dinamism",
    "dinamismului": "dinamism",
    "dinamită": "dinamita",
    "dinamitai": "dinamita",
    "dinamitam": "dinamita",
    "dinamităm": "dinamita",
    "dinamitând": "dinamita",
    "dinamitându": "dinamita",
    "dinamitară": "dinamita",
    "dinamitarăm": "dinamita",
    "dinamitarăți": "dinamita",
    "dinamitase": "dinamita",
    "dinamitasem": "dinamita",
    "dinamitaseră": "dinamita",
    "dinamitaserăm": "dinamita",
    "dinamitaserăți": "dinamita",
    "dinamitaseși": "dinamita",
    "dinamitași": "dinamita",
    "dinamitat": "dinamita",
    "dinamitați": "dinamita",
    "dinamitatu": "dinamita",
    "dinamitau": "dinamita",
    "dinamitează": "dinamita",
    "dinamitez": "dinamita",
    "dinamiteze": "dinamita",
    "dinamitezi": "dinamita",
    "nedinamitând": "dinamita",
    "nedinamitându": "dinamita",
    "nemaidinamitând": "dinamita",
    "nemaidinamitându": "dinamita",
    "dinamita": "dinamită",
    "dinamite": "dinamită",
    "dinamitei": "dinamită",
    "dinamitele": "dinamită",
    "dinamitelor": "dinamită",
    "dinamito": "dinamită",
    "dinamitarea": "dinamitare",
    "dinamitareo": "dinamitare",
    "dinamitări": "dinamitare",
    "dinamitării": "dinamitare",
    "dinamitările": "dinamitare",
    "dinamitărilor": "dinamitare",
    "dinamitată": "dinamitat",
    "dinamitate": "dinamitat",
    "dinamitați": "dinamitat",
    "dinamiză": "dinamiza",
    "dinamizai": "dinamiza",
    "dinamizam": "dinamiza",
    "dinamizăm": "dinamiza",
    "dinamizând": "dinamiza",
    "dinamizându": "dinamiza",
    "dinamizară": "dinamiza",
    "dinamizarăm": "dinamiza",
    "dinamizarăți": "dinamiza",
    "dinamizase": "dinamiza",
    "dinamizasem": "dinamiza",
    "dinamizaseră": "dinamiza",
    "dinamizaserăm": "dinamiza",
    "dinamizaserăți": "dinamiza",
    "dinamizaseși": "dinamiza",
    "dinamizași": "dinamiza",
    "dinamizat": "dinamiza",
    "dinamizați": "dinamiza",
    "dinamizatu": "dinamiza",
    "dinamizau": "dinamiza",
    "dinamizează": "dinamiza",
    "dinamizez": "dinamiza",
    "dinamizeze": "dinamiza",
    "dinamizezi": "dinamiza",
    "nedinamizând": "dinamiza",
    "nedinamizându": "dinamiza",
    "nemaidinamizând": "dinamiza",
    "nemaidinamizându": "dinamiza",
    "dinamizarea": "dinamizare",
    "dinamizareo": "dinamizare",
    "dinamizări": "dinamizare",
    "dinamizării": "dinamizare",
    "dinamizările": "dinamizare",
    "dinamizărilor": "dinamizare",
    "dinamizată": "dinamizat",
    "dinamizate": "dinamizat",
    "dinamizați": "dinamizat",
    "dinamometre": "dinamometru",
    "dinamometrele": "dinamometru",
    "dinamometrelor": "dinamometru",
    "dinamometrul": "dinamometru",
    "dinamometrule": "dinamometru",
    "dinamometrului": "dinamometru",
    "dinari": "dinar",
    "dinarii": "dinar",
    "dinarilor": "dinar",
    "dinarul": "dinar",
    "dinarule": "dinar",
    "dinarului": "dinar",
    "dinastica": "dinastic",
    "dinastică": "dinastic",
    "dinastice": "dinastic",
    "dinasticei": "dinastic",
    "dinasticele": "dinastic",
    "dinasticelor": "dinastic",
    "dinastici": "dinastic",
    "dinasticii": "dinastic",
    "dinasticilor": "dinastic",
    "dinastico": "dinastic",
    "dinasticul": "dinastic",
    "dinasticule": "dinastic",
    "dinasticului": "dinastic",
    "dinastia": "dinastie",
    "dinastiei": "dinastie",
    "dinastii": "dinastie",
    "dinastiile": "dinastie",
    "dinastiilor": "dinastie",
    "dinastio": "dinastie",
    "dineul": "dineu",
    "dineule": "dineu",
    "dineului": "dineu",
    "dineuri": "dineu",
    "dineurile": "dineu",
    "dineurilor": "dineu",
    "dinoterii": "dinoteriu",
    "dinoteriii": "dinoteriu",
    "dinoteriilor": "dinoteriu",
    "dinoteriul": "dinoteriu",
    "dinoteriule": "dinoteriu",
    "dinoteriului": "dinoteriu",
    "dinozauri": "dinozaur",
    "dinozaurii": "dinozaur",
    "dinozaurilor": "dinozaur",
    "dinozaurul": "dinozaur",
    "dinozaurule": "dinozaur",
    "dinozaurului": "dinozaur",
    "dință": "dința",
    "dințai": "dința",
    "dințam": "dința",
    "dințăm": "dința",
    "dințând": "dința",
    "dințându": "dința",
    "dințară": "dința",
    "dințarăm": "dința",
    "dințarăți": "dința",
    "dințase": "dința",
    "dințasem": "dința",
    "dințaseră": "dința",
    "dințaserăm": "dința",
    "dințaserăți": "dința",
    "dințaseși": "dința",
    "dințași": "dința",
    "dințat": "dința",
    "dințați": "dința",
    "dințatu": "dința",
    "dințau": "dința",
    "dințează": "dința",
    "dințez": "dința",
    "dințeze": "dința",
    "dințezi": "dința",
    "nedințând": "dința",
    "nedințându": "dința",
    "nemaidințând": "dința",
    "nemaidințându": "dința",
    "dințarea": "dințare",
    "dințareo": "dințare",
    "dințări": "dințare",
    "dințării": "dințare",
    "dințările": "dințare",
    "dințărilor": "dințare",
    "dințata": "dințat",
    "dințată": "dințat",
    "dințate": "dințat",
    "dințatei": "dințat",
    "dințatele": "dințat",
    "dințatelor": "dințat",
    "dințați": "dințat",
    "dințații": "dințat",
    "dințaților": "dințat",
    "dințato": "dințat",
    "dințatul": "dințat",
    "dințatule": "dințat",
    "dințatului": "dințat",
    "dințătura": "dințătură",
    "dințături": "dințătură",
    "dințăturii": "dințătură",
    "dințăturile": "dințătură",
    "dințăturilor": "dințătură",
    "dințăturo": "dințătură",
    "dintele": "dinte",
    "dintelui": "dinte",
    "dinți": "dinte",
    "dinții": "dinte",
    "dinților": "dinte",
    "dintr": "dintru",
    "dintr-": "dintru",
    "dioceza": "dioceză",
    "dioceze": "dioceză",
    "diocezei": "dioceză",
    "diocezele": "dioceză",
    "diocezelor": "dioceză",
    "diocezo": "dioceză",
    "dioda": "diodă",
    "diode": "diodă",
    "diodei": "diodă",
    "diodele": "diodă",
    "diodelor": "diodă",
    "diodo": "diodă",
    "diomedică": "diomedic",
    "dionisiaca": "dionisiac",
    "dionisiacă": "dionisiac",
    "dionisiace": "dionisiac",
    "dionisiacei": "dionisiac",
    "dionisiacele": "dionisiac",
    "dionisiacelor": "dionisiac",
    "dionisiaci": "dionisiac",
    "dionisiacii": "dionisiac",
    "dionisiacilor": "dionisiac",
    "dionisiaco": "dionisiac",
    "dionisiacul": "dionisiac",
    "dionisiacule": "dionisiac",
    "dionisiacului": "dionisiac",
    "Dionisii": "Dionisie",
    "dioptrica": "dioptric",
    "dioptrică": "dioptric",
    "dioptrice": "dioptric",
    "dioptricei": "dioptric",
    "dioptricele": "dioptric",
    "dioptricelor": "dioptric",
    "dioptrici": "dioptric",
    "dioptricii": "dioptric",
    "dioptricilor": "dioptric",
    "dioptrico": "dioptric",
    "dioptricul": "dioptric",
    "dioptricule": "dioptric",
    "dioptricului": "dioptric",
    "dioptrica": "dioptrică",
    "dioptricele": "dioptrică",
    "dioptrici": "dioptrică",
    "dioptricii": "dioptrică",
    "dioptricilor": "dioptrică",
    "dioptrico": "dioptrică",
    "dioptria": "dioptrie",
    "dioptriei": "dioptrie",
    "dioptrii": "dioptrie",
    "dioptriile": "dioptrie",
    "dioptriilor": "dioptrie",
    "dioptrio": "dioptrie",
    "diorama": "dioramă",
    "diorame": "dioramă",
    "dioramei": "dioramă",
    "dioramele": "dioramă",
    "dioramelor": "dioramă",
    "dioramo": "dioramă",
    "dipetala": "dipetal",
    "dipetală": "dipetal",
    "dipetale": "dipetal",
    "dipetalei": "dipetal",
    "dipetalele": "dipetal",
    "dipetalelor": "dipetal",
    "dipetali": "dipetal",
    "dipetalii": "dipetal",
    "dipetalilor": "dipetal",
    "dipetalo": "dipetal",
    "dipetalul": "dipetal",
    "dipetalule": "dipetal",
    "dipetalului": "dipetal",
    "diploma": "diplomă",
    "diplome": "diplomă",
    "diplomei": "diplomă",
    "diplomele": "diplomă",
    "diplomelor": "diplomă",
    "diplomo": "diplomă",
    "diplomata": "diplomat",
    "diplomată": "diplomat",
    "diplomate": "diplomat",
    "diplomatei": "diplomat",
    "diplomatele": "diplomat",
    "diplomatelor": "diplomat",
    "diplomați": "diplomat",
    "diplomații": "diplomat",
    "diplomaților": "diplomat",
    "diplomato": "diplomat",
    "diplomatul": "diplomat",
    "diplomatule": "diplomat",
    "diplomatului": "diplomat",
    "diplomatica": "diplomatic",
    "diplomatică": "diplomatic",
    "diplomatice": "diplomatic",
    "diplomaticei": "diplomatic",
    "diplomaticele": "diplomatic",
    "diplomaticelor": "diplomatic",
    "diplomatici": "diplomatic",
    "diplomaticii": "diplomatic",
    "diplomaticilor": "diplomatic",
    "diplomatico": "diplomatic",
    "diplomaticul": "diplomatic",
    "diplomaticule": "diplomatic",
    "diplomaticului": "diplomatic",
    "diplomatica": "diplomatică",
    "diplomatice": "diplomatică",
    "diplomaticei": "diplomatică",
    "diplomaticele": "diplomatică",
    "diplomaticelor": "diplomatică",
    "diplomatico": "diplomatică",
    "diplomația": "diplomație",
    "diplomației": "diplomație",
    "diplomații": "diplomație",
    "diplomațiile": "diplomație",
    "diplomațiilor": "diplomație",
    "diplomațio": "diplomație",
    "dipoli": "dipol",
    "dipolii": "dipol",
    "dipolilor": "dipol",
    "dipolul": "dipol",
    "dipolule": "dipol",
    "dipolului": "dipol",
    "diptere": "dipter",
    "dipterele": "dipter",
    "dipterelor": "dipter",
    "dipterul": "dipter",
    "dipterule": "dipter",
    "dipterului": "dipter",
    "directa": "direct",
    "directă": "direct",
    "directe": "direct",
    "directei": "direct",
    "directele": "direct",
    "directelor": "direct",
    "direcți": "direct",
    "direcții": "direct",
    "direcților": "direct",
    "directo": "direct",
    "directul": "direct",
    "directule": "direct",
    "directului": "direct",
    "direcția": "direcție",
    "direcției": "direcție",
    "direcții": "direcție",
    "direcțiile": "direcție",
    "direcțiilor": "direcție",
    "direcțio": "direcție",
    "direcționează": "direcționa",
    "direcționata": "direcționat",
    "direcționată": "direcționat",
    "direcționate": "direcționat",
    "direcționatei": "direcționat",
    "direcționatele": "direcționat",
    "direcționatelor": "direcționat",
    "direcționați": "direcționat",
    "direcționații": "direcționat",
    "direcționaților": "direcționat",
    "direcționato": "direcționat",
    "direcționatul": "direcționat",
    "direcționatule": "direcționat",
    "direcționatului": "direcționat",
    "direcțiunea": "direcțiune",
    "direcțiuneo": "direcțiune",
    "direcțiuni": "direcțiune",
    "direcțiunii": "direcțiune",
    "direcțiunile": "direcțiune",
    "direcțiunilor": "direcțiune",
    "directiva": "directivă",
    "directive": "directivă",
    "directivei": "directivă",
    "directivele": "directivă",
    "directivelor": "directivă",
    "directivo": "directivă",
    "directoarea": "directoare",
    "directoarei": "directoare",
    "directoarele": "directoare",
    "directoarelor": "directoare",
    "directoareo": "directoare",
    "dir.": "director",
    "directoare": "director",
    "directoarea": "director",
    "directoarei": "director",
    "directoarele": "director",
    "directoarelor": "director",
    "directoareo": "director",
    "directori": "director",
    "directorii": "director",
    "directorilor": "director",
    "directorul": "director",
    "directorule": "director",
    "directorului": "director",
    "directorimea": "directorime",
    "directorimi": "directorime",
    "directorimii": "directorime",
    "directorimile": "directorime",
    "directorimilor": "directorime",
    "dirigenția": "dirigenție",
    "dirigenției": "dirigenție",
    "dirigenții": "dirigenție",
    "dirigențiile": "dirigenție",
    "dirigențiilor": "dirigenție",
    "dirigențio": "dirigenție",
    "dirigintele": "diriginte",
    "dirigintelui": "diriginte",
    "diriginți": "diriginte",
    "diriginții": "diriginte",
    "diriginților": "diriginte",
    "diriguia": "dirigui",
    "diriguiai": "dirigui",
    "diriguiam": "dirigui",
    "diriguiască": "dirigui",
    "diriguiați": "dirigui",
    "diriguiau": "dirigui",
    "diriguiesc": "dirigui",
    "diriguiește": "dirigui",
    "diriguiești": "dirigui",
    "diriguii": "dirigui",
    "diriguim": "dirigui",
    "diriguind": "dirigui",
    "diriguindu": "dirigui",
    "diriguiră": "dirigui",
    "diriguirăm": "dirigui",
    "diriguirăți": "dirigui",
    "diriguise": "dirigui",
    "diriguisem": "dirigui",
    "diriguiseră": "dirigui",
    "diriguiserăm": "dirigui",
    "diriguiserăți": "dirigui",
    "diriguiseși": "dirigui",
    "diriguiși": "dirigui",
    "diriguit": "dirigui",
    "diriguiți": "dirigui",
    "diriguitu": "dirigui",
    "nediriguind": "dirigui",
    "nediriguindu": "dirigui",
    "nemaidiriguind": "dirigui",
    "nemaidiriguindu": "dirigui",
    "diriguirea": "diriguire",
    "diriguireo": "diriguire",
    "diriguiri": "diriguire",
    "diriguirii": "diriguire",
    "diriguirile": "diriguire",
    "diriguirilor": "diriguire",
    "diriguită": "diriguit",
    "diriguite": "diriguit",
    "diriguiți": "diriguit",
    "diriguitoarea": "diriguitoare",
    "diriguitoarei": "diriguitoare",
    "diriguitoarele": "diriguitoare",
    "diriguitoarelor": "diriguitoare",
    "diriguitoareo": "diriguitoare",
    "diriguitoare": "diriguitor",
    "diriguitoarea": "diriguitor",
    "diriguitoarei": "diriguitor",
    "diriguitoarele": "diriguitor",
    "diriguitoarelor": "diriguitor",
    "diriguitoareo": "diriguitor",
    "diriguitori": "diriguitor",
    "diriguitorii": "diriguitor",
    "diriguitorilor": "diriguitor",
    "diriguitorul": "diriguitor",
    "diriguitorule": "diriguitor",
    "diriguitorului": "diriguitor",
    "dirijă": "dirija",
    "dirijai": "dirija",
    "dirijam": "dirija",
    "dirijăm": "dirija",
    "dirijând": "dirija",
    "dirijându": "dirija",
    "dirijară": "dirija",
    "dirijarăm": "dirija",
    "dirijarăți": "dirija",
    "dirijase": "dirija",
    "dirijasem": "dirija",
    "dirijaseră": "dirija",
    "dirijaserăm": "dirija",
    "dirijaserăți": "dirija",
    "dirijaseși": "dirija",
    "dirijași": "dirija",
    "dirijat": "dirija",
    "dirijați": "dirija",
    "dirijatu": "dirija",
    "dirijau": "dirija",
    "dirijează": "dirija",
    "dirijez": "dirija",
    "dirijeze": "dirija",
    "dirijezi": "dirija",
    "nedirijând": "dirija",
    "nedirijându": "dirija",
    "nemaidirijând": "dirija",
    "nemaidirijându": "dirija",
    "dirijabile": "dirijabil",
    "dirijabilele": "dirijabil",
    "dirijabilelor": "dirijabil",
    "dirijabilul": "dirijabil",
    "dirijabilule": "dirijabil",
    "dirijabilului": "dirijabil",
    "dirijarea": "dirijare",
    "dirijareo": "dirijare",
    "dirijări": "dirijare",
    "dirijării": "dirijare",
    "dirijările": "dirijare",
    "dirijărilor": "dirijare",
    "dirijata": "dirijat",
    "dirijată": "dirijat",
    "dirijate": "dirijat",
    "dirijatei": "dirijat",
    "dirijatele": "dirijat",
    "dirijatelor": "dirijat",
    "dirijați": "dirijat",
    "dirijații": "dirijat",
    "dirijaților": "dirijat",
    "dirijato": "dirijat",
    "dirijatul": "dirijat",
    "dirijatule": "dirijat",
    "dirijatului": "dirijat",
    "dirijoarea": "dirijoare",
    "dirijoarei": "dirijoare",
    "dirijoarele": "dirijoare",
    "dirijoarelor": "dirijoare",
    "dirijoareo": "dirijoare",
    "dirijori": "dirijor",
    "dirijorii": "dirijor",
    "dirijorilor": "dirijor",
    "dirijorul": "dirijor",
    "dirijorule": "dirijor",
    "dirijorului": "dirijor",
    "discul": "disc",
    "discule": "disc",
    "discului": "disc",
    "discuri": "disc",
    "discurile": "disc",
    "discurilor": "disc",
    "discernământul": "discernământ",
    "discernământule": "discernământ",
    "discernământului": "discernământ",
    "discernăminte": "discernământ",
    "discernămintele": "discernământ",
    "discernămintelor": "discernământ",
    "discearnă": "discerne",
    "discern": "discerne",
    "discernând": "discerne",
    "discernându": "discerne",
    "discernea": "discerne",
    "discerneai": "discerne",
    "discerneam": "discerne",
    "discerneați": "discerne",
    "discerneau": "discerne",
    "discernem": "discerne",
    "discerneți": "discerne",
    "discerni": "discerne",
    "discernu": "discerne",
    "discernui": "discerne",
    "discernură": "discerne",
    "discernurăm": "discerne",
    "discernurăți": "discerne",
    "discernuse": "discerne",
    "discernusem": "discerne",
    "discernuseră": "discerne",
    "discernuserăm": "discerne",
    "discernuserăți": "discerne",
    "discernuseși": "discerne",
    "discernuși": "discerne",
    "discernut": "discerne",
    "discernutu": "discerne",
    "nediscernând": "discerne",
    "nediscernându": "discerne",
    "nemaidiscernând": "discerne",
    "nemaidiscernându": "discerne",
    "discernută": "discernut",
    "discernute": "discernut",
    "discernuți": "discernut",
    "disciplină": "disciplina",
    "disciplinai": "disciplina",
    "disciplinam": "disciplina",
    "disciplinăm": "disciplina",
    "disciplinând": "disciplina",
    "disciplinându": "disciplina",
    "disciplinară": "disciplina",
    "disciplinarăm": "disciplina",
    "disciplinarăți": "disciplina",
    "disciplinase": "disciplina",
    "disciplinasem": "disciplina",
    "disciplinaseră": "disciplina",
    "disciplinaserăm": "disciplina",
    "disciplinaserăți": "disciplina",
    "disciplinaseși": "disciplina",
    "disciplinași": "disciplina",
    "disciplinat": "disciplina",
    "disciplinați": "disciplina",
    "disciplinatu": "disciplina",
    "disciplinau": "disciplina",
    "disciplinează": "disciplina",
    "disciplinez": "disciplina",
    "disciplineze": "disciplina",
    "disciplinezi": "disciplina",
    "nedisciplinând": "disciplina",
    "nedisciplinându": "disciplina",
    "nemaidisciplinând": "disciplina",
    "nemaidisciplinându": "disciplina",
    "disciplina": "disciplină",
    "discipline": "disciplină",
    "disciplinei": "disciplină",
    "disciplinele": "disciplină",
    "disciplinelor": "disciplină",
    "disciplino": "disciplină",
    "disciplinara": "disciplinar",
    "disciplinară": "disciplinar",
    "disciplinare": "disciplinar",
    "disciplinarei": "disciplinar",
    "disciplinarele": "disciplinar",
    "disciplinarelor": "disciplinar",
    "disciplinari": "disciplinar",
    "disciplinarii": "disciplinar",
    "disciplinarilor": "disciplinar",
    "disciplinaro": "disciplinar",
    "disciplinarul": "disciplinar",
    "disciplinarule": "disciplinar",
    "disciplinarului": "disciplinar",
    "disciplinarea": "disciplinare",
    "disciplinareo": "disciplinare",
    "disciplinări": "disciplinare",
    "disciplinării": "disciplinare",
    "disciplinările": "disciplinare",
    "disciplinărilor": "disciplinare",
    "disciplinata": "disciplinat",
    "disciplinată": "disciplinat",
    "disciplinate": "disciplinat",
    "disciplinatei": "disciplinat",
    "disciplinatele": "disciplinat",
    "disciplinatelor": "disciplinat",
    "disciplinați": "disciplinat",
    "disciplinații": "disciplinat",
    "disciplinaților": "disciplinat",
    "disciplinato": "disciplinat",
    "disciplinatul": "disciplinat",
    "disciplinatule": "disciplinat",
    "disciplinatului": "disciplinat",
    "discipoli": "discipol",
    "discipolii": "discipol",
    "discipolilor": "discipol",
    "discipolul": "discipol",
    "discipolule": "discipol",
    "discipolului": "discipol",
    "discoboli": "discobol",
    "discobolii": "discobol",
    "discobolilor": "discobol",
    "discobolul": "discobol",
    "discobolule": "discobol",
    "discobolului": "discobol",
    "discobola": "discobolă",
    "discobole": "discobolă",
    "discobolei": "discobolă",
    "discobolele": "discobolă",
    "discobolelor": "discobolă",
    "discobolo": "discobolă",
    "discografica": "discografic",
    "discografică": "discografic",
    "discografice": "discografic",
    "discograficei": "discografic",
    "discograficele": "discografic",
    "discograficelor": "discografic",
    "discografici": "discografic",
    "discograficii": "discografic",
    "discograficilor": "discografic",
    "discografico": "discografic",
    "discograficul": "discografic",
    "discograficule": "discografic",
    "discograficului": "discografic",
    "discontinua": "discontinuu",
    "discontinuă": "discontinuu",
    "discontinue": "discontinuu",
    "discontinuei": "discontinuu",
    "discontinuele": "discontinuu",
    "discontinuelor": "discontinuu",
    "discontinui": "discontinuu",
    "discontinuii": "discontinuu",
    "discontinuilor": "discontinuu",
    "discontinuo": "discontinuu",
    "discontinuul": "discontinuu",
    "discontinuule": "discontinuu",
    "discontinuului": "discontinuu",
    "discordă": "discorda",
    "discordai": "discorda",
    "discordam": "discorda",
    "discordăm": "discorda",
    "discordând": "discorda",
    "discordându": "discorda",
    "discordară": "discorda",
    "discordarăm": "discorda",
    "discordarăți": "discorda",
    "discordase": "discorda",
    "discordasem": "discorda",
    "discordaseră": "discorda",
    "discordaserăm": "discorda",
    "discordaserăți": "discorda",
    "discordaseși": "discorda",
    "discordași": "discorda",
    "discordat": "discorda",
    "discordați": "discorda",
    "discordatu": "discorda",
    "discordau": "discorda",
    "discordează": "discorda",
    "discordez": "discorda",
    "discordeze": "discorda",
    "discordezi": "discorda",
    "nediscordând": "discorda",
    "nediscordându": "discorda",
    "nemaidiscordând": "discorda",
    "nemaidiscordându": "discorda",
    "discordanta": "discordant",
    "discordantă": "discordant",
    "discordante": "discordant",
    "discordantei": "discordant",
    "discordantele": "discordant",
    "discordantelor": "discordant",
    "discordanți": "discordant",
    "discordanții": "discordant",
    "discordanților": "discordant",
    "discordanto": "discordant",
    "discordantul": "discordant",
    "discordantule": "discordant",
    "discordantului": "discordant",
    "discordanța": "discordanță",
    "discordanțe": "discordanță",
    "discordanței": "discordanță",
    "discordanțele": "discordanță",
    "discordanțelor": "discordanță",
    "discordanțo": "discordanță",
    "discordarea": "discordare",
    "discordareo": "discordare",
    "discordări": "discordare",
    "discordării": "discordare",
    "discordările": "discordare",
    "discordărilor": "discordare",
    "discordata": "discordat",
    "discordată": "discordat",
    "discordate": "discordat",
    "discordatei": "discordat",
    "discordatele": "discordat",
    "discordatelor": "discordat",
    "discordați": "discordat",
    "discordații": "discordat",
    "discordaților": "discordat",
    "discordato": "discordat",
    "discordatul": "discordat",
    "discordatule": "discordat",
    "discordatului": "discordat",
    "discordia": "discordie",
    "discordiei": "discordie",
    "discordii": "discordie",
    "discordiile": "discordie",
    "discordiilor": "discordie",
    "discordio": "discordie",
    "discoteca": "discotecă",
    "discoteci": "discotecă",
    "discotecii": "discotecă",
    "discotecile": "discotecă",
    "discotecilor": "discotecă",
    "discoteco": "discotecă",
    "discredită": "discredita",
    "discreditai": "discredita",
    "discreditam": "discredita",
    "discredităm": "discredita",
    "discreditând": "discredita",
    "discreditându": "discredita",
    "discreditară": "discredita",
    "discreditarăm": "discredita",
    "discreditarăți": "discredita",
    "discreditase": "discredita",
    "discreditasem": "discredita",
    "discreditaseră": "discredita",
    "discreditaserăm": "discredita",
    "discreditaserăți": "discredita",
    "discreditaseși": "discredita",
    "discreditași": "discredita",
    "discreditat": "discredita",
    "discreditați": "discredita",
    "discreditatu": "discredita",
    "discreditau": "discredita",
    "discreditează": "discredita",
    "discreditez": "discredita",
    "discrediteze": "discredita",
    "discreditezi": "discredita",
    "nediscreditând": "discredita",
    "nediscreditându": "discredita",
    "nemaidiscreditând": "discredita",
    "nemaidiscreditându": "discredita",
    "discreditarea": "discreditare",
    "discreditareo": "discreditare",
    "discreditări": "discreditare",
    "discreditării": "discreditare",
    "discreditările": "discreditare",
    "discreditărilor": "discreditare",
    "discreditata": "discreditat",
    "discreditată": "discreditat",
    "discreditate": "discreditat",
    "discreditatei": "discreditat",
    "discreditatele": "discreditat",
    "discreditatelor": "discreditat",
    "discreditați": "discreditat",
    "discreditații": "discreditat",
    "discreditaților": "discreditat",
    "discreditato": "discreditat",
    "discreditatul": "discreditat",
    "discreditatule": "discreditat",
    "discreditatului": "discreditat",
    "discrepanța": "discrepanță",
    "discrepanțe": "discrepanță",
    "discrepanței": "discrepanță",
    "discrepanțele": "discrepanță",
    "discrepanțelor": "discrepanță",
    "discrepanțo": "discrepanță",
    "discreta": "discret",
    "discretă": "discret",
    "discrete": "discret",
    "discretei": "discret",
    "discretele": "discret",
    "discretelor": "discret",
    "discreți": "discret",
    "discreții": "discret",
    "discreților": "discret",
    "discreto": "discret",
    "discretul": "discret",
    "discretule": "discret",
    "discretului": "discret",
    "discreția": "discreție",
    "discreției": "discreție",
    "discreții": "discreție",
    "discrețio": "discreție",
    "discreționara": "discreționar",
    "discreționară": "discreționar",
    "discreționare": "discreționar",
    "discreționarei": "discreționar",
    "discreționarele": "discreționar",
    "discreționarelor": "discreționar",
    "discreționari": "discreționar",
    "discreționarii": "discreționar",
    "discreționarilor": "discreționar",
    "discreționaro": "discreționar",
    "discreționarul": "discreționar",
    "discreționarule": "discreționar",
    "discreționarului": "discreționar",
    "discriminarea": "discriminare",
    "discriminareo": "discriminare",
    "discriminări": "discriminare",
    "discriminării": "discriminare",
    "discriminările": "discriminare",
    "discriminărilor": "discriminare",
    "discriminatoria": "discriminatoriu",
    "discriminatorie": "discriminatoriu",
    "discriminatoriei": "discriminatoriu",
    "discriminatorii": "discriminatoriu",
    "discriminatoriii": "discriminatoriu",
    "discriminatoriile": "discriminatoriu",
    "discriminatoriilor": "discriminatoriu",
    "discriminatorio": "discriminatoriu",
    "discriminatoriul": "discriminatoriu",
    "discriminatoriule": "discriminatoriu",
    "discriminatoriului": "discriminatoriu",
    "disculp": "disculpa",
    "disculpă": "disculpa",
    "disculpai": "disculpa",
    "disculpam": "disculpa",
    "disculpăm": "disculpa",
    "disculpând": "disculpa",
    "disculpându": "disculpa",
    "disculpară": "disculpa",
    "disculparăm": "disculpa",
    "disculparăți": "disculpa",
    "disculpase": "disculpa",
    "disculpasem": "disculpa",
    "disculpaseră": "disculpa",
    "disculpaserăm": "disculpa",
    "disculpaserăți": "disculpa",
    "disculpaseși": "disculpa",
    "disculpași": "disculpa",
    "disculpat": "disculpa",
    "disculpați": "disculpa",
    "disculpatu": "disculpa",
    "disculpau": "disculpa",
    "disculpe": "disculpa",
    "disculpi": "disculpa",
    "nedisculpând": "disculpa",
    "nedisculpându": "disculpa",
    "nemaidisculpând": "disculpa",
    "nemaidisculpându": "disculpa",
    "disculparea": "disculpare",
    "disculpareo": "disculpare",
    "disculpări": "disculpare",
    "disculpării": "disculpare",
    "disculpările": "disculpare",
    "disculpărilor": "disculpare",
    "disculpată": "disculpat",
    "disculpate": "disculpat",
    "disculpați": "disculpat",
    "discursul": "discurs",
    "discursule": "discurs",
    "discursului": "discurs",
    "discursuri": "discurs",
    "discursurile": "discurs",
    "discursurilor": "discurs",
    "discursiva": "discursiv",
    "discursivă": "discursiv",
    "discursive": "discursiv",
    "discursivei": "discursiv",
    "discursivele": "discursiv",
    "discursivelor": "discursiv",
    "discursivi": "discursiv",
    "discursivii": "discursiv",
    "discursivilor": "discursiv",
    "discursivo": "discursiv",
    "discursivul": "discursiv",
    "discursivule": "discursiv",
    "discursivului": "discursiv",
    "discut": "discuta",
    "discută": "discuta",
    "discutai": "discuta",
    "discutam": "discuta",
    "discutăm": "discuta",
    "discutând": "discuta",
    "discutându": "discuta",
    "discutară": "discuta",
    "discutarăm": "discuta",
    "discutarăți": "discuta",
    "discutase": "discuta",
    "discutasem": "discuta",
    "discutaseră": "discuta",
    "discutaserăm": "discuta",
    "discutaserăți": "discuta",
    "discutaseși": "discuta",
    "discutași": "discuta",
    "discutat": "discuta",
    "discutați": "discuta",
    "discutatu": "discuta",
    "discutau": "discuta",
    "discute": "discuta",
    "discuți": "discuta",
    "nediscutând": "discuta",
    "nediscutându": "discuta",
    "nemaidiscutând": "discuta",
    "nemaidiscutându": "discuta",
    "discutabila": "discutabil",
    "discutabilă": "discutabil",
    "discutabile": "discutabil",
    "discutabilei": "discutabil",
    "discutabilele": "discutabil",
    "discutabilelor": "discutabil",
    "discutabili": "discutabil",
    "discutabilii": "discutabil",
    "discutabililor": "discutabil",
    "discutabilo": "discutabil",
    "discutabilul": "discutabil",
    "discutabilule": "discutabil",
    "discutabilului": "discutabil",
    "discutarea": "discutare",
    "discutareo": "discutare",
    "discutări": "discutare",
    "discutării": "discutare",
    "discutările": "discutare",
    "discutărilor": "discutare",
    "discutata": "discutat",
    "discutată": "discutat",
    "discutate": "discutat",
    "discutatei": "discutat",
    "discutatele": "discutat",
    "discutatelor": "discutat",
    "discutați": "discutat",
    "discutații": "discutat",
    "discutaților": "discutat",
    "discutato": "discutat",
    "discutatul": "discutat",
    "discutatule": "discutat",
    "discutatului": "discutat",
    "discuția": "discuție",
    "discuției": "discuție",
    "discuții": "discuție",
    "discuțiile": "discuție",
    "discuțiilor": "discuție",
    "discuțio": "discuție",
    "discuțiunea": "discuțiune",
    "discuțiuneo": "discuțiune",
    "discuțiuni": "discuțiune",
    "discuțiunii": "discuțiune",
    "discuțiunile": "discuțiune",
    "discuțiunilor": "discuțiune",
    "disec": "diseca",
    "disecă": "diseca",
    "disecai": "diseca",
    "disecam": "diseca",
    "disecăm": "diseca",
    "disecând": "diseca",
    "disecându": "diseca",
    "disecară": "diseca",
    "disecarăm": "diseca",
    "disecarăți": "diseca",
    "disecase": "diseca",
    "disecasem": "diseca",
    "disecaseră": "diseca",
    "disecaserăm": "diseca",
    "disecaserăți": "diseca",
    "disecaseși": "diseca",
    "disecași": "diseca",
    "disecat": "diseca",
    "disecați": "diseca",
    "disecatu": "diseca",
    "disecau": "diseca",
    "disece": "diseca",
    "diseci": "diseca",
    "nedisecând": "diseca",
    "nedisecându": "diseca",
    "nemaidisecând": "diseca",
    "nemaidisecându": "diseca",
    "disecarea": "disecare",
    "disecareo": "disecare",
    "disecări": "disecare",
    "disecării": "disecare",
    "disecările": "disecare",
    "disecărilor": "disecare",
    "disecată": "disecat",
    "disecate": "disecat",
    "disecați": "disecat",
    "disecția": "disecție",
    "disecției": "disecție",
    "disecții": "disecție",
    "disecțiile": "disecție",
    "disecțiilor": "disecție",
    "disecțio": "disecție",
    "diseminarea": "diseminare",
    "diseminareo": "diseminare",
    "diseminări": "diseminare",
    "diseminării": "diseminare",
    "diseminările": "diseminare",
    "diseminărilor": "diseminare",
    "diseminată": "diseminat",
    "disensiunea": "disensiune",
    "disensiuneo": "disensiune",
    "disensiuni": "disensiune",
    "disensiunii": "disensiune",
    "disensiunile": "disensiune",
    "disensiunilor": "disensiune",
    "disertă": "diserta",
    "disertai": "diserta",
    "disertam": "diserta",
    "disertăm": "diserta",
    "disertând": "diserta",
    "disertându": "diserta",
    "disertară": "diserta",
    "disertarăm": "diserta",
    "disertarăți": "diserta",
    "disertase": "diserta",
    "disertasem": "diserta",
    "disertaseră": "diserta",
    "disertaserăm": "diserta",
    "disertaserăți": "diserta",
    "disertaseși": "diserta",
    "disertași": "diserta",
    "disertat": "diserta",
    "disertați": "diserta",
    "disertatu": "diserta",
    "disertau": "diserta",
    "disertează": "diserta",
    "disertez": "diserta",
    "diserteze": "diserta",
    "disertezi": "diserta",
    "nedisertând": "diserta",
    "nedisertându": "diserta",
    "nemaidisertând": "diserta",
    "nemaidisertându": "diserta",
    "disertată": "disertat",
    "disertate": "disertat",
    "disertați": "disertat",
    "disfuncția": "disfuncție",
    "disfuncției": "disfuncție",
    "disfuncții": "disfuncție",
    "disfuncțiile": "disfuncție",
    "disfuncțiilor": "disfuncție",
    "disfuncționalitatea": "disfuncționalitate",
    "disfuncționalități": "disfuncționalitate",
    "disfuncționalității": "disfuncționalitate",
    "disfuncționalitățile": "disfuncționalitate",
    "disfuncționalităților": "disfuncționalitate",
    "disidenta": "disident",
    "disidentă": "disident",
    "disidente": "disident",
    "disidentei": "disident",
    "disidentele": "disident",
    "disidentelor": "disident",
    "disidenți": "disident",
    "disidenții": "disident",
    "disidenților": "disident",
    "disidento": "disident",
    "disidentul": "disident",
    "disidentule": "disident",
    "disidentului": "disident",
    "disidenta": "disidentă",
    "disidente": "disidentă",
    "disidentei": "disidentă",
    "disidentele": "disidentă",
    "disidentelor": "disidentă",
    "disidento": "disidentă",
    "disidența": "disidență",
    "disidențe": "disidență",
    "disidenței": "disidență",
    "disidențele": "disidență",
    "disidențelor": "disidență",
    "disidențo": "disidență",
    "disimetria": "disimetrie",
    "disimetriei": "disimetrie",
    "disimetrii": "disimetrie",
    "disimetriile": "disimetrie",
    "disimetriilor": "disimetrie",
    "disimetrio": "disimetrie",
    "disimilă": "disimila",
    "disimilai": "disimila",
    "disimilam": "disimila",
    "disimilăm": "disimila",
    "disimilând": "disimila",
    "disimilându": "disimila",
    "disimilară": "disimila",
    "disimilarăm": "disimila",
    "disimilarăți": "disimila",
    "disimilase": "disimila",
    "disimilasem": "disimila",
    "disimilaseră": "disimila",
    "disimilaserăm": "disimila",
    "disimilaserăți": "disimila",
    "disimilaseși": "disimila",
    "disimilași": "disimila",
    "disimilat": "disimila",
    "disimilați": "disimila",
    "disimilatu": "disimila",
    "disimilau": "disimila",
    "disimilează": "disimila",
    "disimilez": "disimila",
    "disimileze": "disimila",
    "disimilezi": "disimila",
    "nedisimilând": "disimila",
    "nedisimilându": "disimila",
    "nemaidisimilând": "disimila",
    "nemaidisimilându": "disimila",
    "disimilarea": "disimilare",
    "disimilareo": "disimilare",
    "disimilări": "disimilare",
    "disimilării": "disimilare",
    "disimilările": "disimilare",
    "disimilărilor": "disimilare",
    "disimilată": "disimilat",
    "disimilate": "disimilat",
    "disimilați": "disimilat",
    "disimilația": "disimilație",
    "disimilației": "disimilație",
    "disimilații": "disimilație",
    "disimilațiile": "disimilație",
    "disimilațiilor": "disimilație",
    "disimilațio": "disimilație",
    "disimulă": "disimula",
    "disimulai": "disimula",
    "disimulam": "disimula",
    "disimulăm": "disimula",
    "disimulând": "disimula",
    "disimulându": "disimula",
    "disimulară": "disimula",
    "disimularăm": "disimula",
    "disimularăți": "disimula",
    "disimulase": "disimula",
    "disimulasem": "disimula",
    "disimulaseră": "disimula",
    "disimulaserăm": "disimula",
    "disimulaserăți": "disimula",
    "disimulaseși": "disimula",
    "disimulași": "disimula",
    "disimulat": "disimula",
    "disimulați": "disimula",
    "disimulatu": "disimula",
    "disimulau": "disimula",
    "disimulează": "disimula",
    "disimulez": "disimula",
    "disimuleze": "disimula",
    "disimulezi": "disimula",
    "nedisimulând": "disimula",
    "nedisimulându": "disimula",
    "nemaidisimulând": "disimula",
    "nemaidisimulându": "disimula",
    "disimularea": "disimulare",
    "disimulareo": "disimulare",
    "disimulări": "disimulare",
    "disimulării": "disimulare",
    "disimulările": "disimulare",
    "disimulărilor": "disimulare",
    "disimulata": "disimulat",
    "disimulată": "disimulat",
    "disimulate": "disimulat",
    "disimulatei": "disimulat",
    "disimulatele": "disimulat",
    "disimulatelor": "disimulat",
    "disimulați": "disimulat",
    "disimulații": "disimulat",
    "disimulaților": "disimulat",
    "disimulato": "disimulat",
    "disimulatul": "disimulat",
    "disimulatule": "disimulat",
    "disimulatului": "disimulat",
    "disjunctiva": "disjunctiv",
    "disjunctivă": "disjunctiv",
    "disjunctive": "disjunctiv",
    "disjunctivei": "disjunctiv",
    "disjunctivele": "disjunctiv",
    "disjunctivelor": "disjunctiv",
    "disjunctivi": "disjunctiv",
    "disjunctivii": "disjunctiv",
    "disjunctivilor": "disjunctiv",
    "disjunctivo": "disjunctiv",
    "disjunctivul": "disjunctiv",
    "disjunctivule": "disjunctiv",
    "disjunctivului": "disjunctiv",
    "disjunctoare": "disjunctor",
    "disjunctoarele": "disjunctor",
    "disjunctoarelor": "disjunctor",
    "disjunctorul": "disjunctor",
    "disjunctorule": "disjunctor",
    "disjunctorului": "disjunctor",
    "disjung": "disjunge",
    "disjungă": "disjunge",
    "disjungând": "disjunge",
    "disjungându": "disjunge",
    "disjungea": "disjunge",
    "disjungeai": "disjunge",
    "disjungeam": "disjunge",
    "disjungeați": "disjunge",
    "disjungeau": "disjunge",
    "disjungem": "disjunge",
    "disjungeți": "disjunge",
    "disjungi": "disjunge",
    "disjuns": "disjunge",
    "disjunse": "disjunge",
    "disjunsei": "disjunge",
    "disjunseră": "disjunge",
    "disjunserăm": "disjunge",
    "disjunserăți": "disjunge",
    "disjunsese": "disjunge",
    "disjunsesem": "disjunge",
    "disjunseseră": "disjunge",
    "disjunseserăm": "disjunge",
    "disjunseserăți": "disjunge",
    "disjunseseși": "disjunge",
    "disjunseși": "disjunge",
    "disjunsu": "disjunge",
    "nedisjungând": "disjunge",
    "nedisjungându": "disjunge",
    "nemaidisjungând": "disjunge",
    "nemaidisjungându": "disjunge",
    "disjungerea": "disjungere",
    "disjungeri": "disjungere",
    "disjungerii": "disjungere",
    "disjungerile": "disjungere",
    "disjunsa": "disjuns",
    "disjunsă": "disjuns",
    "disjunse": "disjuns",
    "disjunsei": "disjuns",
    "disjunsele": "disjuns",
    "disjunselor": "disjuns",
    "disjunși": "disjuns",
    "disjunșii": "disjuns",
    "disjunșilor": "disjuns",
    "disjunsul": "disjuns",
    "disjunsului": "disjuns",
    "disloc": "disloca",
    "dislocă": "disloca",
    "dislocai": "disloca",
    "dislocam": "disloca",
    "dislocăm": "disloca",
    "dislocând": "disloca",
    "dislocându": "disloca",
    "dislocară": "disloca",
    "dislocarăm": "disloca",
    "dislocarăți": "disloca",
    "dislocase": "disloca",
    "dislocasem": "disloca",
    "dislocaseră": "disloca",
    "dislocaserăm": "disloca",
    "dislocaserăți": "disloca",
    "dislocaseși": "disloca",
    "dislocași": "disloca",
    "dislocat": "disloca",
    "dislocați": "disloca",
    "dislocatu": "disloca",
    "dislocau": "disloca",
    "disloce": "disloca",
    "disloci": "disloca",
    "nedislocând": "disloca",
    "nedislocându": "disloca",
    "nemaidislocând": "disloca",
    "nemaidislocându": "disloca",
    "dislocarea": "dislocare",
    "dislocareo": "dislocare",
    "dislocări": "dislocare",
    "dislocării": "dislocare",
    "dislocările": "dislocare",
    "dislocărilor": "dislocare",
    "dislocata": "dislocat",
    "dislocată": "dislocat",
    "dislocate": "dislocat",
    "dislocatei": "dislocat",
    "dislocatele": "dislocat",
    "dislocatelor": "dislocat",
    "dislocați": "dislocat",
    "dislocații": "dislocat",
    "dislocaților": "dislocat",
    "dislocato": "dislocat",
    "dislocatul": "dislocat",
    "dislocatule": "dislocat",
    "dislocatului": "dislocat",
    "disociai": "disocia",
    "disociam": "disocia",
    "disociară": "disocia",
    "disociarăm": "disocia",
    "disociarăți": "disocia",
    "disociase": "disocia",
    "disociasem": "disocia",
    "disociaseră": "disocia",
    "disociaserăm": "disocia",
    "disociaserăți": "disocia",
    "disociaseși": "disocia",
    "disociași": "disocia",
    "disociat": "disocia",
    "disociați": "disocia",
    "disociatu": "disocia",
    "disociau": "disocia",
    "disociază": "disocia",
    "disocie": "disocia",
    "disociem": "disocia",
    "disociez": "disocia",
    "disocieze": "disocia",
    "disociezi": "disocia",
    "disociind": "disocia",
    "disociindu": "disocia",
    "nedisociind": "disocia",
    "nedisociindu": "disocia",
    "nemaidisociind": "disocia",
    "nemaidisociindu": "disocia",
    "disociata": "disociat",
    "disociată": "disociat",
    "disociate": "disociat",
    "disociatei": "disociat",
    "disociatele": "disociat",
    "disociatelor": "disociat",
    "disociați": "disociat",
    "disociații": "disociat",
    "disociaților": "disociat",
    "disociato": "disociat",
    "disociatul": "disociat",
    "disociatule": "disociat",
    "disociatului": "disociat",
    "disociația": "disociație",
    "disociației": "disociație",
    "disociații": "disociație",
    "disociațiile": "disociație",
    "disociațiilor": "disociație",
    "disociațio": "disociație",
    "disociativa": "disociativ",
    "disociativă": "disociativ",
    "disociative": "disociativ",
    "disociativei": "disociativ",
    "disociativele": "disociativ",
    "disociativelor": "disociativ",
    "disociativi": "disociativ",
    "disociativii": "disociativ",
    "disociativilor": "disociativ",
    "disociativo": "disociativ",
    "disociativul": "disociativ",
    "disociativule": "disociativ",
    "disociativului": "disociativ",
    "disocierea": "disociere",
    "disociereo": "disociere",
    "disocieri": "disociere",
    "disocierii": "disociere",
    "disocierile": "disociere",
    "disocierilor": "disociere",
    "disoluția": "disoluție",
    "disoluției": "disoluție",
    "disoluții": "disoluție",
    "disoluțiile": "disoluție",
    "disoluțiilor": "disoluție",
    "disoluțio": "disoluție",
    "disonanta": "disonant",
    "disonantă": "disonant",
    "disonante": "disonant",
    "disonantei": "disonant",
    "disonantele": "disonant",
    "disonantelor": "disonant",
    "disonanți": "disonant",
    "disonanții": "disonant",
    "disonanților": "disonant",
    "disonanto": "disonant",
    "disonantul": "disonant",
    "disonantule": "disonant",
    "disonantului": "disonant",
    "disonanța": "disonanță",
    "disonanțe": "disonanță",
    "disonanței": "disonanță",
    "disonanțele": "disonanță",
    "disonanțelor": "disonanță",
    "disonanțo": "disonanță",
    "disparata": "disparat",
    "disparată": "disparat",
    "disparate": "disparat",
    "disparatei": "disparat",
    "disparatele": "disparat",
    "disparatelor": "disparat",
    "disparați": "disparat",
    "disparații": "disparat",
    "disparaților": "disparat",
    "disparato": "disparat",
    "disparatul": "disparat",
    "disparatule": "disparat",
    "disparatului": "disparat",
    "dispar": "dispărea",
    "dispară": "dispărea",
    "dispărând": "dispărea",
    "dispărându": "dispărea",
    "dispare": "dispărea",
    "dispăreai": "dispărea",
    "dispăream": "dispărea",
    "dispăreați": "dispărea",
    "dispăreau": "dispărea",
    "dispărem": "dispărea",
    "dispăreți": "dispărea",
    "dispari": "dispărea",
    "dispăru": "dispărea",
    "dispăru'": "dispărea",
    "dispărui": "dispărea",
    "dispărură": "dispărea",
    "dispărurăm": "dispărea",
    "dispărurăți": "dispărea",
    "dispăruse": "dispărea",
    "dispărusem": "dispărea",
    "dispăruseră": "dispărea",
    "dispăruserăm": "dispărea",
    "dispăruserăți": "dispărea",
    "dispăruseși": "dispărea",
    "dispăruși": "dispărea",
    "dispărut": "dispărea",
    "dispărutu": "dispărea",
    "nedispărând": "dispărea",
    "nedispărându": "dispărea",
    "nemaidispărând": "dispărea",
    "nemaidispărându": "dispărea",
    "dispariția": "dispariție",
    "dispariției": "dispariție",
    "dispariții": "dispariție",
    "disparițiile": "dispariție",
    "disparițiilor": "dispariție",
    "disparițio": "dispariție",
    "dispăru'": "dispărut",
    "dispăruta": "dispărut",
    "dispărută": "dispărut",
    "dispărute": "dispărut",
    "dispărutei": "dispărut",
    "dispărutele": "dispărut",
    "dispărutelor": "dispărut",
    "dispăruți": "dispărut",
    "dispăruții": "dispărut",
    "dispăruților": "dispărut",
    "dispăruto": "dispărut",
    "dispărutul": "dispărut",
    "dispărutule": "dispărut",
    "dispărutului": "dispărut",
    "dispeceri": "dispecer",
    "dispecerii": "dispecer",
    "dispecerilor": "dispecer",
    "dispecerul": "dispecer",
    "dispecerule": "dispecer",
    "dispecerului": "dispecer",
    "dispecerate": "dispecerat",
    "dispeceratele": "dispecerat",
    "dispeceratelor": "dispecerat",
    "dispeceratul": "dispecerat",
    "dispeceratule": "dispecerat",
    "dispeceratului": "dispecerat",
    "dispensă": "dispensa",
    "dispensai": "dispensa",
    "dispensam": "dispensa",
    "dispensăm": "dispensa",
    "dispensând": "dispensa",
    "dispensându": "dispensa",
    "dispensară": "dispensa",
    "dispensarăm": "dispensa",
    "dispensarăți": "dispensa",
    "dispensase": "dispensa",
    "dispensasem": "dispensa",
    "dispensaseră": "dispensa",
    "dispensaserăm": "dispensa",
    "dispensaserăți": "dispensa",
    "dispensaseși": "dispensa",
    "dispensași": "dispensa",
    "dispensat": "dispensa",
    "dispensați": "dispensa",
    "dispensatu": "dispensa",
    "dispensau": "dispensa",
    "dispensează": "dispensa",
    "dispensez": "dispensa",
    "dispenseze": "dispensa",
    "dispensezi": "dispensa",
    "nedispensând": "dispensa",
    "nedispensându": "dispensa",
    "nemaidispensând": "dispensa",
    "nemaidispensându": "dispensa",
    "dispensa": "dispensă",
    "dispense": "dispensă",
    "dispensei": "dispensă",
    "dispensele": "dispensă",
    "dispenselor": "dispensă",
    "dispenso": "dispensă",
    "dispensare": "dispensar",
    "dispensarele": "dispensar",
    "dispensarelor": "dispensar",
    "dispensarul": "dispensar",
    "dispensarule": "dispensar",
    "dispensarului": "dispensar",
    "dispensarea": "dispensare",
    "dispensareo": "dispensare",
    "dispensări": "dispensare",
    "dispensării": "dispensare",
    "dispensările": "dispensare",
    "dispensărilor": "dispensare",
    "dispensata": "dispensat",
    "dispensată": "dispensat",
    "dispensate": "dispensat",
    "dispensatei": "dispensat",
    "dispensatele": "dispensat",
    "dispensatelor": "dispensat",
    "dispensați": "dispensat",
    "dispensații": "dispensat",
    "dispensaților": "dispensat",
    "dispensato": "dispensat",
    "dispensatul": "dispensat",
    "dispensatule": "dispensat",
    "dispensatului": "dispensat",
    "disper": "dispera",
    "disperă": "dispera",
    "disperai": "dispera",
    "disperam": "dispera",
    "disperăm": "dispera",
    "disperând": "dispera",
    "disperându": "dispera",
    "disperară": "dispera",
    "disperarăm": "dispera",
    "disperarăți": "dispera",
    "disperase": "dispera",
    "disperasem": "dispera",
    "disperaseră": "dispera",
    "disperaserăm": "dispera",
    "disperaserăți": "dispera",
    "disperaseși": "dispera",
    "disperași": "dispera",
    "disperat": "dispera",
    "disperați": "dispera",
    "disperatu": "dispera",
    "disperau": "dispera",
    "dispere": "dispera",
    "disperi": "dispera",
    "nedisperând": "dispera",
    "nedisperându": "dispera",
    "nemaidisperând": "dispera",
    "nemaidisperându": "dispera",
    "disperarea": "disperare",
    "disperareo": "disperare",
    "disperări": "disperare",
    "disperării": "disperare",
    "disperările": "disperare",
    "disperărilor": "disperare",
    "disperata": "disperat",
    "disperată": "disperat",
    "disperate": "disperat",
    "disperatei": "disperat",
    "disperatele": "disperat",
    "disperatelor": "disperat",
    "disperați": "disperat",
    "disperații": "disperat",
    "disperaților": "disperat",
    "disperato": "disperat",
    "disperatul": "disperat",
    "disperatule": "disperat",
    "disperatului": "disperat",
    "dispersa": "dispers",
    "dispersă": "dispers",
    "disperse": "dispers",
    "dispersei": "dispers",
    "dispersele": "dispers",
    "disperselor": "dispers",
    "disperși": "dispers",
    "disperșii": "dispers",
    "disperșilor": "dispers",
    "disperso": "dispers",
    "dispersul": "dispers",
    "dispersule": "dispers",
    "dispersului": "dispers",
    "dispersă": "dispersa",
    "dispersai": "dispersa",
    "dispersam": "dispersa",
    "dispersăm": "dispersa",
    "dispersând": "dispersa",
    "dispersându": "dispersa",
    "dispersară": "dispersa",
    "dispersarăm": "dispersa",
    "dispersarăți": "dispersa",
    "dispersase": "dispersa",
    "dispersasem": "dispersa",
    "dispersaseră": "dispersa",
    "dispersaserăm": "dispersa",
    "dispersaserăți": "dispersa",
    "dispersaseși": "dispersa",
    "dispersași": "dispersa",
    "dispersat": "dispersa",
    "dispersați": "dispersa",
    "dispersatu": "dispersa",
    "dispersau": "dispersa",
    "dispersează": "dispersa",
    "dispersez": "dispersa",
    "disperseze": "dispersa",
    "dispersezi": "dispersa",
    "nedispersând": "dispersa",
    "nedispersându": "dispersa",
    "nemaidispersând": "dispersa",
    "nemaidispersându": "dispersa",
    "dispersarea": "dispersare",
    "dispersareo": "dispersare",
    "dispersări": "dispersare",
    "dispersării": "dispersare",
    "dispersările": "dispersare",
    "dispersărilor": "dispersare",
    "dispersata": "dispersat",
    "dispersată": "dispersat",
    "dispersate": "dispersat",
    "dispersatei": "dispersat",
    "dispersatele": "dispersat",
    "dispersatelor": "dispersat",
    "dispersați": "dispersat",
    "dispersații": "dispersat",
    "dispersaților": "dispersat",
    "dispersato": "dispersat",
    "dispersatul": "dispersat",
    "dispersatule": "dispersat",
    "dispersatului": "dispersat",
    "dispersiva": "dispersiv",
    "dispersivă": "dispersiv",
    "dispersive": "dispersiv",
    "dispersivei": "dispersiv",
    "dispersivele": "dispersiv",
    "dispersivelor": "dispersiv",
    "dispersivi": "dispersiv",
    "dispersivii": "dispersiv",
    "dispersivilor": "dispersiv",
    "dispersivo": "dispersiv",
    "dispersivul": "dispersiv",
    "dispersivule": "dispersiv",
    "dispersivului": "dispersiv",
    "displac": "displăcea",
    "displacă": "displăcea",
    "displăcând": "displăcea",
    "displăcându": "displăcea",
    "displace": "displăcea",
    "displăceai": "displăcea",
    "displăceam": "displăcea",
    "displăceați": "displăcea",
    "displăceau": "displăcea",
    "displăcem": "displăcea",
    "displăceți": "displăcea",
    "displaci": "displăcea",
    "displăcu": "displăcea",
    "displăcui": "displăcea",
    "displăcură": "displăcea",
    "displăcurăm": "displăcea",
    "displăcurăți": "displăcea",
    "displăcuse": "displăcea",
    "displăcusem": "displăcea",
    "displăcuseră": "displăcea",
    "displăcuserăm": "displăcea",
    "displăcuserăți": "displăcea",
    "displăcuseși": "displăcea",
    "displăcuși": "displăcea",
    "displăcut": "displăcea",
    "displăcutu": "displăcea",
    "nedisplăcând": "displăcea",
    "nedisplăcându": "displăcea",
    "nemaidisplăcând": "displăcea",
    "nemaidisplăcându": "displăcea",
    "displăcuta": "displăcut",
    "displăcută": "displăcut",
    "displăcute": "displăcut",
    "displăcutei": "displăcut",
    "displăcutele": "displăcut",
    "displăcutelor": "displăcut",
    "displăcuți": "displăcut",
    "displăcuții": "displăcut",
    "displăcuților": "displăcut",
    "displăcuto": "displăcut",
    "displăcutul": "displăcut",
    "displăcutule": "displăcut",
    "displăcutului": "displăcut",
    "dispneea": "dispnee",
    "dispneei": "dispnee",
    "dispneele": "dispnee",
    "dispneelor": "dispnee",
    "dispneeo": "dispnee",
    "disponibila": "disponibil",
    "disponibilă": "disponibil",
    "disponibile": "disponibil",
    "disponibilei": "disponibil",
    "disponibilele": "disponibil",
    "disponibilelor": "disponibil",
    "disponibili": "disponibil",
    "disponibilii": "disponibil",
    "disponibililor": "disponibil",
    "disponibilo": "disponibil",
    "disponibilul": "disponibil",
    "disponibilule": "disponibil",
    "disponibilului": "disponibil",
    "disponibilitatea": "disponibilitate",
    "disponibilitateo": "disponibilitate",
    "disponibilități": "disponibilitate",
    "disponibilității": "disponibilitate",
    "disponibilitățile": "disponibilitate",
    "disponibilităților": "disponibilitate",
    "disponibilizarea": "disponibilizare",
    "disponibilizări": "disponibilizare",
    "disponibilizării": "disponibilizare",
    "disponibilizările": "disponibilizare",
    "disponibilizărilor": "disponibilizare",
    "disponibilizată": "disponibilizat",
    "disponibilizate": "disponibilizat",
    "disponibilizați": "disponibilizat",
    "dispoziția": "dispoziție",
    "dispoziției": "dispoziție",
    "dispoziții": "dispoziție",
    "dispozițiile": "dispoziție",
    "dispozițiilor": "dispoziție",
    "dispozițio": "dispoziție",
    "dispozițiunea": "dispozițiune",
    "dispozițiuneo": "dispozițiune",
    "dispozițiuni": "dispozițiune",
    "dispozițiunii": "dispozițiune",
    "dispozițiunile": "dispozițiune",
    "dispozițiunilor": "dispozițiune",
    "dispozitive": "dispozitiv",
    "dispozitivele": "dispozitiv",
    "dispozitivelor": "dispozitiv",
    "dispozitivul": "dispozitiv",
    "dispozitivule": "dispozitiv",
    "dispozitivului": "dispozitiv",
    "disprețul": "dispreț",
    "disprețule": "dispreț",
    "disprețului": "dispreț",
    "disprețuri": "dispreț",
    "disprețurile": "dispreț",
    "disprețurilor": "dispreț",
    "disprețuia": "disprețui",
    "disprețuiai": "disprețui",
    "disprețuiam": "disprețui",
    "disprețuiască": "disprețui",
    "disprețuiați": "disprețui",
    "disprețuiau": "disprețui",
    "disprețuiesc": "disprețui",
    "disprețuiește": "disprețui",
    "disprețuiești": "disprețui",
    "disprețuii": "disprețui",
    "disprețuim": "disprețui",
    "disprețuind": "disprețui",
    "disprețuindu": "disprețui",
    "disprețuiră": "disprețui",
    "disprețuirăm": "disprețui",
    "disprețuirăți": "disprețui",
    "disprețuise": "disprețui",
    "disprețuisem": "disprețui",
    "disprețuiseră": "disprețui",
    "disprețuiserăm": "disprețui",
    "disprețuiserăți": "disprețui",
    "disprețuiseși": "disprețui",
    "disprețuiși": "disprețui",
    "disprețuit": "disprețui",
    "disprețuiți": "disprețui",
    "disprețuitu": "disprețui",
    "nedisprețuind": "disprețui",
    "nedisprețuindu": "disprețui",
    "nemaidisprețuind": "disprețui",
    "nemaidisprețuindu": "disprețui",
    "disprețuirea": "disprețuire",
    "disprețuireo": "disprețuire",
    "disprețuiri": "disprețuire",
    "disprețuirii": "disprețuire",
    "disprețuirile": "disprețuire",
    "disprețuirilor": "disprețuire",
    "disprețuita": "disprețuit",
    "disprețuită": "disprețuit",
    "disprețuite": "disprețuit",
    "disprețuitei": "disprețuit",
    "disprețuitele": "disprețuit",
    "disprețuitelor": "disprețuit",
    "disprețuiți": "disprețuit",
    "disprețuiții": "disprețuit",
    "disprețuiților": "disprețuit",
    "disprețuito": "disprețuit",
    "disprețuitul": "disprețuit",
    "disprețuitule": "disprețuit",
    "disprețuitului": "disprețuit",
    "disprețuitoare": "disprețuitor",
    "disprețuitoarea": "disprețuitor",
    "disprețuitoarei": "disprețuitor",
    "disprețuitoarele": "disprețuitor",
    "disprețuitoarelor": "disprețuitor",
    "disprețuitoareo": "disprețuitor",
    "disprețuitori": "disprețuitor",
    "disprețuitorii": "disprețuitor",
    "disprețuitorilor": "disprețuitor",
    "disprețuitorul": "disprețuitor",
    "disprețuitorule": "disprețuitor",
    "disprețuitorului": "disprețuitor",
    "disproporția": "disproporție",
    "disproporției": "disproporție",
    "disproporții": "disproporție",
    "disproporțiile": "disproporție",
    "disproporțiilor": "disproporție",
    "disproporțio": "disproporție",
    "disproporționata": "disproporționat",
    "disproporționată": "disproporționat",
    "disproporționate": "disproporționat",
    "disproporționatei": "disproporționat",
    "disproporționatele": "disproporționat",
    "disproporționatelor": "disproporționat",
    "disproporționați": "disproporționat",
    "disproporționații": "disproporționat",
    "disproporționaților": "disproporționat",
    "disproporționato": "disproporționat",
    "disproporționatul": "disproporționat",
    "disproporționatule": "disproporționat",
    "disproporționatului": "disproporționat",
    "dispui": "dispune",
    "dispun": "dispune",
    "dispună": "dispune",
    "dispunând": "dispune",
    "dispunându": "dispune",
    "dispunea": "dispune",
    "dispuneai": "dispune",
    "dispuneam": "dispune",
    "dispuneați": "dispune",
    "dispuneau": "dispune",
    "dispunem": "dispune",
    "dispuneți": "dispune",
    "dispus": "dispune",
    "dispuse": "dispune",
    "dispusei": "dispune",
    "dispuseră": "dispune",
    "dispuserăm": "dispune",
    "dispuserăți": "dispune",
    "dispusese": "dispune",
    "dispusesem": "dispune",
    "dispuseseră": "dispune",
    "dispuseserăm": "dispune",
    "dispuseserăți": "dispune",
    "dispuseseși": "dispune",
    "dispuseși": "dispune",
    "dispusu": "dispune",
    "nedispunând": "dispune",
    "nedispunându": "dispune",
    "nemaidispunând": "dispune",
    "nemaidispunându": "dispune",
    "dispunerea": "dispunere",
    "dispunereo": "dispunere",
    "dispuneri": "dispunere",
    "dispunerii": "dispunere",
    "dispunerile": "dispunere",
    "dispunerilor": "dispunere",
    "dispusa": "dispus",
    "dispusă": "dispus",
    "dispuse": "dispus",
    "dispusei": "dispus",
    "dispusele": "dispus",
    "dispuselor": "dispus",
    "dispuși": "dispus",
    "dispușii": "dispus",
    "dispușilor": "dispus",
    "dispuso": "dispus",
    "dispusul": "dispus",
    "dispusule": "dispus",
    "dispusului": "dispus",
    "disput": "disputa",
    "dispută": "disputa",
    "disputai": "disputa",
    "disputam": "disputa",
    "disputăm": "disputa",
    "disputând": "disputa",
    "disputându": "disputa",
    "disputară": "disputa",
    "disputarăm": "disputa",
    "disputarăți": "disputa",
    "disputase": "disputa",
    "disputasem": "disputa",
    "disputaseră": "disputa",
    "disputaserăm": "disputa",
    "disputaserăți": "disputa",
    "disputaseși": "disputa",
    "disputași": "disputa",
    "disputat": "disputa",
    "disputați": "disputa",
    "disputatu": "disputa",
    "disputau": "disputa",
    "dispute": "disputa",
    "dispuți": "disputa",
    "nedisputând": "disputa",
    "nedisputându": "disputa",
    "nemaidisputând": "disputa",
    "nemaidisputându": "disputa",
    "disputa": "dispută",
    "dispute": "dispută",
    "disputei": "dispută",
    "disputele": "dispută",
    "disputelor": "dispută",
    "disputo": "dispută",
    "disputarea": "disputare",
    "disputareo": "disputare",
    "disputări": "disputare",
    "disputării": "disputare",
    "disputările": "disputare",
    "disputărilor": "disputare",
    "disputată": "disputat",
    "disputate": "disputat",
    "disputați": "disputat",
    "distanta": "distant",
    "distantă": "distant",
    "distante": "distant",
    "distantei": "distant",
    "distantele": "distant",
    "distantelor": "distant",
    "distanți": "distant",
    "distanții": "distant",
    "distanților": "distant",
    "distanto": "distant",
    "distantul": "distant",
    "distantule": "distant",
    "distantului": "distant",
    "distanță": "distanța",
    "distanțai": "distanța",
    "distanțam": "distanța",
    "distanțăm": "distanța",
    "distanțând": "distanța",
    "distanțându": "distanța",
    "distanțară": "distanța",
    "distanțarăm": "distanța",
    "distanțarăți": "distanța",
    "distanțase": "distanța",
    "distanțasem": "distanța",
    "distanțaseră": "distanța",
    "distanțaserăm": "distanța",
    "distanțaserăți": "distanța",
    "distanțaseși": "distanța",
    "distanțași": "distanța",
    "distanțat": "distanța",
    "distanțați": "distanța",
    "distanțatu": "distanța",
    "distanțau": "distanța",
    "distanțează": "distanța",
    "distanțez": "distanța",
    "distanțeze": "distanța",
    "distanțezi": "distanța",
    "nedistanțând": "distanța",
    "nedistanțându": "distanța",
    "nemaidistanțând": "distanța",
    "nemaidistanțându": "distanța",
    "distanța": "distanță",
    "distanțe": "distanță",
    "distanței": "distanță",
    "distanțele": "distanță",
    "distanțelor": "distanță",
    "distanțo": "distanță",
    "distanțarea": "distanțare",
    "distanțareo": "distanțare",
    "distanțări": "distanțare",
    "distanțării": "distanțare",
    "distanțările": "distanțare",
    "distanțărilor": "distanțare",
    "distanțată": "distanțat",
    "distanțate": "distanțat",
    "distanțați": "distanțat",
    "distanțiere": "distanțier",
    "distanțierele": "distanțier",
    "distanțierelor": "distanțier",
    "distanțierul": "distanțier",
    "distanțierule": "distanțier",
    "distanțierului": "distanțier",
    "distihul": "distih",
    "distihule": "distih",
    "distihului": "distih",
    "distihuri": "distih",
    "distihurile": "distih",
    "distihurilor": "distih",
    "distilă": "distila",
    "distilai": "distila",
    "distilam": "distila",
    "distilăm": "distila",
    "distilând": "distila",
    "distilându": "distila",
    "distilară": "distila",
    "distilarăm": "distila",
    "distilarăți": "distila",
    "distilase": "distila",
    "distilasem": "distila",
    "distilaseră": "distila",
    "distilaserăm": "distila",
    "distilaserăți": "distila",
    "distilaseși": "distila",
    "distilași": "distila",
    "distilat": "distila",
    "distilați": "distila",
    "distilatu": "distila",
    "distilau": "distila",
    "distilează": "distila",
    "distilez": "distila",
    "distileze": "distila",
    "distilezi": "distila",
    "nedistilând": "distila",
    "nedistilându": "distila",
    "nemaidistilând": "distila",
    "nemaidistilându": "distila",
    "distilarea": "distilare",
    "distilareo": "distilare",
    "distilări": "distilare",
    "distilării": "distilare",
    "distilările": "distilare",
    "distilărilor": "distilare",
    "distilata": "distilat",
    "distilată": "distilat",
    "distilate": "distilat",
    "distilatei": "distilat",
    "distilatele": "distilat",
    "distilatelor": "distilat",
    "distilați": "distilat",
    "distilații": "distilat",
    "distilaților": "distilat",
    "distilato": "distilat",
    "distilatul": "distilat",
    "distilatule": "distilat",
    "distilatului": "distilat",
    "distilatoarea": "distilatoare",
    "distilatoarei": "distilatoare",
    "distilatoarele": "distilatoare",
    "distilatoarelor": "distilatoare",
    "distilatoareo": "distilatoare",
    "distilatoare": "distilator",
    "distilatoarele": "distilator",
    "distilatoarelor": "distilator",
    "distilatori": "distilator",
    "distilatorii": "distilator",
    "distilatorilor": "distilator",
    "distilatorul": "distilator",
    "distilatorule": "distilator",
    "distilatorului": "distilator",
    "distileria": "distilerie",
    "distileriei": "distilerie",
    "distilerii": "distilerie",
    "distileriile": "distilerie",
    "distileriilor": "distilerie",
    "distilerio": "distilerie",
    "distincta": "distinct",
    "distinctă": "distinct",
    "distincte": "distinct",
    "distinctei": "distinct",
    "distinctele": "distinct",
    "distinctelor": "distinct",
    "distincți": "distinct",
    "distincții": "distinct",
    "distincților": "distinct",
    "distincto": "distinct",
    "distinctul": "distinct",
    "distinctule": "distinct",
    "distinctului": "distinct",
    "distincția": "distincție",
    "distincției": "distincție",
    "distincții": "distincție",
    "distincțiile": "distincție",
    "distincțiilor": "distincție",
    "distincțio": "distincție",
    "distinctiva": "distinctiv",
    "distinctivă": "distinctiv",
    "distinctive": "distinctiv",
    "distinctivei": "distinctiv",
    "distinctivele": "distinctiv",
    "distinctivelor": "distinctiv",
    "distinctivi": "distinctiv",
    "distinctivii": "distinctiv",
    "distinctivilor": "distinctiv",
    "distinctivo": "distinctiv",
    "distinctivul": "distinctiv",
    "distinctivule": "distinctiv",
    "distinctivului": "distinctiv",
    "disting": "distinge",
    "distingă": "distinge",
    "distingând": "distinge",
    "distingându": "distinge",
    "distingea": "distinge",
    "distingeai": "distinge",
    "distingeam": "distinge",
    "distingeați": "distinge",
    "distingeau": "distinge",
    "distingem": "distinge",
    "distingeți": "distinge",
    "distingi": "distinge",
    "distins": "distinge",
    "distinse": "distinge",
    "distinsei": "distinge",
    "distinseră": "distinge",
    "distinserăm": "distinge",
    "distinserăți": "distinge",
    "distinsese": "distinge",
    "distinsesem": "distinge",
    "distinseseră": "distinge",
    "distinseserăm": "distinge",
    "distinseserăți": "distinge",
    "distinseseși": "distinge",
    "distinseși": "distinge",
    "distinsu": "distinge",
    "nedistingând": "distinge",
    "nedistingându": "distinge",
    "nemaidistingând": "distinge",
    "nemaidistingându": "distinge",
    "distingerea": "distingere",
    "distingereo": "distingere",
    "distingeri": "distingere",
    "distingerii": "distingere",
    "distingerile": "distingere",
    "distingerilor": "distingere",
    "distinsa": "distins",
    "distinsă": "distins",
    "distinse": "distins",
    "distinsei": "distins",
    "distinsele": "distins",
    "distinselor": "distins",
    "distinși": "distins",
    "distinșii": "distins",
    "distinșilor": "distins",
    "distinso": "distins",
    "distinsul": "distins",
    "distinsule": "distins",
    "distinsului": "distins",
    "distonă": "distona",
    "distonai": "distona",
    "distonam": "distona",
    "distonăm": "distona",
    "distonând": "distona",
    "distonându": "distona",
    "distonară": "distona",
    "distonarăm": "distona",
    "distonarăți": "distona",
    "distonase": "distona",
    "distonasem": "distona",
    "distonaseră": "distona",
    "distonaserăm": "distona",
    "distonaserăți": "distona",
    "distonaseși": "distona",
    "distonași": "distona",
    "distonat": "distona",
    "distonați": "distona",
    "distonatu": "distona",
    "distonau": "distona",
    "distonează": "distona",
    "distonez": "distona",
    "distoneze": "distona",
    "distonezi": "distona",
    "nedistonând": "distona",
    "nedistonându": "distona",
    "nemaidistonând": "distona",
    "nemaidistonându": "distona",
    "distonanta": "distonant",
    "distonantă": "distonant",
    "distonante": "distonant",
    "distonantei": "distonant",
    "distonantele": "distonant",
    "distonantelor": "distonant",
    "distonanți": "distonant",
    "distonanții": "distonant",
    "distonanților": "distonant",
    "distonanto": "distonant",
    "distonantul": "distonant",
    "distonantule": "distonant",
    "distonantului": "distonant",
    "distonată": "distonat",
    "distonate": "distonat",
    "distonați": "distonat",
    "distorsionă": "distorsiona",
    "distorsionai": "distorsiona",
    "distorsionam": "distorsiona",
    "distorsionăm": "distorsiona",
    "distorsionând": "distorsiona",
    "distorsionându": "distorsiona",
    "distorsionară": "distorsiona",
    "distorsionarăm": "distorsiona",
    "distorsionarăți": "distorsiona",
    "distorsionase": "distorsiona",
    "distorsionasem": "distorsiona",
    "distorsionaseră": "distorsiona",
    "distorsionaserăm": "distorsiona",
    "distorsionaserăți": "distorsiona",
    "distorsionaseși": "distorsiona",
    "distorsionași": "distorsiona",
    "distorsionat": "distorsiona",
    "distorsionați": "distorsiona",
    "distorsionatu": "distorsiona",
    "distorsionau": "distorsiona",
    "distorsionează": "distorsiona",
    "distorsionez": "distorsiona",
    "distorsioneze": "distorsiona",
    "distorsionezi": "distorsiona",
    "nedistorsionând": "distorsiona",
    "nedistorsionându": "distorsiona",
    "nemaidistorsionând": "distorsiona",
    "nemaidistorsionându": "distorsiona",
    "distorsionata": "distorsionat",
    "distorsionată": "distorsionat",
    "distorsionate": "distorsionat",
    "distorsionatei": "distorsionat",
    "distorsionatele": "distorsionat",
    "distorsionatelor": "distorsionat",
    "distorsionați": "distorsionat",
    "distorsionații": "distorsionat",
    "distorsionaților": "distorsionat",
    "distorsionato": "distorsionat",
    "distorsionatul": "distorsionat",
    "distorsionatule": "distorsionat",
    "distorsionatului": "distorsionat",
    "distorsiunea": "distorsiune",
    "distorsiuneo": "distorsiune",
    "distorsiuni": "distorsiune",
    "distorsiunii": "distorsiune",
    "distorsiunile": "distorsiune",
    "distorsiunilor": "distorsiune",
    "distră": "distra",
    "distrai": "distra",
    "distram": "distra",
    "distrăm": "distra",
    "distrând": "distra",
    "distrându": "distra",
    "distrară": "distra",
    "distrarăm": "distra",
    "distrarăți": "distra",
    "distrase": "distra",
    "distrasem": "distra",
    "distraseră": "distra",
    "distraserăm": "distra",
    "distraserăți": "distra",
    "distraseși": "distra",
    "distrași": "distra",
    "distrat": "distra",
    "distrați": "distra",
    "distratu": "distra",
    "distrau": "distra",
    "distrează": "distra",
    "distrez": "distra",
    "distreze": "distra",
    "distrezi": "distra",
    "nedistrând": "distra",
    "nedistrându": "distra",
    "nemaidistrând": "distra",
    "nemaidistrându": "distra",
    "distracția": "distracție",
    "distracției": "distracție",
    "distracții": "distracție",
    "distracțiile": "distracție",
    "distracțiilor": "distracție",
    "distracțio": "distracție",
    "distractiva": "distractiv",
    "distractivă": "distractiv",
    "distractive": "distractiv",
    "distractivei": "distractiv",
    "distractivele": "distractiv",
    "distractivelor": "distractiv",
    "distractivi": "distractiv",
    "distractivii": "distractiv",
    "distractivilor": "distractiv",
    "distractivo": "distractiv",
    "distractivul": "distractiv",
    "distractivule": "distractiv",
    "distractivului": "distractiv",
    "distrag": "distrage",
    "distragă": "distrage",
    "distrăgând": "distrage",
    "distrăgându": "distrage",
    "distrăgea": "distrage",
    "distrăgeai": "distrage",
    "distrăgeam": "distrage",
    "distrăgeați": "distrage",
    "distrăgeau": "distrage",
    "distragem": "distrage",
    "distrageți": "distrage",
    "distragi": "distrage",
    "distras": "distrage",
    "distrase": "distrage",
    "distrăsei": "distrage",
    "distraseră": "distrage",
    "distraserăm": "distrage",
    "distraserăți": "distrage",
    "distrăsese": "distrage",
    "distrăsesem": "distrage",
    "distrăseseră": "distrage",
    "distrăseserăm": "distrage",
    "distrăseserăți": "distrage",
    "distrăseseși": "distrage",
    "distrăseși": "distrage",
    "distrasu": "distrage",
    "nedistrăgând": "distrage",
    "nedistrăgându": "distrage",
    "nemaidistrăgând": "distrage",
    "nemaidistrăgându": "distrage",
    "distragerea": "distragere",
    "distragereo": "distragere",
    "distrageri": "distragere",
    "distragerii": "distragere",
    "distragerile": "distragere",
    "distragerilor": "distragere",
    "distrasa": "distras",
    "distrasă": "distras",
    "distrase": "distras",
    "distrasei": "distras",
    "distrasele": "distras",
    "distraselor": "distras",
    "distrași": "distras",
    "distrașii": "distras",
    "distrașilor": "distras",
    "distraso": "distras",
    "distrasul": "distras",
    "distrasule": "distras",
    "distrasului": "distras",
    "distrata": "distrat",
    "distrată": "distrat",
    "distrate": "distrat",
    "distratei": "distrat",
    "distratele": "distrat",
    "distratelor": "distrat",
    "distrați": "distrat",
    "distrații": "distrat",
    "distraților": "distrat",
    "distrato": "distrat",
    "distratul": "distrat",
    "distratule": "distrat",
    "distratului": "distrat",
    "distribuia": "distribui",
    "distribuiai": "distribui",
    "distribuiam": "distribui",
    "distribuiați": "distribui",
    "distribuiau": "distribui",
    "distribuie": "distribui",
    "distribuii": "distribui",
    "distribuim": "distribui",
    "distribuind": "distribui",
    "distribuindu": "distribui",
    "distribuiră": "distribui",
    "distribuirăm": "distribui",
    "distribuirăți": "distribui",
    "distribuise": "distribui",
    "distribuisem": "distribui",
    "distribuiseră": "distribui",
    "distribuiserăm": "distribui",
    "distribuiserăți": "distribui",
    "distribuiseși": "distribui",
    "distribuiși": "distribui",
    "distribuit": "distribui",
    "distribuiți": "distribui",
    "distribuitu": "distribui",
    "nedistribuind": "distribui",
    "nedistribuindu": "distribui",
    "nemaidistribuind": "distribui",
    "nemaidistribuindu": "distribui",
    "distribuirea": "distribuire",
    "distribuireo": "distribuire",
    "distribuiri": "distribuire",
    "distribuirii": "distribuire",
    "distribuirile": "distribuire",
    "distribuirilor": "distribuire",
    "distribuită": "distribuit",
    "distribuite": "distribuit",
    "distribuiți": "distribuit",
    "distribuitoarea": "distribuitoare",
    "distribuitoarei": "distribuitoare",
    "distribuitoarele": "distribuitoare",
    "distribuitoarelor": "distribuitoare",
    "distribuitoareo": "distribuitoare",
    "distribuitoare": "distribuitor",
    "distribuitoarele": "distribuitor",
    "distribuitoarelor": "distribuitor",
    "distribuitori": "distribuitor",
    "distribuitorii": "distribuitor",
    "distribuitorilor": "distribuitor",
    "distribuitorul": "distribuitor",
    "distribuitorule": "distribuitor",
    "distribuitorului": "distribuitor",
    "distribuția": "distribuție",
    "distribuției": "distribuție",
    "distribuții": "distribuție",
    "distribuțiile": "distribuție",
    "distribuțiilor": "distribuție",
    "distribuțio": "distribuție",
    "distributiva": "distributiv",
    "distributivă": "distributiv",
    "distributive": "distributiv",
    "distributivei": "distributiv",
    "distributivele": "distributiv",
    "distributivelor": "distributiv",
    "distributivi": "distributiv",
    "distributivii": "distributiv",
    "distributivilor": "distributiv",
    "distributivo": "distributiv",
    "distributivul": "distributiv",
    "distributivule": "distributiv",
    "distributivului": "distributiv",
    "districte": "district",
    "districtele": "district",
    "districtelor": "district",
    "districtul": "district",
    "districtule": "district",
    "districtului": "district",
    "distrofica": "distrofic",
    "distrofică": "distrofic",
    "distrofice": "distrofic",
    "distroficei": "distrofic",
    "distroficele": "distrofic",
    "distroficelor": "distrofic",
    "distrofici": "distrofic",
    "distroficii": "distrofic",
    "distroficilor": "distrofic",
    "distrofico": "distrofic",
    "distroficul": "distrofic",
    "distroficule": "distrofic",
    "distroficului": "distrofic",
    "distrofia": "distrofie",
    "distrofiei": "distrofie",
    "distrofii": "distrofie",
    "distrofiile": "distrofie",
    "distrofiilor": "distrofie",
    "distrofio": "distrofie",
    "distructiva": "distructiv",
    "distructivă": "distructiv",
    "distructive": "distructiv",
    "distructivei": "distructiv",
    "distructivele": "distructiv",
    "distructivelor": "distructiv",
    "distructivi": "distructiv",
    "distructivii": "distructiv",
    "distructivilor": "distructiv",
    "distructivo": "distructiv",
    "distructivul": "distructiv",
    "distructivule": "distructiv",
    "distructivului": "distructiv",
    "distrugătoare": "distrugător",
    "distrugătoarea": "distrugător",
    "distrugătoarei": "distrugător",
    "distrugătoarele": "distrugător",
    "distrugătoarelor": "distrugător",
    "distrugători": "distrugător",
    "distrugătorii": "distrugător",
    "distrugătorilor": "distrugător",
    "distrugătorul": "distrugător",
    "distrugătorule": "distrugător",
    "distrugătorului": "distrugător",
    "distrug": "distruge",
    "distrugă": "distruge",
    "distrugând": "distruge",
    "distrugându": "distruge",
    "distrugea": "distruge",
    "distrugeai": "distruge",
    "distrugeam": "distruge",
    "distrugeați": "distruge",
    "distrugeau": "distruge",
    "distrugem": "distruge",
    "distrugeți": "distruge",
    "distrugi": "distruge",
    "distrus": "distruge",
    "distruse": "distruge",
    "distrusei": "distruge",
    "distruseră": "distruge",
    "distruserăm": "distruge",
    "distruserăți": "distruge",
    "distrusese": "distruge",
    "distrusesem": "distruge",
    "distruseseră": "distruge",
    "distruseserăm": "distruge",
    "distruseserăți": "distruge",
    "distruseseși": "distruge",
    "distruseși": "distruge",
    "distrusu": "distruge",
    "nedistrugând": "distruge",
    "nedistrugându": "distruge",
    "nemaidistrugând": "distruge",
    "nemaidistrugându": "distruge",
    "distrugerea": "distrugere",
    "distrugereo": "distrugere",
    "distrugeri": "distrugere",
    "distrugerii": "distrugere",
    "distrugerile": "distrugere",
    "distrugerilor": "distrugere",
    "distrusa": "distrus",
    "distrusă": "distrus",
    "distruse": "distrus",
    "distrusei": "distrus",
    "distrusele": "distrus",
    "distruselor": "distrus",
    "distruși": "distrus",
    "distrușii": "distrus",
    "distrușilor": "distrus",
    "distruso": "distrus",
    "distrusul": "distrus",
    "distrusule": "distrus",
    "distrusului": "distrus",
    "ditirambi": "ditiramb",
    "ditirambii": "ditiramb",
    "ditirambilor": "ditiramb",
    "ditirambul": "ditiramb",
    "ditirambule": "ditiramb",
    "ditirambului": "ditiramb",
    "ditirambica": "ditirambic",
    "ditirambică": "ditirambic",
    "ditirambice": "ditirambic",
    "ditirambicei": "ditirambic",
    "ditirambicele": "ditirambic",
    "ditirambicelor": "ditirambic",
    "ditirambici": "ditirambic",
    "ditirambicii": "ditirambic",
    "ditirambicilor": "ditirambic",
    "ditirambico": "ditirambic",
    "ditirambicul": "ditirambic",
    "ditirambicule": "ditirambic",
    "ditirambicului": "ditirambic",
    "diuretica": "diuretic",
    "diuretică": "diuretic",
    "diuretice": "diuretic",
    "diureticei": "diuretic",
    "diureticele": "diuretic",
    "diureticelor": "diuretic",
    "diuretici": "diuretic",
    "diureticii": "diuretic",
    "diureticilor": "diuretic",
    "diuretico": "diuretic",
    "diureticul": "diuretic",
    "diureticule": "diuretic",
    "diureticului": "diuretic",
    "diureza": "diureză",
    "diureze": "diureză",
    "diurezei": "diureză",
    "diurezele": "diureză",
    "diurezelor": "diureză",
    "diurezo": "diureză",
    "diurna": "diurn",
    "diurnă": "diurn",
    "diurne": "diurn",
    "diurnei": "diurn",
    "diurnele": "diurn",
    "diurnelor": "diurn",
    "diurni": "diurn",
    "diurnii": "diurn",
    "diurnilor": "diurn",
    "diurno": "diurn",
    "diurnul": "diurn",
    "diurnule": "diurn",
    "diurnului": "diurn",
    "diurna": "diurnă",
    "diurne": "diurnă",
    "diurnei": "diurnă",
    "diurnele": "diurnă",
    "diurnelor": "diurnă",
    "diurno": "diurnă",
    "diva": "divă",
    "dive": "divă",
    "divei": "divă",
    "divele": "divă",
    "divelor": "divă",
    "divo": "divă",
    "divagă": "divaga",
    "divagai": "divaga",
    "divagam": "divaga",
    "divagăm": "divaga",
    "divagând": "divaga",
    "divagându": "divaga",
    "divagară": "divaga",
    "divagarăm": "divaga",
    "divagarăți": "divaga",
    "divagase": "divaga",
    "divagasem": "divaga",
    "divagaseră": "divaga",
    "divagaserăm": "divaga",
    "divagaserăți": "divaga",
    "divagaseși": "divaga",
    "divagași": "divaga",
    "divagat": "divaga",
    "divagați": "divaga",
    "divagatu": "divaga",
    "divagau": "divaga",
    "divaghează": "divaga",
    "divaghez": "divaga",
    "divagheze": "divaga",
    "divaghezi": "divaga",
    "nedivagând": "divaga",
    "nedivagându": "divaga",
    "nemaidivagând": "divaga",
    "nemaidivagându": "divaga",
    "divagarea": "divagare",
    "divagareo": "divagare",
    "divagări": "divagare",
    "divagării": "divagare",
    "divagările": "divagare",
    "divagărilor": "divagare",
    "divagată": "divagat",
    "divagate": "divagat",
    "divagați": "divagat",
    "divagația": "divagație",
    "divagației": "divagație",
    "divagații": "divagație",
    "divagațiile": "divagație",
    "divagațiilor": "divagație",
    "divagațio": "divagație",
    "divane": "divan",
    "divanele": "divan",
    "divanelor": "divan",
    "divanul": "divan",
    "divanule": "divan",
    "divanului": "divan",
    "divergenta": "divergent",
    "divergentă": "divergent",
    "divergente": "divergent",
    "divergentei": "divergent",
    "divergentele": "divergent",
    "divergentelor": "divergent",
    "divergenți": "divergent",
    "divergenții": "divergent",
    "divergenților": "divergent",
    "divergento": "divergent",
    "divergentul": "divergent",
    "divergentule": "divergent",
    "divergentului": "divergent",
    "divergența": "divergență",
    "divergențe": "divergență",
    "divergenței": "divergență",
    "divergențele": "divergență",
    "divergențelor": "divergență",
    "divergențo": "divergență",
    "diversa": "divers",
    "diversă": "divers",
    "diverse": "divers",
    "diversei": "divers",
    "diversele": "divers",
    "diverselor": "divers",
    "diverși": "divers",
    "diverșii": "divers",
    "diverșilor": "divers",
    "diverso": "divers",
    "diversul": "divers",
    "diversule": "divers",
    "diversului": "divers",
    "diversific": "diversifica",
    "diversifică": "diversifica",
    "diversificai": "diversifica",
    "diversificam": "diversifica",
    "diversificăm": "diversifica",
    "diversificând": "diversifica",
    "diversificându": "diversifica",
    "diversificară": "diversifica",
    "diversificarăm": "diversifica",
    "diversificarăți": "diversifica",
    "diversificase": "diversifica",
    "diversificasem": "diversifica",
    "diversificaseră": "diversifica",
    "diversificaserăm": "diversifica",
    "diversificaserăți": "diversifica",
    "diversificaseși": "diversifica",
    "diversificași": "diversifica",
    "diversificat": "diversifica",
    "diversificați": "diversifica",
    "diversificatu": "diversifica",
    "diversificau": "diversifica",
    "diversifice": "diversifica",
    "diversifici": "diversifica",
    "nediversificând": "diversifica",
    "nediversificându": "diversifica",
    "nemaidiversificând": "diversifica",
    "nemaidiversificându": "diversifica",
    "diversificarea": "diversificare",
    "diversificareo": "diversificare",
    "diversificări": "diversificare",
    "diversificării": "diversificare",
    "diversificările": "diversificare",
    "diversificărilor": "diversificare",
    "diversificată": "diversificat",
    "diversificate": "diversificat",
    "diversificați": "diversificat",
    "diversitatea": "diversitate",
    "diversitateo": "diversitate",
    "diversități": "diversitate",
    "diversității": "diversitate",
    "diversitățile": "diversitate",
    "diversităților": "diversitate",
    "diversiunea": "diversiune",
    "diversiuneo": "diversiune",
    "diversiuni": "diversiune",
    "diversiunii": "diversiune",
    "diversiunile": "diversiune",
    "diversiunilor": "diversiune",
    "divertismente": "divertisment",
    "divertismentele": "divertisment",
    "divertismentelor": "divertisment",
    "divertismentul": "divertisment",
    "divertismentule": "divertisment",
    "divertismentului": "divertisment",
    "div.": "divide",
    "divid": "divide",
    "dividă": "divide",
    "dividem": "divide",
    "divideți": "divide",
    "divizi": "divide",
    "dividende": "dividend",
    "dividendele": "dividend",
    "dividendelor": "dividend",
    "dividendul": "dividend",
    "dividendule": "dividend",
    "dividendului": "dividend",
    "divina": "divin",
    "divină": "divin",
    "divine": "divin",
    "divinei": "divin",
    "divinele": "divin",
    "divinelor": "divin",
    "divini": "divin",
    "divinii": "divin",
    "divinilor": "divin",
    "divino": "divin",
    "divinul": "divin",
    "divinule": "divin",
    "divinului": "divin",
    "divinitatea": "divinitate",
    "divinitateo": "divinitate",
    "divinități": "divinitate",
    "divinității": "divinitate",
    "divinitățile": "divinitate",
    "divinităților": "divinitate",
    "divinizarea": "divinizare",
    "divinizareo": "divinizare",
    "divinizări": "divinizare",
    "divinizării": "divinizare",
    "divinizările": "divinizare",
    "divinizărilor": "divinizare",
    "divinizata": "divinizat",
    "divinizată": "divinizat",
    "divinizate": "divinizat",
    "divinizatei": "divinizat",
    "divinizatele": "divinizat",
    "divinizatelor": "divinizat",
    "divinizați": "divinizat",
    "divinizații": "divinizat",
    "divinizaților": "divinizat",
    "divinizato": "divinizat",
    "divinizatul": "divinizat",
    "divinizatule": "divinizat",
    "divinizatului": "divinizat",
    "diviză": "diviza",
    "divizai": "diviza",
    "divizam": "diviza",
    "divizăm": "diviza",
    "divizând": "diviza",
    "divizându": "diviza",
    "divizară": "diviza",
    "divizarăm": "diviza",
    "divizarăți": "diviza",
    "divizase": "diviza",
    "divizasem": "diviza",
    "divizaseră": "diviza",
    "divizaserăm": "diviza",
    "divizaserăți": "diviza",
    "divizaseși": "diviza",
    "divizași": "diviza",
    "divizat": "diviza",
    "divizați": "diviza",
    "divizatu": "diviza",
    "divizau": "diviza",
    "divizează": "diviza",
    "divizez": "diviza",
    "divizeze": "diviza",
    "divizezi": "diviza",
    "nedivizând": "diviza",
    "nedivizându": "diviza",
    "nemaidivizând": "diviza",
    "nemaidivizându": "diviza",
    "divizarea": "divizare",
    "divizareo": "divizare",
    "divizări": "divizare",
    "divizării": "divizare",
    "divizările": "divizare",
    "divizărilor": "divizare",
    "divizata": "divizat",
    "divizată": "divizat",
    "divizate": "divizat",
    "divizatei": "divizat",
    "divizatele": "divizat",
    "divizatelor": "divizat",
    "divizați": "divizat",
    "divizații": "divizat",
    "divizaților": "divizat",
    "divizato": "divizat",
    "divizatul": "divizat",
    "divizatule": "divizat",
    "divizatului": "divizat",
    "divizibila": "divizibil",
    "divizibilă": "divizibil",
    "divizibile": "divizibil",
    "divizibilei": "divizibil",
    "divizibilele": "divizibil",
    "divizibilelor": "divizibil",
    "divizibili": "divizibil",
    "divizibilii": "divizibil",
    "divizibililor": "divizibil",
    "divizibilo": "divizibil",
    "divizibilul": "divizibil",
    "divizibilule": "divizibil",
    "divizibilului": "divizibil",
    "divizibilitatea": "divizibilitate",
    "divizibilitateo": "divizibilitate",
    "divizibilități": "divizibilitate",
    "divizibilității": "divizibilitate",
    "divizibilitățile": "divizibilitate",
    "divizibilităților": "divizibilitate",
    "divizia": "divizie",
    "diviziei": "divizie",
    "divizii": "divizie",
    "diviziile": "divizie",
    "diviziilor": "divizie",
    "divizio": "divizie",
    "divizioane": "divizion",
    "divizioanele": "divizion",
    "divizioanelor": "divizion",
    "divizionul": "divizion",
    "divizionule": "divizion",
    "divizionului": "divizion",
    "diviziunea": "diviziune",
    "diviziuneo": "diviziune",
    "diviziuni": "diviziune",
    "diviziunii": "diviziune",
    "diviziunile": "diviziune",
    "diviziunilor": "diviziune",
    "divizori": "divizor",
    "divizorii": "divizor",
    "divizorilor": "divizor",
    "divizorul": "divizor",
    "divizorule": "divizor",
    "divizorului": "divizor",
    "divorțul": "divorț",
    "divorțule": "divorț",
    "divorțului": "divorț",
    "divorțuri": "divorț",
    "divorțurile": "divorț",
    "divorțurilor": "divorț",
    "divorță": "divorța",
    "divorțai": "divorța",
    "divorțam": "divorța",
    "divorțăm": "divorța",
    "divorțând": "divorța",
    "divorțându": "divorța",
    "divorțară": "divorța",
    "divorțarăm": "divorța",
    "divorțarăți": "divorța",
    "divorțase": "divorța",
    "divorțasem": "divorța",
    "divorțaseră": "divorța",
    "divorțaserăm": "divorța",
    "divorțaserăți": "divorța",
    "divorțaseși": "divorța",
    "divorțași": "divorța",
    "divorțat": "divorța",
    "divorțați": "divorța",
    "divorțatu": "divorța",
    "divorțau": "divorța",
    "divorțează": "divorța",
    "divorțez": "divorța",
    "divorțeze": "divorța",
    "divorțezi": "divorța",
    "nedivorțând": "divorța",
    "nedivorțându": "divorța",
    "nemaidivorțând": "divorța",
    "nemaidivorțându": "divorța",
    "divorțata": "divorțat",
    "divorțată": "divorțat",
    "divorțate": "divorțat",
    "divorțatei": "divorțat",
    "divorțatele": "divorțat",
    "divorțatelor": "divorțat",
    "divorțați": "divorțat",
    "divorțații": "divorțat",
    "divorțaților": "divorțat",
    "divorțato": "divorțat",
    "divorțatul": "divorțat",
    "divorțatule": "divorțat",
    "divorțatului": "divorțat",
    "divulg": "divulga",
    "divulgă": "divulga",
    "divulgai": "divulga",
    "divulgam": "divulga",
    "divulgăm": "divulga",
    "divulgând": "divulga",
    "divulgându": "divulga",
    "divulgară": "divulga",
    "divulgarăm": "divulga",
    "divulgarăți": "divulga",
    "divulgase": "divulga",
    "divulgasem": "divulga",
    "divulgaseră": "divulga",
    "divulgaserăm": "divulga",
    "divulgaserăți": "divulga",
    "divulgaseși": "divulga",
    "divulgași": "divulga",
    "divulgat": "divulga",
    "divulgați": "divulga",
    "divulgatu": "divulga",
    "divulgau": "divulga",
    "divulge": "divulga",
    "divulgi": "divulga",
    "nedivulgând": "divulga",
    "nedivulgându": "divulga",
    "nemaidivulgând": "divulga",
    "nemaidivulgându": "divulga",
    "divulgarea": "divulgare",
    "divulgareo": "divulgare",
    "divulgări": "divulgare",
    "divulgării": "divulgare",
    "divulgările": "divulgare",
    "divulgărilor": "divulgare",
    "divulgată": "divulgat",
    "divulgate": "divulgat",
    "divulgați": "divulgat",
    "divulgatoarea": "divulgatoare",
    "divulgatoarei": "divulgatoare",
    "divulgatoarele": "divulgatoare",
    "divulgatoarelor": "divulgatoare",
    "divulgatoareo": "divulgatoare",
    "divulgatori": "divulgator",
    "divulgatorii": "divulgator",
    "divulgatorilor": "divulgator",
    "divulgatorul": "divulgator",
    "divulgatorule": "divulgator",
    "divulgatorului": "divulgator",
    "dizarmonica": "dizarmonic",
    "dizarmonică": "dizarmonic",
    "dizarmonice": "dizarmonic",
    "dizarmonicei": "dizarmonic",
    "dizarmonicele": "dizarmonic",
    "dizarmonicelor": "dizarmonic",
    "dizarmonici": "dizarmonic",
    "dizarmonicii": "dizarmonic",
    "dizarmonicilor": "dizarmonic",
    "dizarmonicul": "dizarmonic",
    "dizarmonicului": "dizarmonic",
    "dizenterica": "dizenteric",
    "dizenterică": "dizenteric",
    "dizenterice": "dizenteric",
    "dizentericei": "dizenteric",
    "dizentericele": "dizenteric",
    "dizentericelor": "dizenteric",
    "dizenterici": "dizenteric",
    "dizentericii": "dizenteric",
    "dizentericilor": "dizenteric",
    "dizenterico": "dizenteric",
    "dizentericul": "dizenteric",
    "dizentericule": "dizenteric",
    "dizentericului": "dizenteric",
    "dizenteria": "dizenterie",
    "dizenteriei": "dizenterie",
    "dizenterii": "dizenterie",
    "dizenteriile": "dizenterie",
    "dizenteriilor": "dizenterie",
    "dizenterio": "dizenterie",
    "dizgrațiai": "dizgrația",
    "dizgrațiam": "dizgrația",
    "dizgrațiară": "dizgrația",
    "dizgrațiarăm": "dizgrația",
    "dizgrațiarăți": "dizgrația",
    "dizgrațiase": "dizgrația",
    "dizgrațiasem": "dizgrația",
    "dizgrațiaseră": "dizgrația",
    "dizgrațiaserăm": "dizgrația",
    "dizgrațiaserăți": "dizgrația",
    "dizgrațiaseși": "dizgrația",
    "dizgrațiași": "dizgrația",
    "dizgrațiat": "dizgrația",
    "dizgrațiați": "dizgrația",
    "dizgrațiatu": "dizgrația",
    "dizgrațiau": "dizgrația",
    "dizgrațiază": "dizgrația",
    "dizgrație": "dizgrația",
    "dizgrațiem": "dizgrația",
    "dizgrațiez": "dizgrația",
    "dizgrațieze": "dizgrația",
    "dizgrațiezi": "dizgrația",
    "dizgrațiind": "dizgrația",
    "dizgrațiindu": "dizgrația",
    "nedizgrațiind": "dizgrația",
    "nedizgrațiindu": "dizgrația",
    "nemaidizgrațiind": "dizgrația",
    "nemaidizgrațiindu": "dizgrația",
    "dizgrațiata": "dizgrațiat",
    "dizgrațiată": "dizgrațiat",
    "dizgrațiate": "dizgrațiat",
    "dizgrațiatei": "dizgrațiat",
    "dizgrațiatele": "dizgrațiat",
    "dizgrațiatelor": "dizgrațiat",
    "dizgrațiați": "dizgrațiat",
    "dizgrațiații": "dizgrațiat",
    "dizgrațiaților": "dizgrațiat",
    "dizgrațiato": "dizgrațiat",
    "dizgrațiatul": "dizgrațiat",
    "dizgrațiatule": "dizgrațiat",
    "dizgrațiatului": "dizgrațiat",
    "dizgrația": "dizgrație",
    "dizgrației": "dizgrație",
    "dizgrații": "dizgrație",
    "dizgrațiile": "dizgrație",
    "dizgrațiilor": "dizgrație",
    "dizgrațio": "dizgrație",
    "dizgrațierea": "dizgrațiere",
    "dizgrațiereo": "dizgrațiere",
    "dizgrațieri": "dizgrațiere",
    "dizgrațierii": "dizgrațiere",
    "dizgrațierile": "dizgrațiere",
    "dizgrațierilor": "dizgrațiere",
    "dizgrațioasa": "dizgrațios",
    "dizgrațioasă": "dizgrațios",
    "dizgrațioase": "dizgrațios",
    "dizgrațioasei": "dizgrațios",
    "dizgrațioasele": "dizgrațios",
    "dizgrațioaselor": "dizgrațios",
    "dizgrațioaso": "dizgrațios",
    "dizgrațioși": "dizgrațios",
    "dizgrațioșii": "dizgrațios",
    "dizgrațioșilor": "dizgrațios",
    "dizgrațiosul": "dizgrațios",
    "dizgrațiosule": "dizgrațios",
    "dizgrațiosului": "dizgrațios",
    "dizidența": "dizidență",
    "dizidențe": "dizidență",
    "dizidenței": "dizidență",
    "dizidențele": "dizidență",
    "dizidențelor": "dizidență",
    "dizidențo": "dizidență",
    "dizolv": "dizolva",
    "dizolvă": "dizolva",
    "dizolvai": "dizolva",
    "dizolvam": "dizolva",
    "dizolvăm": "dizolva",
    "dizolvând": "dizolva",
    "dizolvându": "dizolva",
    "dizolvară": "dizolva",
    "dizolvarăm": "dizolva",
    "dizolvarăți": "dizolva",
    "dizolvase": "dizolva",
    "dizolvasem": "dizolva",
    "dizolvaseră": "dizolva",
    "dizolvaserăm": "dizolva",
    "dizolvaserăți": "dizolva",
    "dizolvaseși": "dizolva",
    "dizolvași": "dizolva",
    "dizolvat": "dizolva",
    "dizolvați": "dizolva",
    "dizolvatu": "dizolva",
    "dizolvau": "dizolva",
    "dizolve": "dizolva",
    "dizolvi": "dizolva",
    "nedizolvând": "dizolva",
    "nedizolvându": "dizolva",
    "nemaidizolvând": "dizolva",
    "nemaidizolvându": "dizolva",
    "dizolvarea": "dizolvare",
    "dizolvareo": "dizolvare",
    "dizolvări": "dizolvare",
    "dizolvării": "dizolvare",
    "dizolvările": "dizolvare",
    "dizolvărilor": "dizolvare",
    "dizolvata": "dizolvat",
    "dizolvată": "dizolvat",
    "dizolvate": "dizolvat",
    "dizolvatei": "dizolvat",
    "dizolvatele": "dizolvat",
    "dizolvatelor": "dizolvat",
    "dizolvați": "dizolvat",
    "dizolvații": "dizolvat",
    "dizolvaților": "dizolvat",
    "dizolvato": "dizolvat",
    "dizolvatul": "dizolvat",
    "dizolvatule": "dizolvat",
    "dizolvatului": "dizolvat",
    "doaga": "doagă",
    "doage": "doagă",
    "doagei": "doagă",
    "doagele": "doagă",
    "doagelor": "doagă",
    "doago": "doagă",
    "dna": "doamna",
    "d-na": "doamna",
    "doamna": "doamnă",
    "doamne": "doamnă",
    "doamnei": "doamnă",
    "doamnele": "doamnă",
    "doamnelor": "doamnă",
    "doamno": "doamnă",
    "dnei": "doamnei",
    "d-nei": "doamnei",
    "d-lor": "doamnelor",
    "dobânda": "dobândă",
    "dobândo": "dobândă",
    "dobânzi": "dobândă",
    "dobânzii": "dobândă",
    "dobânzile": "dobândă",
    "dobânzilor": "dobândă",
    "dobândea": "dobândi",
    "dobândeai": "dobândi",
    "dobândeam": "dobândi",
    "dobândească": "dobândi",
    "dobândeați": "dobândi",
    "dobândeau": "dobândi",
    "dobândesc": "dobândi",
    "dobândește": "dobândi",
    "dobândești": "dobândi",
    "dobândii": "dobândi",
    "dobândim": "dobândi",
    "dobândind": "dobândi",
    "dobândindu": "dobândi",
    "dobândiră": "dobândi",
    "dobândirăm": "dobândi",
    "dobândirăți": "dobândi",
    "dobândise": "dobândi",
    "dobândisem": "dobândi",
    "dobândiseră": "dobândi",
    "dobândiserăm": "dobândi",
    "dobândiserăți": "dobândi",
    "dobândiseși": "dobândi",
    "dobândiși": "dobândi",
    "dobândit": "dobândi",
    "dobândiți": "dobândi",
    "dobânditu": "dobândi",
    "nedobândind": "dobândi",
    "nedobândindu": "dobândi",
    "nemaidobândind": "dobândi",
    "nemaidobândindu": "dobândi",
    "dobândirea": "dobândire",
    "dobândireo": "dobândire",
    "dobândiri": "dobândire",
    "dobândirii": "dobândire",
    "dobândirile": "dobândire",
    "dobândirilor": "dobândire",
    "dobândită": "dobândit",
    "dobândite": "dobândit",
    "dobândiți": "dobândit",
    "dobitoaca": "dobitoacă",
    "dobitoace": "dobitoacă",
    "dobitoacei": "dobitoacă",
    "dobitoacele": "dobitoacă",
    "dobitoacelor": "dobitoacă",
    "dobitoaco": "dobitoacă",
    "dobitoaca": "dobitoc",
    "dobitoacă": "dobitoc",
    "dobitoace": "dobitoc",
    "dobitoacei": "dobitoc",
    "dobitoacele": "dobitoc",
    "dobitoacelor": "dobitoc",
    "dobitoaco": "dobitoc",
    "dobitoci": "dobitoc",
    "dobitocii": "dobitoc",
    "dobitocilor": "dobitoc",
    "dobitocul": "dobitoc",
    "dobitocule": "dobitoc",
    "dobitocului": "dobitoc",
    "doborârea": "doborâre",
    "doborâreo": "doborâre",
    "doborâri": "doborâre",
    "doborârii": "doborâre",
    "doborârile": "doborâre",
    "doborârilor": "doborâre",
    "doborâta": "doborât",
    "doborâtă": "doborât",
    "doborâte": "doborât",
    "doborâtei": "doborât",
    "doborâtele": "doborât",
    "doborâtelor": "doborât",
    "doborâți": "doborât",
    "doborâții": "doborât",
    "doborâților": "doborât",
    "doborâto": "doborât",
    "doborâtul": "doborât",
    "doborâtule": "doborât",
    "doborâtului": "doborât",
    "doborâtoare": "doborâtor",
    "doborâtoarea": "doborâtor",
    "doborâtoarei": "doborâtor",
    "doborâtoarele": "doborâtor",
    "doborâtoarelor": "doborâtor",
    "doborâtoareo": "doborâtor",
    "doborâtori": "doborâtor",
    "doborâtorii": "doborâtor",
    "doborâtorilor": "doborâtor",
    "doborâtorul": "doborâtor",
    "doborâtorule": "doborâtor",
    "doborâtorului": "doborâtor",
    "doboară": "doborî",
    "doboare": "doborî",
    "dobor": "doborî",
    "dobora": "doborî",
    "doborai": "doborî",
    "doborâi": "doborî",
    "doboram": "doborî",
    "doborâm": "doborî",
    "doborând": "doborî",
    "doborându": "doborî",
    "doborâră": "doborî",
    "doborârăm": "doborî",
    "doborârăți": "doborî",
    "doborâse": "doborî",
    "doborâsem": "doborî",
    "doborâseră": "doborî",
    "doborâserăm": "doborî",
    "doborâserăți": "doborî",
    "doborâseși": "doborî",
    "doborâși": "doborî",
    "doborât": "doborî",
    "doborați": "doborî",
    "doborâți": "doborî",
    "doborâtu": "doborî",
    "doborau": "doborî",
    "dobori": "doborî",
    "nedoborând": "doborî",
    "nedoborându": "doborî",
    "nemaidoborând": "doborî",
    "nemaidoborându": "doborî",
    "Dobreștiul": "Dobrești",
    "Dobreștiului": "Dobrești",
    "Dobrogei": "Dobrogea",
    "dobrogeana": "dobrogean",
    "dobrogeană": "dobrogean",
    "dobrogeano": "dobrogean",
    "dobrogeanul": "dobrogean",
    "dobrogeanule": "dobrogean",
    "dobrogeanului": "dobrogean",
    "dobrogene": "dobrogean",
    "dobrogenei": "dobrogean",
    "dobrogenele": "dobrogean",
    "dobrogenelor": "dobrogean",
    "dobrogeni": "dobrogean",
    "dobrogenii": "dobrogean",
    "dobrogenilor": "dobrogean",
    "Dobrovățul": "Dobrovăț",
    "Dobrovățului": "Dobrovăț",
    "docul": "doc",
    "docule": "doc",
    "docului": "doc",
    "docuri": "doc",
    "docurile": "doc",
    "docurilor": "doc",
    "docenți": "docent",
    "docenții": "docent",
    "docenților": "docent",
    "docentul": "docent",
    "docentule": "docent",
    "docentului": "docent",
    "docența": "docență",
    "docențe": "docență",
    "docenței": "docență",
    "docențele": "docență",
    "docențelor": "docență",
    "docențo": "docență",
    "docheri": "docher",
    "docherii": "docher",
    "docherilor": "docher",
    "docherul": "docher",
    "docherule": "docher",
    "docherului": "docher",
    "docila": "docil",
    "docilă": "docil",
    "docile": "docil",
    "docilei": "docil",
    "docilele": "docil",
    "docilelor": "docil",
    "docili": "docil",
    "docilii": "docil",
    "docililor": "docil",
    "docilo": "docil",
    "docilul": "docil",
    "docilule": "docil",
    "docilului": "docil",
    "docilitatea": "docilitate",
    "docilitateo": "docilitate",
    "docilități": "docilitate",
    "docilității": "docilitate",
    "docilitățile": "docilitate",
    "docilităților": "docilitate",
    "docta": "doct",
    "doctă": "doct",
    "docte": "doct",
    "doctei": "doct",
    "doctele": "doct",
    "doctelor": "doct",
    "docți": "doct",
    "docții": "doct",
    "docților": "doct",
    "docto": "doct",
    "doctul": "doct",
    "doctule": "doct",
    "doctului": "doct",
    "doctore": "doctor",
    "doctori": "doctor",
    "doctorii": "doctor",
    "doctorilor": "doctor",
    "doctorul": "doctor",
    "doctorule": "doctor",
    "doctorului": "doctor",
    "dr.": "doctor",
    "dr.doc.": "doctor_docent",
    "Dr.H.C.": "Doctor_Honoris_Causa",
    "Dr.J.": "Doctor_Juris",
    "doctorandul": "doctorand",
    "doctorandule": "doctorand",
    "doctorandului": "doctorand",
    "doctoranzi": "doctorand",
    "doctoranzii": "doctorand",
    "doctoranzilor": "doctorand",
    "doctorate": "doctorat",
    "doctoratele": "doctorat",
    "doctoratelor": "doctorat",
    "doctoratul": "doctorat",
    "doctoratule": "doctorat",
    "doctoratului": "doctorat",
    "doctoricea": "doctorici",
    "doctoriceai": "doctorici",
    "doctoriceam": "doctorici",
    "doctoricească": "doctorici",
    "doctoriceați": "doctorici",
    "doctoriceau": "doctorici",
    "doctoricesc": "doctorici",
    "doctoricește": "doctorici",
    "doctoricești": "doctorici",
    "doctoricii": "doctorici",
    "doctoricim": "doctorici",
    "doctoricind": "doctorici",
    "doctoricindu": "doctorici",
    "doctoriciră": "doctorici",
    "doctoricirăm": "doctorici",
    "doctoricirăți": "doctorici",
    "doctoricise": "doctorici",
    "doctoricisem": "doctorici",
    "doctoriciseră": "doctorici",
    "doctoriciserăm": "doctorici",
    "doctoriciserăți": "doctorici",
    "doctoriciseși": "doctorici",
    "doctoriciși": "doctorici",
    "doctoricit": "doctorici",
    "doctoriciți": "doctorici",
    "doctoricitu": "doctorici",
    "nedoctoricind": "doctorici",
    "nedoctoricindu": "doctorici",
    "nemaidoctoricind": "doctorici",
    "nemaidoctoricindu": "doctorici",
    "doctoricită": "doctoricit",
    "doctoricite": "doctoricit",
    "doctoriciți": "doctoricit",
    "doctoria": "doctorie",
    "doctoriei": "doctorie",
    "doctorii": "doctorie",
    "doctoriile": "doctorie",
    "doctoriilor": "doctorie",
    "doctorio": "doctorie",
    "doctrina": "doctrină",
    "doctrine": "doctrină",
    "doctrinei": "doctrină",
    "doctrinele": "doctrină",
    "doctrinelor": "doctrină",
    "doctrino": "doctrină",
    "doctrinara": "doctrinar",
    "doctrinară": "doctrinar",
    "doctrinare": "doctrinar",
    "doctrinarei": "doctrinar",
    "doctrinarele": "doctrinar",
    "doctrinarelor": "doctrinar",
    "doctrinari": "doctrinar",
    "doctrinarii": "doctrinar",
    "doctrinarilor": "doctrinar",
    "doctrinaro": "doctrinar",
    "doctrinarul": "doctrinar",
    "doctrinarule": "doctrinar",
    "doctrinarului": "doctrinar",
    "documente": "document",
    "documentele": "document",
    "documentelor": "document",
    "documentul": "document",
    "documentule": "document",
    "documentului": "document",
    "documentă": "documenta",
    "documentai": "documenta",
    "documentam": "documenta",
    "documentăm": "documenta",
    "documentând": "documenta",
    "documentându": "documenta",
    "documentară": "documenta",
    "documentarăm": "documenta",
    "documentarăți": "documenta",
    "documentase": "documenta",
    "documentasem": "documenta",
    "documentaseră": "documenta",
    "documentaserăm": "documenta",
    "documentaserăți": "documenta",
    "documentaseși": "documenta",
    "documentași": "documenta",
    "documentat": "documenta",
    "documentați": "documenta",
    "documentatu": "documenta",
    "documentau": "documenta",
    "documentează": "documenta",
    "documentez": "documenta",
    "documenteze": "documenta",
    "documentezi": "documenta",
    "nedocumentând": "documenta",
    "nedocumentându": "documenta",
    "nemaidocumentând": "documenta",
    "nemaidocumentându": "documenta",
    "documentară": "documentar",
    "documentare": "documentar",
    "documentarele": "documentar",
    "documentarelor": "documentar",
    "documentari": "documentar",
    "documentarul": "documentar",
    "documentarule": "documentar",
    "documentarului": "documentar",
    "documentarea": "documentare",
    "documentări": "documentare",
    "documentării": "documentare",
    "documentările": "documentare",
    "documentărilor": "documentare",
    "documentata": "documentat",
    "documentată": "documentat",
    "documentate": "documentat",
    "documentatei": "documentat",
    "documentatele": "documentat",
    "documentatelor": "documentat",
    "documentați": "documentat",
    "documentații": "documentat",
    "documentaților": "documentat",
    "documentatul": "documentat",
    "documentatule": "documentat",
    "documentatului": "documentat",
    "documentația": "documentație",
    "documentației": "documentație",
    "documentații": "documentație",
    "documentațiile": "documentație",
    "documentațiilor": "documentație",
    "documentațio": "documentație",
    "dodecaedrica": "dodecaedric",
    "dodecaedrică": "dodecaedric",
    "dodecaedrice": "dodecaedric",
    "dodecaedricei": "dodecaedric",
    "dodecaedricele": "dodecaedric",
    "dodecaedricelor": "dodecaedric",
    "dodecaedrici": "dodecaedric",
    "dodecaedricii": "dodecaedric",
    "dodecaedricilor": "dodecaedric",
    "dodecaedrico": "dodecaedric",
    "dodecaedricul": "dodecaedric",
    "dodecaedricule": "dodecaedric",
    "dodecaedricului": "dodecaedric",
    "dodecaedre": "dodecaedru",
    "dodecaedrele": "dodecaedru",
    "dodecaedrelor": "dodecaedru",
    "dodecaedrul": "dodecaedru",
    "dodecaedrule": "dodecaedru",
    "dodecaedrului": "dodecaedru",
    "dodecagoane": "dodecagon",
    "dodecagoanele": "dodecagon",
    "dodecagoanelor": "dodecagon",
    "dodecagonul": "dodecagon",
    "dodecagonule": "dodecagon",
    "dodecagonului": "dodecagon",
    "doftoricea": "doftorici",
    "doftoriceai": "doftorici",
    "doftoriceam": "doftorici",
    "doftoricească": "doftorici",
    "doftoriceați": "doftorici",
    "doftoriceau": "doftorici",
    "doftoricesc": "doftorici",
    "doftoricește": "doftorici",
    "doftoricești": "doftorici",
    "doftoricii": "doftorici",
    "doftoricim": "doftorici",
    "doftoricind": "doftorici",
    "doftoricindu": "doftorici",
    "doftoriciră": "doftorici",
    "doftoricirăm": "doftorici",
    "doftoricirăți": "doftorici",
    "doftoricise": "doftorici",
    "doftoricisem": "doftorici",
    "doftoriciseră": "doftorici",
    "doftoriciserăm": "doftorici",
    "doftoriciserăți": "doftorici",
    "doftoriciseși": "doftorici",
    "doftoriciși": "doftorici",
    "doftoricit": "doftorici",
    "doftoriciți": "doftorici",
    "doftoricitu": "doftorici",
    "doftoricirea": "doftoricire",
    "doftoriciri": "doftoricire",
    "doftoricirii": "doftoricire",
    "doftoricirile": "doftoricire",
    "doftoricirilor": "doftoricire",
    "doftoricită": "doftoricit",
    "doftoricite": "doftoricit",
    "doftoriciți": "doftoricit",
    "dogi": "dog",
    "dogii": "dog",
    "dogilor": "dog",
    "dogul": "dog",
    "dogule": "dog",
    "dogului": "dog",
    "dogare": "dogar",
    "dogarele": "dogar",
    "dogarelor": "dogar",
    "dogari": "dogar",
    "dogarii": "dogar",
    "dogarilor": "dogar",
    "dogarul": "dogar",
    "dogarule": "dogar",
    "dogarului": "dogar",
    "dogele": "doge",
    "dogelui": "doge",
    "dogi": "doge",
    "dogii": "doge",
    "dogilor": "doge",
    "dogea": "dogi",
    "dogeai": "dogi",
    "dogeam": "dogi",
    "dogească": "dogi",
    "dogeați": "dogi",
    "dogeau": "dogi",
    "dogesc": "dogi",
    "dogește": "dogi",
    "dogești": "dogi",
    "dogii": "dogi",
    "dogim": "dogi",
    "dogind": "dogi",
    "dogindu": "dogi",
    "dogiră": "dogi",
    "dogirăm": "dogi",
    "dogirăți": "dogi",
    "dogise": "dogi",
    "dogisem": "dogi",
    "dogiseră": "dogi",
    "dogiserăm": "dogi",
    "dogiserăți": "dogi",
    "dogiseși": "dogi",
    "dogiși": "dogi",
    "dogit": "dogi",
    "dogiți": "dogi",
    "dogitu": "dogi",
    "nedogind": "dogi",
    "nedogindu": "dogi",
    "nemaidogind": "dogi",
    "nemaidogindu": "dogi",
    "dogita": "dogit",
    "dogită": "dogit",
    "dogite": "dogit",
    "dogitei": "dogit",
    "dogitele": "dogit",
    "dogitelor": "dogit",
    "dogiți": "dogit",
    "dogiții": "dogit",
    "dogiților": "dogit",
    "dogito": "dogit",
    "dogitul": "dogit",
    "dogitule": "dogit",
    "dogitului": "dogit",
    "dogma": "dogmă",
    "dogme": "dogmă",
    "dogmei": "dogmă",
    "dogmele": "dogmă",
    "dogmelor": "dogmă",
    "dogmo": "dogmă",
    "dogmatica": "dogmatic",
    "dogmatică": "dogmatic",
    "dogmatice": "dogmatic",
    "dogmaticei": "dogmatic",
    "dogmaticele": "dogmatic",
    "dogmaticelor": "dogmatic",
    "dogmatici": "dogmatic",
    "dogmaticii": "dogmatic",
    "dogmaticilor": "dogmatic",
    "dogmatico": "dogmatic",
    "dogmaticul": "dogmatic",
    "dogmaticule": "dogmatic",
    "dogmaticului": "dogmatic",
    "dogmatica": "dogmatică",
    "dogmaticele": "dogmatică",
    "dogmatici": "dogmatică",
    "dogmaticii": "dogmatică",
    "dogmaticilor": "dogmatică",
    "dogmatico": "dogmatică",
    "dogmatiști": "dogmatist",
    "dogmatiștii": "dogmatist",
    "dogmatiștilor": "dogmatist",
    "dogmatistul": "dogmatist",
    "dogmatistule": "dogmatist",
    "dogmatistului": "dogmatist",
    "dogmatista": "dogmatistă",
    "dogmatiste": "dogmatistă",
    "dogmatistei": "dogmatistă",
    "dogmatistele": "dogmatistă",
    "dogmatistelor": "dogmatistă",
    "dogmatisto": "dogmatistă",
    "dogoarea": "dogoare",
    "dogoareo": "dogoare",
    "dogoreala": "dogoreală",
    "dogorealo": "dogoreală",
    "dogoreli": "dogoreală",
    "dogorelii": "dogoreală",
    "dogorelile": "dogoreală",
    "dogorelilor": "dogoreală",
    "dogorea": "dogori",
    "dogoreai": "dogori",
    "dogoream": "dogori",
    "dogorească": "dogori",
    "dogoreați": "dogori",
    "dogoreau": "dogori",
    "dogoresc": "dogori",
    "dogorește": "dogori",
    "dogorești": "dogori",
    "dogorii": "dogori",
    "dogorim": "dogori",
    "dogorind": "dogori",
    "dogorindu": "dogori",
    "dogoriră": "dogori",
    "dogorirăm": "dogori",
    "dogorirăți": "dogori",
    "dogorise": "dogori",
    "dogorisem": "dogori",
    "dogoriseră": "dogori",
    "dogoriserăm": "dogori",
    "dogoriserăți": "dogori",
    "dogoriseși": "dogori",
    "dogoriși": "dogori",
    "dogorit": "dogori",
    "dogoriți": "dogori",
    "dogoritu": "dogori",
    "nedogorind": "dogori",
    "nedogorindu": "dogori",
    "nemaidogorind": "dogori",
    "nemaidogorindu": "dogori",
    "dogorita": "dogorit",
    "dogorită": "dogorit",
    "dogorite": "dogorit",
    "dogoritei": "dogorit",
    "dogoritele": "dogorit",
    "dogoritelor": "dogorit",
    "dogoriți": "dogorit",
    "dogoriții": "dogorit",
    "dogoriților": "dogorit",
    "dogorito": "dogorit",
    "dogoritul": "dogorit",
    "dogoritule": "dogorit",
    "dogoritului": "dogorit",
    "dogoritoare": "dogoritor",
    "dogoritoarea": "dogoritor",
    "dogoritoarei": "dogoritor",
    "dogoritoarele": "dogoritor",
    "dogoritoarelor": "dogoritor",
    "dogoritoareo": "dogoritor",
    "dogoritori": "dogoritor",
    "dogoritorii": "dogoritor",
    "dogoritorilor": "dogoritor",
    "dogoritorul": "dogoritor",
    "dogoritorule": "dogoritor",
    "dogoritorului": "dogoritor",
    "doilea": "doi",
    "doua": "doi",
    "două": "doi",
    "II": "doi",
    "doica": "doică",
    "doici": "doică",
    "doicii": "doică",
    "doicile": "doică",
    "doicilor": "doică",
    "doico": "doică",
    "doimea": "doime",
    "doimi": "doime",
    "doimii": "doime",
    "doimile": "doime",
    "doimilor": "doime",
    "doina": "doină",
    "doine": "doină",
    "doinei": "doină",
    "doinele": "doină",
    "doinelor": "doină",
    "doino": "doină",
    "doinea": "doini",
    "doineai": "doini",
    "doineam": "doini",
    "doinească": "doini",
    "doineați": "doini",
    "doineau": "doini",
    "doinesc": "doini",
    "doinește": "doini",
    "doinești": "doini",
    "doinii": "doini",
    "doinim": "doini",
    "doinind": "doini",
    "doinindu": "doini",
    "doiniră": "doini",
    "doinirăm": "doini",
    "doinirăți": "doini",
    "doinise": "doini",
    "doinisem": "doini",
    "doiniseră": "doini",
    "doiniserăm": "doini",
    "doiniserăți": "doini",
    "doiniseși": "doini",
    "doiniși": "doini",
    "doinit": "doini",
    "doiniți": "doini",
    "doinitu": "doini",
    "nedoinind": "doini",
    "nedoinindu": "doini",
    "nemaidoinind": "doini",
    "nemaidoinindu": "doini",
    "doinirea": "doinire",
    "doinireo": "doinire",
    "doiniri": "doinire",
    "doinirii": "doinire",
    "doinirile": "doinire",
    "doinirilor": "doinire",
    "doinită": "doinit",
    "doinite": "doinit",
    "doiniți": "doinit",
    "doinitoarea": "doinitoare",
    "doinitoarei": "doinitoare",
    "doinitoarele": "doinitoare",
    "doinitoarelor": "doinitoare",
    "doinitoareo": "doinitoare",
    "doinitoare": "doinitor",
    "doinitoarea": "doinitor",
    "doinitoarei": "doinitor",
    "doinitoarele": "doinitor",
    "doinitoarelor": "doinitor",
    "doinitoareo": "doinitor",
    "doinitori": "doinitor",
    "doinitorii": "doinitor",
    "doinitorilor": "doinitor",
    "doinitorul": "doinitor",
    "doinitorule": "doinitor",
    "doinitorului": "doinitor",
    "douășpe": "doișpe",
    "douășpea": "doișpelea",
    "doisprezecelea": "doisprezece",
    "douăsprezece": "doisprezece",
    "douăsprezecea": "doisprezece",
    "XII": "doisprezece",
    "doisprezecimea": "doisprezecime",
    "doisprezecimi": "doisprezecime",
    "doisprezecimii": "doisprezecime",
    "doisprezecimile": "doisprezecime",
    "doisprezecimilor": "doisprezecime",
    "dojana": "dojană",
    "dojano": "dojană",
    "dojeni": "dojană",
    "dojenii": "dojană",
    "dojenile": "dojană",
    "dojenilor": "dojană",
    "dojenea": "dojeni",
    "dojeneai": "dojeni",
    "dojeneam": "dojeni",
    "dojenească": "dojeni",
    "dojeneați": "dojeni",
    "dojeneau": "dojeni",
    "dojenesc": "dojeni",
    "dojenește": "dojeni",
    "dojenești": "dojeni",
    "dojenii": "dojeni",
    "dojenim": "dojeni",
    "dojenind": "dojeni",
    "dojenindu": "dojeni",
    "dojeniră": "dojeni",
    "dojenirăm": "dojeni",
    "dojenirăți": "dojeni",
    "dojenise": "dojeni",
    "dojenisem": "dojeni",
    "dojeniseră": "dojeni",
    "dojeniserăm": "dojeni",
    "dojeniserăți": "dojeni",
    "dojeniseși": "dojeni",
    "dojeniși": "dojeni",
    "dojenit": "dojeni",
    "dojeniți": "dojeni",
    "dojenitu": "dojeni",
    "nedojenind": "dojeni",
    "nedojenindu": "dojeni",
    "nemaidojenind": "dojeni",
    "nemaidojenindu": "dojeni",
    "dojenirea": "dojenire",
    "dojenireo": "dojenire",
    "dojeniri": "dojenire",
    "dojenirii": "dojenire",
    "dojenirile": "dojenire",
    "dojenirilor": "dojenire",
    "dojenită": "dojenit",
    "dojenite": "dojenit",
    "dojeniți": "dojenit",
    "dojenitoare": "dojenitor",
    "dojenitoarea": "dojenitor",
    "dojenitoarei": "dojenitor",
    "dojenitoarele": "dojenitor",
    "dojenitoarelor": "dojenitor",
    "dojenitoareo": "dojenitor",
    "dojenitori": "dojenitor",
    "dojenitorii": "dojenitor",
    "dojenitorilor": "dojenitor",
    "dojenitorul": "dojenitor",
    "dojenitorule": "dojenitor",
    "dojenitorului": "dojenitor",
    "dolari": "dolar",
    "dolarii": "dolar",
    "dolarilor": "dolar",
    "dolarul": "dolar",
    "dolarule": "dolar",
    "dolarului": "dolar",
    "dol.": "dolari",
    "doleanța": "doleanță",
    "doleanțe": "doleanță",
    "doleanței": "doleanță",
    "doleanțele": "doleanță",
    "doleanțelor": "doleanță",
    "doleanțo": "doleanță",
    "dolina": "dolină",
    "doline": "dolină",
    "dolinei": "dolină",
    "dolinele": "dolină",
    "dolinelor": "dolină",
    "dolino": "dolină",
    "doliul": "doliu",
    "doliule": "doliu",
    "doliului": "doliu",
    "Doljchimul": "Doljchim",
    "Doljchimului": "Doljchim",
    "dolmane": "dolman",
    "dolmanele": "dolman",
    "dolmanelor": "dolman",
    "dolmanul": "dolman",
    "dolmanule": "dolman",
    "dolmanului": "dolman",
    "dolmene": "dolmen",
    "dolmenele": "dolmen",
    "dolmenelor": "dolmen",
    "dolmenul": "dolmen",
    "dolmenule": "dolmen",
    "dolmenului": "dolmen",
    "dolofana": "dolofan",
    "dolofană": "dolofan",
    "dolofane": "dolofan",
    "dolofanei": "dolofan",
    "dolofanele": "dolofan",
    "dolofanelor": "dolofan",
    "dolofani": "dolofan",
    "dolofanii": "dolofan",
    "dolofanilor": "dolofan",
    "dolofano": "dolofan",
    "dolofanul": "dolofan",
    "dolofanule": "dolofan",
    "dolofanului": "dolofan",
    "domul": "dom",
    "domule": "dom",
    "domului": "dom",
    "domuri": "dom",
    "domurile": "dom",
    "domurilor": "dom",
    "Domanul": "Doman",
    "Domanului": "Doman",
    "domenii": "domeniu",
    "domeniile": "domeniu",
    "domeniilor": "domeniu",
    "domeniul": "domeniu",
    "domeniule": "domeniu",
    "domeniului": "domeniu",
    "domestica": "domestic",
    "domestică": "domestic",
    "domestice": "domestic",
    "domesticei": "domestic",
    "domesticele": "domestic",
    "domesticelor": "domestic",
    "domestici": "domestic",
    "domesticii": "domestic",
    "domesticilor": "domestic",
    "domestico": "domestic",
    "domesticul": "domestic",
    "domesticule": "domestic",
    "domesticului": "domestic",
    "domesticea": "domestici",
    "domesticeai": "domestici",
    "domesticeam": "domestici",
    "domesticească": "domestici",
    "domesticeați": "domestici",
    "domesticeau": "domestici",
    "domesticesc": "domestici",
    "domesticește": "domestici",
    "domesticești": "domestici",
    "domesticii": "domestici",
    "domesticim": "domestici",
    "domesticind": "domestici",
    "domesticindu": "domestici",
    "domesticiră": "domestici",
    "domesticirăm": "domestici",
    "domesticirăți": "domestici",
    "domesticise": "domestici",
    "domesticisem": "domestici",
    "domesticiseră": "domestici",
    "domesticiserăm": "domestici",
    "domesticiserăți": "domestici",
    "domesticiseși": "domestici",
    "domesticiși": "domestici",
    "domesticit": "domestici",
    "domesticiți": "domestici",
    "domesticitu": "domestici",
    "nedomesticind": "domestici",
    "nedomesticindu": "domestici",
    "nemaidomesticind": "domestici",
    "nemaidomesticindu": "domestici",
    "domesticirea": "domesticire",
    "domesticireo": "domesticire",
    "domesticiri": "domesticire",
    "domesticirii": "domesticire",
    "domesticirile": "domesticire",
    "domesticirilor": "domesticire",
    "domesticita": "domesticit",
    "domesticită": "domesticit",
    "domesticite": "domesticit",
    "domesticitei": "domesticit",
    "domesticitele": "domesticit",
    "domesticitelor": "domesticit",
    "domesticiți": "domesticit",
    "domesticiții": "domesticit",
    "domesticiților": "domesticit",
    "domesticito": "domesticit",
    "domesticitul": "domesticit",
    "domesticitule": "domesticit",
    "domesticitului": "domesticit",
    "domiciliai": "domicilia",
    "domiciliam": "domicilia",
    "domiciliară": "domicilia",
    "domiciliarăm": "domicilia",
    "domiciliarăți": "domicilia",
    "domiciliase": "domicilia",
    "domiciliasem": "domicilia",
    "domiciliaseră": "domicilia",
    "domiciliaserăm": "domicilia",
    "domiciliaserăți": "domicilia",
    "domiciliaseși": "domicilia",
    "domiciliași": "domicilia",
    "domiciliat": "domicilia",
    "domiciliați": "domicilia",
    "domiciliatu": "domicilia",
    "domiciliau": "domicilia",
    "domiciliază": "domicilia",
    "domicilie": "domicilia",
    "domiciliem": "domicilia",
    "domiciliez": "domicilia",
    "domicilieze": "domicilia",
    "domiciliezi": "domicilia",
    "domiciliind": "domicilia",
    "domiciliindu": "domicilia",
    "nedomiciliind": "domicilia",
    "nedomiciliindu": "domicilia",
    "nemaidomiciliind": "domicilia",
    "nemaidomiciliindu": "domicilia",
    "domiciliată": "domiciliat",
    "domiciliate": "domiciliat",
    "domiciliați": "domiciliat",
    "domicilii": "domiciliu",
    "domiciliile": "domiciliu",
    "domiciliilor": "domiciliu",
    "domiciliul": "domiciliu",
    "domiciliule": "domiciliu",
    "domiciliului": "domiciliu",
    "domin": "domina",
    "domină": "domina",
    "dominai": "domina",
    "dominam": "domina",
    "dominăm": "domina",
    "dominând": "domina",
    "dominându": "domina",
    "dominară": "domina",
    "dominarăm": "domina",
    "dominarăți": "domina",
    "dominase": "domina",
    "dominasem": "domina",
    "dominaseră": "domina",
    "dominaserăm": "domina",
    "dominaserăți": "domina",
    "dominaseși": "domina",
    "dominași": "domina",
    "dominat": "domina",
    "dominați": "domina",
    "dominatu": "domina",
    "dominau": "domina",
    "domine": "domina",
    "domini": "domina",
    "nedominând": "domina",
    "nedominându": "domina",
    "nemaidominând": "domina",
    "nemaidominându": "domina",
    "dominanta": "dominant",
    "dominantă": "dominant",
    "dominante": "dominant",
    "dominantei": "dominant",
    "dominantele": "dominant",
    "dominantelor": "dominant",
    "dominanți": "dominant",
    "dominanții": "dominant",
    "dominanților": "dominant",
    "dominanto": "dominant",
    "dominantul": "dominant",
    "dominantule": "dominant",
    "dominantului": "dominant",
    "dominanta": "dominantă",
    "dominante": "dominantă",
    "dominantei": "dominantă",
    "dominantele": "dominantă",
    "dominantelor": "dominantă",
    "dominanto": "dominantă",
    "dominarea": "dominare",
    "dominareo": "dominare",
    "dominări": "dominare",
    "dominării": "dominare",
    "dominările": "dominare",
    "dominărilor": "dominare",
    "dominată": "dominat",
    "dominate": "dominat",
    "dominați": "dominat",
    "dominația": "dominație",
    "dominației": "dominație",
    "dominații": "dominație",
    "dominațiile": "dominație",
    "dominațiilor": "dominație",
    "dominațio": "dominație",
    "dominatoare": "dominator",
    "dominatoarea": "dominator",
    "dominatoarei": "dominator",
    "dominatoarele": "dominator",
    "dominatoarelor": "dominator",
    "dominatoareo": "dominator",
    "dominatori": "dominator",
    "dominatorii": "dominator",
    "dominatorilor": "dominator",
    "dominatorul": "dominator",
    "dominatorule": "dominator",
    "dominatorului": "dominator",
    "dominicani": "dominican",
    "dominicanii": "dominican",
    "dominicanilor": "dominican",
    "dominicanul": "dominican",
    "dominicanule": "dominican",
    "dominicanului": "dominican",
    "dominicana": "dominicană",
    "dominicane": "dominicană",
    "dominicanei": "dominicană",
    "dominicanele": "dominicană",
    "dominicanelor": "dominicană",
    "dominicano": "dominicană",
    "dominioane": "dominion",
    "dominioanele": "dominion",
    "dominioanelor": "dominion",
    "dominionul": "dominion",
    "dominionule": "dominion",
    "dominionului": "dominion",
    "dominoul": "domino",
    "dominoule": "domino",
    "dominoului": "domino",
    "dominouri": "domino",
    "dominourile": "domino",
    "dominourilor": "domino",
    "doamne": "domn",
    "domle": "domn",
    "dom'le": "domn",
    "domne": "domn",
    "domni": "domn",
    "domnii": "domn",
    "domnilor": "domn",
    "domnul": "domn",
    "domnule": "domn",
    "domnului": "domn",
    "domnea": "domni",
    "domneai": "domni",
    "domneam": "domni",
    "domnească": "domni",
    "domneați": "domni",
    "domneau": "domni",
    "domnesc": "domni",
    "domnește": "domni",
    "domnești": "domni",
    "domnii": "domni",
    "domnim": "domni",
    "domnind": "domni",
    "domnindu": "domni",
    "domniră": "domni",
    "domnirăm": "domni",
    "domnirăți": "domni",
    "domnise": "domni",
    "domnisem": "domni",
    "domniseră": "domni",
    "domniserăm": "domni",
    "domniserăți": "domni",
    "domniseși": "domni",
    "domniși": "domni",
    "domnit": "domni",
    "domniți": "domni",
    "domnitu": "domni",
    "nedomnind": "domni",
    "nedomnindu": "domni",
    "nemaidomnind": "domni",
    "nemaidomnindu": "domni",
    "domnia": "domnie",
    "domniei": "domnie",
    "domnii": "domnie",
    "domniile": "domnie",
    "domniilor": "domnie",
    "dnii": "domnii",
    "d-nii": "domnii",
    "dlor": "domnilor",
    "d-lor": "domnilor",
    "dra": "domnișoara",
    "d-ra": "domnișoara",
    "domnișoara": "domnișoară",
    "domnișoare": "domnișoară",
    "domnișoarei": "domnișoară",
    "domnișoarele": "domnișoară",
    "domnișoarelor": "domnișoară",
    "domnișoaro": "domnișoară",
    "drei": "domnișoarei",
    "domnișori": "domnișor",
    "domnișorii": "domnișor",
    "domnișorilor": "domnișor",
    "domnișorul": "domnișor",
    "domnișorule": "domnișor",
    "domnișorului": "domnișor",
    "domnită": "domnit",
    "domnite": "domnit",
    "domniți": "domnit",
    "domnița": "domniță",
    "domnițe": "domniță",
    "domniței": "domniță",
    "domnițele": "domniță",
    "domnițelor": "domniță",
    "domnitoare": "domnitor",
    "domnitoarea": "domnitor",
    "domnitoarei": "domnitor",
    "domnitoarele": "domnitor",
    "domnitoarelor": "domnitor",
    "domnitoareo": "domnitor",
    "domnitori": "domnitor",
    "domnitorii": "domnitor",
    "domnitorilor": "domnitor",
    "domnitorul": "domnitor",
    "domnitorule": "domnitor",
    "domnitorului": "domnitor",
    "d.": "domnul",
    "dl": "domnul",
    "dl.": "domnul",
    "dnul": "domnul",
    "domnu'": "domnul",
    "d-le": "domnule",
    "dlui": "domnului",
    "d-lui": "domnului",
    "domoala": "domol",
    "domoală": "domol",
    "domoale": "domol",
    "domoalei": "domol",
    "domoalele": "domol",
    "domoalelor": "domol",
    "domoalo": "domol",
    "domoli": "domol",
    "domolii": "domol",
    "domolilor": "domol",
    "domolul": "domol",
    "domolule": "domol",
    "domolului": "domol",
    "domolea": "domoli",
    "domoleai": "domoli",
    "domoleam": "domoli",
    "domolească": "domoli",
    "domoleați": "domoli",
    "domoleau": "domoli",
    "domolesc": "domoli",
    "domolește": "domoli",
    "domolești": "domoli",
    "domolii": "domoli",
    "domolim": "domoli",
    "domolind": "domoli",
    "domolindu": "domoli",
    "domoliră": "domoli",
    "domolirăm": "domoli",
    "domolirăți": "domoli",
    "domolise": "domoli",
    "domolisem": "domoli",
    "domoliseră": "domoli",
    "domoliserăm": "domoli",
    "domoliserăți": "domoli",
    "domoliseși": "domoli",
    "domoliși": "domoli",
    "domolit": "domoli",
    "domoliți": "domoli",
    "domolitu": "domoli",
    "nedomolind": "domoli",
    "nedomolindu": "domoli",
    "nemaidomolind": "domoli",
    "nemaidomolindu": "domoli",
    "domolirea": "domolire",
    "domolireo": "domolire",
    "domoliri": "domolire",
    "domolirii": "domolire",
    "domolirile": "domolire",
    "domolirilor": "domolire",
    "domolita": "domolit",
    "domolită": "domolit",
    "domolite": "domolit",
    "domolitei": "domolit",
    "domolitele": "domolit",
    "domolitelor": "domolit",
    "domoliți": "domolit",
    "domoliții": "domolit",
    "domoliților": "domolit",
    "domolito": "domolit",
    "domolitul": "domolit",
    "domolitule": "domolit",
    "domolitului": "domolit",
    "Donul": "Don",
    "Donului": "Don",
    "donă": "dona",
    "donai": "dona",
    "donam": "dona",
    "donăm": "dona",
    "donând": "dona",
    "donându": "dona",
    "donară": "dona",
    "donarăm": "dona",
    "donarăți": "dona",
    "donase": "dona",
    "donasem": "dona",
    "donaseră": "dona",
    "donaserăm": "dona",
    "donaserăți": "dona",
    "donaseși": "dona",
    "donași": "dona",
    "donat": "dona",
    "donați": "dona",
    "donatu": "dona",
    "donau": "dona",
    "donează": "dona",
    "donez": "dona",
    "doneze": "dona",
    "donezi": "dona",
    "nedonând": "dona",
    "nedonându": "dona",
    "nemaidonând": "dona",
    "nemaidonându": "dona",
    "donarea": "donare",
    "donareo": "donare",
    "donări": "donare",
    "donării": "donare",
    "donările": "donare",
    "donărilor": "donare",
    "donată": "donat",
    "donate": "donat",
    "donați": "donat",
    "donatari": "donatar",
    "donatarii": "donatar",
    "donatarilor": "donatar",
    "donatarul": "donatar",
    "donatarule": "donatar",
    "donatarului": "donatar",
    "donatara": "donatară",
    "donatare": "donatară",
    "donatarei": "donatară",
    "donatarele": "donatară",
    "donatarelor": "donatară",
    "donataro": "donatară",
    "donația": "donație",
    "donației": "donație",
    "donații": "donație",
    "donațiile": "donație",
    "donațiilor": "donație",
    "donațio": "donație",
    "donatoarea": "donatoare",
    "donatoarei": "donatoare",
    "donatoarele": "donatoare",
    "donatoarelor": "donatoare",
    "donatoareo": "donatoare",
    "donatori": "donator",
    "donatorii": "donator",
    "donatorilor": "donator",
    "donatorul": "donator",
    "donatorule": "donator",
    "donatorului": "donator",
    "donchișotisme": "donchișotism",
    "donchișotismele": "donchișotism",
    "donchișotismelor": "donchișotism",
    "donchișotismul": "donchișotism",
    "donchișotismule": "donchișotism",
    "donchișotismului": "donchișotism",
    "dondănea": "dondăni",
    "dondăneai": "dondăni",
    "dondăneam": "dondăni",
    "dondănească": "dondăni",
    "dondăneați": "dondăni",
    "dondăneau": "dondăni",
    "dondănesc": "dondăni",
    "dondănește": "dondăni",
    "dondănești": "dondăni",
    "dondănii": "dondăni",
    "dondănim": "dondăni",
    "dondănind": "dondăni",
    "dondănindu": "dondăni",
    "dondăniră": "dondăni",
    "dondănirăm": "dondăni",
    "dondănirăți": "dondăni",
    "dondănise": "dondăni",
    "dondănisem": "dondăni",
    "dondăniseră": "dondăni",
    "dondăniserăm": "dondăni",
    "dondăniserăți": "dondăni",
    "dondăniseși": "dondăni",
    "dondăniși": "dondăni",
    "dondănit": "dondăni",
    "dondăniți": "dondăni",
    "dondănitu": "dondăni",
    "nedondănind": "dondăni",
    "nedondănindu": "dondăni",
    "nemaidondănind": "dondăni",
    "nemaidondănindu": "dondăni",
    "dondănită": "dondănit",
    "dondănite": "dondănit",
    "dondăniți": "dondănit",
    "donița": "doniță",
    "donițe": "doniță",
    "doniței": "doniță",
    "donițele": "doniță",
    "donițelor": "doniță",
    "donițo": "doniță",
    "donjoane": "donjon",
    "donjoanele": "donjon",
    "donjoanelor": "donjon",
    "donjonul": "donjon",
    "donjonule": "donjon",
    "donjonului": "donjon",
    "donjuani": "donjuan",
    "donjuanii": "donjuan",
    "donjuanilor": "donjuan",
    "donjuanul": "donjuan",
    "donjuanule": "donjuan",
    "donjuanului": "donjuan",
    "dopul": "dop",
    "dopule": "dop",
    "dopului": "dop",
    "dopuri": "dop",
    "dopurile": "dop",
    "dopurilor": "dop",
    "dopă": "dopa",
    "dopai": "dopa",
    "dopam": "dopa",
    "dopăm": "dopa",
    "dopând": "dopa",
    "dopându": "dopa",
    "dopară": "dopa",
    "doparăm": "dopa",
    "doparăți": "dopa",
    "dopase": "dopa",
    "dopasem": "dopa",
    "dopaseră": "dopa",
    "dopaserăm": "dopa",
    "dopaserăți": "dopa",
    "dopaseși": "dopa",
    "dopași": "dopa",
    "dopat": "dopa",
    "dopați": "dopa",
    "dopatu": "dopa",
    "dopau": "dopa",
    "dopează": "dopa",
    "dopez": "dopa",
    "dopeze": "dopa",
    "dopezi": "dopa",
    "nedopând": "dopa",
    "nedopându": "dopa",
    "nemaidopând": "dopa",
    "nemaidopându": "dopa",
    "dopaje": "dopaj",
    "dopajele": "dopaj",
    "dopajelor": "dopaj",
    "dopajul": "dopaj",
    "dopajului": "dopaj",
    "doparea": "dopare",
    "dopareo": "dopare",
    "dopări": "dopare",
    "dopării": "dopare",
    "dopările": "dopare",
    "dopărilor": "dopare",
    "dopată": "dopat",
    "dopate": "dopat",
    "dopați": "dopat",
    "dorul": "dor",
    "dorule": "dor",
    "dorului": "dor",
    "doruri": "dor",
    "dorurile": "dor",
    "dorurilor": "dor",
    "dorea": "dori",
    "doreai": "dori",
    "doream": "dori",
    "dorească": "dori",
    "doreați": "dori",
    "doreau": "dori",
    "doresc": "dori",
    "dorește": "dori",
    "dorești": "dori",
    "dorii": "dori",
    "dorim": "dori",
    "dorind": "dori",
    "dorindu": "dori",
    "doriră": "dori",
    "dorirăm": "dori",
    "dorirăți": "dori",
    "dorise": "dori",
    "dorisem": "dori",
    "doriseră": "dori",
    "doriserăm": "dori",
    "doriserăți": "dori",
    "doriseși": "dori",
    "doriși": "dori",
    "dorit": "dori",
    "doriți": "dori",
    "doritu": "dori",
    "nedorind": "dori",
    "nedorindu": "dori",
    "nemaidorind": "dori",
    "nemaidorindu": "dori",
    "dorica": "doric",
    "dorică": "doric",
    "dorice": "doric",
    "doricei": "doric",
    "doricele": "doric",
    "doricelor": "doric",
    "dorici": "doric",
    "doricii": "doric",
    "doricilor": "doric",
    "dorico": "doric",
    "doricul": "doric",
    "doricule": "doric",
    "doricului": "doric",
    "Dorinei": "Dorina",
    "dorința": "dorință",
    "dorințe": "dorință",
    "dorinței": "dorință",
    "dorințele": "dorință",
    "dorințelor": "dorință",
    "dorinți": "dorință",
    "dorințo": "dorință",
    "dorirea": "dorire",
    "doriri": "dorire",
    "doririi": "dorire",
    "doririle": "dorire",
    "doririlor": "dorire",
    "dorita": "dorit",
    "dorită": "dorit",
    "dorite": "dorit",
    "doritei": "dorit",
    "doritele": "dorit",
    "doritelor": "dorit",
    "doriți": "dorit",
    "doriții": "dorit",
    "doriților": "dorit",
    "dorito": "dorit",
    "doritul": "dorit",
    "doritule": "dorit",
    "doritului": "dorit",
    "doritoare": "doritor",
    "doritoarea": "doritor",
    "doritoarei": "doritor",
    "doritoarele": "doritor",
    "doritoarelor": "doritor",
    "doritoareo": "doritor",
    "doritori": "doritor",
    "doritorii": "doritor",
    "doritorilor": "doritor",
    "doritorul": "doritor",
    "doritorule": "doritor",
    "doritorului": "doritor",
    "dormeza": "dormeză",
    "dormeze": "dormeză",
    "dormezei": "dormeză",
    "dormezele": "dormeză",
    "dormezelor": "dormeză",
    "dormezo": "dormeză",
    "doarmă": "dormi",
    "doarme": "dormi",
    "dorm": "dormi",
    "dormea": "dormi",
    "dormeai": "dormi",
    "dormeam": "dormi",
    "dormeați": "dormi",
    "dormeau": "dormi",
    "dormii": "dormi",
    "dormim": "dormi",
    "dormind": "dormi",
    "dormindu": "dormi",
    "dormiră": "dormi",
    "dormirăm": "dormi",
    "dormirăți": "dormi",
    "dormise": "dormi",
    "dormisem": "dormi",
    "dormiseră": "dormi",
    "dormiserăm": "dormi",
    "dormiserăți": "dormi",
    "dormiseși": "dormi",
    "dormiși": "dormi",
    "dormit": "dormi",
    "dormiți": "dormi",
    "dormitu": "dormi",
    "nedormind": "dormi",
    "nedormindu": "dormi",
    "nemaidormind": "dormi",
    "nemaidormindu": "dormi",
    "dormită": "dormit",
    "dormite": "dormit",
    "dormiți": "dormit",
    "dormitul": "dormit",
    "dormitule": "dormit",
    "dormitului": "dormit",
    "dormită": "dormita",
    "dormitai": "dormita",
    "dormitam": "dormita",
    "dormităm": "dormita",
    "dormitând": "dormita",
    "dormitându": "dormita",
    "dormitară": "dormita",
    "dormitarăm": "dormita",
    "dormitarăți": "dormita",
    "dormitase": "dormita",
    "dormitasem": "dormita",
    "dormitaseră": "dormita",
    "dormitaserăm": "dormita",
    "dormitaserăți": "dormita",
    "dormitaseși": "dormita",
    "dormitași": "dormita",
    "dormitat": "dormita",
    "dormitați": "dormita",
    "dormitatu": "dormita",
    "dormitau": "dormita",
    "dormitează": "dormita",
    "dormitez": "dormita",
    "dormiteze": "dormita",
    "dormitezi": "dormita",
    "nedormitând": "dormita",
    "nedormitându": "dormita",
    "nemaidormitând": "dormita",
    "nemaidormitându": "dormita",
    "dormitată": "dormitat",
    "dormitate": "dormitat",
    "dormitați": "dormitat",
    "dormitoare": "dormitor",
    "dormitoarele": "dormitor",
    "dormitoarelor": "dormitor",
    "dormitorul": "dormitor",
    "dormitorule": "dormitor",
    "dormitorului": "dormitor",
    "dornul": "dorn",
    "dornule": "dorn",
    "dornului": "dorn",
    "dornuri": "dorn",
    "dornurile": "dorn",
    "dornurilor": "dorn",
    "Dornei": "Dorna",
    "dornica": "dornic",
    "dornică": "dornic",
    "dornice": "dornic",
    "dornicei": "dornic",
    "dornicele": "dornic",
    "dornicelor": "dornic",
    "dornici": "dornic",
    "dornicii": "dornic",
    "dornicilor": "dornic",
    "dornico": "dornic",
    "dornicul": "dornic",
    "dornicule": "dornic",
    "dornicului": "dornic",
    "dorobanți": "dorobanț",
    "dorobanții": "dorobanț",
    "dorobanților": "dorobanț",
    "dorobanțul": "dorobanț",
    "dorobanțule": "dorobanț",
    "dorobanțului": "dorobanț",
    "Dorohoiul": "Dorohoi",
    "Dorohoiului": "Dorohoi",
    "dorohoiană": "dorohoian",
    "dorohoiene": "dorohoian",
    "dorohoieni": "dorohoian",
    "dorsala": "dorsal",
    "dorsală": "dorsal",
    "dorsale": "dorsal",
    "dorsalei": "dorsal",
    "dorsalele": "dorsal",
    "dorsalelor": "dorsal",
    "dorsali": "dorsal",
    "dorsalii": "dorsal",
    "dorsalilor": "dorsal",
    "dorsalo": "dorsal",
    "dorsalul": "dorsal",
    "dorsalule": "dorsal",
    "dorsalului": "dorsal",
    "dosul": "dos",
    "dosule": "dos",
    "dosului": "dos",
    "dosuri": "dos",
    "dosurile": "dos",
    "dosurilor": "dos",
    "dosare": "dosar",
    "dosarele": "dosar",
    "dosarelor": "dosar",
    "dosarul": "dosar",
    "dosarule": "dosar",
    "dosarului": "dosar",
    "dosea": "dosi",
    "doseai": "dosi",
    "doseam": "dosi",
    "dosească": "dosi",
    "doseați": "dosi",
    "doseau": "dosi",
    "dosesc": "dosi",
    "dosește": "dosi",
    "dosești": "dosi",
    "dosii": "dosi",
    "dosim": "dosi",
    "dosind": "dosi",
    "dosindu": "dosi",
    "dosiră": "dosi",
    "dosirăm": "dosi",
    "dosirăți": "dosi",
    "dosise": "dosi",
    "dosisem": "dosi",
    "dosiseră": "dosi",
    "dosiserăm": "dosi",
    "dosiserăți": "dosi",
    "dosiseși": "dosi",
    "dosiși": "dosi",
    "dosit": "dosi",
    "dosiți": "dosi",
    "dositu": "dosi",
    "nedosind": "dosi",
    "nedosindu": "dosi",
    "nemaidosind": "dosi",
    "nemaidosindu": "dosi",
    "dosirea": "dosire",
    "dosireo": "dosire",
    "dosiri": "dosire",
    "dosirii": "dosire",
    "dosirile": "dosire",
    "dosirilor": "dosire",
    "dosita": "dosit",
    "dosită": "dosit",
    "dosite": "dosit",
    "dositei": "dosit",
    "dositele": "dosit",
    "dositelor": "dosit",
    "dosiți": "dosit",
    "dosiții": "dosit",
    "dosiților": "dosit",
    "dosito": "dosit",
    "dositul": "dosit",
    "dositule": "dosit",
    "dositului": "dosit",
    "dosnica": "dosnic",
    "dosnică": "dosnic",
    "dosnice": "dosnic",
    "dosnicei": "dosnic",
    "dosnicele": "dosnic",
    "dosnicelor": "dosnic",
    "dosnici": "dosnic",
    "dosnicii": "dosnic",
    "dosnicilor": "dosnic",
    "dosnico": "dosnic",
    "dosnicul": "dosnic",
    "dosnicule": "dosnic",
    "dosnicului": "dosnic",
    "dospeala": "dospeală",
    "dospealo": "dospeală",
    "dospeli": "dospeală",
    "dospelii": "dospeală",
    "dospelile": "dospeală",
    "dospelilor": "dospeală",
    "dospea": "dospi",
    "dospeai": "dospi",
    "dospeam": "dospi",
    "dospească": "dospi",
    "dospeați": "dospi",
    "dospeau": "dospi",
    "dospesc": "dospi",
    "dospește": "dospi",
    "dospești": "dospi",
    "dospii": "dospi",
    "dospim": "dospi",
    "dospind": "dospi",
    "dospindu": "dospi",
    "dospiră": "dospi",
    "dospirăm": "dospi",
    "dospirăți": "dospi",
    "dospise": "dospi",
    "dospisem": "dospi",
    "dospiseră": "dospi",
    "dospiserăm": "dospi",
    "dospiserăți": "dospi",
    "dospiseși": "dospi",
    "dospiși": "dospi",
    "dospit": "dospi",
    "dospiți": "dospi",
    "dospitu": "dospi",
    "nedospind": "dospi",
    "nedospindu": "dospi",
    "nemaidospind": "dospi",
    "nemaidospindu": "dospi",
    "dospirea": "dospire",
    "dospireo": "dospire",
    "dospiri": "dospire",
    "dospirii": "dospire",
    "dospirile": "dospire",
    "dospirilor": "dospire",
    "dospita": "dospit",
    "dospită": "dospit",
    "dospite": "dospit",
    "dospitei": "dospit",
    "dospitele": "dospit",
    "dospitelor": "dospit",
    "dospiți": "dospit",
    "dospiții": "dospit",
    "dospiților": "dospit",
    "dospito": "dospit",
    "dospitul": "dospit",
    "dospitule": "dospit",
    "dospitului": "dospit",
    "dospitoarea": "dospitoare",
    "dospitoarei": "dospitoare",
    "dospitoarele": "dospitoare",
    "dospitoarelor": "dospitoare",
    "dospitoareo": "dospitoare",
    "dostoievskiana": "dostoievskian",
    "dostoievskiană": "dostoievskian",
    "dostoievskiano": "dostoievskian",
    "dostoievskianul": "dostoievskian",
    "dostoievskianule": "dostoievskian",
    "dostoievskianului": "dostoievskian",
    "dostoievskiene": "dostoievskian",
    "dostoievskienei": "dostoievskian",
    "dostoievskienele": "dostoievskian",
    "dostoievskienelor": "dostoievskian",
    "dostoievskieni": "dostoievskian",
    "dostoievskienii": "dostoievskian",
    "dostoievskienilor": "dostoievskian",
    "dotă": "dota",
    "dotai": "dota",
    "dotam": "dota",
    "dotăm": "dota",
    "dotând": "dota",
    "dotându": "dota",
    "dotară": "dota",
    "dotarăm": "dota",
    "dotarăți": "dota",
    "dotase": "dota",
    "dotasem": "dota",
    "dotaseră": "dota",
    "dotaserăm": "dota",
    "dotaserăți": "dota",
    "dotaseși": "dota",
    "dotași": "dota",
    "dotat": "dota",
    "dotați": "dota",
    "dotatu": "dota",
    "dotau": "dota",
    "dotează": "dota",
    "dotez": "dota",
    "doteze": "dota",
    "dotezi": "dota",
    "nedotând": "dota",
    "nedotându": "dota",
    "nemaidotând": "dota",
    "nemaidotându": "dota",
    "dota": "dotă",
    "dote": "dotă",
    "dotei": "dotă",
    "dotele": "dotă",
    "dotelor": "dotă",
    "doto": "dotă",
    "dotala": "dotal",
    "dotală": "dotal",
    "dotale": "dotal",
    "dotalei": "dotal",
    "dotalele": "dotal",
    "dotalelor": "dotal",
    "dotali": "dotal",
    "dotalii": "dotal",
    "dotalilor": "dotal",
    "dotalo": "dotal",
    "dotalul": "dotal",
    "dotalule": "dotal",
    "dotalului": "dotal",
    "dotarea": "dotare",
    "dotareo": "dotare",
    "dotări": "dotare",
    "dotării": "dotare",
    "dotările": "dotare",
    "dotărilor": "dotare",
    "dotata": "dotat",
    "dotată": "dotat",
    "dotate": "dotat",
    "dotatei": "dotat",
    "dotatele": "dotat",
    "dotatelor": "dotat",
    "dotați": "dotat",
    "dotații": "dotat",
    "dotaților": "dotat",
    "dotato": "dotat",
    "dotatul": "dotat",
    "dotatule": "dotat",
    "dotatului": "dotat",
    "douăzecea": "douăzeci",
    "douăzecilea": "douăzeci",
    "XX": "douăzeci",
    "XXI": "douăzeci_și_unu",
    "douășcinci": "douăzecișicinci",
    "douăș'cinci": "douăzecișicinci",
    "dovada": "dovadă",
    "dovado": "dovadă",
    "dovezi": "dovadă",
    "dovezii": "dovadă",
    "dovezile": "dovadă",
    "dovezilor": "dovadă",
    "dovedea": "dovedi",
    "dovedeai": "dovedi",
    "dovedeam": "dovedi",
    "dovedească": "dovedi",
    "dovedeați": "dovedi",
    "dovedeau": "dovedi",
    "dovedesc": "dovedi",
    "dovedește": "dovedi",
    "dovedești": "dovedi",
    "dovedii": "dovedi",
    "dovedim": "dovedi",
    "dovedind": "dovedi",
    "dovedindu": "dovedi",
    "dovediră": "dovedi",
    "dovedirăm": "dovedi",
    "dovedirăți": "dovedi",
    "dovedise": "dovedi",
    "dovedisem": "dovedi",
    "dovediseră": "dovedi",
    "dovediserăm": "dovedi",
    "dovediserăți": "dovedi",
    "dovediseși": "dovedi",
    "dovediși": "dovedi",
    "dovedit": "dovedi",
    "dovediți": "dovedi",
    "doveditu": "dovedi",
    "nedovedind": "dovedi",
    "nedovedindu": "dovedi",
    "nemaidovedind": "dovedi",
    "nemaidovedindu": "dovedi",
    "dovedirea": "dovedire",
    "dovedireo": "dovedire",
    "dovediri": "dovedire",
    "dovedirii": "dovedire",
    "dovedirile": "dovedire",
    "dovedirilor": "dovedire",
    "dovedită": "dovedit",
    "dovedite": "dovedit",
    "dovediți": "dovedit",
    "doveditoare": "doveditor",
    "doveditoarea": "doveditor",
    "doveditoarei": "doveditor",
    "doveditoarele": "doveditor",
    "doveditoarelor": "doveditor",
    "doveditoareo": "doveditor",
    "doveditori": "doveditor",
    "doveditorii": "doveditor",
    "doveditorilor": "doveditor",
    "doveditorul": "doveditor",
    "doveditorule": "doveditor",
    "doveditorului": "doveditor",
    "dovleacul": "dovleac",
    "dovleacule": "dovleac",
    "dovleacului": "dovleac",
    "dovleci": "dovleac",
    "dovlecii": "dovleac",
    "dovlecilor": "dovleac",
    "dovlecei": "dovlecel",
    "dovleceii": "dovlecel",
    "dovleceilor": "dovlecel",
    "dovlecelul": "dovlecel",
    "dovlecelule": "dovlecel",
    "dovlecelului": "dovlecel",
    "doxa": "doxă",
    "doxe": "doxă",
    "doxei": "doxă",
    "doxele": "doxă",
    "doxelor": "doxă",
    "doxo": "doxă",
    "doxologia": "doxologie",
    "doxologiei": "doxologie",
    "doxologii": "doxologie",
    "doxologiile": "doxologie",
    "doxologiilor": "doxologie",
    "doxologio": "doxologie",
    "doză": "doza",
    "dozai": "doza",
    "dozam": "doza",
    "dozăm": "doza",
    "dozând": "doza",
    "dozându": "doza",
    "dozară": "doza",
    "dozarăm": "doza",
    "dozarăți": "doza",
    "dozase": "doza",
    "dozasem": "doza",
    "dozaseră": "doza",
    "dozaserăm": "doza",
    "dozaserăți": "doza",
    "dozaseși": "doza",
    "dozași": "doza",
    "dozat": "doza",
    "dozați": "doza",
    "dozatu": "doza",
    "dozau": "doza",
    "dozează": "doza",
    "dozez": "doza",
    "dozeze": "doza",
    "dozezi": "doza",
    "nedozând": "doza",
    "nedozându": "doza",
    "nemaidozând": "doza",
    "nemaidozându": "doza",
    "doza": "doză",
    "doze": "doză",
    "dozei": "doză",
    "dozele": "doză",
    "dozelor": "doză",
    "dozo": "doză",
    "dozaje": "dozaj",
    "dozajele": "dozaj",
    "dozajelor": "dozaj",
    "dozajul": "dozaj",
    "dozajule": "dozaj",
    "dozajului": "dozaj",
    "dozarea": "dozare",
    "dozareo": "dozare",
    "dozări": "dozare",
    "dozării": "dozare",
    "dozările": "dozare",
    "dozărilor": "dozare",
    "dozată": "dozat",
    "dozate": "dozat",
    "dozați": "dozat",
    "drace": "drac",
    "draci": "drac",
    "dracii": "drac",
    "dracilor": "drac",
    "dracu": "drac",
    "dracu'": "drac",
    "dracul": "drac",
    "dracule": "drac",
    "dracului": "drac",
    "drăceasca": "drăcesc",
    "drăcească": "drăcesc",
    "drăceasco": "drăcesc",
    "drăcescul": "drăcesc",
    "drăcescule": "drăcesc",
    "drăcescului": "drăcesc",
    "drăcești": "drăcesc",
    "drăceștii": "drăcesc",
    "drăceștile": "drăcesc",
    "drăceștilor": "drăcesc",
    "drăcoaica": "drăcoaică",
    "drăcoaice": "drăcoaică",
    "drăcoaicei": "drăcoaică",
    "drăcoaicele": "drăcoaică",
    "drăcoaicelor": "drăcoaică",
    "drăcoaico": "drăcoaică",
    "draconica": "draconic",
    "draconică": "draconic",
    "draconice": "draconic",
    "draconicei": "draconic",
    "draconicele": "draconic",
    "draconicelor": "draconic",
    "draconici": "draconic",
    "draconicii": "draconic",
    "draconicilor": "draconic",
    "draconico": "draconic",
    "draconicul": "draconic",
    "draconicule": "draconic",
    "draconicului": "draconic",
    "drăcovenia": "drăcovenie",
    "drăcoveniei": "drăcovenie",
    "drăcovenii": "drăcovenie",
    "drăcoveniile": "drăcovenie",
    "drăcoveniilor": "drăcovenie",
    "drăcovenio": "drăcovenie",
    "drăcuia": "drăcui",
    "drăcuiai": "drăcui",
    "drăcuiam": "drăcui",
    "drăcuiască": "drăcui",
    "drăcuiați": "drăcui",
    "drăcuiau": "drăcui",
    "drăcuiesc": "drăcui",
    "drăcuiește": "drăcui",
    "drăcuiești": "drăcui",
    "drăcuii": "drăcui",
    "drăcuim": "drăcui",
    "drăcuind": "drăcui",
    "drăcuindu": "drăcui",
    "drăcuiră": "drăcui",
    "drăcuirăm": "drăcui",
    "drăcuirăți": "drăcui",
    "drăcuise": "drăcui",
    "drăcuisem": "drăcui",
    "drăcuiseră": "drăcui",
    "drăcuiserăm": "drăcui",
    "drăcuiserăți": "drăcui",
    "drăcuiseși": "drăcui",
    "drăcuiși": "drăcui",
    "drăcuit": "drăcui",
    "drăcuiți": "drăcui",
    "drăcuitu": "drăcui",
    "nedrăcuind": "drăcui",
    "nedrăcuindu": "drăcui",
    "nemaidrăcuind": "drăcui",
    "nemaidrăcuindu": "drăcui",
    "drăcuirea": "drăcuire",
    "drăcuireo": "drăcuire",
    "drăcuiri": "drăcuire",
    "drăcuirii": "drăcuire",
    "drăcuirile": "drăcuire",
    "drăcuirilor": "drăcuire",
    "drăcuită": "drăcuit",
    "drăcuite": "drăcuit",
    "drăcuiți": "drăcuit",
    "draga": "drag",
    "dragă": "drag",
    "drage": "drag",
    "dragei": "drag",
    "dragele": "drag",
    "dragelor": "drag",
    "dragi": "drag",
    "dragii": "drag",
    "dragilor": "drag",
    "drago": "drag",
    "dragul": "drag",
    "dragule": "drag",
    "dragului": "drag",
    "dragă": "draga",
    "dragai": "draga",
    "dragam": "draga",
    "dragăm": "draga",
    "dragând": "draga",
    "dragându": "draga",
    "dragară": "draga",
    "dragarăm": "draga",
    "dragarăți": "draga",
    "dragase": "draga",
    "dragasem": "draga",
    "dragaseră": "draga",
    "dragaserăm": "draga",
    "dragaserăți": "draga",
    "dragaseși": "draga",
    "dragași": "draga",
    "dragat": "draga",
    "dragați": "draga",
    "dragatu": "draga",
    "dragau": "draga",
    "draghează": "draga",
    "draghez": "draga",
    "dragheze": "draga",
    "draghezi": "draga",
    "nedragând": "draga",
    "nedragându": "draga",
    "nemaidragând": "draga",
    "nemaidragându": "draga",
    "draga": "dragă",
    "drage": "dragă",
    "dragei": "dragă",
    "dragele": "dragă",
    "dragelor": "dragă",
    "drago": "dragă",
    "drăgaica": "drăgaică",
    "drăgaice": "drăgaică",
    "drăgaicei": "drăgaică",
    "drăgaicele": "drăgaică",
    "drăgaicelor": "drăgaică",
    "drăgaico": "drăgaică",
    "dragaje": "dragaj",
    "dragajele": "dragaj",
    "dragajelor": "dragaj",
    "dragajul": "dragaj",
    "dragajule": "dragaj",
    "dragajului": "dragaj",
    "drăgălașa": "drăgălaș",
    "drăgălașă": "drăgălaș",
    "drăgălașe": "drăgălaș",
    "drăgălașei": "drăgălaș",
    "drăgălașele": "drăgălaș",
    "drăgălașelor": "drăgălaș",
    "drăgălași": "drăgălaș",
    "drăgălașii": "drăgălaș",
    "drăgălașilor": "drăgălaș",
    "drăgălașo": "drăgălaș",
    "drăgălașul": "drăgălaș",
    "drăgălașule": "drăgălaș",
    "drăgălașului": "drăgălaș",
    "drăgălășenia": "drăgălășenie",
    "drăgălășeniei": "drăgălășenie",
    "drăgălășenii": "drăgălășenie",
    "drăgălășeniile": "drăgălășenie",
    "drăgălășeniilor": "drăgălășenie",
    "drăgălășenio": "drăgălășenie",
    "dragarea": "dragare",
    "dragareo": "dragare",
    "dragări": "dragare",
    "dragării": "dragare",
    "dragările": "dragare",
    "dragărilor": "dragare",
    "dragată": "dragat",
    "dragate": "dragat",
    "dragați": "dragat",
    "draglina": "draglină",
    "dragline": "draglină",
    "draglinei": "draglină",
    "draglinele": "draglină",
    "draglinelor": "draglină",
    "draglino": "draglină",
    "dragomani": "dragoman",
    "dragomanii": "dragoman",
    "dragomanilor": "dragoman",
    "dragomanul": "dragoman",
    "dragomanule": "dragoman",
    "dragomanului": "dragoman",
    "dragoane": "dragon",
    "dragoanele": "dragon",
    "dragoanelor": "dragon",
    "dragoni": "dragon",
    "dragonii": "dragon",
    "dragonilor": "dragon",
    "dragonul": "dragon",
    "dragonule": "dragon",
    "dragonului": "dragon",
    "dragoare": "dragor",
    "dragoarele": "dragor",
    "dragoarelor": "dragor",
    "dragori": "dragor",
    "dragorii": "dragor",
    "dragorilor": "dragor",
    "dragorul": "dragor",
    "dragorule": "dragor",
    "dragorului": "dragor",
    "dragostea": "dragoste",
    "dragostei": "dragoste",
    "dragostele": "dragoste",
    "dragostelor": "dragoste",
    "dragosteo": "dragoste",
    "drăgosteala": "drăgosteală",
    "drăgostealo": "drăgosteală",
    "drăgosteli": "drăgosteală",
    "drăgostelii": "drăgosteală",
    "drăgostelile": "drăgosteală",
    "drăgostelilor": "drăgosteală",
    "drăgostea": "drăgosti",
    "drăgosteai": "drăgosti",
    "drăgosteam": "drăgosti",
    "drăgostească": "drăgosti",
    "drăgosteați": "drăgosti",
    "drăgosteau": "drăgosti",
    "drăgostesc": "drăgosti",
    "drăgostește": "drăgosti",
    "drăgostești": "drăgosti",
    "drăgostii": "drăgosti",
    "drăgostim": "drăgosti",
    "drăgostind": "drăgosti",
    "drăgostindu": "drăgosti",
    "drăgostiră": "drăgosti",
    "drăgostirăm": "drăgosti",
    "drăgostirăți": "drăgosti",
    "drăgostise": "drăgosti",
    "drăgostisem": "drăgosti",
    "drăgostiseră": "drăgosti",
    "drăgostiserăm": "drăgosti",
    "drăgostiserăți": "drăgosti",
    "drăgostiseși": "drăgosti",
    "drăgostiși": "drăgosti",
    "drăgostit": "drăgosti",
    "drăgostiți": "drăgosti",
    "drăgostitu": "drăgosti",
    "nedrăgostind": "drăgosti",
    "nedrăgostindu": "drăgosti",
    "nemaidrăgostind": "drăgosti",
    "nemaidrăgostindu": "drăgosti",
    "drăgostirea": "drăgostire",
    "drăgostireo": "drăgostire",
    "drăgostiri": "drăgostire",
    "drăgostirii": "drăgostire",
    "drăgostirile": "drăgostire",
    "drăgostirilor": "drăgostire",
    "drăgostită": "drăgostit",
    "drăgostite": "drăgostit",
    "drăgostiți": "drăgostit",
    "drăguța": "drăguț",
    "drăguță": "drăguț",
    "drăguțe": "drăguț",
    "drăguței": "drăguț",
    "drăguțele": "drăguț",
    "drăguțelor": "drăguț",
    "drăguți": "drăguț",
    "drăguții": "drăguț",
    "drăguților": "drăguț",
    "drăguțo": "drăguț",
    "drăguțul": "drăguț",
    "drăguțule": "drăguț",
    "drăguțului": "drăguț",
    "drăguța": "drăguță",
    "drăguțe": "drăguță",
    "drăguței": "drăguță",
    "drăguțele": "drăguță",
    "drăguțelor": "drăguță",
    "drăguțo": "drăguță",
    "drahma": "drahmă",
    "drahme": "drahmă",
    "drahmei": "drahmă",
    "drahmele": "drahmă",
    "drahmelor": "drahmă",
    "drahmo": "drahmă",
    "drajeul": "drajeu",
    "drajeule": "drajeu",
    "drajeului": "drajeu",
    "drajeuri": "drajeu",
    "drajeurile": "drajeu",
    "drajeurilor": "drajeu",
    "dramul": "dram",
    "dramule": "dram",
    "dramului": "dram",
    "dramuri": "dram",
    "dramurile": "dram",
    "dramurilor": "dram",
    "drama": "dramă",
    "drame": "dramă",
    "dramei": "dramă",
    "dramele": "dramă",
    "dramelor": "dramă",
    "dramo": "dramă",
    "drămăluia": "drămălui",
    "drămăluiai": "drămălui",
    "drămăluiam": "drămălui",
    "drămăluiască": "drămălui",
    "drămăluiați": "drămălui",
    "drămăluiau": "drămălui",
    "drămăluiesc": "drămălui",
    "drămăluiește": "drămălui",
    "drămăluiești": "drămălui",
    "drămăluii": "drămălui",
    "drămăluim": "drămălui",
    "drămăluind": "drămălui",
    "drămăluindu": "drămălui",
    "drămăluiră": "drămălui",
    "drămăluirăm": "drămălui",
    "drămăluirăți": "drămălui",
    "drămăluise": "drămălui",
    "drămăluisem": "drămălui",
    "drămăluiseră": "drămălui",
    "drămăluiserăm": "drămălui",
    "drămăluiserăți": "drămălui",
    "drămăluiseși": "drămălui",
    "drămăluiși": "drămălui",
    "drămăluit": "drămălui",
    "drămăluiți": "drămălui",
    "drămăluitu": "drămălui",
    "nedrămăluind": "drămălui",
    "nedrămăluindu": "drămălui",
    "nemaidrămăluind": "drămălui",
    "nemaidrămăluindu": "drămălui",
    "drămăluirea": "drămăluire",
    "drămăluireo": "drămăluire",
    "drămăluiri": "drămăluire",
    "drămăluirii": "drămăluire",
    "drămăluirile": "drămăluire",
    "drămăluirilor": "drămăluire",
    "drămăluită": "drămăluit",
    "drămăluite": "drămăluit",
    "drămăluiți": "drămăluit",
    "dramatica": "dramatic",
    "dramatică": "dramatic",
    "dramatice": "dramatic",
    "dramaticei": "dramatic",
    "dramaticele": "dramatic",
    "dramaticelor": "dramatic",
    "dramatici": "dramatic",
    "dramaticii": "dramatic",
    "dramaticilor": "dramatic",
    "dramatico": "dramatic",
    "dramaticul": "dramatic",
    "dramaticule": "dramatic",
    "dramaticului": "dramatic",
    "dramatisme": "dramatism",
    "dramatismele": "dramatism",
    "dramatismelor": "dramatism",
    "dramatismul": "dramatism",
    "dramatismule": "dramatism",
    "dramatismului": "dramatism",
    "dramatiză": "dramatiza",
    "dramatizai": "dramatiza",
    "dramatizam": "dramatiza",
    "dramatizăm": "dramatiza",
    "dramatizând": "dramatiza",
    "dramatizându": "dramatiza",
    "dramatizară": "dramatiza",
    "dramatizarăm": "dramatiza",
    "dramatizarăți": "dramatiza",
    "dramatizase": "dramatiza",
    "dramatizasem": "dramatiza",
    "dramatizaseră": "dramatiza",
    "dramatizaserăm": "dramatiza",
    "dramatizaserăți": "dramatiza",
    "dramatizaseși": "dramatiza",
    "dramatizași": "dramatiza",
    "dramatizat": "dramatiza",
    "dramatizați": "dramatiza",
    "dramatizatu": "dramatiza",
    "dramatizau": "dramatiza",
    "dramatizează": "dramatiza",
    "dramatizez": "dramatiza",
    "dramatizeze": "dramatiza",
    "dramatizezi": "dramatiza",
    "nedramatizând": "dramatiza",
    "nedramatizându": "dramatiza",
    "nemaidramatizând": "dramatiza",
    "nemaidramatizându": "dramatiza",
    "dramatizarea": "dramatizare",
    "dramatizareo": "dramatizare",
    "dramatizări": "dramatizare",
    "dramatizării": "dramatizare",
    "dramatizările": "dramatizare",
    "dramatizărilor": "dramatizare",
    "dramatizată": "dramatizat",
    "dramatizate": "dramatizat",
    "dramatizați": "dramatizat",
    "dramaturgi": "dramaturg",
    "dramaturgii": "dramaturg",
    "dramaturgilor": "dramaturg",
    "dramaturgul": "dramaturg",
    "dramaturgule": "dramaturg",
    "dramaturgului": "dramaturg",
    "dramaturgica": "dramaturgic",
    "dramaturgică": "dramaturgic",
    "dramaturgice": "dramaturgic",
    "dramaturgicei": "dramaturgic",
    "dramaturgicele": "dramaturgic",
    "dramaturgicelor": "dramaturgic",
    "dramaturgici": "dramaturgic",
    "dramaturgicii": "dramaturgic",
    "dramaturgicilor": "dramaturgic",
    "dramaturgico": "dramaturgic",
    "dramaturgicul": "dramaturgic",
    "dramaturgicule": "dramaturgic",
    "dramaturgicului": "dramaturgic",
    "dramaturgia": "dramaturgie",
    "dramaturgiei": "dramaturgie",
    "dramaturgii": "dramaturgie",
    "dramaturgiile": "dramaturgie",
    "dramaturgiilor": "dramaturgie",
    "dramaturgio": "dramaturgie",
    "drâmba": "drâmbă",
    "drâmbe": "drâmbă",
    "drâmbei": "drâmbă",
    "drâmbele": "drâmbă",
    "drâmbelor": "drâmbă",
    "drâmbo": "drâmbă",
    "drămuia": "drămui",
    "drămuiai": "drămui",
    "drămuiam": "drămui",
    "drămuiască": "drămui",
    "drămuiați": "drămui",
    "drămuiau": "drămui",
    "drămuiesc": "drămui",
    "drămuiește": "drămui",
    "drămuiești": "drămui",
    "drămuii": "drămui",
    "drămuim": "drămui",
    "drămuind": "drămui",
    "drămuindu": "drămui",
    "drămuiră": "drămui",
    "drămuirăm": "drămui",
    "drămuirăți": "drămui",
    "drămuise": "drămui",
    "drămuisem": "drămui",
    "drămuiseră": "drămui",
    "drămuiserăm": "drămui",
    "drămuiserăți": "drămui",
    "drămuiseși": "drămui",
    "drămuiși": "drămui",
    "drămuit": "drămui",
    "drămuiți": "drămui",
    "drămuitu": "drămui",
    "nedrămuind": "drămui",
    "nedrămuindu": "drămui",
    "nemaidrămuind": "drămui",
    "nemaidrămuindu": "drămui",
    "drămuirea": "drămuire",
    "drămuireo": "drămuire",
    "drămuiri": "drămuire",
    "drămuirii": "drămuire",
    "drămuirile": "drămuire",
    "drămuirilor": "drămuire",
    "drămuită": "drămuit",
    "drămuite": "drămuit",
    "drămuiți": "drămuit",
    "drapă": "drapa",
    "drapai": "drapa",
    "drapam": "drapa",
    "drapăm": "drapa",
    "drapând": "drapa",
    "drapându": "drapa",
    "drapară": "drapa",
    "draparăm": "drapa",
    "draparăți": "drapa",
    "drapase": "drapa",
    "drapasem": "drapa",
    "drapaseră": "drapa",
    "drapaserăm": "drapa",
    "drapaserăți": "drapa",
    "drapaseși": "drapa",
    "drapași": "drapa",
    "drapat": "drapa",
    "drapați": "drapa",
    "drapatu": "drapa",
    "drapau": "drapa",
    "drapează": "drapa",
    "drapez": "drapa",
    "drapeze": "drapa",
    "drapezi": "drapa",
    "nedrapând": "drapa",
    "nedrapându": "drapa",
    "nemaidrapând": "drapa",
    "nemaidrapându": "drapa",
    "draparea": "drapare",
    "drapareo": "drapare",
    "drapări": "drapare",
    "drapării": "drapare",
    "drapările": "drapare",
    "drapărilor": "drapare",
    "drapată": "drapat",
    "drapate": "drapat",
    "drapați": "drapat",
    "drapele": "drapel",
    "drapelele": "drapel",
    "drapelelor": "drapel",
    "drapelul": "drapel",
    "drapelule": "drapel",
    "drapelului": "drapel",
    "draperia": "draperie",
    "draperiei": "draperie",
    "draperii": "draperie",
    "draperiile": "draperie",
    "draperiilor": "draperie",
    "draperio": "draperie",
    "drastica": "drastic",
    "drastică": "drastic",
    "drastice": "drastic",
    "drasticei": "drastic",
    "drasticele": "drastic",
    "drasticelor": "drastic",
    "drastici": "drastic",
    "drasticii": "drastic",
    "drasticilor": "drastic",
    "drastico": "drastic",
    "drasticul": "drastic",
    "drasticule": "drastic",
    "drasticului": "drastic",
    "dreapta": "dreaptă",
    "drepte": "dreaptă",
    "dreptei": "dreaptă",
    "dreptele": "dreaptă",
    "dreptelor": "dreaptă",
    "dregători": "dregător",
    "dregătorii": "dregător",
    "dregătorilor": "dregător",
    "dregătorul": "dregător",
    "dregătorule": "dregător",
    "dregătorului": "dregător",
    "dregătoria": "dregătorie",
    "dregătoriei": "dregătorie",
    "dregătorii": "dregătorie",
    "dregătoriile": "dregătorie",
    "dregătoriilor": "dregătorie",
    "dreagă": "drege",
    "dreg": "drege",
    "dregând": "drege",
    "dregându": "drege",
    "dregea": "drege",
    "dregeai": "drege",
    "dregeam": "drege",
    "dregeați": "drege",
    "dregeau": "drege",
    "dregem": "drege",
    "dregeți": "drege",
    "dregi": "drege",
    "dres": "drege",
    "drese": "drege",
    "dresei": "drege",
    "dreseră": "drege",
    "dreserăm": "drege",
    "dreserăți": "drege",
    "dresese": "drege",
    "dresesem": "drege",
    "dreseseră": "drege",
    "dreseserăm": "drege",
    "dreseserăți": "drege",
    "dreseseși": "drege",
    "dreseși": "drege",
    "dresu": "drege",
    "nedregând": "drege",
    "nedregându": "drege",
    "nemaidregând": "drege",
    "nemaidregându": "drege",
    "drenul": "dren",
    "drenule": "dren",
    "drenului": "dren",
    "drenuri": "dren",
    "drenurile": "dren",
    "drenurilor": "dren",
    "drenă": "drena",
    "drenai": "drena",
    "drenam": "drena",
    "drenăm": "drena",
    "drenând": "drena",
    "drenându": "drena",
    "drenară": "drena",
    "drenarăm": "drena",
    "drenarăți": "drena",
    "drenase": "drena",
    "drenasem": "drena",
    "drenaseră": "drena",
    "drenaserăm": "drena",
    "drenaserăți": "drena",
    "drenaseși": "drena",
    "drenași": "drena",
    "drenat": "drena",
    "drenați": "drena",
    "drenatu": "drena",
    "drenau": "drena",
    "drenează": "drena",
    "drenez": "drena",
    "dreneze": "drena",
    "drenezi": "drena",
    "nedrenând": "drena",
    "nedrenându": "drena",
    "nemaidrenând": "drena",
    "nemaidrenându": "drena",
    "drena": "drenă",
    "drenei": "drenă",
    "drenele": "drenă",
    "drenelor": "drenă",
    "dreneze": "drenă",
    "dreno": "drenă",
    "drenaje": "drenaj",
    "drenajele": "drenaj",
    "drenajelor": "drenaj",
    "drenajul": "drenaj",
    "drenajule": "drenaj",
    "drenajului": "drenaj",
    "drenarea": "drenare",
    "drenareo": "drenare",
    "drenări": "drenare",
    "drenării": "drenare",
    "drenările": "drenare",
    "drenărilor": "drenare",
    "drenată": "drenat",
    "drenate": "drenat",
    "drenați": "drenat",
    "dreapta": "drept",
    "dreaptă": "drept",
    "dreapto": "drept",
    "drepte": "drept",
    "dreptei": "drept",
    "dreptele": "drept",
    "dreptelor": "drept",
    "drepți": "drept",
    "drepții": "drept",
    "drepților": "drept",
    "dreptul": "drept",
    "dreptule": "drept",
    "dreptului": "drept",
    "drepturi": "drept",
    "drepturile": "drept",
    "drepturilor": "drept",
    "dreptatea": "dreptate",
    "dreptateo": "dreptate",
    "dreptăți": "dreptate",
    "dreptății": "dreptate",
    "dreptățile": "dreptate",
    "dreptăților": "dreptate",
    "dreptunghiul": "dreptunghi",
    "dreptunghiule": "dreptunghi",
    "dreptunghiului": "dreptunghi",
    "dreptunghiuri": "dreptunghi",
    "dreptunghiurile": "dreptunghi",
    "dreptunghiurilor": "dreptunghi",
    "dreptunghica": "dreptunghic",
    "dreptunghică": "dreptunghic",
    "dreptunghice": "dreptunghic",
    "dreptunghicei": "dreptunghic",
    "dreptunghicele": "dreptunghic",
    "dreptunghicelor": "dreptunghic",
    "dreptunghici": "dreptunghic",
    "dreptunghicii": "dreptunghic",
    "dreptunghicilor": "dreptunghic",
    "dreptunghico": "dreptunghic",
    "dreptunghicul": "dreptunghic",
    "dreptunghicule": "dreptunghic",
    "dreptunghicului": "dreptunghic",
    "dreptunghiulara": "dreptunghiular",
    "dreptunghiulară": "dreptunghiular",
    "dreptunghiulare": "dreptunghiular",
    "dreptunghiularei": "dreptunghiular",
    "dreptunghiularele": "dreptunghiular",
    "dreptunghiularelor": "dreptunghiular",
    "dreptunghiulari": "dreptunghiular",
    "dreptunghiularii": "dreptunghiular",
    "dreptunghiularilor": "dreptunghiular",
    "dreptunghiularo": "dreptunghiular",
    "dreptunghiularul": "dreptunghiular",
    "dreptunghiularule": "dreptunghiular",
    "dreptunghiularului": "dreptunghiular",
    "dreasă": "dres",
    "drese": "dres",
    "dreși": "dres",
    "dreșii": "dres",
    "dreșilor": "dres",
    "dresul": "dres",
    "dresule": "dres",
    "dresului": "dres",
    "dresuri": "dres",
    "dresurile": "dres",
    "dresurilor": "dres",
    "dresă": "dresa",
    "dresai": "dresa",
    "dresam": "dresa",
    "dresăm": "dresa",
    "dresând": "dresa",
    "dresându": "dresa",
    "dresară": "dresa",
    "dresarăm": "dresa",
    "dresarăți": "dresa",
    "dresase": "dresa",
    "dresasem": "dresa",
    "dresaseră": "dresa",
    "dresaserăm": "dresa",
    "dresaserăți": "dresa",
    "dresaseși": "dresa",
    "dresași": "dresa",
    "dresat": "dresa",
    "dresați": "dresa",
    "dresatu": "dresa",
    "dresau": "dresa",
    "dresează": "dresa",
    "dresez": "dresa",
    "dreseze": "dresa",
    "dresezi": "dresa",
    "nedresând": "dresa",
    "nedresându": "dresa",
    "nemaidresând": "dresa",
    "nemaidresându": "dresa",
    "dresaje": "dresaj",
    "dresajele": "dresaj",
    "dresajelor": "dresaj",
    "dresajul": "dresaj",
    "dresajule": "dresaj",
    "dresajului": "dresaj",
    "dresarea": "dresare",
    "dresareo": "dresare",
    "dresări": "dresare",
    "dresării": "dresare",
    "dresările": "dresare",
    "dresărilor": "dresare",
    "dresata": "dresat",
    "dresată": "dresat",
    "dresate": "dresat",
    "dresatei": "dresat",
    "dresatele": "dresat",
    "dresatelor": "dresat",
    "dresați": "dresat",
    "dresații": "dresat",
    "dresaților": "dresat",
    "dresato": "dresat",
    "dresatul": "dresat",
    "dresatule": "dresat",
    "dresatului": "dresat",
    "dresoarea": "dresoare",
    "dresoarei": "dresoare",
    "dresoarele": "dresoare",
    "dresoarelor": "dresoare",
    "dresoareo": "dresoare",
    "dresori": "dresor",
    "dresorii": "dresor",
    "dresorilor": "dresor",
    "dresorul": "dresor",
    "dresorule": "dresor",
    "dresorului": "dresor",
    "drezina": "drezină",
    "drezine": "drezină",
    "drezinei": "drezină",
    "drezinele": "drezină",
    "drezinelor": "drezină",
    "drezino": "drezină",
    "driada": "driadă",
    "driade": "driadă",
    "driadei": "driadă",
    "driadele": "driadă",
    "driadelor": "driadă",
    "driado": "driadă",
    "driblă": "dribla",
    "driblai": "dribla",
    "driblam": "dribla",
    "driblăm": "dribla",
    "driblând": "dribla",
    "driblându": "dribla",
    "driblară": "dribla",
    "driblarăm": "dribla",
    "driblarăți": "dribla",
    "driblase": "dribla",
    "driblasem": "dribla",
    "driblaseră": "dribla",
    "driblaserăm": "dribla",
    "driblaserăți": "dribla",
    "driblaseși": "dribla",
    "driblași": "dribla",
    "driblat": "dribla",
    "driblați": "dribla",
    "driblatu": "dribla",
    "driblau": "dribla",
    "driblează": "dribla",
    "driblez": "dribla",
    "dribleze": "dribla",
    "driblezi": "dribla",
    "nedriblând": "dribla",
    "nedriblându": "dribla",
    "nemaidriblând": "dribla",
    "nemaidriblându": "dribla",
    "driblarea": "driblare",
    "driblareo": "driblare",
    "driblări": "driblare",
    "driblării": "driblare",
    "driblările": "driblare",
    "driblărilor": "driblare",
    "driblată": "driblat",
    "driblate": "driblat",
    "driblați": "driblat",
    "driblingul": "dribling",
    "driblingule": "dribling",
    "driblingului": "dribling",
    "driblinguri": "dribling",
    "driblingurile": "dribling",
    "driblingurilor": "dribling",
    "dricul": "dric",
    "dricule": "dric",
    "dricului": "dric",
    "dricuri": "dric",
    "dricurile": "dric",
    "dricurilor": "dric",
    "drilul": "dril",
    "drilule": "dril",
    "drilului": "dril",
    "driluri": "dril",
    "drilurile": "dril",
    "drilurilor": "dril",
    "drișca": "drișcă",
    "drișco": "drișcă",
    "driște": "drișcă",
    "driștei": "drișcă",
    "driștele": "drișcă",
    "driștelor": "drișcă",
    "drișcuia": "drișcui",
    "drișcuiai": "drișcui",
    "drișcuiam": "drișcui",
    "drișcuiască": "drișcui",
    "drișcuiați": "drișcui",
    "drișcuiau": "drișcui",
    "drișcuiesc": "drișcui",
    "drișcuiește": "drișcui",
    "drișcuiești": "drișcui",
    "drișcuii": "drișcui",
    "drișcuim": "drișcui",
    "drișcuind": "drișcui",
    "drișcuindu": "drișcui",
    "drișcuiră": "drișcui",
    "drișcuirăm": "drișcui",
    "drișcuirăți": "drișcui",
    "drișcuise": "drișcui",
    "drișcuisem": "drișcui",
    "drișcuiseră": "drișcui",
    "drișcuiserăm": "drișcui",
    "drișcuiserăți": "drișcui",
    "drișcuiseși": "drișcui",
    "drișcuiși": "drișcui",
    "drișcuit": "drișcui",
    "drișcuiți": "drișcui",
    "drișcuitu": "drișcui",
    "nedrișcuind": "drișcui",
    "nedrișcuindu": "drișcui",
    "nemaidrișcuind": "drișcui",
    "nemaidrișcuindu": "drișcui",
    "drișcuirea": "drișcuire",
    "drișcuireo": "drișcuire",
    "drișcuiri": "drișcuire",
    "drișcuirii": "drișcuire",
    "drișcuirile": "drișcuire",
    "drișcuirilor": "drișcuire",
    "drișcuită": "drișcuit",
    "drișcuite": "drișcuit",
    "drișcuiți": "drișcuit",
    "drișcuitul": "drișcuit",
    "drișcuitule": "drișcuit",
    "drișcuitului": "drișcuit",
    "droaia": "droaie",
    "droaio": "droaie",
    "drobi": "drob",
    "drobii": "drob",
    "drobilor": "drob",
    "drobul": "drob",
    "drobule": "drob",
    "drobului": "drob",
    "droburi": "drob",
    "droburile": "drob",
    "droburilor": "drob",
    "drogul": "drog",
    "drogule": "drog",
    "drogului": "drog",
    "droguri": "drog",
    "drogurile": "drog",
    "drogurilor": "drog",
    "drogă": "droga",
    "drogai": "droga",
    "drogam": "droga",
    "drogăm": "droga",
    "drogând": "droga",
    "drogându": "droga",
    "drogară": "droga",
    "drogarăm": "droga",
    "drogarăți": "droga",
    "drogase": "droga",
    "drogasem": "droga",
    "drogaseră": "droga",
    "drogaserăm": "droga",
    "drogaserăți": "droga",
    "drogaseși": "droga",
    "drogași": "droga",
    "drogat": "droga",
    "drogați": "droga",
    "drogatu": "droga",
    "drogau": "droga",
    "droghează": "droga",
    "droghez": "droga",
    "drogheze": "droga",
    "droghezi": "droga",
    "drogata": "drogat",
    "drogată": "drogat",
    "drogate": "drogat",
    "drogatei": "drogat",
    "drogatele": "drogat",
    "drogatelor": "drogat",
    "drogați": "drogat",
    "drogații": "drogat",
    "drogaților": "drogat",
    "drogato": "drogat",
    "drogatul": "drogat",
    "drogatule": "drogat",
    "drogatului": "drogat",
    "drogheria": "drogherie",
    "drogheriei": "drogherie",
    "drogherii": "drogherie",
    "drogheriile": "drogherie",
    "drogheriilor": "drogherie",
    "drogherio": "drogherie",
    "drojdia": "drojdie",
    "drojdiei": "drojdie",
    "drojdii": "drojdie",
    "drojdiile": "drojdie",
    "drojdiilor": "drojdie",
    "drojdio": "drojdie",
    "dromaderi": "dromader",
    "dromaderii": "dromader",
    "dromaderilor": "dromader",
    "dromaderul": "dromader",
    "dromaderule": "dromader",
    "dromaderului": "dromader",
    "dropia": "dropie",
    "dropiei": "dropie",
    "dropii": "dropie",
    "dropiile": "dropie",
    "dropiilor": "dropie",
    "dropio": "dropie",
    "drugi": "drug",
    "drugii": "drug",
    "drugilor": "drug",
    "drugul": "drug",
    "drugule": "drug",
    "drugului": "drug",
    "druguri": "drug",
    "drugurile": "drug",
    "drugurilor": "drug",
    "druga": "drugă",
    "drugi": "drugă",
    "drugii": "drugă",
    "drugile": "drugă",
    "drugilor": "drugă",
    "drugo": "drugă",
    "druidul": "druid",
    "druidule": "druid",
    "druidului": "druid",
    "druizi": "druid",
    "druizii": "druid",
    "druizilor": "druid",
    "drujba": "drujbă",
    "drujbe": "drujbă",
    "drujbei": "drujbă",
    "drujbele": "drujbă",
    "drujbelor": "drujbă",
    "drujbo": "drujbă",
    "drumu'": "drum",
    "drumul": "drum",
    "drumule": "drum",
    "drumului": "drum",
    "drumuri": "drum",
    "drumurile": "drum",
    "drumurilor": "drum",
    "drumul-de-fier": "drum-de-fier",
    "drumeagul": "drumeag",
    "drumeagule": "drumeag",
    "drumeagului": "drumeag",
    "drumeaguri": "drumeag",
    "drumeagurile": "drumeag",
    "drumeagurilor": "drumeag",
    "drumeți": "drumeț",
    "drumeții": "drumeț",
    "drumeților": "drumeț",
    "drumețul": "drumeț",
    "drumețule": "drumeț",
    "drumețului": "drumeț",
    "drumuia": "drumui",
    "drumuiai": "drumui",
    "drumuiam": "drumui",
    "drumuiască": "drumui",
    "drumuiați": "drumui",
    "drumuiau": "drumui",
    "drumuiesc": "drumui",
    "drumuiește": "drumui",
    "drumuiești": "drumui",
    "drumuii": "drumui",
    "drumuim": "drumui",
    "drumuind": "drumui",
    "drumuindu": "drumui",
    "drumuiră": "drumui",
    "drumuirăm": "drumui",
    "drumuirăți": "drumui",
    "drumuise": "drumui",
    "drumuisem": "drumui",
    "drumuiseră": "drumui",
    "drumuiserăm": "drumui",
    "drumuiserăți": "drumui",
    "drumuiseși": "drumui",
    "drumuiși": "drumui",
    "drumuit": "drumui",
    "drumuiți": "drumui",
    "drumuitu": "drumui",
    "nedrumuind": "drumui",
    "nedrumuindu": "drumui",
    "nemaidrumuind": "drumui",
    "nemaidrumuindu": "drumui",
    "drumuită": "drumuit",
    "drumuite": "drumuit",
    "drumuiți": "drumuit",
    "drupa": "drupă",
    "drupe": "drupă",
    "drupei": "drupă",
    "drupele": "drupă",
    "drupelor": "drupă",
    "drupo": "drupă",
    "duale": "dual",
    "dualele": "dual",
    "dualelor": "dual",
    "dualul": "dual",
    "dualule": "dual",
    "dualului": "dual",
    "duba": "dubă",
    "dube": "dubă",
    "dubei": "dubă",
    "dubele": "dubă",
    "dubelor": "dubă",
    "dubo": "dubă",
    "dubioasa": "dubios",
    "dubioasă": "dubios",
    "dubioase": "dubios",
    "dubioasei": "dubios",
    "dubioasele": "dubios",
    "dubioaselor": "dubios",
    "dubioaso": "dubios",
    "dubioși": "dubios",
    "dubioșii": "dubios",
    "dubioșilor": "dubios",
    "dubiosul": "dubios",
    "dubiosule": "dubios",
    "dubiosului": "dubios",
    "dubitativa": "dubitativ",
    "dubitativă": "dubitativ",
    "dubitative": "dubitativ",
    "dubitativei": "dubitativ",
    "dubitativele": "dubitativ",
    "dubitativelor": "dubitativ",
    "dubitativi": "dubitativ",
    "dubitativii": "dubitativ",
    "dubitativilor": "dubitativ",
    "dubitativo": "dubitativ",
    "dubitativul": "dubitativ",
    "dubitativule": "dubitativ",
    "dubitativului": "dubitativ",
    "dubii": "dubiu",
    "dubiile": "dubiu",
    "dubiilor": "dubiu",
    "dubiul": "dubiu",
    "dubiule": "dubiu",
    "dubiului": "dubiu",
    "dublă": "dubla",
    "dublai": "dubla",
    "dublam": "dubla",
    "dublăm": "dubla",
    "dublând": "dubla",
    "dublându": "dubla",
    "dublară": "dubla",
    "dublarăm": "dubla",
    "dublarăți": "dubla",
    "dublase": "dubla",
    "dublasem": "dubla",
    "dublaseră": "dubla",
    "dublaserăm": "dubla",
    "dublaserăți": "dubla",
    "dublaseși": "dubla",
    "dublași": "dubla",
    "dublat": "dubla",
    "dublați": "dubla",
    "dublatu": "dubla",
    "dublau": "dubla",
    "dublează": "dubla",
    "dublez": "dubla",
    "dubleze": "dubla",
    "dublezi": "dubla",
    "nedublând": "dubla",
    "nedublându": "dubla",
    "nemaidublând": "dubla",
    "nemaidublându": "dubla",
    "dubla": "dublă",
    "duble": "dublă",
    "dublei": "dublă",
    "dublele": "dublă",
    "dublelor": "dublă",
    "dublo": "dublă",
    "dublaje": "dublaj",
    "dublajele": "dublaj",
    "dublajelor": "dublaj",
    "dublajul": "dublaj",
    "dublajule": "dublaj",
    "dublajului": "dublaj",
    "dublarea": "dublare",
    "dublareo": "dublare",
    "dublări": "dublare",
    "dublării": "dublare",
    "dublările": "dublare",
    "dublărilor": "dublare",
    "dublată": "dublat",
    "dublate": "dublat",
    "dublați": "dublat",
    "dublete": "dublet",
    "dubletele": "dublet",
    "dubletelor": "dublet",
    "dubletul": "dublet",
    "dubletule": "dublet",
    "dubletului": "dublet",
    "dubla": "dublu",
    "dublă": "dublu",
    "duble": "dublu",
    "dublei": "dublu",
    "dublele": "dublu",
    "dublelor": "dublu",
    "dubli": "dublu",
    "dublii": "dublu",
    "dublilor": "dublu",
    "dublo": "dublu",
    "dublul": "dublu",
    "dublule": "dublu",
    "dublului": "dublu",
    "dubli-decalitri": "dublu-decalitru",
    "dubli-decimetri": "dublu-decimetru",
    "dublugânditul": "dublugândit",
    "dublugânditului": "dublugândit",
    "dubluplusnebune": "dubluplusnebun",
    "dublura": "dublură",
    "dubluri": "dublură",
    "dublurii": "dublură",
    "dublurile": "dublură",
    "dublurilor": "dublură",
    "dubluro": "dublură",
    "dubli-steri": "dublu-ster",
    "du": "duce",
    "duc": "duce",
    "ducă": "duce",
    "ducând": "duce",
    "ducându": "duce",
    "ducea": "duce",
    "duceai": "duce",
    "duceam": "duce",
    "duceați": "duce",
    "duceau": "duce",
    "ducele": "duce",
    "ducelui": "duce",
    "ducem": "duce",
    "duceți": "duce",
    "duci": "duce",
    "ducii": "duce",
    "ducilor": "duce",
    "dus": "duce",
    "duse": "duce",
    "dusei": "duce",
    "duseră": "duce",
    "duserăm": "duce",
    "duserăți": "duce",
    "dusese": "duce",
    "dusesem": "duce",
    "duseseră": "duce",
    "duseserăm": "duce",
    "duseserăți": "duce",
    "duseseși": "duce",
    "duseși": "duce",
    "dusu": "duce",
    "neducând": "duce",
    "neducându": "duce",
    "nemaiducând": "duce",
    "nemaiducându": "duce",
    "ducerea": "ducere",
    "ducereo": "ducere",
    "duceri": "ducere",
    "ducerii": "ducere",
    "ducerile": "ducere",
    "ducerilor": "ducere",
    "ducesa": "ducesă",
    "ducese": "ducesă",
    "ducesei": "ducesă",
    "ducesele": "ducesă",
    "duceselor": "ducesă",
    "duceso": "ducesă",
    "ducipali": "ducipal",
    "ducipalii": "ducipal",
    "ducipalilor": "ducipal",
    "ducipalul": "ducipal",
    "ducipalule": "ducipal",
    "ducipalului": "ducipal",
    "ductila": "ductil",
    "ductilă": "ductil",
    "ductile": "ductil",
    "ductilei": "ductil",
    "ductilele": "ductil",
    "ductilelor": "ductil",
    "ductili": "ductil",
    "ductilii": "ductil",
    "ductililor": "ductil",
    "ductilo": "ductil",
    "ductilul": "ductil",
    "ductilule": "ductil",
    "ductilului": "ductil",
    "dudul": "dud",
    "dudule": "dud",
    "dudului": "dud",
    "duzi": "dud",
    "duzii": "dud",
    "duzilor": "dud",
    "duda": "dudă",
    "dude": "dudă",
    "dudei": "dudă",
    "dudele": "dudă",
    "dudelor": "dudă",
    "dudo": "dudă",
    "duduca": "duducă",
    "duduci": "duducă",
    "duducii": "duducă",
    "duducile": "duducă",
    "duducilor": "duducă",
    "duduco": "duducă",
    "duduia": "dudui",
    "duduiai": "dudui",
    "duduiam": "dudui",
    "duduiați": "dudui",
    "duduiau": "dudui",
    "duduie": "dudui",
    "duduii": "dudui",
    "duduim": "dudui",
    "duduind": "dudui",
    "duduindu": "dudui",
    "duduiră": "dudui",
    "duduirăm": "dudui",
    "duduirăți": "dudui",
    "duduise": "dudui",
    "duduisem": "dudui",
    "duduiseră": "dudui",
    "duduiserăm": "dudui",
    "duduiserăți": "dudui",
    "duduiseși": "dudui",
    "duduiși": "dudui",
    "duduit": "dudui",
    "duduiți": "dudui",
    "duduitu": "dudui",
    "neduduind": "dudui",
    "neduduindu": "dudui",
    "nemaiduduind": "dudui",
    "nemaiduduindu": "dudui",
    "dudui": "duduie",
    "duduia": "duduie",
    "duduii": "duduie",
    "duduile": "duduie",
    "duduilor": "duduie",
    "duduio": "duduie",
    "duduită": "duduit",
    "duduite": "duduit",
    "duduiți": "duduit",
    "duduitul": "duduit",
    "duduitule": "duduit",
    "duduitului": "duduit",
    "duduitura": "duduitură",
    "duduituri": "duduitură",
    "duduiturii": "duduitură",
    "duduiturile": "duduitură",
    "duduiturilor": "duduitură",
    "duduituro": "duduitură",
    "duelul": "duel",
    "duelule": "duel",
    "duelului": "duel",
    "dueluri": "duel",
    "duelurile": "duel",
    "duelurilor": "duel",
    "duelă": "duela",
    "duelai": "duela",
    "duelam": "duela",
    "duelăm": "duela",
    "duelând": "duela",
    "duelându": "duela",
    "duelară": "duela",
    "duelarăm": "duela",
    "duelarăți": "duela",
    "duelase": "duela",
    "duelasem": "duela",
    "duelaseră": "duela",
    "duelaserăm": "duela",
    "duelaserăți": "duela",
    "duelaseși": "duela",
    "duelași": "duela",
    "duelat": "duela",
    "duelați": "duela",
    "duelatu": "duela",
    "duelau": "duela",
    "duelează": "duela",
    "duelez": "duela",
    "dueleze": "duela",
    "duelezi": "duela",
    "neduelând": "duela",
    "neduelându": "duela",
    "nemaiduelând": "duela",
    "nemaiduelându": "duela",
    "duelată": "duelat",
    "duelate": "duelat",
    "duelați": "duelat",
    "duete": "duet",
    "duetele": "duet",
    "duetelor": "duet",
    "duetul": "duet",
    "duetule": "duet",
    "duetului": "duet",
    "dugheana": "dugheană",
    "dugheano": "dugheană",
    "dughene": "dugheană",
    "dughenei": "dugheană",
    "dughenele": "dugheană",
    "dughenelor": "dugheană",
    "duhul": "duh",
    "duhule": "duh",
    "duhului": "duh",
    "duhuri": "duh",
    "duhurile": "duh",
    "duhurilor": "duh",
    "duhănea": "duhăni",
    "duhăneai": "duhăni",
    "duhăneam": "duhăni",
    "duhănească": "duhăni",
    "duhăneați": "duhăni",
    "duhăneau": "duhăni",
    "duhănesc": "duhăni",
    "duhănește": "duhăni",
    "duhănești": "duhăni",
    "duhănim": "duhăni",
    "duhănind": "duhăni",
    "duhănindu": "duhăni",
    "duhăniră": "duhăni",
    "duhănirăm": "duhăni",
    "duhănirăți": "duhăni",
    "duhănise": "duhăni",
    "duhănisem": "duhăni",
    "duhăniseră": "duhăni",
    "duhăniserăm": "duhăni",
    "duhăniserăți": "duhăni",
    "duhăniseși": "duhăni",
    "duhăniși": "duhăni",
    "duhănit": "duhăni",
    "duhăniți": "duhăni",
    "duhănitu": "duhăni",
    "duhănitoare": "duhănitor",
    "duhănitoarea": "duhănitor",
    "duhănitoarei": "duhănitor",
    "duhănitoarele": "duhănitor",
    "duhănitoarelor": "duhănitor",
    "duhănitoareo": "duhănitor",
    "duhănitori": "duhănitor",
    "duhănitorii": "duhănitor",
    "duhănitorilor": "duhănitor",
    "duhănitorul": "duhănitor",
    "duhănitorule": "duhănitor",
    "duhănitorului": "duhănitor",
    "duhnea": "duhni",
    "duhneai": "duhni",
    "duhneam": "duhni",
    "duhnească": "duhni",
    "duhneați": "duhni",
    "duhneau": "duhni",
    "duhnesc": "duhni",
    "duhnește": "duhni",
    "duhnești": "duhni",
    "duhnii": "duhni",
    "duhnim": "duhni",
    "duhnind": "duhni",
    "duhnindu": "duhni",
    "duhniră": "duhni",
    "duhnirăm": "duhni",
    "duhnirăți": "duhni",
    "duhnise": "duhni",
    "duhnisem": "duhni",
    "duhniseră": "duhni",
    "duhniserăm": "duhni",
    "duhniserăți": "duhni",
    "duhniseși": "duhni",
    "duhniși": "duhni",
    "duhnit": "duhni",
    "duhniți": "duhni",
    "duhnitu": "duhni",
    "neduhnind": "duhni",
    "neduhnindu": "duhni",
    "nemaiduhnind": "duhni",
    "nemaiduhnindu": "duhni",
    "duhnită": "duhnit",
    "duhnite": "duhnit",
    "duhniți": "duhnit",
    "duhnitoare": "duhnitor",
    "duhnitoarea": "duhnitor",
    "duhnitoarei": "duhnitor",
    "duhnitoarele": "duhnitor",
    "duhnitoarelor": "duhnitor",
    "duhnitoareo": "duhnitor",
    "duhnitori": "duhnitor",
    "duhnitorii": "duhnitor",
    "duhnitorilor": "duhnitor",
    "duhnitorul": "duhnitor",
    "duhnitorule": "duhnitor",
    "duhnitorului": "duhnitor",
    "duhoarea": "duhoare",
    "duhoareo": "duhoare",
    "duhori": "duhoare",
    "duhorii": "duhoare",
    "duhorile": "duhoare",
    "duhorilor": "duhoare",
    "duhorea": "duhori",
    "duhoreai": "duhori",
    "duhoream": "duhori",
    "duhorească": "duhori",
    "duhoreați": "duhori",
    "duhoreau": "duhori",
    "duhoresc": "duhori",
    "duhorește": "duhori",
    "duhorești": "duhori",
    "duhorii": "duhori",
    "duhorim": "duhori",
    "duhorind": "duhori",
    "duhorindu": "duhori",
    "duhoriră": "duhori",
    "duhorirăm": "duhori",
    "duhorirăți": "duhori",
    "duhorise": "duhori",
    "duhorisem": "duhori",
    "duhoriseră": "duhori",
    "duhoriserăm": "duhori",
    "duhoriserăți": "duhori",
    "duhoriseși": "duhori",
    "duhoriși": "duhori",
    "duhorit": "duhori",
    "duhoriți": "duhori",
    "duhoritu": "duhori",
    "neduhorind": "duhori",
    "neduhorindu": "duhori",
    "nemaiduhorind": "duhori",
    "nemaiduhorindu": "duhori",
    "duhorită": "duhorit",
    "duhorite": "duhorit",
    "duhoriți": "duhorit",
    "duhovnici": "duhovnic",
    "duhovnicii": "duhovnic",
    "duhovnicilor": "duhovnic",
    "duhovnicul": "duhovnic",
    "duhovnicule": "duhovnic",
    "duhovnicului": "duhovnic",
    "duhovnicea": "duhovnici",
    "duhovniceai": "duhovnici",
    "duhovniceam": "duhovnici",
    "duhovnicească": "duhovnici",
    "duhovniceați": "duhovnici",
    "duhovniceau": "duhovnici",
    "duhovnicesc": "duhovnici",
    "duhovnicește": "duhovnici",
    "duhovnicești": "duhovnici",
    "duhovnicii": "duhovnici",
    "duhovnicim": "duhovnici",
    "duhovnicind": "duhovnici",
    "duhovnicindu": "duhovnici",
    "duhovniciră": "duhovnici",
    "duhovnicirăm": "duhovnici",
    "duhovnicirăți": "duhovnici",
    "duhovnicise": "duhovnici",
    "duhovnicisem": "duhovnici",
    "duhovniciseră": "duhovnici",
    "duhovniciserăm": "duhovnici",
    "duhovniciserăți": "duhovnici",
    "duhovniciseși": "duhovnici",
    "duhovniciși": "duhovnici",
    "duhovnicit": "duhovnici",
    "duhovniciți": "duhovnici",
    "duhovnicitu": "duhovnici",
    "neduhovnicind": "duhovnici",
    "neduhovnicindu": "duhovnici",
    "nemaiduhovnicind": "duhovnici",
    "nemaiduhovnicindu": "duhovnici",
    "duhovnicia": "duhovnicie",
    "duhovniciei": "duhovnicie",
    "duhovnicii": "duhovnicie",
    "duhovniciile": "duhovnicie",
    "duhovniciilor": "duhovnicie",
    "duhovnicio": "duhovnicie",
    "duhovnicită": "duhovnicit",
    "duhovnicite": "duhovnicit",
    "duhovniciți": "duhovnicit",
    "duioasa": "duios",
    "duioasă": "duios",
    "duioase": "duios",
    "duioasei": "duios",
    "duioasele": "duios",
    "duioaselor": "duios",
    "duioaso": "duios",
    "duioși": "duios",
    "duioșii": "duios",
    "duioșilor": "duios",
    "duiosul": "duios",
    "duiosule": "duios",
    "duiosului": "duios",
    "duioșia": "duioșie",
    "duioșiei": "duioșie",
    "duioșii": "duioșie",
    "duioșiile": "duioșie",
    "duioșiilor": "duioșie",
    "duioșio": "duioșie",
    "duiumul": "duium",
    "duiumule": "duium",
    "duiumului": "duium",
    "duiumuri": "duium",
    "duiumurile": "duium",
    "duiumurilor": "duium",
    "dulama": "dulamă",
    "dulame": "dulamă",
    "dulamei": "dulamă",
    "dulamele": "dulamă",
    "dulamelor": "dulamă",
    "dulamo": "dulamă",
    "dulapi": "dulap",
    "dulapii": "dulap",
    "dulapilor": "dulap",
    "dulapul": "dulap",
    "dulapule": "dulap",
    "dulapului": "dulap",
    "dulapuri": "dulap",
    "dulapurile": "dulap",
    "dulapurilor": "dulap",
    "dulapule-rastel": "dulap-rastel",
    "dulapul-rastel": "dulap-rastel",
    "dulapului-rastel": "dulap-rastel",
    "dulapurile-rastel": "dulap-rastel",
    "dulapurilor-rastel": "dulap-rastel",
    "dulapuri-rastel": "dulap-rastel",
    "dulăi": "dulău",
    "dulăii": "dulău",
    "dulăilor": "dulău",
    "dulăul": "dulău",
    "dulăule": "dulău",
    "dulăului": "dulău",
    "dulcea": "dulce",
    "dulcele": "dulce",
    "dulcelui": "dulce",
    "dulceo": "dulce",
    "dulci": "dulce",
    "dulcii": "dulce",
    "dulcile": "dulce",
    "dulcilor": "dulce",
    "dulciuri": "dulce",
    "dulciurile": "dulce",
    "dulciurilor": "dulce",
    "dulce-acrișoara": "dulce-acrișor",
    "dulce-acrișoară": "dulce-acrișor",
    "dulce-acrișoare": "dulce-acrișor",
    "dulce-acrișoarei": "dulce-acrișor",
    "dulce-acrișoarele": "dulce-acrișor",
    "dulce-acrișoarelor": "dulce-acrișor",
    "dulce-acrișori": "dulce-acrișor",
    "dulce-acrișorii": "dulce-acrișor",
    "dulce-acrișorilor": "dulce-acrișor",
    "dulce-acrișorul": "dulce-acrișor",
    "dulce-acrișorului": "dulce-acrișor",
    "dulceaga": "dulceag",
    "dulceagă": "dulceag",
    "dulceago": "dulceag",
    "dulceagul": "dulceag",
    "dulceagule": "dulceag",
    "dulceagului": "dulceag",
    "dulcege": "dulceag",
    "dulcegei": "dulceag",
    "dulcegele": "dulceag",
    "dulcegelor": "dulceag",
    "dulcegi": "dulceag",
    "dulcegii": "dulceag",
    "dulcegilor": "dulceag",
    "dulceața": "dulceață",
    "dulceațo": "dulceață",
    "dulceți": "dulceață",
    "dulceții": "dulceață",
    "dulcețuri": "dulceață",
    "dulcețurile": "dulceață",
    "dulcețurilor": "dulceață",
    "dulgheri": "dulgher",
    "dulgherii": "dulgher",
    "dulgherilor": "dulgher",
    "dulgherul": "dulgher",
    "dulgherule": "dulgher",
    "dulgherului": "dulgher",
    "dulgheria": "dulgherie",
    "dulgheriei": "dulgherie",
    "dulgherii": "dulgherie",
    "dulgheriile": "dulgherie",
    "dulgheriilor": "dulgherie",
    "dulgherită": "dulgherit",
    "dulgherite": "dulgherit",
    "dulgheritul": "dulgherit",
    "dulgheritule": "dulgherit",
    "dulgheritului": "dulgherit",
    "dulia": "dulie",
    "duliei": "dulie",
    "dulii": "dulie",
    "duliile": "dulie",
    "duliilor": "dulie",
    "dulio": "dulie",
    "duma": "dumă",
    "dume": "dumă",
    "dumei": "dumă",
    "dumele": "dumă",
    "dumelor": "dumă",
    "dumo": "dumă",
    "dumbrava": "dumbravă",
    "dumbrăvi": "dumbravă",
    "dumbrăvii": "dumbravă",
    "dumbrăvile": "dumbravă",
    "dumbrăvilor": "dumbravă",
    "dumbravo": "dumbravă",
    "dumerea": "dumeri",
    "dumereai": "dumeri",
    "dumeream": "dumeri",
    "dumerească": "dumeri",
    "dumereați": "dumeri",
    "dumereau": "dumeri",
    "dumeresc": "dumeri",
    "dumerește": "dumeri",
    "dumerești": "dumeri",
    "dumerii": "dumeri",
    "dumerim": "dumeri",
    "dumerind": "dumeri",
    "dumerindu": "dumeri",
    "dumeriră": "dumeri",
    "dumerirăm": "dumeri",
    "dumerirăți": "dumeri",
    "dumerise": "dumeri",
    "dumerisem": "dumeri",
    "dumeriseră": "dumeri",
    "dumeriserăm": "dumeri",
    "dumeriserăți": "dumeri",
    "dumeriseși": "dumeri",
    "dumeriși": "dumeri",
    "dumerit": "dumeri",
    "dumeriți": "dumeri",
    "dumeritu": "dumeri",
    "nedumerind": "dumeri",
    "nedumerindu": "dumeri",
    "nemaidumerind": "dumeri",
    "nemaidumerindu": "dumeri",
    "dumerirea": "dumerire",
    "dumerireo": "dumerire",
    "dumeriri": "dumerire",
    "dumeririi": "dumerire",
    "dumeririle": "dumerire",
    "dumeririlor": "dumerire",
    "dumerită": "dumerit",
    "dumerite": "dumerit",
    "dumeriți": "dumerit",
    "dumic": "dumica",
    "dumică": "dumica",
    "dumicai": "dumica",
    "dumicam": "dumica",
    "dumicăm": "dumica",
    "dumicând": "dumica",
    "dumicându": "dumica",
    "dumicară": "dumica",
    "dumicarăm": "dumica",
    "dumicarăți": "dumica",
    "dumicase": "dumica",
    "dumicasem": "dumica",
    "dumicaseră": "dumica",
    "dumicaserăm": "dumica",
    "dumicaserăți": "dumica",
    "dumicaseși": "dumica",
    "dumicași": "dumica",
    "dumicat": "dumica",
    "dumicați": "dumica",
    "dumicatu": "dumica",
    "dumicau": "dumica",
    "dumice": "dumica",
    "dumici": "dumica",
    "nedumicând": "dumica",
    "nedumicându": "dumica",
    "nemaidumicând": "dumica",
    "nemaidumicându": "dumica",
    "dumicată": "dumicat",
    "dumicate": "dumicat",
    "dumicați": "dumicat",
    "dumicații": "dumicat",
    "dumicaților": "dumicat",
    "dumicatul": "dumicat",
    "dumicatule": "dumicat",
    "dumicatului": "dumicat",
    "dumineca": "duminecă",
    "dumineci": "duminecă",
    "duminecii": "duminecă",
    "duminecile": "duminecă",
    "duminecilor": "duminecă",
    "dumineco": "duminecă",
    "duminica": "duminică",
    "duminici": "duminică",
    "duminicii": "duminică",
    "duminicile": "duminică",
    "duminicilor": "duminică",
    "duminico": "duminică",
    "dumirea": "dumiri",
    "dumireai": "dumiri",
    "dumiream": "dumiri",
    "dumirească": "dumiri",
    "dumireați": "dumiri",
    "dumireau": "dumiri",
    "dumiresc": "dumiri",
    "dumirește": "dumiri",
    "dumirești": "dumiri",
    "dumirii": "dumiri",
    "dumirim": "dumiri",
    "dumirind": "dumiri",
    "dumirindu": "dumiri",
    "dumiriră": "dumiri",
    "dumirirăm": "dumiri",
    "dumirirăți": "dumiri",
    "dumirise": "dumiri",
    "dumirisem": "dumiri",
    "dumiriseră": "dumiri",
    "dumiriserăm": "dumiri",
    "dumiriserăți": "dumiri",
    "dumiriseși": "dumiri",
    "dumiriși": "dumiri",
    "dumirit": "dumiri",
    "dumiriți": "dumiri",
    "dumiritu": "dumiri",
    "nedumirind": "dumiri",
    "nedumirindu": "dumiri",
    "nemaidumirind": "dumiri",
    "nemaidumirindu": "dumiri",
    "dumirirea": "dumirire",
    "dumirireo": "dumirire",
    "dumiriri": "dumirire",
    "dumiririi": "dumirire",
    "dumiririle": "dumirire",
    "dumiririlor": "dumirire",
    "dumirită": "dumirit",
    "dumirite": "dumirit",
    "dumiriți": "dumirit",
    "d-sale": "dumisale",
    "d-tale": "dumitale",
    "D.": "Dumitru",
    "d-ei": "dumneaei",
    "d-lor": "dumnealor",
    "d-lui": "dumnealui",
    "dumneaei": "dumnealui",
    "dumnealor": "dumnealui",
    "d-sa": "dumneasa",
    "dumisale": "dumneasa",
    "d-ta": "dumneata",
    "dumitale": "dumneata",
    "dv.": "dumneavoastră",
    "d-voastră": "dumneavoastră",
    "dvs.": "dumneavoastră",
    "dumnezeiasca": "dumnezeiesc",
    "dumnezeiască": "dumnezeiesc",
    "dumnezeiasco": "dumnezeiesc",
    "dumnezeiescul": "dumnezeiesc",
    "dumnezeiescule": "dumnezeiesc",
    "dumnezeiescului": "dumnezeiesc",
    "dumnezeiești": "dumnezeiesc",
    "dumnezeieștii": "dumnezeiesc",
    "dumnezeieștile": "dumnezeiesc",
    "dumnezeieștilor": "dumnezeiesc",
    "dumnezeirea": "dumnezeire",
    "dumnezeireo": "dumnezeire",
    "dumnezeiri": "dumnezeire",
    "dumnezeirii": "dumnezeire",
    "dumnezeirile": "dumnezeire",
    "dumnezeirilor": "dumnezeire",
    "dumnezei": "dumnezeu",
    "dumnezeii": "dumnezeu",
    "dumnezeilor": "dumnezeu",
    "dumnezeul": "dumnezeu",
    "dumnezeule": "dumnezeu",
    "dumnezeului": "dumnezeu",
    "dumpingul": "dumping",
    "dumpingule": "dumping",
    "dumpingului": "dumping",
    "dumpinguri": "dumping",
    "dumpingurile": "dumping",
    "dumpingurilor": "dumping",
    "duna": "dună",
    "dune": "dună",
    "dunei": "dună",
    "dunele": "dună",
    "dunelor": "dună",
    "duno": "dună",
    "Dunărea": "Dunăre",
    "Dunării": "Dunăre",
    "dunăreana": "dunărean",
    "dunăreană": "dunărean",
    "dunăreano": "dunărean",
    "dunăreanul": "dunărean",
    "dunăreanule": "dunărean",
    "dunăreanului": "dunărean",
    "dunărene": "dunărean",
    "dunărenei": "dunărean",
    "dunărenele": "dunărean",
    "dunărenelor": "dunărean",
    "dunăreni": "dunărean",
    "dunărenii": "dunărean",
    "dunărenilor": "dunărean",
    "duneta": "dunetă",
    "dunete": "dunetă",
    "dunetei": "dunetă",
    "dunetele": "dunetă",
    "dunetelor": "dunetă",
    "duneto": "dunetă",
    "dunga": "dungă",
    "dungi": "dungă",
    "dungii": "dungă",
    "dungile": "dungă",
    "dungilor": "dungă",
    "dungo": "dungă",
    "duoul": "duo",
    "duoule": "duo",
    "duoului": "duo",
    "duouri": "duo",
    "duourile": "duo",
    "duourilor": "duo",
    "duodenul": "duoden",
    "duodenule": "duoden",
    "duodenului": "duoden",
    "duodenuri": "duoden",
    "duodenurile": "duoden",
    "duodenurilor": "duoden",
    "dup-": "după",
    "d.a.": "după-amiază",
    "după-amiaza": "după-amiază",
    "după-amiazo": "după-amiază",
    "după-amieze": "după-amiază",
    "după-amiezei": "după-amiază",
    "după-amiezele": "după-amiază",
    "după-amiezelor": "după-amiază",
    "după-amiezii": "după-amiază",
    "după-masa": "după-masă",
    "după-mese": "după-masă",
    "după-mesei": "după-masă",
    "după-mesele": "după-masă",
    "după-meselor": "după-masă",
    "duplexul": "duplex",
    "duplexule": "duplex",
    "duplexului": "duplex",
    "duplexuri": "duplex",
    "duplexurile": "duplex",
    "duplexurilor": "duplex",
    "duplic": "duplica",
    "duplică": "duplica",
    "duplicai": "duplica",
    "duplicam": "duplica",
    "duplicăm": "duplica",
    "duplicând": "duplica",
    "duplicându": "duplica",
    "duplicară": "duplica",
    "duplicarăm": "duplica",
    "duplicarăți": "duplica",
    "duplicase": "duplica",
    "duplicasem": "duplica",
    "duplicaseră": "duplica",
    "duplicaserăm": "duplica",
    "duplicaserăți": "duplica",
    "duplicaseși": "duplica",
    "duplicași": "duplica",
    "duplicat": "duplica",
    "duplicați": "duplica",
    "duplicatu": "duplica",
    "duplicau": "duplica",
    "duplice": "duplica",
    "duplici": "duplica",
    "neduplicând": "duplica",
    "neduplicându": "duplica",
    "nemaiduplicând": "duplica",
    "nemaiduplicându": "duplica",
    "duplicată": "duplicat",
    "duplicate": "duplicat",
    "duplicatele": "duplicat",
    "duplicatelor": "duplicat",
    "duplicați": "duplicat",
    "duplicatul": "duplicat",
    "duplicatule": "duplicat",
    "duplicatului": "duplicat",
    "duplicitatea": "duplicitate",
    "duplicitateo": "duplicitate",
    "duplicități": "duplicitate",
    "duplicității": "duplicitate",
    "duplicitățile": "duplicitate",
    "duplicităților": "duplicitate",
    "dura": "dur",
    "dură": "dur",
    "dure": "dur",
    "durei": "dur",
    "durele": "dur",
    "durelor": "dur",
    "duri": "dur",
    "durii": "dur",
    "durilor": "dur",
    "duro": "dur",
    "durul": "dur",
    "durule": "dur",
    "durului": "dur",
    "dură": "dura",
    "durai": "dura",
    "duram": "dura",
    "durăm": "dura",
    "durând": "dura",
    "durându": "dura",
    "durară": "dura",
    "durarăm": "dura",
    "durarăți": "dura",
    "durase": "dura",
    "durasem": "dura",
    "duraseră": "dura",
    "duraserăm": "dura",
    "duraserăți": "dura",
    "duraseși": "dura",
    "durași": "dura",
    "durat": "dura",
    "durați": "dura",
    "duratu": "dura",
    "durau": "dura",
    "durează": "dura",
    "durez": "dura",
    "dureze": "dura",
    "durezi": "dura",
    "nedurând": "dura",
    "nedurându": "dura",
    "nemaidurând": "dura",
    "nemaidurându": "dura",
    "durabila": "durabil",
    "durabilă": "durabil",
    "durabile": "durabil",
    "durabilei": "durabil",
    "durabilele": "durabil",
    "durabilelor": "durabil",
    "durabili": "durabil",
    "durabilii": "durabil",
    "durabililor": "durabil",
    "durabilo": "durabil",
    "durabilul": "durabil",
    "durabilule": "durabil",
    "durabilului": "durabil",
    "durabilitatea": "durabilitate",
    "durabilitateo": "durabilitate",
    "durabilități": "durabilitate",
    "durabilității": "durabilitate",
    "durabilitățile": "durabilitate",
    "durabilităților": "durabilitate",
    "durăia": "durăi",
    "durăiai": "durăi",
    "durăiam": "durăi",
    "durăiați": "durăi",
    "durăiau": "durăi",
    "durăie": "durăi",
    "durăii": "durăi",
    "durăim": "durăi",
    "durăind": "durăi",
    "durăindu": "durăi",
    "durăiră": "durăi",
    "durăirăm": "durăi",
    "durăirăți": "durăi",
    "durăise": "durăi",
    "durăisem": "durăi",
    "durăiseră": "durăi",
    "durăiserăm": "durăi",
    "durăiserăți": "durăi",
    "durăiseși": "durăi",
    "durăiși": "durăi",
    "durăit": "durăi",
    "durăiți": "durăi",
    "durăitu": "durăi",
    "nedurăind": "durăi",
    "nedurăindu": "durăi",
    "nemaidurăind": "durăi",
    "nemaidurăindu": "durăi",
    "durăită": "durăit",
    "durăite": "durăit",
    "durăiți": "durăit",
    "duraluminiul": "duraluminiu",
    "duraluminiule": "duraluminiu",
    "duraluminiului": "duraluminiu",
    "durări": "durare",
    "durării": "durare",
    "durările": "durare",
    "durărilor": "durare",
    "durată": "durat",
    "durate": "durat",
    "durați": "durat",
    "durata": "durată",
    "durate": "durată",
    "duratei": "durată",
    "duratele": "durată",
    "duratelor": "durată",
    "durato": "durată",
    "durduia": "durdui",
    "durduiai": "durdui",
    "durduiam": "durdui",
    "durduiați": "durdui",
    "durduiau": "durdui",
    "durduie": "durdui",
    "durduii": "durdui",
    "durduim": "durdui",
    "durduind": "durdui",
    "durduindu": "durdui",
    "durduiră": "durdui",
    "durduirăm": "durdui",
    "durduirăți": "durdui",
    "durduise": "durdui",
    "durduisem": "durdui",
    "durduiseră": "durdui",
    "durduiserăm": "durdui",
    "durduiserăți": "durdui",
    "durduiseși": "durdui",
    "durduiși": "durdui",
    "durduit": "durdui",
    "durduiți": "durdui",
    "durduitu": "durdui",
    "nedurduind": "durdui",
    "nedurduindu": "durdui",
    "nemaidurduind": "durdui",
    "nemaidurduindu": "durdui",
    "durduită": "durduit",
    "durduite": "durduit",
    "durduiți": "durduit",
    "durdulia": "durduliu",
    "durdulie": "durduliu",
    "durduliei": "durduliu",
    "durdulii": "durduliu",
    "durduliii": "durduliu",
    "durduliile": "durduliu",
    "durduliilor": "durduliu",
    "durdulio": "durduliu",
    "durduliul": "durduliu",
    "durduliule": "durduliu",
    "durduliului": "durduliu",
    "doară": "durea",
    "doare": "durea",
    "dor": "durea",
    "durând": "durea",
    "durându": "durea",
    "dureau": "durea",
    "duru": "durea",
    "durură": "durea",
    "duruse": "durea",
    "duruseră": "durea",
    "durut": "durea",
    "durutu": "durea",
    "nedurând": "durea",
    "nedurându": "durea",
    "nemaidurând": "durea",
    "nemaidurându": "durea",
    "durerea": "durere",
    "durereo": "durere",
    "dureri": "durere",
    "durerii": "durere",
    "durerile": "durere",
    "durerilor": "durere",
    "dureroasa": "dureros",
    "dureroasă": "dureros",
    "dureroase": "dureros",
    "dureroasei": "dureros",
    "dureroasele": "dureros",
    "dureroaselor": "dureros",
    "dureroaso": "dureros",
    "dureroși": "dureros",
    "dureroșii": "dureros",
    "dureroșilor": "dureros",
    "durerosul": "dureros",
    "durerosule": "dureros",
    "durerosului": "dureros",
    "durific": "durifica",
    "durifică": "durifica",
    "durificai": "durifica",
    "durificam": "durifica",
    "durificăm": "durifica",
    "durificând": "durifica",
    "durificându": "durifica",
    "durificară": "durifica",
    "durificarăm": "durifica",
    "durificarăți": "durifica",
    "durificase": "durifica",
    "durificasem": "durifica",
    "durificaseră": "durifica",
    "durificaserăm": "durifica",
    "durificaserăți": "durifica",
    "durificaseși": "durifica",
    "durificași": "durifica",
    "durificat": "durifica",
    "durificați": "durifica",
    "durificatu": "durifica",
    "durificau": "durifica",
    "durifice": "durifica",
    "durifici": "durifica",
    "durificată": "durificat",
    "durificate": "durificat",
    "durificați": "durificat",
    "nemaidurigând": "duriga",
    "nemaidurigându": "duriga",
    "duritatea": "duritate",
    "duritateo": "duritate",
    "durități": "duritate",
    "durității": "duritate",
    "duritățile": "duritate",
    "durităților": "duritate",
    "duruia": "durui",
    "duruiai": "durui",
    "duruiam": "durui",
    "duruiați": "durui",
    "duruiau": "durui",
    "duruie": "durui",
    "duruii": "durui",
    "duruim": "durui",
    "duruind": "durui",
    "duruindu": "durui",
    "duruiră": "durui",
    "duruirăm": "durui",
    "duruirăți": "durui",
    "duruise": "durui",
    "duruisem": "durui",
    "duruiseră": "durui",
    "duruiserăm": "durui",
    "duruiserăți": "durui",
    "duruiseși": "durui",
    "duruiși": "durui",
    "duruit": "durui",
    "duruiți": "durui",
    "duruitu": "durui",
    "neduruind": "durui",
    "neduruindu": "durui",
    "nemaiduruind": "durui",
    "nemaiduruindu": "durui",
    "duruirea": "duruire",
    "duruireo": "duruire",
    "duruiri": "duruire",
    "duruirii": "duruire",
    "duruirile": "duruire",
    "duruirilor": "duruire",
    "duruită": "duruit",
    "duruite": "duruit",
    "duruiți": "duruit",
    "duruitul": "duruit",
    "duruitule": "duruit",
    "duruitului": "duruit",
    "durută": "durut",
    "durute": "durut",
    "duruți": "durut",
    "dusa": "dus",
    "dusă": "dus",
    "duse": "dus",
    "dusei": "dus",
    "dusele": "dus",
    "duselor": "dus",
    "duși": "dus",
    "dușii": "dus",
    "dușilor": "dus",
    "duso": "dus",
    "dusul": "dus",
    "dusule": "dus",
    "dusului": "dus",
    "dușul": "duș",
    "dușule": "duș",
    "dușului": "duș",
    "dușuri": "duș",
    "dușurile": "duș",
    "dușurilor": "duș",
    "dușca": "dușcă",
    "dușco": "dușcă",
    "Düseldorful": "Düseldorf",
    "Düseldorfului": "Düseldorf",
    "dușmana": "dușman",
    "dușmană": "dușman",
    "dușmane": "dușman",
    "dușmanei": "dușman",
    "dușmanele": "dușman",
    "dușmanelor": "dușman",
    "dușmani": "dușman",
    "dușmanii": "dușman",
    "dușmanilor": "dușman",
    "dușmano": "dușman",
    "dușmanul": "dușman",
    "dușmanule": "dușman",
    "dușmanului": "dușman",
    "dușmanca": "dușmancă",
    "dușmance": "dușmancă",
    "dușmancei": "dușmancă",
    "dușmancele": "dușmancă",
    "dușmancelor": "dușmancă",
    "dușmanco": "dușmancă",
    "dușmănea": "dușmăni",
    "dușmăneai": "dușmăni",
    "dușmăneam": "dușmăni",
    "dușmănească": "dușmăni",
    "dușmăneați": "dușmăni",
    "dușmăneau": "dușmăni",
    "dușmănesc": "dușmăni",
    "dușmănește": "dușmăni",
    "dușmănești": "dușmăni",
    "dușmănii": "dușmăni",
    "dușmănim": "dușmăni",
    "dușmănind": "dușmăni",
    "dușmănindu": "dușmăni",
    "dușmăniră": "dușmăni",
    "dușmănirăm": "dușmăni",
    "dușmănirăți": "dușmăni",
    "dușmănise": "dușmăni",
    "dușmănisem": "dușmăni",
    "dușmăniseră": "dușmăni",
    "dușmăniserăm": "dușmăni",
    "dușmăniserăți": "dușmăni",
    "dușmăniseși": "dușmăni",
    "dușmăniși": "dușmăni",
    "dușmănit": "dușmăni",
    "dușmăniți": "dușmăni",
    "dușmănitu": "dușmăni",
    "nedușmănind": "dușmăni",
    "nedușmănindu": "dușmăni",
    "nemaidușmănind": "dușmăni",
    "nemaidușmănindu": "dușmăni",
    "dușmănia": "dușmănie",
    "dușmăniei": "dușmănie",
    "dușmănii": "dușmănie",
    "dușmăniile": "dușmănie",
    "dușmăniilor": "dușmănie",
    "dușmănio": "dușmănie",
    "dușmănită": "dușmănit",
    "dușmănite": "dușmănit",
    "dușmăniți": "dușmănit",
    "dușmănoasa": "dușmănos",
    "dușmănoasă": "dușmănos",
    "dușmănoase": "dușmănos",
    "dușmănoasei": "dușmănos",
    "dușmănoasele": "dușmănos",
    "dușmănoaselor": "dușmănos",
    "dușmănoaso": "dușmănos",
    "dușmănoși": "dușmănos",
    "dușmănoșii": "dușmănos",
    "dușmănoșilor": "dușmănos",
    "dușmănosul": "dușmănos",
    "dușmănosule": "dușmănos",
    "dușmănosului": "dușmănos",
    "dușumeao": "dușumea",
    "dușumeaua": "dușumea",
    "dușumele": "dușumea",
    "dușumelei": "dușumea",
    "dușumelele": "dușumea",
    "dușumelelor": "dușumea",
    "duza": "duză",
    "duze": "duză",
    "duzei": "duză",
    "duzele": "duză",
    "duzelor": "duză",
    "duzo": "duză",
    "ie": "e",
    "E.E.T.": "East_European_Trading",
    "ebeniști": "ebenist",
    "ebeniștii": "ebenist",
    "ebeniștilor": "ebenist",
    "ebenistul": "ebenist",
    "ebenistule": "ebenist",
    "ebenistului": "ebenist",
    "ebenista": "ebenistă",
    "ebeniste": "ebenistă",
    "ebenistei": "ebenistă",
    "ebenistele": "ebenistă",
    "ebenistelor": "ebenistă",
    "ebenisto": "ebenistă",
    "ebonita": "ebonită",
    "ebonite": "ebonită",
    "ebonitei": "ebonită",
    "ebonitele": "ebonită",
    "ebonitelor": "ebonită",
    "ebonito": "ebonită",
    "eboșă": "eboșa",
    "eboșai": "eboșa",
    "eboșam": "eboșa",
    "eboșăm": "eboșa",
    "eboșând": "eboșa",
    "eboșându": "eboșa",
    "eboșară": "eboșa",
    "eboșarăm": "eboșa",
    "eboșarăți": "eboșa",
    "eboșase": "eboșa",
    "eboșasem": "eboșa",
    "eboșaseră": "eboșa",
    "eboșaserăm": "eboșa",
    "eboșaserăți": "eboșa",
    "eboșaseși": "eboșa",
    "eboșași": "eboșa",
    "eboșat": "eboșa",
    "eboșați": "eboșa",
    "eboșatu": "eboșa",
    "eboșau": "eboșa",
    "eboșează": "eboșa",
    "eboșez": "eboșa",
    "eboșeze": "eboșa",
    "eboșezi": "eboșa",
    "neeboșând": "eboșa",
    "neeboșându": "eboșa",
    "nemaieboșând": "eboșa",
    "nemaieboșându": "eboșa",
    "eboșa": "eboșă",
    "eboșe": "eboșă",
    "eboșei": "eboșă",
    "eboșele": "eboșă",
    "eboșelor": "eboșă",
    "eboșo": "eboșă",
    "eboșarea": "eboșare",
    "eboșareo": "eboșare",
    "eboșări": "eboșare",
    "eboșării": "eboșare",
    "eboșările": "eboșare",
    "eboșărilor": "eboșare",
    "eboșată": "eboșat",
    "eboșate": "eboșat",
    "eboșați": "eboșat",
    "ebraica": "ebraic",
    "ebraică": "ebraic",
    "ebraice": "ebraic",
    "ebraicei": "ebraic",
    "ebraicele": "ebraic",
    "ebraicelor": "ebraic",
    "ebraici": "ebraic",
    "ebraicii": "ebraic",
    "ebraicilor": "ebraic",
    "ebraico": "ebraic",
    "ebraicul": "ebraic",
    "ebraicule": "ebraic",
    "ebraicului": "ebraic",
    "ebrietatea": "ebrietate",
    "ebrietateo": "ebrietate",
    "ebrietăți": "ebrietate",
    "ebrietății": "ebrietate",
    "ecarisaje": "ecarisaj",
    "ecarisajele": "ecarisaj",
    "ecarisajelor": "ecarisaj",
    "ecarisajul": "ecarisaj",
    "ecarisajule": "ecarisaj",
    "ecarisajului": "ecarisaj",
    "ecarisarea": "ecarisare",
    "ecarisareo": "ecarisare",
    "ecarisări": "ecarisare",
    "ecarisării": "ecarisare",
    "ecarisările": "ecarisare",
    "ecarisărilor": "ecarisare",
    "ecarisata": "ecarisat",
    "ecarisată": "ecarisat",
    "ecarisate": "ecarisat",
    "ecarisatei": "ecarisat",
    "ecarisatele": "ecarisat",
    "ecarisatelor": "ecarisat",
    "ecarisați": "ecarisat",
    "ecarisații": "ecarisat",
    "ecarisaților": "ecarisat",
    "ecarisato": "ecarisat",
    "ecarisatul": "ecarisat",
    "ecarisatule": "ecarisat",
    "ecarisatului": "ecarisat",
    "ecartamente": "ecartament",
    "ecartamentele": "ecartament",
    "ecartamentelor": "ecartament",
    "ecartamentul": "ecartament",
    "ecartamentule": "ecartament",
    "ecartamentului": "ecartament",
    "Ecaterinei": "Ecaterina",
    "echere": "echer",
    "echerele": "echer",
    "echerelor": "echer",
    "echerul": "echer",
    "echerule": "echer",
    "echerului": "echer",
    "echidistanta": "echidistant",
    "echidistantă": "echidistant",
    "echidistante": "echidistant",
    "echidistantei": "echidistant",
    "echidistantele": "echidistant",
    "echidistantelor": "echidistant",
    "echidistanți": "echidistant",
    "echidistanții": "echidistant",
    "echidistanților": "echidistant",
    "echidistanto": "echidistant",
    "echidistantul": "echidistant",
    "echidistantule": "echidistant",
    "echidistantului": "echidistant",
    "echidistanța": "echidistanță",
    "echidistanțe": "echidistanță",
    "echidistanței": "echidistanță",
    "echidistanțele": "echidistanță",
    "echidistanțelor": "echidistanță",
    "echidistanțo": "echidistanță",
    "echilaterala": "echilateral",
    "echilaterală": "echilateral",
    "echilaterale": "echilateral",
    "echilateralei": "echilateral",
    "echilateralele": "echilateral",
    "echilateralelor": "echilateral",
    "echilaterali": "echilateral",
    "echilateralii": "echilateral",
    "echilateralilor": "echilateral",
    "echilateralo": "echilateral",
    "echilateralul": "echilateral",
    "echilateralule": "echilateral",
    "echilateralului": "echilateral",
    "echilibră": "echilibra",
    "echilibrai": "echilibra",
    "echilibram": "echilibra",
    "echilibrăm": "echilibra",
    "echilibrând": "echilibra",
    "echilibrându": "echilibra",
    "echilibrară": "echilibra",
    "echilibrarăm": "echilibra",
    "echilibrarăți": "echilibra",
    "echilibrase": "echilibra",
    "echilibrasem": "echilibra",
    "echilibraseră": "echilibra",
    "echilibraserăm": "echilibra",
    "echilibraserăți": "echilibra",
    "echilibraseși": "echilibra",
    "echilibrași": "echilibra",
    "echilibrat": "echilibra",
    "echilibrați": "echilibra",
    "echilibratu": "echilibra",
    "echilibrau": "echilibra",
    "echilibrează": "echilibra",
    "echilibrez": "echilibra",
    "echilibreze": "echilibra",
    "echilibrezi": "echilibra",
    "neechilibrând": "echilibra",
    "neechilibrându": "echilibra",
    "nemaiechilibrând": "echilibra",
    "nemaiechilibrându": "echilibra",
    "echilibranta": "echilibrant",
    "echilibrantă": "echilibrant",
    "echilibrante": "echilibrant",
    "echilibrantei": "echilibrant",
    "echilibrantele": "echilibrant",
    "echilibrantelor": "echilibrant",
    "echilibranți": "echilibrant",
    "echilibranții": "echilibrant",
    "echilibranților": "echilibrant",
    "echilibranto": "echilibrant",
    "echilibrantul": "echilibrant",
    "echilibrantule": "echilibrant",
    "echilibrantului": "echilibrant",
    "echilibrarea": "echilibrare",
    "echilibrareo": "echilibrare",
    "echilibrări": "echilibrare",
    "echilibrării": "echilibrare",
    "echilibrările": "echilibrare",
    "echilibrărilor": "echilibrare",
    "echilibrata": "echilibrat",
    "echilibrată": "echilibrat",
    "echilibrate": "echilibrat",
    "echilibratei": "echilibrat",
    "echilibratele": "echilibrat",
    "echilibratelor": "echilibrat",
    "echilibrați": "echilibrat",
    "echilibrații": "echilibrat",
    "echilibraților": "echilibrat",
    "echilibrato": "echilibrat",
    "echilibratul": "echilibrat",
    "echilibratule": "echilibrat",
    "echilibratului": "echilibrat",
    "echilibriști": "echilibrist",
    "echilibriștii": "echilibrist",
    "echilibriștilor": "echilibrist",
    "echilibristul": "echilibrist",
    "echilibristule": "echilibrist",
    "echilibristului": "echilibrist",
    "echilibrista": "echilibristă",
    "echilibriste": "echilibristă",
    "echilibristei": "echilibristă",
    "echilibristele": "echilibristă",
    "echilibristelor": "echilibristă",
    "echilibristo": "echilibristă",
    "echilibristica": "echilibristică",
    "echilibristici": "echilibristică",
    "echilibristicii": "echilibristică",
    "echilibristicile": "echilibristică",
    "echilibristicilor": "echilibristică",
    "echilibristico": "echilibristică",
    "echilibroare": "echilibror",
    "echilibroarele": "echilibror",
    "echilibroarelor": "echilibror",
    "echilibrorul": "echilibror",
    "echilibrorule": "echilibror",
    "echilibrorului": "echilibror",
    "echilibre": "echilibru",
    "echilibrele": "echilibru",
    "echilibrelor": "echilibru",
    "echilibrul": "echilibru",
    "echilibrule": "echilibru",
    "echilibrului": "echilibru",
    "echimoza": "echimoză",
    "echimoze": "echimoză",
    "echimozei": "echimoză",
    "echimozele": "echimoză",
    "echimozelor": "echimoză",
    "echimozo": "echimoză",
    "echinocții": "echinocțiu",
    "echinocțiile": "echinocțiu",
    "echinocțiilor": "echinocțiu",
    "echinocțiul": "echinocțiu",
    "echinocțiule": "echinocțiu",
    "echinocțiului": "echinocțiu",
    "echinoderme": "echinoderm",
    "echinodermele": "echinoderm",
    "echinodermelor": "echinoderm",
    "echinodermul": "echinoderm",
    "echinodermule": "echinoderm",
    "echinodermului": "echinoderm",
    "echipă": "echipa",
    "echipai": "echipa",
    "echipam": "echipa",
    "echipăm": "echipa",
    "echipând": "echipa",
    "echipându": "echipa",
    "echipară": "echipa",
    "echiparăm": "echipa",
    "echiparăți": "echipa",
    "echipase": "echipa",
    "echipasem": "echipa",
    "echipaseră": "echipa",
    "echipaserăm": "echipa",
    "echipaserăți": "echipa",
    "echipaseși": "echipa",
    "echipași": "echipa",
    "echipat": "echipa",
    "echipați": "echipa",
    "echipatu": "echipa",
    "echipau": "echipa",
    "echipează": "echipa",
    "echipez": "echipa",
    "echipeze": "echipa",
    "echipezi": "echipa",
    "neechipând": "echipa",
    "neechipându": "echipa",
    "nemaiechipând": "echipa",
    "nemaiechipându": "echipa",
    "echipa": "echipă",
    "echipe": "echipă",
    "echipei": "echipă",
    "echipele": "echipă",
    "echipelor": "echipă",
    "echipo": "echipă",
    "echipagii": "echipagiu",
    "echipagiii": "echipagiu",
    "echipagiilor": "echipagiu",
    "echipagiul": "echipagiu",
    "echipagiule": "echipagiu",
    "echipagiului": "echipagiu",
    "echipaje": "echipaj",
    "echipajele": "echipaj",
    "echipajelor": "echipaj",
    "echipajul": "echipaj",
    "echipajule": "echipaj",
    "echipajului": "echipaj",
    "echipamente": "echipament",
    "echipamentele": "echipament",
    "echipamentelor": "echipament",
    "echipamentul": "echipament",
    "echipamentule": "echipament",
    "echipamentului": "echipament",
    "echiparea": "echipare",
    "echipareo": "echipare",
    "echipări": "echipare",
    "echipării": "echipare",
    "echipările": "echipare",
    "echipărilor": "echipare",
    "echipata": "echipat",
    "echipată": "echipat",
    "echipate": "echipat",
    "echipatei": "echipat",
    "echipatele": "echipat",
    "echipatelor": "echipat",
    "echipați": "echipat",
    "echipații": "echipat",
    "echipaților": "echipat",
    "echipato": "echipat",
    "echipatul": "echipat",
    "echipatule": "echipat",
    "echipatului": "echipat",
    "echitabila": "echitabil",
    "echitabilă": "echitabil",
    "echitabile": "echitabil",
    "echitabilei": "echitabil",
    "echitabilele": "echitabil",
    "echitabilelor": "echitabil",
    "echitabili": "echitabil",
    "echitabilii": "echitabil",
    "echitabililor": "echitabil",
    "echitabilo": "echitabil",
    "echitabilul": "echitabil",
    "echitabilule": "echitabil",
    "echitabilului": "echitabil",
    "echitatea": "echitate",
    "echitateo": "echitate",
    "echități": "echitate",
    "echității": "echitate",
    "echitățile": "echitate",
    "echităților": "echitate",
    "echitația": "echitație",
    "echitației": "echitație",
    "echitații": "echitație",
    "echitațio": "echitație",
    "echivală": "echivala",
    "echivalai": "echivala",
    "echivalam": "echivala",
    "echivalăm": "echivala",
    "echivalând": "echivala",
    "echivalându": "echivala",
    "echivalară": "echivala",
    "echivalarăm": "echivala",
    "echivalarăți": "echivala",
    "echivalase": "echivala",
    "echivalasem": "echivala",
    "echivalaseră": "echivala",
    "echivalaserăm": "echivala",
    "echivalaserăți": "echivala",
    "echivalaseși": "echivala",
    "echivalași": "echivala",
    "echivalat": "echivala",
    "echivalați": "echivala",
    "echivalatu": "echivala",
    "echivalau": "echivala",
    "echivalează": "echivala",
    "echivalez": "echivala",
    "echivaleze": "echivala",
    "echivalezi": "echivala",
    "neechivalând": "echivala",
    "neechivalându": "echivala",
    "nemaiechivalând": "echivala",
    "nemaiechivalându": "echivala",
    "echivalarea": "echivalare",
    "echivalareo": "echivalare",
    "echivalări": "echivalare",
    "echivalării": "echivalare",
    "echivalările": "echivalare",
    "echivalărilor": "echivalare",
    "echivalată": "echivalat",
    "echivalate": "echivalat",
    "echivalați": "echivalat",
    "echivalenta": "echivalent",
    "echivalentă": "echivalent",
    "echivalente": "echivalent",
    "echivalentei": "echivalent",
    "echivalentele": "echivalent",
    "echivalentelor": "echivalent",
    "echivalenți": "echivalent",
    "echivalenții": "echivalent",
    "echivalenților": "echivalent",
    "echivalento": "echivalent",
    "echivalentul": "echivalent",
    "echivalentule": "echivalent",
    "echivalentului": "echivalent",
    "echivalența": "echivalență",
    "echivalențe": "echivalență",
    "echivalenței": "echivalență",
    "echivalențele": "echivalență",
    "echivalențelor": "echivalență",
    "echivalențo": "echivalență",
    "echivoca": "echivoc",
    "echivocă": "echivoc",
    "echivoce": "echivoc",
    "echivocei": "echivoc",
    "echivocele": "echivoc",
    "echivocelor": "echivoc",
    "echivoci": "echivoc",
    "echivocii": "echivoc",
    "echivocilor": "echivoc",
    "echivoco": "echivoc",
    "echivocul": "echivoc",
    "echivocule": "echivoc",
    "echivocului": "echivoc",
    "echocardiografia": "echocardiografie",
    "echocardiografiei": "echocardiografie",
    "echocardiografii": "echocardiografie",
    "echocardiografiile": "echocardiografie",
    "echocardiografiilor": "echocardiografie",
    "echocardiografio": "echocardiografie",
    "eclatanta": "eclatant",
    "eclatantă": "eclatant",
    "eclatante": "eclatant",
    "eclatantei": "eclatant",
    "eclatantele": "eclatant",
    "eclatantelor": "eclatant",
    "eclatanți": "eclatant",
    "eclatanții": "eclatant",
    "eclatanților": "eclatant",
    "eclatanto": "eclatant",
    "eclatantul": "eclatant",
    "eclatantule": "eclatant",
    "eclatantului": "eclatant",
    "eclatoare": "eclator",
    "eclatoarele": "eclator",
    "eclatoarelor": "eclator",
    "eclatorul": "eclator",
    "eclatorule": "eclator",
    "eclatorului": "eclator",
    "eclectica": "eclectic",
    "eclectică": "eclectic",
    "eclectice": "eclectic",
    "eclecticei": "eclectic",
    "eclecticele": "eclectic",
    "eclecticelor": "eclectic",
    "eclectici": "eclectic",
    "eclecticii": "eclectic",
    "eclecticilor": "eclectic",
    "eclectico": "eclectic",
    "eclecticul": "eclectic",
    "eclecticule": "eclectic",
    "eclecticului": "eclectic",
    "ecleziastica": "ecleziastic",
    "ecleziastică": "ecleziastic",
    "ecleziastice": "ecleziastic",
    "ecleziasticei": "ecleziastic",
    "ecleziasticele": "ecleziastic",
    "ecleziasticelor": "ecleziastic",
    "ecleziastici": "ecleziastic",
    "ecleziasticii": "ecleziastic",
    "ecleziasticilor": "ecleziastic",
    "ecleziastico": "ecleziastic",
    "ecleziasticul": "ecleziastic",
    "ecleziasticule": "ecleziastic",
    "ecleziasticului": "ecleziastic",
    "eclipsă": "eclipsa",
    "eclipsai": "eclipsa",
    "eclipsam": "eclipsa",
    "eclipsăm": "eclipsa",
    "eclipsând": "eclipsa",
    "eclipsându": "eclipsa",
    "eclipsară": "eclipsa",
    "eclipsarăm": "eclipsa",
    "eclipsarăți": "eclipsa",
    "eclipsase": "eclipsa",
    "eclipsasem": "eclipsa",
    "eclipsaseră": "eclipsa",
    "eclipsaserăm": "eclipsa",
    "eclipsaserăți": "eclipsa",
    "eclipsaseși": "eclipsa",
    "eclipsași": "eclipsa",
    "eclipsat": "eclipsa",
    "eclipsați": "eclipsa",
    "eclipsatu": "eclipsa",
    "eclipsau": "eclipsa",
    "eclipsează": "eclipsa",
    "eclipsez": "eclipsa",
    "eclipseze": "eclipsa",
    "eclipsezi": "eclipsa",
    "neeclipsând": "eclipsa",
    "neeclipsându": "eclipsa",
    "nemaieclipsând": "eclipsa",
    "nemaieclipsându": "eclipsa",
    "eclipsa": "eclipsă",
    "eclipse": "eclipsă",
    "eclipsei": "eclipsă",
    "eclipsele": "eclipsă",
    "eclipselor": "eclipsă",
    "eclipso": "eclipsă",
    "eclipsarea": "eclipsare",
    "eclipsareo": "eclipsare",
    "eclipsări": "eclipsare",
    "eclipsării": "eclipsare",
    "eclipsările": "eclipsare",
    "eclipsărilor": "eclipsare",
    "eclipsată": "eclipsat",
    "eclipsate": "eclipsat",
    "eclipsați": "eclipsat",
    "ecliptica": "ecliptică",
    "ecliptici": "ecliptică",
    "eclipticii": "ecliptică",
    "eclipticile": "ecliptică",
    "eclipticilor": "ecliptică",
    "ecliptico": "ecliptică",
    "ecluza": "ecluză",
    "ecluze": "ecluză",
    "ecluzei": "ecluză",
    "ecluzele": "ecluză",
    "ecluzelor": "ecluză",
    "ecluzo": "ecluză",
    "ecografica": "ecografic",
    "ecografică": "ecografic",
    "ecografice": "ecografic",
    "ecograficei": "ecografic",
    "ecograficele": "ecografic",
    "ecograficelor": "ecografic",
    "ecografici": "ecografic",
    "ecograficii": "ecografic",
    "ecograficilor": "ecografic",
    "ecografico": "ecografic",
    "ecograficul": "ecografic",
    "ecograficule": "ecografic",
    "ecograficului": "ecografic",
    "ecografia": "ecografie",
    "ecografiei": "ecografie",
    "ecografii": "ecografie",
    "ecografiile": "ecografie",
    "ecografiilor": "ecografie",
    "ecografio": "ecografie",
    "ecologica": "ecologic",
    "ecologică": "ecologic",
    "ecologice": "ecologic",
    "ecologicei": "ecologic",
    "ecologicele": "ecologic",
    "ecologicelor": "ecologic",
    "ecologici": "ecologic",
    "ecologicii": "ecologic",
    "ecologicilor": "ecologic",
    "ecologico": "ecologic",
    "ecologicul": "ecologic",
    "ecologicule": "ecologic",
    "ecologicului": "ecologic",
    "ecologia": "ecologie",
    "ecologiei": "ecologie",
    "ecologii": "ecologie",
    "ecologio": "ecologie",
    "ecologismul": "ecologism",
    "ecologismule": "ecologism",
    "ecologismului": "ecologism",
    "ecologista": "ecologist",
    "ecologistă": "ecologist",
    "ecologiste": "ecologist",
    "ecologistei": "ecologist",
    "ecologistele": "ecologist",
    "ecologistelor": "ecologist",
    "ecologiști": "ecologist",
    "ecologiștii": "ecologist",
    "ecologiștilor": "ecologist",
    "ecologisto": "ecologist",
    "ecologistul": "ecologist",
    "ecologistule": "ecologist",
    "ecologistului": "ecologist",
    "ecologista": "ecologistă",
    "ecologiste": "ecologistă",
    "ecologistei": "ecologistă",
    "ecologistele": "ecologistă",
    "ecologistelor": "ecologistă",
    "ecologisto": "ecologistă",
    "ecologizarea": "ecologizare",
    "ecologizări": "ecologizare",
    "ecologizării": "ecologizare",
    "ecologizările": "ecologizare",
    "ecologizărilor": "ecologizare",
    "econoama": "econoamă",
    "econoame": "econoamă",
    "econoamei": "econoamă",
    "econoamele": "econoamă",
    "econoamelor": "econoamă",
    "econoamo": "econoamă",
    "econoama": "econom",
    "econoamă": "econom",
    "econoame": "econom",
    "econoamei": "econom",
    "econoamele": "econom",
    "econoamelor": "econom",
    "economi": "econom",
    "economii": "econom",
    "economilor": "econom",
    "economul": "econom",
    "economule": "econom",
    "economului": "econom",
    "economate": "economat",
    "economatele": "economat",
    "economatelor": "economat",
    "economatul": "economat",
    "economatule": "economat",
    "economatului": "economat",
    "economica": "economic",
    "economică": "economic",
    "economice": "economic",
    "economicei": "economic",
    "economicele": "economic",
    "economicelor": "economic",
    "economici": "economic",
    "economicii": "economic",
    "economicilor": "economic",
    "economico": "economic",
    "economicul": "economic",
    "economicule": "economic",
    "economicului": "economic",
    "economico-comerciale": "economico-comercial",
    "economico-financiară": "economico-financiar",
    "economico-financiare": "economico-financiar",
    "economicoasa": "economicos",
    "economicoasă": "economicos",
    "economicoase": "economicos",
    "economicoasei": "economicos",
    "economicoasele": "economicos",
    "economicoaselor": "economicos",
    "economicoaso": "economicos",
    "economicoși": "economicos",
    "economicoșii": "economicos",
    "economicoșilor": "economicos",
    "economicosul": "economicos",
    "economicosule": "economicos",
    "economicosului": "economicos",
    "econ.": "economie",
    "economia": "economie",
    "economiei": "economie",
    "economii": "economie",
    "economiile": "economie",
    "economiilor": "economie",
    "economio": "economie",
    "economisea": "economisi",
    "economiseai": "economisi",
    "economiseam": "economisi",
    "economisească": "economisi",
    "economiseați": "economisi",
    "economiseau": "economisi",
    "economisesc": "economisi",
    "economisește": "economisi",
    "economisești": "economisi",
    "economisii": "economisi",
    "economisim": "economisi",
    "economisind": "economisi",
    "economisindu": "economisi",
    "economisiră": "economisi",
    "economisirăm": "economisi",
    "economisirăți": "economisi",
    "economisise": "economisi",
    "economisisem": "economisi",
    "economisiseră": "economisi",
    "economisiserăm": "economisi",
    "economisiserăți": "economisi",
    "economisiseși": "economisi",
    "economisiși": "economisi",
    "economisit": "economisi",
    "economisiți": "economisi",
    "economisitu": "economisi",
    "neeconomisind": "economisi",
    "neeconomisindu": "economisi",
    "nemaieconomisind": "economisi",
    "nemaieconomisindu": "economisi",
    "economisirea": "economisire",
    "economisireo": "economisire",
    "economisiri": "economisire",
    "economisirii": "economisire",
    "economisirile": "economisire",
    "economisirilor": "economisire",
    "economisită": "economisit",
    "economisite": "economisit",
    "economisiți": "economisit",
    "economismul": "economism",
    "economismule": "economism",
    "economismului": "economism",
    "economiști": "economist",
    "economiștii": "economist",
    "economiștilor": "economist",
    "economistul": "economist",
    "economistule": "economist",
    "economistului": "economist",
    "economista": "economistă",
    "economiste": "economistă",
    "economistei": "economistă",
    "economistele": "economistă",
    "economistelor": "economistă",
    "economisto": "economistă",
    "economizoare": "economizor",
    "economizoarele": "economizor",
    "economizoarelor": "economizor",
    "economizorul": "economizor",
    "economizorule": "economizor",
    "economizorului": "economizor",
    "ecoul": "ecou",
    "ecoule": "ecou",
    "ecoului": "ecou",
    "ecouri": "ecou",
    "ecourile": "ecou",
    "ecourilor": "ecou",
    "ecrane": "ecran",
    "ecranele": "ecran",
    "ecranelor": "ecran",
    "ecranul": "ecran",
    "ecranule": "ecran",
    "ecranului": "ecran",
    "ecranizarea": "ecranizare",
    "ecranizareo": "ecranizare",
    "ecranizări": "ecranizare",
    "ecranizării": "ecranizare",
    "ecranizările": "ecranizare",
    "ecranizărilor": "ecranizare",
    "ecruisaje": "ecruisaj",
    "ecruisajele": "ecruisaj",
    "ecruisajelor": "ecruisaj",
    "ecruisajul": "ecruisaj",
    "ecruisajule": "ecruisaj",
    "ecruisajului": "ecruisaj",
    "ecruisata": "ecruisat",
    "ecruisată": "ecruisat",
    "ecruisate": "ecruisat",
    "ecruisatei": "ecruisat",
    "ecruisatele": "ecruisat",
    "ecruisatelor": "ecruisat",
    "ecruisați": "ecruisat",
    "ecruisații": "ecruisat",
    "ecruisaților": "ecruisat",
    "ecruisato": "ecruisat",
    "ecruisatul": "ecruisat",
    "ecruisatule": "ecruisat",
    "ecruisatului": "ecruisat",
    "ecuația": "ecuație",
    "ecuației": "ecuație",
    "ecuații": "ecuație",
    "ecuațiile": "ecuație",
    "ecuațiilor": "ecuație",
    "ecuațio": "ecuație",
    "ecuatorul": "ecuator",
    "ecuatorule": "ecuator",
    "ecuatorului": "ecuator",
    "ecuatoriala": "ecuatorial",
    "ecuatorială": "ecuatorial",
    "ecuatoriale": "ecuatorial",
    "ecuatorialei": "ecuatorial",
    "ecuatorialele": "ecuatorial",
    "ecuatorialelor": "ecuatorial",
    "ecuatoriali": "ecuatorial",
    "ecuatorialii": "ecuatorial",
    "ecuatorialilor": "ecuatorial",
    "ecuatorialo": "ecuatorial",
    "ecuatorialul": "ecuatorial",
    "ecuatorialule": "ecuatorial",
    "ecuatorialului": "ecuatorial",
    "ecumenica": "ecumenic",
    "ecumenică": "ecumenic",
    "ecumenice": "ecumenic",
    "ecumenicei": "ecumenic",
    "ecumenicele": "ecumenic",
    "ecumenicelor": "ecumenic",
    "ecumenici": "ecumenic",
    "ecumenicii": "ecumenic",
    "ecumenicilor": "ecumenic",
    "ecumenico": "ecumenic",
    "ecumenicul": "ecumenic",
    "ecumenicule": "ecumenic",
    "ecumenicului": "ecumenic",
    "ecvestra": "ecvestru",
    "ecvestră": "ecvestru",
    "ecvestre": "ecvestru",
    "ecvestrei": "ecvestru",
    "ecvestrele": "ecvestru",
    "ecvestrelor": "ecvestru",
    "ecveștri": "ecvestru",
    "ecveștrii": "ecvestru",
    "ecveștrilor": "ecvestru",
    "ecvestro": "ecvestru",
    "ecvestrul": "ecvestru",
    "ecvestrule": "ecvestru",
    "ecvestrului": "ecvestru",
    "eczema": "eczemă",
    "eczeme": "eczemă",
    "eczemei": "eczemă",
    "eczemele": "eczemă",
    "eczemelor": "eczemă",
    "eczemo": "eczemă",
    "edecul": "edec",
    "edecule": "edec",
    "edecului": "edec",
    "edecuri": "edec",
    "edecurile": "edec",
    "edecurilor": "edec",
    "edeme": "edem",
    "edemele": "edem",
    "edemelor": "edem",
    "edemul": "edem",
    "edemule": "edem",
    "edemului": "edem",
    "edicte": "edict",
    "edictele": "edict",
    "edictelor": "edict",
    "edictul": "edict",
    "edictule": "edict",
    "edictului": "edict",
    "edific": "edifica",
    "edifică": "edifica",
    "edificai": "edifica",
    "edificam": "edifica",
    "edificăm": "edifica",
    "edificând": "edifica",
    "edificându": "edifica",
    "edificară": "edifica",
    "edificarăm": "edifica",
    "edificarăți": "edifica",
    "edificase": "edifica",
    "edificasem": "edifica",
    "edificaseră": "edifica",
    "edificaserăm": "edifica",
    "edificaserăți": "edifica",
    "edificaseși": "edifica",
    "edificași": "edifica",
    "edificat": "edifica",
    "edificați": "edifica",
    "edificatu": "edifica",
    "edificau": "edifica",
    "edifice": "edifica",
    "edifici": "edifica",
    "needificând": "edifica",
    "needificându": "edifica",
    "nemaiedificând": "edifica",
    "nemaiedificându": "edifica",
    "edificarea": "edificare",
    "edificareo": "edificare",
    "edificări": "edificare",
    "edificării": "edificare",
    "edificările": "edificare",
    "edificărilor": "edificare",
    "edificată": "edificat",
    "edificate": "edificat",
    "edificați": "edificat",
    "edificatoare": "edificator",
    "edificatoarea": "edificator",
    "edificatoarei": "edificator",
    "edificatoarele": "edificator",
    "edificatoarelor": "edificator",
    "edificatoareo": "edificator",
    "edificatori": "edificator",
    "edificatorii": "edificator",
    "edificatorilor": "edificator",
    "edificatorul": "edificator",
    "edificatorule": "edificator",
    "edificatorului": "edificator",
    "edificii": "edificiu",
    "edificiile": "edificiu",
    "edificiilor": "edificiu",
    "edificiul": "edificiu",
    "edificiule": "edificiu",
    "edificiului": "edificiu",
    "edili": "edil",
    "edilii": "edil",
    "edililor": "edil",
    "edilul": "edil",
    "edilule": "edil",
    "edilului": "edil",
    "edilitara": "edilitar",
    "edilitară": "edilitar",
    "edilitare": "edilitar",
    "edilitarei": "edilitar",
    "edilitarele": "edilitar",
    "edilitarelor": "edilitar",
    "edilitari": "edilitar",
    "edilitarii": "edilitar",
    "edilitarilor": "edilitar",
    "edilitaro": "edilitar",
    "edilitarul": "edilitar",
    "edilitarule": "edilitar",
    "edilitarului": "edilitar",
    "edită": "edita",
    "editai": "edita",
    "editam": "edita",
    "edităm": "edita",
    "editând": "edita",
    "editându": "edita",
    "editară": "edita",
    "editarăm": "edita",
    "editarăți": "edita",
    "editase": "edita",
    "editasem": "edita",
    "editaseră": "edita",
    "editaserăm": "edita",
    "editaserăți": "edita",
    "editaseși": "edita",
    "editași": "edita",
    "editat": "edita",
    "editați": "edita",
    "editatu": "edita",
    "editau": "edita",
    "editează": "edita",
    "editez": "edita",
    "editeze": "edita",
    "editezi": "edita",
    "needitând": "edita",
    "needitându": "edita",
    "nemaieditând": "edita",
    "nemaieditându": "edita",
    "editarea": "editare",
    "editareo": "editare",
    "editări": "editare",
    "editării": "editare",
    "editările": "editare",
    "editărilor": "editare",
    "editată": "editat",
    "editate": "editat",
    "editați": "editat",
    "ed.": "ediție",
    "ediția": "ediție",
    "ediției": "ediție",
    "ediții": "ediție",
    "edițiile": "ediție",
    "edițiilor": "ediție",
    "edițio": "ediție",
    "e.p.": "editio_princeps",
    "editoarea": "editoare",
    "editoarei": "editoare",
    "editoarele": "editoare",
    "editoarelor": "editoare",
    "editoareo": "editoare",
    "editori": "editor",
    "editorii": "editor",
    "editorilor": "editor",
    "editorul": "editor",
    "editorule": "editor",
    "editorului": "editor",
    "editoriale": "editorial",
    "editorialele": "editorial",
    "editorialelor": "editorial",
    "editorialul": "editorial",
    "editorialule": "editorial",
    "editorialului": "editorial",
    "editura": "editură",
    "edituri": "editură",
    "editurii": "editură",
    "editurile": "editură",
    "editurilor": "editură",
    "edituro": "editură",
    "E.D.P.": "Editura_Didactică_și_Pedagogică",
    "educ": "educa",
    "educă": "educa",
    "educai": "educa",
    "educam": "educa",
    "educăm": "educa",
    "educând": "educa",
    "educându": "educa",
    "educară": "educa",
    "educarăm": "educa",
    "educarăți": "educa",
    "educase": "educa",
    "educasem": "educa",
    "educaseră": "educa",
    "educaserăm": "educa",
    "educaserăți": "educa",
    "educaseși": "educa",
    "educași": "educa",
    "educat": "educa",
    "educați": "educa",
    "educatu": "educa",
    "educau": "educa",
    "educe": "educa",
    "educi": "educa",
    "needucând": "educa",
    "needucându": "educa",
    "nemaieducând": "educa",
    "nemaieducându": "educa",
    "educarea": "educare",
    "educareo": "educare",
    "educări": "educare",
    "educării": "educare",
    "educările": "educare",
    "educărilor": "educare",
    "educată": "educat",
    "educate": "educat",
    "educați": "educat",
    "educația": "educație",
    "educației": "educație",
    "educații": "educație",
    "educațiile": "educație",
    "educațiilor": "educație",
    "educațio": "educație",
    "educativa": "educativ",
    "educativă": "educativ",
    "educative": "educativ",
    "educativei": "educativ",
    "educativele": "educativ",
    "educativelor": "educativ",
    "educativi": "educativ",
    "educativii": "educativ",
    "educativilor": "educativ",
    "educativo": "educativ",
    "educativul": "educativ",
    "educativule": "educativ",
    "educativului": "educativ",
    "educatoarea": "educatoare",
    "educatoarei": "educatoare",
    "educatoarele": "educatoare",
    "educatoarelor": "educatoare",
    "educatoareo": "educatoare",
    "educatoare": "educator",
    "educatoarea": "educator",
    "educatoarei": "educator",
    "educatoarele": "educator",
    "educatoarelor": "educator",
    "educatoareo": "educator",
    "educatori": "educator",
    "educatorii": "educator",
    "educatorilor": "educator",
    "educatorul": "educator",
    "educatorule": "educator",
    "educatorului": "educator",
    "efecte": "efect",
    "efectele": "efect",
    "efectelor": "efect",
    "efectul": "efect",
    "efectule": "efect",
    "efectului": "efect",
    "efectiva": "efectiv",
    "efectivă": "efectiv",
    "efective": "efectiv",
    "efectivei": "efectiv",
    "efectivele": "efectiv",
    "efectivelor": "efectiv",
    "efectivi": "efectiv",
    "efectivii": "efectiv",
    "efectivilor": "efectiv",
    "efectivo": "efectiv",
    "efectivul": "efectiv",
    "efectivule": "efectiv",
    "efectivului": "efectiv",
    "efectuă": "efectua",
    "efectuai": "efectua",
    "efectuam": "efectua",
    "efectuăm": "efectua",
    "efectuând": "efectua",
    "efectuându": "efectua",
    "efectuară": "efectua",
    "efectuarăm": "efectua",
    "efectuarăți": "efectua",
    "efectuase": "efectua",
    "efectuasem": "efectua",
    "efectuaseră": "efectua",
    "efectuaserăm": "efectua",
    "efectuaserăți": "efectua",
    "efectuaseși": "efectua",
    "efectuași": "efectua",
    "efectuat": "efectua",
    "efectuați": "efectua",
    "efectuatu": "efectua",
    "efectuau": "efectua",
    "efectuează": "efectua",
    "efectuez": "efectua",
    "efectueze": "efectua",
    "efectuezi": "efectua",
    "neefectuând": "efectua",
    "neefectuându": "efectua",
    "nemaiefectuând": "efectua",
    "nemaiefectuându": "efectua",
    "efectuarea": "efectuare",
    "efectuareo": "efectuare",
    "efectuări": "efectuare",
    "efectuării": "efectuare",
    "efectuările": "efectuare",
    "efectuărilor": "efectuare",
    "efectuată": "efectuat",
    "efectuate": "efectuat",
    "efectuați": "efectuat",
    "efemera": "efemer",
    "efemeră": "efemer",
    "efemere": "efemer",
    "efemerei": "efemer",
    "efemerele": "efemer",
    "efemerelor": "efemer",
    "efemeri": "efemer",
    "efemerii": "efemer",
    "efemerilor": "efemer",
    "efemero": "efemer",
    "efemerul": "efemer",
    "efemerule": "efemer",
    "efemerului": "efemer",
    "efemerida": "efemeridă",
    "efemeride": "efemeridă",
    "efemeridei": "efemeridă",
    "efemeridele": "efemeridă",
    "efemeridelor": "efemeridă",
    "efemerido": "efemeridă",
    "efemeritatea": "efemeritate",
    "efemeritateo": "efemeritate",
    "efemerități": "efemeritate",
    "efemerității": "efemeritate",
    "efemeritățile": "efemeritate",
    "efemerităților": "efemeritate",
    "efeminata": "efeminat",
    "efeminată": "efeminat",
    "efeminate": "efeminat",
    "efeminatei": "efeminat",
    "efeminatele": "efeminat",
    "efeminatelor": "efeminat",
    "efeminați": "efeminat",
    "efeminații": "efeminat",
    "efeminaților": "efeminat",
    "efeminato": "efeminat",
    "efeminatul": "efeminat",
    "efeminatule": "efeminat",
    "efeminatului": "efeminat",
    "efervescenta": "efervescent",
    "efervescentă": "efervescent",
    "efervescente": "efervescent",
    "efervescentei": "efervescent",
    "efervescentele": "efervescent",
    "efervescentelor": "efervescent",
    "efervescenți": "efervescent",
    "efervescenții": "efervescent",
    "efervescenților": "efervescent",
    "efervescento": "efervescent",
    "efervescentul": "efervescent",
    "efervescentule": "efervescent",
    "efervescentului": "efervescent",
    "efervescența": "efervescență",
    "efervescențe": "efervescență",
    "efervescenței": "efervescență",
    "efervescențele": "efervescență",
    "efervescențelor": "efervescență",
    "efervescențo": "efervescență",
    "eficacitatea": "eficacitate",
    "eficacitateo": "eficacitate",
    "eficacități": "eficacitate",
    "eficacității": "eficacitate",
    "eficacitățile": "eficacitate",
    "eficacităților": "eficacitate",
    "eficienta": "eficient",
    "eficientă": "eficient",
    "eficiente": "eficient",
    "eficientei": "eficient",
    "eficientele": "eficient",
    "eficientelor": "eficient",
    "eficienți": "eficient",
    "eficienții": "eficient",
    "eficienților": "eficient",
    "eficiento": "eficient",
    "eficientul": "eficient",
    "eficientule": "eficient",
    "eficientului": "eficient",
    "eficiența": "eficiență",
    "eficiențe": "eficiență",
    "eficienței": "eficiență",
    "eficiențele": "eficiență",
    "eficiențelor": "eficiență",
    "eficiențo": "eficiență",
    "efigia": "efigie",
    "efigiei": "efigie",
    "efigii": "efigie",
    "efigiile": "efigie",
    "efigiilor": "efigie",
    "efigio": "efigie",
    "eflorescenta": "eflorescent",
    "eflorescentă": "eflorescent",
    "eflorescente": "eflorescent",
    "eflorescentei": "eflorescent",
    "eflorescentele": "eflorescent",
    "eflorescentelor": "eflorescent",
    "eflorescenți": "eflorescent",
    "eflorescenții": "eflorescent",
    "eflorescenților": "eflorescent",
    "eflorescento": "eflorescent",
    "eflorescentul": "eflorescent",
    "eflorescentule": "eflorescent",
    "eflorescentului": "eflorescent",
    "eflorescența": "eflorescență",
    "eflorescențe": "eflorescență",
    "eflorescenței": "eflorescență",
    "eflorescențele": "eflorescență",
    "eflorescențelor": "eflorescență",
    "eflorescențo": "eflorescență",
    "efluvii": "efluviu",
    "efluviile": "efluviu",
    "efluviilor": "efluviu",
    "efluviul": "efluviu",
    "efluviule": "efluviu",
    "efluviului": "efluviu",
    "efori": "efor",
    "eforii": "efor",
    "eforilor": "efor",
    "eforul": "efor",
    "eforule": "efor",
    "eforului": "efor",
    "efortul": "efort",
    "efortule": "efort",
    "efortului": "efort",
    "eforturi": "efort",
    "eforturile": "efort",
    "eforturilor": "efort",
    "efracția": "efracție",
    "efracției": "efracție",
    "efracții": "efracție",
    "efracțiile": "efracție",
    "efracțiilor": "efracție",
    "efracțio": "efracție",
    "efuziunea": "efuziune",
    "efuziuneo": "efuziune",
    "efuziuni": "efuziune",
    "efuziunii": "efuziune",
    "efuziunile": "efuziune",
    "efuziunilor": "efuziune",
    "egala": "egal",
    "egală": "egal",
    "egale": "egal",
    "egalei": "egal",
    "egalele": "egal",
    "egalelor": "egal",
    "egali": "egal",
    "egalii": "egal",
    "egalilor": "egal",
    "egalo": "egal",
    "egalul": "egal",
    "egalule": "egal",
    "egalului": "egal",
    "egală": "egala",
    "egalai": "egala",
    "egalam": "egala",
    "egalăm": "egala",
    "egalând": "egala",
    "egalându": "egala",
    "egalară": "egala",
    "egalarăm": "egala",
    "egalarăți": "egala",
    "egalase": "egala",
    "egalasem": "egala",
    "egalaseră": "egala",
    "egalaserăm": "egala",
    "egalaserăți": "egala",
    "egalaseși": "egala",
    "egalași": "egala",
    "egalat": "egala",
    "egalați": "egala",
    "egalatu": "egala",
    "egalau": "egala",
    "egalează": "egala",
    "egalez": "egala",
    "egaleze": "egala",
    "egalezi": "egala",
    "neegalând": "egala",
    "neegalându": "egala",
    "nemaiegalând": "egala",
    "nemaiegalându": "egala",
    "egala": "egală",
    "egale": "egală",
    "egalarea": "egalare",
    "egalareo": "egalare",
    "egalări": "egalare",
    "egalării": "egalare",
    "egalările": "egalare",
    "egalărilor": "egalare",
    "egalata": "egalat",
    "egalată": "egalat",
    "egalate": "egalat",
    "egalatei": "egalat",
    "egalatele": "egalat",
    "egalatelor": "egalat",
    "egalați": "egalat",
    "egalații": "egalat",
    "egalaților": "egalat",
    "egalato": "egalat",
    "egalatul": "egalat",
    "egalatule": "egalat",
    "egalatului": "egalat",
    "egalitara": "egalitar",
    "egalitară": "egalitar",
    "egalitare": "egalitar",
    "egalitarei": "egalitar",
    "egalitarele": "egalitar",
    "egalitarelor": "egalitar",
    "egalitari": "egalitar",
    "egalitarii": "egalitar",
    "egalitarilor": "egalitar",
    "egalitaro": "egalitar",
    "egalitarul": "egalitar",
    "egalitarule": "egalitar",
    "egalitarului": "egalitar",
    "egalitatea": "egalitate",
    "egalitateo": "egalitate",
    "egalități": "egalitate",
    "egalității": "egalitate",
    "egalitățile": "egalitate",
    "egalităților": "egalitate",
    "egaliză": "egaliza",
    "egalizai": "egaliza",
    "egalizam": "egaliza",
    "egalizăm": "egaliza",
    "egalizând": "egaliza",
    "egalizându": "egaliza",
    "egalizară": "egaliza",
    "egalizarăm": "egaliza",
    "egalizarăți": "egaliza",
    "egalizase": "egaliza",
    "egalizasem": "egaliza",
    "egalizaseră": "egaliza",
    "egalizaserăm": "egaliza",
    "egalizaserăți": "egaliza",
    "egalizaseși": "egaliza",
    "egalizași": "egaliza",
    "egalizat": "egaliza",
    "egalizați": "egaliza",
    "egalizatu": "egaliza",
    "egalizau": "egaliza",
    "egalizează": "egaliza",
    "egalizez": "egaliza",
    "egalizeze": "egaliza",
    "egalizezi": "egaliza",
    "neegalizând": "egaliza",
    "neegalizându": "egaliza",
    "nemaiegalizând": "egaliza",
    "nemaiegalizându": "egaliza",
    "egalizarea": "egalizare",
    "egalizareo": "egalizare",
    "egalizări": "egalizare",
    "egalizării": "egalizare",
    "egalizările": "egalizare",
    "egalizărilor": "egalizare",
    "egalizată": "egalizat",
    "egalizate": "egalizat",
    "egalizați": "egalizat",
    "egalizatoare": "egalizator",
    "egalizatoarea": "egalizator",
    "egalizatoarei": "egalizator",
    "egalizatoarele": "egalizator",
    "egalizatoarelor": "egalizator",
    "egalizatoareo": "egalizator",
    "egalizatori": "egalizator",
    "egalizatorii": "egalizator",
    "egalizatorilor": "egalizator",
    "egalizatorul": "egalizator",
    "egalizatorule": "egalizator",
    "egalizatorului": "egalizator",
    "eghileți": "eghilet",
    "eghileții": "eghilet",
    "eghileților": "eghilet",
    "eghiletul": "eghilet",
    "eghiletule": "eghilet",
    "eghiletului": "eghilet",
    "egida": "egidă",
    "egide": "egidă",
    "egidei": "egidă",
    "egidele": "egidă",
    "egidelor": "egidă",
    "egido": "egidă",
    "Egiptul": "Egipt",
    "Egiptului": "Egipt",
    "egipteana": "egiptean",
    "egipteană": "egiptean",
    "egipteanca": "egiptean",
    "egipteancă": "egiptean",
    "egipteanul": "egiptean",
    "egipteanului": "egiptean",
    "egiptence": "egiptean",
    "egiptencei": "egiptean",
    "egiptencele": "egiptean",
    "egiptencelor": "egiptean",
    "egiptene": "egiptean",
    "egiptenei": "egiptean",
    "egiptenele": "egiptean",
    "egiptenelor": "egiptean",
    "egipteni": "egiptean",
    "egiptenii": "egiptean",
    "egiptenilor": "egiptean",
    "egipteana": "egipteană",
    "egiptene": "egipteană",
    "egiptenei": "egipteană",
    "egiptenele": "egipteană",
    "egiptenelor": "egipteană",
    "egipteanca": "egipteancă",
    "egiptence": "egipteancă",
    "egiptencei": "egipteancă",
    "egiptencele": "egipteancă",
    "egiptencelor": "egipteancă",
    "egiptologi": "egiptolog",
    "egiptologii": "egiptolog",
    "egiptologilor": "egiptolog",
    "egiptologul": "egiptolog",
    "egiptologule": "egiptolog",
    "egiptologului": "egiptolog",
    "egocentrismul": "egocentrism",
    "egocentrismule": "egocentrism",
    "egocentrismului": "egocentrism",
    "egocentrista": "egocentrist",
    "egocentristă": "egocentrist",
    "egocentriste": "egocentrist",
    "egocentristei": "egocentrist",
    "egocentristele": "egocentrist",
    "egocentristelor": "egocentrist",
    "egocentriști": "egocentrist",
    "egocentriștii": "egocentrist",
    "egocentriștilor": "egocentrist",
    "egocentristo": "egocentrist",
    "egocentristul": "egocentrist",
    "egocentristule": "egocentrist",
    "egocentristului": "egocentrist",
    "egoismul": "egoism",
    "egoismule": "egoism",
    "egoismului": "egoism",
    "egoista": "egoist",
    "egoistă": "egoist",
    "egoiste": "egoist",
    "egoistei": "egoist",
    "egoistele": "egoist",
    "egoistelor": "egoist",
    "egoiști": "egoist",
    "egoiștii": "egoist",
    "egoiștilor": "egoist",
    "egoisto": "egoist",
    "egoistul": "egoist",
    "egoistule": "egoist",
    "egoistului": "egoist",
    "egrenă": "egrena",
    "egrenai": "egrena",
    "egrenam": "egrena",
    "egrenăm": "egrena",
    "egrenând": "egrena",
    "egrenându": "egrena",
    "egrenară": "egrena",
    "egrenarăm": "egrena",
    "egrenarăți": "egrena",
    "egrenase": "egrena",
    "egrenasem": "egrena",
    "egrenaseră": "egrena",
    "egrenaserăm": "egrena",
    "egrenaserăți": "egrena",
    "egrenaseși": "egrena",
    "egrenași": "egrena",
    "egrenat": "egrena",
    "egrenați": "egrena",
    "egrenatu": "egrena",
    "egrenau": "egrena",
    "egrenează": "egrena",
    "egrenez": "egrena",
    "egreneze": "egrena",
    "egrenezi": "egrena",
    "neegrenând": "egrena",
    "neegrenându": "egrena",
    "nemaiegrenând": "egrena",
    "nemaiegrenându": "egrena",
    "egrenarea": "egrenare",
    "egrenareo": "egrenare",
    "egrenări": "egrenare",
    "egrenării": "egrenare",
    "egrenările": "egrenare",
    "egrenărilor": "egrenare",
    "egrenată": "egrenat",
    "egrenate": "egrenat",
    "egrenați": "egrenat",
    "egreta": "egretă",
    "egrete": "egretă",
    "egretei": "egretă",
    "egretele": "egretă",
    "egretelor": "egretă",
    "egreto": "egretă",
    "egumeni": "egumen",
    "egumenii": "egumen",
    "egumenilor": "egumen",
    "egumenul": "egumen",
    "egumenule": "egumen",
    "egumenului": "egumen",
    "egumena": "egumenă",
    "egumene": "egumenă",
    "egumenei": "egumenă",
    "egumenele": "egumenă",
    "egumenelor": "egumenă",
    "egumeno": "egumenă",
    "egumenea": "egumeni",
    "egumeneai": "egumeni",
    "egumeneam": "egumeni",
    "egumenească": "egumeni",
    "egumeneați": "egumeni",
    "egumeneau": "egumeni",
    "egumenesc": "egumeni",
    "egumenește": "egumeni",
    "egumenești": "egumeni",
    "egumenii": "egumeni",
    "egumenim": "egumeni",
    "egumenind": "egumeni",
    "egumenindu": "egumeni",
    "egumeniră": "egumeni",
    "egumenirăm": "egumeni",
    "egumenirăți": "egumeni",
    "egumenise": "egumeni",
    "egumenisem": "egumeni",
    "egumeniseră": "egumeni",
    "egumeniserăm": "egumeni",
    "egumeniserăți": "egumeni",
    "egumeniseși": "egumeni",
    "egumeniși": "egumeni",
    "egumenit": "egumeni",
    "egumeniți": "egumeni",
    "egumenitu": "egumeni",
    "neegumenind": "egumeni",
    "neegumenindu": "egumeni",
    "nemaiegumenind": "egumeni",
    "nemaiegumenindu": "egumeni",
    "egumenită": "egumenit",
    "egumenite": "egumenit",
    "egumeniți": "egumenit",
    "e.a.": "eiusdem_anni",
    "e.m.": "eiusdem_mensis",
    "ejaculă": "ejacula",
    "ejaculai": "ejacula",
    "ejaculam": "ejacula",
    "ejaculăm": "ejacula",
    "ejaculând": "ejacula",
    "ejaculându": "ejacula",
    "ejaculară": "ejacula",
    "ejacularăm": "ejacula",
    "ejacularăți": "ejacula",
    "ejaculase": "ejacula",
    "ejaculasem": "ejacula",
    "ejaculaseră": "ejacula",
    "ejaculaserăm": "ejacula",
    "ejaculaserăți": "ejacula",
    "ejaculaseși": "ejacula",
    "ejaculași": "ejacula",
    "ejaculat": "ejacula",
    "ejaculați": "ejacula",
    "ejaculatu": "ejacula",
    "ejaculau": "ejacula",
    "ejaculează": "ejacula",
    "ejaculez": "ejacula",
    "ejaculeze": "ejacula",
    "ejaculezi": "ejacula",
    "ejaculată": "ejaculat",
    "ejaculate": "ejaculat",
    "ejaculați": "ejaculat",
    "ejectoare": "ejector",
    "ejectoarele": "ejector",
    "ejectoarelor": "ejector",
    "ejectorul": "ejector",
    "ejectorule": "ejector",
    "ejectorului": "ejector",
    "ea": "el",
    "ei": "el",
    "ele": "el",
    "i": "el",
    "i-": "el",
    "iel": "el",
    "îi": "el",
    "îl": "el",
    "l": "el",
    "l-": "el",
    "le": "el",
    "le-": "el",
    "li": "el",
    "li-": "el",
    "lor": "el",
    "lui": "el",
    "o": "el",
    "o-": "el",
    "elaboră": "elabora",
    "elaborai": "elabora",
    "elaboram": "elabora",
    "elaborăm": "elabora",
    "elaborând": "elabora",
    "elaborându": "elabora",
    "elaborară": "elabora",
    "elaborarăm": "elabora",
    "elaborarăți": "elabora",
    "elaborase": "elabora",
    "elaborasem": "elabora",
    "elaboraseră": "elabora",
    "elaboraserăm": "elabora",
    "elaboraserăți": "elabora",
    "elaboraseși": "elabora",
    "elaborași": "elabora",
    "elaborat": "elabora",
    "elaborați": "elabora",
    "elaboratu": "elabora",
    "elaborau": "elabora",
    "elaborează": "elabora",
    "elaborez": "elabora",
    "elaboreze": "elabora",
    "elaborezi": "elabora",
    "neelaborând": "elabora",
    "neelaborându": "elabora",
    "nemaielaborând": "elabora",
    "nemaielaborându": "elabora",
    "elaborarea": "elaborare",
    "elaborareo": "elaborare",
    "elaborări": "elaborare",
    "elaborării": "elaborare",
    "elaborările": "elaborare",
    "elaborărilor": "elaborare",
    "elaborată": "elaborat",
    "elaborate": "elaborat",
    "elaborați": "elaborat",
    "elani": "elan",
    "elanii": "elan",
    "elanilor": "elan",
    "elanul": "elan",
    "elanule": "elan",
    "elanului": "elan",
    "elanuri": "elan",
    "elanurile": "elan",
    "elanurilor": "elan",
    "elastica": "elastic",
    "elastică": "elastic",
    "elastice": "elastic",
    "elasticei": "elastic",
    "elasticele": "elastic",
    "elasticelor": "elastic",
    "elastici": "elastic",
    "elasticii": "elastic",
    "elasticilor": "elastic",
    "elastico": "elastic",
    "elasticul": "elastic",
    "elasticule": "elastic",
    "elasticului": "elastic",
    "iele": "ele",
    "elecția": "elecție",
    "elecției": "elecție",
    "elecții": "elecție",
    "elecțiile": "elecție",
    "elecțiilor": "elecție",
    "elecțio": "elecție",
    "electiva": "electiv",
    "electivă": "electiv",
    "elective": "electiv",
    "electivei": "electiv",
    "electivele": "electiv",
    "electivelor": "electiv",
    "electivi": "electiv",
    "electivii": "electiv",
    "electivilor": "electiv",
    "electivo": "electiv",
    "electivul": "electiv",
    "electivule": "electiv",
    "electivului": "electiv",
    "electoarea": "electoare",
    "electoarei": "electoare",
    "electoarele": "electoare",
    "electoarelor": "electoare",
    "electoareo": "electoare",
    "electori": "elector",
    "electorii": "elector",
    "electorilor": "elector",
    "electorul": "elector",
    "electorule": "elector",
    "electorului": "elector",
    "electorala": "electoral",
    "electorală": "electoral",
    "electorale": "electoral",
    "electoralei": "electoral",
    "electoralele": "electoral",
    "electoralelor": "electoral",
    "electorali": "electoral",
    "electoralii": "electoral",
    "electoralilor": "electoral",
    "electoralo": "electoral",
    "electoralul": "electoral",
    "electoralule": "electoral",
    "electoralului": "electoral",
    "electorate": "electorat",
    "electoratele": "electorat",
    "electoratelor": "electorat",
    "electoratul": "electorat",
    "electoratule": "electorat",
    "electoratului": "electorat",
    "electrica": "electric",
    "electrică": "electric",
    "electrice": "electric",
    "electricei": "electric",
    "electricele": "electric",
    "electricelor": "electric",
    "electrici": "electric",
    "electricii": "electric",
    "electricilor": "electric",
    "electrico": "electric",
    "electricul": "electric",
    "electricule": "electric",
    "electricului": "electric",
    "electricianul": "electrician",
    "electricianule": "electrician",
    "electricianului": "electrician",
    "electricieni": "electrician",
    "electricienii": "electrician",
    "electricienilor": "electrician",
    "electriciana": "electriciană",
    "electriciano": "electriciană",
    "electriciene": "electriciană",
    "electricienei": "electriciană",
    "electricienele": "electriciană",
    "electricienelor": "electriciană",
    "electr.": "electricitate",
    "electricitatea": "electricitate",
    "electricitateo": "electricitate",
    "electricități": "electricitate",
    "electricității": "electricitate",
    "electricitățile": "electricitate",
    "electricităților": "electricitate",
    "electrific": "electrifica",
    "electrifică": "electrifica",
    "electrificai": "electrifica",
    "electrificam": "electrifica",
    "electrificăm": "electrifica",
    "electrificând": "electrifica",
    "electrificându": "electrifica",
    "electrificară": "electrifica",
    "electrificarăm": "electrifica",
    "electrificarăți": "electrifica",
    "electrificase": "electrifica",
    "electrificasem": "electrifica",
    "electrificaseră": "electrifica",
    "electrificaserăm": "electrifica",
    "electrificaserăți": "electrifica",
    "electrificaseși": "electrifica",
    "electrificași": "electrifica",
    "electrificat": "electrifica",
    "electrificați": "electrifica",
    "electrificatu": "electrifica",
    "electrificau": "electrifica",
    "electrifice": "electrifica",
    "electrifici": "electrifica",
    "neelectrificând": "electrifica",
    "neelectrificându": "electrifica",
    "nemaielectrificând": "electrifica",
    "nemaielectrificându": "electrifica",
    "electrificarea": "electrificare",
    "electrificareo": "electrificare",
    "electrificări": "electrificare",
    "electrificării": "electrificare",
    "electrificările": "electrificare",
    "electrificărilor": "electrificare",
    "electrificată": "electrificat",
    "electrificate": "electrificat",
    "electrificați": "electrificat",
    "electriză": "electriza",
    "electrizai": "electriza",
    "electrizam": "electriza",
    "electrizăm": "electriza",
    "electrizând": "electriza",
    "electrizându": "electriza",
    "electrizară": "electriza",
    "electrizarăm": "electriza",
    "electrizarăți": "electriza",
    "electrizase": "electriza",
    "electrizasem": "electriza",
    "electrizaseră": "electriza",
    "electrizaserăm": "electriza",
    "electrizaserăți": "electriza",
    "electrizaseși": "electriza",
    "electrizași": "electriza",
    "electrizat": "electriza",
    "electrizați": "electriza",
    "electrizatu": "electriza",
    "electrizau": "electriza",
    "electrizează": "electriza",
    "electrizez": "electriza",
    "electrizeze": "electriza",
    "electrizezi": "electriza",
    "neelectrizând": "electriza",
    "neelectrizându": "electriza",
    "nemaielectrizând": "electriza",
    "nemaielectrizându": "electriza",
    "electrizanta": "electrizant",
    "electrizantă": "electrizant",
    "electrizante": "electrizant",
    "electrizantei": "electrizant",
    "electrizantele": "electrizant",
    "electrizantelor": "electrizant",
    "electrizanți": "electrizant",
    "electrizanții": "electrizant",
    "electrizanților": "electrizant",
    "electrizanto": "electrizant",
    "electrizantul": "electrizant",
    "electrizantule": "electrizant",
    "electrizantului": "electrizant",
    "electrizarea": "electrizare",
    "electrizareo": "electrizare",
    "electrizări": "electrizare",
    "electrizării": "electrizare",
    "electrizările": "electrizare",
    "electrizărilor": "electrizare",
    "electrizata": "electrizat",
    "electrizată": "electrizat",
    "electrizate": "electrizat",
    "electrizatei": "electrizat",
    "electrizatele": "electrizat",
    "electrizatelor": "electrizat",
    "electrizați": "electrizat",
    "electrizații": "electrizat",
    "electrizaților": "electrizat",
    "electrizato": "electrizat",
    "electrizatul": "electrizat",
    "electrizatule": "electrizat",
    "electrizatului": "electrizat",
    "electroanaliza": "electroanaliză",
    "electroanalize": "electroanaliză",
    "electroanalizei": "electroanaliză",
    "electroanalizele": "electroanaliză",
    "electroanalizelor": "electroanaliză",
    "electroanalizo": "electroanaliză",
    "electrocardiografica": "electrocardiografic",
    "electrocardiografică": "electrocardiografic",
    "electrocardiografice": "electrocardiografic",
    "electrocardiograficei": "electrocardiografic",
    "electrocardiograficele": "electrocardiografic",
    "electrocardiograficelor": "electrocardiografic",
    "electrocardiografici": "electrocardiografic",
    "electrocardiograficii": "electrocardiografic",
    "electrocardiograficilor": "electrocardiografic",
    "electrocardiografico": "electrocardiografic",
    "electrocardiograficul": "electrocardiografic",
    "electrocardiograficule": "electrocardiografic",
    "electrocardiograficului": "electrocardiografic",
    "electrocardiografia": "electrocardiografie",
    "electrocardiografiei": "electrocardiografie",
    "electrocardiografii": "electrocardiografie",
    "electrocardiografiile": "electrocardiografie",
    "electrocardiografiilor": "electrocardiografie",
    "electrocardiografio": "electrocardiografie",
    "electrocardiograma": "electrocardiogramă",
    "electrocardiograme": "electrocardiogramă",
    "electrocardiogramei": "electrocardiogramă",
    "electrocardiogramele": "electrocardiogramă",
    "electrocardiogramelor": "electrocardiogramă",
    "electrocardiogramo": "electrocardiogramă",
    "electrocasnica": "electrocasnic",
    "electrocasnică": "electrocasnic",
    "electrocasnice": "electrocasnic",
    "electrocasnicei": "electrocasnic",
    "electrocasnicele": "electrocasnic",
    "electrocasnicelor": "electrocasnic",
    "electrocasnici": "electrocasnic",
    "electrocasnicii": "electrocasnic",
    "electrocasnicilor": "electrocasnic",
    "electrocasnico": "electrocasnic",
    "electrocasnicul": "electrocasnic",
    "electrocasnicule": "electrocasnic",
    "electrocasnicului": "electrocasnic",
    "electrocautere": "electrocauter",
    "electrocauterele": "electrocauter",
    "electrocauterelor": "electrocauter",
    "electrocauterul": "electrocauter",
    "electrocauterule": "electrocauter",
    "electrocauterului": "electrocauter",
    "electrochimica": "electrochimic",
    "electrochimică": "electrochimic",
    "electrochimice": "electrochimic",
    "electrochimicei": "electrochimic",
    "electrochimicele": "electrochimic",
    "electrochimicelor": "electrochimic",
    "electrochimici": "electrochimic",
    "electrochimicii": "electrochimic",
    "electrochimicilor": "electrochimic",
    "electrochimico": "electrochimic",
    "electrochimicul": "electrochimic",
    "electrochimicule": "electrochimic",
    "electrochimicului": "electrochimic",
    "electrochimia": "electrochimie",
    "electrochimiei": "electrochimie",
    "electrochimii": "electrochimie",
    "electrochimio": "electrochimie",
    "electrocută": "electrocuta",
    "electrocutai": "electrocuta",
    "electrocutam": "electrocuta",
    "electrocutăm": "electrocuta",
    "electrocutând": "electrocuta",
    "electrocutându": "electrocuta",
    "electrocutară": "electrocuta",
    "electrocutarăm": "electrocuta",
    "electrocutarăți": "electrocuta",
    "electrocutase": "electrocuta",
    "electrocutasem": "electrocuta",
    "electrocutaseră": "electrocuta",
    "electrocutaserăm": "electrocuta",
    "electrocutaserăți": "electrocuta",
    "electrocutaseși": "electrocuta",
    "electrocutași": "electrocuta",
    "electrocutat": "electrocuta",
    "electrocutați": "electrocuta",
    "electrocutatu": "electrocuta",
    "electrocutau": "electrocuta",
    "electrocutează": "electrocuta",
    "electrocutez": "electrocuta",
    "electrocuteze": "electrocuta",
    "electrocutezi": "electrocuta",
    "neelectrocutând": "electrocuta",
    "neelectrocutându": "electrocuta",
    "nemaielectrocutând": "electrocuta",
    "nemaielectrocutându": "electrocuta",
    "electrocutarea": "electrocutare",
    "electrocutareo": "electrocutare",
    "electrocutări": "electrocutare",
    "electrocutării": "electrocutare",
    "electrocutările": "electrocutare",
    "electrocutărilor": "electrocutare",
    "electrocutată": "electrocutat",
    "electrocutate": "electrocutat",
    "electrocutați": "electrocutat",
    "electrodul": "electrod",
    "electrodule": "electrod",
    "electrodului": "electrod",
    "electrozi": "electrod",
    "electrozii": "electrod",
    "electrozilor": "electrod",
    "electrodinamul": "electrodinam",
    "electrodinamule": "electrodinam",
    "electrodinamului": "electrodinam",
    "electrodinamuri": "electrodinam",
    "electrodinamurile": "electrodinam",
    "electrodinamurilor": "electrodinam",
    "electrodinamica": "electrodinamică",
    "electrodinamici": "electrodinamică",
    "electrodinamicii": "electrodinamică",
    "electrodinamicile": "electrodinamică",
    "electrodinamicilor": "electrodinamică",
    "electrodinamico": "electrodinamică",
    "electrogena": "electrogen",
    "electrogenă": "electrogen",
    "electrogene": "electrogen",
    "electrogenei": "electrogen",
    "electrogenele": "electrogen",
    "electrogenelor": "electrogen",
    "electrogeni": "electrogen",
    "electrogenii": "electrogen",
    "electrogenilor": "electrogen",
    "electrogeno": "electrogen",
    "electrogenul": "electrogen",
    "electrogenule": "electrogen",
    "electrogenului": "electrogen",
    "electroliți": "electrolit",
    "electroliții": "electrolit",
    "electroliților": "electrolit",
    "electrolitul": "electrolit",
    "electrolitule": "electrolit",
    "electrolitului": "electrolit",
    "electrolitica": "electrolitic",
    "electrolitică": "electrolitic",
    "electrolitice": "electrolitic",
    "electroliticei": "electrolitic",
    "electroliticele": "electrolitic",
    "electroliticelor": "electrolitic",
    "electrolitici": "electrolitic",
    "electroliticii": "electrolitic",
    "electroliticilor": "electrolitic",
    "electrolitico": "electrolitic",
    "electroliticul": "electrolitic",
    "electroliticule": "electrolitic",
    "electroliticului": "electrolitic",
    "electroliza": "electroliză",
    "electrolize": "electroliză",
    "electrolizei": "electroliză",
    "electrolizele": "electroliză",
    "electrolizelor": "electroliză",
    "electrolizo": "electroliză",
    "electrolizoare": "electrolizor",
    "electrolizoarele": "electrolizor",
    "electrolizoarelor": "electrolizor",
    "electrolizorul": "electrolizor",
    "electrolizorule": "electrolizor",
    "electrolizorului": "electrolizor",
    "electromagneți": "electromagnet",
    "electromagneții": "electromagnet",
    "electromagneților": "electromagnet",
    "electromagnetul": "electromagnet",
    "electromagnetule": "electromagnet",
    "electromagnetului": "electromagnet",
    "electromagnetica": "electromagnetic",
    "electromagnetică": "electromagnetic",
    "electromagnetice": "electromagnetic",
    "electromagneticei": "electromagnetic",
    "electromagneticele": "electromagnetic",
    "electromagneticelor": "electromagnetic",
    "electromagnetici": "electromagnetic",
    "electromagneticii": "electromagnetic",
    "electromagneticilor": "electromagnetic",
    "electromagnetico": "electromagnetic",
    "electromagneticul": "electromagnetic",
    "electromagneticule": "electromagnetic",
    "electromagneticului": "electromagnetic",
    "electromecanica": "electromecanică",
    "electromecanici": "electromecanică",
    "electromecanicii": "electromecanică",
    "electromecanico": "electromecanică",
    "electromotoare": "electromotor",
    "electromotoarele": "electromotor",
    "electromotoarelor": "electromotor",
    "electromotorul": "electromotor",
    "electromotorule": "electromotor",
    "electromotorului": "electromotor",
    "electroni": "electron",
    "electronii": "electron",
    "electronilor": "electron",
    "electronul": "electron",
    "electronule": "electron",
    "electronului": "electron",
    "electronica": "electronic",
    "electronică": "electronic",
    "electronice": "electronic",
    "electronicei": "electronic",
    "electronicele": "electronic",
    "electronicelor": "electronic",
    "electronici": "electronic",
    "electronicii": "electronic",
    "electronicilor": "electronic",
    "electronico": "electronic",
    "electronicul": "electronic",
    "electronicule": "electronic",
    "electronicului": "electronic",
    "electroscoape": "electroscop",
    "electroscoapele": "electroscop",
    "electroscoapelor": "electroscop",
    "electroscopul": "electroscop",
    "electroscopule": "electroscop",
    "electroscopului": "electroscop",
    "electrostatica": "electrostatică",
    "electrostatici": "electrostatică",
    "electrostaticii": "electrostatică",
    "electrostatico": "electrostatică",
    "electrotehnica": "electrotehnic",
    "electrotehnică": "electrotehnic",
    "electrotehnice": "electrotehnic",
    "electrotehnicei": "electrotehnic",
    "electrotehnicele": "electrotehnic",
    "electrotehnicelor": "electrotehnic",
    "electrotehnici": "electrotehnic",
    "electrotehnicii": "electrotehnic",
    "electrotehnicilor": "electrotehnic",
    "electrotehnico": "electrotehnic",
    "electrotehnicul": "electrotehnic",
    "electrotehnicule": "electrotehnic",
    "electrotehnicului": "electrotehnic",
    "el.tehn.": "electrotehnică",
    "electrotehnica": "electrotehnică",
    "electrotehnici": "electrotehnică",
    "electrotehnicii": "electrotehnică",
    "electrotehnico": "electrotehnică",
    "electroterapia": "electroterapie",
    "electroterapiei": "electroterapie",
    "electroterapii": "electroterapie",
    "electroterapio": "electroterapie",
    "electrovolți": "electrovolt",
    "electrovolții": "electrovolt",
    "electrovolților": "electrovolt",
    "electrovoltul": "electrovolt",
    "electrovoltule": "electrovolt",
    "electrovoltului": "electrovolt",
    "ev.": "electrovolt",
    "elefanți": "elefant",
    "elefanții": "elefant",
    "elefanților": "elefant",
    "elefantul": "elefant",
    "elefantule": "elefant",
    "elefantului": "elefant",
    "elefantiazisul": "elefantiazis",
    "elefantiazisule": "elefantiazis",
    "elefantiazisului": "elefantiazis",
    "eleganta": "elegant",
    "elegantă": "elegant",
    "elegante": "elegant",
    "elegantei": "elegant",
    "elegantele": "elegant",
    "elegantelor": "elegant",
    "eleganți": "elegant",
    "eleganții": "elegant",
    "eleganților": "elegant",
    "eleganto": "elegant",
    "elegantul": "elegant",
    "elegantule": "elegant",
    "elegantului": "elegant",
    "eleganța": "eleganță",
    "eleganțe": "eleganță",
    "eleganței": "eleganță",
    "eleganțele": "eleganță",
    "eleganțelor": "eleganță",
    "eleganțo": "eleganță",
    "elegiaca": "elegiac",
    "elegiacă": "elegiac",
    "elegiace": "elegiac",
    "elegiacei": "elegiac",
    "elegiacele": "elegiac",
    "elegiacelor": "elegiac",
    "elegiaci": "elegiac",
    "elegiacii": "elegiac",
    "elegiacilor": "elegiac",
    "elegiaco": "elegiac",
    "elegiacul": "elegiac",
    "elegiacule": "elegiac",
    "elegiacului": "elegiac",
    "elegia": "elegie",
    "elegiei": "elegie",
    "elegii": "elegie",
    "elegiile": "elegie",
    "elegiilor": "elegie",
    "elegio": "elegie",
    "elemente": "element",
    "elementele": "element",
    "elementelor": "element",
    "elementul": "element",
    "elementule": "element",
    "elementului": "element",
    "elementara": "elementar",
    "elementară": "elementar",
    "elementare": "elementar",
    "elementarei": "elementar",
    "elementarele": "elementar",
    "elementarelor": "elementar",
    "elementari": "elementar",
    "elementarii": "elementar",
    "elementarilor": "elementar",
    "elementaro": "elementar",
    "elementarul": "elementar",
    "elementarule": "elementar",
    "elementarului": "elementar",
    "elena": "elen",
    "elenă": "elen",
    "elene": "elen",
    "elenei": "elen",
    "elenele": "elen",
    "elenelor": "elen",
    "eleni": "elen",
    "elenii": "elen",
    "elenilor": "elen",
    "eleno": "elen",
    "elenul": "elen",
    "elenule": "elen",
    "elenului": "elen",
    "Elenei": "Elena",
    "elena": "elenă",
    "elene": "elenă",
    "elenei": "elenă",
    "elenele": "elenă",
    "elenelor": "elenă",
    "eleno": "elenă",
    "elenistica": "elenistic",
    "elenistică": "elenistic",
    "elenistice": "elenistic",
    "elenisticei": "elenistic",
    "elenisticele": "elenistic",
    "elenisticelor": "elenistic",
    "elenistici": "elenistic",
    "elenisticii": "elenistic",
    "elenisticilor": "elenistic",
    "elenistico": "elenistic",
    "elenisticul": "elenistic",
    "elenisticule": "elenistic",
    "elenisticului": "elenistic",
    "Eleonorei": "Eleonora",
    "eleștee": "eleșteu",
    "eleșteele": "eleșteu",
    "eleșteelor": "eleșteu",
    "eleșteul": "eleșteu",
    "eleșteule": "eleșteu",
    "eleșteului": "eleșteu",
    "elevi": "elev",
    "elevii": "elev",
    "elevilor": "elev",
    "elevul": "elev",
    "elevule": "elev",
    "elevului": "elev",
    "eleva": "elevă",
    "eleve": "elevă",
    "elevei": "elevă",
    "elevele": "elevă",
    "elevelor": "elevă",
    "elevo": "elevă",
    "elevata": "elevat",
    "elevată": "elevat",
    "elevate": "elevat",
    "elevatei": "elevat",
    "elevatele": "elevat",
    "elevatelor": "elevat",
    "elevați": "elevat",
    "elevații": "elevat",
    "elevaților": "elevat",
    "elevato": "elevat",
    "elevatul": "elevat",
    "elevatule": "elevat",
    "elevatului": "elevat",
    "elevația": "elevație",
    "elevației": "elevație",
    "elevații": "elevație",
    "elevațiile": "elevație",
    "elevațiilor": "elevație",
    "elevațio": "elevație",
    "elevatoare": "elevator",
    "elevatoarele": "elevator",
    "elevatoarelor": "elevator",
    "elevatorul": "elevator",
    "elevatorule": "elevator",
    "elevatorului": "elevator",
    "eliberă": "elibera",
    "eliberai": "elibera",
    "eliberam": "elibera",
    "eliberăm": "elibera",
    "eliberând": "elibera",
    "eliberându": "elibera",
    "eliberară": "elibera",
    "eliberarăm": "elibera",
    "eliberarăți": "elibera",
    "eliberase": "elibera",
    "eliberasem": "elibera",
    "eliberaseră": "elibera",
    "eliberaserăm": "elibera",
    "eliberaserăți": "elibera",
    "eliberaseși": "elibera",
    "eliberași": "elibera",
    "eliberat": "elibera",
    "eliberați": "elibera",
    "eliberatu": "elibera",
    "eliberau": "elibera",
    "eliberează": "elibera",
    "eliberez": "elibera",
    "elibereze": "elibera",
    "eliberezi": "elibera",
    "neeliberând": "elibera",
    "neeliberându": "elibera",
    "nemaieliberând": "elibera",
    "nemaieliberându": "elibera",
    "eliberarea": "eliberare",
    "eliberareo": "eliberare",
    "eliberări": "eliberare",
    "eliberării": "eliberare",
    "eliberările": "eliberare",
    "eliberărilor": "eliberare",
    "eliberată": "eliberat",
    "eliberate": "eliberat",
    "eliberatei": "eliberat",
    "eliberatele": "eliberat",
    "eliberatelor": "eliberat",
    "eliberați": "eliberat",
    "eliberații": "eliberat",
    "eliberaților": "eliberat",
    "eliberato": "eliberat",
    "eliberatul": "eliberat",
    "eliberatule": "eliberat",
    "eliberatului": "eliberat",
    "eliberatoarea": "eliberatoare",
    "eliberatoarei": "eliberatoare",
    "eliberatoarele": "eliberatoare",
    "eliberatoarelor": "eliberatoare",
    "eliberatoareo": "eliberatoare",
    "eliberatoare": "eliberator",
    "eliberatoarea": "eliberator",
    "eliberatoarei": "eliberator",
    "eliberatoarele": "eliberator",
    "eliberatoarelor": "eliberator",
    "eliberatoareo": "eliberator",
    "eliberatori": "eliberator",
    "eliberatorii": "eliberator",
    "eliberatorilor": "eliberator",
    "eliberatorul": "eliberator",
    "eliberatorule": "eliberator",
    "eliberatorului": "eliberator",
    "elicea": "elice",
    "elicei": "elice",
    "elicele": "elice",
    "elicelor": "elice",
    "eliceo": "elice",
    "elicoidala": "elicoidal",
    "elicoidală": "elicoidal",
    "elicoidale": "elicoidal",
    "elicoidalei": "elicoidal",
    "elicoidalele": "elicoidal",
    "elicoidalelor": "elicoidal",
    "elicoidali": "elicoidal",
    "elicoidalii": "elicoidal",
    "elicoidalilor": "elicoidal",
    "elicoidalo": "elicoidal",
    "elicoidalul": "elicoidal",
    "elicoidalule": "elicoidal",
    "elicoidalului": "elicoidal",
    "elicoptere": "elicopter",
    "elicopterele": "elicopter",
    "elicopterelor": "elicopter",
    "elicopterul": "elicopter",
    "elicopterule": "elicopter",
    "elicopterului": "elicopter",
    "elidă": "elida",
    "elidai": "elida",
    "elidam": "elida",
    "elidăm": "elida",
    "elidând": "elida",
    "elidându": "elida",
    "elidară": "elida",
    "elidarăm": "elida",
    "elidarăți": "elida",
    "elidase": "elida",
    "elidasem": "elida",
    "elidaseră": "elida",
    "elidaserăm": "elida",
    "elidaserăți": "elida",
    "elidaseși": "elida",
    "elidași": "elida",
    "elidat": "elida",
    "elidați": "elida",
    "elidatu": "elida",
    "elidau": "elida",
    "elidează": "elida",
    "elidez": "elida",
    "elideze": "elida",
    "elidezi": "elida",
    "neelidând": "elida",
    "neelidându": "elida",
    "nemaielidând": "elida",
    "nemaielidându": "elida",
    "elidată": "elidat",
    "elidate": "elidat",
    "elidați": "elidat",
    "eligibila": "eligibil",
    "eligibilă": "eligibil",
    "eligibile": "eligibil",
    "eligibilei": "eligibil",
    "eligibilele": "eligibil",
    "eligibilelor": "eligibil",
    "eligibili": "eligibil",
    "eligibilii": "eligibil",
    "eligibililor": "eligibil",
    "eligibilo": "eligibil",
    "eligibilul": "eligibil",
    "eligibilule": "eligibil",
    "eligibilului": "eligibil",
    "elimin": "elimina",
    "elimină": "elimina",
    "eliminai": "elimina",
    "eliminam": "elimina",
    "eliminăm": "elimina",
    "eliminând": "elimina",
    "eliminându": "elimina",
    "eliminară": "elimina",
    "eliminarăm": "elimina",
    "eliminarăți": "elimina",
    "eliminase": "elimina",
    "eliminasem": "elimina",
    "eliminaseră": "elimina",
    "eliminaserăm": "elimina",
    "eliminaserăți": "elimina",
    "eliminaseși": "elimina",
    "eliminași": "elimina",
    "eliminat": "elimina",
    "eliminați": "elimina",
    "eliminatu": "elimina",
    "eliminau": "elimina",
    "elimine": "elimina",
    "elimini": "elimina",
    "neeliminând": "elimina",
    "neeliminându": "elimina",
    "nemaieliminând": "elimina",
    "nemaieliminându": "elimina",
    "eliminarea": "eliminare",
    "eliminareo": "eliminare",
    "eliminări": "eliminare",
    "eliminării": "eliminare",
    "eliminările": "eliminare",
    "eliminărilor": "eliminare",
    "eliminată": "eliminat",
    "eliminate": "eliminat",
    "eliminați": "eliminat",
    "eliminatoria": "eliminatoriu",
    "eliminatorie": "eliminatoriu",
    "eliminatoriei": "eliminatoriu",
    "eliminatorii": "eliminatoriu",
    "eliminatoriii": "eliminatoriu",
    "eliminatoriile": "eliminatoriu",
    "eliminatoriilor": "eliminatoriu",
    "eliminatorio": "eliminatoriu",
    "eliminatoriul": "eliminatoriu",
    "eliminatoriule": "eliminatoriu",
    "eliminatoriului": "eliminatoriu",
    "elina": "elin",
    "elină": "elin",
    "eline": "elin",
    "elinei": "elin",
    "elinele": "elin",
    "elinelor": "elin",
    "elini": "elin",
    "elinii": "elin",
    "elinilor": "elin",
    "elino": "elin",
    "elinul": "elin",
    "elinule": "elin",
    "elinului": "elin",
    "elipsa": "elipsă",
    "elipse": "elipsă",
    "elipsei": "elipsă",
    "elipsele": "elipsă",
    "elipselor": "elipsă",
    "elipso": "elipsă",
    "elipsoide": "elipsoid",
    "elipsoidele": "elipsoid",
    "elipsoidelor": "elipsoid",
    "elipsoidul": "elipsoid",
    "elipsoidule": "elipsoid",
    "elipsoidului": "elipsoid",
    "eliptica": "eliptic",
    "eliptică": "eliptic",
    "eliptice": "eliptic",
    "elipticei": "eliptic",
    "elipticele": "eliptic",
    "elipticelor": "eliptic",
    "eliptici": "eliptic",
    "elipticii": "eliptic",
    "elipticilor": "eliptic",
    "eliptico": "eliptic",
    "elipticul": "eliptic",
    "elipticule": "eliptic",
    "elipticului": "eliptic",
    "Elisabetei": "Elisabeta",
    "Elisavetei": "Elisaveta",
    "elita": "elită",
    "elite": "elită",
    "elitei": "elită",
    "elitele": "elită",
    "elitelor": "elită",
    "elito": "elită",
    "elitisme": "elitism",
    "elitismele": "elitism",
    "elitismelor": "elitism",
    "elitismul": "elitism",
    "elitismului": "elitism",
    "elitista": "elitist",
    "elitistă": "elitist",
    "elitiste": "elitist",
    "elitistei": "elitist",
    "elitistele": "elitist",
    "elitistelor": "elitist",
    "elitiști": "elitist",
    "elitiștii": "elitist",
    "elitiștilor": "elitist",
    "elitisto": "elitist",
    "elitistul": "elitist",
    "elitistule": "elitist",
    "elitistului": "elitist",
    "elitra": "elitră",
    "elitre": "elitră",
    "elitrei": "elitră",
    "elitrele": "elitră",
    "elitrelor": "elitră",
    "elitro": "elitră",
    "elixirul": "elixir",
    "elixirule": "elixir",
    "elixirului": "elixir",
    "elixiruri": "elixir",
    "elixirurile": "elixir",
    "elixirurilor": "elixir",
    "elocința": "elocință",
    "elocințe": "elocință",
    "elocinței": "elocință",
    "elocințele": "elocință",
    "elocințelor": "elocință",
    "elocințo": "elocință",
    "elocuția": "elocuție",
    "elocuției": "elocuție",
    "elocuții": "elocuție",
    "elocuțiile": "elocuție",
    "elocuțiilor": "elocuție",
    "elocuțio": "elocuție",
    "elocuțiunea": "elocuțiune",
    "elocuțiuneo": "elocuțiune",
    "elocuțiuni": "elocuțiune",
    "elocuțiunii": "elocuțiune",
    "elocuțiunile": "elocuțiune",
    "elocuțiunilor": "elocuțiune",
    "elocventa": "elocvent",
    "elocventă": "elocvent",
    "elocvente": "elocvent",
    "elocventei": "elocvent",
    "elocventele": "elocvent",
    "elocventelor": "elocvent",
    "elocvenți": "elocvent",
    "elocvenții": "elocvent",
    "elocvenților": "elocvent",
    "elocvento": "elocvent",
    "elocventul": "elocvent",
    "elocventule": "elocvent",
    "elocventului": "elocvent",
    "elocvența": "elocvență",
    "elocvențe": "elocvență",
    "elocvenței": "elocvență",
    "elocvențele": "elocvență",
    "elocvențelor": "elocvență",
    "elocvențo": "elocvență",
    "elogiai": "elogia",
    "elogiam": "elogia",
    "elogiară": "elogia",
    "elogiarăm": "elogia",
    "elogiarăți": "elogia",
    "elogiase": "elogia",
    "elogiasem": "elogia",
    "elogiaseră": "elogia",
    "elogiaserăm": "elogia",
    "elogiaserăți": "elogia",
    "elogiaseși": "elogia",
    "elogiași": "elogia",
    "elogiat": "elogia",
    "elogiați": "elogia",
    "elogiatu": "elogia",
    "elogiau": "elogia",
    "elogiază": "elogia",
    "elogie": "elogia",
    "elogiem": "elogia",
    "elogiez": "elogia",
    "elogieze": "elogia",
    "elogiezi": "elogia",
    "elogiind": "elogia",
    "elogiindu": "elogia",
    "neelogiind": "elogia",
    "neelogiindu": "elogia",
    "nemaielogiind": "elogia",
    "nemaielogiindu": "elogia",
    "elogiată": "elogiat",
    "elogiate": "elogiat",
    "elogiați": "elogiat",
    "elogierea": "elogiere",
    "elogiereo": "elogiere",
    "elogieri": "elogiere",
    "elogierii": "elogiere",
    "elogierile": "elogiere",
    "elogierilor": "elogiere",
    "elogii": "elogiu",
    "elogiile": "elogiu",
    "elogiilor": "elogiu",
    "elogiul": "elogiu",
    "elogiule": "elogiu",
    "elogiului": "elogiu",
    "elongația": "elongație",
    "elongației": "elongație",
    "elongații": "elongație",
    "elongațiile": "elongație",
    "elongațiilor": "elongație",
    "elongațio": "elongație",
    "elucidă": "elucida",
    "elucidai": "elucida",
    "elucidam": "elucida",
    "elucidăm": "elucida",
    "elucidând": "elucida",
    "elucidându": "elucida",
    "elucidară": "elucida",
    "elucidarăm": "elucida",
    "elucidarăți": "elucida",
    "elucidase": "elucida",
    "elucidasem": "elucida",
    "elucidaseră": "elucida",
    "elucidaserăm": "elucida",
    "elucidaserăți": "elucida",
    "elucidaseși": "elucida",
    "elucidași": "elucida",
    "elucidat": "elucida",
    "elucidați": "elucida",
    "elucidatu": "elucida",
    "elucidau": "elucida",
    "elucidează": "elucida",
    "elucidez": "elucida",
    "elucideze": "elucida",
    "elucidezi": "elucida",
    "neelucidând": "elucida",
    "neelucidându": "elucida",
    "nemaielucidând": "elucida",
    "nemaielucidându": "elucida",
    "elucidarea": "elucidare",
    "elucidareo": "elucidare",
    "elucidări": "elucidare",
    "elucidării": "elucidare",
    "elucidările": "elucidare",
    "elucidărilor": "elucidare",
    "elucidată": "elucidat",
    "elucidate": "elucidat",
    "elucidați": "elucidat",
    "elucubrația": "elucubrație",
    "elucubrației": "elucubrație",
    "elucubrații": "elucubrație",
    "elucubrațiile": "elucubrație",
    "elucubrațiilor": "elucubrație",
    "elucubrațio": "elucubrație",
    "eludă": "eluda",
    "eludai": "eluda",
    "eludam": "eluda",
    "eludăm": "eluda",
    "eludând": "eluda",
    "eludându": "eluda",
    "eludară": "eluda",
    "eludarăm": "eluda",
    "eludarăți": "eluda",
    "eludase": "eluda",
    "eludasem": "eluda",
    "eludaseră": "eluda",
    "eludaserăm": "eluda",
    "eludaserăți": "eluda",
    "eludaseși": "eluda",
    "eludași": "eluda",
    "eludat": "eluda",
    "eludați": "eluda",
    "eludatu": "eluda",
    "eludau": "eluda",
    "eludează": "eluda",
    "eludez": "eluda",
    "eludeze": "eluda",
    "eludezi": "eluda",
    "neeludând": "eluda",
    "neeludându": "eluda",
    "nemaieludând": "eluda",
    "nemaieludându": "eluda",
    "eludarea": "eludare",
    "eludareo": "eludare",
    "eludări": "eludare",
    "eludării": "eludare",
    "eludările": "eludare",
    "eludărilor": "eludare",
    "eludată": "eludat",
    "eludate": "eludat",
    "eludați": "eludat",
    "Elveție": "Elveția",
    "Elveției": "Elveția",
    "Elveții": "Elveția",
    "elvețiana": "elvețian",
    "elvețiană": "elvețian",
    "elvețiano": "elvețian",
    "elvețianul": "elvețian",
    "elvețianule": "elvețian",
    "elvețianului": "elvețian",
    "elvețiene": "elvețian",
    "elvețienei": "elvețian",
    "elvețienele": "elvețian",
    "elvețienelor": "elvețian",
    "elvețieni": "elvețian",
    "elvețienii": "elvețian",
    "elvețienilor": "elvețian",
    "elvețianca": "elvețiancă",
    "elvețianco": "elvețiancă",
    "elvețience": "elvețiancă",
    "elvețiencei": "elvețiancă",
    "elvețiencele": "elvețiancă",
    "elvețiencelor": "elvețiancă",
    "emaciata": "emaciat",
    "emaciată": "emaciat",
    "emaciate": "emaciat",
    "emaciatei": "emaciat",
    "emaciatele": "emaciat",
    "emaciatelor": "emaciat",
    "emaciați": "emaciat",
    "emaciații": "emaciat",
    "emaciaților": "emaciat",
    "emaciato": "emaciat",
    "emaciatul": "emaciat",
    "emaciatule": "emaciat",
    "emaciatului": "emaciat",
    "emailul": "email",
    "emailule": "email",
    "emailului": "email",
    "emailuri": "email",
    "emailurile": "email",
    "emailurilor": "email",
    "emailă": "emaila",
    "emailai": "emaila",
    "emailam": "emaila",
    "emailăm": "emaila",
    "emailând": "emaila",
    "emailându": "emaila",
    "emailară": "emaila",
    "emailarăm": "emaila",
    "emailarăți": "emaila",
    "emailase": "emaila",
    "emailasem": "emaila",
    "emailaseră": "emaila",
    "emailaserăm": "emaila",
    "emailaserăți": "emaila",
    "emailaseși": "emaila",
    "emailași": "emaila",
    "emailat": "emaila",
    "emailați": "emaila",
    "emailatu": "emaila",
    "emailau": "emaila",
    "emailează": "emaila",
    "emailez": "emaila",
    "emaileze": "emaila",
    "emailezi": "emaila",
    "neemailând": "emaila",
    "neemailându": "emaila",
    "nemaiemailând": "emaila",
    "nemaiemailându": "emaila",
    "emailarea": "emailare",
    "emailareo": "emailare",
    "emailări": "emailare",
    "emailării": "emailare",
    "emailările": "emailare",
    "emailărilor": "emailare",
    "emailata": "emailat",
    "emailată": "emailat",
    "emailate": "emailat",
    "emailatei": "emailat",
    "emailatele": "emailat",
    "emailatelor": "emailat",
    "emailați": "emailat",
    "emailații": "emailat",
    "emailaților": "emailat",
    "emailato": "emailat",
    "emailatul": "emailat",
    "emailatule": "emailat",
    "emailatului": "emailat",
    "emailoarea": "emailoare",
    "emailoarei": "emailoare",
    "emailoarele": "emailoare",
    "emailoarelor": "emailoare",
    "emailoareo": "emailoare",
    "emailori": "emailor",
    "emailorii": "emailor",
    "emailorilor": "emailor",
    "emailorul": "emailor",
    "emailorule": "emailor",
    "emailorului": "emailor",
    "eman": "emana",
    "emană": "emana",
    "emanai": "emana",
    "emanam": "emana",
    "emanăm": "emana",
    "emanând": "emana",
    "emanându": "emana",
    "emanară": "emana",
    "emanarăm": "emana",
    "emanarăți": "emana",
    "emanase": "emana",
    "emanasem": "emana",
    "emanaseră": "emana",
    "emanaserăm": "emana",
    "emanaserăți": "emana",
    "emanaseși": "emana",
    "emanași": "emana",
    "emanat": "emana",
    "emanați": "emana",
    "emanatu": "emana",
    "emanau": "emana",
    "emane": "emana",
    "emani": "emana",
    "neemanând": "emana",
    "neemanându": "emana",
    "nemaiemanând": "emana",
    "nemaiemanându": "emana",
    "emanarea": "emanare",
    "emanareo": "emanare",
    "emanată": "emanat",
    "emanate": "emanat",
    "emanați": "emanat",
    "emanări": "emanație",
    "emanării": "emanație",
    "emanările": "emanație",
    "emanărilor": "emanație",
    "emanația": "emanație",
    "emanației": "emanație",
    "emanații": "emanație",
    "emanațiile": "emanație",
    "emanațiilor": "emanație",
    "emanațio": "emanație",
    "emancipă": "emancipa",
    "emancipai": "emancipa",
    "emancipam": "emancipa",
    "emancipăm": "emancipa",
    "emancipând": "emancipa",
    "emancipându": "emancipa",
    "emancipară": "emancipa",
    "emanciparăm": "emancipa",
    "emanciparăți": "emancipa",
    "emancipase": "emancipa",
    "emancipasem": "emancipa",
    "emancipaseră": "emancipa",
    "emancipaserăm": "emancipa",
    "emancipaserăți": "emancipa",
    "emancipaseși": "emancipa",
    "emancipași": "emancipa",
    "emancipat": "emancipa",
    "emancipați": "emancipa",
    "emancipatu": "emancipa",
    "emancipau": "emancipa",
    "emancipează": "emancipa",
    "emancipez": "emancipa",
    "emancipeze": "emancipa",
    "emancipezi": "emancipa",
    "neemancipând": "emancipa",
    "neemancipându": "emancipa",
    "nemaiemancipând": "emancipa",
    "nemaiemancipându": "emancipa",
    "emanciparea": "emancipare",
    "emancipareo": "emancipare",
    "emancipări": "emancipare",
    "emancipării": "emancipare",
    "emancipările": "emancipare",
    "emancipărilor": "emancipare",
    "emancipata": "emancipat",
    "emancipată": "emancipat",
    "emancipate": "emancipat",
    "emancipatei": "emancipat",
    "emancipatele": "emancipat",
    "emancipatelor": "emancipat",
    "emancipați": "emancipat",
    "emancipații": "emancipat",
    "emancipaților": "emancipat",
    "emancipato": "emancipat",
    "emancipatul": "emancipat",
    "emancipatule": "emancipat",
    "emancipatului": "emancipat",
    "Emanuelei": "Emanuela",
    "embargoul": "embargo",
    "embargoule": "embargo",
    "embargoului": "embargo",
    "embargouri": "embargo",
    "embargourile": "embargo",
    "embargourilor": "embargo",
    "emblema": "emblemă",
    "embleme": "emblemă",
    "emblemei": "emblemă",
    "emblemele": "emblemă",
    "emblemelor": "emblemă",
    "emblemo": "emblemă",
    "embolia": "embolie",
    "emboliei": "embolie",
    "embolii": "embolie",
    "emboliile": "embolie",
    "emboliilor": "embolie",
    "embolio": "embolie",
    "embriologi": "embriolog",
    "embriologii": "embriolog",
    "embriologilor": "embriolog",
    "embriologul": "embriolog",
    "embriologule": "embriolog",
    "embriologului": "embriolog",
    "embriologa": "embriologă",
    "embriologe": "embriologă",
    "embriologei": "embriologă",
    "embriologele": "embriologă",
    "embriologelor": "embriologă",
    "embrioni": "embrion",
    "embrionii": "embrion",
    "embrionilor": "embrion",
    "embrionul": "embrion",
    "embrionule": "embrion",
    "embrionului": "embrion",
    "emergenta": "emergent",
    "emergentă": "emergent",
    "emergente": "emergent",
    "emergentei": "emergent",
    "emergentele": "emergent",
    "emergentelor": "emergent",
    "emergenți": "emergent",
    "emergenții": "emergent",
    "emergenților": "emergent",
    "emergento": "emergent",
    "emergentul": "emergent",
    "emergentule": "emergent",
    "emergentului": "emergent",
    "emergența": "emergență",
    "emergențe": "emergență",
    "emergenței": "emergență",
    "emergențele": "emergență",
    "emergențelor": "emergență",
    "emergențo": "emergență",
    "emerita": "emerit",
    "emerită": "emerit",
    "emerite": "emerit",
    "emeritei": "emerit",
    "emeritele": "emerit",
    "emeritelor": "emerit",
    "emeriți": "emerit",
    "emeriții": "emerit",
    "emeriților": "emerit",
    "emerito": "emerit",
    "emeritul": "emerit",
    "emeritule": "emerit",
    "emeritului": "emerit",
    "emersiuna": "emersiune",
    "emersiunei": "emersiune",
    "emersiuni": "emersiune",
    "emersiunile": "emersiune",
    "emersiunilor": "emersiune",
    "emersiuno": "emersiune",
    "emfatica": "emfatic",
    "emfatică": "emfatic",
    "emfatice": "emfatic",
    "emfaticei": "emfatic",
    "emfaticele": "emfatic",
    "emfaticelor": "emfatic",
    "emfatici": "emfatic",
    "emfaticii": "emfatic",
    "emfaticilor": "emfatic",
    "emfatico": "emfatic",
    "emfaticul": "emfatic",
    "emfaticule": "emfatic",
    "emfaticului": "emfatic",
    "emfaza": "emfază",
    "emfaze": "emfază",
    "emfazei": "emfază",
    "emfazele": "emfază",
    "emfazelor": "emfază",
    "emfazo": "emfază",
    "emfizeme": "emfizem",
    "emfizemele": "emfizem",
    "emfizemelor": "emfizem",
    "emfizemul": "emfizem",
    "emfizemule": "emfizem",
    "emfizemului": "emfizem",
    "emigră": "emigra",
    "emigrai": "emigra",
    "emigram": "emigra",
    "emigrăm": "emigra",
    "emigrând": "emigra",
    "emigrându": "emigra",
    "emigrară": "emigra",
    "emigrarăm": "emigra",
    "emigrarăți": "emigra",
    "emigrase": "emigra",
    "emigrasem": "emigra",
    "emigraseră": "emigra",
    "emigraserăm": "emigra",
    "emigraserăți": "emigra",
    "emigraseși": "emigra",
    "emigrași": "emigra",
    "emigrat": "emigra",
    "emigrați": "emigra",
    "emigratu": "emigra",
    "emigrau": "emigra",
    "emigrează": "emigra",
    "emigrez": "emigra",
    "emigreze": "emigra",
    "emigrezi": "emigra",
    "neemigrând": "emigra",
    "neemigrându": "emigra",
    "nemaiemigrând": "emigra",
    "nemaiemigrându": "emigra",
    "emigranți": "emigrant",
    "emigranții": "emigrant",
    "emigranților": "emigrant",
    "emigrantul": "emigrant",
    "emigrantule": "emigrant",
    "emigrantului": "emigrant",
    "emigranta": "emigrantă",
    "emigrante": "emigrantă",
    "emigrantei": "emigrantă",
    "emigrantele": "emigrantă",
    "emigrantelor": "emigrantă",
    "emigranto": "emigrantă",
    "emigrarea": "emigrare",
    "emigrareo": "emigrare",
    "emigrări": "emigrare",
    "emigrării": "emigrare",
    "emigrările": "emigrare",
    "emigrărilor": "emigrare",
    "emigrată": "emigrat",
    "emigrate": "emigrat",
    "emigrați": "emigrat",
    "emigrații": "emigrat",
    "emigraților": "emigrat",
    "emigratul": "emigrat",
    "emigratului": "emigrat",
    "emigrația": "emigrație",
    "emigrației": "emigrație",
    "emigrații": "emigrație",
    "emigrațiile": "emigrație",
    "emigrațiilor": "emigrație",
    "emigrațio": "emigrație",
    "Emiliei": "Emilia",
    "eminenta": "eminent",
    "eminentă": "eminent",
    "eminente": "eminent",
    "eminentei": "eminent",
    "eminentele": "eminent",
    "eminentelor": "eminent",
    "eminenți": "eminent",
    "eminenții": "eminent",
    "eminenților": "eminent",
    "eminento": "eminent",
    "eminentul": "eminent",
    "eminentule": "eminent",
    "eminentului": "eminent",
    "eminența": "eminență",
    "eminențe": "eminență",
    "eminenței": "eminență",
    "eminențele": "eminență",
    "eminențelor": "eminență",
    "eminențo": "eminență",
    "eminesciana": "eminescian",
    "eminesciană": "eminescian",
    "eminesciano": "eminescian",
    "eminescianul": "eminescian",
    "eminescianule": "eminescian",
    "eminescianului": "eminescian",
    "eminesciene": "eminescian",
    "eminescienei": "eminescian",
    "eminescienele": "eminescian",
    "eminescienelor": "eminescian",
    "eminescieni": "eminescian",
    "eminescienii": "eminescian",
    "eminescienilor": "eminescian",
    "emiri": "emir",
    "emirii": "emir",
    "emirilor": "emir",
    "emirul": "emir",
    "emirule": "emir",
    "emirului": "emir",
    "Emiratelor_Arabe_Unite": "Emiratele_Arabe_Unite",
    "emisă": "emis",
    "emise": "emis",
    "emiși": "emis",
    "emisare": "emisar",
    "emisarele": "emisar",
    "emisarelor": "emisar",
    "emisari": "emisar",
    "emisarii": "emisar",
    "emisarilor": "emisar",
    "emisarul": "emisar",
    "emisarule": "emisar",
    "emisarului": "emisar",
    "emisfera": "emisferă",
    "emisfere": "emisferă",
    "emisferei": "emisferă",
    "emisferele": "emisferă",
    "emisferelor": "emisferă",
    "emisfero": "emisferă",
    "emisferica": "emisferic",
    "emisferică": "emisferic",
    "emisferice": "emisferic",
    "emisfericei": "emisferic",
    "emisfericele": "emisferic",
    "emisfericelor": "emisferic",
    "emisferici": "emisferic",
    "emisfericii": "emisferic",
    "emisfericilor": "emisferic",
    "emisferico": "emisferic",
    "emisfericul": "emisferic",
    "emisfericule": "emisferic",
    "emisfericului": "emisferic",
    "emisia": "emisie",
    "emisiei": "emisie",
    "emisii": "emisie",
    "emisiile": "emisie",
    "emisiilor": "emisie",
    "emisiunea": "emisiune",
    "emisiuneo": "emisiune",
    "emisiuni": "emisiune",
    "emisiunii": "emisiune",
    "emisiunile": "emisiune",
    "emisiunilor": "emisiune",
    "emisiunea-concurs": "emisiune-concurs",
    "emisiuneo-concurs": "emisiune-concurs",
    "emisiuni-concurs": "emisiune-concurs",
    "emisiunii-concurs": "emisiune-concurs",
    "emisiunile-concurs": "emisiune-concurs",
    "emisiunilor-concurs": "emisiune-concurs",
    "emis": "emite",
    "emise": "emite",
    "emisei": "emite",
    "emiseră": "emite",
    "emiserăm": "emite",
    "emiserăți": "emite",
    "emisese": "emite",
    "emisesem": "emite",
    "emiseseră": "emite",
    "emiseserăm": "emite",
    "emiseserăți": "emite",
    "emiseseși": "emite",
    "emiseși": "emite",
    "emisu": "emite",
    "emit": "emite",
    "emită": "emite",
    "emițând": "emite",
    "emițându": "emite",
    "emitea": "emite",
    "emiteai": "emite",
    "emiteam": "emite",
    "emiteați": "emite",
    "emiteau": "emite",
    "emitem": "emite",
    "emiteți": "emite",
    "emiți": "emite",
    "neemițând": "emite",
    "neemițându": "emite",
    "nemaiemițând": "emite",
    "nemaiemițându": "emite",
    "emitenta": "emitent",
    "emitentă": "emitent",
    "emitente": "emitent",
    "emitentei": "emitent",
    "emitentele": "emitent",
    "emitentelor": "emitent",
    "emitenți": "emitent",
    "emitenții": "emitent",
    "emitenților": "emitent",
    "emitento": "emitent",
    "emitentul": "emitent",
    "emitentule": "emitent",
    "emitentului": "emitent",
    "emiterea": "emitere",
    "emitereo": "emitere",
    "emiteri": "emitere",
    "emiterii": "emitere",
    "emiterile": "emitere",
    "emiterilor": "emitere",
    "emolienta": "emolient",
    "emolientă": "emolient",
    "emoliente": "emolient",
    "emolientei": "emolient",
    "emolientele": "emolient",
    "emolientelor": "emolient",
    "emolienți": "emolient",
    "emolienții": "emolient",
    "emolienților": "emolient",
    "emoliento": "emolient",
    "emolientul": "emolient",
    "emolientule": "emolient",
    "emolientului": "emolient",
    "emoția": "emoție",
    "emoției": "emoție",
    "emoții": "emoție",
    "emoțiile": "emoție",
    "emoțiilor": "emoție",
    "emoțio": "emoție",
    "emoționă": "emoționa",
    "emoționai": "emoționa",
    "emoționam": "emoționa",
    "emoționăm": "emoționa",
    "emoționând": "emoționa",
    "emoționându": "emoționa",
    "emoționară": "emoționa",
    "emoționarăm": "emoționa",
    "emoționarăți": "emoționa",
    "emoționase": "emoționa",
    "emoționasem": "emoționa",
    "emoționaseră": "emoționa",
    "emoționaserăm": "emoționa",
    "emoționaserăți": "emoționa",
    "emoționaseși": "emoționa",
    "emoționași": "emoționa",
    "emoționat": "emoționa",
    "emoționați": "emoționa",
    "emoționatu": "emoționa",
    "emoționau": "emoționa",
    "emoționează": "emoționa",
    "emoționez": "emoționa",
    "emoționeze": "emoționa",
    "emoționezi": "emoționa",
    "neemoționând": "emoționa",
    "neemoționându": "emoționa",
    "nemaiemoționând": "emoționa",
    "nemaiemoționându": "emoționa",
    "emoționala": "emoțional",
    "emoțională": "emoțional",
    "emoționale": "emoțional",
    "emoționalei": "emoțional",
    "emoționalele": "emoțional",
    "emoționalelor": "emoțional",
    "emoționali": "emoțional",
    "emoționalii": "emoțional",
    "emoționalilor": "emoțional",
    "emoționalo": "emoțional",
    "emoționalul": "emoțional",
    "emoționalule": "emoțional",
    "emoționalului": "emoțional",
    "emoționanta": "emoționant",
    "emoționantă": "emoționant",
    "emoționante": "emoționant",
    "emoționantei": "emoționant",
    "emoționantele": "emoționant",
    "emoționantelor": "emoționant",
    "emoționanți": "emoționant",
    "emoționanții": "emoționant",
    "emoționanților": "emoționant",
    "emoționanto": "emoționant",
    "emoționantul": "emoționant",
    "emoționantule": "emoționant",
    "emoționantului": "emoționant",
    "emoționata": "emoționat",
    "emoționată": "emoționat",
    "emoționate": "emoționat",
    "emoționatei": "emoționat",
    "emoționatele": "emoționat",
    "emoționatelor": "emoționat",
    "emoționați": "emoționat",
    "emoționații": "emoționat",
    "emoționaților": "emoționat",
    "emoționato": "emoționat",
    "emoționatul": "emoționat",
    "emoționatule": "emoționat",
    "emoționatului": "emoționat",
    "emotiva": "emotiv",
    "emotivă": "emotiv",
    "emotive": "emotiv",
    "emotivei": "emotiv",
    "emotivele": "emotiv",
    "emotivelor": "emotiv",
    "emotivi": "emotiv",
    "emotivii": "emotiv",
    "emotivilor": "emotiv",
    "emotivo": "emotiv",
    "emotivul": "emotiv",
    "emotivule": "emotiv",
    "emotivului": "emotiv",
    "emotivitatea": "emotivitate",
    "emotivitateo": "emotivitate",
    "emotivități": "emotivitate",
    "emotivității": "emotivitate",
    "emotivitățile": "emotivitate",
    "emotivităților": "emotivitate",
    "empirica": "empiric",
    "empirică": "empiric",
    "empirice": "empiric",
    "empiricei": "empiric",
    "empiricele": "empiric",
    "empiricelor": "empiric",
    "empirici": "empiric",
    "empiricii": "empiric",
    "empiricilor": "empiric",
    "empirico": "empiric",
    "empiricul": "empiric",
    "empiricule": "empiric",
    "empiricului": "empiric",
    "empirismul": "empirism",
    "empirismule": "empirism",
    "empirismului": "empirism",
    "empirista": "empirist",
    "empiristă": "empirist",
    "empiriste": "empirist",
    "empiristei": "empirist",
    "empiristele": "empirist",
    "empiristelor": "empirist",
    "empiriști": "empirist",
    "empiriștii": "empirist",
    "empiriștilor": "empirist",
    "empiristo": "empirist",
    "empiristul": "empirist",
    "empiristule": "empirist",
    "empiristului": "empirist",
    "empirista": "empiristă",
    "empiriste": "empiristă",
    "empiristei": "empiristă",
    "empiristele": "empiristă",
    "empiristelor": "empiristă",
    "empiristo": "empiristă",
    "emulația": "emulație",
    "emulației": "emulație",
    "emulații": "emulație",
    "emulațiile": "emulație",
    "emulațiilor": "emulație",
    "emulațio": "emulație",
    "emulsia": "emulsie",
    "emulsiei": "emulsie",
    "emulsii": "emulsie",
    "emulsiile": "emulsie",
    "emulsiilor": "emulsie",
    "emulsio": "emulsie",
    "emulsionă": "emulsiona",
    "emulsionai": "emulsiona",
    "emulsionam": "emulsiona",
    "emulsionăm": "emulsiona",
    "emulsionând": "emulsiona",
    "emulsionându": "emulsiona",
    "emulsionară": "emulsiona",
    "emulsionarăm": "emulsiona",
    "emulsionarăți": "emulsiona",
    "emulsionase": "emulsiona",
    "emulsionasem": "emulsiona",
    "emulsionaseră": "emulsiona",
    "emulsionaserăm": "emulsiona",
    "emulsionaserăți": "emulsiona",
    "emulsionaseși": "emulsiona",
    "emulsionași": "emulsiona",
    "emulsionat": "emulsiona",
    "emulsionați": "emulsiona",
    "emulsionatu": "emulsiona",
    "emulsionau": "emulsiona",
    "emulsionează": "emulsiona",
    "emulsionez": "emulsiona",
    "emulsioneze": "emulsiona",
    "emulsionezi": "emulsiona",
    "neemulsionând": "emulsiona",
    "neemulsionându": "emulsiona",
    "nemaiemulsionând": "emulsiona",
    "nemaiemulsionându": "emulsiona",
    "emulsionarea": "emulsionare",
    "emulsionareo": "emulsionare",
    "emulsionări": "emulsionare",
    "emulsionării": "emulsionare",
    "emulsionările": "emulsionare",
    "emulsionărilor": "emulsionare",
    "emulsionată": "emulsionat",
    "emulsionate": "emulsionat",
    "emulsionați": "emulsionat",
    "encefale": "encefal",
    "encefalele": "encefal",
    "encefalelor": "encefal",
    "encefalul": "encefal",
    "encefalule": "encefal",
    "encefalului": "encefal",
    "encefalica": "encefalic",
    "encefalică": "encefalic",
    "encefalice": "encefalic",
    "encefalicei": "encefalic",
    "encefalicele": "encefalic",
    "encefalicelor": "encefalic",
    "encefalici": "encefalic",
    "encefalicii": "encefalic",
    "encefalicilor": "encefalic",
    "encefalico": "encefalic",
    "encefalicul": "encefalic",
    "encefalicule": "encefalic",
    "encefalicului": "encefalic",
    "encefalita": "encefalită",
    "encefalite": "encefalită",
    "encefalitei": "encefalită",
    "encefalitele": "encefalită",
    "encefalitelor": "encefalită",
    "encefalito": "encefalită",
    "enciclopedica": "enciclopedic",
    "enciclopedică": "enciclopedic",
    "enciclopedice": "enciclopedic",
    "enciclopedicei": "enciclopedic",
    "enciclopedicele": "enciclopedic",
    "enciclopedicelor": "enciclopedic",
    "enciclopedici": "enciclopedic",
    "enciclopedicii": "enciclopedic",
    "enciclopedicilor": "enciclopedic",
    "enciclopedico": "enciclopedic",
    "enciclopedicul": "enciclopedic",
    "enciclopedicule": "enciclopedic",
    "enciclopedicului": "enciclopedic",
    "enciclopedia": "enciclopedie",
    "enciclopediei": "enciclopedie",
    "enciclopedii": "enciclopedie",
    "enciclopediile": "enciclopedie",
    "enciclopediilor": "enciclopedie",
    "enciclopedio": "enciclopedie",
    "enclava": "enclavă",
    "enclave": "enclavă",
    "enclavei": "enclavă",
    "enclavele": "enclavă",
    "enclavelor": "enclavă",
    "enclavo": "enclavă",
    "enclitica": "enclitic",
    "enclitică": "enclitic",
    "enclitice": "enclitic",
    "encliticei": "enclitic",
    "encliticele": "enclitic",
    "encliticelor": "enclitic",
    "enclitici": "enclitic",
    "encliticii": "enclitic",
    "encliticilor": "enclitic",
    "enclitico": "enclitic",
    "encliticul": "enclitic",
    "encliticule": "enclitic",
    "encliticului": "enclitic",
    "endemica": "endemic",
    "endemică": "endemic",
    "endemice": "endemic",
    "endemicei": "endemic",
    "endemicele": "endemic",
    "endemicelor": "endemic",
    "endemici": "endemic",
    "endemicii": "endemic",
    "endemicilor": "endemic",
    "endemico": "endemic",
    "endemicul": "endemic",
    "endemicule": "endemic",
    "endemicului": "endemic",
    "endocardul": "endocard",
    "endocardule": "endocard",
    "endocardului": "endocard",
    "endocarduri": "endocard",
    "endocardurile": "endocard",
    "endocardurilor": "endocard",
    "endocarpul": "endocarp",
    "endocarpule": "endocarp",
    "endocarpului": "endocarp",
    "endocarpuri": "endocarp",
    "endocarpurile": "endocarp",
    "endocarpurilor": "endocarp",
    "endocrina": "endocrin",
    "endocrină": "endocrin",
    "endocrine": "endocrin",
    "endocrinei": "endocrin",
    "endocrinele": "endocrin",
    "endocrinelor": "endocrin",
    "endocrini": "endocrin",
    "endocrinii": "endocrin",
    "endocrinilor": "endocrin",
    "endocrino": "endocrin",
    "endocrinul": "endocrin",
    "endocrinule": "endocrin",
    "endocrinului": "endocrin",
    "endocrinologi": "endocrinolog",
    "endocrinologii": "endocrinolog",
    "endocrinologilor": "endocrinolog",
    "endocrinologul": "endocrinolog",
    "endocrinologule": "endocrinolog",
    "endocrinologului": "endocrinolog",
    "endocrinologia": "endocrinologie",
    "endocrinologiei": "endocrinologie",
    "endocrinologii": "endocrinologie",
    "endocrinologiile": "endocrinologie",
    "endocrinologiilor": "endocrinologie",
    "endocrinologio": "endocrinologie",
    "endoderme": "endoderm",
    "endodermele": "endoderm",
    "endodermelor": "endoderm",
    "endodermul": "endoderm",
    "endodermule": "endoderm",
    "endodermului": "endoderm",
    "endogena": "endogen",
    "endogenă": "endogen",
    "endogene": "endogen",
    "endogenei": "endogen",
    "endogenele": "endogen",
    "endogenelor": "endogen",
    "endogeni": "endogen",
    "endogenii": "endogen",
    "endogenilor": "endogen",
    "endogeno": "endogen",
    "endogenul": "endogen",
    "endogenule": "endogen",
    "endogenului": "endogen",
    "energetica": "energetic",
    "energetică": "energetic",
    "energetice": "energetic",
    "energeticei": "energetic",
    "energeticele": "energetic",
    "energeticelor": "energetic",
    "energetici": "energetic",
    "energeticii": "energetic",
    "energeticilor": "energetic",
    "energetico": "energetic",
    "energeticul": "energetic",
    "energeticule": "energetic",
    "energeticului": "energetic",
    "energetica": "energetică",
    "energetici": "energetică",
    "energeticii": "energetică",
    "energetico": "energetică",
    "energica": "energic",
    "energică": "energic",
    "energice": "energic",
    "energicei": "energic",
    "energicele": "energic",
    "energicelor": "energic",
    "energici": "energic",
    "energicii": "energic",
    "energicilor": "energic",
    "energico": "energic",
    "energicul": "energic",
    "energicule": "energic",
    "energicului": "energic",
    "energia": "energie",
    "energiei": "energie",
    "energii": "energie",
    "energiile": "energie",
    "energiilor": "energie",
    "energio": "energie",
    "energofaga": "energofag",
    "energofagă": "energofag",
    "energofage": "energofag",
    "energofagei": "energofag",
    "energofagele": "energofag",
    "energofagelor": "energofag",
    "energofagi": "energofag",
    "energofagii": "energofag",
    "energofagilor": "energofag",
    "energofago": "energofag",
    "energofagul": "energofag",
    "energofagule": "energofag",
    "energofagului": "energofag",
    "energumeni": "energumen",
    "energumenii": "energumen",
    "energumenilor": "energumen",
    "energumenul": "energumen",
    "energumenule": "energumen",
    "energumenului": "energumen",
    "enervă": "enerva",
    "enervai": "enerva",
    "enervam": "enerva",
    "enervăm": "enerva",
    "enervând": "enerva",
    "enervându": "enerva",
    "enervară": "enerva",
    "enervarăm": "enerva",
    "enervarăți": "enerva",
    "enervase": "enerva",
    "enervasem": "enerva",
    "enervaseră": "enerva",
    "enervaserăm": "enerva",
    "enervaserăți": "enerva",
    "enervaseși": "enerva",
    "enervași": "enerva",
    "enervat": "enerva",
    "enervați": "enerva",
    "enervatu": "enerva",
    "enervau": "enerva",
    "enervează": "enerva",
    "enervez": "enerva",
    "enerveze": "enerva",
    "enervezi": "enerva",
    "neenervând": "enerva",
    "neenervându": "enerva",
    "nemaienervând": "enerva",
    "nemaienervându": "enerva",
    "enervanta": "enervant",
    "enervantă": "enervant",
    "enervante": "enervant",
    "enervantei": "enervant",
    "enervantele": "enervant",
    "enervantelor": "enervant",
    "enervanți": "enervant",
    "enervanții": "enervant",
    "enervanților": "enervant",
    "enervanto": "enervant",
    "enervantul": "enervant",
    "enervantule": "enervant",
    "enervantului": "enervant",
    "enervarea": "enervare",
    "enervareo": "enervare",
    "enervări": "enervare",
    "enervării": "enervare",
    "enervările": "enervare",
    "enervărilor": "enervare",
    "enervata": "enervat",
    "enervată": "enervat",
    "enervate": "enervat",
    "enervatei": "enervat",
    "enervatele": "enervat",
    "enervatelor": "enervat",
    "enervați": "enervat",
    "enervații": "enervat",
    "enervaților": "enervat",
    "enervato": "enervat",
    "enervatul": "enervat",
    "enervatule": "enervat",
    "enervatului": "enervat",
    "engleza": "englez",
    "engleză": "englez",
    "engleze": "englez",
    "englezei": "englez",
    "englezele": "englez",
    "englezelor": "englez",
    "englezi": "englez",
    "englezii": "englez",
    "englezilor": "englez",
    "englezo": "englez",
    "englezul": "englez",
    "englezule": "englez",
    "englezului": "englez",
    "engl.": "engleză",
    "engleza": "engleză",
    "englezeasca": "englezesc",
    "englezească": "englezesc",
    "englezeasco": "englezesc",
    "englezescul": "englezesc",
    "englezescule": "englezesc",
    "englezescului": "englezesc",
    "englezești": "englezesc",
    "englezeștii": "englezesc",
    "englezeștile": "englezesc",
    "englezeștilor": "englezesc",
    "englezoaica": "englezoaică",
    "englezoaice": "englezoaică",
    "englezoaicei": "englezoaică",
    "englezoaicele": "englezoaică",
    "englezoaicelor": "englezoaică",
    "englezoaico": "englezoaică",
    "enigma": "enigmă",
    "enigme": "enigmă",
    "enigmei": "enigmă",
    "enigmele": "enigmă",
    "enigmelor": "enigmă",
    "enigmo": "enigmă",
    "enigmatica": "enigmatic",
    "enigmatică": "enigmatic",
    "enigmatice": "enigmatic",
    "enigmaticei": "enigmatic",
    "enigmaticele": "enigmatic",
    "enigmaticelor": "enigmatic",
    "enigmatici": "enigmatic",
    "enigmaticii": "enigmatic",
    "enigmaticilor": "enigmatic",
    "enigmatico": "enigmatic",
    "enigmaticul": "enigmatic",
    "enigmaticule": "enigmatic",
    "enigmaticului": "enigmatic",
    "enoriași": "enoriaș",
    "enoriașii": "enoriaș",
    "enoriașilor": "enoriaș",
    "enoriașul": "enoriaș",
    "enoriașule": "enoriaș",
    "enoriașului": "enoriaș",
    "enorma": "enorm",
    "enormă": "enorm",
    "enorme": "enorm",
    "enormei": "enorm",
    "enormele": "enorm",
    "enormelor": "enorm",
    "enormi": "enorm",
    "enormii": "enorm",
    "enormilor": "enorm",
    "enormo": "enorm",
    "enormul": "enorm",
    "enormule": "enorm",
    "enormului": "enorm",
    "enormitatea": "enormitate",
    "enormitateo": "enormitate",
    "enormități": "enormitate",
    "enormității": "enormitate",
    "enormitățile": "enormitate",
    "enormităților": "enormitate",
    "enterita": "enterită",
    "enterite": "enterită",
    "enteritei": "enterită",
    "enteritele": "enterită",
    "enteritelor": "enterită",
    "enterito": "enterită",
    "enterocolita": "enterocolită",
    "enterocolite": "enterocolită",
    "enterocolitei": "enterocolită",
    "enterocolitele": "enterocolită",
    "enterocolitelor": "enterocolită",
    "enterocolito": "enterocolită",
    "entitatea": "entitate",
    "entitateo": "entitate",
    "entități": "entitate",
    "entității": "entitate",
    "entitățile": "entitate",
    "entităților": "entitate",
    "entomologi": "entomolog",
    "entomologii": "entomolog",
    "entomologilor": "entomolog",
    "entomologul": "entomolog",
    "entomologule": "entomolog",
    "entomologului": "entomolog",
    "entomologa": "entomologă",
    "entomologe": "entomologă",
    "entomologei": "entomologă",
    "entomologele": "entomologă",
    "entomologelor": "entomologă",
    "entomologica": "entomologic",
    "entomologică": "entomologic",
    "entomologice": "entomologic",
    "entomologicei": "entomologic",
    "entomologicele": "entomologic",
    "entomologicelor": "entomologic",
    "entomologici": "entomologic",
    "entomologicii": "entomologic",
    "entomologicilor": "entomologic",
    "entomologico": "entomologic",
    "entomologicul": "entomologic",
    "entomologicule": "entomologic",
    "entomologicului": "entomologic",
    "entomologia": "entomologie",
    "entomologiei": "entomologie",
    "entomologii": "entomologie",
    "entomologiile": "entomologie",
    "entomologiilor": "entomologie",
    "entomologio": "entomologie",
    "entorsa": "entorsă",
    "entorse": "entorsă",
    "entorsei": "entorsă",
    "entorsele": "entorsă",
    "entorselor": "entorsă",
    "entorso": "entorsă",
    "entozoare": "entozoar",
    "entozoarele": "entozoar",
    "entozoarelor": "entozoar",
    "entozoarul": "entozoar",
    "entozoarule": "entozoar",
    "entozoarului": "entozoar",
    "entropia": "entropie",
    "entropiei": "entropie",
    "entropii": "entropie",
    "entropiile": "entropie",
    "entropiilor": "entropie",
    "entropio": "entropie",
    "entuziasme": "entuziasm",
    "entuziasmele": "entuziasm",
    "entuziasmelor": "entuziasm",
    "entuziasmul": "entuziasm",
    "entuziasmule": "entuziasm",
    "entuziasmului": "entuziasm",
    "entuziasmă": "entuziasma",
    "entuziasmai": "entuziasma",
    "entuziasmam": "entuziasma",
    "entuziasmăm": "entuziasma",
    "entuziasmând": "entuziasma",
    "entuziasmându": "entuziasma",
    "entuziasmară": "entuziasma",
    "entuziasmarăm": "entuziasma",
    "entuziasmarăți": "entuziasma",
    "entuziasmase": "entuziasma",
    "entuziasmasem": "entuziasma",
    "entuziasmaseră": "entuziasma",
    "entuziasmaserăm": "entuziasma",
    "entuziasmaserăți": "entuziasma",
    "entuziasmaseși": "entuziasma",
    "entuziasmași": "entuziasma",
    "entuziasmat": "entuziasma",
    "entuziasmați": "entuziasma",
    "entuziasmatu": "entuziasma",
    "entuziasmau": "entuziasma",
    "entuziasmează": "entuziasma",
    "entuziasmez": "entuziasma",
    "entuziasmeze": "entuziasma",
    "entuziasmezi": "entuziasma",
    "neentuziasmând": "entuziasma",
    "neentuziasmându": "entuziasma",
    "nemaientuziasmând": "entuziasma",
    "nemaientuziasmându": "entuziasma",
    "entuziasmanta": "entuziasmant",
    "entuziasmantă": "entuziasmant",
    "entuziasmante": "entuziasmant",
    "entuziasmantei": "entuziasmant",
    "entuziasmantele": "entuziasmant",
    "entuziasmantelor": "entuziasmant",
    "entuziasmanți": "entuziasmant",
    "entuziasmanții": "entuziasmant",
    "entuziasmanților": "entuziasmant",
    "entuziasmanto": "entuziasmant",
    "entuziasmantul": "entuziasmant",
    "entuziasmantule": "entuziasmant",
    "entuziasmantului": "entuziasmant",
    "entuziasmata": "entuziasmat",
    "entuziasmată": "entuziasmat",
    "entuziasmate": "entuziasmat",
    "entuziasmatei": "entuziasmat",
    "entuziasmatele": "entuziasmat",
    "entuziasmatelor": "entuziasmat",
    "entuziasmați": "entuziasmat",
    "entuziasmații": "entuziasmat",
    "entuziasmaților": "entuziasmat",
    "entuziasmato": "entuziasmat",
    "entuziasmatul": "entuziasmat",
    "entuziasmatule": "entuziasmat",
    "entuziasmatului": "entuziasmat",
    "entuziasta": "entuziast",
    "entuziastă": "entuziast",
    "entuziaste": "entuziast",
    "entuziastei": "entuziast",
    "entuziastele": "entuziast",
    "entuziastelor": "entuziast",
    "entuziaști": "entuziast",
    "entuziaștii": "entuziast",
    "entuziaștilor": "entuziast",
    "entuziasto": "entuziast",
    "entuziastul": "entuziast",
    "entuziastule": "entuziast",
    "entuziastului": "entuziast",
    "entuziasta": "entuziastă",
    "entuziaste": "entuziastă",
    "entuziastei": "entuziastă",
    "entuziastele": "entuziastă",
    "entuziastelor": "entuziastă",
    "entuziasto": "entuziastă",
    "enumer": "enumera",
    "enumeră": "enumera",
    "enumerai": "enumera",
    "enumeram": "enumera",
    "enumerăm": "enumera",
    "enumerând": "enumera",
    "enumerându": "enumera",
    "enumerară": "enumera",
    "enumerarăm": "enumera",
    "enumerarăți": "enumera",
    "enumerase": "enumera",
    "enumerasem": "enumera",
    "enumeraseră": "enumera",
    "enumeraserăm": "enumera",
    "enumeraserăți": "enumera",
    "enumeraseși": "enumera",
    "enumerași": "enumera",
    "enumerat": "enumera",
    "enumerați": "enumera",
    "enumeratu": "enumera",
    "enumerau": "enumera",
    "enumere": "enumera",
    "enumeri": "enumera",
    "neenumerând": "enumera",
    "neenumerându": "enumera",
    "nemaienumerând": "enumera",
    "nemaienumerându": "enumera",
    "enumerarea": "enumerare",
    "enumerareo": "enumerare",
    "enumerări": "enumerare",
    "enumerării": "enumerare",
    "enumerările": "enumerare",
    "enumerărilor": "enumerare",
    "enumerată": "enumerat",
    "enumerate": "enumerat",
    "enumerați": "enumerat",
    "enumerația": "enumerație",
    "enumerației": "enumerație",
    "enumerații": "enumerație",
    "enumerațiile": "enumerație",
    "enumerațiilor": "enumerație",
    "enumerațio": "enumerație",
    "enumerativa": "enumerativ",
    "enumerativă": "enumerativ",
    "enumerative": "enumerativ",
    "enumerativei": "enumerativ",
    "enumerativele": "enumerativ",
    "enumerativelor": "enumerativ",
    "enumerativi": "enumerativ",
    "enumerativii": "enumerativ",
    "enumerativilor": "enumerativ",
    "enumerativo": "enumerativ",
    "enumerativul": "enumerativ",
    "enumerativule": "enumerativ",
    "enumerativului": "enumerativ",
    "enunțul": "enunț",
    "enunțule": "enunț",
    "enunțului": "enunț",
    "enunțuri": "enunț",
    "enunțurile": "enunț",
    "enunțurilor": "enunț",
    "enunț": "enunța",
    "enunță": "enunța",
    "enunțai": "enunța",
    "enunțam": "enunța",
    "enunțăm": "enunța",
    "enunțând": "enunța",
    "enunțându": "enunța",
    "enunțară": "enunța",
    "enunțarăm": "enunța",
    "enunțarăți": "enunța",
    "enunțase": "enunța",
    "enunțasem": "enunța",
    "enunțaseră": "enunța",
    "enunțaserăm": "enunța",
    "enunțaserăți": "enunța",
    "enunțaseși": "enunța",
    "enunțași": "enunța",
    "enunțat": "enunța",
    "enunțați": "enunța",
    "enunțatu": "enunța",
    "enunțau": "enunța",
    "enunțe": "enunța",
    "enunți": "enunța",
    "neenunțând": "enunța",
    "neenunțându": "enunța",
    "nemaienunțând": "enunța",
    "nemaienunțându": "enunța",
    "enunțarea": "enunțare",
    "enunțareo": "enunțare",
    "enunțări": "enunțare",
    "enunțării": "enunțare",
    "enunțările": "enunțare",
    "enunțărilor": "enunțare",
    "enunțată": "enunțat",
    "enunțate": "enunțat",
    "enunțați": "enunțat",
    "enunțiativa": "enunțiativ",
    "enunțiativă": "enunțiativ",
    "enunțiative": "enunțiativ",
    "enunțiativei": "enunțiativ",
    "enunțiativele": "enunțiativ",
    "enunțiativelor": "enunțiativ",
    "enunțiativi": "enunțiativ",
    "enunțiativii": "enunțiativ",
    "enunțiativilor": "enunțiativ",
    "enunțiativo": "enunțiativ",
    "enunțiativul": "enunțiativ",
    "enunțiativule": "enunțiativ",
    "enunțiativului": "enunțiativ",
    "enzima": "enzimă",
    "enzime": "enzimă",
    "enzimei": "enzimă",
    "enzimele": "enzimă",
    "enzimelor": "enzimă",
    "enzimo": "enzimă",
    "eocenul": "eocen",
    "eocenule": "eocen",
    "eocenului": "eocen",
    "eoliana": "eolian",
    "eoliană": "eolian",
    "eoliano": "eolian",
    "eolianul": "eolian",
    "eolianule": "eolian",
    "eolianului": "eolian",
    "eoliene": "eolian",
    "eolienei": "eolian",
    "eolienele": "eolian",
    "eolienelor": "eolian",
    "eolieni": "eolian",
    "eolienii": "eolian",
    "eolienilor": "eolian",
    "eolitica": "eolitic",
    "eolitică": "eolitic",
    "eolitice": "eolitic",
    "eoliticei": "eolitic",
    "eoliticele": "eolitic",
    "eoliticelor": "eolitic",
    "eolitici": "eolitic",
    "eoliticii": "eolitic",
    "eoliticilor": "eolitic",
    "eolitico": "eolitic",
    "eoliticul": "eolitic",
    "eoliticule": "eolitic",
    "eoliticului": "eolitic",
    "epacta": "epactă",
    "epacte": "epactă",
    "epactei": "epactă",
    "epactele": "epactă",
    "epactelor": "epactă",
    "epacto": "epactă",
    "eparhiala": "eparhial",
    "eparhială": "eparhial",
    "eparhiale": "eparhial",
    "eparhialei": "eparhial",
    "eparhialele": "eparhial",
    "eparhialelor": "eparhial",
    "eparhiali": "eparhial",
    "eparhialii": "eparhial",
    "eparhialilor": "eparhial",
    "eparhialo": "eparhial",
    "eparhialul": "eparhial",
    "eparhialule": "eparhial",
    "eparhialului": "eparhial",
    "eparhia": "eparhie",
    "eparhiei": "eparhie",
    "eparhii": "eparhie",
    "eparhiile": "eparhie",
    "eparhiilor": "eparhie",
    "eparhio": "eparhie",
    "epată": "epata",
    "epatai": "epata",
    "epatam": "epata",
    "epatăm": "epata",
    "epatând": "epata",
    "epatându": "epata",
    "epatară": "epata",
    "epatarăm": "epata",
    "epatarăți": "epata",
    "epatase": "epata",
    "epatasem": "epata",
    "epataseră": "epata",
    "epataserăm": "epata",
    "epataserăți": "epata",
    "epataseși": "epata",
    "epatași": "epata",
    "epatat": "epata",
    "epatați": "epata",
    "epatatu": "epata",
    "epatau": "epata",
    "epatează": "epata",
    "epatez": "epata",
    "epateze": "epata",
    "epatezi": "epata",
    "neepatând": "epata",
    "neepatându": "epata",
    "nemaiepatând": "epata",
    "nemaiepatându": "epata",
    "epatată": "epatat",
    "epatate": "epatat",
    "epatați": "epatat",
    "epava": "epavă",
    "epave": "epavă",
    "epavei": "epavă",
    "epavele": "epavă",
    "epavelor": "epavă",
    "epavo": "epavă",
    "epica": "epic",
    "epică": "epic",
    "epice": "epic",
    "epicei": "epic",
    "epicele": "epic",
    "epicelor": "epic",
    "epici": "epic",
    "epicii": "epic",
    "epicilor": "epic",
    "epico": "epic",
    "epicul": "epic",
    "epicule": "epic",
    "epicului": "epic",
    "epicene": "epicen",
    "epicenele": "epicen",
    "epicenelor": "epicen",
    "epicenul": "epicen",
    "epicenule": "epicen",
    "epicenului": "epicen",
    "epicentre": "epicentru",
    "epicentrele": "epicentru",
    "epicentrelor": "epicentru",
    "epicentrul": "epicentru",
    "epicentrule": "epicentru",
    "epicentrului": "epicentru",
    "epicuriana": "epicurian",
    "epicuriană": "epicurian",
    "epicuriano": "epicurian",
    "epicurianul": "epicurian",
    "epicurianule": "epicurian",
    "epicurianului": "epicurian",
    "epicuriene": "epicurian",
    "epicurienei": "epicurian",
    "epicurienele": "epicurian",
    "epicurienelor": "epicurian",
    "epicurieni": "epicurian",
    "epicurienii": "epicurian",
    "epicurienilor": "epicurian",
    "epicurismul": "epicurism",
    "epicurismule": "epicurism",
    "epicurismului": "epicurism",
    "epidemica": "epidemic",
    "epidemică": "epidemic",
    "epidemice": "epidemic",
    "epidemicei": "epidemic",
    "epidemicele": "epidemic",
    "epidemicelor": "epidemic",
    "epidemici": "epidemic",
    "epidemicii": "epidemic",
    "epidemicilor": "epidemic",
    "epidemico": "epidemic",
    "epidemicul": "epidemic",
    "epidemicule": "epidemic",
    "epidemicului": "epidemic",
    "epidemia": "epidemie",
    "epidemiei": "epidemie",
    "epidemii": "epidemie",
    "epidemiile": "epidemie",
    "epidemiilor": "epidemie",
    "epidemio": "epidemie",
    "epidemiologia": "epidemiologie",
    "epidemiologiei": "epidemiologie",
    "epidemiologii": "epidemiologie",
    "epidemiologiile": "epidemiologie",
    "epidemiologiilor": "epidemiologie",
    "epidemiologio": "epidemiologie",
    "epiderma": "epidermă",
    "epiderme": "epidermă",
    "epidermei": "epidermă",
    "epidermele": "epidermă",
    "epidermelor": "epidermă",
    "epidermo": "epidermă",
    "epidermica": "epidermic",
    "epidermică": "epidermic",
    "epidermice": "epidermic",
    "epidermicei": "epidermic",
    "epidermicele": "epidermic",
    "epidermicelor": "epidermic",
    "epidermici": "epidermic",
    "epidermicii": "epidermic",
    "epidermicilor": "epidermic",
    "epidermico": "epidermic",
    "epidermicul": "epidermic",
    "epidermicule": "epidermic",
    "epidermicului": "epidermic",
    "epidiascoape": "epidiascop",
    "epidiascoapele": "epidiascop",
    "epidiascoapelor": "epidiascop",
    "epidiascopul": "epidiascop",
    "epidiascopule": "epidiascop",
    "epidiascopului": "epidiascop",
    "epifiza": "epifiză",
    "epifize": "epifiză",
    "epifizei": "epifiză",
    "epifizele": "epifiză",
    "epifizelor": "epifiză",
    "epifizo": "epifiză",
    "epigastrica": "epigastric",
    "epigastrică": "epigastric",
    "epigastrice": "epigastric",
    "epigastricei": "epigastric",
    "epigastricele": "epigastric",
    "epigastricelor": "epigastric",
    "epigastrici": "epigastric",
    "epigastricii": "epigastric",
    "epigastricilor": "epigastric",
    "epigastrico": "epigastric",
    "epigastricul": "epigastric",
    "epigastricule": "epigastric",
    "epigastricului": "epigastric",
    "epigastre": "epigastru",
    "epigastrele": "epigastru",
    "epigastrelor": "epigastru",
    "epigastrul": "epigastru",
    "epigastrule": "epigastru",
    "epigastrului": "epigastru",
    "epiglota": "epiglotă",
    "epiglote": "epiglotă",
    "epiglotei": "epiglotă",
    "epiglotele": "epiglotă",
    "epiglotelor": "epiglotă",
    "epigloto": "epiglotă",
    "epigoni": "epigon",
    "epigonii": "epigon",
    "epigonilor": "epigon",
    "epigonul": "epigon",
    "epigonule": "epigon",
    "epigonului": "epigon",
    "epigrafe": "epigraf",
    "epigrafele": "epigraf",
    "epigrafelor": "epigraf",
    "epigraful": "epigraf",
    "epigrafule": "epigraf",
    "epigrafului": "epigraf",
    "epigrama": "epigramă",
    "epigrame": "epigramă",
    "epigramei": "epigramă",
    "epigramele": "epigramă",
    "epigramelor": "epigramă",
    "epigramo": "epigramă",
    "epigramatica": "epigramatic",
    "epigramatică": "epigramatic",
    "epigramatice": "epigramatic",
    "epigramaticei": "epigramatic",
    "epigramaticele": "epigramatic",
    "epigramaticelor": "epigramatic",
    "epigramatici": "epigramatic",
    "epigramaticii": "epigramatic",
    "epigramaticilor": "epigramatic",
    "epigramatico": "epigramatic",
    "epigramaticul": "epigramatic",
    "epigramaticule": "epigramatic",
    "epigramaticului": "epigramatic",
    "epilepsia": "epilepsie",
    "epilepsiei": "epilepsie",
    "epilepsii": "epilepsie",
    "epilepsiile": "epilepsie",
    "epilepsiilor": "epilepsie",
    "epilepsio": "epilepsie",
    "epileptica": "epileptic",
    "epileptică": "epileptic",
    "epileptice": "epileptic",
    "epilepticei": "epileptic",
    "epilepticele": "epileptic",
    "epilepticelor": "epileptic",
    "epileptici": "epileptic",
    "epilepticii": "epileptic",
    "epilepticilor": "epileptic",
    "epileptico": "epileptic",
    "epilepticul": "epileptic",
    "epilepticule": "epileptic",
    "epilepticului": "epileptic",
    "epilogul": "epilog",
    "epilogule": "epilog",
    "epilogului": "epilog",
    "epiloguri": "epilog",
    "epilogurile": "epilog",
    "epilogurilor": "epilog",
    "epilogă": "epiloga",
    "epilogai": "epiloga",
    "epilogam": "epiloga",
    "epilogăm": "epiloga",
    "epilogând": "epiloga",
    "epilogându": "epiloga",
    "epilogară": "epiloga",
    "epilogarăm": "epiloga",
    "epilogarăți": "epiloga",
    "epilogase": "epiloga",
    "epilogasem": "epiloga",
    "epilogaseră": "epiloga",
    "epilogaserăm": "epiloga",
    "epilogaserăți": "epiloga",
    "epilogaseși": "epiloga",
    "epilogași": "epiloga",
    "epilogat": "epiloga",
    "epilogați": "epiloga",
    "epilogatu": "epiloga",
    "epilogau": "epiloga",
    "epiloghează": "epiloga",
    "epiloghez": "epiloga",
    "epilogheze": "epiloga",
    "epiloghezi": "epiloga",
    "neepilogând": "epiloga",
    "neepilogându": "epiloga",
    "nemaiepilogând": "epiloga",
    "nemaiepilogându": "epiloga",
    "epilogată": "epilogat",
    "epilogate": "epilogat",
    "epilogați": "epilogat",
    "episcoape": "episcop",
    "episcoapele": "episcop",
    "episcoapelor": "episcop",
    "episcopi": "episcop",
    "episcopii": "episcop",
    "episcopilor": "episcop",
    "episcopul": "episcop",
    "episcopule": "episcop",
    "episcopului": "episcop",
    "episcopala": "episcopal",
    "episcopală": "episcopal",
    "episcopale": "episcopal",
    "episcopalei": "episcopal",
    "episcopalele": "episcopal",
    "episcopalelor": "episcopal",
    "episcopali": "episcopal",
    "episcopalii": "episcopal",
    "episcopalilor": "episcopal",
    "episcopalo": "episcopal",
    "episcopalul": "episcopal",
    "episcopalule": "episcopal",
    "episcopalului": "episcopal",
    "episcopia": "episcopie",
    "episcopiei": "episcopie",
    "episcopii": "episcopie",
    "episcopiile": "episcopie",
    "episcopiilor": "episcopie",
    "episcopio": "episcopie",
    "episoade": "episod",
    "episoadele": "episod",
    "episoadelor": "episod",
    "episodul": "episod",
    "episodule": "episod",
    "episodului": "episod",
    "episodica": "episodic",
    "episodică": "episodic",
    "episodice": "episodic",
    "episodicei": "episodic",
    "episodicele": "episodic",
    "episodicelor": "episodic",
    "episodici": "episodic",
    "episodicii": "episodic",
    "episodicilor": "episodic",
    "episodico": "episodic",
    "episodicul": "episodic",
    "episodicule": "episodic",
    "episodicului": "episodic",
    "ep.": "episodul",
    "epistați": "epistat",
    "epistații": "epistat",
    "epistaților": "epistat",
    "epistatul": "epistat",
    "epistatule": "epistat",
    "epistatului": "epistat",
    "epistola": "epistolă",
    "epistole": "epistolă",
    "epistolei": "epistolă",
    "epistolele": "epistolă",
    "epistolelor": "epistolă",
    "epistolo": "epistolă",
    "epistolia": "epistolie",
    "epistoliei": "epistolie",
    "epistolii": "epistolie",
    "epistoliile": "epistolie",
    "epistoliilor": "epistolie",
    "epistolio": "epistolie",
    "epitaful": "epitaf",
    "epitafule": "epitaf",
    "epitafului": "epitaf",
    "epitafuri": "epitaf",
    "epitafurile": "epitaf",
    "epitafurilor": "epitaf",
    "epitelii": "epiteliu",
    "epiteliile": "epiteliu",
    "epiteliilor": "epiteliu",
    "epiteliul": "epiteliu",
    "epiteliule": "epiteliu",
    "epiteliului": "epiteliu",
    "epitete": "epitet",
    "epitetele": "epitet",
    "epitetelor": "epitet",
    "epitetul": "epitet",
    "epitetule": "epitet",
    "epitetului": "epitet",
    "epitropi": "epitrop",
    "epitropii": "epitrop",
    "epitropilor": "epitrop",
    "epitropul": "epitrop",
    "epitropule": "epitrop",
    "epitropului": "epitrop",
    "epoca": "epocă",
    "epoci": "epocă",
    "epocii": "epocă",
    "epocile": "epocă",
    "epocilor": "epocă",
    "epoco": "epocă",
    "epocala": "epocal",
    "epocală": "epocal",
    "epocale": "epocal",
    "epocalei": "epocal",
    "epocalele": "epocal",
    "epocalelor": "epocal",
    "epocali": "epocal",
    "epocalii": "epocal",
    "epocalilor": "epocal",
    "epocalo": "epocal",
    "epocalul": "epocal",
    "epocalule": "epocal",
    "epocalului": "epocal",
    "epoleți": "epolet",
    "epoleții": "epolet",
    "epoleților": "epolet",
    "epoletul": "epolet",
    "epoletule": "epolet",
    "epoletului": "epolet",
    "eponjul": "eponj",
    "eponjule": "eponj",
    "eponjului": "eponj",
    "epopeea": "epopee",
    "epopeeo": "epopee",
    "epopei": "epopee",
    "epopeii": "epopee",
    "epopeile": "epopee",
    "epopeilor": "epopee",
    "eposul": "epos",
    "eposule": "epos",
    "eposului": "epos",
    "eposuri": "epos",
    "eposurile": "epos",
    "eposurilor": "epos",
    "eprubeta": "eprubetă",
    "eprubete": "eprubetă",
    "eprubetei": "eprubetă",
    "eprubetele": "eprubetă",
    "eprubetelor": "eprubetă",
    "eprubeto": "eprubetă",
    "epruveta": "epruvetă",
    "epruvete": "epruvetă",
    "epruvetei": "epruvetă",
    "epruvetele": "epruvetă",
    "epruvetelor": "epruvetă",
    "epruveto": "epruvetă",
    "epuiză": "epuiza",
    "epuizai": "epuiza",
    "epuizam": "epuiza",
    "epuizăm": "epuiza",
    "epuizând": "epuiza",
    "epuizându": "epuiza",
    "epuizară": "epuiza",
    "epuizarăm": "epuiza",
    "epuizarăți": "epuiza",
    "epuizase": "epuiza",
    "epuizasem": "epuiza",
    "epuizaseră": "epuiza",
    "epuizaserăm": "epuiza",
    "epuizaserăți": "epuiza",
    "epuizaseși": "epuiza",
    "epuizași": "epuiza",
    "epuizat": "epuiza",
    "epuizați": "epuiza",
    "epuizatu": "epuiza",
    "epuizau": "epuiza",
    "epuizează": "epuiza",
    "epuizez": "epuiza",
    "epuizeze": "epuiza",
    "epuizezi": "epuiza",
    "neepuizând": "epuiza",
    "neepuizându": "epuiza",
    "nemaiepuizând": "epuiza",
    "nemaiepuizându": "epuiza",
    "epuizanta": "epuizant",
    "epuizantă": "epuizant",
    "epuizante": "epuizant",
    "epuizantei": "epuizant",
    "epuizantele": "epuizant",
    "epuizantelor": "epuizant",
    "epuizanți": "epuizant",
    "epuizanții": "epuizant",
    "epuizanților": "epuizant",
    "epuizanto": "epuizant",
    "epuizantul": "epuizant",
    "epuizantule": "epuizant",
    "epuizantului": "epuizant",
    "epuizarea": "epuizare",
    "epuizareo": "epuizare",
    "epuizări": "epuizare",
    "epuizării": "epuizare",
    "epuizările": "epuizare",
    "epuizărilor": "epuizare",
    "epuizata": "epuizat",
    "epuizată": "epuizat",
    "epuizate": "epuizat",
    "epuizatei": "epuizat",
    "epuizatele": "epuizat",
    "epuizatelor": "epuizat",
    "epuizați": "epuizat",
    "epuizații": "epuizat",
    "epuizaților": "epuizat",
    "epuizato": "epuizat",
    "epuizatul": "epuizat",
    "epuizatule": "epuizat",
    "epuizatului": "epuizat",
    "epură": "epura",
    "epurai": "epura",
    "epuram": "epura",
    "epurăm": "epura",
    "epurând": "epura",
    "epurându": "epura",
    "epurară": "epura",
    "epurarăm": "epura",
    "epurarăți": "epura",
    "epurase": "epura",
    "epurasem": "epura",
    "epuraseră": "epura",
    "epuraserăm": "epura",
    "epuraserăți": "epura",
    "epuraseși": "epura",
    "epurași": "epura",
    "epurat": "epura",
    "epurați": "epura",
    "epuratu": "epura",
    "epurau": "epura",
    "epurează": "epura",
    "epurez": "epura",
    "epureze": "epura",
    "epurezi": "epura",
    "neepurând": "epura",
    "neepurându": "epura",
    "nemaiepurând": "epura",
    "nemaiepurându": "epura",
    "epura": "epură",
    "epure": "epură",
    "epurei": "epură",
    "epurele": "epură",
    "epurelor": "epură",
    "epuro": "epură",
    "epurarea": "epurare",
    "epurareo": "epurare",
    "epurări": "epurare",
    "epurării": "epurare",
    "epurările": "epurare",
    "epurărilor": "epurare",
    "epurată": "epurat",
    "epurate": "epurat",
    "epurați": "epurat",
    "epurația": "epurație",
    "epurației": "epurație",
    "epurații": "epurație",
    "epurațiile": "epurație",
    "epurațiilor": "epurație",
    "epurațio": "epurație",
    "iera": "era",
    "era": "eră",
    "ere": "eră",
    "erei": "eră",
    "erele": "eră",
    "erelor": "eră",
    "ero": "eră",
    "e.n.": "era_noastră",
    "eradică": "eradica",
    "eradicai": "eradica",
    "eradicam": "eradica",
    "eradicăm": "eradica",
    "eradicând": "eradica",
    "eradicându": "eradica",
    "eradicară": "eradica",
    "eradicarăm": "eradica",
    "eradicarăți": "eradica",
    "eradicase": "eradica",
    "eradicasem": "eradica",
    "eradicaseră": "eradica",
    "eradicaserăm": "eradica",
    "eradicaserăți": "eradica",
    "eradicaseși": "eradica",
    "eradicași": "eradica",
    "eradicat": "eradica",
    "eradicați": "eradica",
    "eradicatu": "eradica",
    "eradicau": "eradica",
    "eradichează": "eradica",
    "eradichez": "eradica",
    "eradicheze": "eradica",
    "eradichezi": "eradica",
    "neeradicând": "eradica",
    "neeradicându": "eradica",
    "nemaieradicând": "eradica",
    "nemaieradicându": "eradica",
    "eradicarea": "eradicare",
    "eradicareo": "eradicare",
    "eradicări": "eradicare",
    "eradicării": "eradicare",
    "eradicările": "eradicare",
    "eradicărilor": "eradicare",
    "eradicata": "eradicat",
    "eradicată": "eradicat",
    "eradicate": "eradicat",
    "eradicatei": "eradicat",
    "eradicatele": "eradicat",
    "eradicatelor": "eradicat",
    "eradicați": "eradicat",
    "eradicații": "eradicat",
    "eradicaților": "eradicat",
    "eradicato": "eradicat",
    "eradicatul": "eradicat",
    "eradicatule": "eradicat",
    "eradicatului": "eradicat",
    "ieram": "eram",
    "erata": "erată",
    "erate": "erată",
    "eratei": "erată",
    "eratele": "erată",
    "eratelor": "erată",
    "erato": "erată",
    "erbaceea": "erbacee",
    "erbaceei": "erbacee",
    "erbaceele": "erbacee",
    "erbaceelor": "erbacee",
    "erbaceeo": "erbacee",
    "erbivora": "erbivor",
    "erbivoră": "erbivor",
    "erbivore": "erbivor",
    "erbivorei": "erbivor",
    "erbivorele": "erbivor",
    "erbivorelor": "erbivor",
    "erbivori": "erbivor",
    "erbivorii": "erbivor",
    "erbivorilor": "erbivor",
    "erbivoro": "erbivor",
    "erbivorul": "erbivor",
    "erbivorule": "erbivor",
    "erbivorului": "erbivor",
    "erecta": "erect",
    "erectă": "erect",
    "erecte": "erect",
    "erectei": "erect",
    "erectele": "erect",
    "erectelor": "erect",
    "erecți": "erect",
    "erecții": "erect",
    "erecților": "erect",
    "erecto": "erect",
    "erectul": "erect",
    "erectule": "erect",
    "erectului": "erect",
    "ereditara": "ereditar",
    "ereditară": "ereditar",
    "ereditare": "ereditar",
    "ereditarei": "ereditar",
    "ereditarele": "ereditar",
    "ereditarelor": "ereditar",
    "ereditari": "ereditar",
    "ereditarii": "ereditar",
    "ereditarilor": "ereditar",
    "ereditaro": "ereditar",
    "ereditarul": "ereditar",
    "ereditarule": "ereditar",
    "ereditarului": "ereditar",
    "ereditatea": "ereditate",
    "ereditateo": "ereditate",
    "eredități": "ereditate",
    "eredității": "ereditate",
    "ereditățile": "ereditate",
    "eredităților": "ereditate",
    "eresul": "eres",
    "eresule": "eres",
    "eresului": "eres",
    "eresuri": "eres",
    "eresurile": "eres",
    "eresurilor": "eres",
    "eretele": "erete",
    "eretelui": "erete",
    "ereți": "erete",
    "ereții": "erete",
    "ereților": "erete",
    "eretica": "eretic",
    "eretică": "eretic",
    "eretice": "eretic",
    "ereticei": "eretic",
    "ereticele": "eretic",
    "ereticelor": "eretic",
    "eretici": "eretic",
    "ereticii": "eretic",
    "ereticilor": "eretic",
    "eretico": "eretic",
    "ereticul": "eretic",
    "ereticule": "eretic",
    "ereticului": "eretic",
    "erezia": "erezie",
    "ereziei": "erezie",
    "erezii": "erezie",
    "ereziile": "erezie",
    "ereziilor": "erezie",
    "erezio": "erezie",
    "ergi": "erg",
    "ergii": "erg",
    "ergilor": "erg",
    "ergul": "erg",
    "ergule": "erg",
    "ergului": "erg",
    "erguri": "erg",
    "ergurile": "erg",
    "ergurilor": "erg",
    "ergonomica": "ergonomic",
    "ergonomică": "ergonomic",
    "ergonomice": "ergonomic",
    "ergonomicei": "ergonomic",
    "ergonomicele": "ergonomic",
    "ergonomicelor": "ergonomic",
    "ergonomici": "ergonomic",
    "ergonomicii": "ergonomic",
    "ergonomicilor": "ergonomic",
    "ergonomico": "ergonomic",
    "ergonomicul": "ergonomic",
    "ergonomicule": "ergonomic",
    "ergonomicului": "ergonomic",
    "ergoterapia": "ergoterapie",
    "ergoterapiei": "ergoterapie",
    "ergoterapii": "ergoterapie",
    "erijă": "erija",
    "erijai": "erija",
    "erijam": "erija",
    "erijăm": "erija",
    "erijând": "erija",
    "erijându": "erija",
    "erijară": "erija",
    "erijarăm": "erija",
    "erijarăți": "erija",
    "erijase": "erija",
    "erijasem": "erija",
    "erijaseră": "erija",
    "erijaserăm": "erija",
    "erijaserăți": "erija",
    "erijaseși": "erija",
    "erijași": "erija",
    "erijat": "erija",
    "erijați": "erija",
    "erijatu": "erija",
    "erijau": "erija",
    "erijează": "erija",
    "erijez": "erija",
    "erijeze": "erija",
    "erijezi": "erija",
    "neerijând": "erija",
    "neerijându": "erija",
    "nemaierijând": "erija",
    "nemaierijându": "erija",
    "erijată": "erijat",
    "erijate": "erijat",
    "erijați": "erijat",
    "eriteme": "eritem",
    "eritemele": "eritem",
    "eritemelor": "eritem",
    "eritemul": "eritem",
    "eritemule": "eritem",
    "eritemului": "eritem",
    "erizipele": "erizipel",
    "erizipelele": "erizipel",
    "erizipelelor": "erizipel",
    "erizipelul": "erizipel",
    "erizipelule": "erizipel",
    "erizipelului": "erizipel",
    "ermetica": "ermetic",
    "ermetică": "ermetic",
    "ermetice": "ermetic",
    "ermeticei": "ermetic",
    "ermeticele": "ermetic",
    "ermeticelor": "ermetic",
    "ermetici": "ermetic",
    "ermeticii": "ermetic",
    "ermeticilor": "ermetic",
    "ermetico": "ermetic",
    "ermeticul": "ermetic",
    "ermeticule": "ermetic",
    "ermeticului": "ermetic",
    "eroarea": "eroare",
    "eroareo": "eroare",
    "erori": "eroare",
    "erorii": "eroare",
    "erorile": "eroare",
    "erorilor": "eroare",
    "erodarea": "erodare",
    "erodări": "erodare",
    "erodării": "erodare",
    "erodările": "erodare",
    "erodărilor": "erodare",
    "eroica": "eroic",
    "eroică": "eroic",
    "eroice": "eroic",
    "eroicei": "eroic",
    "eroicele": "eroic",
    "eroicelor": "eroic",
    "eroici": "eroic",
    "eroicii": "eroic",
    "eroicilor": "eroic",
    "eroico": "eroic",
    "eroicul": "eroic",
    "eroicule": "eroic",
    "eroicului": "eroic",
    "eroina": "eroină",
    "eroine": "eroină",
    "eroinei": "eroină",
    "eroinele": "eroină",
    "eroinelor": "eroină",
    "eroino": "eroină",
    "eroismul": "eroism",
    "eroismule": "eroism",
    "eroismului": "eroism",
    "eronata": "eronat",
    "eronată": "eronat",
    "eronate": "eronat",
    "eronatei": "eronat",
    "eronatele": "eronat",
    "eronatelor": "eronat",
    "eronați": "eronat",
    "eronații": "eronat",
    "eronaților": "eronat",
    "eronato": "eronat",
    "eronatul": "eronat",
    "eronatule": "eronat",
    "eronatului": "eronat",
    "erotica": "erotic",
    "erotică": "erotic",
    "erotice": "erotic",
    "eroticei": "erotic",
    "eroticele": "erotic",
    "eroticelor": "erotic",
    "erotici": "erotic",
    "eroticii": "erotic",
    "eroticilor": "erotic",
    "erotico": "erotic",
    "eroticul": "erotic",
    "eroticule": "erotic",
    "eroticului": "erotic",
    "erotismul": "erotism",
    "erotismule": "erotism",
    "erotismului": "erotism",
    "eroi": "erou",
    "eroii": "erou",
    "eroilor": "erou",
    "eroul": "erou",
    "eroule": "erou",
    "eroului": "erou",
    "eroziunea": "eroziune",
    "eroziuneo": "eroziune",
    "eroziuni": "eroziune",
    "eroziunii": "eroziune",
    "eroziunile": "eroziune",
    "eroziunilor": "eroziune",
    "erudita": "erudit",
    "erudită": "erudit",
    "erudite": "erudit",
    "eruditei": "erudit",
    "eruditele": "erudit",
    "eruditelor": "erudit",
    "erudiți": "erudit",
    "erudiții": "erudit",
    "erudiților": "erudit",
    "erudito": "erudit",
    "eruditul": "erudit",
    "eruditule": "erudit",
    "eruditului": "erudit",
    "erup": "erupe",
    "erupă": "erupe",
    "erupând": "erupe",
    "erupându": "erupe",
    "erupea": "erupe",
    "erupeai": "erupe",
    "erupeam": "erupe",
    "erupeați": "erupe",
    "erupeau": "erupe",
    "erupem": "erupe",
    "erupeți": "erupe",
    "erupi": "erupe",
    "erupse": "erupe",
    "erupsei": "erupe",
    "erupseră": "erupe",
    "erupserăm": "erupe",
    "erupserăți": "erupe",
    "erupsese": "erupe",
    "erupsesem": "erupe",
    "erupseseră": "erupe",
    "erupseserăm": "erupe",
    "erupseserăți": "erupe",
    "erupseseși": "erupe",
    "erupseși": "erupe",
    "erupt": "erupe",
    "eruptu": "erupe",
    "neerupând": "erupe",
    "neerupându": "erupe",
    "nemaierupând": "erupe",
    "nemaierupându": "erupe",
    "eruptă": "erupt",
    "erupte": "erupt",
    "erupți": "erupt",
    "erupția": "erupție",
    "erupției": "erupție",
    "erupții": "erupție",
    "erupțiile": "erupție",
    "erupțiilor": "erupție",
    "erupțio": "erupție",
    "eruptiva": "eruptiv",
    "eruptivă": "eruptiv",
    "eruptive": "eruptiv",
    "eruptivei": "eruptiv",
    "eruptivele": "eruptiv",
    "eruptivelor": "eruptiv",
    "eruptivi": "eruptiv",
    "eruptivii": "eruptiv",
    "eruptivilor": "eruptiv",
    "eruptivo": "eruptiv",
    "eruptivul": "eruptiv",
    "eruptivule": "eruptiv",
    "eruptivului": "eruptiv",
    "eșafoade": "eșafod",
    "eșafoadele": "eșafod",
    "eșafoadelor": "eșafod",
    "eșafodul": "eșafod",
    "eșafodule": "eșafod",
    "eșafodului": "eșafod",
    "eșafodaje": "eșafodaj",
    "eșafodajele": "eșafodaj",
    "eșafodajelor": "eșafodaj",
    "eșafodajul": "eșafodaj",
    "eșafodajule": "eșafodaj",
    "eșafodajului": "eșafodaj",
    "eșaloane": "eșalon",
    "eșaloanele": "eșalon",
    "eșaloanelor": "eșalon",
    "eșalonul": "eșalon",
    "eșalonule": "eșalon",
    "eșalonului": "eșalon",
    "eșalonă": "eșalona",
    "eșalonai": "eșalona",
    "eșalonam": "eșalona",
    "eșalonăm": "eșalona",
    "eșalonând": "eșalona",
    "eșalonându": "eșalona",
    "eșalonară": "eșalona",
    "eșalonarăm": "eșalona",
    "eșalonarăți": "eșalona",
    "eșalonase": "eșalona",
    "eșalonasem": "eșalona",
    "eșalonaseră": "eșalona",
    "eșalonaserăm": "eșalona",
    "eșalonaserăți": "eșalona",
    "eșalonaseși": "eșalona",
    "eșalonași": "eșalona",
    "eșalonat": "eșalona",
    "eșalonați": "eșalona",
    "eșalonatu": "eșalona",
    "eșalonau": "eșalona",
    "eșalonează": "eșalona",
    "eșalonez": "eșalona",
    "eșaloneze": "eșalona",
    "eșalonezi": "eșalona",
    "neeșalonând": "eșalona",
    "neeșalonându": "eșalona",
    "nemaieșalonând": "eșalona",
    "nemaieșalonându": "eșalona",
    "eșalonarea": "eșalonare",
    "eșalonareo": "eșalonare",
    "eșalonări": "eșalonare",
    "eșalonării": "eșalonare",
    "eșalonările": "eșalonare",
    "eșalonărilor": "eșalonare",
    "eșalonată": "eșalonat",
    "eșalonate": "eșalonat",
    "eșalonați": "eșalonat",
    "eșantioane": "eșantion",
    "eșantioanele": "eșantion",
    "eșantioanelor": "eșantion",
    "eșantionul": "eșantion",
    "eșantionule": "eșantion",
    "eșantionului": "eșantion",
    "eșapamente": "eșapament",
    "eșapamentele": "eșapament",
    "eșapamentelor": "eșapament",
    "eșapamentul": "eșapament",
    "eșapamentule": "eșapament",
    "eșapamentului": "eșapament",
    "eșarfa": "eșarfă",
    "eșarfe": "eșarfă",
    "eșarfei": "eșarfă",
    "eșarfele": "eșarfă",
    "eșarfelor": "eșarfă",
    "eșarfo": "eșarfă",
    "escadra": "escadră",
    "escadre": "escadră",
    "escadrei": "escadră",
    "escadrele": "escadră",
    "escadrelor": "escadră",
    "escadro": "escadră",
    "escadrila": "escadrilă",
    "escadrile": "escadrilă",
    "escadrilei": "escadrilă",
    "escadrilele": "escadrilă",
    "escadrilelor": "escadrilă",
    "escadrilo": "escadrilă",
    "escadroane": "escadron",
    "escadroanele": "escadron",
    "escadroanelor": "escadron",
    "escadronul": "escadron",
    "escadronule": "escadron",
    "escadronului": "escadron",
    "escala": "escală",
    "escale": "escală",
    "escalei": "escală",
    "escalele": "escală",
    "escalelor": "escală",
    "escalo": "escală",
    "escaladă": "escalada",
    "escaladai": "escalada",
    "escaladam": "escalada",
    "escaladăm": "escalada",
    "escaladând": "escalada",
    "escaladându": "escalada",
    "escaladară": "escalada",
    "escaladarăm": "escalada",
    "escaladarăți": "escalada",
    "escaladase": "escalada",
    "escaladasem": "escalada",
    "escaladaseră": "escalada",
    "escaladaserăm": "escalada",
    "escaladaserăți": "escalada",
    "escaladaseși": "escalada",
    "escaladași": "escalada",
    "escaladat": "escalada",
    "escaladați": "escalada",
    "escaladatu": "escalada",
    "escaladau": "escalada",
    "escaladează": "escalada",
    "escaladez": "escalada",
    "escaladeze": "escalada",
    "escaladezi": "escalada",
    "neescaladând": "escalada",
    "neescaladându": "escalada",
    "nemaiescaladând": "escalada",
    "nemaiescaladându": "escalada",
    "escaladarea": "escaladare",
    "escaladareo": "escaladare",
    "escaladări": "escaladare",
    "escaladării": "escaladare",
    "escaladările": "escaladare",
    "escaladărilor": "escaladare",
    "escaladată": "escaladat",
    "escaladate": "escaladat",
    "escaladați": "escaladat",
    "escamotă": "escamota",
    "escamotai": "escamota",
    "escamotam": "escamota",
    "escamotăm": "escamota",
    "escamotând": "escamota",
    "escamotându": "escamota",
    "escamotară": "escamota",
    "escamotarăm": "escamota",
    "escamotarăți": "escamota",
    "escamotase": "escamota",
    "escamotasem": "escamota",
    "escamotaseră": "escamota",
    "escamotaserăm": "escamota",
    "escamotaserăți": "escamota",
    "escamotaseși": "escamota",
    "escamotași": "escamota",
    "escamotat": "escamota",
    "escamotați": "escamota",
    "escamotatu": "escamota",
    "escamotau": "escamota",
    "escamotează": "escamota",
    "escamotez": "escamota",
    "escamoteze": "escamota",
    "escamotezi": "escamota",
    "neescamotând": "escamota",
    "neescamotându": "escamota",
    "nemaiescamotând": "escamota",
    "nemaiescamotându": "escamota",
    "escamotabila": "escamotabil",
    "escamotabilă": "escamotabil",
    "escamotabile": "escamotabil",
    "escamotabilei": "escamotabil",
    "escamotabilele": "escamotabil",
    "escamotabilelor": "escamotabil",
    "escamotabili": "escamotabil",
    "escamotabilii": "escamotabil",
    "escamotabililor": "escamotabil",
    "escamotabilo": "escamotabil",
    "escamotabilul": "escamotabil",
    "escamotabilule": "escamotabil",
    "escamotabilului": "escamotabil",
    "escamotarea": "escamotare",
    "escamotareo": "escamotare",
    "escamotări": "escamotare",
    "escamotării": "escamotare",
    "escamotările": "escamotare",
    "escamotărilor": "escamotare",
    "escamotată": "escamotat",
    "escamotate": "escamotat",
    "escamotați": "escamotat",
    "escapada": "escapadă",
    "escapade": "escapadă",
    "escapadei": "escapadă",
    "escapadele": "escapadă",
    "escapadelor": "escapadă",
    "escapado": "escapadă",
    "escavatoare": "escavator",
    "escavatoarele": "escavator",
    "escavatoarelor": "escavator",
    "escavatorul": "escavator",
    "escavatorule": "escavator",
    "escavatorului": "escavator",
    "eschimoasa": "eschimoasă",
    "eschimoase": "eschimoasă",
    "eschimoasei": "eschimoasă",
    "eschimoasele": "eschimoasă",
    "eschimoaselor": "eschimoasă",
    "eschimoaso": "eschimoasă",
    "eschimoși": "eschimos",
    "eschimoșii": "eschimos",
    "eschimoșilor": "eschimos",
    "eschimosul": "eschimos",
    "eschimosule": "eschimos",
    "eschimosului": "eschimos",
    "eschivă": "eschiva",
    "eschivai": "eschiva",
    "eschivam": "eschiva",
    "eschivăm": "eschiva",
    "eschivând": "eschiva",
    "eschivându": "eschiva",
    "eschivară": "eschiva",
    "eschivarăm": "eschiva",
    "eschivarăți": "eschiva",
    "eschivase": "eschiva",
    "eschivasem": "eschiva",
    "eschivaseră": "eschiva",
    "eschivaserăm": "eschiva",
    "eschivaserăți": "eschiva",
    "eschivaseși": "eschiva",
    "eschivași": "eschiva",
    "eschivat": "eschiva",
    "eschivați": "eschiva",
    "eschivatu": "eschiva",
    "eschivau": "eschiva",
    "eschivează": "eschiva",
    "eschivez": "eschiva",
    "eschiveze": "eschiva",
    "eschivezi": "eschiva",
    "neeschivând": "eschiva",
    "neeschivându": "eschiva",
    "nemaieschivând": "eschiva",
    "nemaieschivându": "eschiva",
    "eschivată": "eschivat",
    "eschivate": "eschivat",
    "eschivați": "eschivat",
    "escortă": "escorta",
    "escortai": "escorta",
    "escortam": "escorta",
    "escortăm": "escorta",
    "escortând": "escorta",
    "escortându": "escorta",
    "escortară": "escorta",
    "escortarăm": "escorta",
    "escortarăți": "escorta",
    "escortase": "escorta",
    "escortasem": "escorta",
    "escortaseră": "escorta",
    "escortaserăm": "escorta",
    "escortaserăți": "escorta",
    "escortaseși": "escorta",
    "escortași": "escorta",
    "escortat": "escorta",
    "escortați": "escorta",
    "escortatu": "escorta",
    "escortau": "escorta",
    "escortează": "escorta",
    "escortez": "escorta",
    "escorteze": "escorta",
    "escortezi": "escorta",
    "neescortând": "escorta",
    "neescortându": "escorta",
    "nemaiescortând": "escorta",
    "nemaiescortându": "escorta",
    "escorta": "escortă",
    "escorte": "escortă",
    "escortei": "escortă",
    "escortele": "escortă",
    "escortelor": "escortă",
    "escorto": "escortă",
    "escortată": "escortat",
    "escortate": "escortat",
    "escortați": "escortat",
    "escroaca": "escroacă",
    "escroace": "escroacă",
    "escroacei": "escroacă",
    "escroacele": "escroacă",
    "escroacelor": "escroacă",
    "escroaco": "escroacă",
    "escroci": "escroc",
    "escrocii": "escroc",
    "escrocilor": "escroc",
    "escrocul": "escroc",
    "escrocule": "escroc",
    "escrocului": "escroc",
    "escrocă": "escroca",
    "escrocai": "escroca",
    "escrocam": "escroca",
    "escrocăm": "escroca",
    "escrocând": "escroca",
    "escrocându": "escroca",
    "escrocară": "escroca",
    "escrocarăm": "escroca",
    "escrocarăți": "escroca",
    "escrocase": "escroca",
    "escrocasem": "escroca",
    "escrocaseră": "escroca",
    "escrocaserăm": "escroca",
    "escrocaserăți": "escroca",
    "escrocaseși": "escroca",
    "escrocași": "escroca",
    "escrocat": "escroca",
    "escrocați": "escroca",
    "escrocatu": "escroca",
    "escrocau": "escroca",
    "escrochează": "escroca",
    "escrochez": "escroca",
    "escrocheze": "escroca",
    "escrochezi": "escroca",
    "neescrocând": "escroca",
    "neescrocându": "escroca",
    "nemaiescrocând": "escroca",
    "nemaiescrocându": "escroca",
    "escrocată": "escrocat",
    "escrocate": "escrocat",
    "escrocați": "escrocat",
    "escrocheria": "escrocherie",
    "escrocheriei": "escrocherie",
    "escrocherii": "escrocherie",
    "escrocheriile": "escrocherie",
    "escrocheriilor": "escrocherie",
    "escrocherio": "escrocherie",
    "eșecul": "eșec",
    "eșecule": "eșec",
    "eșecului": "eșec",
    "eșecuri": "eșec",
    "eșecurile": "eșec",
    "eșecurilor": "eșec",
    "eseista": "eseist",
    "eseistă": "eseist",
    "eseiste": "eseist",
    "eseistei": "eseist",
    "eseistele": "eseist",
    "eseistelor": "eseist",
    "eseiști": "eseist",
    "eseiștii": "eseist",
    "eseiștilor": "eseist",
    "eseisto": "eseist",
    "eseistul": "eseist",
    "eseistule": "eseist",
    "eseistului": "eseist",
    "eseista": "eseistă",
    "eseiste": "eseistă",
    "eseistei": "eseistă",
    "eseistele": "eseistă",
    "eseistelor": "eseistă",
    "eseisto": "eseistă",
    "esența": "esență",
    "esențe": "esență",
    "esenței": "esență",
    "esențele": "esență",
    "esențelor": "esență",
    "esențo": "esență",
    "esențiala": "esențial",
    "esențială": "esențial",
    "esențiale": "esențial",
    "esențialei": "esențial",
    "esențialele": "esențial",
    "esențialelor": "esențial",
    "esențiali": "esențial",
    "esențialii": "esențial",
    "esențialilor": "esențial",
    "esențialo": "esențial",
    "esențialul": "esențial",
    "esențialule": "esențial",
    "esențialului": "esențial",
    "eseul": "eseu",
    "eseule": "eseu",
    "eseului": "eseu",
    "eseuri": "eseu",
    "eseurile": "eseu",
    "eseurilor": "eseu",
    "esofage": "esofag",
    "esofagele": "esofag",
    "esofagelor": "esofag",
    "esofagul": "esofag",
    "esofagule": "esofag",
    "esofagului": "esofag",
    "esofaguri": "esofag",
    "esofagurile": "esofag",
    "esofagurilor": "esofag",
    "espadrila": "espadrilă",
    "espadrile": "espadrilă",
    "espadrilei": "espadrilă",
    "espadrilele": "espadrilă",
    "espadrilelor": "espadrilă",
    "espadrilo": "espadrilă",
    "esper.": "esperanto",
    "esperantoul": "esperanto",
    "esperantoule": "esperanto",
    "esperantoului": "esperanto",
    "esplanada": "esplanadă",
    "esplanade": "esplanadă",
    "esplanadei": "esplanadă",
    "esplanadele": "esplanadă",
    "esplanadelor": "esplanadă",
    "esplanado": "esplanadă",
    "E": "est",
    "estul": "est",
    "estule": "est",
    "estului": "est",
    "estacada": "estacadă",
    "estacade": "estacadă",
    "estacadei": "estacadă",
    "estacadele": "estacadă",
    "estacadelor": "estacadă",
    "estacado": "estacadă",
    "Estasiei": "Estasia",
    "estasiene": "estasian",
    "estasiatică": "estasiatic",
    "estasiatice": "estasiatic",
    "estasiaticei": "estasiatic",
    "estasiatici": "estasiatic",
    "estasiaticii": "estasiatic",
    "estasiaticilor": "estasiatic",
    "estasiaticul": "estasiatic",
    "estasiaticului": "estasiatic",
    "ieste": "este",
    "esteri": "ester",
    "esterii": "ester",
    "esterilor": "ester",
    "esterul": "ester",
    "esterule": "ester",
    "esterului": "ester",
    "esteți": "estet",
    "esteții": "estet",
    "esteților": "estet",
    "estetul": "estet",
    "estetule": "estet",
    "estetului": "estet",
    "esteta": "estetă",
    "estete": "estetă",
    "estetei": "estetă",
    "estetele": "estetă",
    "estetelor": "estetă",
    "esteto": "estetă",
    "estetica": "estetic",
    "estetică": "estetic",
    "estetice": "estetic",
    "esteticei": "estetic",
    "esteticele": "estetic",
    "esteticelor": "estetic",
    "estetici": "estetic",
    "esteticii": "estetic",
    "esteticilor": "estetic",
    "estetico": "estetic",
    "esteticul": "estetic",
    "esteticule": "estetic",
    "esteticului": "estetic",
    "estetica": "estetică",
    "estetici": "estetică",
    "esteticii": "estetică",
    "esteticile": "estetică",
    "esteticilor": "estetică",
    "estetico": "estetică",
    "eș'": "ești",
    "ieș'": "ești",
    "estica": "estic",
    "estică": "estic",
    "estice": "estic",
    "esticei": "estic",
    "esticele": "estic",
    "esticelor": "estic",
    "estici": "estic",
    "esticii": "estic",
    "esticilor": "estic",
    "estico": "estic",
    "esticul": "estic",
    "esticule": "estic",
    "esticului": "estic",
    "estimă": "estima",
    "estimai": "estima",
    "estimam": "estima",
    "estimăm": "estima",
    "estimând": "estima",
    "estimându": "estima",
    "estimară": "estima",
    "estimarăm": "estima",
    "estimarăți": "estima",
    "estimase": "estima",
    "estimasem": "estima",
    "estimaseră": "estima",
    "estimaserăm": "estima",
    "estimaserăți": "estima",
    "estimaseși": "estima",
    "estimași": "estima",
    "estimat": "estima",
    "estimați": "estima",
    "estimatu": "estima",
    "estimau": "estima",
    "estimează": "estima",
    "estimez": "estima",
    "estimeze": "estima",
    "estimezi": "estima",
    "neestimând": "estima",
    "neestimându": "estima",
    "nemaiestimând": "estima",
    "nemaiestimându": "estima",
    "estimarea": "estimare",
    "estimareo": "estimare",
    "estimări": "estimare",
    "estimării": "estimare",
    "estimările": "estimare",
    "estimărilor": "estimare",
    "estimată": "estimat",
    "estimate": "estimat",
    "estimați": "estimat",
    "estimația": "estimație",
    "estimației": "estimație",
    "estimații": "estimație",
    "estimațiile": "estimație",
    "estimațiilor": "estimație",
    "estimațio": "estimație",
    "estimativa": "estimativ",
    "estimativă": "estimativ",
    "estimative": "estimativ",
    "estimativei": "estimativ",
    "estimativele": "estimativ",
    "estimativelor": "estimativ",
    "estimativi": "estimativ",
    "estimativii": "estimativ",
    "estimativilor": "estimativ",
    "estimativo": "estimativ",
    "estimativul": "estimativ",
    "estimativule": "estimativ",
    "estimativului": "estimativ",
    "estivala": "estival",
    "estivală": "estival",
    "estivale": "estival",
    "estivalei": "estival",
    "estivalele": "estival",
    "estivalelor": "estival",
    "estivali": "estival",
    "estivalii": "estival",
    "estivalilor": "estival",
    "estivalo": "estival",
    "estivalul": "estival",
    "estivalule": "estival",
    "estivalului": "estival",
    "estompă": "estompa",
    "estompai": "estompa",
    "estompam": "estompa",
    "estompăm": "estompa",
    "estompând": "estompa",
    "estompându": "estompa",
    "estompară": "estompa",
    "estomparăm": "estompa",
    "estomparăți": "estompa",
    "estompase": "estompa",
    "estompasem": "estompa",
    "estompaseră": "estompa",
    "estompaserăm": "estompa",
    "estompaserăți": "estompa",
    "estompaseși": "estompa",
    "estompași": "estompa",
    "estompat": "estompa",
    "estompați": "estompa",
    "estompatu": "estompa",
    "estompau": "estompa",
    "estompează": "estompa",
    "estompez": "estompa",
    "estompeze": "estompa",
    "estompezi": "estompa",
    "neestompând": "estompa",
    "neestompându": "estompa",
    "nemaiestompând": "estompa",
    "nemaiestompându": "estompa",
    "estompa": "estompă",
    "estompe": "estompă",
    "estompei": "estompă",
    "estompele": "estompă",
    "estompelor": "estompă",
    "estompo": "estompă",
    "estomparea": "estompare",
    "estompareo": "estompare",
    "estompări": "estompare",
    "estompării": "estompare",
    "estompările": "estompare",
    "estompărilor": "estompare",
    "estompata": "estompat",
    "estompată": "estompat",
    "estompate": "estompat",
    "estompatei": "estompat",
    "estompatele": "estompat",
    "estompatelor": "estompat",
    "estompați": "estompat",
    "estompații": "estompat",
    "estompaților": "estompat",
    "estompato": "estompat",
    "estompatul": "estompat",
    "estompatule": "estompat",
    "estompatului": "estompat",
    "Estoniei": "Estonia",
    "estorcă": "estorca",
    "estorcai": "estorca",
    "estorcam": "estorca",
    "estorcăm": "estorca",
    "estorcând": "estorca",
    "estorcându": "estorca",
    "estorcară": "estorca",
    "estorcarăm": "estorca",
    "estorcarăți": "estorca",
    "estorcase": "estorca",
    "estorcasem": "estorca",
    "estorcaseră": "estorca",
    "estorcaserăm": "estorca",
    "estorcaserăți": "estorca",
    "estorcaseși": "estorca",
    "estorcași": "estorca",
    "estorcat": "estorca",
    "estorcați": "estorca",
    "estorcatu": "estorca",
    "estorcau": "estorca",
    "estorchează": "estorca",
    "estorchez": "estorca",
    "estorcheze": "estorca",
    "estorchezi": "estorca",
    "neestorcând": "estorca",
    "neestorcându": "estorca",
    "nemaiestorcând": "estorca",
    "nemaiestorcându": "estorca",
    "estorcată": "estorcat",
    "estorcate": "estorcat",
    "estorcați": "estorcat",
    "estrada": "estradă",
    "estrade": "estradă",
    "estradei": "estradă",
    "estradele": "estradă",
    "estradelor": "estradă",
    "estrado": "estradă",
    "estropierea": "estropiere",
    "estropiereo": "estropiere",
    "estropieri": "estropiere",
    "estropierii": "estropiere",
    "estropierile": "estropiere",
    "estropierilor": "estropiere",
    "estuare": "estuar",
    "estuarele": "estuar",
    "estuarelor": "estuar",
    "estuarul": "estuar",
    "estuarule": "estuar",
    "estuarului": "estuar",
    "eșuă": "eșua",
    "eșuai": "eșua",
    "eșuam": "eșua",
    "eșuăm": "eșua",
    "eșuând": "eșua",
    "eșuându": "eșua",
    "eșuară": "eșua",
    "eșuarăm": "eșua",
    "eșuarăți": "eșua",
    "eșuase": "eșua",
    "eșuasem": "eșua",
    "eșuaseră": "eșua",
    "eșuaserăm": "eșua",
    "eșuaserăți": "eșua",
    "eșuaseși": "eșua",
    "eșuași": "eșua",
    "eșuat": "eșua",
    "eșuați": "eșua",
    "eșuatu": "eșua",
    "eșuau": "eșua",
    "eșuează": "eșua",
    "eșuez": "eșua",
    "eșueze": "eșua",
    "eșuezi": "eșua",
    "neeșuând": "eșua",
    "neeșuându": "eșua",
    "nemaieșuând": "eșua",
    "nemaieșuându": "eșua",
    "eșuată": "eșuat",
    "eșuate": "eșuat",
    "eșuați": "eșuat",
    "et.al.": "et_alii",
    "etc": "et_cetera",
    "etc.": "et_cetera",
    "etaje": "etaj",
    "etajele": "etaj",
    "etajelor": "etaj",
    "etajul": "etaj",
    "etajule": "etaj",
    "etajului": "etaj",
    "etajă": "etaja",
    "etajai": "etaja",
    "etajam": "etaja",
    "etajăm": "etaja",
    "etajând": "etaja",
    "etajându": "etaja",
    "etajară": "etaja",
    "etajarăm": "etaja",
    "etajarăți": "etaja",
    "etajase": "etaja",
    "etajasem": "etaja",
    "etajaseră": "etaja",
    "etajaserăm": "etaja",
    "etajaserăți": "etaja",
    "etajaseși": "etaja",
    "etajași": "etaja",
    "etajat": "etaja",
    "etajați": "etaja",
    "etajatu": "etaja",
    "etajau": "etaja",
    "etajează": "etaja",
    "etajez": "etaja",
    "etajeze": "etaja",
    "etajezi": "etaja",
    "neetajând": "etaja",
    "neetajându": "etaja",
    "nemaietajând": "etaja",
    "nemaietajându": "etaja",
    "etajată": "etajat",
    "etajate": "etajat",
    "etajați": "etajat",
    "etajera": "etajeră",
    "etajere": "etajeră",
    "etajerei": "etajeră",
    "etajerele": "etajeră",
    "etajerelor": "etajeră",
    "etajero": "etajeră",
    "et.": "etajul",
    "etală": "etala",
    "etalai": "etala",
    "etalam": "etala",
    "etalăm": "etala",
    "etalând": "etala",
    "etalându": "etala",
    "etalară": "etala",
    "etalarăm": "etala",
    "etalarăți": "etala",
    "etalase": "etala",
    "etalasem": "etala",
    "etalaseră": "etala",
    "etalaserăm": "etala",
    "etalaserăți": "etala",
    "etalaseși": "etala",
    "etalași": "etala",
    "etalat": "etala",
    "etalați": "etala",
    "etalatu": "etala",
    "etalau": "etala",
    "etalează": "etala",
    "etalez": "etala",
    "etaleze": "etala",
    "etalezi": "etala",
    "neetalând": "etala",
    "neetalându": "etala",
    "nemaietalând": "etala",
    "nemaietalându": "etala",
    "etalaje": "etalaj",
    "etalajele": "etalaj",
    "etalajelor": "etalaj",
    "etalajul": "etalaj",
    "etalajule": "etalaj",
    "etalajului": "etalaj",
    "etalarea": "etalare",
    "etalareo": "etalare",
    "etalări": "etalare",
    "etalării": "etalare",
    "etalările": "etalare",
    "etalărilor": "etalare",
    "etalată": "etalat",
    "etalate": "etalat",
    "etalați": "etalat",
    "etaloane": "etalon",
    "etaloanele": "etalon",
    "etaloanelor": "etalon",
    "etalonul": "etalon",
    "etalonule": "etalon",
    "etalonului": "etalon",
    "etalonă": "etalona",
    "etalonai": "etalona",
    "etalonam": "etalona",
    "etalonăm": "etalona",
    "etalonând": "etalona",
    "etalonându": "etalona",
    "etalonară": "etalona",
    "etalonarăm": "etalona",
    "etalonarăți": "etalona",
    "etalonase": "etalona",
    "etalonasem": "etalona",
    "etalonaseră": "etalona",
    "etalonaserăm": "etalona",
    "etalonaserăți": "etalona",
    "etalonaseși": "etalona",
    "etalonași": "etalona",
    "etalonat": "etalona",
    "etalonați": "etalona",
    "etalonatu": "etalona",
    "etalonau": "etalona",
    "etalonează": "etalona",
    "etalonez": "etalona",
    "etaloneze": "etalona",
    "etalonezi": "etalona",
    "neetalonând": "etalona",
    "neetalonându": "etalona",
    "nemaietalonând": "etalona",
    "nemaietalonându": "etalona",
    "etalonarea": "etalonare",
    "etalonareo": "etalonare",
    "etalonări": "etalonare",
    "etalonării": "etalonare",
    "etalonările": "etalonare",
    "etalonărilor": "etalonare",
    "etalonată": "etalonat",
    "etalonate": "etalonat",
    "etalonați": "etalonat",
    "etamina": "etamină",
    "etamine": "etamină",
    "etaminei": "etamină",
    "etaminele": "etamină",
    "etaminelor": "etamină",
    "etamino": "etamină",
    "etanul": "etan",
    "etanule": "etan",
    "etanului": "etan",
    "etanșa": "etanș",
    "etanșă": "etanș",
    "etanșe": "etanș",
    "etanșei": "etanș",
    "etanșele": "etanș",
    "etanșelor": "etanș",
    "etanși": "etanș",
    "etanșii": "etanș",
    "etanșilor": "etanș",
    "etanșo": "etanș",
    "etanșul": "etanș",
    "etanșule": "etanș",
    "etanșului": "etanș",
    "etanșă": "etanșa",
    "etanșai": "etanșa",
    "etanșam": "etanșa",
    "etanșăm": "etanșa",
    "etanșând": "etanșa",
    "etanșându": "etanșa",
    "etanșară": "etanșa",
    "etanșarăm": "etanșa",
    "etanșarăți": "etanșa",
    "etanșase": "etanșa",
    "etanșasem": "etanșa",
    "etanșaseră": "etanșa",
    "etanșaserăm": "etanșa",
    "etanșaserăți": "etanșa",
    "etanșaseși": "etanșa",
    "etanșași": "etanșa",
    "etanșat": "etanșa",
    "etanșați": "etanșa",
    "etanșatu": "etanșa",
    "etanșau": "etanșa",
    "etanșează": "etanșa",
    "etanșez": "etanșa",
    "etanșeze": "etanșa",
    "etanșezi": "etanșa",
    "neetanșând": "etanșa",
    "neetanșându": "etanșa",
    "nemaietanșând": "etanșa",
    "nemaietanșându": "etanșa",
    "etanșarea": "etanșare",
    "etanșareo": "etanșare",
    "etanșări": "etanșare",
    "etanșării": "etanșare",
    "etanșările": "etanșare",
    "etanșărilor": "etanșare",
    "etanșată": "etanșat",
    "etanșate": "etanșat",
    "etanșați": "etanșat",
    "etapa": "etapă",
    "etape": "etapă",
    "etapei": "etapă",
    "etapele": "etapă",
    "etapelor": "etapă",
    "etapo": "etapă",
    "etatea": "etate",
    "etateo": "etate",
    "etăți": "etate",
    "etății": "etate",
    "etatiză": "etatiza",
    "etatizai": "etatiza",
    "etatizam": "etatiza",
    "etatizăm": "etatiza",
    "etatizând": "etatiza",
    "etatizându": "etatiza",
    "etatizară": "etatiza",
    "etatizarăm": "etatiza",
    "etatizarăți": "etatiza",
    "etatizase": "etatiza",
    "etatizasem": "etatiza",
    "etatizaseră": "etatiza",
    "etatizaserăm": "etatiza",
    "etatizaserăți": "etatiza",
    "etatizaseși": "etatiza",
    "etatizași": "etatiza",
    "etatizat": "etatiza",
    "etatizați": "etatiza",
    "etatizatu": "etatiza",
    "etatizau": "etatiza",
    "etatizează": "etatiza",
    "etatizez": "etatiza",
    "etatizeze": "etatiza",
    "etatizezi": "etatiza",
    "neetatizând": "etatiza",
    "neetatizându": "etatiza",
    "nemaietatizând": "etatiza",
    "nemaietatizându": "etatiza",
    "etatizarea": "etatizare",
    "etatizareo": "etatizare",
    "etatizări": "etatizare",
    "etatizării": "etatizare",
    "etatizările": "etatizare",
    "etatizărilor": "etatizare",
    "etatizată": "etatizat",
    "etatizate": "etatizat",
    "etatizați": "etatizat",
    "eteri": "eter",
    "eterii": "eter",
    "eterilor": "eter",
    "eterul": "eter",
    "eterule": "eter",
    "eterului": "eter",
    "eteruri": "eter",
    "eterurile": "eter",
    "eterurilor": "eter",
    "eterica": "eteric",
    "eterică": "eteric",
    "eterice": "eteric",
    "etericei": "eteric",
    "etericele": "eteric",
    "etericelor": "eteric",
    "eterici": "eteric",
    "etericii": "eteric",
    "etericilor": "eteric",
    "eterico": "eteric",
    "etericul": "eteric",
    "etericule": "eteric",
    "etericului": "eteric",
    "eteria": "eterie",
    "eteriei": "eterie",
    "eterii": "eterie",
    "eteriile": "eterie",
    "eteriilor": "eterie",
    "eterio": "eterie",
    "eterista": "eterist",
    "eteristă": "eterist",
    "eteriste": "eterist",
    "eteristei": "eterist",
    "eteristele": "eterist",
    "eteristelor": "eterist",
    "eteriști": "eterist",
    "eteriștii": "eterist",
    "eteriștilor": "eterist",
    "eteristo": "eterist",
    "eteristul": "eterist",
    "eteristule": "eterist",
    "eteristului": "eterist",
    "eterna": "etern",
    "eternă": "etern",
    "eterne": "etern",
    "eternei": "etern",
    "eternele": "etern",
    "eternelor": "etern",
    "eterni": "etern",
    "eternii": "etern",
    "eternilor": "etern",
    "eterno": "etern",
    "eternul": "etern",
    "eternule": "etern",
    "eternului": "etern",
    "eternitatea": "eternitate",
    "eternitateo": "eternitate",
    "eternități": "eternitate",
    "eternității": "eternitate",
    "eternitățile": "eternitate",
    "eternităților": "eternitate",
    "eterniză": "eterniza",
    "eternizai": "eterniza",
    "eternizam": "eterniza",
    "eternizăm": "eterniza",
    "eternizând": "eterniza",
    "eternizându": "eterniza",
    "eternizară": "eterniza",
    "eternizarăm": "eterniza",
    "eternizarăți": "eterniza",
    "eternizase": "eterniza",
    "eternizasem": "eterniza",
    "eternizaseră": "eterniza",
    "eternizaserăm": "eterniza",
    "eternizaserăți": "eterniza",
    "eternizaseși": "eterniza",
    "eternizași": "eterniza",
    "eternizat": "eterniza",
    "eternizați": "eterniza",
    "eternizatu": "eterniza",
    "eternizau": "eterniza",
    "eternizează": "eterniza",
    "eternizez": "eterniza",
    "eternizeze": "eterniza",
    "eternizezi": "eterniza",
    "neeternizând": "eterniza",
    "neeternizându": "eterniza",
    "nemaieternizând": "eterniza",
    "nemaieternizându": "eterniza",
    "eternizată": "eternizat",
    "eternizate": "eternizat",
    "eternizați": "eternizat",
    "eterodocși": "eterodox",
    "eterodocșii": "eterodox",
    "eterodocșilor": "eterodox",
    "eterodoxa": "eterodox",
    "eterodoxă": "eterodox",
    "eterodoxe": "eterodox",
    "eterodoxei": "eterodox",
    "eterodoxele": "eterodox",
    "eterodoxelor": "eterodox",
    "eterodoxo": "eterodox",
    "eterodoxul": "eterodox",
    "eterodoxule": "eterodox",
    "eterodoxului": "eterodox",
    "eterogena": "eterogen",
    "eterogenă": "eterogen",
    "eterogene": "eterogen",
    "eterogenei": "eterogen",
    "eterogenele": "eterogen",
    "eterogenelor": "eterogen",
    "eterogeni": "eterogen",
    "eterogenii": "eterogen",
    "eterogenilor": "eterogen",
    "eterogeno": "eterogen",
    "eterogenul": "eterogen",
    "eterogenule": "eterogen",
    "eterogenului": "eterogen",
    "eteromorfa": "eteromorf",
    "eteromorfă": "eteromorf",
    "eteromorfe": "eteromorf",
    "eteromorfei": "eteromorf",
    "eteromorfele": "eteromorf",
    "eteromorfelor": "eteromorf",
    "eteromorfi": "eteromorf",
    "eteromorfii": "eteromorf",
    "eteromorfilor": "eteromorf",
    "eteromorfo": "eteromorf",
    "eteromorful": "eteromorf",
    "eteromorfule": "eteromorf",
    "eteromorfului": "eteromorf",
    "etica": "etic",
    "etică": "etic",
    "etice": "etic",
    "eticei": "etic",
    "eticele": "etic",
    "eticelor": "etic",
    "etici": "etic",
    "eticii": "etic",
    "eticilor": "etic",
    "etico": "etic",
    "eticul": "etic",
    "eticule": "etic",
    "eticului": "etic",
    "etica": "etică",
    "etici": "etică",
    "eticii": "etică",
    "eticile": "etică",
    "eticilor": "etică",
    "etico": "etică",
    "etichetă": "eticheta",
    "etichetai": "eticheta",
    "etichetam": "eticheta",
    "etichetăm": "eticheta",
    "etichetând": "eticheta",
    "etichetându": "eticheta",
    "etichetară": "eticheta",
    "etichetarăm": "eticheta",
    "etichetarăți": "eticheta",
    "etichetase": "eticheta",
    "etichetasem": "eticheta",
    "etichetaseră": "eticheta",
    "etichetaserăm": "eticheta",
    "etichetaserăți": "eticheta",
    "etichetaseși": "eticheta",
    "etichetași": "eticheta",
    "etichetat": "eticheta",
    "etichetați": "eticheta",
    "etichetatu": "eticheta",
    "etichetau": "eticheta",
    "etichetează": "eticheta",
    "etichetez": "eticheta",
    "eticheteze": "eticheta",
    "etichetezi": "eticheta",
    "neetichetând": "eticheta",
    "neetichetându": "eticheta",
    "nemaietichetând": "eticheta",
    "nemaietichetându": "eticheta",
    "eticheta": "etichetă",
    "etichete": "etichetă",
    "etichetei": "etichetă",
    "etichetele": "etichetă",
    "etichetelor": "etichetă",
    "eticheto": "etichetă",
    "etichetarea": "etichetare",
    "etichetareo": "etichetare",
    "etichetări": "etichetare",
    "etichetării": "etichetare",
    "etichetările": "etichetare",
    "etichetărilor": "etichetare",
    "etichetata": "etichetat",
    "etichetată": "etichetat",
    "etichetate": "etichetat",
    "etichetatei": "etichetat",
    "etichetatele": "etichetat",
    "etichetatelor": "etichetat",
    "etichetați": "etichetat",
    "etichetații": "etichetat",
    "etichetaților": "etichetat",
    "etichetato": "etichetat",
    "etichetatul": "etichetat",
    "etichetatule": "etichetat",
    "etichetatului": "etichetat",
    "etili": "etil",
    "etilii": "etil",
    "etililor": "etil",
    "etilul": "etil",
    "etilule": "etil",
    "etilului": "etil",
    "etilena": "etilenă",
    "etilene": "etilenă",
    "etilenei": "etilenă",
    "etilenele": "etilenă",
    "etilenelor": "etilenă",
    "etileno": "etilenă",
    "etilica": "etilic",
    "etilică": "etilic",
    "etilice": "etilic",
    "etilicei": "etilic",
    "etilicele": "etilic",
    "etilicelor": "etilic",
    "etilici": "etilic",
    "etilicii": "etilic",
    "etilicilor": "etilic",
    "etilico": "etilic",
    "etilicul": "etilic",
    "etilicule": "etilic",
    "etilicului": "etilic",
    "etimologi": "etimolog",
    "etimologii": "etimolog",
    "etimologilor": "etimolog",
    "etimologul": "etimolog",
    "etimologule": "etimolog",
    "etimologului": "etimolog",
    "etimologa": "etimologă",
    "etimologe": "etimologă",
    "etimologei": "etimologă",
    "etimologele": "etimologă",
    "etimologelor": "etimologă",
    "etimologo": "etimologă",
    "etimologica": "etimologic",
    "etimologică": "etimologic",
    "etimologice": "etimologic",
    "etimologicei": "etimologic",
    "etimologicele": "etimologic",
    "etimologicelor": "etimologic",
    "etimologici": "etimologic",
    "etimologicii": "etimologic",
    "etimologicilor": "etimologic",
    "etimologico": "etimologic",
    "etimologicul": "etimologic",
    "etimologicule": "etimologic",
    "etimologicului": "etimologic",
    "etiologica": "etiologic",
    "etiologică": "etiologic",
    "etiologice": "etiologic",
    "etiologicei": "etiologic",
    "etiologicele": "etiologic",
    "etiologicelor": "etiologic",
    "etiologici": "etiologic",
    "etiologicii": "etiologic",
    "etiologicilor": "etiologic",
    "etiologico": "etiologic",
    "etiologicul": "etiologic",
    "etiologicule": "etiologic",
    "etiologicului": "etiologic",
    "etiologia": "etiologie",
    "etiologiei": "etiologie",
    "etiologii": "etiologie",
    "etiologiile": "etiologie",
    "etiologiilor": "etiologie",
    "etiologio": "etiologie",
    "etnica": "etnic",
    "etnică": "etnic",
    "etnice": "etnic",
    "etnicei": "etnic",
    "etnicele": "etnic",
    "etnicelor": "etnic",
    "etnici": "etnic",
    "etnicii": "etnic",
    "etnicilor": "etnic",
    "etnico": "etnic",
    "etnicul": "etnic",
    "etnicule": "etnic",
    "etnicului": "etnic",
    "etnografi": "etnograf",
    "etnografii": "etnograf",
    "etnografilor": "etnograf",
    "etnograful": "etnograf",
    "etnografule": "etnograf",
    "etnografului": "etnograf",
    "etnografa": "etnografă",
    "etnografe": "etnografă",
    "etnografei": "etnografă",
    "etnografele": "etnografă",
    "etnografelor": "etnografă",
    "etnografo": "etnografă",
    "etnografica": "etnografic",
    "etnografică": "etnografic",
    "etnografice": "etnografic",
    "etnograficei": "etnografic",
    "etnograficele": "etnografic",
    "etnograficelor": "etnografic",
    "etnografici": "etnografic",
    "etnograficii": "etnografic",
    "etnograficilor": "etnografic",
    "etnografico": "etnografic",
    "etnograficul": "etnografic",
    "etnograficule": "etnografic",
    "etnograficului": "etnografic",
    "etnologi": "etnolog",
    "etnologii": "etnolog",
    "etnologilor": "etnolog",
    "etnologul": "etnolog",
    "etnologule": "etnolog",
    "etnologului": "etnolog",
    "etnoloago": "etnologă",
    "etnologa": "etnologă",
    "etnologe": "etnologă",
    "etnologei": "etnologă",
    "etnologele": "etnologă",
    "etnologelor": "etnologă",
    "etnologica": "etnologic",
    "etnologică": "etnologic",
    "etnologice": "etnologic",
    "etnologicei": "etnologic",
    "etnologicele": "etnologic",
    "etnologicelor": "etnologic",
    "etnologici": "etnologic",
    "etnologicii": "etnologic",
    "etnologicilor": "etnologic",
    "etnologico": "etnologic",
    "etnologicul": "etnologic",
    "etnologicule": "etnologic",
    "etnologicului": "etnologic",
    "etola": "etolă",
    "etole": "etolă",
    "etolei": "etolă",
    "etolele": "etolă",
    "etolelor": "etolă",
    "etolo": "etolă",
    "etuva": "etuvă",
    "etuve": "etuvă",
    "etuvei": "etuvă",
    "etuvele": "etuvă",
    "etuvelor": "etuvă",
    "etuvo": "etuvă",
    "eul": "eu",
    "eului": "eu",
    "euri": "eu",
    "eurile": "eu",
    "eurilor": "eu",
    "îmi": "eu",
    "io": "eu",
    "m-": "eu",
    "mă": "eu",
    "mă-": "eu",
    "mi": "eu",
    "mi-": "eu",
    "mie": "eu",
    "mine": "eu",
    "eucalipți": "eucalipt",
    "eucalipții": "eucalipt",
    "eucalipților": "eucalipt",
    "eucaliptul": "eucalipt",
    "eucaliptule": "eucalipt",
    "eucaliptului": "eucalipt",
    "eufemisme": "eufemism",
    "eufemismele": "eufemism",
    "eufemismelor": "eufemism",
    "eufemismul": "eufemism",
    "eufemismule": "eufemism",
    "eufemismului": "eufemism",
    "eufonica": "eufonic",
    "eufonică": "eufonic",
    "eufonice": "eufonic",
    "eufonicei": "eufonic",
    "eufonicele": "eufonic",
    "eufonicelor": "eufonic",
    "eufonici": "eufonic",
    "eufonicii": "eufonic",
    "eufonicilor": "eufonic",
    "eufonico": "eufonic",
    "eufonicul": "eufonic",
    "eufonicule": "eufonic",
    "eufonicului": "eufonic",
    "eufonia": "eufonie",
    "eufoniei": "eufonie",
    "eufonii": "eufonie",
    "eufoniile": "eufonie",
    "eufoniilor": "eufonie",
    "eufonio": "eufonie",
    "euforica": "euforic",
    "euforică": "euforic",
    "euforice": "euforic",
    "euforicei": "euforic",
    "euforicele": "euforic",
    "euforicelor": "euforic",
    "euforici": "euforic",
    "euforicii": "euforic",
    "euforicilor": "euforic",
    "euforico": "euforic",
    "euforicul": "euforic",
    "euforicule": "euforic",
    "euforicului": "euforic",
    "euforia": "euforie",
    "euforiei": "euforie",
    "euforii": "euforie",
    "euforiile": "euforie",
    "euforiilor": "euforie",
    "euforio": "euforie",
    "Eugene": "Eugen",
    "eunuci": "eunuc",
    "eunucii": "eunuc",
    "eunucilor": "eunuc",
    "eunucul": "eunuc",
    "eunucule": "eunuc",
    "eunucului": "eunuc",
    "Eurasiei": "Eurasia",
    "eurasiană": "eurasian",
    "eurasiene": "eurasian",
    "eurasieni": "eurasian",
    "euritmica": "euritmic",
    "euritmică": "euritmic",
    "euritmice": "euritmic",
    "euritmicei": "euritmic",
    "euritmicele": "euritmic",
    "euritmicelor": "euritmic",
    "euritmici": "euritmic",
    "euritmicii": "euritmic",
    "euritmicilor": "euritmic",
    "euritmico": "euritmic",
    "euritmicul": "euritmic",
    "euritmicule": "euritmic",
    "euritmicului": "euritmic",
    "euritmia": "euritmie",
    "euritmiei": "euritmie",
    "euritmii": "euritmie",
    "euritmiile": "euritmie",
    "euritmiilor": "euritmie",
    "euritmio": "euritmie",
    "euro-asiatica": "euro-asiatic",
    "euro-asiatică": "euro-asiatic",
    "euro-asiatice": "euro-asiatic",
    "euro-asiaticei": "euro-asiatic",
    "euro-asiaticele": "euro-asiatic",
    "euro-asiaticelor": "euro-asiatic",
    "euro-asiatici": "euro-asiatic",
    "euro-asiaticii": "euro-asiatic",
    "euro-asiaticilor": "euro-asiatic",
    "euro-asiatico": "euro-asiatic",
    "euro-asiaticul": "euro-asiatic",
    "euro-asiaticule": "euro-asiatic",
    "euro-asiaticului": "euro-asiatic",
    "euroatlantica": "euroatlantic",
    "euroatlantică": "euroatlantic",
    "euroatlantice": "euroatlantic",
    "euroatlanticei": "euroatlantic",
    "euroatlanticele": "euroatlantic",
    "euroatlanticelor": "euroatlantic",
    "euroatlantici": "euroatlantic",
    "euroatlanticii": "euroatlantic",
    "euroatlanticilor": "euroatlantic",
    "euroatlantico": "euroatlantic",
    "euroatlanticul": "euroatlantic",
    "euroatlanticule": "euroatlantic",
    "euroatlanticului": "euroatlantic",
    "Europei": "Europa",
    "europeana": "european",
    "europeană": "european",
    "europeano": "european",
    "europeanul": "european",
    "europeanule": "european",
    "europeanului": "european",
    "europene": "european",
    "europenei": "european",
    "europenele": "european",
    "europenelor": "european",
    "europeni": "european",
    "europenii": "european",
    "europenilor": "european",
    "europeanca": "europeancă",
    "europeanco": "europeancă",
    "europence": "europeancă",
    "europencei": "europeancă",
    "europencele": "europeancă",
    "europencelor": "europeancă",
    "evul": "ev",
    "evule": "ev",
    "evului": "ev",
    "evuri": "ev",
    "evurile": "ev",
    "evurilor": "ev",
    "Evei": "Eva",
    "evacuă": "evacua",
    "evacuai": "evacua",
    "evacuam": "evacua",
    "evacuăm": "evacua",
    "evacuând": "evacua",
    "evacuându": "evacua",
    "evacuară": "evacua",
    "evacuarăm": "evacua",
    "evacuarăți": "evacua",
    "evacuase": "evacua",
    "evacuasem": "evacua",
    "evacuaseră": "evacua",
    "evacuaserăm": "evacua",
    "evacuaserăți": "evacua",
    "evacuaseși": "evacua",
    "evacuași": "evacua",
    "evacuat": "evacua",
    "evacuați": "evacua",
    "evacuatu": "evacua",
    "evacuau": "evacua",
    "evacuează": "evacua",
    "evacuez": "evacua",
    "evacueze": "evacua",
    "evacuezi": "evacua",
    "neevacuând": "evacua",
    "neevacuându": "evacua",
    "nemaievacuând": "evacua",
    "nemaievacuându": "evacua",
    "evacuabila": "evacuabil",
    "evacuabilă": "evacuabil",
    "evacuabile": "evacuabil",
    "evacuabilei": "evacuabil",
    "evacuabilele": "evacuabil",
    "evacuabilelor": "evacuabil",
    "evacuabili": "evacuabil",
    "evacuabilii": "evacuabil",
    "evacuabililor": "evacuabil",
    "evacuabilo": "evacuabil",
    "evacuabilul": "evacuabil",
    "evacuabilule": "evacuabil",
    "evacuabilului": "evacuabil",
    "evacuarea": "evacuare",
    "evacuareo": "evacuare",
    "evacuări": "evacuare",
    "evacuării": "evacuare",
    "evacuările": "evacuare",
    "evacuărilor": "evacuare",
    "evacuată": "evacuat",
    "evacuate": "evacuat",
    "evacuați": "evacuat",
    "evadă": "evada",
    "evadai": "evada",
    "evadam": "evada",
    "evadăm": "evada",
    "evadând": "evada",
    "evadându": "evada",
    "evadară": "evada",
    "evadarăm": "evada",
    "evadarăți": "evada",
    "evadase": "evada",
    "evadasem": "evada",
    "evadaseră": "evada",
    "evadaserăm": "evada",
    "evadaserăți": "evada",
    "evadaseși": "evada",
    "evadași": "evada",
    "evadat": "evada",
    "evadați": "evada",
    "evadatu": "evada",
    "evadau": "evada",
    "evadează": "evada",
    "evadez": "evada",
    "evadeze": "evada",
    "evadezi": "evada",
    "neevadând": "evada",
    "neevadându": "evada",
    "nemaievadând": "evada",
    "nemaievadându": "evada",
    "evadarea": "evadare",
    "evadareo": "evadare",
    "evadări": "evadare",
    "evadării": "evadare",
    "evadările": "evadare",
    "evadărilor": "evadare",
    "evadata": "evadat",
    "evadată": "evadat",
    "evadate": "evadat",
    "evadatei": "evadat",
    "evadatele": "evadat",
    "evadatelor": "evadat",
    "evadați": "evadat",
    "evadații": "evadat",
    "evadaților": "evadat",
    "evadato": "evadat",
    "evadatul": "evadat",
    "evadatule": "evadat",
    "evadatului": "evadat",
    "evadata": "evadată",
    "evadate": "evadată",
    "evadatei": "evadată",
    "evadatele": "evadată",
    "evadatelor": "evadată",
    "evadato": "evadată",
    "evaluă": "evalua",
    "evaluai": "evalua",
    "evaluam": "evalua",
    "evaluăm": "evalua",
    "evaluând": "evalua",
    "evaluându": "evalua",
    "evaluară": "evalua",
    "evaluarăm": "evalua",
    "evaluarăți": "evalua",
    "evaluase": "evalua",
    "evaluasem": "evalua",
    "evaluaseră": "evalua",
    "evaluaserăm": "evalua",
    "evaluaserăți": "evalua",
    "evaluaseși": "evalua",
    "evaluași": "evalua",
    "evaluat": "evalua",
    "evaluați": "evalua",
    "evaluatu": "evalua",
    "evaluau": "evalua",
    "evaluează": "evalua",
    "evaluez": "evalua",
    "evalueze": "evalua",
    "evaluezi": "evalua",
    "neevaluând": "evalua",
    "neevaluându": "evalua",
    "nemaievaluând": "evalua",
    "nemaievaluându": "evalua",
    "evaluarea": "evaluare",
    "evaluareo": "evaluare",
    "evaluări": "evaluare",
    "evaluării": "evaluare",
    "evaluările": "evaluare",
    "evaluărilor": "evaluare",
    "evaluată": "evaluat",
    "evaluate": "evaluat",
    "evaluați": "evaluat",
    "evanescenta": "evanescent",
    "evanescentă": "evanescent",
    "evanescente": "evanescent",
    "evanescentei": "evanescent",
    "evanescentele": "evanescent",
    "evanescentelor": "evanescent",
    "evanescenți": "evanescent",
    "evanescenții": "evanescent",
    "evanescenților": "evanescent",
    "evanescento": "evanescent",
    "evanescentul": "evanescent",
    "evanescentule": "evanescent",
    "evanescentului": "evanescent",
    "evangheliare": "evangheliar",
    "evangheliarele": "evangheliar",
    "evangheliarelor": "evangheliar",
    "evangheliarul": "evangheliar",
    "evangheliarule": "evangheliar",
    "evangheliarului": "evangheliar",
    "evanghelica": "evanghelic",
    "evanghelică": "evanghelic",
    "evanghelice": "evanghelic",
    "evanghelicei": "evanghelic",
    "evanghelicele": "evanghelic",
    "evanghelicelor": "evanghelic",
    "evanghelici": "evanghelic",
    "evanghelicii": "evanghelic",
    "evanghelicilor": "evanghelic",
    "evanghelico": "evanghelic",
    "evanghelicul": "evanghelic",
    "evanghelicule": "evanghelic",
    "evanghelicului": "evanghelic",
    "evanghelia": "evanghelie",
    "evangheliei": "evanghelie",
    "evanghelii": "evanghelie",
    "evangheliile": "evanghelie",
    "evangheliilor": "evanghelie",
    "evanghelio": "evanghelie",
    "evangheliști": "evanghelist",
    "evangheliștii": "evanghelist",
    "evangheliștilor": "evanghelist",
    "evanghelistul": "evanghelist",
    "evanghelistule": "evanghelist",
    "evanghelistului": "evanghelist",
    "evangheliză": "evangheliza",
    "evanghelizai": "evangheliza",
    "evanghelizam": "evangheliza",
    "evanghelizăm": "evangheliza",
    "evanghelizând": "evangheliza",
    "evanghelizându": "evangheliza",
    "evanghelizară": "evangheliza",
    "evanghelizarăm": "evangheliza",
    "evanghelizarăți": "evangheliza",
    "evanghelizase": "evangheliza",
    "evanghelizasem": "evangheliza",
    "evanghelizaseră": "evangheliza",
    "evanghelizaserăm": "evangheliza",
    "evanghelizaserăți": "evangheliza",
    "evanghelizaseși": "evangheliza",
    "evanghelizași": "evangheliza",
    "evanghelizat": "evangheliza",
    "evanghelizați": "evangheliza",
    "evanghelizatu": "evangheliza",
    "evanghelizau": "evangheliza",
    "evanghelizează": "evangheliza",
    "evanghelizez": "evangheliza",
    "evanghelizeze": "evangheliza",
    "evanghelizezi": "evangheliza",
    "neevanghelizând": "evangheliza",
    "neevanghelizându": "evangheliza",
    "nemaievanghelizând": "evangheliza",
    "nemaievanghelizându": "evangheliza",
    "evanghelizată": "evanghelizat",
    "evanghelizate": "evanghelizat",
    "evanghelizați": "evanghelizat",
    "evantaie": "evantai",
    "evantaiele": "evantai",
    "evantaielor": "evantai",
    "evantaiul": "evantai",
    "evantaiule": "evantai",
    "evantaiului": "evantai",
    "evapor": "evapora",
    "evaporă": "evapora",
    "evaporai": "evapora",
    "evaporam": "evapora",
    "evaporăm": "evapora",
    "evaporând": "evapora",
    "evaporându": "evapora",
    "evaporară": "evapora",
    "evaporarăm": "evapora",
    "evaporarăți": "evapora",
    "evaporase": "evapora",
    "evaporasem": "evapora",
    "evaporaseră": "evapora",
    "evaporaserăm": "evapora",
    "evaporaserăți": "evapora",
    "evaporaseși": "evapora",
    "evaporași": "evapora",
    "evaporat": "evapora",
    "evaporați": "evapora",
    "evaporatu": "evapora",
    "evaporau": "evapora",
    "evapore": "evapora",
    "evapori": "evapora",
    "neevaporând": "evapora",
    "neevaporându": "evapora",
    "nemaievaporând": "evapora",
    "nemaievaporându": "evapora",
    "evaporarea": "evaporare",
    "evaporareo": "evaporare",
    "evaporări": "evaporare",
    "evaporării": "evaporare",
    "evaporările": "evaporare",
    "evaporărilor": "evaporare",
    "evaporată": "evaporat",
    "evaporate": "evaporat",
    "evaporați": "evaporat",
    "evazionista": "evazionist",
    "evazionistă": "evazionist",
    "evazioniste": "evazionist",
    "evazionistei": "evazionist",
    "evazionistele": "evazionist",
    "evazionistelor": "evazionist",
    "evazioniști": "evazionist",
    "evazioniștii": "evazionist",
    "evazioniștilor": "evazionist",
    "evazionisto": "evazionist",
    "evazionistul": "evazionist",
    "evazionistule": "evazionist",
    "evazionistului": "evazionist",
    "evazionista": "evazionistă",
    "evazioniste": "evazionistă",
    "evazionistei": "evazionistă",
    "evazionistele": "evazionistă",
    "evazionistelor": "evazionistă",
    "evazionisto": "evazionistă",
    "evaziunea": "evaziune",
    "evaziuneo": "evaziune",
    "evaziuni": "evaziune",
    "evaziunii": "evaziune",
    "evaziunile": "evaziune",
    "evaziunilor": "evaziune",
    "evaziva": "evaziv",
    "evazivă": "evaziv",
    "evazive": "evaziv",
    "evazivei": "evaziv",
    "evazivele": "evaziv",
    "evazivelor": "evaziv",
    "evazivi": "evaziv",
    "evazivii": "evaziv",
    "evazivilor": "evaziv",
    "evazivo": "evaziv",
    "evazivul": "evaziv",
    "evazivule": "evaziv",
    "evazivului": "evaziv",
    "evenimente": "eveniment",
    "evenimentele": "eveniment",
    "evenimentelor": "eveniment",
    "evenimentul": "eveniment",
    "evenimentule": "eveniment",
    "evenimentului": "eveniment",
    "eventuala": "eventual",
    "eventuală": "eventual",
    "eventuale": "eventual",
    "eventualei": "eventual",
    "eventualele": "eventual",
    "eventualelor": "eventual",
    "eventuali": "eventual",
    "eventualii": "eventual",
    "eventualilor": "eventual",
    "eventualo": "eventual",
    "eventualul": "eventual",
    "eventualule": "eventual",
    "eventualului": "eventual",
    "eventualitatea": "eventualitate",
    "eventualitateo": "eventualitate",
    "eventualități": "eventualitate",
    "eventualității": "eventualitate",
    "eventualitățile": "eventualitate",
    "eventualităților": "eventualitate",
    "evidenta": "evident",
    "evidentă": "evident",
    "evidente": "evident",
    "evidentei": "evident",
    "evidentele": "evident",
    "evidentelor": "evident",
    "evidenți": "evident",
    "evidenții": "evident",
    "evidenților": "evident",
    "evidento": "evident",
    "evidentul": "evident",
    "evidentule": "evident",
    "evidentului": "evident",
    "evidența": "evidență",
    "evidențe": "evidență",
    "evidenței": "evidență",
    "evidențele": "evidență",
    "evidențelor": "evidență",
    "evidențo": "evidență",
    "evidențiai": "evidenția",
    "evidențiam": "evidenția",
    "evidențiară": "evidenția",
    "evidențiarăm": "evidenția",
    "evidențiarăți": "evidenția",
    "evidențiase": "evidenția",
    "evidențiasem": "evidenția",
    "evidențiaseră": "evidenția",
    "evidențiaserăm": "evidenția",
    "evidențiaserăți": "evidenția",
    "evidențiaseși": "evidenția",
    "evidențiași": "evidenția",
    "evidențiat": "evidenția",
    "evidențiați": "evidenția",
    "evidențiatu": "evidenția",
    "evidențiau": "evidenția",
    "evidențiază": "evidenția",
    "evidenție": "evidenția",
    "evidențiem": "evidenția",
    "evidențiez": "evidenția",
    "evidențieze": "evidenția",
    "evidențiezi": "evidenția",
    "evidențiind": "evidenția",
    "evidențiindu": "evidenția",
    "neevidențiind": "evidenția",
    "neevidențiindu": "evidenția",
    "nemaievidențiind": "evidenția",
    "nemaievidențiindu": "evidenția",
    "evidențiata": "evidențiat",
    "evidențiată": "evidențiat",
    "evidențiate": "evidențiat",
    "evidențiatei": "evidențiat",
    "evidențiatele": "evidențiat",
    "evidențiatelor": "evidențiat",
    "evidențiați": "evidențiat",
    "evidențiații": "evidențiat",
    "evidențiaților": "evidențiat",
    "evidențiato": "evidențiat",
    "evidențiatul": "evidențiat",
    "evidențiatule": "evidențiat",
    "evidențiatului": "evidențiat",
    "evidențiata": "evidențiată",
    "evidențiate": "evidențiată",
    "evidențiatei": "evidențiată",
    "evidențiatele": "evidențiată",
    "evidențiatelor": "evidențiată",
    "evidențiato": "evidențiată",
    "evidențierea": "evidențiere",
    "evidențiereo": "evidențiere",
    "evidențieri": "evidențiere",
    "evidențierii": "evidențiere",
    "evidențierile": "evidențiere",
    "evidențierilor": "evidențiere",
    "evit": "evita",
    "evită": "evita",
    "evitai": "evita",
    "evitam": "evita",
    "evităm": "evita",
    "evitând": "evita",
    "evitându": "evita",
    "evitară": "evita",
    "evitarăm": "evita",
    "evitarăți": "evita",
    "evitase": "evita",
    "evitasem": "evita",
    "evitaseră": "evita",
    "evitaserăm": "evita",
    "evitaserăți": "evita",
    "evitaseși": "evita",
    "evitași": "evita",
    "evitat": "evita",
    "evitați": "evita",
    "evitatu": "evita",
    "evitau": "evita",
    "evite": "evita",
    "eviți": "evita",
    "neevitând": "evita",
    "neevitându": "evita",
    "neevitat": "evita",
    "nemaievitând": "evita",
    "nemaievitându": "evita",
    "evitabila": "evitabil",
    "evitabilă": "evitabil",
    "evitabile": "evitabil",
    "evitabilei": "evitabil",
    "evitabilele": "evitabil",
    "evitabilelor": "evitabil",
    "evitabili": "evitabil",
    "evitabilii": "evitabil",
    "evitabililor": "evitabil",
    "evitabilo": "evitabil",
    "evitabilul": "evitabil",
    "evitabilule": "evitabil",
    "evitabilului": "evitabil",
    "evitarea": "evitare",
    "evitareo": "evitare",
    "evitări": "evitare",
    "evitării": "evitare",
    "evitările": "evitare",
    "evitărilor": "evitare",
    "evitată": "evitat",
    "evitate": "evitat",
    "evitați": "evitat",
    "evlavia": "evlavie",
    "evlaviei": "evlavie",
    "evlavii": "evlavie",
    "evlaviile": "evlavie",
    "evlaviilor": "evlavie",
    "evlavio": "evlavie",
    "evlavioasa": "evlavios",
    "evlavioasă": "evlavios",
    "evlavioase": "evlavios",
    "evlavioasei": "evlavios",
    "evlavioasele": "evlavios",
    "evlavioaselor": "evlavios",
    "evlavioaso": "evlavios",
    "evlavioși": "evlavios",
    "evlavioșii": "evlavios",
    "evlavioșilor": "evlavios",
    "evlaviosul": "evlavios",
    "evlaviosule": "evlavios",
    "evlaviosului": "evlavios",
    "evoc": "evoca",
    "evocă": "evoca",
    "evocai": "evoca",
    "evocam": "evoca",
    "evocăm": "evoca",
    "evocând": "evoca",
    "evocându": "evoca",
    "evocară": "evoca",
    "evocarăm": "evoca",
    "evocarăți": "evoca",
    "evocase": "evoca",
    "evocasem": "evoca",
    "evocaseră": "evoca",
    "evocaserăm": "evoca",
    "evocaserăți": "evoca",
    "evocaseși": "evoca",
    "evocași": "evoca",
    "evocat": "evoca",
    "evocați": "evoca",
    "evocatu": "evoca",
    "evocau": "evoca",
    "evoce": "evoca",
    "evoci": "evoca",
    "neevocând": "evoca",
    "neevocându": "evoca",
    "nemaievocând": "evoca",
    "nemaievocându": "evoca",
    "evocarea": "evocare",
    "evocareo": "evocare",
    "evocări": "evocare",
    "evocării": "evocare",
    "evocările": "evocare",
    "evocărilor": "evocare",
    "evocată": "evocat",
    "evocate": "evocat",
    "evocați": "evocat",
    "evocativa": "evocativ",
    "evocativă": "evocativ",
    "evocative": "evocativ",
    "evocativei": "evocativ",
    "evocativele": "evocativ",
    "evocativelor": "evocativ",
    "evocativi": "evocativ",
    "evocativii": "evocativ",
    "evocativilor": "evocativ",
    "evocativo": "evocativ",
    "evocativul": "evocativ",
    "evocativule": "evocativ",
    "evocativului": "evocativ",
    "evocatoare": "evocator",
    "evocatoarea": "evocator",
    "evocatoarei": "evocator",
    "evocatoarele": "evocator",
    "evocatoarelor": "evocator",
    "evocatoareo": "evocator",
    "evocatori": "evocator",
    "evocatorii": "evocator",
    "evocatorilor": "evocator",
    "evocatorul": "evocator",
    "evocatorule": "evocator",
    "evocatorului": "evocator",
    "evoluă": "evolua",
    "evoluai": "evolua",
    "evoluam": "evolua",
    "evoluăm": "evolua",
    "evoluând": "evolua",
    "evoluându": "evolua",
    "evoluară": "evolua",
    "evoluarăm": "evolua",
    "evoluarăți": "evolua",
    "evoluase": "evolua",
    "evoluasem": "evolua",
    "evoluaseră": "evolua",
    "evoluaserăm": "evolua",
    "evoluaserăți": "evolua",
    "evoluaseși": "evolua",
    "evoluași": "evolua",
    "evoluat": "evolua",
    "evoluați": "evolua",
    "evoluatu": "evolua",
    "evoluau": "evolua",
    "evoluează": "evolua",
    "evoluez": "evolua",
    "evolueze": "evolua",
    "evoluezi": "evolua",
    "neevoluând": "evolua",
    "neevoluându": "evolua",
    "nemaievoluând": "evolua",
    "nemaievoluându": "evolua",
    "evoluata": "evoluat",
    "evoluată": "evoluat",
    "evoluate": "evoluat",
    "evoluatei": "evoluat",
    "evoluatele": "evoluat",
    "evoluatelor": "evoluat",
    "evoluați": "evoluat",
    "evoluații": "evoluat",
    "evoluaților": "evoluat",
    "evoluato": "evoluat",
    "evoluatul": "evoluat",
    "evoluatule": "evoluat",
    "evoluatului": "evoluat",
    "evoluția": "evoluție",
    "evoluției": "evoluție",
    "evoluții": "evoluție",
    "evoluțiile": "evoluție",
    "evoluțiilor": "evoluție",
    "evoluțio": "evoluție",
    "evoluționismul": "evoluționism",
    "evoluționismule": "evoluționism",
    "evoluționismului": "evoluționism",
    "evoluționista": "evoluționist",
    "evoluționistă": "evoluționist",
    "evoluționiste": "evoluționist",
    "evoluționistei": "evoluționist",
    "evoluționistele": "evoluționist",
    "evoluționistelor": "evoluționist",
    "evoluționiști": "evoluționist",
    "evoluționiștii": "evoluționist",
    "evoluționiștilor": "evoluționist",
    "evoluționisto": "evoluționist",
    "evoluționistul": "evoluționist",
    "evoluționistule": "evoluționist",
    "evoluționistului": "evoluționist",
    "evoluționista": "evoluționistă",
    "evoluționiste": "evoluționistă",
    "evoluționistei": "evoluționistă",
    "evoluționistele": "evoluționistă",
    "evoluționistelor": "evoluționistă",
    "evoluționisto": "evoluționistă",
    "evolutiva": "evolutiv",
    "evolutivă": "evolutiv",
    "evolutive": "evolutiv",
    "evolutivei": "evolutiv",
    "evolutivele": "evolutiv",
    "evolutivelor": "evolutiv",
    "evolutivi": "evolutiv",
    "evolutivii": "evolutiv",
    "evolutivilor": "evolutiv",
    "evolutivo": "evolutiv",
    "evolutivul": "evolutiv",
    "evolutivule": "evolutiv",
    "evolutivului": "evolutiv",
    "evreica": "evreică",
    "evreice": "evreică",
    "evreicei": "evreică",
    "evreicele": "evreică",
    "evreicelor": "evreică",
    "evreico": "evreică",
    "evreiasca": "evreiesc",
    "evreiască": "evreiesc",
    "evreiasco": "evreiesc",
    "evreiescul": "evreiesc",
    "evreiescule": "evreiesc",
    "evreiescului": "evreiesc",
    "evreiești": "evreiesc",
    "evreieștii": "evreiesc",
    "evreieștile": "evreiesc",
    "evreieștilor": "evreiesc",
    "evrei": "evreu",
    "evreii": "evreu",
    "evreilor": "evreu",
    "evreul": "evreu",
    "evreule": "evreu",
    "evreului": "evreu",
    "ev.med.": "evul_mediu",
    "ex.lib.": "ex_libris",
    "e.o.": "ex_officio",
    "exacerbă": "exacerba",
    "exacerbai": "exacerba",
    "exacerbam": "exacerba",
    "exacerbăm": "exacerba",
    "exacerbând": "exacerba",
    "exacerbându": "exacerba",
    "exacerbară": "exacerba",
    "exacerbarăm": "exacerba",
    "exacerbarăți": "exacerba",
    "exacerbase": "exacerba",
    "exacerbasem": "exacerba",
    "exacerbaseră": "exacerba",
    "exacerbaserăm": "exacerba",
    "exacerbaserăți": "exacerba",
    "exacerbaseși": "exacerba",
    "exacerbași": "exacerba",
    "exacerbat": "exacerba",
    "exacerbați": "exacerba",
    "exacerbatu": "exacerba",
    "exacerbau": "exacerba",
    "exacerbează": "exacerba",
    "exacerbez": "exacerba",
    "exacerbeze": "exacerba",
    "exacerbezi": "exacerba",
    "neexacerbând": "exacerba",
    "neexacerbându": "exacerba",
    "nemaiexacerbând": "exacerba",
    "nemaiexacerbându": "exacerba",
    "exacerbarea": "exacerbare",
    "exacerbareo": "exacerbare",
    "exacerbări": "exacerbare",
    "exacerbării": "exacerbare",
    "exacerbările": "exacerbare",
    "exacerbărilor": "exacerbare",
    "exacerbata": "exacerbat",
    "exacerbată": "exacerbat",
    "exacerbate": "exacerbat",
    "exacerbatei": "exacerbat",
    "exacerbatele": "exacerbat",
    "exacerbatelor": "exacerbat",
    "exacerbați": "exacerbat",
    "exacerbații": "exacerbat",
    "exacerbaților": "exacerbat",
    "exacerbato": "exacerbat",
    "exacerbatul": "exacerbat",
    "exacerbatule": "exacerbat",
    "exacerbatului": "exacerbat",
    "exacta": "exact",
    "exactă": "exact",
    "exacte": "exact",
    "exactei": "exact",
    "exactele": "exact",
    "exactelor": "exact",
    "exacți": "exact",
    "exacții": "exact",
    "exacților": "exact",
    "exacto": "exact",
    "exactul": "exact",
    "exactule": "exact",
    "exactului": "exact",
    "iegzact": "exact",
    "iegzactă": "exactă",
    "exactitatea": "exactitate",
    "exactitateo": "exactitate",
    "exactități": "exactitate",
    "exactității": "exactitate",
    "exactitățile": "exactitate",
    "exactităților": "exactitate",
    "exactitudinea": "exactitudine",
    "exactitudineo": "exactitudine",
    "exactitudini": "exactitudine",
    "exactitudinii": "exactitudine",
    "exactitudinile": "exactitudine",
    "exactitudinilor": "exactitudine",
    "exageră": "exagera",
    "exagerai": "exagera",
    "exageram": "exagera",
    "exagerăm": "exagera",
    "exagerând": "exagera",
    "exagerându": "exagera",
    "exagerară": "exagera",
    "exagerarăm": "exagera",
    "exagerarăți": "exagera",
    "exagerase": "exagera",
    "exagerasem": "exagera",
    "exageraseră": "exagera",
    "exageraserăm": "exagera",
    "exageraserăți": "exagera",
    "exageraseși": "exagera",
    "exagerași": "exagera",
    "exagerat": "exagera",
    "exagerați": "exagera",
    "exageratu": "exagera",
    "exagerau": "exagera",
    "exagerează": "exagera",
    "exagerez": "exagera",
    "exagereze": "exagera",
    "exagerezi": "exagera",
    "neexagerând": "exagera",
    "neexagerându": "exagera",
    "nemaiexagerând": "exagera",
    "nemaiexagerându": "exagera",
    "exagerarea": "exagerare",
    "exagerareo": "exagerare",
    "exagerări": "exagerare",
    "exagerării": "exagerare",
    "exagerările": "exagerare",
    "exagerărilor": "exagerare",
    "exagerata": "exagerat",
    "exagerată": "exagerat",
    "exagerate": "exagerat",
    "exageratei": "exagerat",
    "exageratele": "exagerat",
    "exageratelor": "exagerat",
    "exagerați": "exagerat",
    "exagerații": "exagerat",
    "exageraților": "exagerat",
    "exagerato": "exagerat",
    "exageratul": "exagerat",
    "exageratule": "exagerat",
    "exageratului": "exagerat",
    "exagerația": "exagerație",
    "exagerației": "exagerație",
    "exagerații": "exagerație",
    "exagerațiile": "exagerație",
    "exagerațiilor": "exagerație",
    "exagerațio": "exagerație",
    "exal": "exala",
    "exală": "exala",
    "exalai": "exala",
    "exalam": "exala",
    "exalăm": "exala",
    "exalând": "exala",
    "exalându": "exala",
    "exalară": "exala",
    "exalarăm": "exala",
    "exalarăți": "exala",
    "exalase": "exala",
    "exalasem": "exala",
    "exalaseră": "exala",
    "exalaserăm": "exala",
    "exalaserăți": "exala",
    "exalaseși": "exala",
    "exalași": "exala",
    "exalat": "exala",
    "exalați": "exala",
    "exalatu": "exala",
    "exalau": "exala",
    "exale": "exala",
    "exali": "exala",
    "neexalând": "exala",
    "neexalându": "exala",
    "nemaiexalând": "exala",
    "nemaiexalându": "exala",
    "exalarea": "exalare",
    "exalareo": "exalare",
    "exalări": "exalare",
    "exalării": "exalare",
    "exalările": "exalare",
    "exalărilor": "exalare",
    "exalată": "exalat",
    "exalate": "exalat",
    "exalați": "exalat",
    "exalația": "exalație",
    "exalației": "exalație",
    "exalații": "exalație",
    "exalațiile": "exalație",
    "exalațiilor": "exalație",
    "exalațio": "exalație",
    "exalt": "exalta",
    "exaltă": "exalta",
    "exaltai": "exalta",
    "exaltam": "exalta",
    "exaltăm": "exalta",
    "exaltând": "exalta",
    "exaltându": "exalta",
    "exaltară": "exalta",
    "exaltarăm": "exalta",
    "exaltarăți": "exalta",
    "exaltase": "exalta",
    "exaltasem": "exalta",
    "exaltaseră": "exalta",
    "exaltaserăm": "exalta",
    "exaltaserăți": "exalta",
    "exaltaseși": "exalta",
    "exaltași": "exalta",
    "exaltat": "exalta",
    "exaltați": "exalta",
    "exaltatu": "exalta",
    "exaltau": "exalta",
    "exalte": "exalta",
    "exalți": "exalta",
    "neexaltând": "exalta",
    "neexaltându": "exalta",
    "nemaiexaltând": "exalta",
    "nemaiexaltându": "exalta",
    "exaltarea": "exaltare",
    "exaltareo": "exaltare",
    "exaltări": "exaltare",
    "exaltării": "exaltare",
    "exaltările": "exaltare",
    "exaltărilor": "exaltare",
    "exaltata": "exaltat",
    "exaltată": "exaltat",
    "exaltate": "exaltat",
    "exaltatei": "exaltat",
    "exaltatele": "exaltat",
    "exaltatelor": "exaltat",
    "exaltați": "exaltat",
    "exaltații": "exaltat",
    "exaltaților": "exaltat",
    "exaltato": "exaltat",
    "exaltatul": "exaltat",
    "exaltatule": "exaltat",
    "exaltatului": "exaltat",
    "examene": "examen",
    "examenele": "examen",
    "examenelor": "examen",
    "examenul": "examen",
    "examenule": "examen",
    "examenului": "examen",
    "examină": "examina",
    "examinai": "examina",
    "examinam": "examina",
    "examinăm": "examina",
    "examinând": "examina",
    "examinându": "examina",
    "examinară": "examina",
    "examinarăm": "examina",
    "examinarăți": "examina",
    "examinase": "examina",
    "examinasem": "examina",
    "examinaseră": "examina",
    "examinaserăm": "examina",
    "examinaserăți": "examina",
    "examinaseși": "examina",
    "examinași": "examina",
    "examinat": "examina",
    "examinați": "examina",
    "examinatu": "examina",
    "examinau": "examina",
    "examinează": "examina",
    "examinez": "examina",
    "examineze": "examina",
    "examinezi": "examina",
    "neexaminând": "examina",
    "neexaminându": "examina",
    "nemaiexaminând": "examina",
    "nemaiexaminându": "examina",
    "examinarea": "examinare",
    "examinareo": "examinare",
    "examinări": "examinare",
    "examinării": "examinare",
    "examinările": "examinare",
    "examinărilor": "examinare",
    "examinată": "examinat",
    "examinate": "examinat",
    "examinați": "examinat",
    "examinatoarea": "examinatoare",
    "examinatoarei": "examinatoare",
    "examinatoarele": "examinatoare",
    "examinatoarelor": "examinatoare",
    "examinatoareo": "examinatoare",
    "examinatoare": "examinator",
    "examinatoarea": "examinator",
    "examinatoarei": "examinator",
    "examinatoarele": "examinator",
    "examinatoarelor": "examinator",
    "examinatoareo": "examinator",
    "examinatori": "examinator",
    "examinatorii": "examinator",
    "examinatorilor": "examinator",
    "examinatorul": "examinator",
    "examinatorule": "examinator",
    "examinatorului": "examinator",
    "exantematice": "exantematic",
    "exantematicele": "exantematic",
    "exantematicelor": "exantematic",
    "exantematicul": "exantematic",
    "exantematicule": "exantematic",
    "exantematicului": "exantematic",
    "exasperă": "exaspera",
    "exasperai": "exaspera",
    "exasperam": "exaspera",
    "exasperăm": "exaspera",
    "exasperând": "exaspera",
    "exasperându": "exaspera",
    "exasperară": "exaspera",
    "exasperarăm": "exaspera",
    "exasperarăți": "exaspera",
    "exasperase": "exaspera",
    "exasperasem": "exaspera",
    "exasperaseră": "exaspera",
    "exasperaserăm": "exaspera",
    "exasperaserăți": "exaspera",
    "exasperaseși": "exaspera",
    "exasperași": "exaspera",
    "exasperat": "exaspera",
    "exasperați": "exaspera",
    "exasperatu": "exaspera",
    "exasperau": "exaspera",
    "exasperează": "exaspera",
    "exasperez": "exaspera",
    "exaspereze": "exaspera",
    "exasperezi": "exaspera",
    "neexasperând": "exaspera",
    "neexasperându": "exaspera",
    "nemaiexasperând": "exaspera",
    "nemaiexasperându": "exaspera",
    "exasperanta": "exasperant",
    "exasperantă": "exasperant",
    "exasperante": "exasperant",
    "exasperantei": "exasperant",
    "exasperantele": "exasperant",
    "exasperantelor": "exasperant",
    "exasperanți": "exasperant",
    "exasperanții": "exasperant",
    "exasperanților": "exasperant",
    "exasperanto": "exasperant",
    "exasperantul": "exasperant",
    "exasperantule": "exasperant",
    "exasperantului": "exasperant",
    "exasperarea": "exasperare",
    "exasperareo": "exasperare",
    "exasperări": "exasperare",
    "exasperării": "exasperare",
    "exasperările": "exasperare",
    "exasperărilor": "exasperare",
    "exasperata": "exasperat",
    "exasperată": "exasperat",
    "exasperate": "exasperat",
    "exasperatei": "exasperat",
    "exasperatele": "exasperat",
    "exasperatelor": "exasperat",
    "exasperați": "exasperat",
    "exasperații": "exasperat",
    "exasperaților": "exasperat",
    "exasperato": "exasperat",
    "exasperatul": "exasperat",
    "exasperatule": "exasperat",
    "exasperatului": "exasperat",
    "excavă": "excava",
    "excavai": "excava",
    "excavam": "excava",
    "excavăm": "excava",
    "excavând": "excava",
    "excavându": "excava",
    "excavară": "excava",
    "excavarăm": "excava",
    "excavarăți": "excava",
    "excavase": "excava",
    "excavasem": "excava",
    "excavaseră": "excava",
    "excavaserăm": "excava",
    "excavaserăți": "excava",
    "excavaseși": "excava",
    "excavași": "excava",
    "excavat": "excava",
    "excavați": "excava",
    "excavatu": "excava",
    "excavau": "excava",
    "excavează": "excava",
    "excavez": "excava",
    "excaveze": "excava",
    "excavezi": "excava",
    "neexcavând": "excava",
    "neexcavându": "excava",
    "nemaiexcavând": "excava",
    "nemaiexcavându": "excava",
    "excavarea": "excavare",
    "excavareo": "excavare",
    "excavări": "excavare",
    "excavării": "excavare",
    "excavările": "excavare",
    "excavărilor": "excavare",
    "excavată": "excavat",
    "excavate": "excavat",
    "excavați": "excavat",
    "excavația": "excavație",
    "excavației": "excavație",
    "excavații": "excavație",
    "excavațiile": "excavație",
    "excavațiilor": "excavație",
    "excavațio": "excavație",
    "excavatoare": "excavator",
    "excavatoarele": "excavator",
    "excavatoarelor": "excavator",
    "excavatorul": "excavator",
    "excavatorule": "excavator",
    "excavatorului": "excavator",
    "excedente": "excedent",
    "excedentele": "excedent",
    "excedentelor": "excedent",
    "excedentul": "excedent",
    "excedentule": "excedent",
    "excedentului": "excedent",
    "excedentara": "excedentar",
    "excedentară": "excedentar",
    "excedentare": "excedentar",
    "excedentarei": "excedentar",
    "excedentarele": "excedentar",
    "excedentarelor": "excedentar",
    "excedentari": "excedentar",
    "excedentarii": "excedentar",
    "excedentarilor": "excedentar",
    "excedentarul": "excedentar",
    "excedentarului": "excedentar",
    "excelă": "excela",
    "excelai": "excela",
    "excelam": "excela",
    "excelăm": "excela",
    "excelând": "excela",
    "excelându": "excela",
    "excelară": "excela",
    "excelarăm": "excela",
    "excelarăți": "excela",
    "excelase": "excela",
    "excelasem": "excela",
    "excelaseră": "excela",
    "excelaserăm": "excela",
    "excelaserăți": "excela",
    "excelaseși": "excela",
    "excelași": "excela",
    "excelat": "excela",
    "excelați": "excela",
    "excelatu": "excela",
    "excelau": "excela",
    "excelează": "excela",
    "excelez": "excela",
    "exceleze": "excela",
    "excelezi": "excela",
    "neexcelând": "excela",
    "neexcelându": "excela",
    "nemaiexcelând": "excela",
    "nemaiexcelându": "excela",
    "excelată": "excelat",
    "excelate": "excelat",
    "excelați": "excelat",
    "excelenta": "excelent",
    "excelentă": "excelent",
    "excelente": "excelent",
    "excelentei": "excelent",
    "excelentele": "excelent",
    "excelentelor": "excelent",
    "excelenți": "excelent",
    "excelenții": "excelent",
    "excelenților": "excelent",
    "excelento": "excelent",
    "excelentul": "excelent",
    "excelentule": "excelent",
    "excelentului": "excelent",
    "E.": "Excelență",
    "Exc.": "Excelență",
    "excelența": "excelență",
    "excelențe": "excelență",
    "excelenței": "excelență",
    "excelențele": "excelență",
    "excelențelor": "excelență",
    "excelențo": "excelență",
    "excentrica": "excentric",
    "excentrică": "excentric",
    "excentrice": "excentric",
    "excentricei": "excentric",
    "excentricele": "excentric",
    "excentricelor": "excentric",
    "excentrici": "excentric",
    "excentricii": "excentric",
    "excentricilor": "excentric",
    "excentrico": "excentric",
    "excentricul": "excentric",
    "excentricule": "excentric",
    "excentricului": "excentric",
    "excentritatea": "excentritate",
    "excentritateo": "excentritate",
    "excentrități": "excentritate",
    "excentrității": "excentritate",
    "excentritățile": "excentritate",
    "excentrităților": "excentritate",
    "exceptă": "excepta",
    "exceptai": "excepta",
    "exceptam": "excepta",
    "exceptăm": "excepta",
    "exceptând": "excepta",
    "exceptându": "excepta",
    "exceptară": "excepta",
    "exceptarăm": "excepta",
    "exceptarăți": "excepta",
    "exceptase": "excepta",
    "exceptasem": "excepta",
    "exceptaseră": "excepta",
    "exceptaserăm": "excepta",
    "exceptaserăți": "excepta",
    "exceptaseși": "excepta",
    "exceptași": "excepta",
    "exceptat": "excepta",
    "exceptați": "excepta",
    "exceptatu": "excepta",
    "exceptau": "excepta",
    "exceptează": "excepta",
    "exceptez": "excepta",
    "excepteze": "excepta",
    "exceptezi": "excepta",
    "neexceptând": "excepta",
    "neexceptându": "excepta",
    "nemaiexceptând": "excepta",
    "nemaiexceptându": "excepta",
    "exceptarea": "exceptare",
    "exceptareo": "exceptare",
    "exceptări": "exceptare",
    "exceptării": "exceptare",
    "exceptările": "exceptare",
    "exceptărilor": "exceptare",
    "exceptată": "exceptat",
    "exceptate": "exceptat",
    "exceptați": "exceptat",
    "excepția": "excepție",
    "excepției": "excepție",
    "excepții": "excepție",
    "excepțiile": "excepție",
    "excepțiilor": "excepție",
    "excepțio": "excepție",
    "excepționala": "excepțional",
    "excepțională": "excepțional",
    "excepționale": "excepțional",
    "excepționalei": "excepțional",
    "excepționalele": "excepțional",
    "excepționalelor": "excepțional",
    "excepționali": "excepțional",
    "excepționalii": "excepțional",
    "excepționalilor": "excepțional",
    "excepționalo": "excepțional",
    "excepționalul": "excepțional",
    "excepționalule": "excepțional",
    "excepționalului": "excepțional",
    "excese": "exces",
    "excesele": "exces",
    "exceselor": "exces",
    "excesul": "exces",
    "excesule": "exces",
    "excesului": "exces",
    "excesiva": "excesiv",
    "excesivă": "excesiv",
    "excesive": "excesiv",
    "excesivei": "excesiv",
    "excesivele": "excesiv",
    "excesivelor": "excesiv",
    "excesivi": "excesiv",
    "excesivii": "excesiv",
    "excesivilor": "excesiv",
    "excesivo": "excesiv",
    "excesivul": "excesiv",
    "excesivule": "excesiv",
    "excesivului": "excesiv",
    "excit": "excita",
    "excită": "excita",
    "excitai": "excita",
    "excitam": "excita",
    "excităm": "excita",
    "excitând": "excita",
    "excitându": "excita",
    "excitară": "excita",
    "excitarăm": "excita",
    "excitarăți": "excita",
    "excitase": "excita",
    "excitasem": "excita",
    "excitaseră": "excita",
    "excitaserăm": "excita",
    "excitaserăți": "excita",
    "excitaseși": "excita",
    "excitași": "excita",
    "excitat": "excita",
    "excitați": "excita",
    "excitatu": "excita",
    "excitau": "excita",
    "excite": "excita",
    "exciți": "excita",
    "neexcitând": "excita",
    "neexcitându": "excita",
    "nemaiexcitând": "excita",
    "nemaiexcitându": "excita",
    "excitabila": "excitabil",
    "excitabilă": "excitabil",
    "excitabile": "excitabil",
    "excitabilei": "excitabil",
    "excitabilele": "excitabil",
    "excitabilelor": "excitabil",
    "excitabili": "excitabil",
    "excitabilii": "excitabil",
    "excitabililor": "excitabil",
    "excitabilo": "excitabil",
    "excitabilul": "excitabil",
    "excitabilule": "excitabil",
    "excitabilului": "excitabil",
    "excitabilitatea": "excitabilitate",
    "excitabilitateo": "excitabilitate",
    "excitabilități": "excitabilitate",
    "excitabilității": "excitabilitate",
    "excitabilitățile": "excitabilitate",
    "excitabilităților": "excitabilitate",
    "excitarea": "excitare",
    "excitareo": "excitare",
    "excitări": "excitare",
    "excitării": "excitare",
    "excitările": "excitare",
    "excitărilor": "excitare",
    "excitata": "excitat",
    "excitată": "excitat",
    "excitate": "excitat",
    "excitatei": "excitat",
    "excitatele": "excitat",
    "excitatelor": "excitat",
    "excitați": "excitat",
    "excitații": "excitat",
    "excitaților": "excitat",
    "excitato": "excitat",
    "excitatul": "excitat",
    "excitatule": "excitat",
    "excitatului": "excitat",
    "excitația": "excitație",
    "excitației": "excitație",
    "excitații": "excitație",
    "excitațiile": "excitație",
    "excitațiilor": "excitație",
    "excitațio": "excitație",
    "excitatoare": "excitator",
    "excitatoarea": "excitator",
    "excitatoarei": "excitator",
    "excitatoarele": "excitator",
    "excitatoarelor": "excitator",
    "excitatoareo": "excitator",
    "excitatori": "excitator",
    "excitatorii": "excitator",
    "excitatorilor": "excitator",
    "excitatorul": "excitator",
    "excitatorule": "excitator",
    "excitatorului": "excitator",
    "exclam": "exclama",
    "exclamă": "exclama",
    "exclamai": "exclama",
    "exclamam": "exclama",
    "exclamăm": "exclama",
    "exclamând": "exclama",
    "exclamându": "exclama",
    "exclamară": "exclama",
    "exclamarăm": "exclama",
    "exclamarăți": "exclama",
    "exclamase": "exclama",
    "exclamasem": "exclama",
    "exclamaseră": "exclama",
    "exclamaserăm": "exclama",
    "exclamaserăți": "exclama",
    "exclamaseși": "exclama",
    "exclamași": "exclama",
    "exclamat": "exclama",
    "exclamați": "exclama",
    "exclamatu": "exclama",
    "exclamau": "exclama",
    "exclame": "exclama",
    "exclami": "exclama",
    "neexclamând": "exclama",
    "neexclamându": "exclama",
    "nemaiexclamând": "exclama",
    "nemaiexclamându": "exclama",
    "exclamarea": "exclamare",
    "exclamareo": "exclamare",
    "exclamări": "exclamare",
    "exclamării": "exclamare",
    "exclamările": "exclamare",
    "exclamărilor": "exclamare",
    "exclamată": "exclamat",
    "exclamate": "exclamat",
    "exclamați": "exclamat",
    "exclamația": "exclamație",
    "exclamației": "exclamație",
    "exclamații": "exclamație",
    "exclamațiile": "exclamație",
    "exclamațiilor": "exclamație",
    "exclamațio": "exclamație",
    "exclamativa": "exclamativ",
    "exclamativă": "exclamativ",
    "exclamative": "exclamativ",
    "exclamativei": "exclamativ",
    "exclamativele": "exclamativ",
    "exclamativelor": "exclamativ",
    "exclamativi": "exclamativ",
    "exclamativii": "exclamativ",
    "exclamativilor": "exclamativ",
    "exclamativo": "exclamativ",
    "exclamativul": "exclamativ",
    "exclamativule": "exclamativ",
    "exclamativului": "exclamativ",
    "exclud": "exclude",
    "excludă": "exclude",
    "excludea": "exclude",
    "excludeai": "exclude",
    "excludeam": "exclude",
    "excludeați": "exclude",
    "excludeau": "exclude",
    "excludem": "exclude",
    "excludeți": "exclude",
    "exclus": "exclude",
    "excluse": "exclude",
    "exclusei": "exclude",
    "excluseră": "exclude",
    "excluserăm": "exclude",
    "excluserăți": "exclude",
    "exclusese": "exclude",
    "exclusesem": "exclude",
    "excluseseră": "exclude",
    "excluseserăm": "exclude",
    "excluseserăți": "exclude",
    "excluseseși": "exclude",
    "excluseși": "exclude",
    "exclusu": "exclude",
    "excluzând": "exclude",
    "excluzându": "exclude",
    "excluzi": "exclude",
    "neexcluzând": "exclude",
    "neexcluzându": "exclude",
    "nemaiexcluzând": "exclude",
    "nemaiexcluzându": "exclude",
    "excluderea": "excludere",
    "excludereo": "excludere",
    "excluderi": "excludere",
    "excluderii": "excludere",
    "excluderile": "excludere",
    "excluderilor": "excludere",
    "exclusa": "exclus",
    "exclusă": "exclus",
    "excluse": "exclus",
    "exclusei": "exclus",
    "exclusele": "exclus",
    "excluselor": "exclus",
    "excluși": "exclus",
    "exclușii": "exclus",
    "exclușilor": "exclus",
    "excluso": "exclus",
    "exclusul": "exclus",
    "exclusule": "exclus",
    "exclusului": "exclus",
    "excl.": "exclusiv",
    "exclusiva": "exclusiv",
    "exclusivă": "exclusiv",
    "exclusive": "exclusiv",
    "exclusivei": "exclusiv",
    "exclusivele": "exclusiv",
    "exclusivelor": "exclusiv",
    "exclusivi": "exclusiv",
    "exclusivii": "exclusiv",
    "exclusivilor": "exclusiv",
    "exclusivo": "exclusiv",
    "exclusivul": "exclusiv",
    "exclusivule": "exclusiv",
    "exclusivului": "exclusiv",
    "exclusivitatea": "exclusivitate",
    "exclusivitateo": "exclusivitate",
    "exclusivități": "exclusivitate",
    "exclusivității": "exclusivitate",
    "exclusivitățile": "exclusivitate",
    "exclusivităților": "exclusivitate",
    "excomunic": "excomunica",
    "excomunică": "excomunica",
    "excomunicai": "excomunica",
    "excomunicam": "excomunica",
    "excomunicăm": "excomunica",
    "excomunicând": "excomunica",
    "excomunicându": "excomunica",
    "excomunicară": "excomunica",
    "excomunicarăm": "excomunica",
    "excomunicarăți": "excomunica",
    "excomunicase": "excomunica",
    "excomunicasem": "excomunica",
    "excomunicaseră": "excomunica",
    "excomunicaserăm": "excomunica",
    "excomunicaserăți": "excomunica",
    "excomunicaseși": "excomunica",
    "excomunicași": "excomunica",
    "excomunicat": "excomunica",
    "excomunicați": "excomunica",
    "excomunicatu": "excomunica",
    "excomunicau": "excomunica",
    "excomunice": "excomunica",
    "excomunici": "excomunica",
    "neexcomunicând": "excomunica",
    "neexcomunicându": "excomunica",
    "nemaiexcomunicând": "excomunica",
    "nemaiexcomunicându": "excomunica",
    "excomunicarea": "excomunicare",
    "excomunicareo": "excomunicare",
    "excomunicări": "excomunicare",
    "excomunicării": "excomunicare",
    "excomunicările": "excomunicare",
    "excomunicărilor": "excomunicare",
    "excomunicată": "excomunicat",
    "excomunicate": "excomunicat",
    "excomunicați": "excomunicat",
    "excremente": "excrement",
    "excrementele": "excrement",
    "excrementelor": "excrement",
    "excrementul": "excrement",
    "excrementule": "excrement",
    "excrementului": "excrement",
    "excrescența": "excrescență",
    "excrescențe": "excrescență",
    "excrescenței": "excrescență",
    "excrescențele": "excrescență",
    "excrescențelor": "excrescență",
    "excrescențo": "excrescență",
    "excretă": "excreta",
    "excretai": "excreta",
    "excretam": "excreta",
    "excretăm": "excreta",
    "excretând": "excreta",
    "excretându": "excreta",
    "excretară": "excreta",
    "excretarăm": "excreta",
    "excretarăți": "excreta",
    "excretase": "excreta",
    "excretasem": "excreta",
    "excretaseră": "excreta",
    "excretaserăm": "excreta",
    "excretaserăți": "excreta",
    "excretaseși": "excreta",
    "excretași": "excreta",
    "excretat": "excreta",
    "excretați": "excreta",
    "excretatu": "excreta",
    "excretau": "excreta",
    "excretează": "excreta",
    "excretez": "excreta",
    "excreteze": "excreta",
    "excretezi": "excreta",
    "neexcretând": "excreta",
    "neexcretându": "excreta",
    "nemaiexcretând": "excreta",
    "nemaiexcretându": "excreta",
    "excretată": "excretat",
    "excretate": "excretat",
    "excretați": "excretat",
    "excreția": "excreție",
    "excreției": "excreție",
    "excreții": "excreție",
    "excrețiile": "excreție",
    "excrețiilor": "excreție",
    "excrețio": "excreție",
    "excretoare": "excretor",
    "excretoarea": "excretor",
    "excretoarei": "excretor",
    "excretoarele": "excretor",
    "excretoarelor": "excretor",
    "excretoareo": "excretor",
    "excretori": "excretor",
    "excretorii": "excretor",
    "excretorilor": "excretor",
    "excretorul": "excretor",
    "excretorule": "excretor",
    "excretorului": "excretor",
    "excursul": "excurs",
    "excursule": "excurs",
    "excursului": "excurs",
    "excursuri": "excurs",
    "excursurile": "excurs",
    "excursurilor": "excurs",
    "excursia": "excursie",
    "excursiei": "excursie",
    "excursii": "excursie",
    "excursiile": "excursie",
    "excursiilor": "excursie",
    "excursio": "excursie",
    "excursioniști": "excursionist",
    "excursioniștii": "excursionist",
    "excursioniștilor": "excursionist",
    "excursionistul": "excursionist",
    "excursionistule": "excursionist",
    "excursionistului": "excursionist",
    "excursionista": "excursionistă",
    "excursioniste": "excursionistă",
    "excursionistei": "excursionistă",
    "excursionistele": "excursionistă",
    "excursionistelor": "excursionistă",
    "excursionisto": "excursionistă",
    "execrabila": "execrabil",
    "execrabilă": "execrabil",
    "execrabile": "execrabil",
    "execrabilei": "execrabil",
    "execrabilele": "execrabil",
    "execrabilelor": "execrabil",
    "execrabili": "execrabil",
    "execrabilii": "execrabil",
    "execrabililor": "execrabil",
    "execrabilo": "execrabil",
    "execrabilul": "execrabil",
    "execrabilule": "execrabil",
    "execrabilului": "execrabil",
    "execut": "executa",
    "execută": "executa",
    "executai": "executa",
    "executam": "executa",
    "executăm": "executa",
    "executând": "executa",
    "executându": "executa",
    "executară": "executa",
    "executarăm": "executa",
    "executarăți": "executa",
    "executase": "executa",
    "executasem": "executa",
    "executaseră": "executa",
    "executaserăm": "executa",
    "executaserăți": "executa",
    "executaseși": "executa",
    "executași": "executa",
    "executat": "executa",
    "executați": "executa",
    "executatu": "executa",
    "executau": "executa",
    "execute": "executa",
    "execuți": "executa",
    "neexecutând": "executa",
    "neexecutându": "executa",
    "nemaiexecutând": "executa",
    "nemaiexecutându": "executa",
    "executanți": "executant",
    "executanții": "executant",
    "executanților": "executant",
    "executantul": "executant",
    "executantule": "executant",
    "executantului": "executant",
    "executanta": "executantă",
    "executante": "executantă",
    "executantei": "executantă",
    "executantele": "executantă",
    "executantelor": "executantă",
    "executanto": "executantă",
    "executarea": "executare",
    "executareo": "executare",
    "executări": "executare",
    "executării": "executare",
    "executările": "executare",
    "executărilor": "executare",
    "executată": "executat",
    "executate": "executat",
    "executați": "executat",
    "execuția": "execuție",
    "execuției": "execuție",
    "execuții": "execuție",
    "execuțiile": "execuție",
    "execuțiilor": "execuție",
    "execuțio": "execuție",
    "executiva": "executiv",
    "executivă": "executiv",
    "executive": "executiv",
    "executivei": "executiv",
    "executivele": "executiv",
    "executivelor": "executiv",
    "executivi": "executiv",
    "executivii": "executiv",
    "executivilor": "executiv",
    "executivo": "executiv",
    "executivul": "executiv",
    "executivule": "executiv",
    "executivului": "executiv",
    "executoarea": "executoare",
    "executoarei": "executoare",
    "executoarele": "executoare",
    "executoarelor": "executoare",
    "executoareo": "executoare",
    "executoare": "executor",
    "executoarea": "executor",
    "executoarei": "executor",
    "executoarele": "executor",
    "executoarelor": "executor",
    "executoareo": "executor",
    "executori": "executor",
    "executorii": "executor",
    "executorilor": "executor",
    "executorul": "executor",
    "executorule": "executor",
    "executorului": "executor",
    "executoria": "executoriu",
    "executorie": "executoriu",
    "executoriei": "executoriu",
    "executorii": "executoriu",
    "executoriii": "executoriu",
    "executoriile": "executoriu",
    "executoriilor": "executoriu",
    "executorio": "executoriu",
    "executoriul": "executoriu",
    "executoriule": "executoriu",
    "executoriului": "executoriu",
    "exegeți": "exeget",
    "exegeții": "exeget",
    "exegeților": "exeget",
    "exegetul": "exeget",
    "exegetule": "exeget",
    "exegetului": "exeget",
    "exegetica": "exegetic",
    "exegetică": "exegetic",
    "exegetice": "exegetic",
    "exegeticei": "exegetic",
    "exegeticele": "exegetic",
    "exegeticelor": "exegetic",
    "exegetici": "exegetic",
    "exegeticii": "exegetic",
    "exegeticilor": "exegetic",
    "exegetico": "exegetic",
    "exegeticul": "exegetic",
    "exegeticule": "exegetic",
    "exegeticului": "exegetic",
    "exegeza": "exegeză",
    "exegeze": "exegeză",
    "exegezei": "exegeză",
    "exegezele": "exegeză",
    "exegezelor": "exegeză",
    "exegezo": "exegeză",
    "exemplara": "exemplar",
    "exemplară": "exemplar",
    "exemplare": "exemplar",
    "exemplarei": "exemplar",
    "exemplarele": "exemplar",
    "exemplarelor": "exemplar",
    "exemplari": "exemplar",
    "exemplarii": "exemplar",
    "exemplarilor": "exemplar",
    "exemplaro": "exemplar",
    "exemplarul": "exemplar",
    "exemplarule": "exemplar",
    "exemplarului": "exemplar",
    "ex.": "exemplare",
    "e.c.": "exempli_causa",
    "e.g.": "exempli_gratia",
    "exemplific": "exemplifica",
    "exemplifică": "exemplifica",
    "exemplificai": "exemplifica",
    "exemplificam": "exemplifica",
    "exemplificăm": "exemplifica",
    "exemplificând": "exemplifica",
    "exemplificându": "exemplifica",
    "exemplificară": "exemplifica",
    "exemplificarăm": "exemplifica",
    "exemplificarăți": "exemplifica",
    "exemplificase": "exemplifica",
    "exemplificasem": "exemplifica",
    "exemplificaseră": "exemplifica",
    "exemplificaserăm": "exemplifica",
    "exemplificaserăți": "exemplifica",
    "exemplificaseși": "exemplifica",
    "exemplificași": "exemplifica",
    "exemplificat": "exemplifica",
    "exemplificați": "exemplifica",
    "exemplificatu": "exemplifica",
    "exemplificau": "exemplifica",
    "exemplifice": "exemplifica",
    "exemplifici": "exemplifica",
    "neexemplificând": "exemplifica",
    "neexemplificându": "exemplifica",
    "nemaiexemplificând": "exemplifica",
    "nemaiexemplificându": "exemplifica",
    "exemplificarea": "exemplificare",
    "exemplificareo": "exemplificare",
    "exemplificări": "exemplificare",
    "exemplificării": "exemplificare",
    "exemplificările": "exemplificare",
    "exemplificărilor": "exemplificare",
    "expl.": "exemplificare",
    "exemplificată": "exemplificat",
    "exemplificate": "exemplificat",
    "exemplificați": "exemplificat",
    "ex.": "exemplu",
    "exemple": "exemplu",
    "exemplele": "exemplu",
    "exemplelor": "exemplu",
    "exemplul": "exemplu",
    "exemplule": "exemplu",
    "exemplului": "exemplu",
    "exercit": "exercita",
    "exercită": "exercita",
    "exercitai": "exercita",
    "exercitam": "exercita",
    "exercităm": "exercita",
    "exercitând": "exercita",
    "exercitându": "exercita",
    "exercitară": "exercita",
    "exercitarăm": "exercita",
    "exercitarăți": "exercita",
    "exercitase": "exercita",
    "exercitasem": "exercita",
    "exercitaseră": "exercita",
    "exercitaserăm": "exercita",
    "exercitaserăți": "exercita",
    "exercitaseși": "exercita",
    "exercitași": "exercita",
    "exercitat": "exercita",
    "exercitați": "exercita",
    "exercitatu": "exercita",
    "exercitau": "exercita",
    "exercite": "exercita",
    "exerciți": "exercita",
    "neexercitând": "exercita",
    "neexercitându": "exercita",
    "nemaiexercitând": "exercita",
    "nemaiexercitându": "exercita",
    "exercitarea": "exercitare",
    "exercitareo": "exercitare",
    "exercitări": "exercitare",
    "exercitării": "exercitare",
    "exercitările": "exercitare",
    "exercitărilor": "exercitare",
    "exercitată": "exercitat",
    "exercitate": "exercitat",
    "exercitați": "exercitat",
    "exerciții": "exercițiu",
    "exercițiile": "exercițiu",
    "exercițiilor": "exercițiu",
    "exercițiul": "exercițiu",
    "exercițiule": "exercițiu",
    "exercițiului": "exercițiu",
    "exersă": "exersa",
    "exersai": "exersa",
    "exersam": "exersa",
    "exersăm": "exersa",
    "exersând": "exersa",
    "exersându": "exersa",
    "exersară": "exersa",
    "exersarăm": "exersa",
    "exersarăți": "exersa",
    "exersase": "exersa",
    "exersasem": "exersa",
    "exersaseră": "exersa",
    "exersaserăm": "exersa",
    "exersaserăți": "exersa",
    "exersaseși": "exersa",
    "exersași": "exersa",
    "exersat": "exersa",
    "exersați": "exersa",
    "exersatu": "exersa",
    "exersau": "exersa",
    "exersează": "exersa",
    "exersez": "exersa",
    "exerseze": "exersa",
    "exersezi": "exersa",
    "neexersând": "exersa",
    "neexersându": "exersa",
    "nemaiexersând": "exersa",
    "nemaiexersându": "exersa",
    "exersarea": "exersare",
    "exersareo": "exersare",
    "exersări": "exersare",
    "exersării": "exersare",
    "exersările": "exersare",
    "exersărilor": "exersare",
    "exersată": "exersat",
    "exersate": "exersat",
    "exersați": "exersat",
    "exhaustiva": "exhaustiv",
    "exhaustivă": "exhaustiv",
    "exhaustive": "exhaustiv",
    "exhaustivei": "exhaustiv",
    "exhaustivele": "exhaustiv",
    "exhaustivelor": "exhaustiv",
    "exhaustivi": "exhaustiv",
    "exhaustivii": "exhaustiv",
    "exhaustivilor": "exhaustiv",
    "exhaustivo": "exhaustiv",
    "exhaustivul": "exhaustiv",
    "exhaustivule": "exhaustiv",
    "exhaustivului": "exhaustiv",
    "exhib": "exhiba",
    "exhibă": "exhiba",
    "exhibai": "exhiba",
    "exhibam": "exhiba",
    "exhibăm": "exhiba",
    "exhibând": "exhiba",
    "exhibându": "exhiba",
    "exhibară": "exhiba",
    "exhibarăm": "exhiba",
    "exhibarăți": "exhiba",
    "exhibase": "exhiba",
    "exhibasem": "exhiba",
    "exhibaseră": "exhiba",
    "exhibaserăm": "exhiba",
    "exhibaserăți": "exhiba",
    "exhibaseși": "exhiba",
    "exhibași": "exhiba",
    "exhibat": "exhiba",
    "exhibați": "exhiba",
    "exhibatu": "exhiba",
    "exhibau": "exhiba",
    "exhibe": "exhiba",
    "exhibează": "exhiba",
    "exhibez": "exhiba",
    "exhibeze": "exhiba",
    "exhibezi": "exhiba",
    "exhibi": "exhiba",
    "neexhibând": "exhiba",
    "neexhibându": "exhiba",
    "nemaiexhibând": "exhiba",
    "nemaiexhibându": "exhiba",
    "exhibată": "exhibat",
    "exhibate": "exhibat",
    "exhibați": "exhibat",
    "exhibiția": "exhibiție",
    "exhibiției": "exhibiție",
    "exhibiții": "exhibiție",
    "exhibițiile": "exhibiție",
    "exhibițiilor": "exhibiție",
    "exhibițio": "exhibiție",
    "exhibiționismul": "exhibiționism",
    "exhibiționismule": "exhibiționism",
    "exhibiționismului": "exhibiționism",
    "exhibiționiști": "exhibiționist",
    "exhibiționiștii": "exhibiționist",
    "exhibiționiștilor": "exhibiționist",
    "exhibiționistul": "exhibiționist",
    "exhibiționistule": "exhibiționist",
    "exhibiționistului": "exhibiționist",
    "exhibiționista": "exhibiționistă",
    "exhibiționiste": "exhibiționistă",
    "exhibiționistei": "exhibiționistă",
    "exhibiționistele": "exhibiționistă",
    "exhibiționistelor": "exhibiționistă",
    "exhibiționisto": "exhibiționistă",
    "exhumă": "exhuma",
    "exhumai": "exhuma",
    "exhumam": "exhuma",
    "exhumăm": "exhuma",
    "exhumând": "exhuma",
    "exhumându": "exhuma",
    "exhumară": "exhuma",
    "exhumarăm": "exhuma",
    "exhumarăți": "exhuma",
    "exhumase": "exhuma",
    "exhumasem": "exhuma",
    "exhumaseră": "exhuma",
    "exhumaserăm": "exhuma",
    "exhumaserăți": "exhuma",
    "exhumaseși": "exhuma",
    "exhumași": "exhuma",
    "exhumat": "exhuma",
    "exhumați": "exhuma",
    "exhumatu": "exhuma",
    "exhumau": "exhuma",
    "exhumează": "exhuma",
    "exhumez": "exhuma",
    "exhumeze": "exhuma",
    "exhumezi": "exhuma",
    "neexhumând": "exhuma",
    "neexhumându": "exhuma",
    "nemaiexhumând": "exhuma",
    "nemaiexhumându": "exhuma",
    "exhumarea": "exhumare",
    "exhumareo": "exhumare",
    "exhumări": "exhumare",
    "exhumării": "exhumare",
    "exhumările": "exhumare",
    "exhumărilor": "exhumare",
    "exhumată": "exhumat",
    "exhumate": "exhumat",
    "exhumați": "exhumat",
    "exigenta": "exigent",
    "exigentă": "exigent",
    "exigente": "exigent",
    "exigentei": "exigent",
    "exigentele": "exigent",
    "exigentelor": "exigent",
    "exigenți": "exigent",
    "exigenții": "exigent",
    "exigenților": "exigent",
    "exigento": "exigent",
    "exigentul": "exigent",
    "exigentule": "exigent",
    "exigentului": "exigent",
    "exigența": "exigență",
    "exigențe": "exigență",
    "exigenței": "exigență",
    "exigențele": "exigență",
    "exigențelor": "exigență",
    "exigențo": "exigență",
    "exilul": "exil",
    "exilule": "exil",
    "exilului": "exil",
    "exiluri": "exil",
    "exilurile": "exil",
    "exilurilor": "exil",
    "exilă": "exila",
    "exilai": "exila",
    "exilam": "exila",
    "exilăm": "exila",
    "exilând": "exila",
    "exilându": "exila",
    "exilară": "exila",
    "exilarăm": "exila",
    "exilarăți": "exila",
    "exilase": "exila",
    "exilasem": "exila",
    "exilaseră": "exila",
    "exilaserăm": "exila",
    "exilaserăți": "exila",
    "exilaseși": "exila",
    "exilași": "exila",
    "exilat": "exila",
    "exilați": "exila",
    "exilatu": "exila",
    "exilau": "exila",
    "exilează": "exila",
    "exilez": "exila",
    "exileze": "exila",
    "exilezi": "exila",
    "neexilând": "exila",
    "neexilându": "exila",
    "nemaiexilând": "exila",
    "nemaiexilându": "exila",
    "exilarea": "exilare",
    "exilareo": "exilare",
    "exilări": "exilare",
    "exilării": "exilare",
    "exilările": "exilare",
    "exilărilor": "exilare",
    "exilata": "exilat",
    "exilată": "exilat",
    "exilate": "exilat",
    "exilatei": "exilat",
    "exilatele": "exilat",
    "exilatelor": "exilat",
    "exilați": "exilat",
    "exilații": "exilat",
    "exilaților": "exilat",
    "exilato": "exilat",
    "exilatul": "exilat",
    "exilatule": "exilat",
    "exilatului": "exilat",
    "exilata": "exilată",
    "exilate": "exilată",
    "exilatei": "exilată",
    "exilatele": "exilată",
    "exilatelor": "exilată",
    "exilato": "exilată",
    "exist": "exista",
    "există": "exista",
    "existai": "exista",
    "existam": "exista",
    "existăm": "exista",
    "existând": "exista",
    "existându": "exista",
    "existară": "exista",
    "existarăm": "exista",
    "existarăți": "exista",
    "existase": "exista",
    "existasem": "exista",
    "existaseră": "exista",
    "existaserăm": "exista",
    "existaserăți": "exista",
    "existaseși": "exista",
    "existași": "exista",
    "existat": "exista",
    "existați": "exista",
    "existatu": "exista",
    "existau": "exista",
    "existe": "exista",
    "exiști": "exista",
    "neexistând": "exista",
    "neexistându": "exista",
    "nemaiexistând": "exista",
    "nemaiexistându": "exista",
    "existată": "existat",
    "existate": "existat",
    "existați": "existat",
    "existenta": "existent",
    "existentă": "existent",
    "existente": "existent",
    "existentei": "existent",
    "existentele": "existent",
    "existentelor": "existent",
    "existenți": "existent",
    "existenții": "existent",
    "existenților": "existent",
    "existento": "existent",
    "existentul": "existent",
    "existentule": "existent",
    "existentului": "existent",
    "existența": "existență",
    "existențe": "existență",
    "existenței": "existență",
    "existențele": "existență",
    "existențelor": "existență",
    "existențo": "existență",
    "existențiala": "existențial",
    "existențială": "existențial",
    "existențiale": "existențial",
    "existențialei": "existențial",
    "existențialele": "existențial",
    "existențialelor": "existențial",
    "existențiali": "existențial",
    "existențialii": "existențial",
    "existențialilor": "existențial",
    "existențialo": "existențial",
    "existențialul": "existențial",
    "existențialule": "existențial",
    "existențialului": "existențial",
    "exmatriculă": "exmatricula",
    "exmatriculai": "exmatricula",
    "exmatriculam": "exmatricula",
    "exmatriculăm": "exmatricula",
    "exmatriculând": "exmatricula",
    "exmatriculându": "exmatricula",
    "exmatriculară": "exmatricula",
    "exmatricularăm": "exmatricula",
    "exmatricularăți": "exmatricula",
    "exmatriculase": "exmatricula",
    "exmatriculasem": "exmatricula",
    "exmatriculaseră": "exmatricula",
    "exmatriculaserăm": "exmatricula",
    "exmatriculaserăți": "exmatricula",
    "exmatriculaseși": "exmatricula",
    "exmatriculași": "exmatricula",
    "exmatriculat": "exmatricula",
    "exmatriculați": "exmatricula",
    "exmatriculatu": "exmatricula",
    "exmatriculau": "exmatricula",
    "exmatriculează": "exmatricula",
    "exmatriculez": "exmatricula",
    "exmatriculeze": "exmatricula",
    "exmatriculezi": "exmatricula",
    "neexmatriculând": "exmatricula",
    "neexmatriculându": "exmatricula",
    "nemaiexmatriculând": "exmatricula",
    "nemaiexmatriculându": "exmatricula",
    "exmatricularea": "exmatriculare",
    "exmatriculareo": "exmatriculare",
    "exmatriculări": "exmatriculare",
    "exmatriculării": "exmatriculare",
    "exmatriculările": "exmatriculare",
    "exmatriculărilor": "exmatriculare",
    "exmatriculată": "exmatriculat",
    "exmatriculate": "exmatriculat",
    "exmatriculați": "exmatriculat",
    "exodul": "exod",
    "exodule": "exod",
    "exodului": "exod",
    "exoduri": "exod",
    "exodurile": "exod",
    "exodurilor": "exod",
    "exoftalmia": "exoftalmie",
    "exoftalmiei": "exoftalmie",
    "exoftalmii": "exoftalmie",
    "exoftalmiile": "exoftalmie",
    "exoftalmiilor": "exoftalmie",
    "exoftalmio": "exoftalmie",
    "exoneră": "exonera",
    "exonerai": "exonera",
    "exoneram": "exonera",
    "exonerăm": "exonera",
    "exonerând": "exonera",
    "exonerându": "exonera",
    "exonerară": "exonera",
    "exonerarăm": "exonera",
    "exonerarăți": "exonera",
    "exonerase": "exonera",
    "exonerasem": "exonera",
    "exoneraseră": "exonera",
    "exoneraserăm": "exonera",
    "exoneraserăți": "exonera",
    "exoneraseși": "exonera",
    "exonerași": "exonera",
    "exonerat": "exonera",
    "exonerați": "exonera",
    "exoneratu": "exonera",
    "exonerau": "exonera",
    "exonerează": "exonera",
    "exonerez": "exonera",
    "exonereze": "exonera",
    "exonerezi": "exonera",
    "neexonerând": "exonera",
    "neexonerându": "exonera",
    "nemaiexonerând": "exonera",
    "nemaiexonerându": "exonera",
    "exonerată": "exonerat",
    "exonerate": "exonerat",
    "exonerați": "exonerat",
    "exorbitanta": "exorbitant",
    "exorbitantă": "exorbitant",
    "exorbitante": "exorbitant",
    "exorbitantei": "exorbitant",
    "exorbitantele": "exorbitant",
    "exorbitantelor": "exorbitant",
    "exorbitanți": "exorbitant",
    "exorbitanții": "exorbitant",
    "exorbitanților": "exorbitant",
    "exorbitanto": "exorbitant",
    "exorbitantul": "exorbitant",
    "exorbitantule": "exorbitant",
    "exorbitantului": "exorbitant",
    "exoterica": "exoteric",
    "exoterică": "exoteric",
    "exoterice": "exoteric",
    "exotericei": "exoteric",
    "exotericele": "exoteric",
    "exotericelor": "exoteric",
    "exoterici": "exoteric",
    "exotericii": "exoteric",
    "exotericilor": "exoteric",
    "exoterico": "exoteric",
    "exotericul": "exoteric",
    "exotericule": "exoteric",
    "exotericului": "exoteric",
    "exotermica": "exotermic",
    "exotermică": "exotermic",
    "exotermice": "exotermic",
    "exotermicei": "exotermic",
    "exotermicele": "exotermic",
    "exotermicelor": "exotermic",
    "exotermici": "exotermic",
    "exotermicii": "exotermic",
    "exotermicilor": "exotermic",
    "exotermico": "exotermic",
    "exotermicul": "exotermic",
    "exotermicule": "exotermic",
    "exotermicului": "exotermic",
    "exotica": "exotic",
    "exotică": "exotic",
    "exotice": "exotic",
    "exoticei": "exotic",
    "exoticele": "exotic",
    "exoticelor": "exotic",
    "exotici": "exotic",
    "exoticii": "exotic",
    "exoticilor": "exotic",
    "exotico": "exotic",
    "exoticul": "exotic",
    "exoticule": "exotic",
    "exoticului": "exotic",
    "exotismul": "exotism",
    "exotismule": "exotism",
    "exotismului": "exotism",
    "expansibila": "expansibil",
    "expansibilă": "expansibil",
    "expansibile": "expansibil",
    "expansibilei": "expansibil",
    "expansibilele": "expansibil",
    "expansibilelor": "expansibil",
    "expansibili": "expansibil",
    "expansibilii": "expansibil",
    "expansibililor": "expansibil",
    "expansibilo": "expansibil",
    "expansibilul": "expansibil",
    "expansibilule": "expansibil",
    "expansibilului": "expansibil",
    "expansiunea": "expansiune",
    "expansiuneo": "expansiune",
    "expansiuni": "expansiune",
    "expansiunii": "expansiune",
    "expansiunile": "expansiune",
    "expansiunilor": "expansiune",
    "expansiva": "expansiv",
    "expansivă": "expansiv",
    "expansive": "expansiv",
    "expansivei": "expansiv",
    "expansivele": "expansiv",
    "expansivelor": "expansiv",
    "expansivi": "expansiv",
    "expansivii": "expansiv",
    "expansivilor": "expansiv",
    "expansivo": "expansiv",
    "expansivul": "expansiv",
    "expansivule": "expansiv",
    "expansivului": "expansiv",
    "expatriai": "expatria",
    "expatriam": "expatria",
    "expatriară": "expatria",
    "expatriarăm": "expatria",
    "expatriarăți": "expatria",
    "expatriase": "expatria",
    "expatriasem": "expatria",
    "expatriaseră": "expatria",
    "expatriaserăm": "expatria",
    "expatriaserăți": "expatria",
    "expatriaseși": "expatria",
    "expatriași": "expatria",
    "expatriat": "expatria",
    "expatriați": "expatria",
    "expatriatu": "expatria",
    "expatriau": "expatria",
    "expatriază": "expatria",
    "expatrie": "expatria",
    "expatriem": "expatria",
    "expatriez": "expatria",
    "expatrieze": "expatria",
    "expatriezi": "expatria",
    "expatriind": "expatria",
    "expatriindu": "expatria",
    "neexpatriind": "expatria",
    "neexpatriindu": "expatria",
    "nemaiexpatriind": "expatria",
    "nemaiexpatriindu": "expatria",
    "expatriata": "expatriat",
    "expatriată": "expatriat",
    "expatriate": "expatriat",
    "expatriatei": "expatriat",
    "expatriatele": "expatriat",
    "expatriatelor": "expatriat",
    "expatriați": "expatriat",
    "expatriații": "expatriat",
    "expatriaților": "expatriat",
    "expatriato": "expatriat",
    "expatriatul": "expatriat",
    "expatriatule": "expatriat",
    "expatriatului": "expatriat",
    "expatriata": "expatriată",
    "expatriate": "expatriată",
    "expatriatei": "expatriată",
    "expatriatele": "expatriată",
    "expatriatelor": "expatriată",
    "expatriato": "expatriată",
    "expatrierea": "expatriere",
    "expatriereo": "expatriere",
    "expatrieri": "expatriere",
    "expatrierii": "expatriere",
    "expatrierile": "expatriere",
    "expatrierilor": "expatriere",
    "expectativa": "expectativă",
    "expectative": "expectativă",
    "expectativei": "expectativă",
    "expectativele": "expectativă",
    "expectativelor": "expectativă",
    "expectativo": "expectativă",
    "expectoră": "expectora",
    "expectorai": "expectora",
    "expectoram": "expectora",
    "expectorăm": "expectora",
    "expectorând": "expectora",
    "expectorându": "expectora",
    "expectorară": "expectora",
    "expectorarăm": "expectora",
    "expectorarăți": "expectora",
    "expectorase": "expectora",
    "expectorasem": "expectora",
    "expectoraseră": "expectora",
    "expectoraserăm": "expectora",
    "expectoraserăți": "expectora",
    "expectoraseși": "expectora",
    "expectorași": "expectora",
    "expectorat": "expectora",
    "expectorați": "expectora",
    "expectoratu": "expectora",
    "expectorau": "expectora",
    "expectorează": "expectora",
    "expectorez": "expectora",
    "expectoreze": "expectora",
    "expectorezi": "expectora",
    "neexpectorând": "expectora",
    "neexpectorându": "expectora",
    "nemaiexpectorând": "expectora",
    "nemaiexpectorându": "expectora",
    "expectoranta": "expectorant",
    "expectorantă": "expectorant",
    "expectorante": "expectorant",
    "expectorantei": "expectorant",
    "expectorantele": "expectorant",
    "expectorantelor": "expectorant",
    "expectoranți": "expectorant",
    "expectoranții": "expectorant",
    "expectoranților": "expectorant",
    "expectoranto": "expectorant",
    "expectorantul": "expectorant",
    "expectorantule": "expectorant",
    "expectorantului": "expectorant",
    "expectorarea": "expectorare",
    "expectorareo": "expectorare",
    "expectorări": "expectorare",
    "expectorării": "expectorare",
    "expectorările": "expectorare",
    "expectorărilor": "expectorare",
    "expectorată": "expectorat",
    "expectorate": "expectorat",
    "expectorați": "expectorat",
    "expediai": "expedia",
    "expediam": "expedia",
    "expediară": "expedia",
    "expediarăm": "expedia",
    "expediarăți": "expedia",
    "expediase": "expedia",
    "expediasem": "expedia",
    "expediaseră": "expedia",
    "expediaserăm": "expedia",
    "expediaserăți": "expedia",
    "expediaseși": "expedia",
    "expediași": "expedia",
    "expediat": "expedia",
    "expediați": "expedia",
    "expediatu": "expedia",
    "expediau": "expedia",
    "expediază": "expedia",
    "expedie": "expedia",
    "expediem": "expedia",
    "expediez": "expedia",
    "expedieze": "expedia",
    "expediezi": "expedia",
    "expediind": "expedia",
    "expediindu": "expedia",
    "neexpediind": "expedia",
    "neexpediindu": "expedia",
    "nemaiexpediind": "expedia",
    "nemaiexpediindu": "expedia",
    "expediată": "expediat",
    "expediate": "expediat",
    "expediați": "expediat",
    "expediente": "expedient",
    "expedientele": "expedient",
    "expedientelor": "expedient",
    "expedientul": "expedient",
    "expedientule": "expedient",
    "expedientului": "expedient",
    "expedierea": "expediere",
    "expediereo": "expediere",
    "expedieri": "expediere",
    "expedierii": "expediere",
    "expedierile": "expediere",
    "expedierilor": "expediere",
    "expediția": "expediție",
    "expediției": "expediție",
    "expediții": "expediție",
    "expedițiile": "expediție",
    "expedițiilor": "expediție",
    "expedițio": "expediție",
    "expediționara": "expediționar",
    "expediționară": "expediționar",
    "expediționare": "expediționar",
    "expediționarei": "expediționar",
    "expediționarele": "expediționar",
    "expediționarelor": "expediționar",
    "expediționari": "expediționar",
    "expediționarii": "expediționar",
    "expediționarilor": "expediționar",
    "expediționarul": "expediționar",
    "expediționarului": "expediționar",
    "expeditiva": "expeditiv",
    "expeditivă": "expeditiv",
    "expeditive": "expeditiv",
    "expeditivei": "expeditiv",
    "expeditivele": "expeditiv",
    "expeditivelor": "expeditiv",
    "expeditivi": "expeditiv",
    "expeditivii": "expeditiv",
    "expeditivilor": "expeditiv",
    "expeditivo": "expeditiv",
    "expeditivul": "expeditiv",
    "expeditivule": "expeditiv",
    "expeditivului": "expeditiv",
    "expeditoarea": "expeditoare",
    "expeditoarei": "expeditoare",
    "expeditoarele": "expeditoare",
    "expeditoarelor": "expeditoare",
    "expeditoareo": "expeditoare",
    "expeditoare": "expeditor",
    "expeditoarea": "expeditor",
    "expeditoarei": "expeditor",
    "expeditoarele": "expeditor",
    "expeditoarelor": "expeditor",
    "expeditoareo": "expeditor",
    "expeditori": "expeditor",
    "expeditorii": "expeditor",
    "expeditorilor": "expeditor",
    "expeditorul": "expeditor",
    "expeditorule": "expeditor",
    "expeditorului": "expeditor",
    "experiența": "experiență",
    "experiențe": "experiență",
    "experienței": "experiență",
    "experiențele": "experiență",
    "experiențelor": "experiență",
    "experiențo": "experiență",
    "experimente": "experiment",
    "experimentele": "experiment",
    "experimentelor": "experiment",
    "experimentul": "experiment",
    "experimentule": "experiment",
    "experimentului": "experiment",
    "experimentă": "experimenta",
    "experimentai": "experimenta",
    "experimentam": "experimenta",
    "experimentăm": "experimenta",
    "experimentând": "experimenta",
    "experimentându": "experimenta",
    "experimentară": "experimenta",
    "experimentarăm": "experimenta",
    "experimentarăți": "experimenta",
    "experimentase": "experimenta",
    "experimentasem": "experimenta",
    "experimentaseră": "experimenta",
    "experimentaserăm": "experimenta",
    "experimentaserăți": "experimenta",
    "experimentaseși": "experimenta",
    "experimentași": "experimenta",
    "experimentat": "experimenta",
    "experimentați": "experimenta",
    "experimentatu": "experimenta",
    "experimentau": "experimenta",
    "experimentează": "experimenta",
    "experimentez": "experimenta",
    "experimenteze": "experimenta",
    "experimentezi": "experimenta",
    "neexperimentând": "experimenta",
    "neexperimentându": "experimenta",
    "nemaiexperimentând": "experimenta",
    "nemaiexperimentându": "experimenta",
    "experimentala": "experimental",
    "experimentală": "experimental",
    "experimentale": "experimental",
    "experimentalei": "experimental",
    "experimentalele": "experimental",
    "experimentalelor": "experimental",
    "experimentali": "experimental",
    "experimentalii": "experimental",
    "experimentalilor": "experimental",
    "experimentalo": "experimental",
    "experimentalul": "experimental",
    "experimentalule": "experimental",
    "experimentalului": "experimental",
    "experimentarea": "experimentare",
    "experimentareo": "experimentare",
    "experimentări": "experimentare",
    "experimentării": "experimentare",
    "experimentările": "experimentare",
    "experimentărilor": "experimentare",
    "experimentata": "experimentat",
    "experimentată": "experimentat",
    "experimentate": "experimentat",
    "experimentatei": "experimentat",
    "experimentatele": "experimentat",
    "experimentatelor": "experimentat",
    "experimentați": "experimentat",
    "experimentații": "experimentat",
    "experimentaților": "experimentat",
    "experimentato": "experimentat",
    "experimentatul": "experimentat",
    "experimentatule": "experimentat",
    "experimentatului": "experimentat",
    "experimentatoarea": "experimentatoare",
    "experimentatoarei": "experimentatoare",
    "experimentatoarele": "experimentatoare",
    "experimentatoarelor": "experimentatoare",
    "experimentatoareo": "experimentatoare",
    "experimentatori": "experimentator",
    "experimentatorii": "experimentator",
    "experimentatorilor": "experimentator",
    "experimentatorul": "experimentator",
    "experimentatorule": "experimentator",
    "experimentatorului": "experimentator",
    "experți": "expert",
    "experții": "expert",
    "experților": "expert",
    "expertul": "expert",
    "expertule": "expert",
    "expertului": "expert",
    "experta": "expertă",
    "experte": "expertă",
    "expertei": "expertă",
    "expertele": "expertă",
    "expertelor": "expertă",
    "experto": "expertă",
    "expertiză": "expertiza",
    "expertizai": "expertiza",
    "expertizam": "expertiza",
    "expertizăm": "expertiza",
    "expertizând": "expertiza",
    "expertizându": "expertiza",
    "expertizară": "expertiza",
    "expertizarăm": "expertiza",
    "expertizarăți": "expertiza",
    "expertizase": "expertiza",
    "expertizasem": "expertiza",
    "expertizaseră": "expertiza",
    "expertizaserăm": "expertiza",
    "expertizaserăți": "expertiza",
    "expertizaseși": "expertiza",
    "expertizași": "expertiza",
    "expertizat": "expertiza",
    "expertizați": "expertiza",
    "expertizatu": "expertiza",
    "expertizau": "expertiza",
    "expertizează": "expertiza",
    "expertizez": "expertiza",
    "expertizeze": "expertiza",
    "expertizezi": "expertiza",
    "neexpertizând": "expertiza",
    "neexpertizându": "expertiza",
    "nemaiexpertizând": "expertiza",
    "nemaiexpertizându": "expertiza",
    "expertiza": "expertiză",
    "expertize": "expertiză",
    "expertizei": "expertiză",
    "expertizele": "expertiză",
    "expertizelor": "expertiză",
    "expertizo": "expertiză",
    "expertizată": "expertizat",
    "expertizate": "expertizat",
    "expertizați": "expertizat",
    "expir": "expira",
    "expiră": "expira",
    "expirai": "expira",
    "expiram": "expira",
    "expirăm": "expira",
    "expirând": "expira",
    "expirându": "expira",
    "expirară": "expira",
    "expirarăm": "expira",
    "expirarăți": "expira",
    "expirase": "expira",
    "expirasem": "expira",
    "expiraseră": "expira",
    "expiraserăm": "expira",
    "expiraserăți": "expira",
    "expiraseși": "expira",
    "expirași": "expira",
    "expirat": "expira",
    "expirați": "expira",
    "expiratu": "expira",
    "expirau": "expira",
    "expire": "expira",
    "expiri": "expira",
    "neexpirând": "expira",
    "neexpirându": "expira",
    "nemaiexpirând": "expira",
    "nemaiexpirându": "expira",
    "expirarea": "expirare",
    "expirareo": "expirare",
    "expirări": "expirare",
    "expirării": "expirare",
    "expirările": "expirare",
    "expirărilor": "expirare",
    "expirată": "expirat",
    "expirate": "expirat",
    "expirați": "expirat",
    "expirația": "expirație",
    "expirației": "expirație",
    "expirații": "expirație",
    "expirațiile": "expirație",
    "expirațiilor": "expirație",
    "expirațio": "expirație",
    "expiratoare": "expirator",
    "expiratoarea": "expirator",
    "expiratoarei": "expirator",
    "expiratoarele": "expirator",
    "expiratoarelor": "expirator",
    "expiratoareo": "expirator",
    "expiratori": "expirator",
    "expiratorii": "expirator",
    "expiratorilor": "expirator",
    "expiratorul": "expirator",
    "expiratorule": "expirator",
    "expiratorului": "expirator",
    "explic": "explica",
    "explică": "explica",
    "explicai": "explica",
    "explicam": "explica",
    "explicăm": "explica",
    "explicând": "explica",
    "explicându": "explica",
    "explicară": "explica",
    "explicarăm": "explica",
    "explicarăți": "explica",
    "explicase": "explica",
    "explicasem": "explica",
    "explicaseră": "explica",
    "explicaserăm": "explica",
    "explicaserăți": "explica",
    "explicaseși": "explica",
    "explicași": "explica",
    "explicat": "explica",
    "explicați": "explica",
    "explicatu": "explica",
    "explicau": "explica",
    "explice": "explica",
    "explici": "explica",
    "neexplicând": "explica",
    "neexplicându": "explica",
    "nemaiexplicând": "explica",
    "nemaiexplicându": "explica",
    "explicabila": "explicabil",
    "explicabilă": "explicabil",
    "explicabile": "explicabil",
    "explicabilei": "explicabil",
    "explicabilele": "explicabil",
    "explicabilelor": "explicabil",
    "explicabili": "explicabil",
    "explicabilii": "explicabil",
    "explicabililor": "explicabil",
    "explicabilo": "explicabil",
    "explicabilul": "explicabil",
    "explicabilule": "explicabil",
    "explicabilului": "explicabil",
    "explicarea": "explicare",
    "explicareo": "explicare",
    "explicări": "explicare",
    "explicării": "explicare",
    "explicările": "explicare",
    "explicărilor": "explicare",
    "explicată": "explicat",
    "explicate": "explicat",
    "explicați": "explicat",
    "explicația": "explicație",
    "explicației": "explicație",
    "explicații": "explicație",
    "explicațiile": "explicație",
    "explicațiilor": "explicație",
    "explicațio": "explicație",
    "explicativa": "explicativ",
    "explicativă": "explicativ",
    "explicative": "explicativ",
    "explicativei": "explicativ",
    "explicativele": "explicativ",
    "explicativelor": "explicativ",
    "explicativi": "explicativ",
    "explicativii": "explicativ",
    "explicativilor": "explicativ",
    "explicativo": "explicativ",
    "explicativul": "explicativ",
    "explicativule": "explicativ",
    "explicativului": "explicativ",
    "explicatoare": "explicator",
    "explicatoarea": "explicator",
    "explicatoarei": "explicator",
    "explicatoarele": "explicator",
    "explicatoarelor": "explicator",
    "explicatoareo": "explicator",
    "explicatori": "explicator",
    "explicatorii": "explicator",
    "explicatorilor": "explicator",
    "explicatorul": "explicator",
    "explicatorule": "explicator",
    "explicatorului": "explicator",
    "explicita": "explicit",
    "explicită": "explicit",
    "explicite": "explicit",
    "explicitei": "explicit",
    "explicitele": "explicit",
    "explicitelor": "explicit",
    "expliciți": "explicit",
    "expliciții": "explicit",
    "expliciților": "explicit",
    "explicito": "explicit",
    "explicitul": "explicit",
    "explicitule": "explicit",
    "explicitului": "explicit",
    "exploată": "exploata",
    "exploatai": "exploata",
    "exploatam": "exploata",
    "exploatăm": "exploata",
    "exploatând": "exploata",
    "exploatându": "exploata",
    "exploatară": "exploata",
    "exploatarăm": "exploata",
    "exploatarăți": "exploata",
    "exploatase": "exploata",
    "exploatasem": "exploata",
    "exploataseră": "exploata",
    "exploataserăm": "exploata",
    "exploataserăți": "exploata",
    "exploataseși": "exploata",
    "exploatași": "exploata",
    "exploatat": "exploata",
    "exploatați": "exploata",
    "exploatatu": "exploata",
    "exploatau": "exploata",
    "exploatează": "exploata",
    "exploatez": "exploata",
    "exploateze": "exploata",
    "exploatezi": "exploata",
    "neexploatând": "exploata",
    "neexploatându": "exploata",
    "nemaiexploatând": "exploata",
    "nemaiexploatându": "exploata",
    "exploatabila": "exploatabil",
    "exploatabilă": "exploatabil",
    "exploatabile": "exploatabil",
    "exploatabilei": "exploatabil",
    "exploatabilele": "exploatabil",
    "exploatabilelor": "exploatabil",
    "exploatabili": "exploatabil",
    "exploatabilii": "exploatabil",
    "exploatabililor": "exploatabil",
    "exploatabilo": "exploatabil",
    "exploatabilul": "exploatabil",
    "exploatabilule": "exploatabil",
    "exploatabilului": "exploatabil",
    "exploatarea": "exploatare",
    "exploatareo": "exploatare",
    "exploatări": "exploatare",
    "exploatării": "exploatare",
    "exploatările": "exploatare",
    "exploatărilor": "exploatare",
    "exploatata": "exploatat",
    "exploatată": "exploatat",
    "exploatate": "exploatat",
    "exploatatei": "exploatat",
    "exploatatele": "exploatat",
    "exploatatelor": "exploatat",
    "exploatați": "exploatat",
    "exploatații": "exploatat",
    "exploataților": "exploatat",
    "exploatato": "exploatat",
    "exploatatul": "exploatat",
    "exploatatule": "exploatat",
    "exploatatului": "exploatat",
    "exploatația": "exploatație",
    "exploatației": "exploatație",
    "exploatații": "exploatație",
    "exploatațiile": "exploatație",
    "exploatațiilor": "exploatație",
    "exploatațio": "exploatație",
    "exploatatoarea": "exploatatoare",
    "exploatatoarei": "exploatatoare",
    "exploatatoarele": "exploatatoare",
    "exploatatoarelor": "exploatatoare",
    "exploatatoareo": "exploatatoare",
    "exploatatoare": "exploatator",
    "exploatatoarea": "exploatator",
    "exploatatoarei": "exploatator",
    "exploatatoarele": "exploatator",
    "exploatatoarelor": "exploatator",
    "exploatatoareo": "exploatator",
    "exploatatori": "exploatator",
    "exploatatorii": "exploatator",
    "exploatatorilor": "exploatator",
    "exploatatorul": "exploatator",
    "exploatatorule": "exploatator",
    "exploatatorului": "exploatator",
    "explodă": "exploda",
    "explodai": "exploda",
    "explodam": "exploda",
    "explodăm": "exploda",
    "explodând": "exploda",
    "explodându": "exploda",
    "explodară": "exploda",
    "explodarăm": "exploda",
    "explodarăți": "exploda",
    "explodase": "exploda",
    "explodasem": "exploda",
    "explodaseră": "exploda",
    "explodaserăm": "exploda",
    "explodaserăți": "exploda",
    "explodaseși": "exploda",
    "explodași": "exploda",
    "explodat": "exploda",
    "explodați": "exploda",
    "explodatu": "exploda",
    "explodau": "exploda",
    "explodează": "exploda",
    "explodez": "exploda",
    "explodeze": "exploda",
    "explodezi": "exploda",
    "neexplodând": "exploda",
    "neexplodându": "exploda",
    "nemaiexplodând": "exploda",
    "nemaiexplodându": "exploda",
    "explodarea": "explodare",
    "explodareo": "explodare",
    "explodări": "explodare",
    "explodării": "explodare",
    "explodările": "explodare",
    "explodărilor": "explodare",
    "explodată": "explodat",
    "explodate": "explodat",
    "explodați": "explodat",
    "exploră": "explora",
    "explorai": "explora",
    "exploram": "explora",
    "explorăm": "explora",
    "explorând": "explora",
    "explorându": "explora",
    "explorară": "explora",
    "explorarăm": "explora",
    "explorarăți": "explora",
    "explorase": "explora",
    "explorasem": "explora",
    "exploraseră": "explora",
    "exploraserăm": "explora",
    "exploraserăți": "explora",
    "exploraseși": "explora",
    "explorași": "explora",
    "explorat": "explora",
    "explorați": "explora",
    "exploratu": "explora",
    "explorau": "explora",
    "explorează": "explora",
    "explorez": "explora",
    "exploreze": "explora",
    "explorezi": "explora",
    "neexplorând": "explora",
    "neexplorându": "explora",
    "nemaiexplorând": "explora",
    "nemaiexplorându": "explora",
    "explorarea": "explorare",
    "explorareo": "explorare",
    "explorări": "explorare",
    "explorării": "explorare",
    "explorările": "explorare",
    "explorărilor": "explorare",
    "explorată": "explorat",
    "explorate": "explorat",
    "explorați": "explorat",
    "exploratoarea": "exploratoare",
    "exploratoarei": "exploratoare",
    "exploratoarele": "exploratoare",
    "exploratoarelor": "exploratoare",
    "exploratoareo": "exploratoare",
    "exploratori": "explorator",
    "exploratorii": "explorator",
    "exploratorilor": "explorator",
    "exploratorul": "explorator",
    "exploratorule": "explorator",
    "exploratorului": "explorator",
    "explozibila": "explozibil",
    "explozibilă": "explozibil",
    "explozibile": "explozibil",
    "explozibilei": "explozibil",
    "explozibilele": "explozibil",
    "explozibilelor": "explozibil",
    "explozibili": "explozibil",
    "explozibilii": "explozibil",
    "explozibililor": "explozibil",
    "explozibilo": "explozibil",
    "explozibilul": "explozibil",
    "explozibilule": "explozibil",
    "explozibilului": "explozibil",
    "explozia": "explozie",
    "exploziei": "explozie",
    "explozii": "explozie",
    "exploziile": "explozie",
    "exploziilor": "explozie",
    "explozio": "explozie",
    "exploziva": "exploziv",
    "explozivă": "exploziv",
    "explozive": "exploziv",
    "explozivei": "exploziv",
    "explozivele": "exploziv",
    "explozivelor": "exploziv",
    "explozivi": "exploziv",
    "explozivii": "exploziv",
    "explozivilor": "exploziv",
    "explozivo": "exploziv",
    "explozivul": "exploziv",
    "explozivule": "exploziv",
    "explozivului": "exploziv",
    "exponate": "exponat",
    "exponatele": "exponat",
    "exponatelor": "exponat",
    "exponatul": "exponat",
    "exponatule": "exponat",
    "exponatului": "exponat",
    "exponenți": "exponent",
    "exponenții": "exponent",
    "exponenților": "exponent",
    "exponentul": "exponent",
    "exponentule": "exponent",
    "exponentului": "exponent",
    "exponenta": "exponentă",
    "exponente": "exponentă",
    "exponentei": "exponentă",
    "exponentele": "exponentă",
    "exponentelor": "exponentă",
    "exponento": "exponentă",
    "exportul": "export",
    "exportule": "export",
    "exportului": "export",
    "exporturi": "export",
    "exporturile": "export",
    "exporturilor": "export",
    "export": "exporta",
    "exportă": "exporta",
    "exportai": "exporta",
    "exportam": "exporta",
    "exportăm": "exporta",
    "exportând": "exporta",
    "exportându": "exporta",
    "exportară": "exporta",
    "exportarăm": "exporta",
    "exportarăți": "exporta",
    "exportase": "exporta",
    "exportasem": "exporta",
    "exportaseră": "exporta",
    "exportaserăm": "exporta",
    "exportaserăți": "exporta",
    "exportaseși": "exporta",
    "exportași": "exporta",
    "exportat": "exporta",
    "exportați": "exporta",
    "exportatu": "exporta",
    "exportau": "exporta",
    "exporte": "exporta",
    "exporți": "exporta",
    "neexportând": "exporta",
    "neexportându": "exporta",
    "nemaiexportând": "exporta",
    "nemaiexportându": "exporta",
    "exportabila": "exportabil",
    "exportabilă": "exportabil",
    "exportabile": "exportabil",
    "exportabilei": "exportabil",
    "exportabilele": "exportabil",
    "exportabilelor": "exportabil",
    "exportabili": "exportabil",
    "exportabilii": "exportabil",
    "exportabililor": "exportabil",
    "exportabilo": "exportabil",
    "exportabilul": "exportabil",
    "exportabilule": "exportabil",
    "exportabilului": "exportabil",
    "exportată": "exportat",
    "exportate": "exportat",
    "exportați": "exportat",
    "exportatoarea": "exportatoare",
    "exportatoarei": "exportatoare",
    "exportatoarele": "exportatoare",
    "exportatoarelor": "exportatoare",
    "exportatoareo": "exportatoare",
    "exportatoare": "exportator",
    "exportatoarea": "exportator",
    "exportatoarei": "exportator",
    "exportatoarele": "exportator",
    "exportatoarelor": "exportator",
    "exportatoareo": "exportator",
    "exportatori": "exportator",
    "exportatorii": "exportator",
    "exportatorilor": "exportator",
    "exportatorul": "exportator",
    "exportatorule": "exportator",
    "exportatorului": "exportator",
    "expozeul": "expozeu",
    "expozeule": "expozeu",
    "expozeului": "expozeu",
    "expozeuri": "expozeu",
    "expozeurile": "expozeu",
    "expozeurilor": "expozeu",
    "expo.": "expoziție",
    "expoziția": "expoziție",
    "expoziției": "expoziție",
    "expoziții": "expoziție",
    "expozițiile": "expoziție",
    "expozițiilor": "expoziție",
    "expozițio": "expoziție",
    "expozitiva": "expozitiv",
    "expozitivă": "expozitiv",
    "expozitive": "expozitiv",
    "expozitivei": "expozitiv",
    "expozitivele": "expozitiv",
    "expozitivelor": "expozitiv",
    "expozitivi": "expozitiv",
    "expozitivii": "expozitiv",
    "expozitivilor": "expozitiv",
    "expozitivo": "expozitiv",
    "expozitivul": "expozitiv",
    "expozitivule": "expozitiv",
    "expozitivului": "expozitiv",
    "expresa": "expres",
    "expresă": "expres",
    "exprese": "expres",
    "expresei": "expres",
    "expresele": "expres",
    "expreselor": "expres",
    "expreși": "expres",
    "expreșii": "expres",
    "expreșilor": "expres",
    "expreso": "expres",
    "expresul": "expres",
    "expresule": "expres",
    "expresului": "expres",
    "expr.": "expresie",
    "expresia": "expresie",
    "expresiei": "expresie",
    "expresii": "expresie",
    "expresiile": "expresie",
    "expresiilor": "expresie",
    "expresio": "expresie",
    "expresiva": "expresiv",
    "expresivă": "expresiv",
    "expresive": "expresiv",
    "expresivei": "expresiv",
    "expresivele": "expresiv",
    "expresivelor": "expresiv",
    "expresivi": "expresiv",
    "expresivii": "expresiv",
    "expresivilor": "expresiv",
    "expresivo": "expresiv",
    "expresivul": "expresiv",
    "expresivule": "expresiv",
    "expresivului": "expresiv",
    "exprim": "exprima",
    "exprimă": "exprima",
    "exprimai": "exprima",
    "exprimam": "exprima",
    "exprimăm": "exprima",
    "exprimând": "exprima",
    "exprimându": "exprima",
    "exprimară": "exprima",
    "exprimarăm": "exprima",
    "exprimarăți": "exprima",
    "exprimase": "exprima",
    "exprimasem": "exprima",
    "exprimaseră": "exprima",
    "exprimaserăm": "exprima",
    "exprimaserăți": "exprima",
    "exprimaseși": "exprima",
    "exprimași": "exprima",
    "exprimat": "exprima",
    "exprimați": "exprima",
    "exprimatu": "exprima",
    "exprimau": "exprima",
    "exprime": "exprima",
    "exprimi": "exprima",
    "neexprimând": "exprima",
    "neexprimându": "exprima",
    "nemaiexprimând": "exprima",
    "nemaiexprimându": "exprima",
    "exprimabila": "exprimabil",
    "exprimabilă": "exprimabil",
    "exprimabile": "exprimabil",
    "exprimabilei": "exprimabil",
    "exprimabilele": "exprimabil",
    "exprimabilelor": "exprimabil",
    "exprimabili": "exprimabil",
    "exprimabilii": "exprimabil",
    "exprimabililor": "exprimabil",
    "exprimabilo": "exprimabil",
    "exprimabilul": "exprimabil",
    "exprimabilule": "exprimabil",
    "exprimabilului": "exprimabil",
    "exprimarea": "exprimare",
    "exprimareo": "exprimare",
    "exprimări": "exprimare",
    "exprimării": "exprimare",
    "exprimările": "exprimare",
    "exprimărilor": "exprimare",
    "exprimată": "exprimat",
    "exprimate": "exprimat",
    "exprimați": "exprimat",
    "expropriai": "expropria",
    "expropriam": "expropria",
    "expropriară": "expropria",
    "expropriarăm": "expropria",
    "expropriarăți": "expropria",
    "expropriase": "expropria",
    "expropriasem": "expropria",
    "expropriaseră": "expropria",
    "expropriaserăm": "expropria",
    "expropriaserăți": "expropria",
    "expropriaseși": "expropria",
    "expropriași": "expropria",
    "expropriat": "expropria",
    "expropriați": "expropria",
    "expropriatu": "expropria",
    "expropriau": "expropria",
    "expropriază": "expropria",
    "exproprie": "expropria",
    "expropriem": "expropria",
    "expropriez": "expropria",
    "exproprieze": "expropria",
    "expropriezi": "expropria",
    "expropriind": "expropria",
    "expropriindu": "expropria",
    "neexpropriind": "expropria",
    "neexpropriindu": "expropria",
    "nemaiexpropriind": "expropria",
    "nemaiexpropriindu": "expropria",
    "expropriata": "expropriat",
    "expropriată": "expropriat",
    "expropriate": "expropriat",
    "expropriatei": "expropriat",
    "expropriatele": "expropriat",
    "expropriatelor": "expropriat",
    "expropriați": "expropriat",
    "expropriații": "expropriat",
    "expropriaților": "expropriat",
    "expropriato": "expropriat",
    "expropriatul": "expropriat",
    "expropriatule": "expropriat",
    "expropriatului": "expropriat",
    "expropriatori": "expropriator",
    "expropriatorii": "expropriator",
    "expropriatorilor": "expropriator",
    "expropriatorul": "expropriator",
    "expropriatorule": "expropriator",
    "expropriatorului": "expropriator",
    "exproprierea": "expropriere",
    "expropriereo": "expropriere",
    "exproprieri": "expropriere",
    "exproprierii": "expropriere",
    "exproprierile": "expropriere",
    "exproprierilor": "expropriere",
    "expulsia": "expulsie",
    "expulsiei": "expulsie",
    "expulsii": "expulsie",
    "expulsiile": "expulsie",
    "expulsiilor": "expulsie",
    "expulsio": "expulsie",
    "expulză": "expulza",
    "expulzai": "expulza",
    "expulzam": "expulza",
    "expulzăm": "expulza",
    "expulzând": "expulza",
    "expulzându": "expulza",
    "expulzară": "expulza",
    "expulzarăm": "expulza",
    "expulzarăți": "expulza",
    "expulzase": "expulza",
    "expulzasem": "expulza",
    "expulzaseră": "expulza",
    "expulzaserăm": "expulza",
    "expulzaserăți": "expulza",
    "expulzaseși": "expulza",
    "expulzași": "expulza",
    "expulzat": "expulza",
    "expulzați": "expulza",
    "expulzatu": "expulza",
    "expulzau": "expulza",
    "expulzează": "expulza",
    "expulzez": "expulza",
    "expulzeze": "expulza",
    "expulzezi": "expulza",
    "neexpulzând": "expulza",
    "neexpulzându": "expulza",
    "nemaiexpulzând": "expulza",
    "nemaiexpulzându": "expulza",
    "expulzarea": "expulzare",
    "expulzareo": "expulzare",
    "expulzări": "expulzare",
    "expulzării": "expulzare",
    "expulzările": "expulzare",
    "expulzărilor": "expulzare",
    "expulzată": "expulzat",
    "expulzate": "expulzat",
    "expulzați": "expulzat",
    "expui": "expune",
    "expun": "expune",
    "expună": "expune",
    "expunând": "expune",
    "expunându": "expune",
    "expunea": "expune",
    "expuneai": "expune",
    "expuneam": "expune",
    "expuneați": "expune",
    "expuneau": "expune",
    "expunem": "expune",
    "expuneți": "expune",
    "expus": "expune",
    "expuse": "expune",
    "expusei": "expune",
    "expuseră": "expune",
    "expuserăm": "expune",
    "expuserăți": "expune",
    "expusese": "expune",
    "expusesem": "expune",
    "expuseseră": "expune",
    "expuseserăm": "expune",
    "expuseserăți": "expune",
    "expuseseși": "expune",
    "expuseși": "expune",
    "expusu": "expune",
    "neexpunând": "expune",
    "neexpunându": "expune",
    "nemaiexpunând": "expune",
    "nemaiexpunându": "expune",
    "expunerea": "expunere",
    "expunereo": "expunere",
    "expuneri": "expunere",
    "expunerii": "expunere",
    "expunerile": "expunere",
    "expunerilor": "expunere",
    "expusă": "expus",
    "expuse": "expus",
    "expuși": "expus",
    "extaze": "extaz",
    "extazele": "extaz",
    "extazelor": "extaz",
    "extazul": "extaz",
    "extazule": "extaz",
    "extazului": "extaz",
    "extaziai": "extazia",
    "extaziam": "extazia",
    "extaziară": "extazia",
    "extaziarăm": "extazia",
    "extaziarăți": "extazia",
    "extaziase": "extazia",
    "extaziasem": "extazia",
    "extaziaseră": "extazia",
    "extaziaserăm": "extazia",
    "extaziaserăți": "extazia",
    "extaziaseși": "extazia",
    "extaziași": "extazia",
    "extaziat": "extazia",
    "extaziați": "extazia",
    "extaziatu": "extazia",
    "extaziau": "extazia",
    "extaziază": "extazia",
    "extazie": "extazia",
    "extaziem": "extazia",
    "extaziez": "extazia",
    "extazieze": "extazia",
    "extaziezi": "extazia",
    "extaziind": "extazia",
    "extaziindu": "extazia",
    "neextaziind": "extazia",
    "neextaziindu": "extazia",
    "nemaiextaziind": "extazia",
    "nemaiextaziindu": "extazia",
    "extaziata": "extaziat",
    "extaziată": "extaziat",
    "extaziate": "extaziat",
    "extaziatei": "extaziat",
    "extaziatele": "extaziat",
    "extaziatelor": "extaziat",
    "extaziați": "extaziat",
    "extaziații": "extaziat",
    "extaziaților": "extaziat",
    "extaziato": "extaziat",
    "extaziatul": "extaziat",
    "extaziatule": "extaziat",
    "extaziatului": "extaziat",
    "extazierea": "extaziere",
    "extaziereo": "extaziere",
    "extazieri": "extaziere",
    "extazierii": "extaziere",
    "extazierile": "extaziere",
    "extazierilor": "extaziere",
    "extemporale": "extemporal",
    "extemporalele": "extemporal",
    "extemporalelor": "extemporal",
    "extemporalul": "extemporal",
    "extemporalule": "extemporal",
    "extemporalului": "extemporal",
    "extensia": "extensie",
    "extensiei": "extensie",
    "extensii": "extensie",
    "extensiile": "extensie",
    "extensiilor": "extensie",
    "extensio": "extensie",
    "extensiunea": "extensiune",
    "extensiuneo": "extensiune",
    "extensiuni": "extensiune",
    "extensiunii": "extensiune",
    "extensiunile": "extensiune",
    "extensiunilor": "extensiune",
    "extensiva": "extensiv",
    "extensivă": "extensiv",
    "extensive": "extensiv",
    "extensivei": "extensiv",
    "extensivele": "extensiv",
    "extensivelor": "extensiv",
    "extensivi": "extensiv",
    "extensivii": "extensiv",
    "extensivilor": "extensiv",
    "extensivo": "extensiv",
    "extensivul": "extensiv",
    "extensivule": "extensiv",
    "extensivului": "extensiv",
    "extensoare": "extensor",
    "extensoarele": "extensor",
    "extensoarelor": "extensor",
    "extensorul": "extensor",
    "extensorule": "extensor",
    "extensorului": "extensor",
    "extenuă": "extenua",
    "extenuai": "extenua",
    "extenuam": "extenua",
    "extenuăm": "extenua",
    "extenuând": "extenua",
    "extenuându": "extenua",
    "extenuară": "extenua",
    "extenuarăm": "extenua",
    "extenuarăți": "extenua",
    "extenuase": "extenua",
    "extenuasem": "extenua",
    "extenuaseră": "extenua",
    "extenuaserăm": "extenua",
    "extenuaserăți": "extenua",
    "extenuaseși": "extenua",
    "extenuași": "extenua",
    "extenuat": "extenua",
    "extenuați": "extenua",
    "extenuatu": "extenua",
    "extenuau": "extenua",
    "extenuează": "extenua",
    "extenuez": "extenua",
    "extenueze": "extenua",
    "extenuezi": "extenua",
    "neextenuând": "extenua",
    "neextenuându": "extenua",
    "nemaiextenuând": "extenua",
    "nemaiextenuându": "extenua",
    "extenuarea": "extenuare",
    "extenuareo": "extenuare",
    "extenuări": "extenuare",
    "extenuării": "extenuare",
    "extenuările": "extenuare",
    "extenuărilor": "extenuare",
    "extenuata": "extenuat",
    "extenuată": "extenuat",
    "extenuate": "extenuat",
    "extenuatei": "extenuat",
    "extenuatele": "extenuat",
    "extenuatelor": "extenuat",
    "extenuați": "extenuat",
    "extenuații": "extenuat",
    "extenuaților": "extenuat",
    "extenuato": "extenuat",
    "extenuatul": "extenuat",
    "extenuatule": "extenuat",
    "extenuatului": "extenuat",
    "ext.": "exterior",
    "exterioara": "exterior",
    "exterioară": "exterior",
    "exterioare": "exterior",
    "exterioarei": "exterior",
    "exterioarele": "exterior",
    "exterioarelor": "exterior",
    "exterioaro": "exterior",
    "exteriori": "exterior",
    "exteriorii": "exterior",
    "exteriorilor": "exterior",
    "exteriorul": "exterior",
    "exteriorului": "exterior",
    "exterioriză": "exterioriza",
    "exteriorizai": "exterioriza",
    "exteriorizam": "exterioriza",
    "exteriorizăm": "exterioriza",
    "exteriorizând": "exterioriza",
    "exteriorizându": "exterioriza",
    "exteriorizară": "exterioriza",
    "exteriorizarăm": "exterioriza",
    "exteriorizarăți": "exterioriza",
    "exteriorizase": "exterioriza",
    "exteriorizasem": "exterioriza",
    "exteriorizaseră": "exterioriza",
    "exteriorizaserăm": "exterioriza",
    "exteriorizaserăți": "exterioriza",
    "exteriorizaseși": "exterioriza",
    "exteriorizași": "exterioriza",
    "exteriorizat": "exterioriza",
    "exteriorizați": "exterioriza",
    "exteriorizatu": "exterioriza",
    "exteriorizau": "exterioriza",
    "exteriorizează": "exterioriza",
    "exteriorizez": "exterioriza",
    "exteriorizeze": "exterioriza",
    "exteriorizezi": "exterioriza",
    "neexteriorizând": "exterioriza",
    "neexteriorizându": "exterioriza",
    "nemaiexteriorizând": "exterioriza",
    "nemaiexteriorizându": "exterioriza",
    "exteriorizarea": "exteriorizare",
    "exteriorizareo": "exteriorizare",
    "exteriorizări": "exteriorizare",
    "exteriorizării": "exteriorizare",
    "exteriorizările": "exteriorizare",
    "exteriorizărilor": "exteriorizare",
    "exteriorizată": "exteriorizat",
    "exteriorizate": "exteriorizat",
    "exteriorizați": "exteriorizat",
    "extermin": "extermina",
    "extermină": "extermina",
    "exterminai": "extermina",
    "exterminam": "extermina",
    "exterminăm": "extermina",
    "exterminând": "extermina",
    "exterminându": "extermina",
    "exterminară": "extermina",
    "exterminarăm": "extermina",
    "exterminarăți": "extermina",
    "exterminase": "extermina",
    "exterminasem": "extermina",
    "exterminaseră": "extermina",
    "exterminaserăm": "extermina",
    "exterminaserăți": "extermina",
    "exterminaseși": "extermina",
    "exterminași": "extermina",
    "exterminat": "extermina",
    "exterminați": "extermina",
    "exterminatu": "extermina",
    "exterminau": "extermina",
    "extermine": "extermina",
    "extermini": "extermina",
    "neexterminând": "extermina",
    "neexterminându": "extermina",
    "nemaiexterminând": "extermina",
    "nemaiexterminându": "extermina",
    "exterminarea": "exterminare",
    "exterminareo": "exterminare",
    "exterminări": "exterminare",
    "exterminării": "exterminare",
    "exterminările": "exterminare",
    "exterminărilor": "exterminare",
    "exterminata": "exterminat",
    "exterminată": "exterminat",
    "exterminate": "exterminat",
    "exterminatei": "exterminat",
    "exterminatele": "exterminat",
    "exterminatelor": "exterminat",
    "exterminați": "exterminat",
    "exterminații": "exterminat",
    "exterminaților": "exterminat",
    "exterminato": "exterminat",
    "exterminatul": "exterminat",
    "exterminatule": "exterminat",
    "exterminatului": "exterminat",
    "exterminatoare": "exterminator",
    "exterminatoarea": "exterminator",
    "exterminatoarei": "exterminator",
    "exterminatoarele": "exterminator",
    "exterminatoarelor": "exterminator",
    "exterminatoareo": "exterminator",
    "exterminatori": "exterminator",
    "exterminatorii": "exterminator",
    "exterminatorilor": "exterminator",
    "exterminatorul": "exterminator",
    "exterminatorule": "exterminator",
    "exterminatorului": "exterminator",
    "externa": "extern",
    "externă": "extern",
    "externe": "extern",
    "externei": "extern",
    "externele": "extern",
    "externelor": "extern",
    "externi": "extern",
    "externii": "extern",
    "externilor": "extern",
    "externo": "extern",
    "externul": "extern",
    "externule": "extern",
    "externului": "extern",
    "externarea": "externare",
    "externareo": "externare",
    "externări": "externare",
    "externării": "externare",
    "externările": "externare",
    "externărilor": "externare",
    "externate": "externat",
    "externatele": "externat",
    "externatelor": "externat",
    "externatul": "externat",
    "externatule": "externat",
    "externatului": "externat",
    "extinctoare": "extinctor",
    "extinctoarea": "extinctor",
    "extinctoarei": "extinctor",
    "extinctoarele": "extinctor",
    "extinctoarelor": "extinctor",
    "extinctoareo": "extinctor",
    "extinctori": "extinctor",
    "extinctorii": "extinctor",
    "extinctorilor": "extinctor",
    "extinctorul": "extinctor",
    "extinctorule": "extinctor",
    "extinctorului": "extinctor",
    "extind": "extinde",
    "extindă": "extinde",
    "extindea": "extinde",
    "extindeai": "extinde",
    "extindeam": "extinde",
    "extindeați": "extinde",
    "extindeau": "extinde",
    "extindem": "extinde",
    "extindeți": "extinde",
    "extins": "extinde",
    "extinse": "extinde",
    "extinsei": "extinde",
    "extinseră": "extinde",
    "extinserăm": "extinde",
    "extinserăți": "extinde",
    "extinsese": "extinde",
    "extinsesem": "extinde",
    "extinseseră": "extinde",
    "extinseserăm": "extinde",
    "extinseserăți": "extinde",
    "extinseseși": "extinde",
    "extinseși": "extinde",
    "extinsu": "extinde",
    "extinzând": "extinde",
    "extinzându": "extinde",
    "extinzi": "extinde",
    "neextinzând": "extinde",
    "neextinzându": "extinde",
    "nemaiextinzând": "extinde",
    "nemaiextinzându": "extinde",
    "extinderea": "extindere",
    "extindereo": "extindere",
    "extinderi": "extindere",
    "extinderii": "extindere",
    "extinderile": "extindere",
    "extinderilor": "extindere",
    "extinsă": "extins",
    "extinse": "extins",
    "extinși": "extins",
    "extirp": "extirpa",
    "extirpă": "extirpa",
    "extirpai": "extirpa",
    "extirpam": "extirpa",
    "extirpăm": "extirpa",
    "extirpând": "extirpa",
    "extirpându": "extirpa",
    "extirpară": "extirpa",
    "extirparăm": "extirpa",
    "extirparăți": "extirpa",
    "extirpase": "extirpa",
    "extirpasem": "extirpa",
    "extirpaseră": "extirpa",
    "extirpaserăm": "extirpa",
    "extirpaserăți": "extirpa",
    "extirpaseși": "extirpa",
    "extirpași": "extirpa",
    "extirpat": "extirpa",
    "extirpați": "extirpa",
    "extirpatu": "extirpa",
    "extirpau": "extirpa",
    "extirpe": "extirpa",
    "extirpi": "extirpa",
    "neextirpând": "extirpa",
    "neextirpându": "extirpa",
    "nemaiextirpând": "extirpa",
    "nemaiextirpându": "extirpa",
    "extirparea": "extirpare",
    "extirpareo": "extirpare",
    "extirpări": "extirpare",
    "extirpării": "extirpare",
    "extirpările": "extirpare",
    "extirpărilor": "extirpare",
    "extirpată": "extirpat",
    "extirpate": "extirpat",
    "extirpați": "extirpat",
    "extirpatoare": "extirpator",
    "extirpatoarele": "extirpator",
    "extirpatoarelor": "extirpator",
    "extirpatorul": "extirpator",
    "extirpatorule": "extirpator",
    "extirpatorului": "extirpator",
    "extorcă": "extorca",
    "extorcai": "extorca",
    "extorcam": "extorca",
    "extorcăm": "extorca",
    "extorcând": "extorca",
    "extorcându": "extorca",
    "extorcară": "extorca",
    "extorcarăm": "extorca",
    "extorcarăți": "extorca",
    "extorcase": "extorca",
    "extorcasem": "extorca",
    "extorcaseră": "extorca",
    "extorcaserăm": "extorca",
    "extorcaserăți": "extorca",
    "extorcaseși": "extorca",
    "extorcași": "extorca",
    "extorcat": "extorca",
    "extorcați": "extorca",
    "extorcatu": "extorca",
    "extorcau": "extorca",
    "extorchează": "extorca",
    "extorchez": "extorca",
    "extorcheze": "extorca",
    "extorchezi": "extorca",
    "neextorcând": "extorca",
    "neextorcându": "extorca",
    "nemaiextorcând": "extorca",
    "nemaiextorcându": "extorca",
    "extorcarea": "extorcare",
    "extorcareo": "extorcare",
    "extorcări": "extorcare",
    "extorcării": "extorcare",
    "extorcările": "extorcare",
    "extorcărilor": "extorcare",
    "extorcată": "extorcat",
    "extorcate": "extorcat",
    "extorcați": "extorcat",
    "ex.": "extra",
    "extracarpatica": "extracarpatic",
    "extracarpatică": "extracarpatic",
    "extracarpatice": "extracarpatic",
    "extracarpaticei": "extracarpatic",
    "extracarpaticele": "extracarpatic",
    "extracarpaticelor": "extracarpatic",
    "extracarpatici": "extracarpatic",
    "extracarpaticii": "extracarpatic",
    "extracarpaticilor": "extracarpatic",
    "extracarpatico": "extracarpatic",
    "extracarpaticul": "extracarpatic",
    "extracarpaticule": "extracarpatic",
    "extracarpaticului": "extracarpatic",
    "extracte": "extract",
    "extractele": "extract",
    "extractelor": "extract",
    "extractul": "extract",
    "extractule": "extract",
    "extractului": "extract",
    "extracția": "extracție",
    "extracției": "extracție",
    "extracții": "extracție",
    "extracțiile": "extracție",
    "extracțiilor": "extracție",
    "extracțio": "extracție",
    "extractiva": "extractiv",
    "extractivă": "extractiv",
    "extractive": "extractiv",
    "extractivei": "extractiv",
    "extractivele": "extractiv",
    "extractivelor": "extractiv",
    "extractivi": "extractiv",
    "extractivii": "extractiv",
    "extractivilor": "extractiv",
    "extractivo": "extractiv",
    "extractivul": "extractiv",
    "extractivule": "extractiv",
    "extractivului": "extractiv",
    "extractoare": "extractor",
    "extractoarea": "extractor",
    "extractoarei": "extractor",
    "extractoarele": "extractor",
    "extractoarelor": "extractor",
    "extractoareo": "extractor",
    "extractori": "extractor",
    "extractorii": "extractor",
    "extractorilor": "extractor",
    "extractorul": "extractor",
    "extractorule": "extractor",
    "extractorului": "extractor",
    "extrădă": "extrăda",
    "extrădai": "extrăda",
    "extrădam": "extrăda",
    "extrădăm": "extrăda",
    "extrădând": "extrăda",
    "extrădându": "extrăda",
    "extrădară": "extrăda",
    "extrădarăm": "extrăda",
    "extrădarăți": "extrăda",
    "extrădase": "extrăda",
    "extrădasem": "extrăda",
    "extrădaseră": "extrăda",
    "extrădaserăm": "extrăda",
    "extrădaserăți": "extrăda",
    "extrădaseși": "extrăda",
    "extrădași": "extrăda",
    "extrădat": "extrăda",
    "extrădați": "extrăda",
    "extrădatu": "extrăda",
    "extrădau": "extrăda",
    "extrădează": "extrăda",
    "extrădez": "extrăda",
    "extrădeze": "extrăda",
    "extrădezi": "extrăda",
    "neextrădând": "extrăda",
    "neextrădându": "extrăda",
    "nemaiextrădând": "extrăda",
    "nemaiextrădându": "extrăda",
    "extrădarea": "extrădare",
    "extrădareo": "extrădare",
    "extrădări": "extrădare",
    "extrădării": "extrădare",
    "extrădările": "extrădare",
    "extrădărilor": "extrădare",
    "extrădată": "extrădat",
    "extrădate": "extrădat",
    "extrădați": "extrădat",
    "extrag": "extrage",
    "extragă": "extrage",
    "extrăgând": "extrage",
    "extrăgându": "extrage",
    "extrăgea": "extrage",
    "extrăgeai": "extrage",
    "extrăgeam": "extrage",
    "extrăgeați": "extrage",
    "extrăgeau": "extrage",
    "extragem": "extrage",
    "extrageți": "extrage",
    "extragi": "extrage",
    "extras": "extrage",
    "extrăse": "extrage",
    "extrăsei": "extrage",
    "extrăseră": "extrage",
    "extrăserăm": "extrage",
    "extrăserăți": "extrage",
    "extrăsese": "extrage",
    "extrăsesem": "extrage",
    "extrăseseră": "extrage",
    "extrăseserăm": "extrage",
    "extrăseserăți": "extrage",
    "extrăseseși": "extrage",
    "extrăseși": "extrage",
    "extrasu": "extrage",
    "neextrăgând": "extrage",
    "neextrăgându": "extrage",
    "nemaiextrăgând": "extrage",
    "nemaiextrăgându": "extrage",
    "extragerea": "extragere",
    "extragereo": "extragere",
    "extrageri": "extragere",
    "extragerii": "extragere",
    "extragerile": "extragere",
    "extragerilor": "extragere",
    "extraordinara": "extraordinar",
    "extraordinară": "extraordinar",
    "extraordinare": "extraordinar",
    "extraordinarei": "extraordinar",
    "extraordinarele": "extraordinar",
    "extraordinarelor": "extraordinar",
    "extraordinari": "extraordinar",
    "extraordinarii": "extraordinar",
    "extraordinarilor": "extraordinar",
    "extraordinaro": "extraordinar",
    "extraordinarul": "extraordinar",
    "extraordinarule": "extraordinar",
    "extraordinarului": "extraordinar",
    "extrapolă": "extrapola",
    "extrapolai": "extrapola",
    "extrapolam": "extrapola",
    "extrapolăm": "extrapola",
    "extrapolând": "extrapola",
    "extrapolându": "extrapola",
    "extrapolară": "extrapola",
    "extrapolarăm": "extrapola",
    "extrapolarăți": "extrapola",
    "extrapolase": "extrapola",
    "extrapolasem": "extrapola",
    "extrapolaseră": "extrapola",
    "extrapolaserăm": "extrapola",
    "extrapolaserăți": "extrapola",
    "extrapolaseși": "extrapola",
    "extrapolași": "extrapola",
    "extrapolat": "extrapola",
    "extrapolați": "extrapola",
    "extrapolatu": "extrapola",
    "extrapolau": "extrapola",
    "extrapolează": "extrapola",
    "extrapolez": "extrapola",
    "extrapoleze": "extrapola",
    "extrapolezi": "extrapola",
    "extrapolarea": "extrapolare",
    "extrapolări": "extrapolare",
    "extrapolării": "extrapolare",
    "extrapolările": "extrapolare",
    "extrapolărilor": "extrapolare",
    "extrapolată": "extrapolat",
    "extrapolate": "extrapolat",
    "extrapolați": "extrapolat",
    "extrapolatul": "extrapolat",
    "extrapolatului": "extrapolat",
    "extrasă": "extras",
    "extrase": "extras",
    "extrasele": "extras",
    "extraselor": "extras",
    "extrași": "extras",
    "extrasul": "extras",
    "extrasule": "extras",
    "extrasului": "extras",
    "extrasuri": "extras",
    "extrasurile": "extras",
    "extrasurilor": "extras",
    "extrasenzoriala": "extrasenzorial",
    "extrasenzorială": "extrasenzorial",
    "extrasenzoriale": "extrasenzorial",
    "extrasenzorialei": "extrasenzorial",
    "extrasenzorialele": "extrasenzorial",
    "extrasenzorialelor": "extrasenzorial",
    "extrasenzoriali": "extrasenzorial",
    "extrasenzorialii": "extrasenzorial",
    "extrasenzorialilor": "extrasenzorial",
    "extrasenzorialul": "extrasenzorial",
    "extrasenzorialului": "extrasenzorial",
    "extraterestra": "extraterestră",
    "extraterestre": "extraterestră",
    "extraterestrei": "extraterestră",
    "extraterestrele": "extraterestră",
    "extraterestrelor": "extraterestră",
    "extraterestro": "extraterestră",
    "extraterești": "extraterestru",
    "extratereștii": "extraterestru",
    "extratereștilor": "extraterestru",
    "extraterestra": "extraterestru",
    "extraterestră": "extraterestru",
    "extraterestre": "extraterestru",
    "extraterestrei": "extraterestru",
    "extraterestrele": "extraterestru",
    "extraterestrelor": "extraterestru",
    "extraterestro": "extraterestru",
    "extraterestrul": "extraterestru",
    "extraterestrule": "extraterestru",
    "extraterestrului": "extraterestru",
    "extravaganta": "extravagant",
    "extravagantă": "extravagant",
    "extravagante": "extravagant",
    "extravagantei": "extravagant",
    "extravagantele": "extravagant",
    "extravagantelor": "extravagant",
    "extravaganți": "extravagant",
    "extravaganții": "extravagant",
    "extravaganților": "extravagant",
    "extravaganto": "extravagant",
    "extravagantul": "extravagant",
    "extravagantule": "extravagant",
    "extravagantului": "extravagant",
    "extravaganța": "extravaganță",
    "extravaganțe": "extravaganță",
    "extravaganței": "extravaganță",
    "extravaganțele": "extravaganță",
    "extravaganțelor": "extravaganță",
    "extravaganțo": "extravaganță",
    "extrema": "extrem",
    "extremă": "extrem",
    "extreme": "extrem",
    "extremei": "extrem",
    "extremele": "extrem",
    "extremelor": "extrem",
    "extremi": "extrem",
    "extremii": "extrem",
    "extremilor": "extrem",
    "extremo": "extrem",
    "extremul": "extrem",
    "extremule": "extrem",
    "extremului": "extrem",
    "extrema": "extremă",
    "extreme": "extremă",
    "extremei": "extremă",
    "extremele": "extremă",
    "extremelor": "extremă",
    "extremo": "extremă",
    "extremismului": "extremism",
    "extremista": "extremist",
    "extremistă": "extremist",
    "extremiste": "extremist",
    "extremistei": "extremist",
    "extremistele": "extremist",
    "extremistelor": "extremist",
    "extremiști": "extremist",
    "extremiștii": "extremist",
    "extremiștilor": "extremist",
    "extremisto": "extremist",
    "extremistul": "extremist",
    "extremistule": "extremist",
    "extremistului": "extremist",
    "extremista": "extremistă",
    "extremiste": "extremistă",
    "extremistei": "extremistă",
    "extremistele": "extremistă",
    "extremistelor": "extremistă",
    "extremisto": "extremistă",
    "extrinseca": "extrinsec",
    "extrinsecă": "extrinsec",
    "extrinsece": "extrinsec",
    "extrinsecei": "extrinsec",
    "extrinsecele": "extrinsec",
    "extrinsecelor": "extrinsec",
    "extrinseci": "extrinsec",
    "extrinsecii": "extrinsec",
    "extrinsecilor": "extrinsec",
    "extrinseco": "extrinsec",
    "extrinsecul": "extrinsec",
    "extrinsecule": "extrinsec",
    "extrinsecului": "extrinsec",
    "extrovertita": "extrovertit",
    "extrovertită": "extrovertit",
    "extrovertite": "extrovertit",
    "extrovertitei": "extrovertit",
    "extrovertitele": "extrovertit",
    "extrovertitelor": "extrovertit",
    "extrovertiți": "extrovertit",
    "extrovertiții": "extrovertit",
    "extrovertiților": "extrovertit",
    "extrovertito": "extrovertit",
    "extrovertitul": "extrovertit",
    "extrovertitule": "extrovertit",
    "extrovertitului": "extrovertit",
    "exuberanta": "exuberant",
    "exuberantă": "exuberant",
    "exuberante": "exuberant",
    "exuberantei": "exuberant",
    "exuberantele": "exuberant",
    "exuberantelor": "exuberant",
    "exuberanți": "exuberant",
    "exuberanții": "exuberant",
    "exuberanților": "exuberant",
    "exuberanto": "exuberant",
    "exuberantul": "exuberant",
    "exuberantule": "exuberant",
    "exuberantului": "exuberant",
    "exuberanța": "exuberanță",
    "exuberanțe": "exuberanță",
    "exuberanței": "exuberanță",
    "exuberanțele": "exuberanță",
    "exuberanțelor": "exuberanță",
    "exuberanțo": "exuberanță",
    "exult": "exulta",
    "exultă": "exulta",
    "exultai": "exulta",
    "exultam": "exulta",
    "exultăm": "exulta",
    "exultând": "exulta",
    "exultându": "exulta",
    "exultară": "exulta",
    "exultarăm": "exulta",
    "exultarăți": "exulta",
    "exultase": "exulta",
    "exultasem": "exulta",
    "exultaseră": "exulta",
    "exultaserăm": "exulta",
    "exultaserăți": "exulta",
    "exultaseși": "exulta",
    "exultași": "exulta",
    "exultat": "exulta",
    "exultați": "exulta",
    "exultatu": "exulta",
    "exultau": "exulta",
    "exulte": "exulta",
    "exulți": "exulta",
    "neexultând": "exulta",
    "neexultându": "exulta",
    "nemaiexultând": "exulta",
    "nemaiexultându": "exulta",
    "exultarea": "exultare",
    "exultareo": "exultare",
    "exultări": "exultare",
    "exultării": "exultare",
    "exultările": "exultare",
    "exultărilor": "exultare",
    "exultată": "exultat",
    "exultate": "exultat",
    "exultați": "exultat",
    "ezit": "ezita",
    "ezită": "ezita",
    "ezitai": "ezita",
    "ezitam": "ezita",
    "ezităm": "ezita",
    "ezitând": "ezita",
    "ezitându": "ezita",
    "ezitară": "ezita",
    "ezitarăm": "ezita",
    "ezitarăți": "ezita",
    "ezitase": "ezita",
    "ezitasem": "ezita",
    "ezitaseră": "ezita",
    "ezitaserăm": "ezita",
    "ezitaserăți": "ezita",
    "ezitaseși": "ezita",
    "ezitași": "ezita",
    "ezitat": "ezita",
    "ezitați": "ezita",
    "ezitatu": "ezita",
    "ezitau": "ezita",
    "ezite": "ezita",
    "eziți": "ezita",
    "neezitând": "ezita",
    "neezitându": "ezita",
    "nemaiezitând": "ezita",
    "nemaiezitându": "ezita",
    "ezitanta": "ezitant",
    "ezitantă": "ezitant",
    "ezitante": "ezitant",
    "ezitantei": "ezitant",
    "ezitantele": "ezitant",
    "ezitantelor": "ezitant",
    "ezitanți": "ezitant",
    "ezitanții": "ezitant",
    "ezitanților": "ezitant",
    "ezitanto": "ezitant",
    "ezitantul": "ezitant",
    "ezitantule": "ezitant",
    "ezitantului": "ezitant",
    "ezitarea": "ezitare",
    "ezitareo": "ezitare",
    "ezitări": "ezitare",
    "ezitării": "ezitare",
    "ezitările": "ezitare",
    "ezitărilor": "ezitare",
    "ezitată": "ezitat",
    "ezitate": "ezitat",
    "ezitați": "ezitat",
    "ezoterica": "ezoteric",
    "ezoterică": "ezoteric",
    "ezoterice": "ezoteric",
    "ezotericei": "ezoteric",
    "ezotericele": "ezoteric",
    "ezotericelor": "ezoteric",
    "ezoterici": "ezoteric",
    "ezotericii": "ezoteric",
    "ezotericilor": "ezoteric",
    "ezoterico": "ezoteric",
    "ezotericul": "ezoteric",
    "ezotericule": "ezoteric",
    "ezotericului": "ezoteric",
    "ezoterisme": "ezoterism",
    "ezoterismul": "ezoterism",
    "ezoterismule": "ezoterism",
    "ezoterismului": "ezoterism",
    "faul": "fa",
    "faului": "fa",
    "fabianul": "fabian",
    "fabianului": "fabian",
    "fabieni": "fabian",
    "fabienii": "fabian",
    "fabienilor": "fabian",
    "fabianismul": "fabianism",
    "fabianismului": "fabianism",
    "fabric": "fabrica",
    "fabrică": "fabrica",
    "fabricai": "fabrica",
    "fabricam": "fabrica",
    "fabricăm": "fabrica",
    "fabricând": "fabrica",
    "fabricându": "fabrica",
    "fabricară": "fabrica",
    "fabricarăm": "fabrica",
    "fabricarăți": "fabrica",
    "fabricase": "fabrica",
    "fabricasem": "fabrica",
    "fabricaseră": "fabrica",
    "fabricaserăm": "fabrica",
    "fabricaserăți": "fabrica",
    "fabricaseși": "fabrica",
    "fabricași": "fabrica",
    "fabricat": "fabrica",
    "fabricați": "fabrica",
    "fabricatu": "fabrica",
    "fabricau": "fabrica",
    "fabrice": "fabrica",
    "fabrici": "fabrica",
    "nefabricând": "fabrica",
    "nefabricându": "fabrica",
    "nemaifabricând": "fabrica",
    "nemaifabricându": "fabrica",
    "fabrica": "fabrică",
    "fabrici": "fabrică",
    "fabricii": "fabrică",
    "fabricile": "fabrică",
    "fabricilor": "fabrică",
    "fabricanți": "fabricant",
    "fabricanții": "fabricant",
    "fabricanților": "fabricant",
    "fabricantul": "fabricant",
    "fabricantului": "fabricant",
    "fabricanta": "fabricantă",
    "fabricante": "fabricantă",
    "fabricantei": "fabricantă",
    "fabricantele": "fabricantă",
    "fabricantelor": "fabricantă",
    "fabricarea": "fabricare",
    "fabricări": "fabricare",
    "fabricării": "fabricare",
    "fabricările": "fabricare",
    "fabricărilor": "fabricare",
    "fabr.": "fabricat",
    "fabricată": "fabricat",
    "fabricate": "fabricat",
    "fabricatele": "fabricat",
    "fabricatelor": "fabricat",
    "fabricați": "fabricat",
    "fabricatul": "fabricat",
    "fabricatului": "fabricat",
    "fabricația": "fabricație",
    "fabricației": "fabricație",
    "fabricații": "fabricație",
    "fabricațiile": "fabricație",
    "fabricațiilor": "fabricație",
    "fabulă": "fabula",
    "fabulai": "fabula",
    "fabulam": "fabula",
    "fabulăm": "fabula",
    "fabulând": "fabula",
    "fabulându": "fabula",
    "fabulară": "fabula",
    "fabularăm": "fabula",
    "fabularăți": "fabula",
    "fabulase": "fabula",
    "fabulasem": "fabula",
    "fabulaseră": "fabula",
    "fabulaserăm": "fabula",
    "fabulaserăți": "fabula",
    "fabulaseși": "fabula",
    "fabulași": "fabula",
    "fabulat": "fabula",
    "fabulați": "fabula",
    "fabulatu": "fabula",
    "fabulau": "fabula",
    "fabulează": "fabula",
    "fabulez": "fabula",
    "fabuleze": "fabula",
    "fabulezi": "fabula",
    "fabula": "fabulă",
    "fabule": "fabulă",
    "fabulei": "fabulă",
    "fabulele": "fabulă",
    "fabulelor": "fabulă",
    "fabularea": "fabulare",
    "fabulări": "fabulare",
    "fabulării": "fabulare",
    "fabulările": "fabulare",
    "fabulărilor": "fabulare",
    "fabulată": "fabulat",
    "fabulate": "fabulat",
    "fabulați": "fabulat",
    "fabulatul": "fabulat",
    "fabulatului": "fabulat",
    "fabulația": "fabulație",
    "fabulației": "fabulație",
    "fabulații": "fabulație",
    "fabulațiile": "fabulație",
    "fabulațiilor": "fabulație",
    "fabuliști": "fabulist",
    "fabuliștii": "fabulist",
    "fabuliștilor": "fabulist",
    "fabulistul": "fabulist",
    "fabulistului": "fabulist",
    "fabulista": "fabulistă",
    "fabuliste": "fabulistă",
    "fabulistei": "fabulistă",
    "fabulistele": "fabulistă",
    "fabulistelor": "fabulistă",
    "fabuloasa": "fabulos",
    "fabuloasă": "fabulos",
    "fabuloase": "fabulos",
    "fabuloasei": "fabulos",
    "fabuloasele": "fabulos",
    "fabuloaselor": "fabulos",
    "fabuloși": "fabulos",
    "fabuloșii": "fabulos",
    "fabuloșilor": "fabulos",
    "fabulosul": "fabulos",
    "fabulosului": "fabulos",
    "făcăluia": "făcălui",
    "făcăluiai": "făcălui",
    "făcăluiam": "făcălui",
    "făcăluiască": "făcălui",
    "făcăluiați": "făcălui",
    "făcăluiau": "făcălui",
    "făcăluiesc": "făcălui",
    "făcăluiește": "făcălui",
    "făcăluiești": "făcălui",
    "făcăluii": "făcălui",
    "făcăluim": "făcălui",
    "făcăluind": "făcălui",
    "făcăluindu": "făcălui",
    "făcăluiră": "făcălui",
    "făcăluirăm": "făcălui",
    "făcăluirăți": "făcălui",
    "făcăluise": "făcălui",
    "făcăluisem": "făcălui",
    "făcăluiseră": "făcălui",
    "făcăluiserăm": "făcălui",
    "făcăluiserăți": "făcălui",
    "făcăluiseși": "făcălui",
    "făcăluiși": "făcălui",
    "făcăluit": "făcălui",
    "făcăluiți": "făcălui",
    "făcăluitu": "făcălui",
    "nefăcăluind": "făcălui",
    "nefăcăluindu": "făcălui",
    "nemaifăcăluind": "făcălui",
    "nemaifăcăluindu": "făcălui",
    "făcăluită": "făcăluit",
    "făcăluite": "făcăluit",
    "făcăluiți": "făcăluit",
    "făcătoare": "făcător",
    "făcătoarea": "făcător",
    "făcătoarei": "făcător",
    "făcătoarele": "făcător",
    "făcătoarelor": "făcător",
    "făcătoareo": "făcător",
    "făcători": "făcător",
    "făcătorii": "făcător",
    "făcătorilor": "făcător",
    "făcătorul": "făcător",
    "făcătorule": "făcător",
    "făcătorului": "făcător",
    "făcătura": "făcătură",
    "făcături": "făcătură",
    "făcăturii": "făcătură",
    "făcăturile": "făcătură",
    "făcăturilor": "făcătură",
    "făcaie": "făcău",
    "făcaiele": "făcău",
    "făcaielor": "făcău",
    "făcăul": "făcău",
    "făcăului": "făcău",
    "fă": "face",
    "fac": "face",
    "facă": "face",
    "făcând": "face",
    "făcându": "face",
    "făcea": "face",
    "făceai": "face",
    "făceam": "face",
    "făceați": "face",
    "făceau": "face",
    "facem": "face",
    "faceți": "face",
    "făceți": "face",
    "faci": "face",
    "făcu": "face",
    "făcu'": "face",
    "făcui": "face",
    "făcură": "face",
    "făcurăm": "face",
    "făcurăți": "face",
    "făcuse": "face",
    "făcusem": "face",
    "făcuseră": "face",
    "făcuserăm": "face",
    "făcuserăți": "face",
    "făcuseși": "face",
    "făcuși": "face",
    "făcut": "face",
    "făcutu": "face",
    "nefăcând": "face",
    "nefăcându": "face",
    "nemaifăcând": "face",
    "nemaifăcându": "face",
    "facerea": "facere",
    "faceri": "facere",
    "facerii": "facere",
    "facerile": "facere",
    "facerilor": "facere",
    "faceț'": "faceți",
    "fachia": "fachie",
    "fachiei": "fachie",
    "fachii": "fachie",
    "fachiile": "fachie",
    "fachiilor": "fachie",
    "fachiri": "fachir",
    "fachirii": "fachir",
    "fachirilor": "fachir",
    "fachirul": "fachir",
    "fachirului": "fachir",
    "faciala": "facial",
    "facială": "facial",
    "faciale": "facial",
    "facialei": "facial",
    "facialele": "facial",
    "facialelor": "facial",
    "faciali": "facial",
    "facialii": "facial",
    "facialilor": "facial",
    "facialul": "facial",
    "facialului": "facial",
    "faciesul": "facies",
    "faciesului": "facies",
    "faciesuri": "facies",
    "faciesurile": "facies",
    "faciesurilor": "facies",
    "facila": "facil",
    "facilă": "facil",
    "facile": "facil",
    "facilei": "facil",
    "facilele": "facil",
    "facilelor": "facil",
    "facili": "facil",
    "facilii": "facil",
    "facililor": "facil",
    "facilul": "facil",
    "facilului": "facil",
    "facilită": "facilita",
    "facilitai": "facilita",
    "facilitam": "facilita",
    "facilităm": "facilita",
    "facilitând": "facilita",
    "facilitându": "facilita",
    "facilitară": "facilita",
    "facilitarăm": "facilita",
    "facilitarăți": "facilita",
    "facilitase": "facilita",
    "facilitasem": "facilita",
    "facilitaseră": "facilita",
    "facilitaserăm": "facilita",
    "facilitaserăți": "facilita",
    "facilitaseși": "facilita",
    "facilitași": "facilita",
    "facilitat": "facilita",
    "facilitați": "facilita",
    "facilitatu": "facilita",
    "facilitau": "facilita",
    "facilitează": "facilita",
    "facilitez": "facilita",
    "faciliteze": "facilita",
    "facilitezi": "facilita",
    "nefacilitând": "facilita",
    "nefacilitându": "facilita",
    "nemaifacilitând": "facilita",
    "nemaifacilitându": "facilita",
    "facilitarea": "facilitare",
    "facilitări": "facilitare",
    "facilitării": "facilitare",
    "facilitările": "facilitare",
    "facilitărilor": "facilitare",
    "facilitată": "facilitat",
    "facilitate": "facilitat",
    "facilitați": "facilitat",
    "facilitatea": "facilitate",
    "facilități": "facilitate",
    "facilității": "facilitate",
    "facilitățile": "facilitate",
    "facilităților": "facilitate",
    "facla": "faclă",
    "facle": "faclă",
    "faclei": "faclă",
    "faclele": "faclă",
    "faclelor": "faclă",
    "făclia": "făclie",
    "făcliei": "făclie",
    "făclii": "făclie",
    "făcliile": "făclie",
    "făcliilor": "făclie",
    "făclioara": "făclioară",
    "făclioare": "făclioară",
    "făclioarei": "făclioară",
    "făclioarele": "făclioară",
    "făclioarelor": "făclioară",
    "făcliuța": "făcliuță",
    "făcliuțe": "făcliuță",
    "făcliuței": "făcliuță",
    "făcliuțele": "făcliuță",
    "făcliuțelor": "făcliuță",
    "facsimile": "facsimil",
    "facsimilele": "facsimil",
    "facsimilelor": "facsimil",
    "facsimilul": "facsimil",
    "facsimilului": "facsimil",
    "factaje": "factaj",
    "factajele": "factaj",
    "factajelor": "factaj",
    "factajul": "factaj",
    "factajului": "factaj",
    "factitive": "factitiv",
    "factitivele": "factitiv",
    "factitivelor": "factitiv",
    "factitivul": "factitiv",
    "factitivului": "factitiv",
    "facțiunea": "facțiune",
    "facțiuni": "facțiune",
    "facțiunii": "facțiune",
    "facțiunile": "facțiune",
    "facțiunilor": "facțiune",
    "factologia": "factologie",
    "factologiei": "factologie",
    "factologii": "factologie",
    "factologiile": "factologie",
    "factologiilor": "factologie",
    "factori": "factor",
    "factorii": "factor",
    "factorilor": "factor",
    "factorul": "factor",
    "factorului": "factor",
    "factoria": "factorie",
    "factoriei": "factorie",
    "factorii": "factorie",
    "factoriile": "factorie",
    "factoriilor": "factorie",
    "factotumul": "factotum",
    "factotumului": "factotum",
    "factură": "factura",
    "facturai": "factura",
    "facturam": "factura",
    "facturăm": "factura",
    "facturând": "factura",
    "facturându": "factura",
    "facturară": "factura",
    "facturarăm": "factura",
    "facturarăți": "factura",
    "facturase": "factura",
    "facturasem": "factura",
    "facturaseră": "factura",
    "facturaserăm": "factura",
    "facturaserăți": "factura",
    "facturaseși": "factura",
    "facturași": "factura",
    "facturat": "factura",
    "facturați": "factura",
    "facturatu": "factura",
    "facturau": "factura",
    "facturează": "factura",
    "facturez": "factura",
    "factureze": "factura",
    "facturezi": "factura",
    "nefacturând": "factura",
    "nefacturându": "factura",
    "nemaifacturând": "factura",
    "nemaifacturându": "factura",
    "factura": "factură",
    "facturi": "factură",
    "facturii": "factură",
    "facturile": "factură",
    "facturilor": "factură",
    "facturată": "facturat",
    "facturate": "facturat",
    "facturați": "facturat",
    "facturiere": "facturier",
    "facturierii": "facturier",
    "facturierilor": "facturier",
    "facturierul": "facturier",
    "facturierului": "facturier",
    "facula": "faculă",
    "facule": "faculă",
    "faculei": "faculă",
    "faculele": "faculă",
    "faculelor": "faculă",
    "facultatea": "facultate",
    "facultăți": "facultate",
    "facultății": "facultate",
    "facultățile": "facultate",
    "facultăților": "facultate",
    "facultativa": "facultativ",
    "facultativă": "facultativ",
    "facultative": "facultativ",
    "facultativei": "facultativ",
    "facultativele": "facultativ",
    "facultativelor": "facultativ",
    "facultativi": "facultativ",
    "facultativii": "facultativ",
    "facultativilor": "facultativ",
    "facultativul": "facultativ",
    "facultativului": "facultativ",
    "făcu'": "făcut",
    "făcută": "făcut",
    "făcute": "făcut",
    "făcuți": "făcut",
    "făcutul": "făcut",
    "făcutului": "făcut",
    "fada": "fad",
    "fadă": "fad",
    "fade": "fad",
    "fadei": "fad",
    "fadele": "fad",
    "fadelor": "fad",
    "fadul": "fad",
    "fadului": "fad",
    "fazi": "fad",
    "fazii": "fad",
    "fazilor": "fad",
    "fadoul": "fado",
    "fadoului": "fado",
    "fadouri": "fado",
    "fadourile": "fado",
    "fadourilor": "fado",
    "faetoane": "faeton",
    "faetoanele": "faeton",
    "faetoanelor": "faeton",
    "faetonul": "faeton",
    "faetonului": "faeton",
    "fagi": "fag",
    "fagii": "fag",
    "fagilor": "fag",
    "fagul": "fag",
    "fagului": "fag",
    "fagaceele": "fagacee",
    "fagaceelor": "fagacee",
    "făgădaie": "făgădău",
    "făgădaiele": "făgădău",
    "făgădaielor": "făgădău",
    "făgădăul": "făgădău",
    "făgădăului": "făgădău",
    "făgăduia": "făgădui",
    "făgăduiai": "făgădui",
    "făgăduiam": "făgădui",
    "făgăduiască": "făgădui",
    "făgăduiați": "făgădui",
    "făgăduiau": "făgădui",
    "făgăduiesc": "făgădui",
    "făgăduiește": "făgădui",
    "făgăduiești": "făgădui",
    "făgăduii": "făgădui",
    "făgăduim": "făgădui",
    "făgăduind": "făgădui",
    "făgăduindu": "făgădui",
    "făgăduiră": "făgădui",
    "făgăduirăm": "făgădui",
    "făgăduirăți": "făgădui",
    "făgăduise": "făgădui",
    "făgăduisem": "făgădui",
    "făgăduiseră": "făgădui",
    "făgăduiserăm": "făgădui",
    "făgăduiserăți": "făgădui",
    "făgăduiseși": "făgădui",
    "făgăduiși": "făgădui",
    "făgăduit": "făgădui",
    "făgăduiți": "făgădui",
    "făgăduitu": "făgădui",
    "nefăgăduind": "făgădui",
    "nefăgăduindu": "făgădui",
    "nemaifăgăduind": "făgădui",
    "nemaifăgăduindu": "făgădui",
    "făgăduiala": "făgăduială",
    "făgăduieli": "făgăduială",
    "făgăduielii": "făgăduială",
    "făgăduielile": "făgăduială",
    "făgăduielilor": "făgăduială",
    "făgăduința": "făgăduință",
    "făgăduințe": "făgăduință",
    "făgăduinței": "făgăduință",
    "făgăduințele": "făgăduință",
    "făgăduințelor": "făgăduință",
    "făgăduită": "făgăduit",
    "făgăduite": "făgăduit",
    "făgăduiți": "făgăduit",
    "făgașe": "făgaș",
    "făgașele": "făgaș",
    "făgașelor": "făgaș",
    "făgașul": "făgaș",
    "făgașului": "făgaș",
    "făgete": "făget",
    "făgetele": "făget",
    "făgetelor": "făget",
    "făgetul": "făget",
    "făgetului": "făget",
    "făgețele": "făgețel",
    "făgețelele": "făgețel",
    "făgețelelor": "făgețel",
    "făgețelul": "făgețel",
    "făgețelului": "făgețel",
    "fagocite": "fagocit",
    "fagocitele": "fagocit",
    "fagocitelor": "fagocit",
    "fagocitul": "fagocit",
    "fagocitului": "fagocit",
    "fagocitoza": "fagocitoză",
    "fagocitoze": "fagocitoză",
    "fagocitozei": "fagocitoză",
    "fagocitozele": "fagocitoză",
    "fagocitozelor": "fagocitoză",
    "fagotul": "fagot",
    "fagotului": "fagot",
    "fagoturi": "fagot",
    "fagoturile": "fagot",
    "fagoturilor": "fagot",
    "fagotiști": "fagotist",
    "fagotiștii": "fagotist",
    "fagotiștilor": "fagotist",
    "fagotistul": "fagotist",
    "fagotistului": "fagotist",
    "fagotista": "fagotistă",
    "fagotiste": "fagotistă",
    "fagotistei": "fagotistă",
    "fagotistele": "fagotistă",
    "fagotistelor": "fagotistă",
    "fagurele": "fagure",
    "fagurelui": "fagure",
    "faguri": "fagure",
    "fagurii": "fagure",
    "fagurilor": "fagure",
    "F": "Fahrenheit",
    "faianță": "faianța",
    "faianțai": "faianța",
    "faianțam": "faianța",
    "faianțăm": "faianța",
    "faianțând": "faianța",
    "faianțându": "faianța",
    "faianțară": "faianța",
    "faianțarăm": "faianța",
    "faianțarăți": "faianța",
    "faianțase": "faianța",
    "faianțasem": "faianța",
    "faianțaseră": "faianța",
    "faianțaserăm": "faianța",
    "faianțaserăți": "faianța",
    "faianțaseși": "faianța",
    "faianțași": "faianța",
    "faianțat": "faianța",
    "faianțați": "faianța",
    "faianțatu": "faianța",
    "faianțau": "faianța",
    "faianțează": "faianța",
    "faianțez": "faianța",
    "faianțeze": "faianța",
    "faianțezi": "faianța",
    "nefaianțând": "faianța",
    "nefaianțându": "faianța",
    "nemaifaianțând": "faianța",
    "nemaifaianțându": "faianța",
    "faianța": "faianță",
    "faianțe": "faianță",
    "faianței": "faianță",
    "faianțele": "faianță",
    "faianțelor": "faianță",
    "faianțarea": "faianțare",
    "faianțări": "faianțare",
    "faianțării": "faianțare",
    "faianțările": "faianțare",
    "faianțărilor": "faianțare",
    "faianțată": "faianțat",
    "faianțate": "faianțat",
    "faianțați": "faianțat",
    "faianțatoarea": "faianțatoare",
    "faianțatoarei": "faianțatoare",
    "faianțatoarele": "faianțatoare",
    "faianțatoarelor": "faianțatoare",
    "faianțatori": "faianțator",
    "faianțatorii": "faianțator",
    "faianțatorilor": "faianțator",
    "faianțatorul": "faianțator",
    "faianțatorului": "faianțator",
    "faima": "faimă",
    "faime": "faimă",
    "faimei": "faimă",
    "faimele": "faimă",
    "faimelor": "faimă",
    "faimoasa": "faimos",
    "faimoasă": "faimos",
    "faimoase": "faimos",
    "faimoasei": "faimos",
    "faimoasele": "faimos",
    "faimoaselor": "faimos",
    "faimoși": "faimos",
    "faimoșii": "faimos",
    "faimoșilor": "faimos",
    "faimosul": "faimos",
    "faimosului": "faimos",
    "faina": "fain",
    "faină": "fain",
    "faine": "fain",
    "fainei": "fain",
    "fainele": "fain",
    "fainelor": "fain",
    "faini": "fain",
    "fainii": "fain",
    "fainilor": "fain",
    "faino": "fain",
    "fainul": "fain",
    "fainule": "fain",
    "fainului": "fain",
    "făina": "făină",
    "făini": "făină",
    "făinii": "făină",
    "făinuri": "făină",
    "făinurile": "făină",
    "făinurilor": "făină",
    "făinarea": "făinare",
    "făinări": "făinare",
    "făinării": "făinare",
    "făinoasele": "făinoase",
    "făinoaselor": "făinoase",
    "făinoasă": "făinos",
    "făinoase": "făinos",
    "făinoasele": "făinos",
    "făinoaselor": "făinos",
    "fairplayul": "fairplay",
    "fairplayului": "fairplay",
    "fala": "fală",
    "fale": "fală",
    "falei": "fală",
    "falaitari": "falaitar",
    "falaitarii": "falaitar",
    "falaitarilor": "falaitar",
    "falaitarul": "falaitar",
    "falaitarului": "falaitar",
    "fălălăia": "fălălăi",
    "fălălăiai": "fălălăi",
    "fălălăiam": "fălălăi",
    "fălălăiască": "fălălăi",
    "fălălăiați": "fălălăi",
    "fălălăiau": "fălălăi",
    "fălălăiesc": "fălălăi",
    "fălălăiește": "fălălăi",
    "fălălăiești": "fălălăi",
    "fălălăii": "fălălăi",
    "fălălăim": "fălălăi",
    "fălălăind": "fălălăi",
    "fălălăindu": "fălălăi",
    "fălălăiră": "fălălăi",
    "fălălăirăm": "fălălăi",
    "fălălăirăți": "fălălăi",
    "fălălăise": "fălălăi",
    "fălălăisem": "fălălăi",
    "fălălăiseră": "fălălăi",
    "fălălăiserăm": "fălălăi",
    "fălălăiserăți": "fălălăi",
    "fălălăiseși": "fălălăi",
    "fălălăiși": "fălălăi",
    "fălălăit": "fălălăi",
    "fălălăiți": "fălălăi",
    "fălălăitu": "fălălăi",
    "nefălălăind": "fălălăi",
    "nefălălăindu": "fălălăi",
    "nemaifălălăind": "fălălăi",
    "nemaifălălăindu": "fălălăi",
    "fălălăită": "fălălăit",
    "fălălăite": "fălălăit",
    "fălălăiți": "fălălăit",
    "falanga": "falangă",
    "falange": "falangă",
    "falangei": "falangă",
    "falangele": "falangă",
    "falangelor": "falangă",
    "falangiști": "falangist",
    "falangiștii": "falangist",
    "falangiștilor": "falangist",
    "falangistul": "falangist",
    "falangistului": "falangist",
    "falanstere": "falanster",
    "falansterele": "falanster",
    "falansterelor": "falanster",
    "falansterul": "falanster",
    "falansterului": "falanster",
    "falansterianul": "falansterian",
    "falansterianului": "falansterian",
    "falansterieni": "falansterian",
    "falansterienii": "falansterian",
    "falansterienilor": "falansterian",
    "falansterianismul": "falansterianism",
    "falansterianismului": "falansterianism",
    "falarica": "falarică",
    "falarice": "falarică",
    "falaricei": "falarică",
    "falbalale": "falbala",
    "falbalalei": "falbala",
    "falbalalele": "falbala",
    "falbalalelor": "falbala",
    "falbalaua": "falbala",
    "falca": "falcă",
    "fălci": "falcă",
    "fălcii": "falcă",
    "fălcile": "falcă",
    "fălcilor": "falcă",
    "fălcarița": "fălcariță",
    "fălcarițe": "fălcariță",
    "fălcariței": "fălcariță",
    "fălcarițele": "fălcariță",
    "fălcarițelor": "fălcariță",
    "fălceaua": "fălcea",
    "fălcele": "fălcea",
    "fălcelei": "fălcea",
    "fălcelele": "fălcea",
    "fălcelelor": "fălcea",
    "falconete": "falconet",
    "falconetele": "falconet",
    "falconetelor": "falconet",
    "falconetul": "falconet",
    "falconetului": "falconet",
    "falconida": "falconidă",
    "falconide": "falconidă",
    "falconidei": "falconidă",
    "falconidele": "falconidă",
    "falconidelor": "falconidă",
    "falconiforma": "falconiformă",
    "falconiforme": "falconiformă",
    "falconiformei": "falconiformă",
    "falconiformele": "falconiformă",
    "falconiformelor": "falconiformă",
    "faldul": "fald",
    "faldului": "fald",
    "falduri": "fald",
    "faldurile": "fald",
    "faldurilor": "fald",
    "falena": "falenă",
    "falene": "falenă",
    "falenei": "falenă",
    "falenele": "falenă",
    "falenelor": "falenă",
    "falernul": "falern",
    "falernului": "falern",
    "faletul": "falet",
    "faletului": "falet",
    "faleturi": "falet",
    "faleturile": "falet",
    "faleturilor": "falet",
    "faleza": "faleză",
    "faleze": "faleză",
    "falezei": "faleză",
    "falezele": "faleză",
    "falezelor": "faleză",
    "fâlfâia": "fâlfâi",
    "fâlfâiai": "fâlfâi",
    "fâlfâiam": "fâlfâi",
    "fâlfâiați": "fâlfâi",
    "fâlfâiau": "fâlfâi",
    "fâlfâie": "fâlfâi",
    "fâlfâii": "fâlfâi",
    "fâlfâim": "fâlfâi",
    "fâlfâind": "fâlfâi",
    "fâlfâindu": "fâlfâi",
    "fâlfâiră": "fâlfâi",
    "fâlfâirăm": "fâlfâi",
    "fâlfâirăți": "fâlfâi",
    "fâlfâise": "fâlfâi",
    "fâlfâisem": "fâlfâi",
    "fâlfâiseră": "fâlfâi",
    "fâlfâiserăm": "fâlfâi",
    "fâlfâiserăți": "fâlfâi",
    "fâlfâiseși": "fâlfâi",
    "fâlfâiși": "fâlfâi",
    "fâlfâit": "fâlfâi",
    "fâlfâiți": "fâlfâi",
    "fâlfâitu": "fâlfâi",
    "nefâlfâind": "fâlfâi",
    "nefâlfâindu": "fâlfâi",
    "nemaifâlfâind": "fâlfâi",
    "nemaifâlfâindu": "fâlfâi",
    "fâlfâirea": "fâlfâire",
    "fâlfâiri": "fâlfâire",
    "fâlfâirii": "fâlfâire",
    "fâlfâirile": "fâlfâire",
    "fâlfâirilor": "fâlfâire",
    "fâlfâită": "fâlfâit",
    "fâlfâite": "fâlfâit",
    "fâlfâiți": "fâlfâit",
    "fâlfâitul": "fâlfâit",
    "fâlfâitului": "fâlfâit",
    "fâlfâituri": "fâlfâit",
    "fâlfâiturile": "fâlfâit",
    "fâlfâiturilor": "fâlfâit",
    "fălea": "făli",
    "făleai": "făli",
    "făleam": "făli",
    "fălească": "făli",
    "făleați": "făli",
    "făleau": "făli",
    "fălesc": "făli",
    "fălește": "făli",
    "fălești": "făli",
    "fălii": "făli",
    "fălim": "făli",
    "fălind": "făli",
    "fălindu": "făli",
    "făliră": "făli",
    "fălirăm": "făli",
    "fălirăți": "făli",
    "fălise": "făli",
    "fălisem": "făli",
    "făliseră": "făli",
    "făliserăm": "făli",
    "făliserăți": "făli",
    "făliseși": "făli",
    "făliși": "făli",
    "fălit": "făli",
    "făliți": "făli",
    "fălitu": "făli",
    "nefălind": "făli",
    "nefălindu": "făli",
    "nemaifălind": "făli",
    "nemaifălindu": "făli",
    "faliai": "falia",
    "faliam": "falia",
    "faliară": "falia",
    "faliarăm": "falia",
    "faliarăți": "falia",
    "faliase": "falia",
    "faliasem": "falia",
    "faliaseră": "falia",
    "faliaserăm": "falia",
    "faliaserăți": "falia",
    "faliaseși": "falia",
    "faliași": "falia",
    "faliat": "falia",
    "faliați": "falia",
    "faliatu": "falia",
    "faliau": "falia",
    "faliază": "falia",
    "falie": "falia",
    "faliem": "falia",
    "faliez": "falia",
    "falieze": "falia",
    "faliezi": "falia",
    "faliind": "falia",
    "faliindu": "falia",
    "nefaliind": "falia",
    "nefaliindu": "falia",
    "nemaifaliind": "falia",
    "nemaifaliindu": "falia",
    "faliată": "faliat",
    "faliate": "faliat",
    "faliați": "faliat",
    "falia": "falie",
    "faliei": "falie",
    "falii": "falie",
    "faliile": "falie",
    "faliilor": "falie",
    "falimente": "faliment",
    "falimentele": "faliment",
    "falimentelor": "faliment",
    "falimentul": "faliment",
    "falimentului": "faliment",
    "falimentară": "falimentar",
    "falimentarea": "falimentare",
    "falimentări": "falimentare",
    "falimentării": "falimentare",
    "falimentările": "falimentare",
    "falimentărilor": "falimentare",
    "falita": "falit",
    "falită": "falit",
    "falite": "falit",
    "falitei": "falit",
    "falitele": "falit",
    "falitelor": "falit",
    "faliți": "falit",
    "faliții": "falit",
    "faliților": "falit",
    "falitul": "falit",
    "falitului": "falit",
    "fălită": "fălit",
    "fălite": "fălit",
    "făliți": "fălit",
    "falita": "falită",
    "falite": "falită",
    "falitei": "falită",
    "falitele": "falită",
    "falitelor": "falită",
    "fălnicia": "fălnicie",
    "fălniciei": "fălnicie",
    "fălnicii": "fălnicie",
    "făloasa": "fălos",
    "făloasă": "fălos",
    "făloase": "fălos",
    "făloasei": "fălos",
    "făloasele": "fălos",
    "făloaselor": "fălos",
    "făloaso": "fălos",
    "făloși": "fălos",
    "făloșii": "fălos",
    "făloșilor": "fălos",
    "fălosul": "fălos",
    "fălosule": "fălos",
    "fălosului": "fălos",
    "făloșea": "făloși",
    "făloșeai": "făloși",
    "făloșeam": "făloși",
    "făloșească": "făloși",
    "făloșeați": "făloși",
    "făloșeau": "făloși",
    "făloșesc": "făloși",
    "făloșește": "făloși",
    "făloșești": "făloși",
    "făloșii": "făloși",
    "făloșim": "făloși",
    "făloșind": "făloși",
    "făloșindu": "făloși",
    "făloșiră": "făloși",
    "făloșirăm": "făloși",
    "făloșirăți": "făloși",
    "făloșise": "făloși",
    "făloșisem": "făloși",
    "făloșiseră": "făloși",
    "făloșiserăm": "făloși",
    "făloșiserăți": "făloși",
    "făloșiseși": "făloși",
    "făloșiși": "făloși",
    "făloșit": "făloși",
    "făloșiți": "făloși",
    "făloșitu": "făloși",
    "nefăloșind": "făloși",
    "nefăloșindu": "făloși",
    "nemaifăloșind": "făloși",
    "nemaifăloșindu": "făloși",
    "făloșia": "făloșie",
    "făloșiei": "făloșie",
    "făloșii": "făloșie",
    "făloșită": "făloșit",
    "făloșite": "făloșit",
    "făloșiți": "făloșit",
    "falsa": "fals",
    "falsă": "fals",
    "false": "fals",
    "falsei": "fals",
    "falsele": "fals",
    "falselor": "fals",
    "falși": "fals",
    "falșii": "fals",
    "falșilor": "fals",
    "falsul": "fals",
    "falsului": "fals",
    "falsuri": "fals",
    "falsurile": "fals",
    "falsurilor": "fals",
    "falsific": "falsifica",
    "falsifică": "falsifica",
    "falsificai": "falsifica",
    "falsificam": "falsifica",
    "falsificăm": "falsifica",
    "falsificând": "falsifica",
    "falsificându": "falsifica",
    "falsificară": "falsifica",
    "falsificarăm": "falsifica",
    "falsificarăți": "falsifica",
    "falsificase": "falsifica",
    "falsificasem": "falsifica",
    "falsificaseră": "falsifica",
    "falsificaserăm": "falsifica",
    "falsificaserăți": "falsifica",
    "falsificaseși": "falsifica",
    "falsificași": "falsifica",
    "falsificat": "falsifica",
    "falsificați": "falsifica",
    "falsificatu": "falsifica",
    "falsificau": "falsifica",
    "falsifice": "falsifica",
    "falsifici": "falsifica",
    "nefalsificând": "falsifica",
    "nefalsificându": "falsifica",
    "nemaifalsificând": "falsifica",
    "nemaifalsificându": "falsifica",
    "falsificarea": "falsificare",
    "falsificări": "falsificare",
    "falsificării": "falsificare",
    "falsificările": "falsificare",
    "falsificărilor": "falsificare",
    "falsificată": "falsificat",
    "falsificate": "falsificat",
    "falsificați": "falsificat",
    "falsitatea": "falsitate",
    "falsități": "falsitate",
    "falsității": "falsitate",
    "falsitățile": "falsitate",
    "falsităților": "falsitate",
    "falțul": "falț",
    "falțului": "falț",
    "falțuri": "falț",
    "falțurile": "falț",
    "falțurilor": "falț",
    "fălțuia": "fălțui",
    "fălțuiai": "fălțui",
    "fălțuiam": "fălțui",
    "fălțuiască": "fălțui",
    "fălțuiați": "fălțui",
    "fălțuiau": "fălțui",
    "fălțuiesc": "fălțui",
    "fălțuiește": "fălțui",
    "fălțuiești": "fălțui",
    "fălțuii": "fălțui",
    "fălțuim": "fălțui",
    "fălțuind": "fălțui",
    "fălțuindu": "fălțui",
    "fălțuiră": "fălțui",
    "fălțuirăm": "fălțui",
    "fălțuirăți": "fălțui",
    "fălțuise": "fălțui",
    "fălțuisem": "fălțui",
    "fălțuiseră": "fălțui",
    "fălțuiserăm": "fălțui",
    "fălțuiserăți": "fălțui",
    "fălțuiseși": "fălțui",
    "fălțuiși": "fălțui",
    "fălțuit": "fălțui",
    "fălțuiți": "fălțui",
    "fălțuitu": "fălțui",
    "nefălțuind": "fălțui",
    "nefălțuindu": "fălțui",
    "nemaifălțuind": "fălțui",
    "nemaifălțuindu": "fălțui",
    "fălțuirea": "fălțuire",
    "fălțuiri": "fălțuire",
    "fălțuirii": "fălțuire",
    "fălțuirile": "fălțuire",
    "fălțuirilor": "fălțuire",
    "fălțuită": "fălțuit",
    "fălțuite": "fălțuit",
    "fălțuiți": "fălțuit",
    "fălțuitul": "fălțuit",
    "fălțuitului": "fălțuit",
    "fălțuitoarea": "fălțuitoare",
    "fălțuitoarei": "fălțuitoare",
    "fălțuitoarele": "fălțuitoare",
    "fălțuitoarelor": "fălțuitoare",
    "fălțuitori": "fălțuitor",
    "fălțuitorii": "fălțuitor",
    "fălțuitorilor": "fălțuitor",
    "fălțuitorul": "fălțuitor",
    "fălțuitorului": "fălțuitor",
    "famata": "famat",
    "famată": "famat",
    "famate": "famat",
    "famatei": "famat",
    "famatele": "famat",
    "famatelor": "famat",
    "famați": "famat",
    "famații": "famat",
    "famaților": "famat",
    "famatul": "famat",
    "famatului": "famat",
    "familiala": "familial",
    "familială": "familial",
    "familiale": "familial",
    "familialei": "familial",
    "familialele": "familial",
    "familialelor": "familial",
    "familiali": "familial",
    "familialii": "familial",
    "familialilor": "familial",
    "familialul": "familial",
    "familialului": "familial",
    "familiara": "familiar",
    "familiară": "familiar",
    "familiare": "familiar",
    "familiarei": "familiar",
    "familiarele": "familiar",
    "familiarelor": "familiar",
    "familiari": "familiar",
    "familiarii": "familiar",
    "familiarilor": "familiar",
    "familiarul": "familiar",
    "familiarului": "familiar",
    "familiariză": "familiariza",
    "familiarizai": "familiariza",
    "familiarizam": "familiariza",
    "familiarizăm": "familiariza",
    "familiarizând": "familiariza",
    "familiarizându": "familiariza",
    "familiarizară": "familiariza",
    "familiarizarăm": "familiariza",
    "familiarizarăți": "familiariza",
    "familiarizase": "familiariza",
    "familiarizasem": "familiariza",
    "familiarizaseră": "familiariza",
    "familiarizaserăm": "familiariza",
    "familiarizaserăți": "familiariza",
    "familiarizaseși": "familiariza",
    "familiarizași": "familiariza",
    "familiarizat": "familiariza",
    "familiarizați": "familiariza",
    "familiarizau": "familiariza",
    "familiarizează": "familiariza",
    "familiarizez": "familiariza",
    "familiarizeze": "familiariza",
    "familiarizezi": "familiariza",
    "nefamiliarizând": "familiariza",
    "nefamiliarizându": "familiariza",
    "nemaifamiliarizând": "familiariza",
    "nemaifamiliarizându": "familiariza",
    "familiarizarea": "familiarizare",
    "familiarizareo": "familiarizare",
    "familiarizări": "familiarizare",
    "familiarizării": "familiarizare",
    "familiarizările": "familiarizare",
    "familiarizărilor": "familiarizare",
    "familiarizată": "familiarizat",
    "familiarizate": "familiarizat",
    "familiarizați": "familiarizat",
    "familia": "familie",
    "familiei": "familie",
    "familii": "familie",
    "familiile": "familie",
    "familiilor": "familie",
    "familista": "familist",
    "familistă": "familist",
    "familiste": "familist",
    "familistei": "familist",
    "familistele": "familist",
    "familistelor": "familist",
    "familiști": "familist",
    "familiștii": "familist",
    "familiștilor": "familist",
    "familistul": "familist",
    "familistului": "familist",
    "familista": "familistă",
    "familiste": "familistă",
    "familistei": "familistă",
    "familistele": "familistă",
    "familistelor": "familistă",
    "fânul": "fân",
    "fânului": "fân",
    "fânuri": "fân",
    "fânurile": "fân",
    "fânurilor": "fân",
    "fană": "fana",
    "fanai": "fana",
    "fanam": "fana",
    "fanăm": "fana",
    "fanând": "fana",
    "fanându": "fana",
    "fanară": "fana",
    "fanarăm": "fana",
    "fanarăți": "fana",
    "fanase": "fana",
    "fanasem": "fana",
    "fanaseră": "fana",
    "fanaserăm": "fana",
    "fanaserăți": "fana",
    "fanaseși": "fana",
    "fanași": "fana",
    "fanat": "fana",
    "fanați": "fana",
    "fanatu": "fana",
    "fanau": "fana",
    "fanează": "fana",
    "fanez": "fana",
    "faneze": "fana",
    "fanezi": "fana",
    "nefanând": "fana",
    "nefanându": "fana",
    "nemaifanând": "fana",
    "nemaifanându": "fana",
    "fanarea": "fanare",
    "fanări": "fanare",
    "fanării": "fanare",
    "fanările": "fanare",
    "fanărilor": "fanare",
    "fanariota": "fanariot",
    "fanariotă": "fanariot",
    "fanariote": "fanariot",
    "fanariotei": "fanariot",
    "fanariotele": "fanariot",
    "fanariotelor": "fanariot",
    "fanarioți": "fanariot",
    "fanarioții": "fanariot",
    "fanarioților": "fanariot",
    "fanariotul": "fanariot",
    "fanariotului": "fanariot",
    "fanariota": "fanariotă",
    "fanariote": "fanariotă",
    "fanariotei": "fanariotă",
    "fanariotele": "fanariotă",
    "fanariotelor": "fanariotă",
    "fanariotiză": "fanariotiza",
    "fanariotizai": "fanariotiza",
    "fanariotizam": "fanariotiza",
    "fanariotizăm": "fanariotiza",
    "fanariotizând": "fanariotiza",
    "fanariotizându": "fanariotiza",
    "fanariotizară": "fanariotiza",
    "fanariotizarăm": "fanariotiza",
    "fanariotizarăți": "fanariotiza",
    "fanariotizase": "fanariotiza",
    "fanariotizasem": "fanariotiza",
    "fanariotizaseră": "fanariotiza",
    "fanariotizaserăm": "fanariotiza",
    "fanariotizaserăți": "fanariotiza",
    "fanariotizaseși": "fanariotiza",
    "fanariotizași": "fanariotiza",
    "fanariotizat": "fanariotiza",
    "fanariotizați": "fanariotiza",
    "fanariotizau": "fanariotiza",
    "fanariotizează": "fanariotiza",
    "fanariotizez": "fanariotiza",
    "fanariotizeze": "fanariotiza",
    "fanariotizezi": "fanariotiza",
    "nefanariotizând": "fanariotiza",
    "nefanariotizându": "fanariotiza",
    "nemaifanariotizând": "fanariotiza",
    "nemaifanariotizându": "fanariotiza",
    "fanariotizarea": "fanariotizare",
    "fanariotizareo": "fanariotizare",
    "fanariotizări": "fanariotizare",
    "fanariotizării": "fanariotizare",
    "fanariotizările": "fanariotizare",
    "fanariotizărilor": "fanariotizare",
    "fanariotizată": "fanariotizat",
    "fanariotizate": "fanariotizat",
    "fanariotizați": "fanariotizat",
    "fanată": "fanat",
    "fanate": "fanat",
    "fanați": "fanat",
    "fanatica": "fanatic",
    "fanatică": "fanatic",
    "fanatice": "fanatic",
    "fanaticei": "fanatic",
    "fanaticele": "fanatic",
    "fanaticelor": "fanatic",
    "fanatici": "fanatic",
    "fanaticii": "fanatic",
    "fanaticilor": "fanatic",
    "fanaticul": "fanatic",
    "fanaticului": "fanatic",
    "fanatica": "fanatică",
    "fanatice": "fanatică",
    "fanaticei": "fanatică",
    "fanaticele": "fanatică",
    "fanaticelor": "fanatică",
    "fanatisme": "fanatism",
    "fanatismele": "fanatism",
    "fanatismelor": "fanatism",
    "fanatismul": "fanatism",
    "fanatismului": "fanatism",
    "fandă": "fanda",
    "fandai": "fanda",
    "fandam": "fanda",
    "fandăm": "fanda",
    "fandând": "fanda",
    "fandându": "fanda",
    "fandară": "fanda",
    "fandarăm": "fanda",
    "fandarăți": "fanda",
    "fandase": "fanda",
    "fandasem": "fanda",
    "fandaseră": "fanda",
    "fandaserăm": "fanda",
    "fandaserăți": "fanda",
    "fandaseși": "fanda",
    "fandași": "fanda",
    "fandat": "fanda",
    "fandați": "fanda",
    "fandatu": "fanda",
    "fandau": "fanda",
    "fandează": "fanda",
    "fandez": "fanda",
    "fandeze": "fanda",
    "fandezi": "fanda",
    "nefandând": "fanda",
    "nefandându": "fanda",
    "nemaifandând": "fanda",
    "nemaifandându": "fanda",
    "fandarea": "fandare",
    "fandări": "fandare",
    "fandării": "fandare",
    "fandările": "fandare",
    "fandărilor": "fandare",
    "fandată": "fandat",
    "fandate": "fandat",
    "fandați": "fandat",
    "fandosea": "fandosi",
    "fandoseai": "fandosi",
    "fandoseam": "fandosi",
    "fandosească": "fandosi",
    "fandoseați": "fandosi",
    "fandoseau": "fandosi",
    "fandosesc": "fandosi",
    "fandosește": "fandosi",
    "fandosești": "fandosi",
    "fandosii": "fandosi",
    "fandosim": "fandosi",
    "fandosind": "fandosi",
    "fandosindu": "fandosi",
    "fandosiră": "fandosi",
    "fandosirăm": "fandosi",
    "fandosirăți": "fandosi",
    "fandosise": "fandosi",
    "fandosisem": "fandosi",
    "fandosiseră": "fandosi",
    "fandosiserăm": "fandosi",
    "fandosiserăți": "fandosi",
    "fandosiseși": "fandosi",
    "fandosiși": "fandosi",
    "fandosit": "fandosi",
    "fandosiți": "fandosi",
    "fandositu": "fandosi",
    "nefandosind": "fandosi",
    "nefandosindu": "fandosi",
    "nemaifandosind": "fandosi",
    "nemaifandosindu": "fandosi",
    "fandosirea": "fandosire",
    "fandosireo": "fandosire",
    "fandosiri": "fandosire",
    "fandosirii": "fandosire",
    "fandosirile": "fandosire",
    "fandosirilor": "fandosire",
    "fandosita": "fandosit",
    "fandosită": "fandosit",
    "fandosite": "fandosit",
    "fandositei": "fandosit",
    "fandositele": "fandosit",
    "fandositelor": "fandosit",
    "fandosiți": "fandosit",
    "fandosiții": "fandosit",
    "fandosiților": "fandosit",
    "fandosito": "fandosit",
    "fandositul": "fandosit",
    "fandositule": "fandosit",
    "fandositului": "fandosit",
    "fanfara": "fanfară",
    "fanfare": "fanfară",
    "fanfarei": "fanfară",
    "fanfarele": "fanfară",
    "fanfarelor": "fanfară",
    "fanioane": "fanion",
    "fanioanele": "fanion",
    "fanioanelor": "fanion",
    "fanionul": "fanion",
    "fanionului": "fanion",
    "fanta": "fantă",
    "fante": "fantă",
    "fantei": "fantă",
    "fantele": "fantă",
    "fantelor": "fantă",
    "fântâna": "fântână",
    "fântâni": "fântână",
    "fântânii": "fântână",
    "fântânile": "fântână",
    "fântânilor": "fântână",
    "fantasma": "fantasmă",
    "fantasme": "fantasmă",
    "fantasmei": "fantasmă",
    "fantasmele": "fantasmă",
    "fantasmelor": "fantasmă",
    "fantastica": "fantastic",
    "fantastică": "fantastic",
    "fantastice": "fantastic",
    "fantasticei": "fantastic",
    "fantasticele": "fantastic",
    "fantasticelor": "fantastic",
    "fantastici": "fantastic",
    "fantasticii": "fantastic",
    "fantasticilor": "fantastic",
    "fantasticul": "fantastic",
    "fantasticului": "fantastic",
    "fantază": "fantaza",
    "fantazai": "fantaza",
    "fantazam": "fantaza",
    "fantazăm": "fantaza",
    "fantazând": "fantaza",
    "fantazându": "fantaza",
    "fantazară": "fantaza",
    "fantazarăm": "fantaza",
    "fantazarăți": "fantaza",
    "fantazase": "fantaza",
    "fantazasem": "fantaza",
    "fantazaseră": "fantaza",
    "fantazaserăm": "fantaza",
    "fantazaserăți": "fantaza",
    "fantazaseși": "fantaza",
    "fantazași": "fantaza",
    "fantazat": "fantaza",
    "fantazați": "fantaza",
    "fantazatu": "fantaza",
    "fantazau": "fantaza",
    "fantazează": "fantaza",
    "fantazez": "fantaza",
    "fantazeze": "fantaza",
    "fantazezi": "fantaza",
    "fantazarea": "fantazare",
    "fantazareo": "fantazare",
    "fantazări": "fantazare",
    "fantazării": "fantazare",
    "fantazările": "fantazare",
    "fantazărilor": "fantazare",
    "fantazată": "fantazat",
    "fantazate": "fantazat",
    "fantazați": "fantazat",
    "fantele": "fante",
    "fantelui": "fante",
    "fantezia": "fantezie",
    "fanteziei": "fantezie",
    "fantezii": "fantezie",
    "fanteziile": "fantezie",
    "fanteziilor": "fantezie",
    "fantezista": "fantezist",
    "fantezistă": "fantezist",
    "fanteziste": "fantezist",
    "fantezistei": "fantezist",
    "fantezistele": "fantezist",
    "fantezistelor": "fantezist",
    "fanteziști": "fantezist",
    "fanteziștii": "fantezist",
    "fanteziștilor": "fantezist",
    "fantezistul": "fantezist",
    "fantezistului": "fantezist",
    "fantoma": "fantomă",
    "fantome": "fantomă",
    "fantomei": "fantomă",
    "fantomele": "fantomă",
    "fantomelor": "fantomă",
    "fantomatica": "fantomatic",
    "fantomatică": "fantomatic",
    "fantomatice": "fantomatic",
    "fantomaticei": "fantomatic",
    "fantomaticele": "fantomatic",
    "fantomaticelor": "fantomatic",
    "fantomatici": "fantomatic",
    "fantomaticii": "fantomatic",
    "fantomaticilor": "fantomatic",
    "fantomaticul": "fantomatic",
    "fantomaticului": "fantomatic",
    "fantoșa": "fantoșă",
    "fantoșe": "fantoșă",
    "fantoșei": "fantoșă",
    "fantoșele": "fantoșă",
    "fantoșelor": "fantoșă",
    "fapte": "fapt",
    "faptele": "fapt",
    "faptelor": "fapt",
    "faptul": "fapt",
    "faptului": "fapt",
    "fapta": "faptă",
    "fapte": "faptă",
    "faptei": "faptă",
    "faptele": "faptă",
    "faptelor": "faptă",
    "făptași": "făptaș",
    "făptașii": "făptaș",
    "făptașilor": "făptaș",
    "făptașul": "făptaș",
    "făptașului": "făptaș",
    "făptașa": "făptașă",
    "făptașe": "făptașă",
    "făptașei": "făptașă",
    "făptașele": "făptașă",
    "făptașelor": "făptașă",
    "faptica": "faptic",
    "faptică": "faptic",
    "faptice": "faptic",
    "fapticei": "faptic",
    "fapticele": "faptic",
    "fapticelor": "faptic",
    "faptici": "faptic",
    "fapticii": "faptic",
    "fapticilor": "faptic",
    "faptico": "faptic",
    "fapticul": "faptic",
    "fapticule": "faptic",
    "fapticului": "faptic",
    "făptuia": "făptui",
    "făptuiai": "făptui",
    "făptuiam": "făptui",
    "făptuiască": "făptui",
    "făptuiați": "făptui",
    "făptuiau": "făptui",
    "făptuie": "făptui",
    "făptuiesc": "făptui",
    "făptuiește": "făptui",
    "făptuiești": "făptui",
    "făptuii": "făptui",
    "făptuim": "făptui",
    "făptuind": "făptui",
    "făptuindu": "făptui",
    "făptuiră": "făptui",
    "făptuirăm": "făptui",
    "făptuirăți": "făptui",
    "făptuise": "făptui",
    "făptuisem": "făptui",
    "făptuiseră": "făptui",
    "făptuiserăm": "făptui",
    "făptuiserăți": "făptui",
    "făptuiseși": "făptui",
    "făptuiși": "făptui",
    "făptuit": "făptui",
    "făptuiți": "făptui",
    "făptuitu": "făptui",
    "nefăptuind": "făptui",
    "nefăptuindu": "făptui",
    "nemaifăptuind": "făptui",
    "nemaifăptuindu": "făptui",
    "făptuirea": "făptuire",
    "făptuiri": "făptuire",
    "făptuirii": "făptuire",
    "făptuirile": "făptuire",
    "făptuirilor": "făptuire",
    "făptuită": "făptuit",
    "făptuite": "făptuit",
    "făptuiți": "făptuit",
    "făptuitoarea": "făptuitoare",
    "făptuitoarei": "făptuitoare",
    "făptuitoarele": "făptuitoare",
    "făptuitoarelor": "făptuitoare",
    "făptuitori": "făptuitor",
    "făptuitorii": "făptuitor",
    "făptuitorilor": "făptuitor",
    "făptuitorul": "făptuitor",
    "făptuitorului": "făptuitor",
    "făptura": "făptură",
    "făpturi": "făptură",
    "făpturii": "făptură",
    "făpturile": "făptură",
    "făpturilor": "făptură",
    "farul": "far",
    "farului": "far",
    "faruri": "far",
    "farurile": "far",
    "farurilor": "far",
    "făr'": "fără",
    "f.a.": "fără_an",
    "f.f.": "fără_frecvență",
    "F": "farad",
    "faradul": "farad",
    "faradului": "farad",
    "farazi": "farad",
    "farazii": "farad",
    "farazilor": "farad",
    "fărădelegea": "fărădelege",
    "fărădelegi": "fărădelege",
    "fărădelegii": "fărădelege",
    "fărădelegile": "fărădelege",
    "fărădelegilor": "fărădelege",
    "faradoterapia": "faradoterapie",
    "faradoterapiei": "faradoterapie",
    "faradoterapii": "faradoterapie",
    "farafastâcul": "farafastâc",
    "farafastâcului": "farafastâc",
    "farafastâcuri": "farafastâc",
    "farafastâcurile": "farafastâc",
    "farafastâcurilor": "farafastâc",
    "fărâm": "fărâma",
    "fărâmă": "fărâma",
    "fărâmai": "fărâma",
    "fărâmam": "fărâma",
    "fărâmăm": "fărâma",
    "fărâmând": "fărâma",
    "fărâmându": "fărâma",
    "fărâmară": "fărâma",
    "fărâmarăm": "fărâma",
    "fărâmarăți": "fărâma",
    "fărâmase": "fărâma",
    "fărâmasem": "fărâma",
    "fărâmaseră": "fărâma",
    "fărâmaserăm": "fărâma",
    "fărâmaserăți": "fărâma",
    "fărâmaseși": "fărâma",
    "fărâmași": "fărâma",
    "fărâmat": "fărâma",
    "fărâmați": "fărâma",
    "fărâmatu": "fărâma",
    "fărâmau": "fărâma",
    "fărâme": "fărâma",
    "fărâmi": "fărâma",
    "nefărâmând": "fărâma",
    "nefărâmându": "fărâma",
    "nemaifărâmând": "fărâma",
    "nemaifărâmându": "fărâma",
    "fărâma": "fărâmă",
    "fărâme": "fărâmă",
    "fărâmei": "fărâmă",
    "fărâmele": "fărâmă",
    "fărâmelor": "fărâmă",
    "fărâmarea": "fărâmare",
    "fărâmări": "fărâmare",
    "fărâmării": "fărâmare",
    "fărâmată": "fărâmat",
    "fărâmate": "fărâmat",
    "fărâmați": "fărâmat",
    "fărâmatul": "fărâmat",
    "fărâmatului": "fărâmat",
    "fărâmători": "fărâmător",
    "fărâmătorii": "fărâmător",
    "fărâmătorilor": "fărâmător",
    "fărâmătorul": "fărâmător",
    "fărâmătorului": "fărâmător",
    "fărâmătura": "fărâmătură",
    "fărâmături": "fărâmătură",
    "fărâmăturii": "fărâmătură",
    "fărâmăturile": "fărâmătură",
    "fărâmăturilor": "fărâmătură",
    "fărâmica": "fărâmică",
    "fărâmici": "fărâmică",
    "fărâmicii": "fărâmică",
    "fărâmicile": "fărâmică",
    "fărâmicilor": "fărâmică",
    "fărâmicioasa": "fărâmicios",
    "fărâmicioasă": "fărâmicios",
    "fărâmicioase": "fărâmicios",
    "fărâmicioasei": "fărâmicios",
    "fărâmicioasele": "fărâmicios",
    "fărâmicioaselor": "fărâmicios",
    "fărâmicioși": "fărâmicios",
    "fărâmicioșii": "fărâmicios",
    "fărâmicioșilor": "fărâmicios",
    "fărâmiciosul": "fărâmicios",
    "fărâmiciosului": "fărâmicios",
    "fărâmiță": "fărâmița",
    "fărâmițai": "fărâmița",
    "fărâmițam": "fărâmița",
    "fărâmițăm": "fărâmița",
    "fărâmițând": "fărâmița",
    "fărâmițându": "fărâmița",
    "fărâmițară": "fărâmița",
    "fărâmițarăm": "fărâmița",
    "fărâmițarăți": "fărâmița",
    "fărâmițase": "fărâmița",
    "fărâmițasem": "fărâmița",
    "fărâmițaseră": "fărâmița",
    "fărâmițaserăm": "fărâmița",
    "fărâmițaserăți": "fărâmița",
    "fărâmițaseși": "fărâmița",
    "fărâmițași": "fărâmița",
    "fărâmițat": "fărâmița",
    "fărâmițați": "fărâmița",
    "fărâmițatu": "fărâmița",
    "fărâmițau": "fărâmița",
    "fărâmițează": "fărâmița",
    "fărâmițez": "fărâmița",
    "fărâmițeze": "fărâmița",
    "fărâmițezi": "fărâmița",
    "nefărâmițând": "fărâmița",
    "nefărâmițându": "fărâmița",
    "nemaifărâmițând": "fărâmița",
    "nemaifărâmițându": "fărâmița",
    "fărâmița": "fărâmiță",
    "fărâmițe": "fărâmiță",
    "fărâmiței": "fărâmiță",
    "fărâmițele": "fărâmiță",
    "fărâmițelor": "fărâmiță",
    "fărâmițarea": "fărâmițare",
    "fărâmițări": "fărâmițare",
    "fărâmițării": "fărâmițare",
    "fărâmițările": "fărâmițare",
    "fărâmițărilor": "fărâmițare",
    "fărâmițată": "fărâmițat",
    "fărâmițate": "fărâmițat",
    "fărâmițați": "fărâmițat",
    "fărâmițatul": "fărâmițat",
    "fărâmițatului": "fărâmițat",
    "farandola": "farandolă",
    "farandole": "farandolă",
    "farandolei": "farandolă",
    "farandolele": "farandolă",
    "farandolelor": "farandolă",
    "faraoni": "faraon",
    "faraonii": "faraon",
    "faraonilor": "faraon",
    "faraonul": "faraon",
    "faraonului": "faraon",
    "fărașe": "făraș",
    "fărașele": "făraș",
    "fărașelor": "făraș",
    "fărașul": "făraș",
    "fărașului": "făraș",
    "fardul": "fard",
    "fardului": "fard",
    "farduri": "fard",
    "fardurile": "fard",
    "fardurilor": "fard",
    "fardă": "farda",
    "fardai": "farda",
    "fardam": "farda",
    "fardăm": "farda",
    "fardând": "farda",
    "fardându": "farda",
    "fardară": "farda",
    "fardarăm": "farda",
    "fardarăți": "farda",
    "fardase": "farda",
    "fardasem": "farda",
    "fardaseră": "farda",
    "fardaserăm": "farda",
    "fardaserăți": "farda",
    "fardaseși": "farda",
    "fardași": "farda",
    "fardat": "farda",
    "fardați": "farda",
    "fardatu": "farda",
    "fardau": "farda",
    "fardează": "farda",
    "fardez": "farda",
    "fardeze": "farda",
    "fardezi": "farda",
    "nefardând": "farda",
    "nefardându": "farda",
    "nemaifardând": "farda",
    "nemaifardându": "farda",
    "fardarea": "fardare",
    "fardări": "fardare",
    "fardării": "fardare",
    "fardările": "fardare",
    "fardărilor": "fardare",
    "fardată": "fardat",
    "fardate": "fardat",
    "fardați": "fardat",
    "fardatul": "fardat",
    "fardatului": "fardat",
    "faretra": "faretră",
    "faretre": "faretră",
    "faretrei": "faretră",
    "faretrele": "faretră",
    "faretrelor": "faretră",
    "farfarale": "farfara",
    "farfaralei": "farfara",
    "farfaralele": "farfara",
    "farfaralelor": "farfara",
    "farfaraua": "farfara",
    "farfurăria": "farfurărie",
    "farfurăriei": "farfurărie",
    "farfurării": "farfurărie",
    "farfuria": "farfurie",
    "farfuriei": "farfurie",
    "farfurii": "farfurie",
    "farfuriile": "farfurie",
    "farfuriilor": "farfurie",
    "farfurioara": "farfurioară",
    "farfurioare": "farfurioară",
    "farfurioarei": "farfurioară",
    "farfurioarele": "farfurioară",
    "farfurioarelor": "farfurioară",
    "farfuriuța": "farfuriuță",
    "farfuriuțe": "farfuriuță",
    "farfuriuței": "farfuriuță",
    "farfuriuțele": "farfuriuță",
    "farfuriuțelor": "farfuriuță",
    "faringele": "faringe",
    "faringelor": "faringe",
    "faringelui": "faringe",
    "faringita": "faringită",
    "faringite": "faringită",
    "faringitei": "faringită",
    "faringitele": "faringită",
    "faringitelor": "faringită",
    "faringolaringita": "faringolaringită",
    "faringolaringite": "faringolaringită",
    "faringolaringitei": "faringolaringită",
    "faringolaringitele": "faringolaringită",
    "faringolaringitelor": "faringolaringită",
    "faingoscoapele": "faringoscop",
    "faingoscoapelor": "faringoscop",
    "faringoscoape": "faringoscop",
    "faringoscopul": "faringoscop",
    "faringoscopului": "faringoscop",
    "faringoscopia": "faringoscopie",
    "faringoscopiei": "faringoscopie",
    "faringoscopii": "faringoscopie",
    "faringoscopiile": "faringoscopie",
    "faringoscopiilor": "faringoscopie",
    "farinografe": "farinograf",
    "farinografele": "farinograf",
    "farinografelor": "farinograf",
    "farinograful": "farinograf",
    "farinografului": "farinograf",
    "farinotoame": "farinotom",
    "farinotoamele": "farinotom",
    "farinotoamelor": "farinotom",
    "farinotomul": "farinotom",
    "farinotomului": "farinotom",
    "fariseismul": "fariseism",
    "fariseismului": "fariseism",
    "farisei": "fariseu",
    "fariseii": "fariseu",
    "fariseilor": "fariseu",
    "fariseul": "fariseu",
    "fariseului": "fariseu",
    "farmaceutica": "farmaceutic",
    "farmaceutică": "farmaceutic",
    "farmaceutice": "farmaceutic",
    "farmaceuticei": "farmaceutic",
    "farmaceuticele": "farmaceutic",
    "farmaceuticelor": "farmaceutic",
    "farmaceutici": "farmaceutic",
    "farmaceuticii": "farmaceutic",
    "farmaceuticilor": "farmaceutic",
    "farmaceutico": "farmaceutic",
    "farmaceuticul": "farmaceutic",
    "farmaceuticule": "farmaceutic",
    "farmaceuticului": "farmaceutic",
    "farm.": "farmacia",
    "farmacia": "farmacie",
    "farmaciei": "farmacie",
    "farmacii": "farmacie",
    "farmaciile": "farmacie",
    "farmaciilor": "farmacie",
    "farmaciști": "farmacist",
    "farmaciștii": "farmacist",
    "farmaciștilor": "farmacist",
    "farmacistul": "farmacist",
    "farmacistului": "farmacist",
    "farmacista": "farmacistă",
    "farmaciste": "farmacistă",
    "farmacistei": "farmacistă",
    "farmacistele": "farmacistă",
    "farmacistelor": "farmacistă",
    "farmacodinamia": "farmacodinamie",
    "farmacodinamiei": "farmacodinamie",
    "farmacodinamii": "farmacodinamie",
    "farmacologi": "farmacolog",
    "farmacologii": "farmacolog",
    "farmacologilor": "farmacolog",
    "farmacologul": "farmacolog",
    "farmacologului": "farmacolog",
    "farmacologa": "farmacologă",
    "farmacologe": "farmacologă",
    "farmacologei": "farmacologă",
    "farmacologele": "farmacologă",
    "farmacologelor": "farmacologă",
    "farmacologia": "farmacologie",
    "farmacologiei": "farmacologie",
    "farmacologii": "farmacologie",
    "farmacopeea": "farmacopee",
    "farmacopei": "farmacopee",
    "farmacopeii": "farmacopee",
    "farmacopeile": "farmacopee",
    "farmacopeilor": "farmacopee",
    "farmacoterapia": "farmacoterapie",
    "farmacoterapiei": "farmacoterapie",
    "farmacoterapii": "farmacoterapie",
    "farmazoana": "farmazoană",
    "farmazoane": "farmazoană",
    "farmazoanei": "farmazoană",
    "farmazoanele": "farmazoană",
    "farmazoanelor": "farmazoană",
    "farmazoni": "farmazon",
    "farmazonii": "farmazon",
    "farmazonilor": "farmazon",
    "farmazonul": "farmazon",
    "farmazonului": "farmazon",
    "farmazonia": "farmazonie",
    "farmazoniei": "farmazonie",
    "farmazonii": "farmazonie",
    "farmece": "farmec",
    "farmecele": "farmec",
    "farmecelor": "farmec",
    "farmecul": "farmec",
    "farmecului": "farmec",
    "fârnâia": "fârnâi",
    "fârnâiai": "fârnâi",
    "fârnâiam": "fârnâi",
    "fârnâiați": "fârnâi",
    "fârnâiau": "fârnâi",
    "fârnâie": "fârnâi",
    "fârnâii": "fârnâi",
    "fârnâim": "fârnâi",
    "fârnâind": "fârnâi",
    "fârnâindu": "fârnâi",
    "fârnâiră": "fârnâi",
    "fârnâirăm": "fârnâi",
    "fârnâirăți": "fârnâi",
    "fârnâise": "fârnâi",
    "fârnâisem": "fârnâi",
    "fârnâiseră": "fârnâi",
    "fârnâiserăm": "fârnâi",
    "fârnâiserăți": "fârnâi",
    "fârnâiseși": "fârnâi",
    "fârnâiși": "fârnâi",
    "fârnâit": "fârnâi",
    "fârnâiți": "fârnâi",
    "fârnâitu": "fârnâi",
    "nefârnâind": "fârnâi",
    "nefârnâindu": "fârnâi",
    "nemaifârnâind": "fârnâi",
    "nemaifârnâindu": "fârnâi",
    "fârnâită": "fârnâit",
    "fârnâite": "fârnâit",
    "fârnâiți": "fârnâit",
    "farnesolul": "farnesol",
    "farnesolului": "farnesol",
    "farnientele": "farniente",
    "farnientelui": "farniente",
    "farsa": "farsă",
    "farse": "farsă",
    "farsei": "farsă",
    "farsele": "farsă",
    "farselor": "farsă",
    "fărșeroți": "fărșerot",
    "fărșeroții": "fărșerot",
    "fărșeroților": "fărșerot",
    "fărșerotul": "fărșerot",
    "fărșerotului": "fărșerot",
    "farsoarea": "farsoare",
    "farsoarei": "farsoare",
    "farsoarele": "farsoare",
    "farsoarelor": "farsoare",
    "farsori": "farsor",
    "farsorii": "farsor",
    "farsorilor": "farsor",
    "farsorul": "farsor",
    "farsorului": "farsor",
    "fârtați": "fârtat",
    "fârtații": "fârtat",
    "fârtaților": "fârtat",
    "fârtatul": "fârtat",
    "fârtatule": "fârtat",
    "fârtatului": "fârtat",
    "fașa": "fașă",
    "feși": "fașă",
    "feșii": "fașă",
    "feșile": "fașă",
    "feșilor": "fașă",
    "fâsâia": "fâsâi",
    "fâsâiai": "fâsâi",
    "fâsâiam": "fâsâi",
    "fâsâiați": "fâsâi",
    "fâsâiau": "fâsâi",
    "fâsâie": "fâsâi",
    "fâsâii": "fâsâi",
    "fâsâim": "fâsâi",
    "fâsâind": "fâsâi",
    "fâsâindu": "fâsâi",
    "fâsâiră": "fâsâi",
    "fâsâirăm": "fâsâi",
    "fâsâirăți": "fâsâi",
    "fâsâise": "fâsâi",
    "fâsâisem": "fâsâi",
    "fâsâiseră": "fâsâi",
    "fâsâiserăm": "fâsâi",
    "fâsâiserăți": "fâsâi",
    "fâsâiseși": "fâsâi",
    "fâsâiși": "fâsâi",
    "fâsâit": "fâsâi",
    "fâsâiți": "fâsâi",
    "fâsâitu": "fâsâi",
    "nefâsâind": "fâsâi",
    "nefâsâindu": "fâsâi",
    "nemaifâsâind": "fâsâi",
    "nemaifâsâindu": "fâsâi",
    "fâșâia": "fâșâi",
    "fâșâiai": "fâșâi",
    "fâșâiam": "fâșâi",
    "fâșâiați": "fâșâi",
    "fâșâiau": "fâșâi",
    "fâșâie": "fâșâi",
    "fâșâii": "fâșâi",
    "fâșâim": "fâșâi",
    "fâșâind": "fâșâi",
    "fâșâindu": "fâșâi",
    "fâșâiră": "fâșâi",
    "fâșâirăm": "fâșâi",
    "fâșâirăți": "fâșâi",
    "fâșâise": "fâșâi",
    "fâșâisem": "fâșâi",
    "fâșâiseră": "fâșâi",
    "fâșâiserăm": "fâșâi",
    "fâșâiserăți": "fâșâi",
    "fâșâiseși": "fâșâi",
    "fâșâiși": "fâșâi",
    "fâșâit": "fâșâi",
    "fâșâiți": "fâșâi",
    "fâșâitu": "fâșâi",
    "nefâșâind": "fâșâi",
    "nefâșâindu": "fâșâi",
    "nemaifâșâind": "fâșâi",
    "nemaifâșâindu": "fâșâi",
    "fâsâită": "fâsâit",
    "fâsâite": "fâsâit",
    "fâsâiți": "fâsâit",
    "fâșâită": "fâșâit",
    "fâșâite": "fâșâit",
    "fâșâiți": "fâșâit",
    "fâșâitul": "fâșâit",
    "fâșâitului": "fâșâit",
    "fâșâituri": "fâșâit",
    "fâșâiturile": "fâșâit",
    "fâșâiturilor": "fâșâit",
    "fascicule": "fascicul",
    "fasciculele": "fascicul",
    "fasciculelor": "fascicul",
    "fasciculul": "fascicul",
    "fasciculului": "fascicul",
    "fascicula": "fasciculă",
    "fascicule": "fasciculă",
    "fasciculei": "fasciculă",
    "fasciculele": "fasciculă",
    "fasciculelor": "fasciculă",
    "fascia": "fascie",
    "fasciei": "fascie",
    "fascii": "fascie",
    "fasciile": "fascie",
    "fasciilor": "fascie",
    "fascină": "fascina",
    "fascinai": "fascina",
    "fascinam": "fascina",
    "fascinăm": "fascina",
    "fascinând": "fascina",
    "fascinându": "fascina",
    "fascinară": "fascina",
    "fascinarăm": "fascina",
    "fascinarăți": "fascina",
    "fascinase": "fascina",
    "fascinasem": "fascina",
    "fascinaseră": "fascina",
    "fascinaserăm": "fascina",
    "fascinaserăți": "fascina",
    "fascinaseși": "fascina",
    "fascinași": "fascina",
    "fascinat": "fascina",
    "fascinați": "fascina",
    "fascinatu": "fascina",
    "fascinau": "fascina",
    "fascinează": "fascina",
    "fascinez": "fascina",
    "fascineze": "fascina",
    "fascinezi": "fascina",
    "nefascinând": "fascina",
    "nefascinându": "fascina",
    "nemaifascinând": "fascina",
    "nemaifascinându": "fascina",
    "fascina": "fascină",
    "fascine": "fascină",
    "fascinei": "fascină",
    "fascinele": "fascină",
    "fascinelor": "fascină",
    "fascinanta": "fascinant",
    "fascinantă": "fascinant",
    "fascinante": "fascinant",
    "fascinantei": "fascinant",
    "fascinantele": "fascinant",
    "fascinantelor": "fascinant",
    "fascinanți": "fascinant",
    "fascinanții": "fascinant",
    "fascinanților": "fascinant",
    "fascinantul": "fascinant",
    "fascinantului": "fascinant",
    "fascinarea": "fascinare",
    "fascinări": "fascinare",
    "fascinării": "fascinare",
    "fascinată": "fascinat",
    "fascinate": "fascinat",
    "fascinați": "fascinat",
    "fascinația": "fascinație",
    "fascinației": "fascinație",
    "fascinații": "fascinație",
    "fascinațiile": "fascinație",
    "fascinațiilor": "fascinație",
    "fascioloza": "fascioloză",
    "fascioloze": "fascioloză",
    "fasciolozei": "fascioloză",
    "fasciolozele": "fascioloză",
    "fasciolozelor": "fascioloză",
    "fascismul": "fascism",
    "fascismului": "fascism",
    "fascista": "fascist",
    "fascistă": "fascist",
    "fasciste": "fascist",
    "fascistei": "fascist",
    "fascistele": "fascist",
    "fascistelor": "fascist",
    "fasciști": "fascist",
    "fasciștii": "fascist",
    "fasciștilor": "fascist",
    "fascisto": "fascist",
    "fascistul": "fascist",
    "fascistule": "fascist",
    "fascistului": "fascist",
    "fasciză": "fasciza",
    "fascizai": "fasciza",
    "fascizam": "fasciza",
    "fascizăm": "fasciza",
    "fascizând": "fasciza",
    "fascizându": "fasciza",
    "fascizară": "fasciza",
    "fascizarăm": "fasciza",
    "fascizarăți": "fasciza",
    "fascizase": "fasciza",
    "fascizasem": "fasciza",
    "fascizaseră": "fasciza",
    "fascizaserăm": "fasciza",
    "fascizaserăți": "fasciza",
    "fascizaseși": "fasciza",
    "fascizași": "fasciza",
    "fascizat": "fasciza",
    "fascizați": "fasciza",
    "fascizatu": "fasciza",
    "fascizau": "fasciza",
    "fascizează": "fasciza",
    "fascizez": "fasciza",
    "fascizeze": "fasciza",
    "fascizezi": "fasciza",
    "nefascizând": "fasciza",
    "nefascizându": "fasciza",
    "nemaifascizând": "fasciza",
    "nemaifascizându": "fasciza",
    "fascizarea": "fascizare",
    "fascizări": "fascizare",
    "fascizării": "fascizare",
    "fascizată": "fascizat",
    "fascizate": "fascizat",
    "fascizați": "fascizat",
    "fâșia": "fâșie",
    "fâșiei": "fâșie",
    "fâșii": "fâșie",
    "fâșiile": "fâșie",
    "fâșiilor": "fâșie",
    "fasolea": "fasole",
    "fasolei": "fasole",
    "fasoleala": "fasoleală",
    "fasoleli": "fasoleală",
    "fasolelii": "fasoleală",
    "fasolelile": "fasoleală",
    "fasolelilor": "fasoleală",
    "fasolea": "fasoli",
    "fasoleai": "fasoli",
    "fasoleam": "fasoli",
    "fasolească": "fasoli",
    "fasoleați": "fasoli",
    "fasoleau": "fasoli",
    "fasolesc": "fasoli",
    "fasolește": "fasoli",
    "fasolești": "fasoli",
    "fasolii": "fasoli",
    "fasolim": "fasoli",
    "fasolind": "fasoli",
    "fasolindu": "fasoli",
    "fasoliră": "fasoli",
    "fasolirăm": "fasoli",
    "fasolirăți": "fasoli",
    "fasolise": "fasoli",
    "fasolisem": "fasoli",
    "fasoliseră": "fasoli",
    "fasoliserăm": "fasoli",
    "fasoliserăți": "fasoli",
    "fasoliseși": "fasoli",
    "fasoliși": "fasoli",
    "fasolit": "fasoli",
    "fasoliți": "fasoli",
    "fasolitu": "fasoli",
    "nefasolind": "fasoli",
    "nefasolindu": "fasoli",
    "nemaifasolind": "fasoli",
    "nemaifasolindu": "fasoli",
    "fasolica": "fasolică",
    "fasolici": "fasolică",
    "fasolicii": "fasolică",
    "fasolicile": "fasolică",
    "fasolicilor": "fasolică",
    "fasolirea": "fasolire",
    "fasoliri": "fasolire",
    "fasolirii": "fasolire",
    "fasolirile": "fasolire",
    "fasolirilor": "fasolire",
    "fasolită": "fasolit",
    "fasolite": "fasolit",
    "fasoliți": "fasolit",
    "fasoane": "fason",
    "fasoanele": "fason",
    "fasoanelor": "fason",
    "fasonul": "fason",
    "fasonului": "fason",
    "fasonă": "fasona",
    "fasonai": "fasona",
    "fasonam": "fasona",
    "fasonăm": "fasona",
    "fasonând": "fasona",
    "fasonându": "fasona",
    "fasonară": "fasona",
    "fasonarăm": "fasona",
    "fasonarăți": "fasona",
    "fasonase": "fasona",
    "fasonasem": "fasona",
    "fasonaseră": "fasona",
    "fasonaserăm": "fasona",
    "fasonaserăți": "fasona",
    "fasonaseși": "fasona",
    "fasonași": "fasona",
    "fasonat": "fasona",
    "fasonați": "fasona",
    "fasonatu": "fasona",
    "fasonau": "fasona",
    "fasonează": "fasona",
    "fasonez": "fasona",
    "fasoneze": "fasona",
    "fasonezi": "fasona",
    "nefasonând": "fasona",
    "nefasonându": "fasona",
    "nemaifasonând": "fasona",
    "nemaifasonându": "fasona",
    "fasonarea": "fasonare",
    "fasonări": "fasonare",
    "fasonării": "fasonare",
    "fasonările": "fasonare",
    "fasonărilor": "fasonare",
    "fasonată": "fasonat",
    "fasonate": "fasonat",
    "fasonați": "fasonat",
    "fasonatul": "fasonat",
    "fasonatului": "fasonat",
    "fasonatoarea": "fasonatoare",
    "fasonatoarei": "fasonatoare",
    "fasonatoarele": "fasonatoare",
    "fasonatoarelor": "fasonatoare",
    "fasonatori": "fasonator",
    "fasonatorii": "fasonator",
    "fasonatorilor": "fasonator",
    "fasonatorul": "fasonator",
    "fasonatorului": "fasonator",
    "fastul": "fast",
    "fastului": "fast",
    "fâstâcea": "fâstâci",
    "fâstâceai": "fâstâci",
    "fâstâceam": "fâstâci",
    "fâstâcească": "fâstâci",
    "fâstâceați": "fâstâci",
    "fâstâceau": "fâstâci",
    "fâstâcesc": "fâstâci",
    "fâstâcește": "fâstâci",
    "fâstâcești": "fâstâci",
    "fâstâcii": "fâstâci",
    "fâstâcim": "fâstâci",
    "fâstâcind": "fâstâci",
    "fâstâcindu": "fâstâci",
    "fâstâciră": "fâstâci",
    "fâstâcirăm": "fâstâci",
    "fâstâcirăți": "fâstâci",
    "fâstâcise": "fâstâci",
    "fâstâcisem": "fâstâci",
    "fâstâciseră": "fâstâci",
    "fâstâciserăm": "fâstâci",
    "fâstâciserăți": "fâstâci",
    "fâstâciseși": "fâstâci",
    "fâstâciși": "fâstâci",
    "fâstâcit": "fâstâci",
    "fâstâciți": "fâstâci",
    "fâstâcitu": "fâstâci",
    "nefâstâcind": "fâstâci",
    "nefâstâcindu": "fâstâci",
    "nemaifâstâcind": "fâstâci",
    "nemaifâstâcindu": "fâstâci",
    "fâstâcită": "fâstâcit",
    "fâstâcite": "fâstâcit",
    "fâstâciți": "fâstâcit",
    "fastele": "faste",
    "fastelor": "faste",
    "fastuoasa": "fastuos",
    "fastuoasă": "fastuos",
    "fastuoase": "fastuos",
    "fastuoasei": "fastuos",
    "fastuoasele": "fastuos",
    "fastuoaselor": "fastuos",
    "fastuoși": "fastuos",
    "fastuoșii": "fastuos",
    "fastuoșilor": "fastuos",
    "fastuosul": "fastuos",
    "fastuosului": "fastuos",
    "fasungul": "fasung",
    "fasungului": "fasung",
    "fasunguri": "fasung",
    "fasungurile": "fasung",
    "fasungurilor": "fasung",
    "fătul": "făt",
    "fătului": "făt",
    "feți": "făt",
    "feții": "făt",
    "feților": "făt",
    "fata": "fată",
    "fete": "fată",
    "fetei": "fată",
    "fetele": "fată",
    "fetelor": "fată",
    "fața": "față",
    "fețe": "față",
    "feței": "față",
    "fețele": "față",
    "fețelor": "față",
    "feții": "față",
    "făt": "făta",
    "fată": "făta",
    "fătă": "făta",
    "fătai": "făta",
    "fătam": "făta",
    "fătăm": "făta",
    "fătând": "făta",
    "fătându": "făta",
    "fătară": "făta",
    "fătarăm": "făta",
    "fătarăți": "făta",
    "fătase": "făta",
    "fătasem": "făta",
    "fătaseră": "făta",
    "fătaserăm": "făta",
    "fătaserăți": "făta",
    "fătaseși": "făta",
    "fătași": "făta",
    "fătat": "făta",
    "fătați": "făta",
    "fătatu": "făta",
    "fătau": "făta",
    "fete": "făta",
    "feți": "făta",
    "nefătând": "făta",
    "nefătându": "făta",
    "nemaifătând": "făta",
    "nemaifătându": "făta",
    "fațada": "fațadă",
    "fațade": "fațadă",
    "fațadei": "fațadă",
    "fațadele": "fațadă",
    "fațadelor": "fațadă",
    "fâțâia": "fâțâi",
    "fâțâiai": "fâțâi",
    "fâțâiam": "fâțâi",
    "fâțâiați": "fâțâi",
    "fâțâiau": "fâțâi",
    "fâțâie": "fâțâi",
    "fâțâii": "fâțâi",
    "fâțâim": "fâțâi",
    "fâțâind": "fâțâi",
    "fâțâindu": "fâțâi",
    "fâțâiră": "fâțâi",
    "fâțâirăm": "fâțâi",
    "fâțâirăți": "fâțâi",
    "fâțâise": "fâțâi",
    "fâțâisem": "fâțâi",
    "fâțâiseră": "fâțâi",
    "fâțâiserăm": "fâțâi",
    "fâțâiserăți": "fâțâi",
    "fâțâiseși": "fâțâi",
    "fâțâiși": "fâțâi",
    "fâțâit": "fâțâi",
    "fâțâiți": "fâțâi",
    "fâțâitu": "fâțâi",
    "nefâțâind": "fâțâi",
    "nefâțâindu": "fâțâi",
    "nemaifâțâind": "fâțâi",
    "nemaifâțâindu": "fâțâi",
    "fâțâiala": "fâțâială",
    "fâțâieli": "fâțâială",
    "fâțâielii": "fâțâială",
    "fâțâielile": "fâțâială",
    "fâțâielilor": "fâțâială",
    "fâțâită": "fâțâit",
    "fâțâite": "fâțâit",
    "fâțâiți": "fâțâit",
    "fatala": "fatal",
    "fatală": "fatal",
    "fatale": "fatal",
    "fatalei": "fatal",
    "fatalele": "fatal",
    "fatalelor": "fatal",
    "fatali": "fatal",
    "fatalii": "fatal",
    "fatalilor": "fatal",
    "fatalul": "fatal",
    "fatalului": "fatal",
    "fătălăi": "fătălău",
    "fătălăii": "fătălău",
    "fătălăilor": "fătălău",
    "fătălăul": "fătălău",
    "fătălăului": "fătălău",
    "fatalismul": "fatalism",
    "fatalismului": "fatalism",
    "fataliști": "fatalist",
    "fataliștii": "fatalist",
    "fataliștilor": "fatalist",
    "fatalistul": "fatalist",
    "fatalistului": "fatalist",
    "fatalista": "fatalistă",
    "fataliste": "fatalistă",
    "fatalistei": "fatalistă",
    "fatalistele": "fatalistă",
    "fatalistelor": "fatalistă",
    "fatalitatea": "fatalitate",
    "fatalități": "fatalitate",
    "fatalității": "fatalitate",
    "fatalitățile": "fatalitate",
    "fatalităților": "fatalitate",
    "fătarea": "fătare",
    "fătări": "fătare",
    "fătării": "fătare",
    "fătările": "fătare",
    "fătărilor": "fătare",
    "fățărea": "fățări",
    "fățăreai": "fățări",
    "fățăream": "fățări",
    "fățărească": "fățări",
    "fățăreați": "fățări",
    "fățăreau": "fățări",
    "fățăresc": "fățări",
    "fățărește": "fățări",
    "fățărești": "fățări",
    "fățării": "fățări",
    "fățărim": "fățări",
    "fățărind": "fățări",
    "fățărindu": "fățări",
    "fățăriră": "fățări",
    "fățărirăm": "fățări",
    "fățărirăți": "fățări",
    "fățărise": "fățări",
    "fățărisem": "fățări",
    "fățăriseră": "fățări",
    "fățăriserăm": "fățări",
    "fățăriserăți": "fățări",
    "fățăriseși": "fățări",
    "fățăriși": "fățări",
    "fățărit": "fățări",
    "fățăriți": "fățări",
    "fățăritu": "fățări",
    "nefățărind": "fățări",
    "nefățărindu": "fățări",
    "nemaifățărind": "fățări",
    "nemaifățărindu": "fățări",
    "fățăria": "fățărie",
    "fățăriei": "fățărie",
    "fățării": "fățărie",
    "fățăriile": "fățărie",
    "fățăriilor": "fățărie",
    "fățărită": "fățărit",
    "fățărite": "fățărit",
    "fățăriți": "fățărit",
    "fățarnica": "fățarnic",
    "fățarnică": "fățarnic",
    "fățarnice": "fățarnic",
    "fățarnicei": "fățarnic",
    "fățarnicele": "fățarnic",
    "fățarnicelor": "fățarnic",
    "fățarnici": "fățarnic",
    "fățarnicii": "fățarnic",
    "fățarnicilor": "fățarnic",
    "fățarnicul": "fățarnic",
    "fățarnicului": "fățarnic",
    "fățărnicea": "fățărnici",
    "fățărniceai": "fățărnici",
    "fățărniceam": "fățărnici",
    "fățărnicească": "fățărnici",
    "fățărniceați": "fățărnici",
    "fățărniceau": "fățărnici",
    "fățărnicesc": "fățărnici",
    "fățărnicește": "fățărnici",
    "fățărnicești": "fățărnici",
    "fățărnicii": "fățărnici",
    "fățărnicim": "fățărnici",
    "fățărnicind": "fățărnici",
    "fățărnicindu": "fățărnici",
    "fățărniciră": "fățărnici",
    "fățărnicirăm": "fățărnici",
    "fățărnicirăți": "fățărnici",
    "fățărnicise": "fățărnici",
    "fățărnicisem": "fățărnici",
    "fățărniciseră": "fățărnici",
    "fățărniciserăm": "fățărnici",
    "fățărniciserăți": "fățărnici",
    "fățărniciseși": "fățărnici",
    "fățărniciși": "fățărnici",
    "fățărnicit": "fățărnici",
    "fățărniciți": "fățărnici",
    "fățărnicitu": "fățărnici",
    "nefățărnicind": "fățărnici",
    "nefățărnicindu": "fățărnici",
    "nemaifățărnicind": "fățărnici",
    "nemaifățărnicindu": "fățărnici",
    "fățărnicia": "fățărnicie",
    "fățărniciei": "fățărnicie",
    "fățărnicii": "fățărnicie",
    "fățărniciile": "fățărnicie",
    "fățărniciilor": "fățărnicie",
    "fățărnicită": "fățărnicit",
    "fățărnicite": "fățărnicit",
    "fățărniciți": "fățărnicit",
    "fătată": "fătat",
    "fătate": "fătat",
    "fătați": "fătat",
    "fătatul": "fătat",
    "fătatului": "fătat",
    "fătătoarea": "fătătoare",
    "fătătoarei": "fătătoare",
    "fătătoarele": "fătătoare",
    "fătătoarelor": "fătătoare",
    "fațeta": "fațetă",
    "fațete": "fațetă",
    "fațetei": "fațetă",
    "fațetele": "fațetă",
    "fațetelor": "fațetă",
    "feți-frumoși": "făt-frumos",
    "fățișa": "fățiș",
    "fățișă": "fățiș",
    "fățișe": "fățiș",
    "fățișei": "fățiș",
    "fățișele": "fățiș",
    "fățișelor": "fățiș",
    "fățiși": "fățiș",
    "fățișii": "fățiș",
    "fățișilor": "fățiș",
    "fățișul": "fățiș",
    "fățișului": "fățiș",
    "feți-logofeți": "făt-logofăt",
    "fătoaie": "fătoi",
    "fătoaiele": "fătoi",
    "fătoaielor": "fătoi",
    "fătoiul": "fătoi",
    "fătoiului": "fătoi",
    "fatrasia": "fatrasie",
    "fatrasiei": "fatrasie",
    "fatrasii": "fatrasie",
    "fătuca": "fătucă",
    "fătuci": "fătucă",
    "fătucii": "fătucă",
    "fătucile": "fătucă",
    "fătucilor": "fătucă",
    "fătuco": "fătucă",
    "fățuia": "fățui",
    "fățuiai": "fățui",
    "fățuiam": "fățui",
    "fățuiască": "fățui",
    "fățuiați": "fățui",
    "fățuiau": "fățui",
    "fățuiesc": "fățui",
    "fățuiește": "fățui",
    "fățuiești": "fățui",
    "fățuii": "fățui",
    "fățuim": "fățui",
    "fățuind": "fățui",
    "fățuindu": "fățui",
    "fățuiră": "fățui",
    "fățuirăm": "fățui",
    "fățuirăți": "fățui",
    "fățuise": "fățui",
    "fățuisem": "fățui",
    "fățuiseră": "fățui",
    "fățuiserăm": "fățui",
    "fățuiserăți": "fățui",
    "fățuiseși": "fățui",
    "fățuiși": "fățui",
    "fățuit": "fățui",
    "fățuiți": "fățui",
    "fățuitu": "fățui",
    "nefățuind": "fățui",
    "nefățuindu": "fățui",
    "nemaifățuind": "fățui",
    "nemaifățuindu": "fățui",
    "fățuiala": "fățuială",
    "fățuieli": "fățuială",
    "fățuielii": "fățuială",
    "fățuielile": "fățuială",
    "fățuielilor": "fățuială",
    "fățuirea": "fățuire",
    "fățuiri": "fățuire",
    "fățuirii": "fățuire",
    "fățuirile": "fățuire",
    "fățuirilor": "fățuire",
    "fățuită": "fățuit",
    "fățuite": "fățuit",
    "fățuiți": "fățuit",
    "fățuitul": "fățuit",
    "fățuitului": "fățuit",
    "fatuitatea": "fatuitate",
    "fatuități": "fatuitate",
    "fatuității": "fatuitate",
    "fățuitoarea": "fățuitoare",
    "fățuitoarei": "fățuitoare",
    "fățuitoarele": "fățuitoare",
    "fățuitoarelor": "fățuitoare",
    "fățuitori": "fățuitor",
    "fățuitorii": "fățuitor",
    "fățuitorilor": "fățuitor",
    "fățuitorul": "fățuitor",
    "fățuitorului": "fățuitor",
    "fatumul": "fatum",
    "fatumului": "fatum",
    "faultul": "fault",
    "faultului": "fault",
    "faulturi": "fault",
    "faulturile": "fault",
    "faulturilor": "fault",
    "faultă": "faulta",
    "faultai": "faulta",
    "faultam": "faulta",
    "faultăm": "faulta",
    "faultând": "faulta",
    "faultându": "faulta",
    "faultară": "faulta",
    "faultarăm": "faulta",
    "faultarăți": "faulta",
    "faultase": "faulta",
    "faultasem": "faulta",
    "faultaseră": "faulta",
    "faultaserăm": "faulta",
    "faultaserăți": "faulta",
    "faultaseși": "faulta",
    "faultași": "faulta",
    "faultat": "faulta",
    "faultați": "faulta",
    "faultatu": "faulta",
    "faultau": "faulta",
    "faultează": "faulta",
    "faultez": "faulta",
    "faulteze": "faulta",
    "faultezi": "faulta",
    "nefaultând": "faulta",
    "nefaultându": "faulta",
    "nemaifaultând": "faulta",
    "nemaifaultându": "faulta",
    "faultarea": "faultare",
    "faultări": "faultare",
    "faultării": "faultare",
    "faultările": "faultare",
    "faultărilor": "faultare",
    "faultată": "faultat",
    "faultate": "faultat",
    "faultați": "faultat",
    "fauni": "faun",
    "faunii": "faun",
    "faunilor": "faun",
    "faunul": "faun",
    "faunului": "faun",
    "fauna": "faună",
    "faune": "faună",
    "faunei": "faună",
    "faunele": "faună",
    "faunelor": "faună",
    "fauri": "faur",
    "faurii": "faur",
    "faurilor": "faur",
    "faurul": "faur",
    "faurului": "faur",
    "făurari": "făurar",
    "făurarii": "făurar",
    "făurarilor": "făurar",
    "făurarul": "făurar",
    "făurarului": "făurar",
    "făurăria": "făurărie",
    "făurăriei": "făurărie",
    "făurării": "făurărie",
    "făurăriile": "făurărie",
    "făurăriilor": "făurărie",
    "făurea": "făuri",
    "făureai": "făuri",
    "făuream": "făuri",
    "făurească": "făuri",
    "făureați": "făuri",
    "făureau": "făuri",
    "făuresc": "făuri",
    "făurește": "făuri",
    "făurești": "făuri",
    "făurii": "făuri",
    "făurim": "făuri",
    "făurind": "făuri",
    "făurindu": "făuri",
    "făuriră": "făuri",
    "făurirăm": "făuri",
    "făurirăți": "făuri",
    "făurise": "făuri",
    "făurisem": "făuri",
    "făuriseră": "făuri",
    "făuriserăm": "făuri",
    "făuriserăți": "făuri",
    "făuriseși": "făuri",
    "făuriși": "făuri",
    "făurit": "făuri",
    "făuriți": "făuri",
    "făuritu": "făuri",
    "nefăurind": "făuri",
    "nefăurindu": "făuri",
    "nemaifăurind": "făuri",
    "nemaifăurindu": "făuri",
    "făurirea": "făurire",
    "făuriri": "făurire",
    "făuririi": "făurire",
    "făuririle": "făurire",
    "făuririlor": "făurire",
    "făuriștea": "făuriște",
    "făuriști": "făuriște",
    "făuriștii": "făuriște",
    "făuriștile": "făuriște",
    "făuriștilor": "făuriște",
    "făurită": "făurit",
    "făurite": "făurit",
    "făuriți": "făurit",
    "făuritoarea": "făuritoare",
    "făuritoarei": "făuritoare",
    "făuritoarele": "făuritoare",
    "făuritoarelor": "făuritoare",
    "făuritori": "făuritor",
    "făuritorii": "făuritor",
    "făuritorilor": "făuritor",
    "făuritorul": "făuritor",
    "făuritorului": "făuritor",
    "faurmauri": "faurmaur",
    "faurmaurii": "faurmaur",
    "faurmaurilor": "faurmaur",
    "faurmaurul": "faurmaur",
    "faurmaurului": "faurmaur",
    "faustpatroni": "faustpatron",
    "faustpatronii": "faustpatron",
    "faustpatronilor": "faustpatron",
    "faustpatronul": "faustpatron",
    "faustpatronului": "faustpatron",
    "favisa": "favisă",
    "favise": "favisă",
    "favisei": "favisă",
    "favoarea": "favoare",
    "favori": "favoare",
    "favorii": "favoare",
    "favoruri": "favoare",
    "favorurile": "favoare",
    "favorurilor": "favoare",
    "favorul": "favor",
    "favorului": "favor",
    "favorabila": "favorabil",
    "favorabilă": "favorabil",
    "favorabile": "favorabil",
    "favorabilei": "favorabil",
    "favorabilele": "favorabil",
    "favorabilelor": "favorabil",
    "favorabili": "favorabil",
    "favorabilii": "favorabil",
    "favorabililor": "favorabil",
    "favorabilul": "favorabil",
    "favorabilului": "favorabil",
    "favorita": "favorit",
    "favorită": "favorit",
    "favorite": "favorit",
    "favoritei": "favorit",
    "favoritele": "favorit",
    "favoritelor": "favorit",
    "favoriți": "favorit",
    "favoriții": "favorit",
    "favoriților": "favorit",
    "favoritul": "favorit",
    "favoritului": "favorit",
    "favorita": "favorită",
    "favorite": "favorită",
    "favoritei": "favorită",
    "favoritele": "favorită",
    "favoritelor": "favorită",
    "favoriții": "favoriți",
    "favoriților": "favoriți",
    "favoritisme": "favoritism",
    "favoritismele": "favoritism",
    "favoritismelor": "favoritism",
    "favoritismul": "favoritism",
    "favoritismului": "favoritism",
    "favoriză": "favoriza",
    "favorizai": "favoriza",
    "favorizam": "favoriza",
    "favorizăm": "favoriza",
    "favorizând": "favoriza",
    "favorizându": "favoriza",
    "favorizară": "favoriza",
    "favorizarăm": "favoriza",
    "favorizarăți": "favoriza",
    "favorizase": "favoriza",
    "favorizasem": "favoriza",
    "favorizaseră": "favoriza",
    "favorizaserăm": "favoriza",
    "favorizaserăți": "favoriza",
    "favorizaseși": "favoriza",
    "favorizași": "favoriza",
    "favorizat": "favoriza",
    "favorizați": "favoriza",
    "favorizatu": "favoriza",
    "favorizau": "favoriza",
    "favorizează": "favoriza",
    "favorizez": "favoriza",
    "favorizeze": "favoriza",
    "favorizezi": "favoriza",
    "nefavorizând": "favoriza",
    "nefavorizându": "favoriza",
    "nemaifavorizând": "favoriza",
    "nemaifavorizându": "favoriza",
    "favorizanta": "favorizant",
    "favorizantă": "favorizant",
    "favorizante": "favorizant",
    "favorizantei": "favorizant",
    "favorizantele": "favorizant",
    "favorizantelor": "favorizant",
    "favorizanți": "favorizant",
    "favorizanții": "favorizant",
    "favorizanților": "favorizant",
    "favorizantul": "favorizant",
    "favorizantului": "favorizant",
    "favorizarea": "favorizare",
    "favorizări": "favorizare",
    "favorizării": "favorizare",
    "favorizările": "favorizare",
    "favorizărilor": "favorizare",
    "favorizată": "favorizat",
    "favorizate": "favorizat",
    "favorizați": "favorizat",
    "favusul": "favus",
    "favusului": "favus",
    "favusuri": "favus",
    "favusurile": "favus",
    "favusurilor": "favus",
    "faxul": "fax",
    "faxule": "fax",
    "faxului": "fax",
    "faxuri": "fax",
    "faxurile": "fax",
    "faxurilor": "fax",
    "faza": "fază",
    "faze": "fază",
    "fazei": "fază",
    "fazele": "fază",
    "fazelor": "fază",
    "fazani": "fazan",
    "fazanii": "fazan",
    "fazanilor": "fazan",
    "fazanul": "fazan",
    "fazanului": "fazan",
    "fazaneria": "fazanerie",
    "fazaneriei": "fazanerie",
    "fazanerii": "fazanerie",
    "fazaneriile": "fazanerie",
    "fazaneriilor": "fazanerie",
    "făzănița": "făzăniță",
    "făzănițe": "făzăniță",
    "făzăniței": "făzăniță",
    "făzănițele": "făzăniță",
    "făzănițelor": "făzăniță",
    "fazmetre": "fazmetru",
    "fazmetrele": "fazmetru",
    "fazmetrelor": "fazmetru",
    "fazmetrul": "fazmetru",
    "fazmetrului": "fazmetru",
    "feblețea": "feblețe",
    "febleți": "feblețe",
    "febleții": "feblețe",
    "febra": "febră",
    "febre": "febră",
    "febrei": "febră",
    "febricită": "febricita",
    "febricitai": "febricita",
    "febricitam": "febricita",
    "febricităm": "febricita",
    "febricitând": "febricita",
    "febricitându": "febricita",
    "febricitară": "febricita",
    "febricitarăm": "febricita",
    "febricitarăți": "febricita",
    "febricitase": "febricita",
    "febricitasem": "febricita",
    "febricitaseră": "febricita",
    "febricitaserăm": "febricita",
    "febricitaserăți": "febricita",
    "febricitaseși": "febricita",
    "febricitași": "febricita",
    "febricitat": "febricita",
    "febricitați": "febricita",
    "febricitatu": "febricita",
    "febricitau": "febricita",
    "febricitează": "febricita",
    "febricitez": "febricita",
    "febriciteze": "febricita",
    "febricitezi": "febricita",
    "nefebricitând": "febricita",
    "nefebricitându": "febricita",
    "nemaifebricitând": "febricita",
    "nemaifebricitându": "febricita",
    "febricitată": "febricitat",
    "febricitate": "febricitat",
    "febricitați": "febricitat",
    "febrifuge": "febrifug",
    "febrifugele": "febrifug",
    "febrifugelor": "febrifug",
    "febrifugul": "febrifug",
    "febrifugului": "febrifug",
    "febrila": "febril",
    "febrilă": "febril",
    "febrile": "febril",
    "febrilei": "febril",
    "febrilele": "febril",
    "febrilelor": "febril",
    "febrili": "febril",
    "febrilii": "febril",
    "febrililor": "febril",
    "febrilul": "febril",
    "febrilului": "febril",
    "febrilitatea": "febrilitate",
    "febrilități": "febrilitate",
    "febrilității": "febrilitate",
    "febrilitățile": "febrilitate",
    "febrilităților": "febrilitate",
    "feb.": "februarie",
    "fecale": "fecală",
    "fecalele": "fecale",
    "fecalelor": "fecale",
    "fecioara": "fecioară",
    "fecioare": "fecioară",
    "fecioarei": "fecioară",
    "fecioarele": "fecioară",
    "fecioarelor": "fecioară",
    "feciori": "fecior",
    "feciorii": "fecior",
    "feciorilor": "fecior",
    "feciorul": "fecior",
    "feciorule": "fecior",
    "feciorului": "fecior",
    "feciorași": "fecioraș",
    "feciorașii": "fecioraș",
    "feciorașilor": "fecioraș",
    "feciorașul": "fecioraș",
    "feciorașului": "fecioraș",
    "feciorelnica": "feciorelnic",
    "feciorelnică": "feciorelnic",
    "feciorelnice": "feciorelnic",
    "feciorelnicei": "feciorelnic",
    "feciorelnicele": "feciorelnic",
    "feciorelnicelor": "feciorelnic",
    "feciorelnici": "feciorelnic",
    "feciorelnicii": "feciorelnic",
    "feciorelnicilor": "feciorelnic",
    "feciorelnicul": "feciorelnic",
    "feciorelnicului": "feciorelnic",
    "feciorele": "feciorică",
    "feciorelei": "feciorică",
    "feciorelele": "feciorică",
    "feciorelelor": "feciorică",
    "feciorica": "feciorică",
    "fecioria": "feciorie",
    "fecioriei": "feciorie",
    "feciorii": "feciorie",
    "fecula": "feculă",
    "fecule": "feculă",
    "feculei": "feculă",
    "feculența": "feculență",
    "feculențe": "feculență",
    "feculenței": "feculență",
    "fecunda": "fecund",
    "fecundă": "fecund",
    "fecunde": "fecund",
    "fecundei": "fecund",
    "fecundele": "fecund",
    "fecundelor": "fecund",
    "fecundul": "fecund",
    "fecundului": "fecund",
    "fecunzi": "fecund",
    "fecunzii": "fecund",
    "fecunzilor": "fecund",
    "fecundă": "fecunda",
    "fecundai": "fecunda",
    "fecundam": "fecunda",
    "fecundăm": "fecunda",
    "fecundând": "fecunda",
    "fecundându": "fecunda",
    "fecundară": "fecunda",
    "fecundarăm": "fecunda",
    "fecundarăți": "fecunda",
    "fecundase": "fecunda",
    "fecundasem": "fecunda",
    "fecundaseră": "fecunda",
    "fecundaserăm": "fecunda",
    "fecundaserăți": "fecunda",
    "fecundaseși": "fecunda",
    "fecundași": "fecunda",
    "fecundat": "fecunda",
    "fecundați": "fecunda",
    "fecundatu": "fecunda",
    "fecundau": "fecunda",
    "fecundează": "fecunda",
    "fecundez": "fecunda",
    "fecundeze": "fecunda",
    "fecundezi": "fecunda",
    "nefecundând": "fecunda",
    "nefecundându": "fecunda",
    "nemaifecundând": "fecunda",
    "nemaifecundându": "fecunda",
    "fecundarea": "fecundare",
    "fecundări": "fecundare",
    "fecundării": "fecundare",
    "fecundările": "fecundare",
    "fecundărilor": "fecundare",
    "fecundată": "fecundat",
    "fecundate": "fecundat",
    "fecundați": "fecundat",
    "fecundatul": "fecundat",
    "fecundatului": "fecundat",
    "fecundația": "fecundație",
    "fecundației": "fecundație",
    "fecundații": "fecundație",
    "fecundațiile": "fecundație",
    "fecundațiilor": "fecundație",
    "fecunditatea": "fecunditate",
    "fecundități": "fecunditate",
    "fecundității": "fecunditate",
    "fedeleșe": "fedeleș",
    "fedeleșele": "fedeleș",
    "fedeleșelor": "fedeleș",
    "fedeleșul": "fedeleș",
    "fedeleșului": "fedeleș",
    "fedeleșuri": "fedeleș",
    "fedeleșurile": "fedeleș",
    "fedeleșurilor": "fedeleș",
    "federe": "feder",
    "federele": "feder",
    "federelor": "feder",
    "federul": "feder",
    "federului": "feder",
    "federala": "federal",
    "federală": "federal",
    "federale": "federal",
    "federalei": "federal",
    "federalele": "federal",
    "federalelor": "federal",
    "federali": "federal",
    "federalii": "federal",
    "federalilor": "federal",
    "federalul": "federal",
    "federalului": "federal",
    "federalismul": "federalism",
    "federalismului": "federalism",
    "federaliză": "federaliza",
    "federalizai": "federaliza",
    "federalizam": "federaliza",
    "federalizăm": "federaliza",
    "federalizând": "federaliza",
    "federalizându": "federaliza",
    "federalizară": "federaliza",
    "federalizarăm": "federaliza",
    "federalizarăți": "federaliza",
    "federalizase": "federaliza",
    "federalizasem": "federaliza",
    "federalizaseră": "federaliza",
    "federalizaserăm": "federaliza",
    "federalizaserăți": "federaliza",
    "federalizaseși": "federaliza",
    "federalizași": "federaliza",
    "federalizat": "federaliza",
    "federalizați": "federaliza",
    "federalizatu": "federaliza",
    "federalizau": "federaliza",
    "federalizează": "federaliza",
    "federalizez": "federaliza",
    "federalizeze": "federaliza",
    "federalizezi": "federaliza",
    "nefederalizând": "federaliza",
    "nefederalizându": "federaliza",
    "nemaifederalizând": "federaliza",
    "nemaifederalizându": "federaliza",
    "federalizarea": "federalizare",
    "federalizări": "federalizare",
    "federalizării": "federalizare",
    "federalizările": "federalizare",
    "federalizărilor": "federalizare",
    "federalizată": "federalizat",
    "federalizate": "federalizat",
    "federalizați": "federalizat",
    "federați": "federat",
    "federații": "federat",
    "federaților": "federat",
    "federatul": "federat",
    "federatului": "federat",
    "FIFA": "Federația_Internațională_a_Fotbalului_Amator",
    "federația": "federație",
    "federației": "federație",
    "federații": "federație",
    "federațiile": "federație",
    "federațiilor": "federație",
    "federativa": "federativ",
    "federativă": "federativ",
    "federative": "federativ",
    "federativei": "federativ",
    "federativele": "federativ",
    "federativelor": "federativ",
    "federativi": "federativ",
    "federativii": "federativ",
    "federativilor": "federativ",
    "federativul": "federativ",
    "federativului": "federativ",
    "feea": "fee",
    "feei": "fee",
    "feele": "fee",
    "feelor": "fee",
    "feedbackul": "feedback",
    "feedbackului": "feedback",
    "feedbackuri": "feedback",
    "feedbackurile": "feedback",
    "feedbackurilor": "feedback",
    "feerica": "feeric",
    "feerică": "feeric",
    "feerice": "feeric",
    "feericei": "feeric",
    "feericele": "feeric",
    "feericelor": "feeric",
    "feerici": "feeric",
    "feericii": "feeric",
    "feericilor": "feeric",
    "feericul": "feeric",
    "feericului": "feeric",
    "feeria": "feerie",
    "feeriei": "feerie",
    "feerii": "feerie",
    "feeriile": "feerie",
    "feeriilor": "feerie",
    "felul": "fel",
    "felului": "fel",
    "feluri": "fel",
    "felurile": "fel",
    "felurilor": "fel",
    "felahi": "felah",
    "felahii": "felah",
    "felahilor": "felah",
    "felahul": "felah",
    "felahului": "felah",
    "felceri": "felcer",
    "felcerii": "felcer",
    "felcerilor": "felcer",
    "felcerul": "felcer",
    "felcerului": "felcer",
    "felcera": "felceră",
    "felcere": "felceră",
    "felcerei": "felceră",
    "felcerele": "felceră",
    "felcerelor": "felceră",
    "felcerița": "felceriță",
    "felcerițe": "felceriță",
    "felceriței": "felceriță",
    "felcerițele": "felceriță",
    "felcerițelor": "felceriță",
    "feldmareșali": "feldmareșal",
    "feldmareșalii": "feldmareșal",
    "feldmareșalilor": "feldmareșal",
    "feldmareșalul": "feldmareșal",
    "feldmareșalului": "feldmareșal",
    "felea": "fele",
    "felei": "fele",
    "felele": "fele",
    "felelor": "fele",
    "Feleacului": "Feleacul",
    "felegeanul": "felegean",
    "felegeanului": "felegean",
    "felegene": "felegean",
    "felegenele": "felegean",
    "felegenelor": "felegean",
    "felendreșul": "felendreș",
    "felendreșului": "felendreș",
    "feleșagul": "feleșag",
    "feleșagului": "feleșag",
    "feleșaguri": "feleșag",
    "feleșagurile": "feleșag",
    "feleșagurilor": "feleșag",
    "feleștiocul": "feleștioc",
    "feleștiocului": "feleștioc",
    "feleștiocuri": "feleștioc",
    "feleștiocurile": "feleștioc",
    "feleștiocurilor": "feleștioc",
    "felicit": "felicita",
    "felicită": "felicita",
    "felicitai": "felicita",
    "felicitam": "felicita",
    "felicităm": "felicita",
    "felicitând": "felicita",
    "felicitându": "felicita",
    "felicitară": "felicita",
    "felicitarăm": "felicita",
    "felicitarăți": "felicita",
    "felicitase": "felicita",
    "felicitasem": "felicita",
    "felicitaseră": "felicita",
    "felicitaserăm": "felicita",
    "felicitaserăți": "felicita",
    "felicitaseși": "felicita",
    "felicitași": "felicita",
    "felicitat": "felicita",
    "felicitați": "felicita",
    "felicitatu": "felicita",
    "felicitau": "felicita",
    "felicite": "felicita",
    "feliciți": "felicita",
    "nefelicitând": "felicita",
    "nefelicitându": "felicita",
    "nemaifelicitând": "felicita",
    "nemaifelicitându": "felicita",
    "felicitarea": "felicitare",
    "felicitări": "felicitare",
    "felicitării": "felicitare",
    "felicitările": "felicitare",
    "felicitărilor": "felicitare",
    "felicitată": "felicitat",
    "felicitate": "felicitat",
    "felicitați": "felicitat",
    "felide": "felid",
    "felidele": "felid",
    "felidelor": "felid",
    "felidul": "felid",
    "felidului": "felid",
    "felia": "felie",
    "feliei": "felie",
    "felii": "felie",
    "feliile": "felie",
    "feliilor": "felie",
    "felina": "felin",
    "felină": "felin",
    "feline": "felin",
    "felinei": "felin",
    "felinele": "felin",
    "felinelor": "felin",
    "felini": "felin",
    "felinii": "felin",
    "felinilor": "felin",
    "felinul": "felin",
    "felinului": "felin",
    "felinare": "felinar",
    "felinarele": "felinar",
    "felinarelor": "felinar",
    "felinarul": "felinar",
    "felinarului": "felinar",
    "felinitatea": "felinitate",
    "felinități": "felinitate",
    "felinității": "felinitate",
    "felinitățile": "felinitate",
    "felinităților": "felinitate",
    "felioara": "felioară",
    "felioare": "felioară",
    "felioarei": "felioară",
    "felioarele": "felioară",
    "felioarelor": "felioară",
    "feliuța": "feliuță",
    "feliuțe": "feliuță",
    "feliuței": "feliuță",
    "feliuțele": "feliuță",
    "feliuțelor": "feliuță",
    "felodermul": "feloderm",
    "felodermului": "feloderm",
    "felogenul": "felogen",
    "felogenului": "felogen",
    "feloane": "felon",
    "feloanele": "felon",
    "feloanelor": "felon",
    "felonul": "felon",
    "felonului": "felon",
    "felonia": "felonie",
    "feloniei": "felonie",
    "felonii": "felonie",
    "feluca": "felucă",
    "feluci": "felucă",
    "felucii": "felucă",
    "felucile": "felucă",
    "felucilor": "felucă",
    "felurea": "feluri",
    "felureai": "feluri",
    "feluream": "feluri",
    "felurească": "feluri",
    "felureați": "feluri",
    "felureau": "feluri",
    "feluresc": "feluri",
    "felurește": "feluri",
    "felurești": "feluri",
    "felurii": "feluri",
    "felurim": "feluri",
    "felurind": "feluri",
    "felurindu": "feluri",
    "feluriră": "feluri",
    "felurirăm": "feluri",
    "felurirăți": "feluri",
    "felurise": "feluri",
    "felurisem": "feluri",
    "feluriseră": "feluri",
    "feluriserăm": "feluri",
    "feluriserăți": "feluri",
    "feluriseși": "feluri",
    "feluriși": "feluri",
    "felurit": "feluri",
    "feluriți": "feluri",
    "feluritu": "feluri",
    "nefelurind": "feluri",
    "nefelurindu": "feluri",
    "nemaifelurind": "feluri",
    "nemaifelurindu": "feluri",
    "felurimea": "felurime",
    "felurimi": "felurime",
    "felurimii": "felurime",
    "felurimile": "felurime",
    "felurimilor": "felurime",
    "felurita": "felurit",
    "felurită": "felurit",
    "felurite": "felurit",
    "feluritei": "felurit",
    "feluritele": "felurit",
    "feluritelor": "felurit",
    "feluriți": "felurit",
    "feluriții": "felurit",
    "feluriților": "felurit",
    "feluritul": "felurit",
    "feluritului": "felurit",
    "femei": "femeie",
    "femeia": "femeie",
    "femeii": "femeie",
    "femeile": "femeie",
    "femeilor": "femeie",
    "femei-paznic": "femeie-paznic",
    "femei-paznici": "femeie-paznic",
    "femei-proli": "femeie-prol",
    "femeiasca": "femeiesc",
    "femeiască": "femeiesc",
    "femeiescul": "femeiesc",
    "femeiescului": "femeiesc",
    "femeiești": "femeiesc",
    "femeieștii": "femeiesc",
    "femeieștile": "femeiesc",
    "femeieștilor": "femeiesc",
    "femeiușca": "femeiușcă",
    "femeiuște": "femeiușcă",
    "femeiuștei": "femeiușcă",
    "femeiuștele": "femeiușcă",
    "femeiuștelor": "femeiușcă",
    "femela": "femelă",
    "femele": "femelă",
    "femelei": "femelă",
    "femelele": "femelă",
    "femelelor": "femelă",
    "f.": "feminin",
    "feminina": "feminin",
    "feminină": "feminin",
    "feminine": "feminin",
    "femininei": "feminin",
    "femininele": "feminin",
    "femininelor": "feminin",
    "feminini": "feminin",
    "femininii": "feminin",
    "femininilor": "feminin",
    "femininul": "feminin",
    "femininului": "feminin",
    "feminismul": "feminism",
    "feminismului": "feminism",
    "feminitatea": "feminitate",
    "feminități": "feminitate",
    "feminității": "feminitate",
    "feminiză": "feminiza",
    "feminizai": "feminiza",
    "feminizam": "feminiza",
    "feminizăm": "feminiza",
    "feminizând": "feminiza",
    "feminizându": "feminiza",
    "feminizară": "feminiza",
    "feminizarăm": "feminiza",
    "feminizarăți": "feminiza",
    "feminizase": "feminiza",
    "feminizasem": "feminiza",
    "feminizaseră": "feminiza",
    "feminizaserăm": "feminiza",
    "feminizaserăți": "feminiza",
    "feminizaseși": "feminiza",
    "feminizași": "feminiza",
    "feminizat": "feminiza",
    "feminizați": "feminiza",
    "feminizatu": "feminiza",
    "feminizau": "feminiza",
    "feminizează": "feminiza",
    "feminizez": "feminiza",
    "feminizeze": "feminiza",
    "feminizezi": "feminiza",
    "nefeminizând": "feminiza",
    "nefeminizându": "feminiza",
    "nemaifeminizând": "feminiza",
    "nemaifeminizându": "feminiza",
    "feminizarea": "feminizare",
    "feminizări": "feminizare",
    "feminizării": "feminizare",
    "feminizările": "feminizare",
    "feminizărilor": "feminizare",
    "feminizată": "feminizat",
    "feminizate": "feminizat",
    "feminizați": "feminizat",
    "femurul": "femur",
    "femurului": "femur",
    "femururi": "femur",
    "femururile": "femur",
    "femururilor": "femur",
    "fenacetina": "fenacetină",
    "fenacetine": "fenacetină",
    "fenacetinei": "fenacetină",
    "fenantrenul": "fenantren",
    "fenantrenului": "fenantren",
    "fenazona": "fenazonă",
    "fenazone": "fenazonă",
    "fenazonei": "fenazonă",
    "feneci": "fenec",
    "fenecii": "fenec",
    "fenecilor": "fenec",
    "fenecul": "fenec",
    "fenecului": "fenec",
    "fenianul": "fenian",
    "fenianului": "fenian",
    "fenieni": "fenian",
    "fenienii": "fenian",
    "fenienilor": "fenian",
    "fenianismul": "fenianism",
    "fenianismului": "fenianism",
    "feniciana": "fenician",
    "feniciană": "fenician",
    "fenicianul": "fenician",
    "fenicianului": "fenician",
    "feniciene": "fenician",
    "fenicienei": "fenician",
    "fenicienele": "fenician",
    "fenicienelor": "fenician",
    "fenicieni": "fenician",
    "fenicienii": "fenician",
    "fenicienilor": "fenician",
    "feniciana": "feniciană",
    "feniciene": "feniciană",
    "fenicienei": "feniciană",
    "fenicienele": "feniciană",
    "fenicienelor": "feniciană",
    "feniculi": "fenicul",
    "feniculii": "fenicul",
    "feniculilor": "fenicul",
    "feniculul": "fenicul",
    "feniculului": "fenicul",
    "fenili": "fenil",
    "fenilii": "fenil",
    "fenililor": "fenil",
    "fenilul": "fenil",
    "fenilului": "fenil",
    "fenilalanina": "fenilalanină",
    "fenilalanine": "fenilalanină",
    "fenilalaninei": "fenilalanină",
    "fenilamina": "fenilamină",
    "fenilamine": "fenilamină",
    "fenilaminei": "fenilamină",
    "fenilbutazona": "fenilbutazonă",
    "fenilbutazone": "fenilbutazonă",
    "fenilbutazonei": "fenilbutazonă",
    "fenilene": "fenilen",
    "fenilenele": "fenilen",
    "fenilenelor": "fenilen",
    "fenilenul": "fenilen",
    "fenilenului": "fenilen",
    "fenilhidrazina": "fenilhidrazină",
    "fenilhidrazine": "fenilhidrazină",
    "fenilhidrazinei": "fenilhidrazină",
    "fenicși": "fenix",
    "fenicșii": "fenix",
    "fenicșilor": "fenix",
    "fenixul": "fenix",
    "fenixului": "fenix",
    "fenofaza": "fenofază",
    "fenofaze": "fenofază",
    "fenofazei": "fenofază",
    "fenolftaina": "fenolftaină",
    "fenolftaine": "fenolftaină",
    "fenolftainei": "fenolftaină",
    "fenologia": "fenologie",
    "fenologiei": "fenologie",
    "fenologii": "fenologie",
    "fenolsteroidul": "fenolsteroid",
    "fenolsteroidului": "fenolsteroid",
    "fenolsteroizi": "fenolsteroid",
    "fenolsteroizii": "fenolsteroid",
    "fenolsteroizilor": "fenolsteroid",
    "fenomene": "fenomen",
    "fenomenele": "fenomen",
    "fenomenelor": "fenomen",
    "fenomenul": "fenomen",
    "fenomenului": "fenomen",
    "fenomenala": "fenomenal",
    "fenomenală": "fenomenal",
    "fenomenale": "fenomenal",
    "fenomenalei": "fenomenal",
    "fenomenalele": "fenomenal",
    "fenomenalelor": "fenomenal",
    "fenomenali": "fenomenal",
    "fenomenalii": "fenomenal",
    "fenomenalilor": "fenomenal",
    "fenomenalul": "fenomenal",
    "fenomenalului": "fenomenal",
    "fenomenalismul": "fenomenalism",
    "fenomenalismului": "fenomenalism",
    "fenomenalitatea": "fenomenalitate",
    "fenomenalități": "fenomenalitate",
    "fenomenalității": "fenomenalitate",
    "fenomenalitățile": "fenomenalitate",
    "fenomenalităților": "fenomenalitate",
    "fenomenologi": "fenomenolog",
    "fenomenologii": "fenomenolog",
    "fenomenologilor": "fenomenolog",
    "fenomenologul": "fenomenolog",
    "fenomenologului": "fenomenolog",
    "fenomenologia": "fenomenologie",
    "fenomenologiei": "fenomenologie",
    "fenomenologii": "fenomenologie",
    "fenoplaste": "fenoplast",
    "fenoplastele": "fenoplast",
    "fenoplastelor": "fenoplast",
    "fenoplastul": "fenoplast",
    "fenoplastului": "fenoplast",
    "fenotipul": "fenotip",
    "fenotipului": "fenotip",
    "fenta": "fentă",
    "fente": "fentă",
    "fentei": "fentă",
    "fentele": "fentă",
    "fentelor": "fentă",
    "ferăstrăiașe": "ferăstrăiaș",
    "ferăstrăiașele": "ferăstrăiaș",
    "ferăstrăiașelor": "ferăstrăiaș",
    "ferăstrăiași": "ferăstrăiaș",
    "ferăstrăiașii": "ferăstrăiaș",
    "ferăstrăiașilor": "ferăstrăiaș",
    "ferăstrăiașul": "ferăstrăiaș",
    "ferăstrăiașului": "ferăstrăiaș",
    "ferăstrași": "ferăstraș",
    "ferăstrașii": "ferăstraș",
    "ferăstrașilor": "ferăstraș",
    "ferăstrașul": "ferăstraș",
    "ferăstrașului": "ferăstraș",
    "ferăstraie": "ferăstrău",
    "ferăstraiele": "ferăstrău",
    "ferăstraielor": "ferăstrău",
    "ferăstrăul": "ferăstrău",
    "ferăstrăului": "ferăstrău",
    "ferați": "ferat",
    "ferații": "ferat",
    "feraților": "ferat",
    "feratul": "ferat",
    "feratului": "ferat",
    "ferate": "ferată",
    "ferbere": "ferber",
    "ferberele": "ferber",
    "ferberelor": "ferber",
    "ferberul": "ferber",
    "ferberului": "ferber",
    "fercheșa": "fercheș",
    "fercheșă": "fercheș",
    "fercheșe": "fercheș",
    "fercheșei": "fercheș",
    "fercheșele": "fercheș",
    "fercheșelor": "fercheș",
    "fercheși": "fercheș",
    "fercheșii": "fercheș",
    "fercheșilor": "fercheș",
    "fercheșul": "fercheș",
    "fercheșului": "fercheș",
    "ferchezuia": "ferchezui",
    "ferchezuiai": "ferchezui",
    "ferchezuiam": "ferchezui",
    "ferchezuiască": "ferchezui",
    "ferchezuiați": "ferchezui",
    "ferchezuiau": "ferchezui",
    "ferchezuiesc": "ferchezui",
    "ferchezuiește": "ferchezui",
    "ferchezuiești": "ferchezui",
    "ferchezuii": "ferchezui",
    "ferchezuim": "ferchezui",
    "ferchezuind": "ferchezui",
    "ferchezuindu": "ferchezui",
    "ferchezuiră": "ferchezui",
    "ferchezuirăm": "ferchezui",
    "ferchezuirăți": "ferchezui",
    "ferchezuise": "ferchezui",
    "ferchezuisem": "ferchezui",
    "ferchezuiseră": "ferchezui",
    "ferchezuiserăm": "ferchezui",
    "ferchezuiserăți": "ferchezui",
    "ferchezuiseși": "ferchezui",
    "ferchezuiși": "ferchezui",
    "ferchezuit": "ferchezui",
    "ferchezuiți": "ferchezui",
    "ferchezuitu": "ferchezui",
    "neferchezuind": "ferchezui",
    "neferchezuindu": "ferchezui",
    "nemaiferchezuind": "ferchezui",
    "nemaiferchezuindu": "ferchezui",
    "ferchezuiala": "ferchezuială",
    "ferchezuieli": "ferchezuială",
    "ferchezuielii": "ferchezuială",
    "ferchezuielile": "ferchezuială",
    "ferchezuielilor": "ferchezuială",
    "ferchezuită": "ferchezuit",
    "ferchezuite": "ferchezuit",
    "ferchezuiți": "ferchezuit",
    "fereala": "fereală",
    "ferealo": "fereală",
    "fereli": "fereală",
    "ferelii": "fereală",
    "ferelile": "fereală",
    "ferelilor": "fereală",
    "fereastra": "fereastră",
    "ferestre": "fereastră",
    "ferestrei": "fereastră",
    "ferestrele": "fereastră",
    "ferestrelor": "fereastră",
    "ferec": "fereca",
    "ferecă": "fereca",
    "ferecai": "fereca",
    "ferecam": "fereca",
    "ferecăm": "fereca",
    "ferecând": "fereca",
    "ferecându": "fereca",
    "ferecară": "fereca",
    "ferecarăm": "fereca",
    "ferecarăți": "fereca",
    "ferecase": "fereca",
    "ferecasem": "fereca",
    "ferecaseră": "fereca",
    "ferecaserăm": "fereca",
    "ferecaserăți": "fereca",
    "ferecaseși": "fereca",
    "ferecași": "fereca",
    "ferecat": "fereca",
    "ferecați": "fereca",
    "ferecatu": "fereca",
    "ferecau": "fereca",
    "ferece": "fereca",
    "fereci": "fereca",
    "neferecând": "fereca",
    "neferecându": "fereca",
    "nemaiferecând": "fereca",
    "nemaiferecându": "fereca",
    "ferecată": "ferecat",
    "ferecate": "ferecat",
    "ferecați": "ferecat",
    "fereduia": "feredui",
    "fereduiai": "feredui",
    "fereduiam": "feredui",
    "fereduiască": "feredui",
    "fereduiați": "feredui",
    "fereduiau": "feredui",
    "fereduiesc": "feredui",
    "fereduiește": "feredui",
    "fereduiești": "feredui",
    "fereduii": "feredui",
    "fereduim": "feredui",
    "fereduind": "feredui",
    "fereduindu": "feredui",
    "fereduiră": "feredui",
    "fereduirăm": "feredui",
    "fereduirăți": "feredui",
    "fereduise": "feredui",
    "fereduisem": "feredui",
    "fereduiseră": "feredui",
    "fereduiserăm": "feredui",
    "fereduiserăți": "feredui",
    "fereduiseși": "feredui",
    "fereduiși": "feredui",
    "fereduit": "feredui",
    "fereduiți": "feredui",
    "fereduitu": "feredui",
    "nefereduind": "feredui",
    "nefereduindu": "feredui",
    "nemaifereduind": "feredui",
    "nemaifereduindu": "feredui",
    "fereduită": "fereduit",
    "fereduite": "fereduit",
    "fereduiți": "fereduit",
    "ferestruia": "ferestrui",
    "ferestruiai": "ferestrui",
    "ferestruiam": "ferestrui",
    "ferestruiască": "ferestrui",
    "ferestruiați": "ferestrui",
    "ferestruiau": "ferestrui",
    "ferestruiesc": "ferestrui",
    "ferestruiește": "ferestrui",
    "ferestruiești": "ferestrui",
    "ferestruii": "ferestrui",
    "ferestruim": "ferestrui",
    "ferestruind": "ferestrui",
    "ferestruindu": "ferestrui",
    "ferestruiră": "ferestrui",
    "ferestruirăm": "ferestrui",
    "ferestruirăți": "ferestrui",
    "ferestruise": "ferestrui",
    "ferestruisem": "ferestrui",
    "ferestruiseră": "ferestrui",
    "ferestruiserăm": "ferestrui",
    "ferestruiserăți": "ferestrui",
    "ferestruiseși": "ferestrui",
    "ferestruiși": "ferestrui",
    "ferestruit": "ferestrui",
    "ferestruiți": "ferestrui",
    "ferestruitu": "ferestrui",
    "neferestruind": "ferestrui",
    "neferestruindu": "ferestrui",
    "nemaiferestruind": "ferestrui",
    "nemaiferestruindu": "ferestrui",
    "ferestruită": "ferestruit",
    "ferestruite": "ferestruit",
    "ferestruiți": "ferestruit",
    "ferfenițea": "ferfeniți",
    "ferfenițeai": "ferfeniți",
    "ferfenițeam": "ferfeniți",
    "ferfenițească": "ferfeniți",
    "ferfenițeați": "ferfeniți",
    "ferfenițeau": "ferfeniți",
    "ferfenițesc": "ferfeniți",
    "ferfenițește": "ferfeniți",
    "ferfenițești": "ferfeniți",
    "ferfeniții": "ferfeniți",
    "ferfenițim": "ferfeniți",
    "ferfenițind": "ferfeniți",
    "ferfenițindu": "ferfeniți",
    "ferfenițiră": "ferfeniți",
    "ferfenițirăm": "ferfeniți",
    "ferfenițirăți": "ferfeniți",
    "ferfenițise": "ferfeniți",
    "ferfenițisem": "ferfeniți",
    "ferfenițiseră": "ferfeniți",
    "ferfenițiserăm": "ferfeniți",
    "ferfenițiserăți": "ferfeniți",
    "ferfenițiseși": "ferfeniți",
    "ferfenițiși": "ferfeniți",
    "ferfenițit": "ferfeniți",
    "ferfenițiți": "ferfeniți",
    "ferfenițitu": "ferfeniți",
    "neferfenițind": "ferfeniți",
    "neferfenițindu": "ferfeniți",
    "nemaiferfenițind": "ferfeniți",
    "nemaiferfenițindu": "ferfeniți",
    "ferfenițită": "ferfenițit",
    "ferfenițite": "ferfenițit",
    "ferfenițiți": "ferfenițit",
    "ferea": "feri",
    "fereai": "feri",
    "feream": "feri",
    "ferească": "feri",
    "fereați": "feri",
    "fereau": "feri",
    "feresc": "feri",
    "ferește": "feri",
    "ferești": "feri",
    "ferii": "feri",
    "ferim": "feri",
    "ferind": "feri",
    "ferindu": "feri",
    "feriră": "feri",
    "ferirăm": "feri",
    "ferirăți": "feri",
    "ferise": "feri",
    "ferisem": "feri",
    "feriseră": "feri",
    "feriserăm": "feri",
    "feriserăți": "feri",
    "feriseși": "feri",
    "feriși": "feri",
    "ferit": "feri",
    "feriți": "feri",
    "feritu": "feri",
    "neferind": "feri",
    "neferindu": "feri",
    "nemaiferind": "feri",
    "nemaiferindu": "feri",
    "feribotul": "feribot",
    "feribotului": "feribot",
    "feriboturi": "feribot",
    "feriboturile": "feribot",
    "feriboturilor": "feribot",
    "fericea": "ferici",
    "fericeai": "ferici",
    "fericeam": "ferici",
    "fericească": "ferici",
    "fericeați": "ferici",
    "fericeau": "ferici",
    "fericesc": "ferici",
    "fericește": "ferici",
    "fericești": "ferici",
    "fericii": "ferici",
    "fericim": "ferici",
    "fericind": "ferici",
    "fericindu": "ferici",
    "fericiră": "ferici",
    "fericirăm": "ferici",
    "fericirăți": "ferici",
    "fericise": "ferici",
    "fericisem": "ferici",
    "fericiseră": "ferici",
    "fericiserăm": "ferici",
    "fericiserăți": "ferici",
    "fericiseși": "ferici",
    "fericiși": "ferici",
    "fericit": "ferici",
    "fericiți": "ferici",
    "fericitu": "ferici",
    "nefericind": "ferici",
    "nefericindu": "ferici",
    "nemaifericind": "ferici",
    "nemaifericindu": "ferici",
    "fericirea": "fericire",
    "fericiri": "fericire",
    "fericirii": "fericire",
    "fericirile": "fericire",
    "fericirilor": "fericire",
    "fericita": "fericit",
    "fericită": "fericit",
    "fericite": "fericit",
    "fericitei": "fericit",
    "fericitele": "fericit",
    "fericitelor": "fericit",
    "fericiți": "fericit",
    "fericiții": "fericit",
    "fericiților": "fericit",
    "fericitul": "fericit",
    "fericitule": "fericit",
    "fericitului": "fericit",
    "fericita": "fericită",
    "fericite": "fericită",
    "fericitei": "fericită",
    "fericitele": "fericită",
    "fericitelor": "fericită",
    "feriga": "ferigă",
    "ferigi": "ferigă",
    "ferigii": "ferigă",
    "ferigile": "ferigă",
    "ferigilor": "ferigă",
    "ferita": "ferit",
    "ferită": "ferit",
    "ferite": "ferit",
    "feritei": "ferit",
    "feritele": "ferit",
    "feritelor": "ferit",
    "feriți": "ferit",
    "feriții": "ferit",
    "feriților": "ferit",
    "feritul": "ferit",
    "feritului": "ferit",
    "feritori": "feritor",
    "ferma": "ferm",
    "fermă": "ferm",
    "ferme": "ferm",
    "fermei": "ferm",
    "fermele": "ferm",
    "fermelor": "ferm",
    "fermi": "ferm",
    "fermii": "ferm",
    "fermilor": "ferm",
    "fermul": "ferm",
    "fermului": "ferm",
    "ferma": "fermă",
    "ferme": "fermă",
    "fermei": "fermă",
    "fermele": "fermă",
    "fermelor": "fermă",
    "fermecă": "fermeca",
    "fermecai": "fermeca",
    "fermecam": "fermeca",
    "fermecăm": "fermeca",
    "fermecând": "fermeca",
    "fermecându": "fermeca",
    "fermecară": "fermeca",
    "fermecarăm": "fermeca",
    "fermecarăți": "fermeca",
    "fermecase": "fermeca",
    "fermecasem": "fermeca",
    "fermecaseră": "fermeca",
    "fermecaserăm": "fermeca",
    "fermecaserăți": "fermeca",
    "fermecaseși": "fermeca",
    "fermecași": "fermeca",
    "fermecat": "fermeca",
    "fermecați": "fermeca",
    "fermecatu": "fermeca",
    "fermecau": "fermeca",
    "nefermecând": "fermeca",
    "nefermecându": "fermeca",
    "nemaifermecând": "fermeca",
    "nemaifermecându": "fermeca",
    "fermecata": "fermecat",
    "fermecată": "fermecat",
    "fermecate": "fermecat",
    "fermecatei": "fermecat",
    "fermecatele": "fermecat",
    "fermecatelor": "fermecat",
    "fermecați": "fermecat",
    "fermecații": "fermecat",
    "fermecaților": "fermecat",
    "fermecatul": "fermecat",
    "fermecatului": "fermecat",
    "fermecătoare": "fermecător",
    "fermecătoarea": "fermecător",
    "fermecătoarei": "fermecător",
    "fermecătoarele": "fermecător",
    "fermecătoarelor": "fermecător",
    "fermecători": "fermecător",
    "fermecătorii": "fermecător",
    "fermecătorilor": "fermecător",
    "fermecătorul": "fermecător",
    "fermecătorului": "fermecător",
    "fermenți": "ferment",
    "fermenții": "ferment",
    "fermenților": "ferment",
    "fermentul": "ferment",
    "fermentului": "ferment",
    "fermentă": "fermenta",
    "fermentai": "fermenta",
    "fermentam": "fermenta",
    "fermentăm": "fermenta",
    "fermentând": "fermenta",
    "fermentându": "fermenta",
    "fermentară": "fermenta",
    "fermentarăm": "fermenta",
    "fermentarăți": "fermenta",
    "fermentase": "fermenta",
    "fermentasem": "fermenta",
    "fermentaseră": "fermenta",
    "fermentaserăm": "fermenta",
    "fermentaserăți": "fermenta",
    "fermentaseși": "fermenta",
    "fermentași": "fermenta",
    "fermentat": "fermenta",
    "fermentați": "fermenta",
    "fermentatu": "fermenta",
    "fermentau": "fermenta",
    "fermentează": "fermenta",
    "fermentez": "fermenta",
    "fermenteze": "fermenta",
    "fermentezi": "fermenta",
    "nefermentând": "fermenta",
    "nefermentându": "fermenta",
    "nemaifermentând": "fermenta",
    "nemaifermentându": "fermenta",
    "fermentată": "fermentat",
    "fermentate": "fermentat",
    "fermentați": "fermentat",
    "fermentația": "fermentație",
    "fermentației": "fermentație",
    "fermentații": "fermentație",
    "fermentațiile": "fermentație",
    "fermentațiilor": "fermentație",
    "fermieri": "fermier",
    "fermierii": "fermier",
    "fermierilor": "fermier",
    "fermierul": "fermier",
    "fermierului": "fermier",
    "fermitatea": "fermitate",
    "fermități": "fermitate",
    "fermității": "fermitate",
    "fermoare": "fermoar",
    "fermoarele": "fermoar",
    "fermoarelor": "fermoar",
    "fermoarul": "fermoar",
    "fermoarului": "fermoar",
    "ferocitatea": "ferocitate",
    "ferocități": "ferocitate",
    "ferocității": "ferocitate",
    "feroasa": "feros",
    "feroasă": "feros",
    "feroase": "feros",
    "feroasei": "feros",
    "feroasele": "feros",
    "feroaselor": "feros",
    "feroși": "feros",
    "feroșii": "feros",
    "feroșilor": "feros",
    "ferosul": "feros",
    "ferosului": "feros",
    "fertila": "fertil",
    "fertilă": "fertil",
    "fertile": "fertil",
    "fertilei": "fertil",
    "fertilele": "fertil",
    "fertilelor": "fertil",
    "fertili": "fertil",
    "fertilii": "fertil",
    "fertililor": "fertil",
    "fertilul": "fertil",
    "fertilului": "fertil",
    "fertilitatea": "fertilitate",
    "fertilități": "fertilitate",
    "fertilității": "fertilitate",
    "fertiliză": "fertiliza",
    "fertilizai": "fertiliza",
    "fertilizam": "fertiliza",
    "fertilizăm": "fertiliza",
    "fertilizând": "fertiliza",
    "fertilizându": "fertiliza",
    "fertilizară": "fertiliza",
    "fertilizarăm": "fertiliza",
    "fertilizarăți": "fertiliza",
    "fertilizase": "fertiliza",
    "fertilizasem": "fertiliza",
    "fertilizaseră": "fertiliza",
    "fertilizaserăm": "fertiliza",
    "fertilizaserăți": "fertiliza",
    "fertilizaseși": "fertiliza",
    "fertilizași": "fertiliza",
    "fertilizat": "fertiliza",
    "fertilizați": "fertiliza",
    "fertilizatu": "fertiliza",
    "fertilizau": "fertiliza",
    "fertilizează": "fertiliza",
    "fertilizez": "fertiliza",
    "fertilizeze": "fertiliza",
    "fertilizezi": "fertiliza",
    "nefertilizând": "fertiliza",
    "nefertilizându": "fertiliza",
    "nemaifertilizând": "fertiliza",
    "nemaifertilizându": "fertiliza",
    "fertilizarea": "fertilizare",
    "fertilizări": "fertilizare",
    "fertilizării": "fertilizare",
    "fertilizările": "fertilizare",
    "fertilizărilor": "fertilizare",
    "fertilizată": "fertilizat",
    "fertilizate": "fertilizat",
    "fertilizați": "fertilizat",
    "ferventa": "fervent",
    "ferventă": "fervent",
    "fervente": "fervent",
    "ferventei": "fervent",
    "ferventele": "fervent",
    "ferventelor": "fervent",
    "fervenți": "fervent",
    "fervenții": "fervent",
    "fervenților": "fervent",
    "ferventul": "fervent",
    "ferventului": "fervent",
    "fesul": "fes",
    "fesului": "fes",
    "fesuri": "fes",
    "fesurile": "fes",
    "fesurilor": "fes",
    "fesa": "fesă",
    "fese": "fesă",
    "fesei": "fesă",
    "fesele": "fesă",
    "feselor": "fesă",
    "festa": "festă",
    "feste": "festă",
    "festei": "festă",
    "festele": "festă",
    "festelor": "festă",
    "feștelea": "feșteli",
    "feșteleai": "feșteli",
    "feșteleam": "feșteli",
    "feștelească": "feșteli",
    "feșteleați": "feșteli",
    "feșteleau": "feșteli",
    "feștelesc": "feșteli",
    "feștelește": "feșteli",
    "feștelești": "feșteli",
    "feștelii": "feșteli",
    "feștelim": "feșteli",
    "feștelind": "feșteli",
    "feștelindu": "feșteli",
    "feșteliră": "feșteli",
    "feștelirăm": "feșteli",
    "feștelirăți": "feșteli",
    "feștelise": "feșteli",
    "feștelisem": "feșteli",
    "feșteliseră": "feșteli",
    "feșteliserăm": "feșteli",
    "feșteliserăți": "feșteli",
    "feșteliseși": "feșteli",
    "feșteliși": "feșteli",
    "feștelit": "feșteli",
    "feșteliți": "feșteli",
    "feștelitu": "feșteli",
    "nefeștelind": "feșteli",
    "nefeștelindu": "feșteli",
    "nemaifeștelind": "feșteli",
    "nemaifeștelindu": "feșteli",
    "feștelită": "feștelit",
    "feștelite": "feștelit",
    "feșteliți": "feștelit",
    "feștila": "feștilă",
    "feștile": "feștilă",
    "feștilei": "feștilă",
    "feștilele": "feștilă",
    "feștilelor": "feștilă",
    "festiva": "festiv",
    "festivă": "festiv",
    "festive": "festiv",
    "festivei": "festiv",
    "festivele": "festiv",
    "festivelor": "festiv",
    "festivi": "festiv",
    "festivii": "festiv",
    "festivilor": "festiv",
    "festivul": "festiv",
    "festivului": "festiv",
    "festivalul": "festival",
    "festivalului": "festival",
    "festivaluri": "festival",
    "festivalurile": "festival",
    "festivalurilor": "festival",
    "festivitatea": "festivitate",
    "festivități": "festivitate",
    "festivității": "festivitate",
    "festoane": "feston",
    "festoanele": "feston",
    "festoanelor": "feston",
    "festonul": "feston",
    "festonului": "feston",
    "festonă": "festona",
    "festonai": "festona",
    "festonam": "festona",
    "festonăm": "festona",
    "festonând": "festona",
    "festonându": "festona",
    "festonară": "festona",
    "festonarăm": "festona",
    "festonarăți": "festona",
    "festonase": "festona",
    "festonasem": "festona",
    "festonaseră": "festona",
    "festonaserăm": "festona",
    "festonaserăți": "festona",
    "festonaseși": "festona",
    "festonași": "festona",
    "festonat": "festona",
    "festonați": "festona",
    "festonatu": "festona",
    "festonau": "festona",
    "festonează": "festona",
    "festonez": "festona",
    "festoneze": "festona",
    "festonezi": "festona",
    "nefestonând": "festona",
    "nefestonându": "festona",
    "nemaifestonând": "festona",
    "nemaifestonându": "festona",
    "festonată": "festonat",
    "festonate": "festonat",
    "festonați": "festonat",
    "fetea": "feti",
    "feteai": "feti",
    "feteam": "feti",
    "fetească": "feti",
    "feteați": "feti",
    "feteau": "feti",
    "fetesc": "feti",
    "fetește": "feti",
    "fetești": "feti",
    "fetii": "feti",
    "fetim": "feti",
    "fetind": "feti",
    "fetindu": "feti",
    "fetiră": "feti",
    "fetirăm": "feti",
    "fetirăți": "feti",
    "fetise": "feti",
    "fetisem": "feti",
    "fetiseră": "feti",
    "fetiserăm": "feti",
    "fetiserăți": "feti",
    "fetiseși": "feti",
    "fetiși": "feti",
    "fetit": "feti",
    "fetiți": "feti",
    "fetitu": "feti",
    "nefetind": "feti",
    "nefetindu": "feti",
    "nemaifetind": "feti",
    "nemaifetindu": "feti",
    "fetida": "fetid",
    "fetidă": "fetid",
    "fetide": "fetid",
    "fetidei": "fetid",
    "fetidele": "fetid",
    "fetidelor": "fetid",
    "fetido": "fetid",
    "fetidul": "fetid",
    "fetidule": "fetid",
    "fetidului": "fetid",
    "fetizi": "fetid",
    "fetizii": "fetid",
    "fetizilor": "fetid",
    "fetișcana": "fetișcană",
    "fetișcane": "fetișcană",
    "fetișcanei": "fetișcană",
    "fetișcanele": "fetișcană",
    "fetișcanelor": "fetișcană",
    "fetișiză": "fetișiza",
    "fetișizai": "fetișiza",
    "fetișizam": "fetișiza",
    "fetișizăm": "fetișiza",
    "fetișizând": "fetișiza",
    "fetișizându": "fetișiza",
    "fetișizară": "fetișiza",
    "fetișizarăm": "fetișiza",
    "fetișizarăți": "fetișiza",
    "fetișizase": "fetișiza",
    "fetișizasem": "fetișiza",
    "fetișizaseră": "fetișiza",
    "fetișizaserăm": "fetișiza",
    "fetișizaserăți": "fetișiza",
    "fetișizaseși": "fetișiza",
    "fetișizași": "fetișiza",
    "fetișizat": "fetișiza",
    "fetișizați": "fetișiza",
    "fetișizatu": "fetișiza",
    "fetișizau": "fetișiza",
    "fetișizează": "fetișiza",
    "fetișizez": "fetișiza",
    "fetișizeze": "fetișiza",
    "fetișizezi": "fetișiza",
    "nefetișizând": "fetișiza",
    "nefetișizându": "fetișiza",
    "nemaifetișizând": "fetișiza",
    "nemaifetișizându": "fetișiza",
    "fetișizată": "fetișizat",
    "fetișizate": "fetișizat",
    "fetișizați": "fetișizat",
    "fetișoara": "fetișoară",
    "fetișoare": "fetișoară",
    "fetișoarei": "fetișoară",
    "fetișoarele": "fetișoară",
    "fetișoarelor": "fetișoară",
    "fetită": "fetit",
    "fetite": "fetit",
    "fetiți": "fetit",
    "fetița": "fetiță",
    "fetițe": "fetiță",
    "fetiței": "fetiță",
    "fetițele": "fetiță",
    "fetițelor": "fetiță",
    "fetrul": "fetru",
    "fetrului": "fetru",
    "feudala": "feudal",
    "feudală": "feudal",
    "feudale": "feudal",
    "feudalei": "feudal",
    "feudalele": "feudal",
    "feudalelor": "feudal",
    "feudali": "feudal",
    "feudalii": "feudal",
    "feudalilor": "feudal",
    "feudalul": "feudal",
    "feudalului": "feudal",
    "feudalismul": "feudalism",
    "feudalismului": "feudalism",
    "fezabila": "fezabil",
    "fezabilă": "fezabil",
    "fezabile": "fezabil",
    "fezabilei": "fezabil",
    "fezabilele": "fezabil",
    "fezabilelor": "fezabil",
    "fezabili": "fezabil",
    "fezabilii": "fezabil",
    "fezabililor": "fezabil",
    "fezabilo": "fezabil",
    "fezabilul": "fezabil",
    "fezabilule": "fezabil",
    "fezabilului": "fezabil",
    "fezandă": "fezanda",
    "fezandai": "fezanda",
    "fezandam": "fezanda",
    "fezandăm": "fezanda",
    "fezandând": "fezanda",
    "fezandându": "fezanda",
    "fezandară": "fezanda",
    "fezandarăm": "fezanda",
    "fezandarăți": "fezanda",
    "fezandase": "fezanda",
    "fezandasem": "fezanda",
    "fezandaseră": "fezanda",
    "fezandaserăm": "fezanda",
    "fezandaserăți": "fezanda",
    "fezandaseși": "fezanda",
    "fezandași": "fezanda",
    "fezandat": "fezanda",
    "fezandați": "fezanda",
    "fezandatu": "fezanda",
    "fezandau": "fezanda",
    "fezandează": "fezanda",
    "fezandez": "fezanda",
    "fezandeze": "fezanda",
    "fezandezi": "fezanda",
    "nefezandând": "fezanda",
    "nefezandându": "fezanda",
    "nemaifezandând": "fezanda",
    "nemaifezandându": "fezanda",
    "fezandată": "fezandat",
    "fezandate": "fezandat",
    "fezandați": "fezandat",
    "e": "fi",
    "e-": "fi",
    "era": "fi",
    "erai": "fi",
    "eram": "fi",
    "erați": "fi",
    "erau": "fi",
    "este": "fi",
    "ești": "fi",
    "fie": "fi",
    "fii": "fi",
    "fiind": "fi",
    "fiindu": "fi",
    "fim": "fi",
    "fir-": "fi",
    "fiți": "fi",
    "fiu": "fi",
    "fos'": "fi",
    "fost": "fi",
    "fostu": "fi",
    "fu": "fi",
    "fură": "fi",
    "fuse": "fi",
    "fusei": "fi",
    "fuseră": "fi",
    "fuserăm": "fi",
    "fuserăți": "fi",
    "fusese": "fi",
    "fusesem": "fi",
    "fuseseră": "fi",
    "fuseserăm": "fi",
    "fuseserăți": "fi",
    "fuseseși": "fi",
    "fuseși": "fi",
    "i-": "fi",
    "nefiind": "fi",
    "nefiindu": "fi",
    "nemaifiind": "fi",
    "nemaifiindu": "fi",
    "sunt": "fi",
    "suntem": "fi",
    "sunteți": "fi",
    "fiabila": "fiabil",
    "fiabilă": "fiabil",
    "fiabile": "fiabil",
    "fiabilei": "fiabil",
    "fiabilele": "fiabil",
    "fiabilelor": "fiabil",
    "fiabili": "fiabil",
    "fiabilii": "fiabil",
    "fiabililor": "fiabil",
    "fiabilul": "fiabil",
    "fiabilului": "fiabil",
    "fiara": "fiară",
    "fiare": "fiară",
    "fiarei": "fiară",
    "fiarele": "fiară",
    "fiarelor": "fiară",
    "fiascoul": "fiasco",
    "fiascoului": "fiasco",
    "fibra": "fibră",
    "fibre": "fibră",
    "fibrei": "fibră",
    "fibrele": "fibră",
    "fibrelor": "fibră",
    "ficați": "ficat",
    "ficații": "ficat",
    "ficaților": "ficat",
    "ficatul": "ficat",
    "ficatului": "ficat",
    "ficțiunea": "ficțiune",
    "ficțiuni": "ficțiune",
    "ficțiunii": "ficțiune",
    "ficțiunile": "ficțiune",
    "ficțiunilor": "ficțiune",
    "fictiva": "fictiv",
    "fictivă": "fictiv",
    "fictive": "fictiv",
    "fictivei": "fictiv",
    "fictivele": "fictiv",
    "fictivelor": "fictiv",
    "fictivi": "fictiv",
    "fictivii": "fictiv",
    "fictivilor": "fictiv",
    "fictivul": "fictiv",
    "fictivului": "fictiv",
    "fideaua": "fidea",
    "fidele": "fidea",
    "fidelei": "fidea",
    "fidelele": "fidea",
    "fidelelor": "fidea",
    "fidela": "fidel",
    "fidelă": "fidel",
    "fidele": "fidel",
    "fidelei": "fidel",
    "fidelele": "fidel",
    "fidelelor": "fidel",
    "fideli": "fidel",
    "fidelii": "fidel",
    "fidelilor": "fidel",
    "fidelul": "fidel",
    "fidelului": "fidel",
    "fidelitatea": "fidelitate",
    "fidelități": "fidelitate",
    "fidelității": "fidelitate",
    "fiecărei": "fiecare",
    "fiecăreia": "fiecare",
    "fiecărui": "fiecare",
    "fiecăruia": "fiecare",
    "Fe": "fier",
    "fiare": "fier",
    "fiarele": "fier",
    "fiarelor": "fier",
    "fierul": "fier",
    "fierului": "fier",
    "fierari": "fierar",
    "fierarii": "fierar",
    "fierarilor": "fierar",
    "fierarul": "fierar",
    "fierarului": "fierar",
    "fierăria": "fierărie",
    "fierăriei": "fierărie",
    "fierării": "fierărie",
    "fierăriile": "fierărie",
    "fierăriilor": "fierărie",
    "fierb": "fierbe",
    "fierbând": "fierbe",
    "fierbându": "fierbe",
    "fierbea": "fierbe",
    "fierbeai": "fierbe",
    "fierbeam": "fierbe",
    "fierbeați": "fierbe",
    "fierbeau": "fierbe",
    "fierbem": "fierbe",
    "fierbeți": "fierbe",
    "fierbi": "fierbe",
    "fierse": "fierbe",
    "fiersei": "fierbe",
    "fierseră": "fierbe",
    "fierserăm": "fierbe",
    "fierserăți": "fierbe",
    "fiersese": "fierbe",
    "fiersesem": "fierbe",
    "fierseseră": "fierbe",
    "fierseserăm": "fierbe",
    "fierseserăți": "fierbe",
    "fierseseși": "fierbe",
    "fierseși": "fierbe",
    "fiert": "fierbe",
    "fiertu": "fierbe",
    "nefierbând": "fierbe",
    "nefierbându": "fierbe",
    "nemaifierbând": "fierbe",
    "nemaifierbându": "fierbe",
    "fierberea": "fierbere",
    "fierberi": "fierbere",
    "fierberii": "fierbere",
    "fierberile": "fierbere",
    "fierberilor": "fierbere",
    "fbt.": "fierbinte",
    "fierb.": "fierbinte",
    "fierbintea": "fierbinte",
    "fierbintele": "fierbinte",
    "fierbintelui": "fierbinte",
    "fierbinți": "fierbinte",
    "fierbinții": "fierbinte",
    "fierbințile": "fierbinte",
    "fierbinților": "fierbinte",
    "fierbințeala": "fierbințeală",
    "fierbințeli": "fierbințeală",
    "fierbințelii": "fierbințeală",
    "fierbințelile": "fierbințeală",
    "fierbințelilor": "fierbințeală",
    "fierea": "fiere",
    "fieri": "fiere",
    "fierii": "fiere",
    "fiarta": "fiert",
    "fiartă": "fiert",
    "fiertă": "fiert",
    "fierte": "fiert",
    "fiertei": "fiert",
    "fiertele": "fiert",
    "fiertelor": "fiert",
    "fierți": "fiert",
    "fierții": "fiert",
    "fierților": "fiert",
    "fiertul": "fiert",
    "fiertului": "fiert",
    "fiertura": "fiertură",
    "fierturi": "fiertură",
    "fierturii": "fiertură",
    "fierturile": "fiertură",
    "fierturilor": "fiertură",
    "fig.": "figura",
    "figură": "figura",
    "figurai": "figura",
    "figuram": "figura",
    "figurăm": "figura",
    "figurând": "figura",
    "figurându": "figura",
    "figurară": "figura",
    "figurarăm": "figura",
    "figurarăți": "figura",
    "figurase": "figura",
    "figurasem": "figura",
    "figuraseră": "figura",
    "figuraserăm": "figura",
    "figuraserăți": "figura",
    "figuraseși": "figura",
    "figurași": "figura",
    "figurat": "figura",
    "figurați": "figura",
    "figuratu": "figura",
    "figurau": "figura",
    "figurează": "figura",
    "figurez": "figura",
    "figureze": "figura",
    "figurezi": "figura",
    "nefigurând": "figura",
    "nefigurându": "figura",
    "nemaifigurând": "figura",
    "nemaifigurându": "figura",
    "figura": "figură",
    "figuri": "figură",
    "figurii": "figură",
    "figurile": "figură",
    "figurilor": "figură",
    "figuranți": "figurant",
    "figuranții": "figurant",
    "figuranților": "figurant",
    "figurantul": "figurant",
    "figurantului": "figurant",
    "fig.": "figurat",
    "figurata": "figurat",
    "figurată": "figurat",
    "figurate": "figurat",
    "figuratei": "figurat",
    "figuratele": "figurat",
    "figuratelor": "figurat",
    "figurați": "figurat",
    "figurații": "figurat",
    "figuraților": "figurat",
    "figuratul": "figurat",
    "figuratului": "figurat",
    "figurina": "figurină",
    "figurine": "figurină",
    "figurinei": "figurină",
    "figurinele": "figurină",
    "figurinelor": "figurină",
    "fii-": "fiică",
    "fiica": "fiică",
    "fiice": "fiică",
    "fiicei": "fiică",
    "fiicele": "fiică",
    "fiicelor": "fiică",
    "fiindc-": "fiindcă",
    "ființă": "ființa",
    "ființai": "ființa",
    "ființam": "ființa",
    "ființăm": "ființa",
    "ființând": "ființa",
    "ființându": "ființa",
    "ființară": "ființa",
    "ființarăm": "ființa",
    "ființarăți": "ființa",
    "ființase": "ființa",
    "ființasem": "ființa",
    "ființaseră": "ființa",
    "ființaserăm": "ființa",
    "ființaserăți": "ființa",
    "ființaseși": "ființa",
    "ființași": "ființa",
    "ființat": "ființa",
    "ființați": "ființa",
    "ființatu": "ființa",
    "ființau": "ființa",
    "ființează": "ființa",
    "ființez": "ființa",
    "ființeze": "ființa",
    "ființezi": "ființa",
    "neființând": "ființa",
    "neființându": "ființa",
    "nemaiființând": "ființa",
    "nemaiființându": "ființa",
    "ființa": "ființă",
    "ființe": "ființă",
    "ființei": "ființă",
    "ființele": "ființă",
    "ființelor": "ființă",
    "ființată": "ființat",
    "ființate": "ființat",
    "ființați": "ființat",
    "ființiala": "ființial",
    "ființială": "ființial",
    "ființiale": "ființial",
    "ființialei": "ființial",
    "ființialele": "ființial",
    "ființialelor": "ființial",
    "ființiali": "ființial",
    "ființialii": "ființial",
    "ființialilor": "ființial",
    "ființialo": "ființial",
    "ființialul": "ființial",
    "ființialule": "ființial",
    "ființialului": "ființial",
    "filă": "fila",
    "filai": "fila",
    "filam": "fila",
    "filăm": "fila",
    "filând": "fila",
    "filându": "fila",
    "filară": "fila",
    "filarăm": "fila",
    "filarăți": "fila",
    "filase": "fila",
    "filasem": "fila",
    "filaseră": "fila",
    "filaserăm": "fila",
    "filaserăți": "fila",
    "filaseși": "fila",
    "filași": "fila",
    "filat": "fila",
    "filați": "fila",
    "filatu": "fila",
    "filau": "fila",
    "filează": "fila",
    "filez": "fila",
    "fileze": "fila",
    "filezi": "fila",
    "nefilând": "fila",
    "nefilându": "fila",
    "nemaifilând": "fila",
    "nemaifilându": "fila",
    "fila": "filă",
    "file": "filă",
    "filei": "filă",
    "filele": "filă",
    "filelor": "filă",
    "filo": "filă",
    "filantropi": "filantrop",
    "filantropii": "filantrop",
    "filantropilor": "filantrop",
    "filantropul": "filantrop",
    "filantropului": "filantrop",
    "filantropia": "filantropie",
    "filantropiei": "filantropie",
    "filantropii": "filantropie",
    "filarmonica": "filarmonică",
    "filarmonici": "filarmonică",
    "filarmonicii": "filarmonică",
    "filarmonicile": "filarmonică",
    "filarmonicilor": "filarmonică",
    "filată": "filat",
    "filate": "filat",
    "filați": "filat",
    "filatelia": "filatelie",
    "filateliei": "filatelie",
    "filatelii": "filatelie",
    "filateliști": "filatelist",
    "filateliștii": "filatelist",
    "filateliștilor": "filatelist",
    "filatelistul": "filatelist",
    "filatelistului": "filatelist",
    "filatura": "filatură",
    "filaturi": "filatură",
    "filaturii": "filatură",
    "filaturile": "filatură",
    "filaturilor": "filatură",
    "fildeși": "fildeș",
    "fildeșii": "fildeș",
    "fildeșilor": "fildeș",
    "fildeșul": "fildeș",
    "fildeșului": "fildeș",
    "fildeșuri": "fildeș",
    "fildeșurile": "fildeș",
    "fildeșurilor": "fildeș",
    "filetul": "filet",
    "filetului": "filet",
    "fileturi": "filet",
    "fileturile": "filet",
    "fileturilor": "filet",
    "filetă": "fileta",
    "filetai": "fileta",
    "filetam": "fileta",
    "filetăm": "fileta",
    "filetând": "fileta",
    "filetându": "fileta",
    "filetară": "fileta",
    "filetarăm": "fileta",
    "filetarăți": "fileta",
    "filetase": "fileta",
    "filetasem": "fileta",
    "filetaseră": "fileta",
    "filetaserăm": "fileta",
    "filetaserăți": "fileta",
    "filetaseși": "fileta",
    "filetași": "fileta",
    "filetat": "fileta",
    "filetați": "fileta",
    "filetatu": "fileta",
    "filetau": "fileta",
    "filetează": "fileta",
    "filetez": "fileta",
    "fileteze": "fileta",
    "filetezi": "fileta",
    "nefiletând": "fileta",
    "nefiletându": "fileta",
    "nemaifiletând": "fileta",
    "nemaifiletându": "fileta",
    "filetată": "filetat",
    "filetate": "filetat",
    "filetați": "filetat",
    "fileul": "fileu",
    "fileului": "fileu",
    "fileuri": "fileu",
    "fileurile": "fileu",
    "fileurilor": "fileu",
    "filfizoni": "filfizon",
    "filfizonii": "filfizon",
    "filfizonilor": "filfizon",
    "filfizonul": "filfizon",
    "filfizonule": "filfizon",
    "filfizonului": "filfizon",
    "filiala": "filial",
    "filială": "filial",
    "filiale": "filial",
    "filialei": "filial",
    "filialele": "filial",
    "filialelor": "filial",
    "filiali": "filial",
    "filialii": "filial",
    "filialilor": "filial",
    "filialul": "filial",
    "filialului": "filial",
    "filiala": "filială",
    "filiale": "filială",
    "filialei": "filială",
    "filialele": "filială",
    "filialelor": "filială",
    "filiera": "filieră",
    "filiere": "filieră",
    "filierei": "filieră",
    "filierele": "filieră",
    "filierelor": "filieră",
    "filigrane": "filigran",
    "filigranele": "filigran",
    "filigranelor": "filigran",
    "filigranul": "filigran",
    "filigranului": "filigran",
    "filigrană": "filigrana",
    "filigranai": "filigrana",
    "filigranam": "filigrana",
    "filigranăm": "filigrana",
    "filigranând": "filigrana",
    "filigranându": "filigrana",
    "filigranară": "filigrana",
    "filigranarăm": "filigrana",
    "filigranarăți": "filigrana",
    "filigranase": "filigrana",
    "filigranasem": "filigrana",
    "filigranaseră": "filigrana",
    "filigranaserăm": "filigrana",
    "filigranaserăți": "filigrana",
    "filigranaseși": "filigrana",
    "filigranași": "filigrana",
    "filigranat": "filigrana",
    "filigranați": "filigrana",
    "filigranatu": "filigrana",
    "filigranau": "filigrana",
    "filigranează": "filigrana",
    "filigranez": "filigrana",
    "filigraneze": "filigrana",
    "filigranezi": "filigrana",
    "nefiligranând": "filigrana",
    "nefiligranându": "filigrana",
    "nemaifiligranând": "filigrana",
    "nemaifiligranându": "filigrana",
    "filigranată": "filigranat",
    "filigranate": "filigranat",
    "filigranați": "filigranat",
    "Filipeștii": "Filipești",
    "filisteanul": "filistean",
    "filisteanule": "filistean",
    "filisteanului": "filistean",
    "filisteni": "filistean",
    "filistenii": "filistean",
    "filistenilor": "filistean",
    "filme": "film",
    "filmele": "film",
    "filmelor": "film",
    "filmul": "film",
    "filmului": "film",
    "filmă": "filma",
    "filmai": "filma",
    "filmam": "filma",
    "filmăm": "filma",
    "filmând": "filma",
    "filmându": "filma",
    "filmară": "filma",
    "filmarăm": "filma",
    "filmarăți": "filma",
    "filmase": "filma",
    "filmasem": "filma",
    "filmaseră": "filma",
    "filmaserăm": "filma",
    "filmaserăți": "filma",
    "filmaseși": "filma",
    "filmași": "filma",
    "filmat": "filma",
    "filmați": "filma",
    "filmatu": "filma",
    "filmau": "filma",
    "filmează": "filma",
    "filmez": "filma",
    "filmeze": "filma",
    "filmezi": "filma",
    "nefilmând": "filma",
    "nefilmându": "filma",
    "nemaifilmând": "filma",
    "nemaifilmându": "filma",
    "filmată": "filmat",
    "filmate": "filmat",
    "filmați": "filmat",
    "Filocaliei": "Filocalia",
    "filocalica": "filocalic",
    "filocalică": "filocalic",
    "filocalice": "filocalic",
    "filocalicei": "filocalic",
    "filocalicele": "filocalic",
    "filocalicelor": "filocalic",
    "filocalici": "filocalic",
    "filocalicii": "filocalic",
    "filocalicilor": "filocalic",
    "filocalico": "filocalic",
    "filocalicul": "filocalic",
    "filocalicule": "filocalic",
    "filocalicului": "filocalic",
    "Filofteii": "Filofteia",
    "filologi": "filolog",
    "filologii": "filolog",
    "filologilor": "filolog",
    "filologul": "filolog",
    "filologului": "filolog",
    "filologa": "filologă",
    "filologe": "filologă",
    "filologei": "filologă",
    "filologele": "filologă",
    "filologelor": "filologă",
    "filologica": "filologic",
    "filologică": "filologic",
    "filologice": "filologic",
    "filologicei": "filologic",
    "filologicele": "filologic",
    "filologicelor": "filologic",
    "filologici": "filologic",
    "filologicii": "filologic",
    "filologicilor": "filologic",
    "filologico": "filologic",
    "filologicul": "filologic",
    "filologicule": "filologic",
    "filologicului": "filologic",
    "filol.": "filologie",
    "filologia": "filologie",
    "filologiei": "filologie",
    "filologii": "filologie",
    "filoane": "filon",
    "filoanele": "filon",
    "filoanelor": "filon",
    "filonul": "filon",
    "filonului": "filon",
    "filosoafa": "filosoafă",
    "filosoafe": "filosoafă",
    "filosoafei": "filosoafă",
    "filosoafele": "filosoafă",
    "filosoafelor": "filosoafă",
    "filosofi": "filosof",
    "filosofii": "filosof",
    "filosofilor": "filosof",
    "filosoful": "filosof",
    "filosofului": "filosof",
    "filosofă": "filosofa",
    "filosofai": "filosofa",
    "filosofam": "filosofa",
    "filosofăm": "filosofa",
    "filosofând": "filosofa",
    "filosofându": "filosofa",
    "filosofară": "filosofa",
    "filosofarăm": "filosofa",
    "filosofarăți": "filosofa",
    "filosofase": "filosofa",
    "filosofasem": "filosofa",
    "filosofaseră": "filosofa",
    "filosofaserăm": "filosofa",
    "filosofaserăți": "filosofa",
    "filosofaseși": "filosofa",
    "filosofași": "filosofa",
    "filosofat": "filosofa",
    "filosofați": "filosofa",
    "filosofatu": "filosofa",
    "filosofau": "filosofa",
    "filosofează": "filosofa",
    "filosofez": "filosofa",
    "filosofeze": "filosofa",
    "filosofezi": "filosofa",
    "filosofată": "filosofat",
    "filosofate": "filosofat",
    "filosofați": "filosofat",
    "filosofica": "filosofic",
    "filosofică": "filosofic",
    "filosofice": "filosofic",
    "filosoficei": "filosofic",
    "filosoficele": "filosofic",
    "filosoficelor": "filosofic",
    "filosofici": "filosofic",
    "filosoficii": "filosofic",
    "filosoficilor": "filosofic",
    "filosofico": "filosofic",
    "filosoficul": "filosofic",
    "filosoficule": "filosofic",
    "filosoficului": "filosofic",
    "fil.": "filosofie",
    "filosofia": "filosofie",
    "filosofiei": "filosofie",
    "filosofii": "filosofie",
    "filosovietica": "filosovietic",
    "filosovietică": "filosovietic",
    "filosovietice": "filosovietic",
    "filosovieticei": "filosovietic",
    "filosovieticele": "filosovietic",
    "filosovieticelor": "filosovietic",
    "filosovietici": "filosovietic",
    "filosovieticii": "filosovietic",
    "filosovieticilor": "filosovietic",
    "filosovietico": "filosovietic",
    "filosovieticul": "filosovietic",
    "filosovieticule": "filosovietic",
    "filosovieticului": "filosovietic",
    "filozoafa": "filozoafă",
    "filozoafe": "filozoafă",
    "filozoafei": "filozoafă",
    "filozoafele": "filozoafă",
    "filozoafelor": "filozoafă",
    "filozofi": "filozof",
    "filozofii": "filozof",
    "filozofilor": "filozof",
    "filozoful": "filozof",
    "filozofului": "filozof",
    "filozofă": "filozofa",
    "filozofai": "filozofa",
    "filozofam": "filozofa",
    "filozofăm": "filozofa",
    "filozofând": "filozofa",
    "filozofându": "filozofa",
    "filozofară": "filozofa",
    "filozofarăm": "filozofa",
    "filozofarăți": "filozofa",
    "filozofase": "filozofa",
    "filozofasem": "filozofa",
    "filozofaseră": "filozofa",
    "filozofaserăm": "filozofa",
    "filozofaserăți": "filozofa",
    "filozofaseși": "filozofa",
    "filozofași": "filozofa",
    "filozofat": "filozofa",
    "filozofați": "filozofa",
    "filozofatu": "filozofa",
    "filozofau": "filozofa",
    "filozofează": "filozofa",
    "filozofez": "filozofa",
    "filozofeze": "filozofa",
    "filozofezi": "filozofa",
    "nefilozofând": "filozofa",
    "nefilozofându": "filozofa",
    "nemaifilozofând": "filozofa",
    "nemaifilozofându": "filozofa",
    "filozofată": "filozofat",
    "filozofate": "filozofat",
    "filozofați": "filozofat",
    "filozofica": "filozofic",
    "filozofică": "filozofic",
    "filozofice": "filozofic",
    "filozoficei": "filozofic",
    "filozoficele": "filozofic",
    "filozoficelor": "filozofic",
    "filozofici": "filozofic",
    "filozoficii": "filozofic",
    "filozoficilor": "filozofic",
    "filozoficul": "filozofic",
    "filozoficului": "filozofic",
    "filozofia": "filozofie",
    "filozofiei": "filozofie",
    "filozofii": "filozofie",
    "filtră": "filtra",
    "filtrai": "filtra",
    "filtram": "filtra",
    "filtrăm": "filtra",
    "filtrând": "filtra",
    "filtrându": "filtra",
    "filtrară": "filtra",
    "filtrarăm": "filtra",
    "filtrarăți": "filtra",
    "filtrase": "filtra",
    "filtrasem": "filtra",
    "filtraseră": "filtra",
    "filtraserăm": "filtra",
    "filtraserăți": "filtra",
    "filtraseși": "filtra",
    "filtrași": "filtra",
    "filtrat": "filtra",
    "filtrați": "filtra",
    "filtratu": "filtra",
    "filtrau": "filtra",
    "filtrează": "filtra",
    "filtrez": "filtra",
    "filtreze": "filtra",
    "filtrezi": "filtra",
    "nefiltrând": "filtra",
    "nefiltrându": "filtra",
    "nemaifiltrând": "filtra",
    "nemaifiltrându": "filtra",
    "filtrarea": "filtrare",
    "filtrări": "filtrare",
    "filtrării": "filtrare",
    "filtrările": "filtrare",
    "filtrărilor": "filtrare",
    "filtrată": "filtrat",
    "filtrate": "filtrat",
    "filtrați": "filtrat",
    "filtre": "filtru",
    "filtrele": "filtru",
    "filtrelor": "filtru",
    "filtrul": "filtru",
    "filtrului": "filtru",
    "fina": "fin",
    "fină": "fin",
    "fine": "fin",
    "finei": "fin",
    "finele": "fin",
    "finelor": "fin",
    "fini": "fin",
    "finii": "fin",
    "finilor": "fin",
    "finul": "fin",
    "finului": "fin",
    "fina": "fină",
    "fine": "fină",
    "finei": "fină",
    "finele": "fină",
    "finelor": "fină",
    "finala": "final",
    "finală": "final",
    "finale": "final",
    "finalei": "final",
    "finalele": "final",
    "finalelor": "final",
    "finali": "final",
    "finalii": "final",
    "finalilor": "final",
    "finalul": "final",
    "finalului": "final",
    "finala": "finală",
    "finale": "finală",
    "finalei": "finală",
    "finalele": "finală",
    "finalelor": "finală",
    "finaliști": "finalist",
    "finaliștii": "finalist",
    "finaliștilor": "finalist",
    "finalistul": "finalist",
    "finalistului": "finalist",
    "finalitatea": "finalitate",
    "finalități": "finalitate",
    "finalității": "finalitate",
    "finalitățile": "finalitate",
    "finalităților": "finalitate",
    "finaliză": "finaliza",
    "finalizai": "finaliza",
    "finalizam": "finaliza",
    "finalizăm": "finaliza",
    "finalizând": "finaliza",
    "finalizându": "finaliza",
    "finalizară": "finaliza",
    "finalizarăm": "finaliza",
    "finalizarăți": "finaliza",
    "finalizase": "finaliza",
    "finalizasem": "finaliza",
    "finalizaseră": "finaliza",
    "finalizaserăm": "finaliza",
    "finalizaserăți": "finaliza",
    "finalizaseși": "finaliza",
    "finalizași": "finaliza",
    "finalizat": "finaliza",
    "finalizați": "finaliza",
    "finalizatu": "finaliza",
    "finalizau": "finaliza",
    "finalizează": "finaliza",
    "finalizez": "finaliza",
    "finalizeze": "finaliza",
    "finalizezi": "finaliza",
    "nefinalizând": "finaliza",
    "nefinalizându": "finaliza",
    "nemaifinalizând": "finaliza",
    "nemaifinalizându": "finaliza",
    "finalizarea": "finalizare",
    "finalizareo": "finalizare",
    "finalizări": "finalizare",
    "finalizării": "finalizare",
    "finalizările": "finalizare",
    "finalizărilor": "finalizare",
    "finalizată": "finalizat",
    "finalizate": "finalizat",
    "finalizați": "finalizat",
    "financiara": "financiar",
    "financiară": "financiar",
    "financiare": "financiar",
    "financiarei": "financiar",
    "financiarele": "financiar",
    "financiarelor": "financiar",
    "financiari": "financiar",
    "financiarii": "financiar",
    "financiarilor": "financiar",
    "financiarul": "financiar",
    "financiarului": "financiar",
    "financiar-bancare": "financiar-bancar",
    "finanță": "finanța",
    "finanțai": "finanța",
    "finanțam": "finanța",
    "finanțăm": "finanța",
    "finanțând": "finanța",
    "finanțându": "finanța",
    "finanțară": "finanța",
    "finanțarăm": "finanța",
    "finanțarăți": "finanța",
    "finanțase": "finanța",
    "finanțasem": "finanța",
    "finanțaseră": "finanța",
    "finanțaserăm": "finanța",
    "finanțaserăți": "finanța",
    "finanțaseși": "finanța",
    "finanțași": "finanța",
    "finanțat": "finanța",
    "finanțați": "finanța",
    "finanțatu": "finanța",
    "finanțau": "finanța",
    "finanțează": "finanța",
    "finanțez": "finanța",
    "finanțeze": "finanța",
    "finanțezi": "finanța",
    "nefinanțând": "finanța",
    "nefinanțându": "finanța",
    "nemaifinanțând": "finanța",
    "nemaifinanțându": "finanța",
    "finanțarea": "finanțare",
    "finanțareo": "finanțare",
    "finanțări": "finanțare",
    "finanțării": "finanțare",
    "finanțările": "finanțare",
    "finanțărilor": "finanțare",
    "finanțată": "finanțat",
    "finanțate": "finanțat",
    "finanțați": "finanțat",
    "fin.": "finanțe",
    "finanțele": "finanțe",
    "finanțelor": "finanțe",
    "finele": "fine",
    "finelui": "fine",
    "finetul": "finet",
    "finetului": "finet",
    "fineturi": "finet",
    "fineturile": "finet",
    "fineturilor": "finet",
    "finețea": "finețe",
    "fineți": "finețe",
    "fineții": "finețe",
    "finețuri": "finețe",
    "finețurile": "finețe",
    "finețurilor": "finețe",
    "finea": "fini",
    "fineai": "fini",
    "fineam": "fini",
    "finească": "fini",
    "fineați": "fini",
    "fineau": "fini",
    "finesc": "fini",
    "finește": "fini",
    "finești": "fini",
    "finii": "fini",
    "finim": "fini",
    "finind": "fini",
    "finindu": "fini",
    "finiră": "fini",
    "finirăm": "fini",
    "finirăți": "fini",
    "finise": "fini",
    "finisem": "fini",
    "finiseră": "fini",
    "finiserăm": "fini",
    "finiserăți": "fini",
    "finiseși": "fini",
    "finiși": "fini",
    "finit": "fini",
    "finiți": "fini",
    "finitu": "fini",
    "nefinind": "fini",
    "nefinindu": "fini",
    "nemaifinind": "fini",
    "nemaifinindu": "fini",
    "finisă": "finisa",
    "finisai": "finisa",
    "finisam": "finisa",
    "finisăm": "finisa",
    "finisând": "finisa",
    "finisându": "finisa",
    "finisară": "finisa",
    "finisarăm": "finisa",
    "finisarăți": "finisa",
    "finisase": "finisa",
    "finisasem": "finisa",
    "finisaseră": "finisa",
    "finisaserăm": "finisa",
    "finisaserăți": "finisa",
    "finisaseși": "finisa",
    "finisași": "finisa",
    "finisat": "finisa",
    "finisați": "finisa",
    "finisatu": "finisa",
    "finisau": "finisa",
    "finisează": "finisa",
    "finisez": "finisa",
    "finiseze": "finisa",
    "finisezi": "finisa",
    "nefinisând": "finisa",
    "nefinisându": "finisa",
    "nemaifinisând": "finisa",
    "nemaifinisându": "finisa",
    "finisaje": "finisaj",
    "finisarea": "finisare",
    "finisări": "finisare",
    "finisării": "finisare",
    "finisările": "finisare",
    "finisărilor": "finisare",
    "finisată": "finisat",
    "finisate": "finisat",
    "finisați": "finisat",
    "finita": "finit",
    "finită": "finit",
    "finite": "finit",
    "finitei": "finit",
    "finitele": "finit",
    "finitelor": "finit",
    "finiți": "finit",
    "finiții": "finit",
    "finiților": "finit",
    "finitul": "finit",
    "finitului": "finit",
    "Finlandă": "Finlanda",
    "Finlandei": "Finlanda",
    "finlandeza": "finlandez",
    "finlandeză": "finlandez",
    "finlandeze": "finlandez",
    "finlandezei": "finlandez",
    "finlandezele": "finlandez",
    "finlandezelor": "finlandez",
    "finlandezi": "finlandez",
    "finlandezii": "finlandez",
    "finlandezilor": "finlandez",
    "finlandezul": "finlandez",
    "finlandezului": "finlandez",
    "finlandeza": "finlandeză",
    "finlandeze": "finlandeză",
    "finlandezei": "finlandeză",
    "finlandezele": "finlandeză",
    "finlandezelor": "finlandeză",
    "fiola": "fiolă",
    "fiole": "fiolă",
    "fiolei": "fiolă",
    "fiolele": "fiolă",
    "fiolelor": "fiolă",
    "fiori": "fior",
    "fiorii": "fior",
    "fiorilor": "fior",
    "fiorul": "fior",
    "fiorului": "fior",
    "fiordul": "fiord",
    "fiordului": "fiord",
    "fiorduri": "fiord",
    "fiordurile": "fiord",
    "fiordurilor": "fiord",
    "fioroasa": "fioros",
    "fioroasă": "fioros",
    "fioroase": "fioros",
    "fioroasei": "fioros",
    "fioroasele": "fioros",
    "fioroaselor": "fioros",
    "fioroși": "fioros",
    "fioroșii": "fioros",
    "fioroșilor": "fioros",
    "fiorosul": "fioros",
    "fiorosului": "fioros",
    "fire": "fir",
    "firele": "fir",
    "firelor": "fir",
    "firul": "fir",
    "firului": "fir",
    "firava": "firav",
    "firavă": "firav",
    "firave": "firav",
    "firavei": "firav",
    "firavele": "firav",
    "firavelor": "firav",
    "firavi": "firav",
    "firavii": "firav",
    "firavilor": "firav",
    "firavul": "firav",
    "firavului": "firav",
    "firea": "fire",
    "firi": "fire",
    "firii": "fire",
    "firile": "fire",
    "firilor": "fire",
    "fireasca": "firesc",
    "firească": "firesc",
    "firescul": "firesc",
    "firescului": "firesc",
    "firești": "firesc",
    "fireștii": "firesc",
    "fireștile": "firesc",
    "fireștilor": "firesc",
    "firetul": "firet",
    "firetului": "firet",
    "fireturi": "firet",
    "fireturile": "firet",
    "fireturilor": "firet",
    "firida": "firidă",
    "firide": "firidă",
    "firidei": "firidă",
    "firidele": "firidă",
    "firidelor": "firidă",
    "firido": "firidă",
    "firimitura": "firimitură",
    "firimituri": "firimitură",
    "firimiturii": "firimitură",
    "firimiturile": "firimitură",
    "firimiturilor": "firimitură",
    "firma": "firmă",
    "firme": "firmă",
    "firmei": "firmă",
    "firmele": "firmă",
    "firmelor": "firmă",
    "firmamente": "firmament",
    "firmamentele": "firmament",
    "firmamentelor": "firmament",
    "firmamentul": "firmament",
    "firmamentului": "firmament",
    "firoscoasa": "firoscos",
    "firoscoasă": "firoscos",
    "firoscoase": "firoscos",
    "firoscoasei": "firoscos",
    "firoscoasele": "firoscos",
    "firoscoaselor": "firoscos",
    "firoscoaso": "firoscos",
    "firoscoși": "firoscos",
    "firoscoșii": "firoscos",
    "firoscoșilor": "firoscos",
    "firoscosul": "firoscos",
    "firoscosule": "firoscos",
    "firoscosului": "firoscos",
    "fisa": "fisă",
    "fise": "fisă",
    "fisei": "fisă",
    "fisele": "fisă",
    "fiselor": "fisă",
    "fișă": "fișa",
    "fișai": "fișa",
    "fișam": "fișa",
    "fișăm": "fișa",
    "fișând": "fișa",
    "fișându": "fișa",
    "fișară": "fișa",
    "fișarăm": "fișa",
    "fișarăți": "fișa",
    "fișase": "fișa",
    "fișasem": "fișa",
    "fișaseră": "fișa",
    "fișaserăm": "fișa",
    "fișaserăți": "fișa",
    "fișaseși": "fișa",
    "fișași": "fișa",
    "fișat": "fișa",
    "fișați": "fișa",
    "fișatu": "fișa",
    "fișau": "fișa",
    "fișează": "fișa",
    "fișez": "fișa",
    "fișeze": "fișa",
    "fișezi": "fișa",
    "nefișând": "fișa",
    "nefișându": "fișa",
    "nemaifișând": "fișa",
    "nemaifișându": "fișa",
    "fișa": "fișă",
    "fișe": "fișă",
    "fișei": "fișă",
    "fișele": "fișă",
    "fișelor": "fișă",
    "fișată": "fișat",
    "fișate": "fișat",
    "fișați": "fișat",
    "fiscul": "fisc",
    "fiscului": "fisc",
    "fiscuri": "fisc",
    "fiscurile": "fisc",
    "fiscurilor": "fisc",
    "fiscala": "fiscal",
    "fiscală": "fiscal",
    "fiscale": "fiscal",
    "fiscalei": "fiscal",
    "fiscalele": "fiscal",
    "fiscalelor": "fiscal",
    "fiscali": "fiscal",
    "fiscalii": "fiscal",
    "fiscalilor": "fiscal",
    "fiscalul": "fiscal",
    "fiscalului": "fiscal",
    "fiscalitatea": "fiscalitate",
    "fiscalități": "fiscalitate",
    "fiscalității": "fiscalitate",
    "fiscalitățile": "fiscalitate",
    "fiscalităților": "fiscalitate",
    "fișete": "fișet",
    "fișetele": "fișet",
    "fișetelor": "fișet",
    "fișetul": "fișet",
    "fișetului": "fișet",
    "fișiere": "fișier",
    "fișierele": "fișier",
    "fișierelor": "fișier",
    "fișierul": "fișier",
    "fișierului": "fișier",
    "fisionă": "fisiona",
    "fisionai": "fisiona",
    "fisionam": "fisiona",
    "fisionăm": "fisiona",
    "fisionând": "fisiona",
    "fisionându": "fisiona",
    "fisionară": "fisiona",
    "fisionarăm": "fisiona",
    "fisionarăți": "fisiona",
    "fisionase": "fisiona",
    "fisionasem": "fisiona",
    "fisionaseră": "fisiona",
    "fisionaserăm": "fisiona",
    "fisionaserăți": "fisiona",
    "fisionaseși": "fisiona",
    "fisionași": "fisiona",
    "fisionat": "fisiona",
    "fisionați": "fisiona",
    "fisionatu": "fisiona",
    "fisionau": "fisiona",
    "fisionează": "fisiona",
    "fisionez": "fisiona",
    "fisioneze": "fisiona",
    "fisionezi": "fisiona",
    "nefisionând": "fisiona",
    "nefisionându": "fisiona",
    "nemaifisionând": "fisiona",
    "nemaifisionându": "fisiona",
    "fisionată": "fisionat",
    "fisionate": "fisionat",
    "fisionați": "fisionat",
    "fisiunea": "fisiune",
    "fisiuni": "fisiune",
    "fisiunii": "fisiune",
    "fisiunile": "fisiune",
    "fisiunilor": "fisiune",
    "fisură": "fisura",
    "fisurai": "fisura",
    "fisuram": "fisura",
    "fisurăm": "fisura",
    "fisurând": "fisura",
    "fisurându": "fisura",
    "fisurară": "fisura",
    "fisurarăm": "fisura",
    "fisurarăți": "fisura",
    "fisurase": "fisura",
    "fisurasem": "fisura",
    "fisuraseră": "fisura",
    "fisuraserăm": "fisura",
    "fisuraserăți": "fisura",
    "fisuraseși": "fisura",
    "fisurași": "fisura",
    "fisurat": "fisura",
    "fisurați": "fisura",
    "fisuratu": "fisura",
    "fisurau": "fisura",
    "fisurează": "fisura",
    "fisurez": "fisura",
    "fisureze": "fisura",
    "fisurezi": "fisura",
    "nefisurând": "fisura",
    "nefisurându": "fisura",
    "nemaifisurând": "fisura",
    "nemaifisurându": "fisura",
    "fisura": "fisură",
    "fisuri": "fisură",
    "fisurii": "fisură",
    "fisurile": "fisură",
    "fisurilor": "fisură",
    "fisurată": "fisurat",
    "fisurate": "fisurat",
    "fisurați": "fisurat",
    "fița": "fiță",
    "fițe": "fiță",
    "fiței": "fiță",
    "fițele": "fiță",
    "fițelor": "fiță",
    "fițo": "fiță",
    "fitilul": "fitil",
    "fitilului": "fitil",
    "fitiluri": "fitil",
    "fitilurile": "fitil",
    "fitilurilor": "fitil",
    "fituia": "fitui",
    "fituiai": "fitui",
    "fituiam": "fitui",
    "fituiască": "fitui",
    "fituiați": "fitui",
    "fituiau": "fitui",
    "fituiesc": "fitui",
    "fituiește": "fitui",
    "fituiești": "fitui",
    "fituii": "fitui",
    "fituim": "fitui",
    "fituind": "fitui",
    "fituindu": "fitui",
    "fituiră": "fitui",
    "fituirăm": "fitui",
    "fituirăți": "fitui",
    "fituise": "fitui",
    "fituisem": "fitui",
    "fituiseră": "fitui",
    "fituiserăm": "fitui",
    "fituiserăți": "fitui",
    "fituiseși": "fitui",
    "fituiși": "fitui",
    "fituit": "fitui",
    "fituiți": "fitui",
    "fituitu": "fitui",
    "nefituind": "fitui",
    "nefituindu": "fitui",
    "nemaifituind": "fitui",
    "nemaifituindu": "fitui",
    "fițuica": "fițuică",
    "fițuici": "fițuică",
    "fițuicii": "fițuică",
    "fițuicile": "fițuică",
    "fițuicilor": "fițuică",
    "fituită": "fituit",
    "fituite": "fituit",
    "fituiți": "fituit",
    "fii": "fiu",
    "fii-": "fiu",
    "fiii": "fiu",
    "fiilor": "fiu",
    "fiul": "fiu",
    "fiului": "fiu",
    "ficș": "fix",
    "ficși": "fix",
    "ficșii": "fix",
    "ficșilor": "fix",
    "ficșul": "fix",
    "ficșului": "fix",
    "fixa": "fix",
    "fixă": "fix",
    "fixe": "fix",
    "fixei": "fix",
    "fixele": "fix",
    "fixelor": "fix",
    "fixul": "fix",
    "fixului": "fix",
    "fixă": "fixa",
    "fixai": "fixa",
    "fixam": "fixa",
    "fixăm": "fixa",
    "fixând": "fixa",
    "fixându": "fixa",
    "fixară": "fixa",
    "fixarăm": "fixa",
    "fixarăți": "fixa",
    "fixase": "fixa",
    "fixasem": "fixa",
    "fixaseră": "fixa",
    "fixaserăm": "fixa",
    "fixaserăți": "fixa",
    "fixaseși": "fixa",
    "fixași": "fixa",
    "fixat": "fixa",
    "fixați": "fixa",
    "fixatu": "fixa",
    "fixau": "fixa",
    "fixează": "fixa",
    "fixez": "fixa",
    "fixeze": "fixa",
    "fixezi": "fixa",
    "nefixând": "fixa",
    "nefixându": "fixa",
    "nemaifixând": "fixa",
    "nemaifixându": "fixa",
    "fixată": "fixat",
    "fixate": "fixat",
    "fixați": "fixat",
    "fizica": "fizic",
    "fizică": "fizic",
    "fizice": "fizic",
    "fizicei": "fizic",
    "fizicele": "fizic",
    "fizicelor": "fizic",
    "fizici": "fizic",
    "fizicii": "fizic",
    "fizicilor": "fizic",
    "fizicul": "fizic",
    "fizicului": "fizic",
    "fizicuri": "fizic",
    "fizicurile": "fizic",
    "fizicurilor": "fizic",
    "fiz.": "fizică",
    "fizica": "fizică",
    "fizicele": "fizică",
    "fizicelor": "fizică",
    "fizici": "fizică",
    "fizicii": "fizică",
    "fizicianul": "fizician",
    "fizicianului": "fizician",
    "fizicieni": "fizician",
    "fizicienii": "fizician",
    "fizicienilor": "fizician",
    "fiziciana": "fiziciană",
    "fiziciene": "fiziciană",
    "fizicienei": "fiziciană",
    "fizicienele": "fiziciană",
    "fizicienelor": "fiziciană",
    "fiziognomonica": "fiziognomonic",
    "fiziognomonică": "fiziognomonic",
    "fiziognomonice": "fiziognomonic",
    "fiziognomonicei": "fiziognomonic",
    "fiziognomonicele": "fiziognomonic",
    "fiziognomonicelor": "fiziognomonic",
    "fiziognomonici": "fiziognomonic",
    "fiziognomonicii": "fiziognomonic",
    "fiziognomonicilor": "fiziognomonic",
    "fiziognomonico": "fiziognomonic",
    "fiziognomonicul": "fiziognomonic",
    "fiziognomonicule": "fiziognomonic",
    "fiziognomonicului": "fiziognomonic",
    "fiziologica": "fiziologic",
    "fiziologică": "fiziologic",
    "fiziologice": "fiziologic",
    "fiziologicei": "fiziologic",
    "fiziologicele": "fiziologic",
    "fiziologicelor": "fiziologic",
    "fiziologici": "fiziologic",
    "fiziologicii": "fiziologic",
    "fiziologicilor": "fiziologic",
    "fiziologicul": "fiziologic",
    "fiziologicului": "fiziologic",
    "fiziologia": "fiziologie",
    "fiziologiei": "fiziologie",
    "fiziologii": "fiziologie",
    "fizionomia": "fizionomie",
    "fizionomiei": "fizionomie",
    "fizionomii": "fizionomie",
    "flăcăia": "flăcăi",
    "flăcăiai": "flăcăi",
    "flăcăiam": "flăcăi",
    "flăcăiască": "flăcăi",
    "flăcăiați": "flăcăi",
    "flăcăiau": "flăcăi",
    "flăcăiesc": "flăcăi",
    "flăcăiește": "flăcăi",
    "flăcăiești": "flăcăi",
    "flăcăii": "flăcăi",
    "flăcăim": "flăcăi",
    "flăcăind": "flăcăi",
    "flăcăindu": "flăcăi",
    "flăcăiră": "flăcăi",
    "flăcăirăm": "flăcăi",
    "flăcăirăți": "flăcăi",
    "flăcăise": "flăcăi",
    "flăcăisem": "flăcăi",
    "flăcăiseră": "flăcăi",
    "flăcăiserăm": "flăcăi",
    "flăcăiserăți": "flăcăi",
    "flăcăiseși": "flăcăi",
    "flăcăiși": "flăcăi",
    "flăcăit": "flăcăi",
    "flăcăiți": "flăcăi",
    "flăcăitu": "flăcăi",
    "neflăcăind": "flăcăi",
    "neflăcăindu": "flăcăi",
    "nemaiflăcăind": "flăcăi",
    "nemaiflăcăindu": "flăcăi",
    "flăcăiandri": "flăcăiandru",
    "flăcăiandrii": "flăcăiandru",
    "flăcăiandrilor": "flăcăiandru",
    "flăcăiandrul": "flăcăiandru",
    "flăcăiandrule": "flăcăiandru",
    "flăcăiandrului": "flăcăiandru",
    "flăcăiași": "flăcăiaș",
    "flăcăiașii": "flăcăiaș",
    "flăcăiașilor": "flăcăiaș",
    "flăcăiașul": "flăcăiaș",
    "flăcăiașule": "flăcăiaș",
    "flăcăiașului": "flăcăiaș",
    "flăcăită": "flăcăit",
    "flăcăite": "flăcăit",
    "flăcăiți": "flăcăit",
    "flacăra": "flacără",
    "flăcări": "flacără",
    "flăcării": "flacără",
    "flăcările": "flacără",
    "flăcărilor": "flacără",
    "flăcărui": "flăcăruie",
    "flăcăruia": "flăcăruie",
    "flăcăruii": "flăcăruie",
    "flăcăruile": "flăcăruie",
    "flăcăruilor": "flăcăruie",
    "flăcăruio": "flăcăruie",
    "flăcăi": "flăcău",
    "flăcăii": "flăcău",
    "flăcăilor": "flăcău",
    "flăcăul": "flăcău",
    "flăcăului": "flăcău",
    "flacoane": "flacon",
    "flacoanele": "flacon",
    "flacoanelor": "flacon",
    "flaconul": "flacon",
    "flaconului": "flacon",
    "flagelul": "flagel",
    "flagelului": "flagel",
    "flageluri": "flagel",
    "flagelurile": "flagel",
    "flagelurilor": "flagel",
    "flagelă": "flagela",
    "flagelai": "flagela",
    "flagelam": "flagela",
    "flagelăm": "flagela",
    "flagelând": "flagela",
    "flagelându": "flagela",
    "flagelară": "flagela",
    "flagelarăm": "flagela",
    "flagelarăți": "flagela",
    "flagelase": "flagela",
    "flagelasem": "flagela",
    "flagelaseră": "flagela",
    "flagelaserăm": "flagela",
    "flagelaserăți": "flagela",
    "flagelaseși": "flagela",
    "flagelași": "flagela",
    "flagelat": "flagela",
    "flagelați": "flagela",
    "flagelatu": "flagela",
    "flagelau": "flagela",
    "flagelează": "flagela",
    "flagelez": "flagela",
    "flageleze": "flagela",
    "flagelezi": "flagela",
    "neflagelând": "flagela",
    "neflagelându": "flagela",
    "nemaiflagelând": "flagela",
    "nemaiflagelându": "flagela",
    "flagelarea": "flagelare",
    "flagelări": "flagelare",
    "flagelării": "flagelare",
    "flagelările": "flagelare",
    "flagelărilor": "flagelare",
    "flagelată": "flagelat",
    "flagelate": "flagelat",
    "flagelați": "flagelat",
    "flagranta": "flagrant",
    "flagrantă": "flagrant",
    "flagrante": "flagrant",
    "flagrantei": "flagrant",
    "flagrantele": "flagrant",
    "flagrantelor": "flagrant",
    "flagranți": "flagrant",
    "flagranții": "flagrant",
    "flagranților": "flagrant",
    "flagrantul": "flagrant",
    "flagrantului": "flagrant",
    "flama": "flamă",
    "flame": "flamă",
    "flamei": "flamă",
    "flamele": "flamă",
    "flamelor": "flamă",
    "flamanda": "flamand",
    "flamandă": "flamand",
    "flamande": "flamand",
    "flamandei": "flamand",
    "flamandele": "flamand",
    "flamandelor": "flamand",
    "flamandul": "flamand",
    "flamandului": "flamand",
    "flamanzi": "flamand",
    "flamanzii": "flamand",
    "flamanzilor": "flamand",
    "flămânda": "flămând",
    "flămândă": "flămând",
    "flămânde": "flămând",
    "flămândei": "flămând",
    "flămândele": "flămând",
    "flămândelor": "flămând",
    "flămândul": "flămând",
    "flămândului": "flămând",
    "flămânzi": "flămând",
    "flămânzii": "flămând",
    "flămânzilor": "flămând",
    "flamanda": "flamandă",
    "flamande": "flamandă",
    "flamandei": "flamandă",
    "flamandele": "flamandă",
    "flamandelor": "flamandă",
    "flămânzea": "flămânzi",
    "flămânzeai": "flămânzi",
    "flămânzeam": "flămânzi",
    "flămânzească": "flămânzi",
    "flămânzeați": "flămânzi",
    "flămânzeau": "flămânzi",
    "flămânzesc": "flămânzi",
    "flămânzește": "flămânzi",
    "flămânzești": "flămânzi",
    "flămânzii": "flămânzi",
    "flămânzim": "flămânzi",
    "flămânzind": "flămânzi",
    "flămânzindu": "flămânzi",
    "flămânziră": "flămânzi",
    "flămânzirăm": "flămânzi",
    "flămânzirăți": "flămânzi",
    "flămânzise": "flămânzi",
    "flămânzisem": "flămânzi",
    "flămânziseră": "flămânzi",
    "flămânziserăm": "flămânzi",
    "flămânziserăți": "flămânzi",
    "flămânziseși": "flămânzi",
    "flămânziși": "flămânzi",
    "flămânzit": "flămânzi",
    "flămânziți": "flămânzi",
    "flămânzitu": "flămânzi",
    "neflămânzind": "flămânzi",
    "neflămânzindu": "flămânzi",
    "nemaiflămânzind": "flămânzi",
    "nemaiflămânzindu": "flămânzi",
    "flămânzita": "flămânzit",
    "flămânzită": "flămânzit",
    "flămânzite": "flămânzit",
    "flămânzitei": "flămânzit",
    "flămânzitele": "flămânzit",
    "flămânzitelor": "flămânzit",
    "flămânziți": "flămânzit",
    "flămânziții": "flămânzit",
    "flămânziților": "flămânzit",
    "flămânzito": "flămânzit",
    "flămânzitul": "flămânzit",
    "flămânzitule": "flămânzit",
    "flămânzitului": "flămânzit",
    "flambă": "flamba",
    "flambai": "flamba",
    "flambam": "flamba",
    "flambăm": "flamba",
    "flambând": "flamba",
    "flambându": "flamba",
    "flambară": "flamba",
    "flambarăm": "flamba",
    "flambarăți": "flamba",
    "flambase": "flamba",
    "flambasem": "flamba",
    "flambaseră": "flamba",
    "flambaserăm": "flamba",
    "flambaserăți": "flamba",
    "flambaseși": "flamba",
    "flambași": "flamba",
    "flambat": "flamba",
    "flambați": "flamba",
    "flambatu": "flamba",
    "flambau": "flamba",
    "flambează": "flamba",
    "flambez": "flamba",
    "flambeze": "flamba",
    "flambezi": "flamba",
    "neflambând": "flamba",
    "neflambându": "flamba",
    "nemaiflambând": "flamba",
    "nemaiflambându": "flamba",
    "flambată": "flambat",
    "flambate": "flambat",
    "flambați": "flambat",
    "flamura": "flamură",
    "flamuri": "flamură",
    "flamurii": "flamură",
    "flamurile": "flamură",
    "flamurilor": "flamură",
    "flană": "flana",
    "flanai": "flana",
    "flanam": "flana",
    "flanăm": "flana",
    "flanând": "flana",
    "flanându": "flana",
    "flanară": "flana",
    "flanarăm": "flana",
    "flanarăți": "flana",
    "flanase": "flana",
    "flanasem": "flana",
    "flanaseră": "flana",
    "flanaserăm": "flana",
    "flanaserăți": "flana",
    "flanaseși": "flana",
    "flanași": "flana",
    "flanat": "flana",
    "flanați": "flana",
    "flanatu": "flana",
    "flanau": "flana",
    "flanează": "flana",
    "flanez": "flana",
    "flaneze": "flana",
    "flanezi": "flana",
    "neflanând": "flana",
    "neflanându": "flana",
    "nemaiflanând": "flana",
    "nemaiflanându": "flana",
    "flanată": "flanat",
    "flanate": "flanat",
    "flanați": "flanat",
    "flancul": "flanc",
    "flancului": "flanc",
    "flancuri": "flanc",
    "flancurile": "flanc",
    "flancurilor": "flanc",
    "flancă": "flanca",
    "flancai": "flanca",
    "flancam": "flanca",
    "flancăm": "flanca",
    "flancând": "flanca",
    "flancându": "flanca",
    "flancară": "flanca",
    "flancarăm": "flanca",
    "flancarăți": "flanca",
    "flancase": "flanca",
    "flancasem": "flanca",
    "flancaseră": "flanca",
    "flancaserăm": "flanca",
    "flancaserăți": "flanca",
    "flancaseși": "flanca",
    "flancași": "flanca",
    "flancat": "flanca",
    "flancați": "flanca",
    "flancatu": "flanca",
    "flancau": "flanca",
    "flanceze": "flanca",
    "flanchează": "flanca",
    "flanchez": "flanca",
    "flanchezi": "flanca",
    "neflancând": "flanca",
    "neflancându": "flanca",
    "nemaiflancând": "flanca",
    "nemaiflancându": "flanca",
    "flancată": "flancat",
    "flancate": "flancat",
    "flancați": "flancat",
    "flanela": "flanelă",
    "flanele": "flanelă",
    "flanelei": "flanelă",
    "flanelele": "flanelă",
    "flanelelor": "flanelă",
    "flasca": "flasc",
    "flască": "flasc",
    "flasce": "flasc",
    "flascei": "flasc",
    "flascele": "flasc",
    "flascelor": "flasc",
    "flasci": "flasc",
    "flascii": "flasc",
    "flascilor": "flasc",
    "flascul": "flasc",
    "flascului": "flasc",
    "flașneta": "flașnetă",
    "flașnete": "flașnetă",
    "flașnetei": "flașnetă",
    "flașnetele": "flașnetă",
    "flașnetelor": "flașnetă",
    "flată": "flata",
    "flatai": "flata",
    "flatam": "flata",
    "flatăm": "flata",
    "flatând": "flata",
    "flatându": "flata",
    "flatară": "flata",
    "flatarăm": "flata",
    "flatarăți": "flata",
    "flatase": "flata",
    "flatasem": "flata",
    "flataseră": "flata",
    "flataserăm": "flata",
    "flataserăți": "flata",
    "flataseși": "flata",
    "flatași": "flata",
    "flatat": "flata",
    "flatați": "flata",
    "flatatu": "flata",
    "flatau": "flata",
    "flatează": "flata",
    "flatez": "flata",
    "flateze": "flata",
    "flatezi": "flata",
    "neflatând": "flata",
    "neflatându": "flata",
    "nemaiflatând": "flata",
    "nemaiflatându": "flata",
    "flatanta": "flatant",
    "flatantă": "flatant",
    "flatante": "flatant",
    "flatantei": "flatant",
    "flatantele": "flatant",
    "flatantelor": "flatant",
    "flatanți": "flatant",
    "flatanții": "flatant",
    "flatanților": "flatant",
    "flatanto": "flatant",
    "flatantul": "flatant",
    "flatantule": "flatant",
    "flatantului": "flatant",
    "flatarea": "flatare",
    "flatareo": "flatare",
    "flatări": "flatare",
    "flatării": "flatare",
    "flatările": "flatare",
    "flatărilor": "flatare",
    "flatată": "flatat",
    "flatate": "flatat",
    "flatați": "flatat",
    "flaute": "flaut",
    "flautele": "flaut",
    "flautelor": "flaut",
    "flautul": "flaut",
    "flautului": "flaut",
    "flautiști": "flautist",
    "flautiștii": "flautist",
    "flautiștilor": "flautist",
    "flautistul": "flautist",
    "flautistului": "flautist",
    "fleacul": "fleac",
    "fleacului": "fleac",
    "fleacuri": "fleac",
    "fleacurile": "fleac",
    "fleacurilor": "fleac",
    "fleanca": "fleancă",
    "flecul": "flec",
    "flecului": "flec",
    "flecuri": "flec",
    "flecurile": "flec",
    "flecurilor": "flec",
    "flecara": "flecar",
    "flecară": "flecar",
    "flecare": "flecar",
    "flecarei": "flecar",
    "flecarele": "flecar",
    "flecarelor": "flecar",
    "flecari": "flecar",
    "flecarii": "flecar",
    "flecarilor": "flecar",
    "flecarul": "flecar",
    "flecarului": "flecar",
    "flecăreala": "flecăreală",
    "flecăreli": "flecăreală",
    "flecărelii": "flecăreală",
    "flecărelile": "flecăreală",
    "flecărelilor": "flecăreală",
    "flecărea": "flecări",
    "flecăreai": "flecări",
    "flecăream": "flecări",
    "flecărească": "flecări",
    "flecăreați": "flecări",
    "flecăreau": "flecări",
    "flecăresc": "flecări",
    "flecărește": "flecări",
    "flecărești": "flecări",
    "flecării": "flecări",
    "flecărim": "flecări",
    "flecărind": "flecări",
    "flecărindu": "flecări",
    "flecăriră": "flecări",
    "flecărirăm": "flecări",
    "flecărirăți": "flecări",
    "flecărise": "flecări",
    "flecărisem": "flecări",
    "flecăriseră": "flecări",
    "flecăriserăm": "flecări",
    "flecăriserăți": "flecări",
    "flecăriseși": "flecări",
    "flecăriși": "flecări",
    "flecărit": "flecări",
    "flecăriți": "flecări",
    "flecăritu": "flecări",
    "neflecărind": "flecări",
    "neflecărindu": "flecări",
    "nemaiflecărind": "flecări",
    "nemaiflecărindu": "flecări",
    "flecărită": "flecărit",
    "flecărite": "flecărit",
    "flecăriți": "flecărit",
    "flecuia": "flecui",
    "flecuiai": "flecui",
    "flecuiam": "flecui",
    "flecuiască": "flecui",
    "flecuiați": "flecui",
    "flecuiau": "flecui",
    "flecuiesc": "flecui",
    "flecuiește": "flecui",
    "flecuiești": "flecui",
    "flecuii": "flecui",
    "flecuim": "flecui",
    "flecuind": "flecui",
    "flecuindu": "flecui",
    "flecuiră": "flecui",
    "flecuirăm": "flecui",
    "flecuirăți": "flecui",
    "flecuise": "flecui",
    "flecuisem": "flecui",
    "flecuiseră": "flecui",
    "flecuiserăm": "flecui",
    "flecuiserăți": "flecui",
    "flecuiseși": "flecui",
    "flecuiși": "flecui",
    "flecuit": "flecui",
    "flecuiți": "flecui",
    "flecuitu": "flecui",
    "neflecuind": "flecui",
    "neflecuindu": "flecui",
    "nemaiflecuind": "flecui",
    "nemaiflecuindu": "flecui",
    "flecuită": "flecuit",
    "flecuite": "flecuit",
    "flecuiți": "flecuit",
    "flecuștețe": "flecușteț",
    "flecuștețele": "flecușteț",
    "flecuștețelor": "flecușteț",
    "flecuștețul": "flecușteț",
    "flecuștețului": "flecușteț",
    "flegma": "flegmă",
    "flegme": "flegmă",
    "flegmei": "flegmă",
    "flegmele": "flegmă",
    "flegmelor": "flegmă",
    "flegmatica": "flegmatic",
    "flegmatică": "flegmatic",
    "flegmatice": "flegmatic",
    "flegmaticei": "flegmatic",
    "flegmaticele": "flegmatic",
    "flegmaticelor": "flegmatic",
    "flegmatici": "flegmatic",
    "flegmaticii": "flegmatic",
    "flegmaticilor": "flegmatic",
    "flegmaticul": "flegmatic",
    "flegmaticului": "flegmatic",
    "flencănea": "flencăni",
    "flencăneai": "flencăni",
    "flencăneam": "flencăni",
    "flencănească": "flencăni",
    "flencăneați": "flencăni",
    "flencăneau": "flencăni",
    "flencănesc": "flencăni",
    "flencănește": "flencăni",
    "flencănești": "flencăni",
    "flencănii": "flencăni",
    "flencănim": "flencăni",
    "flencănind": "flencăni",
    "flencănindu": "flencăni",
    "flencăniră": "flencăni",
    "flencănirăm": "flencăni",
    "flencănirăți": "flencăni",
    "flencănise": "flencăni",
    "flencănisem": "flencăni",
    "flencăniseră": "flencăni",
    "flencăniserăm": "flencăni",
    "flencăniserăți": "flencăni",
    "flencăniseși": "flencăni",
    "flencăniși": "flencăni",
    "flencănit": "flencăni",
    "flencăniți": "flencăni",
    "flencănitu": "flencăni",
    "neflencănind": "flencăni",
    "neflencănindu": "flencăni",
    "nemaiflencănind": "flencăni",
    "nemaiflencănindu": "flencăni",
    "flencănită": "flencănit",
    "flencănite": "flencănit",
    "flencăniți": "flencănit",
    "flerul": "fler",
    "flerului": "fler",
    "fleruri": "fler",
    "flerurile": "fler",
    "flerurilor": "fler",
    "fleșcăia": "fleșcăi",
    "fleșcăiai": "fleșcăi",
    "fleșcăiam": "fleșcăi",
    "fleșcăiască": "fleșcăi",
    "fleșcăiați": "fleșcăi",
    "fleșcăiau": "fleșcăi",
    "fleșcăiesc": "fleșcăi",
    "fleșcăiește": "fleșcăi",
    "fleșcăiești": "fleșcăi",
    "fleșcăii": "fleșcăi",
    "fleșcăim": "fleșcăi",
    "fleșcăind": "fleșcăi",
    "fleșcăindu": "fleșcăi",
    "fleșcăiră": "fleșcăi",
    "fleșcăirăm": "fleșcăi",
    "fleșcăirăți": "fleșcăi",
    "fleșcăise": "fleșcăi",
    "fleșcăisem": "fleșcăi",
    "fleșcăiseră": "fleșcăi",
    "fleșcăiserăm": "fleșcăi",
    "fleșcăiserăți": "fleșcăi",
    "fleșcăiseși": "fleșcăi",
    "fleșcăiși": "fleșcăi",
    "fleșcăit": "fleșcăi",
    "fleșcăiți": "fleșcăi",
    "fleșcăitu": "fleșcăi",
    "nefleșcăind": "fleșcăi",
    "nefleșcăindu": "fleșcăi",
    "nemaifleșcăind": "fleșcăi",
    "nemaifleșcăindu": "fleșcăi",
    "fleșcăiala": "fleșcăială",
    "fleșcăialo": "fleșcăială",
    "fleșcăieli": "fleșcăială",
    "fleșcăielii": "fleșcăială",
    "fleșcăielile": "fleșcăială",
    "fleșcăielilor": "fleșcăială",
    "fleșcăita": "fleșcăit",
    "fleșcăită": "fleșcăit",
    "fleșcăite": "fleșcăit",
    "fleșcăitei": "fleșcăit",
    "fleșcăitele": "fleșcăit",
    "fleșcăitelor": "fleșcăit",
    "fleșcăiți": "fleșcăit",
    "fleșcăiții": "fleșcăit",
    "fleșcăiților": "fleșcăit",
    "fleșcăitul": "fleșcăit",
    "fleșcăitului": "fleșcăit",
    "flexibila": "flexibil",
    "flexibilă": "flexibil",
    "flexibile": "flexibil",
    "flexibilei": "flexibil",
    "flexibilele": "flexibil",
    "flexibilelor": "flexibil",
    "flexibili": "flexibil",
    "flexibilii": "flexibil",
    "flexibililor": "flexibil",
    "flexibilul": "flexibil",
    "flexibilului": "flexibil",
    "flexibilitatea": "flexibilitate",
    "flexibilități": "flexibilitate",
    "flexibilității": "flexibilitate",
    "flexibiliză": "flexibiliza",
    "flexibilizai": "flexibiliza",
    "flexibilizam": "flexibiliza",
    "flexibilizăm": "flexibiliza",
    "flexibilizând": "flexibiliza",
    "flexibilizându": "flexibiliza",
    "flexibilizară": "flexibiliza",
    "flexibilizarăm": "flexibiliza",
    "flexibilizarăți": "flexibiliza",
    "flexibilizase": "flexibiliza",
    "flexibilizasem": "flexibiliza",
    "flexibilizaseră": "flexibiliza",
    "flexibilizaserăm": "flexibiliza",
    "flexibilizaserăți": "flexibiliza",
    "flexibilizaseși": "flexibiliza",
    "flexibilizași": "flexibiliza",
    "flexibilizat": "flexibiliza",
    "flexibilizați": "flexibiliza",
    "flexibilizatu": "flexibiliza",
    "flexibilizau": "flexibiliza",
    "flexibilizează": "flexibiliza",
    "flexibilizez": "flexibiliza",
    "flexibilizeze": "flexibiliza",
    "flexibilizezi": "flexibiliza",
    "flexibilizarea": "flexibilizare",
    "flexibilizări": "flexibilizare",
    "flexibilizării": "flexibilizare",
    "flexibilizările": "flexibilizare",
    "flexibilizărilor": "flexibilizare",
    "flexibilizată": "flexibilizat",
    "flexibilizate": "flexibilizat",
    "flexibilizați": "flexibilizat",
    "flexibilizatul": "flexibilizat",
    "flexibilizatului": "flexibilizat",
    "flexionă": "flexiona",
    "flexionai": "flexiona",
    "flexionam": "flexiona",
    "flexionăm": "flexiona",
    "flexionând": "flexiona",
    "flexionându": "flexiona",
    "flexionară": "flexiona",
    "flexionarăm": "flexiona",
    "flexionarăți": "flexiona",
    "flexionase": "flexiona",
    "flexionasem": "flexiona",
    "flexionaseră": "flexiona",
    "flexionaserăm": "flexiona",
    "flexionaserăți": "flexiona",
    "flexionaseși": "flexiona",
    "flexionași": "flexiona",
    "flexionat": "flexiona",
    "flexionați": "flexiona",
    "flexionatu": "flexiona",
    "flexionau": "flexiona",
    "flexionează": "flexiona",
    "flexionez": "flexiona",
    "flexioneze": "flexiona",
    "flexionezi": "flexiona",
    "neflexionând": "flexiona",
    "neflexionându": "flexiona",
    "nemaiflexionând": "flexiona",
    "nemaiflexionându": "flexiona",
    "flexionată": "flexionat",
    "flexionate": "flexionat",
    "flexionați": "flexionat",
    "flexiunea": "flexiune",
    "flexiuni": "flexiune",
    "flexiunii": "flexiune",
    "flexiunile": "flexiune",
    "flexiunilor": "flexiune",
    "flirtă": "flirta",
    "flirtai": "flirta",
    "flirtam": "flirta",
    "flirtăm": "flirta",
    "flirtând": "flirta",
    "flirtându": "flirta",
    "flirtară": "flirta",
    "flirtarăm": "flirta",
    "flirtarăți": "flirta",
    "flirtase": "flirta",
    "flirtasem": "flirta",
    "flirtaseră": "flirta",
    "flirtaserăm": "flirta",
    "flirtaserăți": "flirta",
    "flirtaseși": "flirta",
    "flirtași": "flirta",
    "flirtat": "flirta",
    "flirtați": "flirta",
    "flirtatu": "flirta",
    "flirtau": "flirta",
    "flirtează": "flirta",
    "flirtez": "flirta",
    "flirteze": "flirta",
    "flirtezi": "flirta",
    "neflirtând": "flirta",
    "neflirtându": "flirta",
    "nemaiflirtând": "flirta",
    "nemaiflirtându": "flirta",
    "flirtată": "flirtat",
    "flirtate": "flirtat",
    "flirtați": "flirtat",
    "floarea": "floare",
    "flori": "floare",
    "florii": "floare",
    "florile": "floare",
    "florilor": "floare",
    "Floarei": "Floarea",
    "florii-soarelui": "floarea-soarelui",
    "florile-soarelui": "floarea-soarelui",
    "florilor-soarelui": "floarea-soarelui",
    "floarea-de-colț": "floare-de-colț",
    "flori-de-colț": "floare-de-colț",
    "florii-de-colț": "floare-de-colț",
    "florile-de-colț": "floare-de-colț",
    "florilor-de-colț": "floare-de-colț",
    "florii-de-leac": "floare-de-leac",
    "floarea-domnească": "floare-domnească",
    "flori-domnești": "floare-domnească",
    "florii-domnești": "floare-domnească",
    "florile-domnești": "floare-domnească",
    "florilor-domnești": "floare-domnească",
    "flocăia": "flocăi",
    "flocăiai": "flocăi",
    "flocăiam": "flocăi",
    "flocăiască": "flocăi",
    "flocăiați": "flocăi",
    "flocăiau": "flocăi",
    "flocăiesc": "flocăi",
    "flocăiește": "flocăi",
    "flocăiești": "flocăi",
    "flocăii": "flocăi",
    "flocăim": "flocăi",
    "flocăind": "flocăi",
    "flocăindu": "flocăi",
    "flocăiră": "flocăi",
    "flocăirăm": "flocăi",
    "flocăirăți": "flocăi",
    "flocăise": "flocăi",
    "flocăisem": "flocăi",
    "flocăiseră": "flocăi",
    "flocăiserăm": "flocăi",
    "flocăiserăți": "flocăi",
    "flocăiseși": "flocăi",
    "flocăiși": "flocăi",
    "flocăit": "flocăi",
    "flocăiți": "flocăi",
    "flocăitu": "flocăi",
    "neflocăind": "flocăi",
    "neflocăindu": "flocăi",
    "nemaiflocăind": "flocăi",
    "nemaiflocăindu": "flocăi",
    "flocăită": "flocăit",
    "flocăite": "flocăit",
    "flocăiți": "flocăit",
    "flocoasa": "flocos",
    "flocoasă": "flocos",
    "flocoase": "flocos",
    "flocoasei": "flocos",
    "flocoasele": "flocos",
    "flocoaselor": "flocos",
    "flocoși": "flocos",
    "flocoșii": "flocos",
    "flocoșilor": "flocos",
    "flocosul": "flocos",
    "flocosului": "flocos",
    "flora": "floră",
    "flore": "floră",
    "florei": "floră",
    "florala": "floral",
    "florală": "floral",
    "florale": "floral",
    "floralei": "floral",
    "floralele": "floral",
    "floralelor": "floral",
    "florali": "floral",
    "floralii": "floral",
    "floralilor": "floral",
    "floralo": "floral",
    "floralul": "floral",
    "floralule": "floral",
    "floralului": "floral",
    "florăreasa": "florăreasă",
    "florărese": "florăreasă",
    "florăresei": "florăreasă",
    "florăresele": "florăreasă",
    "florăreselor": "florăreasă",
    "florăria": "florărie",
    "florăriei": "florărie",
    "florării": "florărie",
    "florăriile": "florărie",
    "florăriilor": "florărie",
    "Floricăi": "Florica",
    "Floricii": "Florica",
    "Fla": "Florida",
    "f.": "florin",
    "florini": "florin",
    "florinii": "florin",
    "florinilor": "florin",
    "florinul": "florin",
    "florinului": "florin",
    "flotă": "flota",
    "flotai": "flota",
    "flotam": "flota",
    "flotăm": "flota",
    "flotând": "flota",
    "flotându": "flota",
    "flotară": "flota",
    "flotarăm": "flota",
    "flotarăți": "flota",
    "flotase": "flota",
    "flotasem": "flota",
    "flotaseră": "flota",
    "flotaserăm": "flota",
    "flotaserăți": "flota",
    "flotaseși": "flota",
    "flotași": "flota",
    "flotat": "flota",
    "flotați": "flota",
    "flotatu": "flota",
    "flotau": "flota",
    "flotează": "flota",
    "flotez": "flota",
    "floteze": "flota",
    "flotezi": "flota",
    "neflotând": "flota",
    "neflotându": "flota",
    "nemaiflotând": "flota",
    "nemaiflotându": "flota",
    "flota": "flotă",
    "flote": "flotă",
    "flotei": "flotă",
    "flotele": "flotă",
    "flotelor": "flotă",
    "flotanta": "flotant",
    "flotantă": "flotant",
    "flotante": "flotant",
    "flotantei": "flotant",
    "flotantele": "flotant",
    "flotantelor": "flotant",
    "flotanți": "flotant",
    "flotanții": "flotant",
    "flotanților": "flotant",
    "flotantul": "flotant",
    "flotantului": "flotant",
    "flotată": "flotat",
    "flotate": "flotat",
    "flotați": "flotat",
    "flotila": "flotilă",
    "flotile": "flotilă",
    "flotilei": "flotilă",
    "flotilele": "flotilă",
    "flotilelor": "flotilă",
    "fluctuă": "fluctua",
    "fluctuai": "fluctua",
    "fluctuam": "fluctua",
    "fluctuăm": "fluctua",
    "fluctuând": "fluctua",
    "fluctuându": "fluctua",
    "fluctuară": "fluctua",
    "fluctuarăm": "fluctua",
    "fluctuarăți": "fluctua",
    "fluctuase": "fluctua",
    "fluctuasem": "fluctua",
    "fluctuaseră": "fluctua",
    "fluctuaserăm": "fluctua",
    "fluctuaserăți": "fluctua",
    "fluctuaseși": "fluctua",
    "fluctuași": "fluctua",
    "fluctuat": "fluctua",
    "fluctuați": "fluctua",
    "fluctuatu": "fluctua",
    "fluctuau": "fluctua",
    "fluctuează": "fluctua",
    "fluctuez": "fluctua",
    "fluctueze": "fluctua",
    "fluctuezi": "fluctua",
    "nefluctuând": "fluctua",
    "nefluctuându": "fluctua",
    "nemaifluctuând": "fluctua",
    "nemaifluctuându": "fluctua",
    "fluctuată": "fluctuat",
    "fluctuate": "fluctuat",
    "fluctuați": "fluctuat",
    "fluctuația": "fluctuație",
    "fluctuației": "fluctuație",
    "fluctuații": "fluctuație",
    "fluctuațiile": "fluctuație",
    "fluctuațiilor": "fluctuație",
    "fluenta": "fluent",
    "fluentă": "fluent",
    "fluente": "fluent",
    "fluentei": "fluent",
    "fluentele": "fluent",
    "fluentelor": "fluent",
    "fluenți": "fluent",
    "fluenții": "fluent",
    "fluenților": "fluent",
    "fluentul": "fluent",
    "fluentului": "fluent",
    "fluența": "fluență",
    "fluențe": "fluență",
    "fluenței": "fluență",
    "fluențele": "fluență",
    "fluențelor": "fluență",
    "fluida": "fluid",
    "fluidă": "fluid",
    "fluide": "fluid",
    "fluidei": "fluid",
    "fluidele": "fluid",
    "fluidelor": "fluid",
    "fluidul": "fluid",
    "fluidului": "fluid",
    "fluizi": "fluid",
    "fluizii": "fluid",
    "fluizilor": "fluid",
    "fluidific": "fluidifica",
    "fluidifică": "fluidifica",
    "fluidificai": "fluidifica",
    "fluidificam": "fluidifica",
    "fluidificăm": "fluidifica",
    "fluidificând": "fluidifica",
    "fluidificându": "fluidifica",
    "fluidificară": "fluidifica",
    "fluidificarăm": "fluidifica",
    "fluidificarăți": "fluidifica",
    "fluidificase": "fluidifica",
    "fluidificasem": "fluidifica",
    "fluidificaseră": "fluidifica",
    "fluidificaserăm": "fluidifica",
    "fluidificaserăți": "fluidifica",
    "fluidificaseși": "fluidifica",
    "fluidificași": "fluidifica",
    "fluidificat": "fluidifica",
    "fluidificați": "fluidifica",
    "fluidificatu": "fluidifica",
    "fluidificau": "fluidifica",
    "fluidifice": "fluidifica",
    "fluidifici": "fluidifica",
    "nefluidificând": "fluidifica",
    "nefluidificându": "fluidifica",
    "nemaifluidificând": "fluidifica",
    "nemaifluidificându": "fluidifica",
    "fluidificată": "fluidificat",
    "fluidificate": "fluidificat",
    "fluidificați": "fluidificat",
    "fluiditatea": "fluiditate",
    "fluidități": "fluiditate",
    "fluidității": "fluiditate",
    "fluidiză": "fluidiza",
    "fluidizai": "fluidiza",
    "fluidizam": "fluidiza",
    "fluidizăm": "fluidiza",
    "fluidizând": "fluidiza",
    "fluidizându": "fluidiza",
    "fluidizară": "fluidiza",
    "fluidizarăm": "fluidiza",
    "fluidizarăți": "fluidiza",
    "fluidizase": "fluidiza",
    "fluidizasem": "fluidiza",
    "fluidizaseră": "fluidiza",
    "fluidizaserăm": "fluidiza",
    "fluidizaserăți": "fluidiza",
    "fluidizaseși": "fluidiza",
    "fluidizași": "fluidiza",
    "fluidizat": "fluidiza",
    "fluidizați": "fluidiza",
    "fluidizatu": "fluidiza",
    "fluidizau": "fluidiza",
    "fluidizează": "fluidiza",
    "fluidizez": "fluidiza",
    "fluidizeze": "fluidiza",
    "fluidizezi": "fluidiza",
    "nefluidizând": "fluidiza",
    "nefluidizându": "fluidiza",
    "nemaifluidizând": "fluidiza",
    "nemaifluidizându": "fluidiza",
    "fluidizată": "fluidizat",
    "fluidizate": "fluidizat",
    "fluidizați": "fluidizat",
    "fluiere": "fluier",
    "fluierele": "fluier",
    "fluierelor": "fluier",
    "fluierul": "fluier",
    "fluierului": "fluier",
    "fluier": "fluiera",
    "fluieră": "fluiera",
    "fluierai": "fluiera",
    "fluieram": "fluiera",
    "fluierăm": "fluiera",
    "fluierând": "fluiera",
    "fluierându": "fluiera",
    "fluierară": "fluiera",
    "fluierarăm": "fluiera",
    "fluierarăți": "fluiera",
    "fluierase": "fluiera",
    "fluierasem": "fluiera",
    "fluieraseră": "fluiera",
    "fluieraserăm": "fluiera",
    "fluieraserăți": "fluiera",
    "fluieraseși": "fluiera",
    "fluierași": "fluiera",
    "fluierat": "fluiera",
    "fluierați": "fluiera",
    "fluieratu": "fluiera",
    "fluierau": "fluiera",
    "fluiere": "fluiera",
    "fluieri": "fluiera",
    "nefluierând": "fluiera",
    "nefluierându": "fluiera",
    "nemaifluierând": "fluiera",
    "nemaifluierându": "fluiera",
    "fluierată": "fluierat",
    "fluierate": "fluierat",
    "fluierați": "fluierat",
    "fluieratul": "fluierat",
    "fluieratului": "fluierat",
    "fluierătura": "fluierătură",
    "fluierături": "fluierătură",
    "fluierăturii": "fluierătură",
    "fluierăturile": "fluierătură",
    "fluierăturilor": "fluierătură",
    "F": "fluor",
    "fluorul": "fluor",
    "fluorului": "fluor",
    "fluoruri": "fluor",
    "fluorurile": "fluor",
    "fluorurilor": "fluor",
    "fluorescenta": "fluorescent",
    "fluorescentă": "fluorescent",
    "fluorescente": "fluorescent",
    "fluorescentei": "fluorescent",
    "fluorescentele": "fluorescent",
    "fluorescentelor": "fluorescent",
    "fluorescenți": "fluorescent",
    "fluorescenții": "fluorescent",
    "fluorescenților": "fluorescent",
    "fluorescentul": "fluorescent",
    "fluorescentului": "fluorescent",
    "fluoriză": "fluoriza",
    "fluorizai": "fluoriza",
    "fluorizam": "fluoriza",
    "fluorizăm": "fluoriza",
    "fluorizând": "fluoriza",
    "fluorizându": "fluoriza",
    "fluorizară": "fluoriza",
    "fluorizarăm": "fluoriza",
    "fluorizarăți": "fluoriza",
    "fluorizase": "fluoriza",
    "fluorizasem": "fluoriza",
    "fluorizaseră": "fluoriza",
    "fluorizaserăm": "fluoriza",
    "fluorizaserăți": "fluoriza",
    "fluorizaseși": "fluoriza",
    "fluorizași": "fluoriza",
    "fluorizat": "fluoriza",
    "fluorizați": "fluoriza",
    "fluorizatu": "fluoriza",
    "fluorizau": "fluoriza",
    "fluorizează": "fluoriza",
    "fluorizez": "fluoriza",
    "fluorizeze": "fluoriza",
    "fluorizezi": "fluoriza",
    "nefluorizând": "fluoriza",
    "nefluorizându": "fluoriza",
    "nemaifluorizând": "fluoriza",
    "nemaifluorizându": "fluoriza",
    "fluorizată": "fluorizat",
    "fluorizate": "fluorizat",
    "fluorizați": "fluorizat",
    "fluștur": "fluștura",
    "fluștură": "fluștura",
    "flușturai": "fluștura",
    "flușturam": "fluștura",
    "flușturăm": "fluștura",
    "flușturând": "fluștura",
    "flușturându": "fluștura",
    "flușturară": "fluștura",
    "flușturarăm": "fluștura",
    "flușturarăți": "fluștura",
    "flușturase": "fluștura",
    "flușturasem": "fluștura",
    "flușturaseră": "fluștura",
    "flușturaserăm": "fluștura",
    "flușturaserăți": "fluștura",
    "flușturaseși": "fluștura",
    "flușturași": "fluștura",
    "flușturat": "fluștura",
    "flușturați": "fluștura",
    "flușturatu": "fluștura",
    "flușturau": "fluștura",
    "flușture": "fluștura",
    "flușturi": "fluștura",
    "neflușturând": "fluștura",
    "neflușturându": "fluștura",
    "nemaiflușturând": "fluștura",
    "nemaiflușturându": "fluștura",
    "flușturată": "flușturat",
    "flușturate": "flușturat",
    "flușturați": "flușturat",
    "flutur": "flutura",
    "flutură": "flutura",
    "fluturai": "flutura",
    "fluturam": "flutura",
    "fluturăm": "flutura",
    "fluturând": "flutura",
    "fluturându": "flutura",
    "fluturară": "flutura",
    "fluturarăm": "flutura",
    "fluturarăți": "flutura",
    "fluturase": "flutura",
    "fluturasem": "flutura",
    "fluturaseră": "flutura",
    "fluturaserăm": "flutura",
    "fluturaserăți": "flutura",
    "fluturaseși": "flutura",
    "fluturași": "flutura",
    "fluturat": "flutura",
    "fluturați": "flutura",
    "fluturatu": "flutura",
    "fluturau": "flutura",
    "fluture": "flutura",
    "fluturi": "flutura",
    "nefluturând": "flutura",
    "nefluturându": "flutura",
    "nemaifluturând": "flutura",
    "nemaifluturându": "flutura",
    "fluturași": "fluturaș",
    "fluturașii": "fluturaș",
    "fluturașilor": "fluturaș",
    "fluturașul": "fluturaș",
    "fluturașului": "fluturaș",
    "fluturată": "fluturat",
    "fluturate": "fluturat",
    "fluturați": "fluturat",
    "fluturele": "fluture",
    "fluturelui": "fluture",
    "fluturi": "fluture",
    "fluturii": "fluture",
    "fluturilor": "fluture",
    "fluviala": "fluvial",
    "fluvială": "fluvial",
    "fluviale": "fluvial",
    "fluvialei": "fluvial",
    "fluvialele": "fluvial",
    "fluvialelor": "fluvial",
    "fluviali": "fluvial",
    "fluvialii": "fluvial",
    "fluvialilor": "fluvial",
    "fluvialul": "fluvial",
    "fluvialului": "fluvial",
    "fluvii": "fluviu",
    "fluviii": "fluviu",
    "fluviilor": "fluviu",
    "fluviul": "fluviu",
    "fluviului": "fluviu",
    "fluxul": "flux",
    "fluxului": "flux",
    "fluxuri": "flux",
    "fluxurile": "flux",
    "fluxurilor": "flux",
    "foaia": "foaie",
    "foi": "foaie",
    "foii": "foaie",
    "foile": "foaie",
    "foilor": "foaie",
    "foaiere": "foaier",
    "foaierele": "foaier",
    "foaierelor": "foaier",
    "foaierul": "foaier",
    "foaierului": "foaier",
    "foalele": "foale",
    "foalelor": "foale",
    "foamea": "foame",
    "foamei": "foame",
    "foametea": "foamete",
    "foametei": "foamete",
    "foarfeca": "foarfecă",
    "foarfeci": "foarfecă",
    "foarfecii": "foarfecă",
    "foarfecile": "foarfecă",
    "foarfecilor": "foarfecă",
    "f.": "foarte",
    "f.m.": "foarte_mult",
    "fobia": "fobie",
    "fobiei": "fobie",
    "fobii": "fobie",
    "fobiile": "fobie",
    "fobiilor": "fobie",
    "focul": "foc",
    "focului": "foc",
    "focuri": "foc",
    "focurile": "foc",
    "focurilor": "foc",
    "foca": "focă",
    "foci": "focă",
    "focii": "focă",
    "focile": "focă",
    "focilor": "focă",
    "focaliză": "focaliza",
    "focalizai": "focaliza",
    "focalizam": "focaliza",
    "focalizăm": "focaliza",
    "focalizând": "focaliza",
    "focalizându": "focaliza",
    "focalizară": "focaliza",
    "focalizarăm": "focaliza",
    "focalizarăți": "focaliza",
    "focalizase": "focaliza",
    "focalizasem": "focaliza",
    "focalizaseră": "focaliza",
    "focalizaserăm": "focaliza",
    "focalizaserăți": "focaliza",
    "focalizaseși": "focaliza",
    "focalizași": "focaliza",
    "focalizat": "focaliza",
    "focalizați": "focaliza",
    "focalizatu": "focaliza",
    "focalizau": "focaliza",
    "focalizează": "focaliza",
    "focalizez": "focaliza",
    "focalizeze": "focaliza",
    "focalizezi": "focaliza",
    "nefocalizând": "focaliza",
    "nefocalizându": "focaliza",
    "nemaifocalizând": "focaliza",
    "nemaifocalizându": "focaliza",
    "focalizată": "focalizat",
    "focalizate": "focalizat",
    "focalizați": "focalizat",
    "focare": "focar",
    "focarele": "focar",
    "focarelor": "focar",
    "focarul": "focar",
    "focarului": "focar",
    "fochiști": "fochist",
    "fochiștii": "fochist",
    "fochiștilor": "fochist",
    "fochistul": "fochist",
    "fochistului": "fochist",
    "focoase": "focos",
    "focoasele": "focos",
    "focoaselor": "focos",
    "focosul": "focos",
    "focosului": "focos",
    "fofilă": "fofila",
    "fofilai": "fofila",
    "fofilam": "fofila",
    "fofilăm": "fofila",
    "fofilând": "fofila",
    "fofilându": "fofila",
    "fofilară": "fofila",
    "fofilarăm": "fofila",
    "fofilarăți": "fofila",
    "fofilase": "fofila",
    "fofilasem": "fofila",
    "fofilaseră": "fofila",
    "fofilaserăm": "fofila",
    "fofilaserăți": "fofila",
    "fofilaseși": "fofila",
    "fofilași": "fofila",
    "fofilat": "fofila",
    "fofilați": "fofila",
    "fofilatu": "fofila",
    "fofilau": "fofila",
    "fofilează": "fofila",
    "fofilez": "fofila",
    "fofileze": "fofila",
    "fofilezi": "fofila",
    "nefofilând": "fofila",
    "nefofilându": "fofila",
    "nemaifofilând": "fofila",
    "nemaifofilându": "fofila",
    "fofilată": "fofilat",
    "fofilate": "fofilat",
    "fofilați": "fofilat",
    "foia": "foi",
    "foiai": "foi",
    "foiam": "foi",
    "foiască": "foi",
    "foiați": "foi",
    "foiau": "foi",
    "foiesc": "foi",
    "foiește": "foi",
    "foiești": "foi",
    "foii": "foi",
    "foim": "foi",
    "foind": "foi",
    "foindu": "foi",
    "foiră": "foi",
    "foirăm": "foi",
    "foirăți": "foi",
    "foise": "foi",
    "foisem": "foi",
    "foiseră": "foi",
    "foiserăm": "foi",
    "foiserăți": "foi",
    "foiseși": "foi",
    "foiși": "foi",
    "foit": "foi",
    "foiți": "foi",
    "foitu": "foi",
    "nefoind": "foi",
    "nefoindu": "foi",
    "nemaifoind": "foi",
    "nemaifoindu": "foi",
    "foiala": "foială",
    "foialo": "foială",
    "foieli": "foială",
    "foielii": "foială",
    "foielile": "foială",
    "foielilor": "foială",
    "foicele": "foicică",
    "foicelei": "foicică",
    "foicelele": "foicică",
    "foicelelor": "foicică",
    "foicica": "foicică",
    "foiletă": "foileta",
    "foiletai": "foileta",
    "foiletam": "foileta",
    "foiletăm": "foileta",
    "foiletând": "foileta",
    "foiletându": "foileta",
    "foiletară": "foileta",
    "foiletarăm": "foileta",
    "foiletarăți": "foileta",
    "foiletase": "foileta",
    "foiletasem": "foileta",
    "foiletaseră": "foileta",
    "foiletaserăm": "foileta",
    "foiletaserăți": "foileta",
    "foiletaseși": "foileta",
    "foiletași": "foileta",
    "foiletat": "foileta",
    "foiletați": "foileta",
    "foiletatu": "foileta",
    "foiletau": "foileta",
    "foiletează": "foileta",
    "foiletez": "foileta",
    "foileteze": "foileta",
    "foiletezi": "foileta",
    "nefoiletând": "foileta",
    "nefoiletându": "foileta",
    "nemaifoiletând": "foileta",
    "nemaifoiletându": "foileta",
    "foiletată": "foiletat",
    "foiletate": "foiletat",
    "foiletați": "foiletat",
    "foiletoane": "foileton",
    "foiletoanele": "foileton",
    "foiletoanelor": "foileton",
    "foiletonul": "foileton",
    "foiletonului": "foileton",
    "foișoare": "foișor",
    "foișoarele": "foișor",
    "foișoarelor": "foișor",
    "foișorul": "foișor",
    "foișorului": "foișor",
    "foită": "foit",
    "foite": "foit",
    "foiți": "foit",
    "foița": "foiță",
    "foițe": "foiță",
    "foiței": "foiță",
    "foițele": "foiță",
    "foițelor": "foiță",
    "fojgăia": "fojgăi",
    "fojgăiai": "fojgăi",
    "fojgăiam": "fojgăi",
    "fojgăiască": "fojgăi",
    "fojgăiați": "fojgăi",
    "fojgăiau": "fojgăi",
    "fojgăiesc": "fojgăi",
    "fojgăiește": "fojgăi",
    "fojgăiești": "fojgăi",
    "fojgăii": "fojgăi",
    "fojgăim": "fojgăi",
    "fojgăind": "fojgăi",
    "fojgăindu": "fojgăi",
    "fojgăiră": "fojgăi",
    "fojgăirăm": "fojgăi",
    "fojgăirăți": "fojgăi",
    "fojgăise": "fojgăi",
    "fojgăisem": "fojgăi",
    "fojgăiseră": "fojgăi",
    "fojgăiserăm": "fojgăi",
    "fojgăiserăți": "fojgăi",
    "fojgăiseși": "fojgăi",
    "fojgăiși": "fojgăi",
    "fojgăit": "fojgăi",
    "fojgăiți": "fojgăi",
    "fojgăitu": "fojgăi",
    "nefojgăind": "fojgăi",
    "nefojgăindu": "fojgăi",
    "nemaifojgăind": "fojgăi",
    "nemaifojgăindu": "fojgăi",
    "fojgăită": "fojgăit",
    "fojgăite": "fojgăit",
    "fojgăiți": "fojgăit",
    "folclorul": "folclor",
    "folclorului": "folclor",
    "folclorica": "folcloric",
    "folclorică": "folcloric",
    "folclorice": "folcloric",
    "folcloricei": "folcloric",
    "folcloricele": "folcloric",
    "folcloricelor": "folcloric",
    "folclorici": "folcloric",
    "folcloricii": "folcloric",
    "folcloricilor": "folcloric",
    "folcloricul": "folcloric",
    "folcloricului": "folcloric",
    "folfăia": "folfăi",
    "folfăiai": "folfăi",
    "folfăiam": "folfăi",
    "folfăiască": "folfăi",
    "folfăiați": "folfăi",
    "folfăiau": "folfăi",
    "folfăiesc": "folfăi",
    "folfăiește": "folfăi",
    "folfăiești": "folfăi",
    "folfăii": "folfăi",
    "folfăim": "folfăi",
    "folfăind": "folfăi",
    "folfăindu": "folfăi",
    "folfăiră": "folfăi",
    "folfăirăm": "folfăi",
    "folfăirăți": "folfăi",
    "folfăise": "folfăi",
    "folfăisem": "folfăi",
    "folfăiseră": "folfăi",
    "folfăiserăm": "folfăi",
    "folfăiserăți": "folfăi",
    "folfăiseși": "folfăi",
    "folfăiși": "folfăi",
    "folfăit": "folfăi",
    "folfăiți": "folfăi",
    "folfăitu": "folfăi",
    "nefolfăind": "folfăi",
    "nefolfăindu": "folfăi",
    "nemaifolfăind": "folfăi",
    "nemaifolfăindu": "folfăi",
    "folfăită": "folfăit",
    "folfăite": "folfăit",
    "folfăiți": "folfăit",
    "fo.": "folio",
    "f.r.": "folio_recto",
    "f.v.": "folio_verso",
    "foloase": "folos",
    "foloasele": "folos",
    "foloaselor": "folos",
    "folosul": "folos",
    "folosului": "folos",
    "folosea": "folosi",
    "foloseai": "folosi",
    "foloseam": "folosi",
    "folosească": "folosi",
    "foloseați": "folosi",
    "foloseau": "folosi",
    "folosesc": "folosi",
    "folosește": "folosi",
    "folosești": "folosi",
    "folosii": "folosi",
    "folosim": "folosi",
    "folosind": "folosi",
    "folosindu": "folosi",
    "folosiră": "folosi",
    "folosirăm": "folosi",
    "folosirăți": "folosi",
    "folosise": "folosi",
    "folosisem": "folosi",
    "folosiseră": "folosi",
    "folosiserăm": "folosi",
    "folosiserăți": "folosi",
    "folosiseși": "folosi",
    "folosiși": "folosi",
    "folosit": "folosi",
    "folosiți": "folosi",
    "folositu": "folosi",
    "nefolosind": "folosi",
    "nefolosindu": "folosi",
    "nemaifolosind": "folosi",
    "nemaifolosindu": "folosi",
    "folosința": "folosință",
    "folosințe": "folosință",
    "folosinței": "folosință",
    "folosințele": "folosință",
    "folosințelor": "folosință",
    "folosirea": "folosire",
    "folosiri": "folosire",
    "folosirii": "folosire",
    "folosirile": "folosire",
    "folosirilor": "folosire",
    "folosită": "folosit",
    "folosite": "folosit",
    "folosiți": "folosit",
    "folositul": "folosit",
    "folositoare": "folositor",
    "folositoarea": "folositor",
    "folositoarei": "folositor",
    "folositoarele": "folositor",
    "folositoarelor": "folositor",
    "folositori": "folositor",
    "folositorii": "folositor",
    "folositorilor": "folositor",
    "folositorul": "folositor",
    "folositorului": "folositor",
    "fondul": "fond",
    "fondului": "fond",
    "fonduri": "fond",
    "fondurile": "fond",
    "fondurilor": "fond",
    "fondă": "fonda",
    "fondai": "fonda",
    "fondam": "fonda",
    "fondăm": "fonda",
    "fondând": "fonda",
    "fondându": "fonda",
    "fondară": "fonda",
    "fondarăm": "fonda",
    "fondarăți": "fonda",
    "fondase": "fonda",
    "fondasem": "fonda",
    "fondaseră": "fonda",
    "fondaserăm": "fonda",
    "fondaserăți": "fonda",
    "fondaseși": "fonda",
    "fondași": "fonda",
    "fondat": "fonda",
    "fondați": "fonda",
    "fondatu": "fonda",
    "fondau": "fonda",
    "fondează": "fonda",
    "fondez": "fonda",
    "fondeze": "fonda",
    "fondezi": "fonda",
    "nefondând": "fonda",
    "nefondându": "fonda",
    "nemaifondând": "fonda",
    "nemaifondându": "fonda",
    "fondată": "fondat",
    "fondate": "fondat",
    "fondați": "fondat",
    "fondatoare": "fondator",
    "fondatoarea": "fondator",
    "fondatoarei": "fondator",
    "fondatoarele": "fondator",
    "fondatoarelor": "fondator",
    "fondatori": "fondator",
    "fondatorii": "fondator",
    "fondatorilor": "fondator",
    "fondatorul": "fondator",
    "fondatorului": "fondator",
    "FMI": "Fondul_Monetar_Internațional",
    "FMOA": "Fondul_Mutual_al_Oamenilor_de_Afaceri",
    "FPS": "Fondul_Proprietății_de_Stat",
    "FPP": "Fondul_Proprietății_Private",
    "foneme": "fonem",
    "fonemele": "fonem",
    "fonemelor": "fonem",
    "fonemul": "fonem",
    "fonemului": "fonem",
    "fonetica": "fonetic",
    "fonetică": "fonetic",
    "fonetice": "fonetic",
    "foneticei": "fonetic",
    "foneticele": "fonetic",
    "foneticelor": "fonetic",
    "fonetici": "fonetic",
    "foneticii": "fonetic",
    "foneticilor": "fonetic",
    "foneticul": "fonetic",
    "foneticului": "fonetic",
    "fon.": "fonetică",
    "fonetica": "fonetică",
    "fonetici": "fonetică",
    "foneticii": "fonetică",
    "foneticile": "fonetică",
    "foneticilor": "fonetică",
    "fonetisme": "fonetism",
    "fonetismele": "fonetism",
    "fonetismelor": "fonetism",
    "fonetismul": "fonetism",
    "fonetismule": "fonetism",
    "fonetismului": "fonetism",
    "fonfăia": "fonfăi",
    "fonfăiai": "fonfăi",
    "fonfăiam": "fonfăi",
    "fonfăiați": "fonfăi",
    "fonfăiau": "fonfăi",
    "fonfăie": "fonfăi",
    "fonfăii": "fonfăi",
    "fonfăim": "fonfăi",
    "fonfăind": "fonfăi",
    "fonfăindu": "fonfăi",
    "fonfăiră": "fonfăi",
    "fonfăirăm": "fonfăi",
    "fonfăirăți": "fonfăi",
    "fonfăise": "fonfăi",
    "fonfăisem": "fonfăi",
    "fonfăiseră": "fonfăi",
    "fonfăiserăm": "fonfăi",
    "fonfăiserăți": "fonfăi",
    "fonfăiseși": "fonfăi",
    "fonfăiși": "fonfăi",
    "fonfăit": "fonfăi",
    "fonfăiți": "fonfăi",
    "fonfăitu": "fonfăi",
    "nefonfăind": "fonfăi",
    "nefonfăindu": "fonfăi",
    "nemaifonfăind": "fonfăi",
    "nemaifonfăindu": "fonfăi",
    "fonfăită": "fonfăit",
    "fonfăite": "fonfăit",
    "fonfăiți": "fonfăit",
    "fonologia": "fonologie",
    "fonologiei": "fonologie",
    "fonologii": "fonologie",
    "fonologiile": "fonologie",
    "fonologiilor": "fonologie",
    "fonta": "fontă",
    "fonte": "fontă",
    "fontei": "fontă",
    "fontele": "fontă",
    "fontelor": "fontă",
    "forul": "for",
    "forului": "for",
    "foruri": "for",
    "forurile": "for",
    "forurilor": "for",
    "foră": "fora",
    "forai": "fora",
    "foram": "fora",
    "forăm": "fora",
    "forând": "fora",
    "forându": "fora",
    "forară": "fora",
    "forarăm": "fora",
    "forarăți": "fora",
    "forase": "fora",
    "forasem": "fora",
    "foraseră": "fora",
    "foraserăm": "fora",
    "foraserăți": "fora",
    "foraseși": "fora",
    "forași": "fora",
    "forat": "fora",
    "forați": "fora",
    "foratu": "fora",
    "forau": "fora",
    "forează": "fora",
    "forez": "fora",
    "foreze": "fora",
    "forezi": "fora",
    "neforând": "fora",
    "neforându": "fora",
    "nemaiforând": "fora",
    "nemaiforându": "fora",
    "forăia": "forăi",
    "forăiai": "forăi",
    "forăiam": "forăi",
    "forăiați": "forăi",
    "forăiau": "forăi",
    "forăie": "forăi",
    "forăii": "forăi",
    "forăim": "forăi",
    "forăind": "forăi",
    "forăindu": "forăi",
    "forăiră": "forăi",
    "forăirăm": "forăi",
    "forăirăți": "forăi",
    "forăise": "forăi",
    "forăisem": "forăi",
    "forăiseră": "forăi",
    "forăiserăm": "forăi",
    "forăiserăți": "forăi",
    "forăiseși": "forăi",
    "forăiși": "forăi",
    "forăit": "forăi",
    "forăiți": "forăi",
    "forăitu": "forăi",
    "neforăind": "forăi",
    "neforăindu": "forăi",
    "nemaiforăind": "forăi",
    "nemaiforăindu": "forăi",
    "forăită": "forăit",
    "forăite": "forăit",
    "forăiți": "forăit",
    "foraje": "foraj",
    "forajele": "foraj",
    "forajelor": "foraj",
    "forajul": "foraj",
    "forajului": "foraj",
    "forată": "forat",
    "forate": "forat",
    "forați": "forat",
    "forcepsul": "forceps",
    "forestiera": "forestier",
    "forestieră": "forestier",
    "forestiere": "forestier",
    "forestierei": "forestier",
    "forestierele": "forestier",
    "forestierelor": "forestier",
    "forestieri": "forestier",
    "forestierii": "forestier",
    "forestierilor": "forestier",
    "forestierul": "forestier",
    "forestierului": "forestier",
    "forfăia": "forfăi",
    "forfăiai": "forfăi",
    "forfăiam": "forfăi",
    "forfăiască": "forfăi",
    "forfăiați": "forfăi",
    "forfăiau": "forfăi",
    "forfăiesc": "forfăi",
    "forfăiește": "forfăi",
    "forfăiești": "forfăi",
    "forfăii": "forfăi",
    "forfăim": "forfăi",
    "forfăind": "forfăi",
    "forfăindu": "forfăi",
    "forfăiră": "forfăi",
    "forfăirăm": "forfăi",
    "forfăirăți": "forfăi",
    "forfăise": "forfăi",
    "forfăisem": "forfăi",
    "forfăiseră": "forfăi",
    "forfăiserăm": "forfăi",
    "forfăiserăți": "forfăi",
    "forfăiseși": "forfăi",
    "forfăiși": "forfăi",
    "forfăit": "forfăi",
    "forfăiți": "forfăi",
    "forfăitu": "forfăi",
    "neforfăind": "forfăi",
    "neforfăindu": "forfăi",
    "nemaiforfăind": "forfăi",
    "nemaiforfăindu": "forfăi",
    "forfăită": "forfăit",
    "forfăite": "forfăit",
    "forfăiți": "forfăit",
    "foarfec": "forfeca",
    "foarfecă": "forfeca",
    "foarfece": "forfeca",
    "foarfeci": "forfeca",
    "forfecă": "forfeca",
    "forfecai": "forfeca",
    "forfecam": "forfeca",
    "forfecăm": "forfeca",
    "forfecând": "forfeca",
    "forfecându": "forfeca",
    "forfecară": "forfeca",
    "forfecarăm": "forfeca",
    "forfecarăți": "forfeca",
    "forfecase": "forfeca",
    "forfecasem": "forfeca",
    "forfecaseră": "forfeca",
    "forfecaserăm": "forfeca",
    "forfecaserăți": "forfeca",
    "forfecaseși": "forfeca",
    "forfecași": "forfeca",
    "forfecat": "forfeca",
    "forfecați": "forfeca",
    "forfecatu": "forfeca",
    "forfecau": "forfeca",
    "neforfecând": "forfeca",
    "neforfecându": "forfeca",
    "nemaiforfecând": "forfeca",
    "nemaiforfecându": "forfeca",
    "forfecată": "forfecat",
    "forfecate": "forfecat",
    "forfecați": "forfecat",
    "forfecuța": "forfecuță",
    "forfecuțe": "forfecuță",
    "forfecuței": "forfecuță",
    "forfecuțele": "forfecuță",
    "forfecuțelor": "forfecuță",
    "forfetară": "forfetar",
    "forfetare": "forfetar",
    "forfetari": "forfetar",
    "forfota": "forfotă",
    "forfote": "forfotă",
    "forfotei": "forfotă",
    "forfotele": "forfotă",
    "forfotelor": "forfotă",
    "forfoteala": "forfoteală",
    "forfotealo": "forfoteală",
    "forfoteli": "forfoteală",
    "forfotelii": "forfoteală",
    "forfotelile": "forfoteală",
    "forfotelilor": "forfoteală",
    "forfotea": "forfoti",
    "forfoteai": "forfoti",
    "forfoteam": "forfoti",
    "forfotească": "forfoti",
    "forfoteați": "forfoti",
    "forfoteau": "forfoti",
    "forfotesc": "forfoti",
    "forfotește": "forfoti",
    "forfotești": "forfoti",
    "forfotii": "forfoti",
    "forfotim": "forfoti",
    "forfotind": "forfoti",
    "forfotindu": "forfoti",
    "forfotiră": "forfoti",
    "forfotirăm": "forfoti",
    "forfotirăți": "forfoti",
    "forfotise": "forfoti",
    "forfotisem": "forfoti",
    "forfotiseră": "forfoti",
    "forfotiserăm": "forfoti",
    "forfotiserăți": "forfoti",
    "forfotiseși": "forfoti",
    "forfotiși": "forfoti",
    "forfotit": "forfoti",
    "forfotiți": "forfoti",
    "forfotitu": "forfoti",
    "neforfotind": "forfoti",
    "neforfotindu": "forfoti",
    "nemaiforfotind": "forfoti",
    "nemaiforfotindu": "forfoti",
    "forfotită": "forfotit",
    "forfotite": "forfotit",
    "forfotiți": "forfotit",
    "forjă": "forja",
    "forjai": "forja",
    "forjam": "forja",
    "forjăm": "forja",
    "forjând": "forja",
    "forjându": "forja",
    "forjară": "forja",
    "forjarăm": "forja",
    "forjarăți": "forja",
    "forjase": "forja",
    "forjasem": "forja",
    "forjaseră": "forja",
    "forjaserăm": "forja",
    "forjaserăți": "forja",
    "forjaseși": "forja",
    "forjași": "forja",
    "forjat": "forja",
    "forjați": "forja",
    "forjatu": "forja",
    "forjau": "forja",
    "forjează": "forja",
    "forjez": "forja",
    "forjeze": "forja",
    "forjezi": "forja",
    "neforjând": "forja",
    "neforjându": "forja",
    "nemaiforjând": "forja",
    "nemaiforjându": "forja",
    "forja": "forjă",
    "forje": "forjă",
    "forjei": "forjă",
    "forjele": "forjă",
    "forjelor": "forjă",
    "forjată": "forjat",
    "forjate": "forjat",
    "forjați": "forjat",
    "formă": "forma",
    "formai": "forma",
    "formam": "forma",
    "formăm": "forma",
    "formând": "forma",
    "formându": "forma",
    "formară": "forma",
    "formarăm": "forma",
    "formarăți": "forma",
    "formase": "forma",
    "formasem": "forma",
    "formaseră": "forma",
    "formaserăm": "forma",
    "formaserăți": "forma",
    "formaseși": "forma",
    "formași": "forma",
    "format": "forma",
    "formați": "forma",
    "formatu": "forma",
    "formau": "forma",
    "formează": "forma",
    "formez": "forma",
    "formeze": "forma",
    "formezi": "forma",
    "neformând": "forma",
    "neformându": "forma",
    "nemaiformând": "forma",
    "nemaiformându": "forma",
    "forma": "formă",
    "forme": "formă",
    "formei": "formă",
    "formele": "formă",
    "formelor": "formă",
    "formala": "formal",
    "formală": "formal",
    "formale": "formal",
    "formalei": "formal",
    "formalele": "formal",
    "formalelor": "formal",
    "formali": "formal",
    "formalii": "formal",
    "formalilor": "formal",
    "formalul": "formal",
    "formalului": "formal",
    "formalisme": "formalism",
    "formalismele": "formalism",
    "formalismelor": "formalism",
    "formalismul": "formalism",
    "formalismului": "formalism",
    "formalitatea": "formalitate",
    "formalități": "formalitate",
    "formalității": "formalitate",
    "formalitățile": "formalitate",
    "formalităților": "formalitate",
    "formaliză": "formaliza",
    "formalizai": "formaliza",
    "formalizam": "formaliza",
    "formalizăm": "formaliza",
    "formalizând": "formaliza",
    "formalizându": "formaliza",
    "formalizară": "formaliza",
    "formalizarăm": "formaliza",
    "formalizarăți": "formaliza",
    "formalizase": "formaliza",
    "formalizasem": "formaliza",
    "formalizaseră": "formaliza",
    "formalizaserăm": "formaliza",
    "formalizaserăți": "formaliza",
    "formalizaseși": "formaliza",
    "formalizași": "formaliza",
    "formalizat": "formaliza",
    "formalizați": "formaliza",
    "formalizatu": "formaliza",
    "formalizau": "formaliza",
    "formalizează": "formaliza",
    "formalizez": "formaliza",
    "formalizeze": "formaliza",
    "formalizezi": "formaliza",
    "neformalizând": "formaliza",
    "neformalizându": "formaliza",
    "nemaiformalizând": "formaliza",
    "nemaiformalizându": "formaliza",
    "formalizată": "formalizat",
    "formalizate": "formalizat",
    "formalizați": "formalizat",
    "formarea": "formare",
    "formări": "formare",
    "formării": "formare",
    "formările": "formare",
    "formărilor": "formare",
    "formata": "format",
    "formată": "format",
    "formate": "format",
    "formatei": "format",
    "formatele": "format",
    "formatelor": "format",
    "formați": "format",
    "formații": "format",
    "formaților": "format",
    "formatul": "format",
    "formatului": "format",
    "formația": "formație",
    "formației": "formație",
    "formații": "formație",
    "formațiile": "formație",
    "formațiilor": "formație",
    "formațiunea": "formațiune",
    "formațiuneo": "formațiune",
    "formațiuni": "formațiune",
    "formațiunii": "formațiune",
    "formațiunile": "formațiune",
    "formațiunilor": "formațiune",
    "formativa": "formativ",
    "formativă": "formativ",
    "formative": "formativ",
    "formativei": "formativ",
    "formativele": "formativ",
    "formativelor": "formativ",
    "formativi": "formativ",
    "formativii": "formativ",
    "formativilor": "formativ",
    "formativo": "formativ",
    "formativul": "formativ",
    "formativule": "formativ",
    "formativului": "formativ",
    "formidabila": "formidabil",
    "formidabilă": "formidabil",
    "formidabile": "formidabil",
    "formidabilei": "formidabil",
    "formidabilele": "formidabil",
    "formidabilelor": "formidabil",
    "formidabili": "formidabil",
    "formidabilii": "formidabil",
    "formidabililor": "formidabil",
    "formidabilul": "formidabil",
    "formidabilului": "formidabil",
    "formulă": "formula",
    "formulai": "formula",
    "formulam": "formula",
    "formulăm": "formula",
    "formulând": "formula",
    "formulându": "formula",
    "formulară": "formula",
    "formularăm": "formula",
    "formularăți": "formula",
    "formulase": "formula",
    "formulasem": "formula",
    "formulaseră": "formula",
    "formulaserăm": "formula",
    "formulaserăți": "formula",
    "formulaseși": "formula",
    "formulași": "formula",
    "formulat": "formula",
    "formulați": "formula",
    "formulatu": "formula",
    "formulau": "formula",
    "formulează": "formula",
    "formulez": "formula",
    "formuleze": "formula",
    "formulezi": "formula",
    "neformulând": "formula",
    "neformulându": "formula",
    "nemaiformulând": "formula",
    "nemaiformulându": "formula",
    "formula": "formulă",
    "formule": "formulă",
    "formulei": "formulă",
    "formulele": "formulă",
    "formulelor": "formulă",
    "formulare": "formular",
    "formularele": "formular",
    "formularelor": "formular",
    "formularul": "formular",
    "formularului": "formular",
    "formularea": "formulare",
    "formulări": "formulare",
    "formulării": "formulare",
    "formulările": "formulare",
    "formulărilor": "formulare",
    "formularistica": "formularistică",
    "formularistici": "formularistică",
    "formularisticii": "formularistică",
    "formularisticile": "formularistică",
    "formularisticilor": "formularistică",
    "formulată": "formulat",
    "formulate": "formulat",
    "formulați": "formulat",
    "fornăia": "fornăi",
    "fornăiai": "fornăi",
    "fornăiam": "fornăi",
    "fornăiați": "fornăi",
    "fornăiau": "fornăi",
    "fornăie": "fornăi",
    "fornăii": "fornăi",
    "fornăim": "fornăi",
    "fornăind": "fornăi",
    "fornăindu": "fornăi",
    "fornăiră": "fornăi",
    "fornăirăm": "fornăi",
    "fornăirăți": "fornăi",
    "fornăise": "fornăi",
    "fornăisem": "fornăi",
    "fornăiseră": "fornăi",
    "fornăiserăm": "fornăi",
    "fornăiserăți": "fornăi",
    "fornăiseși": "fornăi",
    "fornăiși": "fornăi",
    "fornăit": "fornăi",
    "fornăiți": "fornăi",
    "fornăitu": "fornăi",
    "nefornăind": "fornăi",
    "nefornăindu": "fornăi",
    "nemaifornăind": "fornăi",
    "nemaifornăindu": "fornăi",
    "fornăită": "fornăit",
    "fornăite": "fornăit",
    "fornăiți": "fornăit",
    "fortul": "fort",
    "fortului": "fort",
    "forturi": "fort",
    "forturile": "fort",
    "forturilor": "fort",
    "forță": "forța",
    "forțai": "forța",
    "forțam": "forța",
    "forțăm": "forța",
    "forțând": "forța",
    "forțându": "forța",
    "forțară": "forța",
    "forțarăm": "forța",
    "forțarăți": "forța",
    "forțase": "forța",
    "forțasem": "forța",
    "forțaseră": "forța",
    "forțaserăm": "forța",
    "forțaserăți": "forța",
    "forțaseși": "forța",
    "forțași": "forța",
    "forțat": "forța",
    "forțați": "forța",
    "forțatu": "forța",
    "forțau": "forța",
    "forțează": "forța",
    "forțez": "forța",
    "forțeze": "forța",
    "forțezi": "forța",
    "neforțând": "forța",
    "neforțându": "forța",
    "nemaiforțând": "forța",
    "nemaiforțându": "forța",
    "forța": "forță",
    "forțe": "forță",
    "forței": "forță",
    "forțele": "forță",
    "forțelor": "forță",
    "forțarea": "forțare",
    "forțareo": "forțare",
    "forțări": "forțare",
    "forțării": "forțare",
    "forțările": "forțare",
    "forțărilor": "forțare",
    "fortăreața": "fortăreață",
    "fortărețe": "fortăreață",
    "fortăreței": "fortăreață",
    "fortărețele": "fortăreață",
    "fortărețelor": "fortăreață",
    "forțata": "forțat",
    "forțată": "forțat",
    "forțate": "forțat",
    "forțatei": "forțat",
    "forțatele": "forțat",
    "forțatelor": "forțat",
    "forțați": "forțat",
    "forțații": "forțat",
    "forțaților": "forțat",
    "forțatul": "forțat",
    "forțatului": "forțat",
    "fortific": "fortifica",
    "fortifică": "fortifica",
    "fortificai": "fortifica",
    "fortificam": "fortifica",
    "fortificăm": "fortifica",
    "fortificând": "fortifica",
    "fortificându": "fortifica",
    "fortificară": "fortifica",
    "fortificarăm": "fortifica",
    "fortificarăți": "fortifica",
    "fortificase": "fortifica",
    "fortificasem": "fortifica",
    "fortificaseră": "fortifica",
    "fortificaserăm": "fortifica",
    "fortificaserăți": "fortifica",
    "fortificaseși": "fortifica",
    "fortificași": "fortifica",
    "fortificat": "fortifica",
    "fortificați": "fortifica",
    "fortificatu": "fortifica",
    "fortificau": "fortifica",
    "fortifice": "fortifica",
    "fortifici": "fortifica",
    "nefortificând": "fortifica",
    "nefortificându": "fortifica",
    "nemaifortificând": "fortifica",
    "nemaifortificându": "fortifica",
    "fortificată": "fortificat",
    "fortificate": "fortificat",
    "fortificați": "fortificat",
    "fort.": "fortificație",
    "fortificația": "fortificație",
    "fortificației": "fortificație",
    "fortificații": "fortificație",
    "fortificațiile": "fortificație",
    "fortificațiilor": "fortificație",
    "Fortunei": "Fortuna",
    "foșăia": "foșăi",
    "foșăiai": "foșăi",
    "foșăiam": "foșăi",
    "foșăiați": "foșăi",
    "foșăiau": "foșăi",
    "foșăie": "foșăi",
    "foșăii": "foșăi",
    "foșăim": "foșăi",
    "foșăind": "foșăi",
    "foșăindu": "foșăi",
    "foșăiră": "foșăi",
    "foșăirăm": "foșăi",
    "foșăirăți": "foșăi",
    "foșăise": "foșăi",
    "foșăisem": "foșăi",
    "foșăiseră": "foșăi",
    "foșăiserăm": "foșăi",
    "foșăiserăți": "foșăi",
    "foșăiseși": "foșăi",
    "foșăiși": "foșăi",
    "foșăit": "foșăi",
    "foșăiți": "foșăi",
    "foșăitu": "foșăi",
    "nefoșăind": "foșăi",
    "nefoșăindu": "foșăi",
    "nemaifoșăind": "foșăi",
    "nemaifoșăindu": "foșăi",
    "foșăită": "foșăit",
    "foșăite": "foșăit",
    "foșăiți": "foșăit",
    "fosfați": "fosfat",
    "fosfații": "fosfat",
    "fosfaților": "fosfat",
    "fosfatul": "fosfat",
    "fosfatului": "fosfat",
    "fosfată": "fosfata",
    "fosfatai": "fosfata",
    "fosfatam": "fosfata",
    "fosfatăm": "fosfata",
    "fosfatând": "fosfata",
    "fosfatându": "fosfata",
    "fosfatară": "fosfata",
    "fosfatarăm": "fosfata",
    "fosfatarăți": "fosfata",
    "fosfatase": "fosfata",
    "fosfatasem": "fosfata",
    "fosfataseră": "fosfata",
    "fosfataserăm": "fosfata",
    "fosfataserăți": "fosfata",
    "fosfataseși": "fosfata",
    "fosfatași": "fosfata",
    "fosfatat": "fosfata",
    "fosfatați": "fosfata",
    "fosfatatu": "fosfata",
    "fosfatau": "fosfata",
    "fosfatează": "fosfata",
    "fosfatez": "fosfata",
    "fosfateze": "fosfata",
    "fosfatezi": "fosfata",
    "nefosfatând": "fosfata",
    "nefosfatându": "fosfata",
    "nemaifosfatând": "fosfata",
    "nemaifosfatându": "fosfata",
    "fosfatată": "fosfatat",
    "fosfatate": "fosfatat",
    "fosfatați": "fosfatat",
    "fosfatică": "fosfatic",
    "fosfatice": "fosfatic",
    "fosfatici": "fosfatic",
    "fosforul": "fosfor",
    "fosforului": "fosfor",
    "P.": "fosfor",
    "fosforescenta": "fosforescent",
    "fosforescentă": "fosforescent",
    "fosforescente": "fosforescent",
    "fosforescentei": "fosforescent",
    "fosforescentele": "fosforescent",
    "fosforescentelor": "fosforescent",
    "fosforescenți": "fosforescent",
    "fosforescenții": "fosforescent",
    "fosforescenților": "fosforescent",
    "fosforescentul": "fosforescent",
    "fosforescentului": "fosforescent",
    "fosila": "fosil",
    "fosilă": "fosil",
    "fosile": "fosil",
    "fosilei": "fosil",
    "fosilele": "fosil",
    "fosilelor": "fosil",
    "fosili": "fosil",
    "fosilii": "fosil",
    "fosililor": "fosil",
    "fosilul": "fosil",
    "fosilului": "fosil",
    "fosila": "fosilă",
    "fosile": "fosilă",
    "fosilei": "fosilă",
    "fosilele": "fosilă",
    "fosilelor": "fosilă",
    "fosiliză": "fosiliza",
    "fosilizai": "fosiliza",
    "fosilizam": "fosiliza",
    "fosilizăm": "fosiliza",
    "fosilizând": "fosiliza",
    "fosilizându": "fosiliza",
    "fosilizară": "fosiliza",
    "fosilizarăm": "fosiliza",
    "fosilizarăți": "fosiliza",
    "fosilizase": "fosiliza",
    "fosilizasem": "fosiliza",
    "fosilizaseră": "fosiliza",
    "fosilizaserăm": "fosiliza",
    "fosilizaserăți": "fosiliza",
    "fosilizaseși": "fosiliza",
    "fosilizași": "fosiliza",
    "fosilizat": "fosiliza",
    "fosilizați": "fosiliza",
    "fosilizatu": "fosiliza",
    "fosilizau": "fosiliza",
    "fosilizează": "fosiliza",
    "fosilizez": "fosiliza",
    "fosilizeze": "fosiliza",
    "fosilizezi": "fosiliza",
    "nefosilizând": "fosiliza",
    "nefosilizându": "fosiliza",
    "nemaifosilizând": "fosiliza",
    "nemaifosilizându": "fosiliza",
    "fosilizată": "fosilizat",
    "fosilizate": "fosilizat",
    "fosilizați": "fosilizat",
    "foșnete": "foșnet",
    "foșnetele": "foșnet",
    "foșnetelor": "foșnet",
    "foșnetul": "foșnet",
    "foșnetului": "foșnet",
    "foșnea": "foșni",
    "foșneai": "foșni",
    "foșneam": "foșni",
    "foșnească": "foșni",
    "foșneați": "foșni",
    "foșneau": "foșni",
    "foșnesc": "foșni",
    "foșnește": "foșni",
    "foșnești": "foșni",
    "foșnii": "foșni",
    "foșnim": "foșni",
    "foșnind": "foșni",
    "foșnindu": "foșni",
    "foșniră": "foșni",
    "foșnirăm": "foșni",
    "foșnirăți": "foșni",
    "foșnise": "foșni",
    "foșnisem": "foșni",
    "foșniseră": "foșni",
    "foșniserăm": "foșni",
    "foșniserăți": "foșni",
    "foșniseși": "foșni",
    "foșniși": "foșni",
    "foșnit": "foșni",
    "foșniți": "foșni",
    "foșnitu": "foșni",
    "nefoșnind": "foșni",
    "nefoșnindu": "foșni",
    "nemaifoșnind": "foșni",
    "nemaifoșnindu": "foșni",
    "foșnită": "foșnit",
    "foșnite": "foșnit",
    "foșniți": "foșnit",
    "fos'": "fost",
    "fosta": "fost",
    "fostă": "fost",
    "foste": "fost",
    "fostei": "fost",
    "fostele": "fost",
    "fostelor": "fost",
    "foști": "fost",
    "foștii": "fost",
    "foștilor": "fost",
    "fostul": "fost",
    "fostului": "fost",
    "fotbalul": "fotbal",
    "fotbalului": "fotbal",
    "F.C.": "Fotbal_Club",
    "fotbaliști": "fotbalist",
    "fotbaliștii": "fotbalist",
    "fotbaliștilor": "fotbalist",
    "fotbalistul": "fotbalist",
    "fotbalistului": "fotbalist",
    "fotografi": "fotograf",
    "fotografii": "fotograf",
    "fotografilor": "fotograf",
    "fotograful": "fotograf",
    "fotografului": "fotograf",
    "fotografiai": "fotografia",
    "fotografiam": "fotografia",
    "fotografiară": "fotografia",
    "fotografiarăm": "fotografia",
    "fotografiarăți": "fotografia",
    "fotografiase": "fotografia",
    "fotografiasem": "fotografia",
    "fotografiaseră": "fotografia",
    "fotografiaserăm": "fotografia",
    "fotografiaserăți": "fotografia",
    "fotografiaseși": "fotografia",
    "fotografiași": "fotografia",
    "fotografiat": "fotografia",
    "fotografiați": "fotografia",
    "fotografiatu": "fotografia",
    "fotografiau": "fotografia",
    "fotografiază": "fotografia",
    "fotografie": "fotografia",
    "fotografiem": "fotografia",
    "fotografiez": "fotografia",
    "fotografieze": "fotografia",
    "fotografiezi": "fotografia",
    "fotografiind": "fotografia",
    "fotografiindu": "fotografia",
    "nefotografiind": "fotografia",
    "nefotografiindu": "fotografia",
    "nemaifotografiind": "fotografia",
    "nemaifotografiindu": "fotografia",
    "fotografiată": "fotografiat",
    "fotografiate": "fotografiat",
    "fotografiați": "fotografiat",
    "fotografica": "fotografic",
    "fotografică": "fotografic",
    "fotografice": "fotografic",
    "fotograficei": "fotografic",
    "fotograficele": "fotografic",
    "fotograficelor": "fotografic",
    "fotografici": "fotografic",
    "fotograficii": "fotografic",
    "fotograficilor": "fotografic",
    "fotograficul": "fotografic",
    "fotograficului": "fotografic",
    "fotogr.": "fotografie",
    "fotografia": "fotografie",
    "fotografiei": "fotografie",
    "fotografii": "fotografie",
    "fotografiile": "fotografie",
    "fotografiilor": "fotografie",
    "fotografierea": "fotografiere",
    "fotografiereo": "fotografiere",
    "fotografieri": "fotografiere",
    "fotografierii": "fotografiere",
    "fotografierile": "fotografiere",
    "fotografierilor": "fotografiere",
    "fotolii": "fotoliu",
    "fotoliii": "fotoliu",
    "fotoliilor": "fotoliu",
    "fotoliul": "fotoliu",
    "fotoliului": "fotoliu",
    "fotomontaje": "fotomontaj",
    "fotomontajele": "fotomontaj",
    "fotomontajelor": "fotomontaj",
    "fotomontajul": "fotomontaj",
    "fotomontajului": "fotomontaj",
    "fotoreporteri": "fotoreporter",
    "fotoreporterii": "fotoreporter",
    "fotoreporterilor": "fotoreporter",
    "fotoreporterul": "fotoreporter",
    "fotoreporterului": "fotoreporter",
    "fototapete": "fototapet",
    "fototapetele": "fototapet",
    "fototapetelor": "fototapet",
    "fototapetul": "fototapet",
    "fototapetului": "fototapet",
    "fracul": "frac",
    "fracului": "frac",
    "fracuri": "frac",
    "fracurile": "frac",
    "fracurilor": "frac",
    "fracția": "fracție",
    "fracției": "fracție",
    "fracții": "fracție",
    "fracțiile": "fracție",
    "fracțiilor": "fracție",
    "fracționă": "fracționa",
    "fracționai": "fracționa",
    "fracționam": "fracționa",
    "fracționăm": "fracționa",
    "fracționând": "fracționa",
    "fracționându": "fracționa",
    "fracționară": "fracționa",
    "fracționarăm": "fracționa",
    "fracționarăți": "fracționa",
    "fracționase": "fracționa",
    "fracționasem": "fracționa",
    "fracționaseră": "fracționa",
    "fracționaserăm": "fracționa",
    "fracționaserăți": "fracționa",
    "fracționaseși": "fracționa",
    "fracționași": "fracționa",
    "fracționat": "fracționa",
    "fracționați": "fracționa",
    "fracționatu": "fracționa",
    "fracționau": "fracționa",
    "fracționează": "fracționa",
    "fracționez": "fracționa",
    "fracționeze": "fracționa",
    "fracționezi": "fracționa",
    "nefracționând": "fracționa",
    "nefracționându": "fracționa",
    "nemaifracționând": "fracționa",
    "nemaifracționându": "fracționa",
    "fracționată": "fracționat",
    "fracționate": "fracționat",
    "fracționați": "fracționat",
    "fracțiunea": "fracțiune",
    "fracțiuni": "fracțiune",
    "fracțiunii": "fracțiune",
    "fracțiunile": "fracțiune",
    "fracțiunilor": "fracțiune",
    "fractură": "fractura",
    "fracturai": "fractura",
    "fracturam": "fractura",
    "fracturăm": "fractura",
    "fracturând": "fractura",
    "fracturându": "fractura",
    "fracturară": "fractura",
    "fracturarăm": "fractura",
    "fracturarăți": "fractura",
    "fracturase": "fractura",
    "fracturasem": "fractura",
    "fracturaseră": "fractura",
    "fracturaserăm": "fractura",
    "fracturaserăți": "fractura",
    "fracturaseși": "fractura",
    "fracturași": "fractura",
    "fracturat": "fractura",
    "fracturați": "fractura",
    "fracturatu": "fractura",
    "fracturau": "fractura",
    "fracturează": "fractura",
    "fracturez": "fractura",
    "fractureze": "fractura",
    "fracturezi": "fractura",
    "nefracturând": "fractura",
    "nefracturându": "fractura",
    "nemaifracturând": "fractura",
    "nemaifracturându": "fractura",
    "fractura": "fractură",
    "fracturi": "fractură",
    "fracturii": "fractură",
    "fracturile": "fractură",
    "fracturilor": "fractură",
    "fracturată": "fracturat",
    "fracturate": "fracturat",
    "fracturați": "fracturat",
    "fragi": "frag",
    "fragii": "frag",
    "fragilor": "frag",
    "fragul": "frag",
    "fragului": "frag",
    "fraga": "fragă",
    "fragi": "fragă",
    "fragii": "fragă",
    "fragile": "fragă",
    "fragilor": "fragă",
    "frageda": "fraged",
    "fragedă": "fraged",
    "fragede": "fraged",
    "fragedei": "fraged",
    "fragedele": "fraged",
    "fragedelor": "fraged",
    "fragedul": "fraged",
    "fragedului": "fraged",
    "fragezi": "fraged",
    "fragezii": "fraged",
    "fragezilor": "fraged",
    "frăgezea": "frăgezi",
    "frăgezeai": "frăgezi",
    "frăgezeam": "frăgezi",
    "frăgezească": "frăgezi",
    "frăgezeați": "frăgezi",
    "frăgezeau": "frăgezi",
    "frăgezesc": "frăgezi",
    "frăgezește": "frăgezi",
    "frăgezești": "frăgezi",
    "frăgezii": "frăgezi",
    "frăgezim": "frăgezi",
    "frăgezind": "frăgezi",
    "frăgezindu": "frăgezi",
    "frăgeziră": "frăgezi",
    "frăgezirăm": "frăgezi",
    "frăgezirăți": "frăgezi",
    "frăgezise": "frăgezi",
    "frăgezisem": "frăgezi",
    "frăgeziseră": "frăgezi",
    "frăgeziserăm": "frăgezi",
    "frăgeziserăți": "frăgezi",
    "frăgeziseși": "frăgezi",
    "frăgeziși": "frăgezi",
    "frăgezit": "frăgezi",
    "frăgeziți": "frăgezi",
    "frăgezitu": "frăgezi",
    "nefrăgezind": "frăgezi",
    "nefrăgezindu": "frăgezi",
    "nemaifrăgezind": "frăgezi",
    "nemaifrăgezindu": "frăgezi",
    "frăgezimea": "frăgezime",
    "frăgezimi": "frăgezime",
    "frăgezimii": "frăgezime",
    "frăgezimile": "frăgezime",
    "frăgezimilor": "frăgezime",
    "frăgezită": "frăgezit",
    "frăgezite": "frăgezit",
    "frăgeziți": "frăgezit",
    "fragila": "fragil",
    "fragilă": "fragil",
    "fragile": "fragil",
    "fragilei": "fragil",
    "fragilele": "fragil",
    "fragilelor": "fragil",
    "fragili": "fragil",
    "fragilii": "fragil",
    "fragililor": "fragil",
    "fragilul": "fragil",
    "fragilului": "fragil",
    "fragilitatea": "fragilitate",
    "fragilități": "fragilitate",
    "fragilității": "fragilitate",
    "fr.": "fragment",
    "fragmente": "fragment",
    "fragmentele": "fragment",
    "fragmentelor": "fragment",
    "fragmentul": "fragment",
    "fragmentului": "fragment",
    "fragmentă": "fragmenta",
    "fragmentai": "fragmenta",
    "fragmentam": "fragmenta",
    "fragmentăm": "fragmenta",
    "fragmentând": "fragmenta",
    "fragmentându": "fragmenta",
    "fragmentară": "fragmenta",
    "fragmentarăm": "fragmenta",
    "fragmentarăți": "fragmenta",
    "fragmentase": "fragmenta",
    "fragmentasem": "fragmenta",
    "fragmentaseră": "fragmenta",
    "fragmentaserăm": "fragmenta",
    "fragmentaserăți": "fragmenta",
    "fragmentaseși": "fragmenta",
    "fragmentași": "fragmenta",
    "fragmentat": "fragmenta",
    "fragmentați": "fragmenta",
    "fragmentatu": "fragmenta",
    "fragmentau": "fragmenta",
    "fragmentează": "fragmenta",
    "fragmentez": "fragmenta",
    "fragmenteze": "fragmenta",
    "fragmentezi": "fragmenta",
    "nefragmentând": "fragmenta",
    "nefragmentându": "fragmenta",
    "nemaifragmentând": "fragmenta",
    "nemaifragmentându": "fragmenta",
    "fragmentara": "fragmentar",
    "fragmentară": "fragmentar",
    "fragmentare": "fragmentar",
    "fragmentarei": "fragmentar",
    "fragmentarele": "fragmentar",
    "fragmentarelor": "fragmentar",
    "fragmentari": "fragmentar",
    "fragmentarii": "fragmentar",
    "fragmentarilor": "fragmentar",
    "fragmentarul": "fragmentar",
    "fragmentarului": "fragmentar",
    "fragmentarea": "fragmentare",
    "fragmentări": "fragmentare",
    "fragmentării": "fragmentare",
    "fragmentările": "fragmentare",
    "fragmentărilor": "fragmentare",
    "fragmentată": "fragmentat",
    "fragmentate": "fragmentat",
    "fragmentați": "fragmentat",
    "fraierea": "fraieri",
    "fraiereai": "fraieri",
    "fraieream": "fraieri",
    "fraierească": "fraieri",
    "fraiereați": "fraieri",
    "fraiereau": "fraieri",
    "fraieresc": "fraieri",
    "fraierește": "fraieri",
    "fraierești": "fraieri",
    "fraierii": "fraieri",
    "fraierim": "fraieri",
    "fraierind": "fraieri",
    "fraierindu": "fraieri",
    "fraieriră": "fraieri",
    "fraierirăm": "fraieri",
    "fraierirăți": "fraieri",
    "fraierise": "fraieri",
    "fraierisem": "fraieri",
    "fraieriseră": "fraieri",
    "fraieriserăm": "fraieri",
    "fraieriserăți": "fraieri",
    "fraieriseși": "fraieri",
    "fraieriși": "fraieri",
    "fraierit": "fraieri",
    "fraieriți": "fraieri",
    "fraieritu": "fraieri",
    "nefraierind": "fraieri",
    "nefraierindu": "fraieri",
    "nemaifraierind": "fraieri",
    "nemaifraierindu": "fraieri",
    "fraierită": "fraierit",
    "fraierite": "fraierit",
    "fraieriți": "fraierit",
    "frământ": "frământa",
    "frământă": "frământa",
    "frământai": "frământa",
    "frământam": "frământa",
    "frământăm": "frământa",
    "frământând": "frământa",
    "frământându": "frământa",
    "frământară": "frământa",
    "frământarăm": "frământa",
    "frământarăți": "frământa",
    "frământase": "frământa",
    "frământasem": "frământa",
    "frământaseră": "frământa",
    "frământaserăm": "frământa",
    "frământaserăți": "frământa",
    "frământaseși": "frământa",
    "frământași": "frământa",
    "frământat": "frământa",
    "frământați": "frământa",
    "frământatu": "frământa",
    "frământau": "frământa",
    "frământe": "frământa",
    "frămânți": "frământa",
    "nefrământând": "frământa",
    "nefrământându": "frământa",
    "nemaifrământând": "frământa",
    "nemaifrământându": "frământa",
    "frământarea": "frământare",
    "frământări": "frământare",
    "frământării": "frământare",
    "frământările": "frământare",
    "frământărilor": "frământare",
    "frământată": "frământat",
    "frământate": "frământat",
    "frământați": "frământat",
    "frână": "frâna",
    "frânai": "frâna",
    "frânam": "frâna",
    "frânăm": "frâna",
    "frânând": "frâna",
    "frânându": "frâna",
    "frânară": "frâna",
    "frânarăm": "frâna",
    "frânarăți": "frâna",
    "frânase": "frâna",
    "frânasem": "frâna",
    "frânaseră": "frâna",
    "frânaserăm": "frâna",
    "frânaserăți": "frâna",
    "frânaseși": "frâna",
    "frânași": "frâna",
    "frânat": "frâna",
    "frânați": "frâna",
    "frânatu": "frâna",
    "frânau": "frâna",
    "frânează": "frâna",
    "frânez": "frâna",
    "frâneze": "frâna",
    "frânezi": "frâna",
    "nefrânând": "frâna",
    "nefrânându": "frâna",
    "nemaifrânând": "frâna",
    "nemaifrânându": "frâna",
    "frâna": "frână",
    "frâne": "frână",
    "frânei": "frână",
    "frânele": "frână",
    "frânelor": "frână",
    "frânari": "frânar",
    "frânarii": "frânar",
    "frânarilor": "frânar",
    "frânarul": "frânar",
    "frânarului": "frânar",
    "frânată": "frânat",
    "frânate": "frânat",
    "frânați": "frânat",
    "f.": "franc",
    "Fr.": "franc",
    "franca": "franc",
    "francă": "franc",
    "france": "franc",
    "francei": "franc",
    "francele": "franc",
    "francelor": "franc",
    "franci": "franc",
    "francii": "franc",
    "francilor": "franc",
    "francul": "franc",
    "francului": "franc",
    "francă": "franca",
    "francai": "franca",
    "francam": "franca",
    "francăm": "franca",
    "francând": "franca",
    "francându": "franca",
    "francară": "franca",
    "francarăm": "franca",
    "francarăți": "franca",
    "francase": "franca",
    "francasem": "franca",
    "francaseră": "franca",
    "francaserăm": "franca",
    "francaserăți": "franca",
    "francaseși": "franca",
    "francași": "franca",
    "francat": "franca",
    "francați": "franca",
    "francatu": "franca",
    "francau": "franca",
    "franchează": "franca",
    "franchez": "franca",
    "francheze": "franca",
    "franchezi": "franca",
    "nefrancând": "franca",
    "nefrancându": "franca",
    "nemaifrancând": "franca",
    "nemaifrancându": "franca",
    "francată": "francat",
    "francate": "francat",
    "francați": "francat",
    "franceza": "francez",
    "franceză": "francez",
    "franceze": "francez",
    "francezei": "francez",
    "francezele": "francez",
    "francezelor": "francez",
    "francezi": "francez",
    "francezii": "francez",
    "francezilor": "francez",
    "francezul": "francez",
    "francezului": "francez",
    "franceza": "franceză",
    "franceze": "franceză",
    "francezei": "franceză",
    "franchețea": "franchețe",
    "franchețeo": "franchețe",
    "francheți": "franchețe",
    "francheții": "franchețe",
    "franchețile": "franchețe",
    "francheților": "franchețe",
    "frângători": "frângător",
    "frângătorii": "frângător",
    "frângătorilor": "frângător",
    "frângătorul": "frângător",
    "frângătorule": "frângător",
    "frângătorului": "frângător",
    "frâng": "frânge",
    "frângă": "frânge",
    "frângând": "frânge",
    "frângându": "frânge",
    "frângea": "frânge",
    "frângeai": "frânge",
    "frângeam": "frânge",
    "frângeați": "frânge",
    "frângeau": "frânge",
    "frângem": "frânge",
    "frângeți": "frânge",
    "frângi": "frânge",
    "frânse": "frânge",
    "frânsei": "frânge",
    "frânseră": "frânge",
    "frânserăm": "frânge",
    "frânserăți": "frânge",
    "frânsese": "frânge",
    "frânsesem": "frânge",
    "frânseseră": "frânge",
    "frânseserăm": "frânge",
    "frânseserăți": "frânge",
    "frânseseși": "frânge",
    "frânseși": "frânge",
    "frânt": "frânge",
    "frântu": "frânge",
    "nefrângând": "frânge",
    "nefrângându": "frânge",
    "nemaifrângând": "frânge",
    "nemaifrângându": "frânge",
    "frângerea": "frângere",
    "frângereo": "frângere",
    "frângeri": "frângere",
    "frângerii": "frângere",
    "frângerile": "frângere",
    "frângerilor": "frângere",
    "frânghia": "frânghie",
    "frânghiei": "frânghie",
    "frânghii": "frânghie",
    "frânghiile": "frânghie",
    "frânghiilor": "frânghie",
    "frânta": "frânt",
    "frântă": "frânt",
    "frânte": "frânt",
    "frântei": "frânt",
    "frântele": "frânt",
    "frântelor": "frânt",
    "frânți": "frânt",
    "frânții": "frânt",
    "frânților": "frânt",
    "frântul": "frânt",
    "frântului": "frânt",
    "Fr.": "Franța",
    "Franță": "Franța",
    "Franțe": "Franța",
    "Franței": "Franța",
    "frântura": "frântură",
    "frânturi": "frântură",
    "frânturii": "frântură",
    "frânturile": "frântură",
    "frânturilor": "frântură",
    "franțuzeasca": "franțuzesc",
    "franțuzească": "franțuzesc",
    "franțuzescul": "franțuzesc",
    "franțuzescului": "franțuzesc",
    "franțuzești": "franțuzesc",
    "franțuzeștii": "franțuzesc",
    "franțuzeștile": "franțuzesc",
    "franțuzeștilor": "franțuzesc",
    "franțuzea": "franțuzi",
    "franțuzeai": "franțuzi",
    "franțuzeam": "franțuzi",
    "franțuzească": "franțuzi",
    "franțuzeați": "franțuzi",
    "franțuzeau": "franțuzi",
    "franțuzesc": "franțuzi",
    "franțuzește": "franțuzi",
    "franțuzești": "franțuzi",
    "franțuzii": "franțuzi",
    "franțuzim": "franțuzi",
    "franțuzind": "franțuzi",
    "franțuzindu": "franțuzi",
    "franțuziră": "franțuzi",
    "franțuzirăm": "franțuzi",
    "franțuzirăți": "franțuzi",
    "franțuzise": "franțuzi",
    "franțuzisem": "franțuzi",
    "franțuziseră": "franțuzi",
    "franțuziserăm": "franțuzi",
    "franțuziserăți": "franțuzi",
    "franțuziseși": "franțuzi",
    "franțuziși": "franțuzi",
    "franțuzit": "franțuzi",
    "franțuziți": "franțuzi",
    "franțuzitu": "franțuzi",
    "nefranțuzind": "franțuzi",
    "nefranțuzindu": "franțuzi",
    "nemaifranțuzind": "franțuzi",
    "nemaifranțuzindu": "franțuzi",
    "franțuzită": "franțuzit",
    "franțuzite": "franțuzit",
    "franțuziți": "franțuzit",
    "franțuzoaica": "franțuzoaică",
    "franțuzoaice": "franțuzoaică",
    "franțuzoaicei": "franțuzoaică",
    "franțuzoaicele": "franțuzoaică",
    "franțuzoaicelor": "franțuzoaică",
    "franzela": "franzelă",
    "franzele": "franzelă",
    "franzelei": "franzelă",
    "franzelele": "franzelă",
    "franzelelor": "franzelă",
    "frapă": "frapa",
    "frapai": "frapa",
    "frapam": "frapa",
    "frapăm": "frapa",
    "frapând": "frapa",
    "frapându": "frapa",
    "frapară": "frapa",
    "fraparăm": "frapa",
    "fraparăți": "frapa",
    "frapase": "frapa",
    "frapasem": "frapa",
    "frapaseră": "frapa",
    "frapaserăm": "frapa",
    "frapaserăți": "frapa",
    "frapaseși": "frapa",
    "frapași": "frapa",
    "frapat": "frapa",
    "frapați": "frapa",
    "frapatu": "frapa",
    "frapau": "frapa",
    "frapează": "frapa",
    "frapez": "frapa",
    "frapeze": "frapa",
    "frapezi": "frapa",
    "nefrapând": "frapa",
    "nefrapându": "frapa",
    "nemaifrapând": "frapa",
    "nemaifrapându": "frapa",
    "frapanta": "frapant",
    "frapantă": "frapant",
    "frapante": "frapant",
    "frapantei": "frapant",
    "frapantele": "frapant",
    "frapantelor": "frapant",
    "frapanți": "frapant",
    "frapanții": "frapant",
    "frapanților": "frapant",
    "frapantul": "frapant",
    "frapantului": "frapant",
    "frapată": "frapat",
    "frapate": "frapat",
    "frapați": "frapat",
    "frapiera": "frapieră",
    "frapiere": "frapieră",
    "frapierei": "frapieră",
    "frapierele": "frapieră",
    "frapierelor": "frapieră",
    "frasini": "frasin",
    "frasinii": "frasin",
    "frasinilor": "frasin",
    "frasinul": "frasin",
    "frasinului": "frasin",
    "frăsuia": "frăsui",
    "frăsuiai": "frăsui",
    "frăsuiam": "frăsui",
    "frăsuiască": "frăsui",
    "frăsuiați": "frăsui",
    "frăsuiau": "frăsui",
    "frăsuiesc": "frăsui",
    "frăsuiește": "frăsui",
    "frăsuiești": "frăsui",
    "frăsuii": "frăsui",
    "frăsuim": "frăsui",
    "frăsuind": "frăsui",
    "frăsuindu": "frăsui",
    "frăsuiră": "frăsui",
    "frăsuirăm": "frăsui",
    "frăsuirăți": "frăsui",
    "frăsuise": "frăsui",
    "frăsuisem": "frăsui",
    "frăsuiseră": "frăsui",
    "frăsuiserăm": "frăsui",
    "frăsuiserăți": "frăsui",
    "frăsuiseși": "frăsui",
    "frăsuiși": "frăsui",
    "frăsuit": "frăsui",
    "frăsuiți": "frăsui",
    "frăsuitu": "frăsui",
    "nefrăsuind": "frăsui",
    "nefrăsuindu": "frăsui",
    "nemaifrăsuind": "frăsui",
    "nemaifrăsuindu": "frăsui",
    "frăsuită": "frăsuit",
    "frăsuite": "frăsuit",
    "frăsuiți": "frăsuit",
    "fra-te": "frate",
    "fratele": "frate",
    "fratelui": "frate",
    "frați": "frate",
    "frații": "frate",
    "fraților": "frate",
    "FM": "Fratele_cel_Mare",
    "fraterna": "fratern",
    "fraternă": "fratern",
    "fraterne": "fratern",
    "fraternei": "fratern",
    "fraternele": "fratern",
    "fraternelor": "fratern",
    "fraterni": "fratern",
    "fraternii": "fratern",
    "fraternilor": "fratern",
    "fraternul": "fratern",
    "fraternului": "fratern",
    "fraternitatea": "fraternitate",
    "fraternități": "fraternitate",
    "fraternității": "fraternitate",
    "fraterniză": "fraterniza",
    "fraternizai": "fraterniza",
    "fraternizam": "fraterniza",
    "fraternizăm": "fraterniza",
    "fraternizând": "fraterniza",
    "fraternizându": "fraterniza",
    "fraternizară": "fraterniza",
    "fraternizarăm": "fraterniza",
    "fraternizarăți": "fraterniza",
    "fraternizase": "fraterniza",
    "fraternizasem": "fraterniza",
    "fraternizaseră": "fraterniza",
    "fraternizaserăm": "fraterniza",
    "fraternizaserăți": "fraterniza",
    "fraternizaseși": "fraterniza",
    "fraternizași": "fraterniza",
    "fraternizat": "fraterniza",
    "fraternizați": "fraterniza",
    "fraternizatu": "fraterniza",
    "fraternizau": "fraterniza",
    "fraternizează": "fraterniza",
    "fraternizez": "fraterniza",
    "fraternizeze": "fraterniza",
    "fraternizezi": "fraterniza",
    "nefraternizând": "fraterniza",
    "nefraternizându": "fraterniza",
    "nemaifraternizând": "fraterniza",
    "nemaifraternizându": "fraterniza",
    "fraternizată": "fraternizat",
    "fraternizate": "fraternizat",
    "fraternizați": "fraternizat",
    "frățeasca": "frățesc",
    "frățească": "frățesc",
    "frățescul": "frățesc",
    "frățescului": "frățesc",
    "frățești": "frățesc",
    "frățeștii": "frățesc",
    "frățeștile": "frățesc",
    "frățeștilor": "frățesc",
    "frăția": "frăție",
    "frăției": "frăție",
    "frății": "frăție",
    "frățiile": "frăție",
    "frățiilor": "frăție",
    "frățietatea": "frățietate",
    "frățietateo": "frățietate",
    "frâie": "frâu",
    "frâiele": "frâu",
    "frâielor": "frâu",
    "frâul": "frâu",
    "frâului": "frâu",
    "fraudă": "frauda",
    "fraudai": "frauda",
    "fraudam": "frauda",
    "fraudăm": "frauda",
    "fraudând": "frauda",
    "fraudându": "frauda",
    "fraudară": "frauda",
    "fraudarăm": "frauda",
    "fraudarăți": "frauda",
    "fraudase": "frauda",
    "fraudasem": "frauda",
    "fraudaseră": "frauda",
    "fraudaserăm": "frauda",
    "fraudaserăți": "frauda",
    "fraudaseși": "frauda",
    "fraudași": "frauda",
    "fraudat": "frauda",
    "fraudați": "frauda",
    "fraudatu": "frauda",
    "fraudau": "frauda",
    "fraudează": "frauda",
    "fraudez": "frauda",
    "fraudeze": "frauda",
    "fraudezi": "frauda",
    "nefraudând": "frauda",
    "nefraudându": "frauda",
    "nemaifraudând": "frauda",
    "nemaifraudându": "frauda",
    "frauda": "fraudă",
    "fraude": "fraudă",
    "fraudei": "fraudă",
    "fraudele": "fraudă",
    "fraudelor": "fraudă",
    "fraudarea": "fraudare",
    "fraudată": "fraudat",
    "fraudate": "fraudat",
    "fraudați": "fraudat",
    "frauduloasa": "fraudulos",
    "frauduloasă": "fraudulos",
    "frauduloase": "fraudulos",
    "frauduloasei": "fraudulos",
    "frauduloasele": "fraudulos",
    "frauduloaselor": "fraudulos",
    "frauduloși": "fraudulos",
    "frauduloșii": "fraudulos",
    "frauduloșilor": "fraudulos",
    "fraudulosul": "fraudulos",
    "fraudulosului": "fraudulos",
    "frază": "fraza",
    "frazai": "fraza",
    "frazam": "fraza",
    "frazăm": "fraza",
    "frazând": "fraza",
    "frazându": "fraza",
    "frazară": "fraza",
    "frazarăm": "fraza",
    "frazarăți": "fraza",
    "frazase": "fraza",
    "frazasem": "fraza",
    "frazaseră": "fraza",
    "frazaserăm": "fraza",
    "frazaserăți": "fraza",
    "frazaseși": "fraza",
    "frazași": "fraza",
    "frazat": "fraza",
    "frazați": "fraza",
    "frazatu": "fraza",
    "frazau": "fraza",
    "frazează": "fraza",
    "frazez": "fraza",
    "frazeze": "fraza",
    "frazezi": "fraza",
    "nefrazând": "fraza",
    "nefrazându": "fraza",
    "nemaifrazând": "fraza",
    "nemaifrazându": "fraza",
    "fraza": "frază",
    "fraze": "frază",
    "frazei": "frază",
    "frazele": "frază",
    "frazelor": "frază",
    "frazată": "frazat",
    "frazate": "frazat",
    "frazați": "frazat",
    "frazeologia": "frazeologie",
    "frazeologiei": "frazeologie",
    "frazeologii": "frazeologie",
    "frazeologiile": "frazeologie",
    "frazeologiilor": "frazeologie",
    "freamăte": "freamăt",
    "freamătele": "freamăt",
    "freamătelor": "freamăt",
    "freamătul": "freamăt",
    "freamătului": "freamăt",
    "freacă": "freca",
    "frec": "freca",
    "frecă": "freca",
    "frecai": "freca",
    "frecam": "freca",
    "frecăm": "freca",
    "frecând": "freca",
    "frecându": "freca",
    "frecară": "freca",
    "frecarăm": "freca",
    "frecarăți": "freca",
    "frecase": "freca",
    "frecasem": "freca",
    "frecaseră": "freca",
    "frecaserăm": "freca",
    "frecaserăți": "freca",
    "frecaseși": "freca",
    "frecași": "freca",
    "frecat": "freca",
    "frecați": "freca",
    "frecatu": "freca",
    "frecau": "freca",
    "frece": "freca",
    "freci": "freca",
    "nefrecând": "freca",
    "nefrecându": "freca",
    "nemaifrecând": "freca",
    "nemaifrecându": "freca",
    "frecarea": "frecare",
    "frecări": "frecare",
    "frecării": "frecare",
    "frecările": "frecare",
    "frecărilor": "frecare",
    "frecată": "frecat",
    "frecate": "frecat",
    "frecați": "frecat",
    "frecatul": "frecat",
    "frecatului": "frecat",
    "frecția": "frecție",
    "frecției": "frecție",
    "frecții": "frecție",
    "frecțiile": "frecție",
    "frecțiilor": "frecție",
    "frecușul": "frecuș",
    "frecușule": "frecuș",
    "frecușului": "frecuș",
    "frecușuri": "frecuș",
    "frecușurile": "frecuș",
    "frecușurilor": "frecuș",
    "frecventa": "frecvent",
    "frecventă": "frecvent",
    "frecvente": "frecvent",
    "frecventei": "frecvent",
    "frecventele": "frecvent",
    "frecventelor": "frecvent",
    "frecvenți": "frecvent",
    "frecvenții": "frecvent",
    "frecvenților": "frecvent",
    "frecventul": "frecvent",
    "frecventului": "frecvent",
    "frecventă": "frecventa",
    "frecventai": "frecventa",
    "frecventam": "frecventa",
    "frecventăm": "frecventa",
    "frecventând": "frecventa",
    "frecventându": "frecventa",
    "frecventară": "frecventa",
    "frecventarăm": "frecventa",
    "frecventarăți": "frecventa",
    "frecventase": "frecventa",
    "frecventasem": "frecventa",
    "frecventaseră": "frecventa",
    "frecventaserăm": "frecventa",
    "frecventaserăți": "frecventa",
    "frecventaseși": "frecventa",
    "frecventași": "frecventa",
    "frecventat": "frecventa",
    "frecventați": "frecventa",
    "frecventatu": "frecventa",
    "frecventau": "frecventa",
    "frecventează": "frecventa",
    "frecventez": "frecventa",
    "frecventeze": "frecventa",
    "frecventezi": "frecventa",
    "nefrecventând": "frecventa",
    "nefrecventându": "frecventa",
    "nemaifrecventând": "frecventa",
    "nemaifrecventându": "frecventa",
    "frecvența": "frecvență",
    "frecvențe": "frecvență",
    "frecvenței": "frecvență",
    "frecvențele": "frecvență",
    "frecvențelor": "frecvență",
    "frecventarea": "frecventare",
    "frecventareo": "frecventare",
    "frecventări": "frecventare",
    "frecventării": "frecventare",
    "frecventările": "frecventare",
    "frecventărilor": "frecventare",
    "frecventată": "frecventat",
    "frecventate": "frecventat",
    "frecventați": "frecventat",
    "frecventatoare": "frecventator",
    "frecventatoarea": "frecventator",
    "frecventatoarei": "frecventator",
    "frecventatoarele": "frecventator",
    "frecventatoarelor": "frecventator",
    "frecventatoareo": "frecventator",
    "frecventatori": "frecventator",
    "frecventatorii": "frecventator",
    "frecventatorilor": "frecventator",
    "frecventatorul": "frecventator",
    "frecventatorule": "frecventator",
    "frecventatorului": "frecventator",
    "fredonă": "fredona",
    "fredonai": "fredona",
    "fredonam": "fredona",
    "fredonăm": "fredona",
    "fredonând": "fredona",
    "fredonându": "fredona",
    "fredonară": "fredona",
    "fredonarăm": "fredona",
    "fredonarăți": "fredona",
    "fredonase": "fredona",
    "fredonasem": "fredona",
    "fredonaseră": "fredona",
    "fredonaserăm": "fredona",
    "fredonaserăți": "fredona",
    "fredonaseși": "fredona",
    "fredonași": "fredona",
    "fredonat": "fredona",
    "fredonați": "fredona",
    "fredonatu": "fredona",
    "fredonau": "fredona",
    "fredonează": "fredona",
    "fredonez": "fredona",
    "fredoneze": "fredona",
    "fredonezi": "fredona",
    "nefredonând": "fredona",
    "nefredonându": "fredona",
    "nemaifredonând": "fredona",
    "nemaifredonându": "fredona",
    "fredonată": "fredonat",
    "fredonate": "fredonat",
    "fredonați": "fredonat",
    "freamăt": "fremăta",
    "freamătă": "fremăta",
    "freamăți": "fremăta",
    "freamete": "fremăta",
    "fremătă": "fremăta",
    "fremătai": "fremăta",
    "fremătam": "fremăta",
    "fremătăm": "fremăta",
    "fremătând": "fremăta",
    "fremătându": "fremăta",
    "fremătară": "fremăta",
    "fremătarăm": "fremăta",
    "fremătarăți": "fremăta",
    "fremătase": "fremăta",
    "fremătasem": "fremăta",
    "fremătaseră": "fremăta",
    "fremătaserăm": "fremăta",
    "fremătaserăți": "fremăta",
    "fremătaseși": "fremăta",
    "fremătași": "fremăta",
    "fremătat": "fremăta",
    "fremătați": "fremăta",
    "fremătatu": "fremăta",
    "fremătau": "fremăta",
    "nefremătând": "fremăta",
    "nefremătându": "fremăta",
    "nemaifremătând": "fremăta",
    "nemaifremătându": "fremăta",
    "fremătată": "fremătat",
    "fremătate": "fremătat",
    "fremătați": "fremătat",
    "fremătătoare": "fremătător",
    "fremătătoarea": "fremătător",
    "fremătătoarei": "fremătător",
    "fremătătoarele": "fremătător",
    "fremătătoarelor": "fremătător",
    "fremătători": "fremătător",
    "fremătătorii": "fremătător",
    "fremătătorilor": "fremătător",
    "fremătătorul": "fremătător",
    "fremătătorului": "fremătător",
    "frenetica": "frenetic",
    "frenetică": "frenetic",
    "frenetice": "frenetic",
    "freneticei": "frenetic",
    "freneticele": "frenetic",
    "freneticelor": "frenetic",
    "frenetici": "frenetic",
    "freneticii": "frenetic",
    "freneticilor": "frenetic",
    "freneticul": "frenetic",
    "freneticului": "frenetic",
    "frenezia": "frenezie",
    "freneziei": "frenezie",
    "frenezii": "frenezie",
    "freneziile": "frenezie",
    "freneziilor": "frenezie",
    "fresca": "frescă",
    "fresce": "frescă",
    "frescei": "frescă",
    "frescele": "frescă",
    "frescelor": "frescă",
    "fretă": "freta",
    "fretai": "freta",
    "fretam": "freta",
    "fretăm": "freta",
    "fretând": "freta",
    "fretându": "freta",
    "fretară": "freta",
    "fretarăm": "freta",
    "fretarăți": "freta",
    "fretase": "freta",
    "fretasem": "freta",
    "fretaseră": "freta",
    "fretaserăm": "freta",
    "fretaserăți": "freta",
    "fretaseși": "freta",
    "fretași": "freta",
    "fretat": "freta",
    "fretați": "freta",
    "fretatu": "freta",
    "fretau": "freta",
    "fretează": "freta",
    "fretez": "freta",
    "freteze": "freta",
    "fretezi": "freta",
    "nefretând": "freta",
    "nefretându": "freta",
    "nemaifretând": "freta",
    "nemaifretându": "freta",
    "fretată": "fretat",
    "fretate": "fretat",
    "fretați": "fretat",
    "freză": "freza",
    "frezai": "freza",
    "frezam": "freza",
    "frezăm": "freza",
    "frezând": "freza",
    "frezându": "freza",
    "frezară": "freza",
    "frezarăm": "freza",
    "frezarăți": "freza",
    "frezase": "freza",
    "frezasem": "freza",
    "frezaseră": "freza",
    "frezaserăm": "freza",
    "frezaserăți": "freza",
    "frezaseși": "freza",
    "frezași": "freza",
    "frezat": "freza",
    "frezați": "freza",
    "frezatu": "freza",
    "frezau": "freza",
    "frezează": "freza",
    "frezez": "freza",
    "frezeze": "freza",
    "frezezi": "freza",
    "nefrezând": "freza",
    "nefrezându": "freza",
    "nemaifrezând": "freza",
    "nemaifrezându": "freza",
    "freza": "freză",
    "freze": "freză",
    "frezei": "freză",
    "frezele": "freză",
    "frezelor": "freză",
    "frezată": "frezat",
    "frezate": "frezat",
    "frezați": "frezat",
    "frica": "frică",
    "frici": "frică",
    "fricii": "frică",
    "fricile": "frică",
    "fricilor": "frică",
    "frichinea": "frichini",
    "frichineai": "frichini",
    "frichineam": "frichini",
    "frichinească": "frichini",
    "frichineați": "frichini",
    "frichineau": "frichini",
    "frichinesc": "frichini",
    "frichinește": "frichini",
    "frichinești": "frichini",
    "frichinii": "frichini",
    "frichinim": "frichini",
    "frichinind": "frichini",
    "frichinindu": "frichini",
    "frichiniră": "frichini",
    "frichinirăm": "frichini",
    "frichinirăți": "frichini",
    "frichinise": "frichini",
    "frichinisem": "frichini",
    "frichiniseră": "frichini",
    "frichiniserăm": "frichini",
    "frichiniserăți": "frichini",
    "frichiniseși": "frichini",
    "frichiniși": "frichini",
    "frichinit": "frichini",
    "frichiniți": "frichini",
    "frichinitu": "frichini",
    "nefrichinind": "frichini",
    "nefrichinindu": "frichini",
    "nemaifrichinind": "frichini",
    "nemaifrichinindu": "frichini",
    "frichinită": "frichinit",
    "frichinite": "frichinit",
    "frichiniți": "frichinit",
    "fricoasa": "fricos",
    "fricoasă": "fricos",
    "fricoase": "fricos",
    "fricoasei": "fricos",
    "fricoasele": "fricos",
    "fricoaselor": "fricos",
    "fricoși": "fricos",
    "fricoșii": "fricos",
    "fricoșilor": "fricos",
    "fricosul": "fricos",
    "fricosului": "fricos",
    "fricționă": "fricționa",
    "fricționai": "fricționa",
    "fricționam": "fricționa",
    "fricționăm": "fricționa",
    "fricționând": "fricționa",
    "fricționându": "fricționa",
    "fricționară": "fricționa",
    "fricționarăm": "fricționa",
    "fricționarăți": "fricționa",
    "fricționase": "fricționa",
    "fricționasem": "fricționa",
    "fricționaseră": "fricționa",
    "fricționaserăm": "fricționa",
    "fricționaserăți": "fricționa",
    "fricționaseși": "fricționa",
    "fricționași": "fricționa",
    "fricționat": "fricționa",
    "fricționați": "fricționa",
    "fricționatu": "fricționa",
    "fricționau": "fricționa",
    "fricționează": "fricționa",
    "fricționez": "fricționa",
    "fricționeze": "fricționa",
    "fricționezi": "fricționa",
    "nefricționând": "fricționa",
    "nefricționându": "fricționa",
    "nemaifricționând": "fricționa",
    "nemaifricționându": "fricționa",
    "fricționată": "fricționat",
    "fricționate": "fricționat",
    "fricționați": "fricționat",
    "fricțiunea": "fricțiune",
    "fricțiuni": "fricțiune",
    "fricțiunii": "fricțiune",
    "fricțiunile": "fricțiune",
    "fricțiunilor": "fricțiune",
    "frigul": "frig",
    "frigului": "frig",
    "friguri": "frig",
    "frigurile": "frig",
    "frigurilor": "frig",
    "frigarea": "frigare",
    "frigări": "frigare",
    "frigării": "frigare",
    "frigările": "frigare",
    "frigărilor": "frigare",
    "frig": "frige",
    "frigă": "frige",
    "frigând": "frige",
    "frigându": "frige",
    "frigea": "frige",
    "frigeai": "frige",
    "frigeam": "frige",
    "frigeați": "frige",
    "frigeau": "frige",
    "frigem": "frige",
    "frigeți": "frige",
    "frigi": "frige",
    "fripse": "frige",
    "fripsei": "frige",
    "fripseră": "frige",
    "fripserăm": "frige",
    "fripserăți": "frige",
    "fripsese": "frige",
    "fripsesem": "frige",
    "fripseseră": "frige",
    "fripseserăm": "frige",
    "fripseserăți": "frige",
    "fripseseși": "frige",
    "fripseși": "frige",
    "fript": "frige",
    "friptu": "frige",
    "nefrigând": "frige",
    "nefrigându": "frige",
    "nemaifrigând": "frige",
    "nemaifrigându": "frige",
    "frigida": "frigid",
    "frigidă": "frigid",
    "frigide": "frigid",
    "frigidei": "frigid",
    "frigidele": "frigid",
    "frigidelor": "frigid",
    "frigidul": "frigid",
    "frigidului": "frigid",
    "frigizi": "frigid",
    "frigizii": "frigid",
    "frigizilor": "frigid",
    "frigidere": "frigider",
    "frigiderele": "frigider",
    "frigiderelor": "frigider",
    "frigiderul": "frigider",
    "frigiderului": "frigider",
    "frigiditatea": "frigiditate",
    "frigidități": "frigiditate",
    "frigidității": "frigiditate",
    "frig.": "frigorifer",
    "frigorifera": "frigorifer",
    "frigoriferă": "frigorifer",
    "frigorifere": "frigorifer",
    "frigoriferei": "frigorifer",
    "frigoriferele": "frigorifer",
    "frigoriferelor": "frigorifer",
    "frigoriferi": "frigorifer",
    "frigoriferii": "frigorifer",
    "frigoriferilor": "frigorifer",
    "frigoriferul": "frigorifer",
    "frigoriferului": "frigorifer",
    "friguroasa": "friguros",
    "friguroasă": "friguros",
    "friguroase": "friguros",
    "friguroasei": "friguros",
    "friguroasele": "friguros",
    "friguroaselor": "friguros",
    "friguroși": "friguros",
    "friguroșii": "friguros",
    "friguroșilor": "friguros",
    "frigurosul": "friguros",
    "frigurosului": "friguros",
    "friptă": "fript",
    "fripte": "fript",
    "fripți": "fript",
    "friptura": "friptură",
    "fripturi": "friptură",
    "fripturii": "friptură",
    "fripturile": "friptură",
    "fripturilor": "friptură",
    "frișca": "frișcă",
    "frișcăi": "frișcă",
    "frisoane": "frison",
    "frisoanele": "frison",
    "frisoanelor": "frison",
    "frisonul": "frison",
    "frisonului": "frison",
    "frivola": "frivol",
    "frivolă": "frivol",
    "frivole": "frivol",
    "frivolei": "frivol",
    "frivolele": "frivol",
    "frivolelor": "frivol",
    "frivoli": "frivol",
    "frivolii": "frivol",
    "frivolilor": "frivol",
    "frivolul": "frivol",
    "frivolului": "frivol",
    "frivolitatea": "frivolitate",
    "frivolități": "frivolitate",
    "frivolității": "frivolitate",
    "frivolitățile": "frivolitate",
    "frivolităților": "frivolitate",
    "friză": "friza",
    "frizai": "friza",
    "frizam": "friza",
    "frizăm": "friza",
    "frizând": "friza",
    "frizându": "friza",
    "frizară": "friza",
    "frizarăm": "friza",
    "frizarăți": "friza",
    "frizase": "friza",
    "frizasem": "friza",
    "frizaseră": "friza",
    "frizaserăm": "friza",
    "frizaserăți": "friza",
    "frizaseși": "friza",
    "frizași": "friza",
    "frizat": "friza",
    "frizați": "friza",
    "frizatu": "friza",
    "frizau": "friza",
    "frizează": "friza",
    "frizez": "friza",
    "frizeze": "friza",
    "frizezi": "friza",
    "nefrizând": "friza",
    "nefrizându": "friza",
    "nemaifrizând": "friza",
    "nemaifrizându": "friza",
    "frizată": "frizat",
    "frizate": "frizat",
    "frizați": "frizat",
    "frizeri": "frizer",
    "frizerii": "frizer",
    "frizerilor": "frizer",
    "frizerul": "frizer",
    "frizerului": "frizer",
    "frizeria": "frizerie",
    "frizeriei": "frizerie",
    "frizerii": "frizerie",
    "frizeriile": "frizerie",
    "frizeriilor": "frizerie",
    "fronda": "frondă",
    "fronde": "frondă",
    "frondei": "frondă",
    "frondele": "frondă",
    "frondelor": "frondă",
    "frondo": "frondă",
    "frontul": "front",
    "frontului": "front",
    "fronturi": "front",
    "fronturile": "front",
    "fronturilor": "front",
    "frontala": "frontal",
    "frontală": "frontal",
    "frontale": "frontal",
    "frontalei": "frontal",
    "frontalele": "frontal",
    "frontalelor": "frontal",
    "frontali": "frontal",
    "frontalii": "frontal",
    "frontalilor": "frontal",
    "frontalul": "frontal",
    "frontalului": "frontal",
    "frontiera": "frontieră",
    "frontiere": "frontieră",
    "frontierei": "frontieră",
    "frontierele": "frontieră",
    "frontierelor": "frontieră",
    "frontoane": "fronton",
    "frontoanele": "fronton",
    "frontoanelor": "fronton",
    "frontonul": "fronton",
    "frontonului": "fronton",
    "FSN": "Frontul_Salvării_Naționale",
    "frotă": "frota",
    "frotai": "frota",
    "frotam": "frota",
    "frotăm": "frota",
    "frotând": "frota",
    "frotându": "frota",
    "frotară": "frota",
    "frotarăm": "frota",
    "frotarăți": "frota",
    "frotase": "frota",
    "frotasem": "frota",
    "frotaseră": "frota",
    "frotaserăm": "frota",
    "frotaserăți": "frota",
    "frotaseși": "frota",
    "frotași": "frota",
    "frotat": "frota",
    "frotați": "frota",
    "frotatu": "frota",
    "frotau": "frota",
    "frotează": "frota",
    "frotez": "frota",
    "froteze": "frota",
    "frotezi": "frota",
    "nefrotând": "frota",
    "nefrotându": "frota",
    "nemaifrotând": "frota",
    "nemaifrotându": "frota",
    "frotată": "frotat",
    "frotate": "frotat",
    "frotați": "frotat",
    "fructe": "fruct",
    "fructele": "fruct",
    "fructelor": "fruct",
    "fructul": "fruct",
    "fructului": "fruct",
    "fructifera": "fructifer",
    "fructiferă": "fructifer",
    "fructifere": "fructifer",
    "fructiferei": "fructifer",
    "fructiferele": "fructifer",
    "fructiferelor": "fructifer",
    "fructiferi": "fructifer",
    "fructiferii": "fructifer",
    "fructiferilor": "fructifer",
    "fructiferul": "fructifer",
    "fructiferului": "fructifer",
    "fructific": "fructifica",
    "fructifică": "fructifica",
    "fructificai": "fructifica",
    "fructificam": "fructifica",
    "fructificăm": "fructifica",
    "fructificând": "fructifica",
    "fructificându": "fructifica",
    "fructificară": "fructifica",
    "fructificarăm": "fructifica",
    "fructificarăți": "fructifica",
    "fructificase": "fructifica",
    "fructificasem": "fructifica",
    "fructificaseră": "fructifica",
    "fructificaserăm": "fructifica",
    "fructificaserăți": "fructifica",
    "fructificaseși": "fructifica",
    "fructificași": "fructifica",
    "fructificat": "fructifica",
    "fructificați": "fructifica",
    "fructificatu": "fructifica",
    "fructificau": "fructifica",
    "fructifice": "fructifica",
    "fructifici": "fructifica",
    "nefructificând": "fructifica",
    "nefructificându": "fructifica",
    "nemaifructificând": "fructifica",
    "nemaifructificându": "fructifica",
    "fructificată": "fructificat",
    "fructificate": "fructificat",
    "fructificați": "fructificat",
    "fructuoasa": "fructuos",
    "fructuoasă": "fructuos",
    "fructuoase": "fructuos",
    "fructuoasei": "fructuos",
    "fructuoasele": "fructuos",
    "fructuoaselor": "fructuos",
    "fructuoși": "fructuos",
    "fructuoșii": "fructuos",
    "fructuoșilor": "fructuos",
    "fructuosul": "fructuos",
    "fructuosului": "fructuos",
    "frugala": "frugal",
    "frugală": "frugal",
    "frugale": "frugal",
    "frugalei": "frugal",
    "frugalele": "frugal",
    "frugalelor": "frugal",
    "frugali": "frugal",
    "frugalii": "frugal",
    "frugalilor": "frugal",
    "frugalul": "frugal",
    "frugalului": "frugal",
    "frumoasa": "frumos",
    "frumoasă": "frumos",
    "frumoase": "frumos",
    "frumoasei": "frumos",
    "frumoasele": "frumos",
    "frumoaselor": "frumos",
    "frumoși": "frumos",
    "frumoșii": "frumos",
    "frumoșilor": "frumos",
    "frumosul": "frumos",
    "frumosului": "frumos",
    "frumușei": "frumușel",
    "frumușeii": "frumușel",
    "frumușeilor": "frumușel",
    "frumușele": "frumușel",
    "frumușelei": "frumușel",
    "frumușelele": "frumușel",
    "frumușelelor": "frumușel",
    "frumușelul": "frumușel",
    "frumușelului": "frumușel",
    "frumușica": "frumușel",
    "frumușică": "frumușel",
    "frumusețea": "frumusețe",
    "frumuseți": "frumusețe",
    "frumuseții": "frumusețe",
    "frumusețile": "frumusețe",
    "frumuseților": "frumusețe",
    "fruntașa": "fruntaș",
    "fruntașă": "fruntaș",
    "fruntașe": "fruntaș",
    "fruntașei": "fruntaș",
    "fruntașele": "fruntaș",
    "fruntașelor": "fruntaș",
    "fruntași": "fruntaș",
    "fruntașii": "fruntaș",
    "fruntașilor": "fruntaș",
    "fruntașul": "fruntaș",
    "fruntașului": "fruntaș",
    "fruntea": "frunte",
    "frunți": "frunte",
    "frunții": "frunte",
    "frunțile": "frunte",
    "frunților": "frunte",
    "frunza": "frunză",
    "frunze": "frunză",
    "frunzei": "frunză",
    "frunzele": "frunză",
    "frunzelor": "frunză",
    "frunza-de-potcă": "frunză-de-potcă",
    "frunzei-de-potcă": "frunză-de-potcă",
    "frunzărea": "frunzări",
    "frunzăreai": "frunzări",
    "frunzăream": "frunzări",
    "frunzărească": "frunzări",
    "frunzăreați": "frunzări",
    "frunzăreau": "frunzări",
    "frunzăresc": "frunzări",
    "frunzărește": "frunzări",
    "frunzărești": "frunzări",
    "frunzării": "frunzări",
    "frunzărim": "frunzări",
    "frunzărind": "frunzări",
    "frunzărindu": "frunzări",
    "frunzăriră": "frunzări",
    "frunzărirăm": "frunzări",
    "frunzărirăți": "frunzări",
    "frunzărise": "frunzări",
    "frunzărisem": "frunzări",
    "frunzăriseră": "frunzări",
    "frunzăriserăm": "frunzări",
    "frunzăriserăți": "frunzări",
    "frunzăriseși": "frunzări",
    "frunzăriși": "frunzări",
    "frunzărit": "frunzări",
    "frunzăriți": "frunzări",
    "frunzăritu": "frunzări",
    "nefrunzărind": "frunzări",
    "nefrunzărindu": "frunzări",
    "nemaifrunzărind": "frunzări",
    "nemaifrunzărindu": "frunzări",
    "frunzărită": "frunzărit",
    "frunzărite": "frunzărit",
    "frunzăriți": "frunzărit",
    "frunzișul": "frunziș",
    "frunzișului": "frunziș",
    "frunzișuri": "frunziș",
    "frunzișurile": "frunziș",
    "frunzișurilor": "frunziș",
    "frunzulița": "frunzuliță",
    "frunzulițe": "frunzuliță",
    "frunzuliței": "frunzuliță",
    "frunzulițele": "frunzuliță",
    "frunzulițelor": "frunzuliță",
    "frustră": "frustra",
    "frustrai": "frustra",
    "frustram": "frustra",
    "frustrăm": "frustra",
    "frustrând": "frustra",
    "frustrându": "frustra",
    "frustrară": "frustra",
    "frustrarăm": "frustra",
    "frustrarăți": "frustra",
    "frustrase": "frustra",
    "frustrasem": "frustra",
    "frustraseră": "frustra",
    "frustraserăm": "frustra",
    "frustraserăți": "frustra",
    "frustraseși": "frustra",
    "frustrași": "frustra",
    "frustrat": "frustra",
    "frustrați": "frustra",
    "frustratu": "frustra",
    "frustrau": "frustra",
    "frustrează": "frustra",
    "frustrez": "frustra",
    "frustreze": "frustra",
    "frustrezi": "frustra",
    "nefrustrând": "frustra",
    "nefrustrându": "frustra",
    "nemaifrustrând": "frustra",
    "nemaifrustrându": "frustra",
    "frustrarea": "frustrare",
    "frustrări": "frustrare",
    "frustrării": "frustrare",
    "frustrările": "frustrare",
    "frustrărilor": "frustrare",
    "frustrată": "frustrat",
    "frustrate": "frustrat",
    "frustrați": "frustrat",
    "ftizia": "ftizie",
    "ftiziei": "ftizie",
    "ftizii": "ftizie",
    "ftiziile": "ftizie",
    "ftiziilor": "ftizie",
    "fudula": "fudul",
    "fudulă": "fudul",
    "fudule": "fudul",
    "fudulei": "fudul",
    "fudulele": "fudul",
    "fudulelor": "fudul",
    "fuduli": "fudul",
    "fudulii": "fudul",
    "fudulilor": "fudul",
    "fudulul": "fudul",
    "fudulului": "fudul",
    "fudulea": "fuduli",
    "fuduleai": "fuduli",
    "fuduleam": "fuduli",
    "fudulească": "fuduli",
    "fuduleați": "fuduli",
    "fuduleau": "fuduli",
    "fudulesc": "fuduli",
    "fudulește": "fuduli",
    "fudulești": "fuduli",
    "fudulii": "fuduli",
    "fudulim": "fuduli",
    "fudulind": "fuduli",
    "fudulindu": "fuduli",
    "fuduliră": "fuduli",
    "fudulirăm": "fuduli",
    "fudulirăți": "fuduli",
    "fudulise": "fuduli",
    "fudulisem": "fuduli",
    "fuduliseră": "fuduli",
    "fuduliserăm": "fuduli",
    "fuduliserăți": "fuduli",
    "fuduliseși": "fuduli",
    "fuduliși": "fuduli",
    "fudulit": "fuduli",
    "fuduliți": "fuduli",
    "fudulitu": "fuduli",
    "nefudulind": "fuduli",
    "nefudulindu": "fuduli",
    "nemaifudulind": "fuduli",
    "nemaifudulindu": "fuduli",
    "fudulită": "fudulit",
    "fudulite": "fudulit",
    "fuduliți": "fudulit",
    "fufa": "fufă",
    "fufe": "fufă",
    "fufei": "fufă",
    "fufele": "fufă",
    "fufelor": "fufă",
    "fuga": "fugă",
    "fugi": "fugă",
    "fugii": "fugă",
    "fugile": "fugă",
    "fugilor": "fugă",
    "fugara": "fugar",
    "fugară": "fugar",
    "fugare": "fugar",
    "fugarei": "fugar",
    "fugarele": "fugar",
    "fugarelor": "fugar",
    "fugari": "fugar",
    "fugarii": "fugar",
    "fugarilor": "fugar",
    "fugarul": "fugar",
    "fugarului": "fugar",
    "fugărea": "fugări",
    "fugăreai": "fugări",
    "fugăream": "fugări",
    "fugărească": "fugări",
    "fugăreați": "fugări",
    "fugăreau": "fugări",
    "fugăresc": "fugări",
    "fugărește": "fugări",
    "fugărești": "fugări",
    "fugării": "fugări",
    "fugărim": "fugări",
    "fugărind": "fugări",
    "fugărindu": "fugări",
    "fugăriră": "fugări",
    "fugărirăm": "fugări",
    "fugărirăți": "fugări",
    "fugărise": "fugări",
    "fugărisem": "fugări",
    "fugăriseră": "fugări",
    "fugăriserăm": "fugări",
    "fugăriserăți": "fugări",
    "fugăriseși": "fugări",
    "fugăriși": "fugări",
    "fugărit": "fugări",
    "fugăriți": "fugări",
    "fugăritu": "fugări",
    "nefugărind": "fugări",
    "nefugărindu": "fugări",
    "nemaifugărind": "fugări",
    "nemaifugărindu": "fugări",
    "fugărită": "fugărit",
    "fugărite": "fugărit",
    "fugăriți": "fugărit",
    "fug": "fugi",
    "fugă": "fugi",
    "fuge": "fugi",
    "fugea": "fugi",
    "fugeai": "fugi",
    "fugeam": "fugi",
    "fugeați": "fugi",
    "fugeau": "fugi",
    "fugii": "fugi",
    "fugim": "fugi",
    "fugind": "fugi",
    "fugindu": "fugi",
    "fugiră": "fugi",
    "fugirăm": "fugi",
    "fugirăți": "fugi",
    "fugise": "fugi",
    "fugisem": "fugi",
    "fugiseră": "fugi",
    "fugiserăm": "fugi",
    "fugiserăți": "fugi",
    "fugiseși": "fugi",
    "fugiși": "fugi",
    "fugit": "fugi",
    "fugiți": "fugi",
    "fugitu": "fugi",
    "nefugind": "fugi",
    "nefugindu": "fugi",
    "nemaifugind": "fugi",
    "nemaifugindu": "fugi",
    "fugita": "fugit",
    "fugită": "fugit",
    "fugite": "fugit",
    "fugitei": "fugit",
    "fugitele": "fugit",
    "fugitelor": "fugit",
    "fugiți": "fugit",
    "fugiții": "fugit",
    "fugiților": "fugit",
    "fugito": "fugit",
    "fugitul": "fugit",
    "fugitule": "fugit",
    "fugitului": "fugit",
    "fuguia": "fugui",
    "fuguiai": "fugui",
    "fuguiam": "fugui",
    "fuguiască": "fugui",
    "fuguiați": "fugui",
    "fuguiau": "fugui",
    "fuguiesc": "fugui",
    "fuguiește": "fugui",
    "fuguiești": "fugui",
    "fuguii": "fugui",
    "fuguim": "fugui",
    "fuguind": "fugui",
    "fuguindu": "fugui",
    "fuguiră": "fugui",
    "fuguirăm": "fugui",
    "fuguirăți": "fugui",
    "fuguise": "fugui",
    "fuguisem": "fugui",
    "fuguiseră": "fugui",
    "fuguiserăm": "fugui",
    "fuguiserăți": "fugui",
    "fuguiseși": "fugui",
    "fuguiși": "fugui",
    "fuguit": "fugui",
    "fuguiți": "fugui",
    "fuguitu": "fugui",
    "nefuguind": "fugui",
    "nefuguindu": "fugui",
    "nemaifuguind": "fugui",
    "nemaifuguindu": "fugui",
    "fuguită": "fuguit",
    "fuguite": "fuguit",
    "fuguiți": "fuguit",
    "fuioare": "fuior",
    "fuioarele": "fuior",
    "fuioarelor": "fuior",
    "fuiorul": "fuior",
    "fuiorule": "fuior",
    "fuiorului": "fuior",
    "fulă": "fula",
    "fulai": "fula",
    "fulam": "fula",
    "fulăm": "fula",
    "fulând": "fula",
    "fulându": "fula",
    "fulară": "fula",
    "fularăm": "fula",
    "fularăți": "fula",
    "fulase": "fula",
    "fulasem": "fula",
    "fulaseră": "fula",
    "fulaserăm": "fula",
    "fulaserăți": "fula",
    "fulaseși": "fula",
    "fulași": "fula",
    "fulat": "fula",
    "fulați": "fula",
    "fulatu": "fula",
    "fulau": "fula",
    "fulează": "fula",
    "fulez": "fula",
    "fuleze": "fula",
    "fulezi": "fula",
    "nefulând": "fula",
    "nefulându": "fula",
    "nemaifulând": "fula",
    "nemaifulându": "fula",
    "fulare": "fular",
    "fularele": "fular",
    "fularelor": "fular",
    "fularul": "fular",
    "fularului": "fular",
    "fulardă": "fularda",
    "fulardai": "fularda",
    "fulardam": "fularda",
    "fulardăm": "fularda",
    "fulardând": "fularda",
    "fulardându": "fularda",
    "fulardară": "fularda",
    "fulardarăm": "fularda",
    "fulardarăți": "fularda",
    "fulardase": "fularda",
    "fulardasem": "fularda",
    "fulardaseră": "fularda",
    "fulardaserăm": "fularda",
    "fulardaserăți": "fularda",
    "fulardaseși": "fularda",
    "fulardași": "fularda",
    "fulardat": "fularda",
    "fulardați": "fularda",
    "fulardatu": "fularda",
    "fulardau": "fularda",
    "fulardează": "fularda",
    "fulardez": "fularda",
    "fulardeze": "fularda",
    "fulardezi": "fularda",
    "nefulardând": "fularda",
    "nefulardându": "fularda",
    "nemaifulardând": "fularda",
    "nemaifulardându": "fularda",
    "fulardată": "fulardat",
    "fulardate": "fulardat",
    "fulardați": "fulardat",
    "fulată": "fulat",
    "fulate": "fulat",
    "fulați": "fulat",
    "fulgi": "fulg",
    "fulgii": "fulg",
    "fulgilor": "fulg",
    "fulgul": "fulg",
    "fulgului": "fulg",
    "fulgere": "fulger",
    "fulgerele": "fulger",
    "fulgerelor": "fulger",
    "fulgerul": "fulger",
    "fulgerului": "fulger",
    "fulger": "fulgera",
    "fulgeră": "fulgera",
    "fulgerai": "fulgera",
    "fulgeram": "fulgera",
    "fulgerăm": "fulgera",
    "fulgerând": "fulgera",
    "fulgerându": "fulgera",
    "fulgerară": "fulgera",
    "fulgerarăm": "fulgera",
    "fulgerarăți": "fulgera",
    "fulgerase": "fulgera",
    "fulgerasem": "fulgera",
    "fulgeraseră": "fulgera",
    "fulgeraserăm": "fulgera",
    "fulgeraserăți": "fulgera",
    "fulgeraseși": "fulgera",
    "fulgerași": "fulgera",
    "fulgerat": "fulgera",
    "fulgerați": "fulgera",
    "fulgeratu": "fulgera",
    "fulgerau": "fulgera",
    "fulgere": "fulgera",
    "fulgeri": "fulgera",
    "nefulgerând": "fulgera",
    "nefulgerându": "fulgera",
    "nemaifulgerând": "fulgera",
    "nemaifulgerându": "fulgera",
    "fulgerarea": "fulgerare",
    "fulgerareo": "fulgerare",
    "fulgerări": "fulgerare",
    "fulgerării": "fulgerare",
    "fulgerările": "fulgerare",
    "fulgerărilor": "fulgerare",
    "fulgerată": "fulgerat",
    "fulgerate": "fulgerat",
    "fulgerați": "fulgerat",
    "fulgerătoare": "fulgerător",
    "fulgerătoarea": "fulgerător",
    "fulgerătoarei": "fulgerător",
    "fulgerătoarele": "fulgerător",
    "fulgerătoarelor": "fulgerător",
    "fulgerători": "fulgerător",
    "fulgerătorii": "fulgerător",
    "fulgerătorilor": "fulgerător",
    "fulgerătorul": "fulgerător",
    "fulgerătorului": "fulgerător",
    "fulguia": "fulgui",
    "fulguiască": "fulgui",
    "fulguiau": "fulgui",
    "fulguiesc": "fulgui",
    "fulguiește": "fulgui",
    "fulguind": "fulgui",
    "fulguindu": "fulgui",
    "fulguiră": "fulgui",
    "fulguise": "fulgui",
    "fulguiseră": "fulgui",
    "fulguit": "fulgui",
    "fulguitu": "fulgui",
    "nefulguind": "fulgui",
    "nefulguindu": "fulgui",
    "nemaifulguind": "fulgui",
    "nemaifulguindu": "fulgui",
    "fulguită": "fulguit",
    "fulguite": "fulguit",
    "fulguiți": "fulguit",
    "fulminanta": "fulminant",
    "fulminantă": "fulminant",
    "fulminante": "fulminant",
    "fulminantei": "fulminant",
    "fulminantele": "fulminant",
    "fulminantelor": "fulminant",
    "fulminanți": "fulminant",
    "fulminanții": "fulminant",
    "fulminanților": "fulminant",
    "fulminantul": "fulminant",
    "fulminantului": "fulminant",
    "fumul": "fum",
    "fumului": "fum",
    "fumuri": "fum",
    "fumurile": "fum",
    "fumurilor": "fum",
    "fumă": "fuma",
    "fumai": "fuma",
    "fumam": "fuma",
    "fumăm": "fuma",
    "fumând": "fuma",
    "fumându": "fuma",
    "fumară": "fuma",
    "fumarăm": "fuma",
    "fumarăți": "fuma",
    "fumase": "fuma",
    "fumasem": "fuma",
    "fumaseră": "fuma",
    "fumaserăm": "fuma",
    "fumaserăți": "fuma",
    "fumaseși": "fuma",
    "fumași": "fuma",
    "fumat": "fuma",
    "fumați": "fuma",
    "fumatu": "fuma",
    "fumau": "fuma",
    "fumează": "fuma",
    "fumez": "fuma",
    "fumeze": "fuma",
    "fumezi": "fuma",
    "nefumând": "fuma",
    "nefumându": "fuma",
    "nemaifumând": "fuma",
    "nemaifumându": "fuma",
    "fumată": "fumat",
    "fumate": "fumat",
    "fumați": "fumat",
    "fumatul": "fumat",
    "fumatului": "fumat",
    "fumători": "fumător",
    "fumătorii": "fumător",
    "fumătorilor": "fumător",
    "fumătorul": "fumător",
    "fumătorului": "fumător",
    "fumeg": "fumega",
    "fumegă": "fumega",
    "fumegai": "fumega",
    "fumegam": "fumega",
    "fumegăm": "fumega",
    "fumegând": "fumega",
    "fumegându": "fumega",
    "fumegară": "fumega",
    "fumegarăm": "fumega",
    "fumegarăți": "fumega",
    "fumegase": "fumega",
    "fumegasem": "fumega",
    "fumegaseră": "fumega",
    "fumegaserăm": "fumega",
    "fumegaserăți": "fumega",
    "fumegaseși": "fumega",
    "fumegași": "fumega",
    "fumegat": "fumega",
    "fumegați": "fumega",
    "fumegatu": "fumega",
    "fumegau": "fumega",
    "fumege": "fumega",
    "fumegi": "fumega",
    "nefumegând": "fumega",
    "nefumegându": "fumega",
    "nemaifumegând": "fumega",
    "nemaifumegându": "fumega",
    "fumegânda": "fumegând",
    "fumegândă": "fumegând",
    "fumegânde": "fumegând",
    "fumegândei": "fumegând",
    "fumegândele": "fumegând",
    "fumegândelor": "fumegând",
    "fumegândo": "fumegând",
    "fumegândul": "fumegând",
    "fumegândule": "fumegând",
    "fumegândului": "fumegând",
    "fumegânzi": "fumegând",
    "fumegânzii": "fumegând",
    "fumegânzilor": "fumegând",
    "fumegată": "fumegat",
    "fumegate": "fumegat",
    "fumegați": "fumegat",
    "fumiză": "fumiza",
    "fumizai": "fumiza",
    "fumizam": "fumiza",
    "fumizăm": "fumiza",
    "fumizând": "fumiza",
    "fumizându": "fumiza",
    "fumizară": "fumiza",
    "fumizarăm": "fumiza",
    "fumizarăți": "fumiza",
    "fumizase": "fumiza",
    "fumizasem": "fumiza",
    "fumizaseră": "fumiza",
    "fumizaserăm": "fumiza",
    "fumizaserăți": "fumiza",
    "fumizaseși": "fumiza",
    "fumizași": "fumiza",
    "fumizat": "fumiza",
    "fumizați": "fumiza",
    "fumizatu": "fumiza",
    "fumizau": "fumiza",
    "fumizează": "fumiza",
    "fumizez": "fumiza",
    "fumizeze": "fumiza",
    "fumizezi": "fumiza",
    "nefumizând": "fumiza",
    "nefumizându": "fumiza",
    "nemaifumizând": "fumiza",
    "nemaifumizându": "fumiza",
    "fumizată": "fumizat",
    "fumizate": "fumizat",
    "fumizați": "fumizat",
    "fumoare": "fumoar",
    "fumoarele": "fumoar",
    "fumoarelor": "fumoar",
    "fumoarul": "fumoar",
    "fumoarului": "fumoar",
    "fumuia": "fumui",
    "fumuiai": "fumui",
    "fumuiam": "fumui",
    "fumuiască": "fumui",
    "fumuiați": "fumui",
    "fumuiau": "fumui",
    "fumuiesc": "fumui",
    "fumuiește": "fumui",
    "fumuiești": "fumui",
    "fumuii": "fumui",
    "fumuim": "fumui",
    "fumuind": "fumui",
    "fumuindu": "fumui",
    "fumuiră": "fumui",
    "fumuirăm": "fumui",
    "fumuirăți": "fumui",
    "fumuise": "fumui",
    "fumuisem": "fumui",
    "fumuiseră": "fumui",
    "fumuiserăm": "fumui",
    "fumuiserăți": "fumui",
    "fumuiseși": "fumui",
    "fumuiși": "fumui",
    "fumuit": "fumui",
    "fumuiți": "fumui",
    "fumuitu": "fumui",
    "nefumuind": "fumui",
    "nefumuindu": "fumui",
    "nemaifumuind": "fumui",
    "nemaifumuindu": "fumui",
    "fumuită": "fumuit",
    "fumuite": "fumuit",
    "fumuiți": "fumuit",
    "fumuria": "fumuriu",
    "fumurie": "fumuriu",
    "fumuriei": "fumuriu",
    "fumurii": "fumuriu",
    "fumuriii": "fumuriu",
    "fumuriile": "fumuriu",
    "fumuriilor": "fumuriu",
    "fumuriul": "fumuriu",
    "fumuriului": "fumuriu",
    "funciara": "funciar",
    "funciară": "funciar",
    "funciare": "funciar",
    "funciarei": "funciar",
    "funciarele": "funciar",
    "funciarelor": "funciar",
    "funciari": "funciar",
    "funciarii": "funciar",
    "funciarilor": "funciar",
    "funciarul": "funciar",
    "funciarului": "funciar",
    "funcția": "funcție",
    "funcției": "funcție",
    "funcții": "funcție",
    "funcțiile": "funcție",
    "funcțiilor": "funcție",
    "funcționă": "funcționa",
    "funcționai": "funcționa",
    "funcționam": "funcționa",
    "funcționăm": "funcționa",
    "funcționând": "funcționa",
    "funcționându": "funcționa",
    "funcționară": "funcționa",
    "funcționarăm": "funcționa",
    "funcționarăți": "funcționa",
    "funcționase": "funcționa",
    "funcționasem": "funcționa",
    "funcționaseră": "funcționa",
    "funcționaserăm": "funcționa",
    "funcționaserăți": "funcționa",
    "funcționaseși": "funcționa",
    "funcționași": "funcționa",
    "funcționat": "funcționa",
    "funcționați": "funcționa",
    "funcționatu": "funcționa",
    "funcționau": "funcționa",
    "funcționează": "funcționa",
    "funcționez": "funcționa",
    "funcționeze": "funcționa",
    "funcționezi": "funcționa",
    "nefuncționând": "funcționa",
    "nefuncționându": "funcționa",
    "nemaifuncționând": "funcționa",
    "nemaifuncționându": "funcționa",
    "funcționala": "funcțional",
    "funcțională": "funcțional",
    "funcționale": "funcțional",
    "funcționalei": "funcțional",
    "funcționalele": "funcțional",
    "funcționalelor": "funcțional",
    "funcționali": "funcțional",
    "funcționalii": "funcțional",
    "funcționalilor": "funcțional",
    "funcționalo": "funcțional",
    "funcționalul": "funcțional",
    "funcționalule": "funcțional",
    "funcționalului": "funcțional",
    "funcționari": "funcționar",
    "funcționarii": "funcționar",
    "funcționarilor": "funcționar",
    "funcționarul": "funcționar",
    "funcționarului": "funcționar",
    "funcționara": "funcționară",
    "funcționare": "funcționară",
    "funcționarei": "funcționară",
    "funcționarele": "funcționară",
    "funcționarelor": "funcționară",
    "funcționarea": "funcționare",
    "funcționareo": "funcționare",
    "funcționări": "funcționare",
    "funcționării": "funcționare",
    "funcționările": "funcționare",
    "funcționărilor": "funcționare",
    "funcționată": "funcționat",
    "funcționate": "funcționat",
    "funcționați": "funcționat",
    "funcțiunea": "funcțiune",
    "funcțiuni": "funcțiune",
    "funcțiunii": "funcțiune",
    "funcțiunile": "funcțiune",
    "funcțiunilor": "funcțiune",
    "fundul": "fund",
    "fundului": "fund",
    "funduri": "fund",
    "fundurile": "fund",
    "fundurilor": "fund",
    "fundă": "funda",
    "fundai": "funda",
    "fundam": "funda",
    "fundăm": "funda",
    "fundând": "funda",
    "fundându": "funda",
    "fundară": "funda",
    "fundarăm": "funda",
    "fundarăți": "funda",
    "fundase": "funda",
    "fundasem": "funda",
    "fundaseră": "funda",
    "fundaserăm": "funda",
    "fundaserăți": "funda",
    "fundaseși": "funda",
    "fundași": "funda",
    "fundat": "funda",
    "fundați": "funda",
    "fundatu": "funda",
    "fundau": "funda",
    "fundează": "funda",
    "fundez": "funda",
    "fundeze": "funda",
    "fundezi": "funda",
    "nefundând": "funda",
    "nefundându": "funda",
    "nemaifundând": "funda",
    "nemaifundându": "funda",
    "funda": "fundă",
    "funde": "fundă",
    "fundei": "fundă",
    "fundele": "fundă",
    "fundelor": "fundă",
    "fundale": "fundal",
    "fundalul": "fundal",
    "fundalului": "fundal",
    "fundalurile": "fundal",
    "fundalurilor": "fundal",
    "fundamente": "fundament",
    "fundamentele": "fundament",
    "fundamentelor": "fundament",
    "fundamentul": "fundament",
    "fundamentului": "fundament",
    "fundamentă": "fundamenta",
    "fundamentai": "fundamenta",
    "fundamentam": "fundamenta",
    "fundamentăm": "fundamenta",
    "fundamentând": "fundamenta",
    "fundamentându": "fundamenta",
    "fundamentară": "fundamenta",
    "fundamentarăm": "fundamenta",
    "fundamentarăți": "fundamenta",
    "fundamentase": "fundamenta",
    "fundamentasem": "fundamenta",
    "fundamentaseră": "fundamenta",
    "fundamentaserăm": "fundamenta",
    "fundamentaserăți": "fundamenta",
    "fundamentaseși": "fundamenta",
    "fundamentași": "fundamenta",
    "fundamentat": "fundamenta",
    "fundamentați": "fundamenta",
    "fundamentatu": "fundamenta",
    "fundamentau": "fundamenta",
    "fundamentează": "fundamenta",
    "fundamentez": "fundamenta",
    "fundamenteze": "fundamenta",
    "fundamentezi": "fundamenta",
    "nefundamentând": "fundamenta",
    "nefundamentându": "fundamenta",
    "nemaifundamentând": "fundamenta",
    "nemaifundamentându": "fundamenta",
    "fundamentala": "fundamental",
    "fundamentală": "fundamental",
    "fundamentale": "fundamental",
    "fundamentalei": "fundamental",
    "fundamentalele": "fundamental",
    "fundamentalelor": "fundamental",
    "fundamentali": "fundamental",
    "fundamentalii": "fundamental",
    "fundamentalilor": "fundamental",
    "fundamentalul": "fundamental",
    "fundamentalului": "fundamental",
    "fundamentarea": "fundamentare",
    "fundamentări": "fundamentare",
    "fundamentării": "fundamentare",
    "fundamentările": "fundamentare",
    "fundamentărilor": "fundamentare",
    "fundamentată": "fundamentat",
    "fundamentate": "fundamentat",
    "fundamentați": "fundamentat",
    "fundarisea": "fundarisi",
    "fundariseai": "fundarisi",
    "fundariseam": "fundarisi",
    "fundarisească": "fundarisi",
    "fundariseați": "fundarisi",
    "fundariseau": "fundarisi",
    "fundarisesc": "fundarisi",
    "fundarisește": "fundarisi",
    "fundarisești": "fundarisi",
    "fundarisii": "fundarisi",
    "fundarisim": "fundarisi",
    "fundarisind": "fundarisi",
    "fundarisindu": "fundarisi",
    "fundarisiră": "fundarisi",
    "fundarisirăm": "fundarisi",
    "fundarisirăți": "fundarisi",
    "fundarisise": "fundarisi",
    "fundarisisem": "fundarisi",
    "fundarisiseră": "fundarisi",
    "fundarisiserăm": "fundarisi",
    "fundarisiserăți": "fundarisi",
    "fundarisiseși": "fundarisi",
    "fundarisiși": "fundarisi",
    "fundarisit": "fundarisi",
    "fundarisiți": "fundarisi",
    "fundarisitu": "fundarisi",
    "nefundarisind": "fundarisi",
    "nefundarisindu": "fundarisi",
    "nemaifundarisind": "fundarisi",
    "nemaifundarisindu": "fundarisi",
    "fundarisită": "fundarisit",
    "fundarisite": "fundarisit",
    "fundarisiți": "fundarisit",
    "fundași": "fundaș",
    "fundașii": "fundaș",
    "fundașilor": "fundaș",
    "fundașul": "fundaș",
    "fundașului": "fundaș",
    "fundată": "fundat",
    "fundate": "fundat",
    "fundați": "fundat",
    "fundația": "fundație",
    "fundației": "fundație",
    "fundații": "fundație",
    "fundațiile": "fundație",
    "fundațiilor": "fundație",
    "fundătura": "fundătură",
    "fundături": "fundătură",
    "fundăturii": "fundătură",
    "fundăturile": "fundătură",
    "fundăturilor": "fundătură",
    "funebra": "funebru",
    "funebră": "funebru",
    "funebre": "funebru",
    "funebrei": "funebru",
    "funebrele": "funebru",
    "funebrelor": "funebru",
    "funebri": "funebru",
    "funebrii": "funebru",
    "funebrilor": "funebru",
    "funebrul": "funebru",
    "funebrului": "funebru",
    "funeraliile": "funeralii",
    "funeraliilor": "funeralii",
    "funerara": "funerar",
    "funerară": "funerar",
    "funerare": "funerar",
    "funerarei": "funerar",
    "funerarele": "funerar",
    "funerarelor": "funerar",
    "funerari": "funerar",
    "funerarii": "funerar",
    "funerarilor": "funerar",
    "funerarul": "funerar",
    "funerarului": "funerar",
    "funesta": "funest",
    "funestă": "funest",
    "funeste": "funest",
    "funestei": "funest",
    "funestele": "funest",
    "funestelor": "funest",
    "funești": "funest",
    "funeștii": "funest",
    "funeștilor": "funest",
    "funestul": "funest",
    "funestului": "funest",
    "funiculare": "funicular",
    "funicularele": "funicular",
    "funicularelor": "funicular",
    "funicularul": "funicular",
    "funicularului": "funicular",
    "funia": "funie",
    "funiei": "funie",
    "funii": "funie",
    "funiile": "funie",
    "funiilor": "funie",
    "funinginea": "funingine",
    "funingini": "funingine",
    "funinginii": "funingine",
    "funinginile": "funingine",
    "funinginilor": "funingine",
    "furul": "fur",
    "furului": "fur",
    "fur": "fura",
    "fură": "fura",
    "furai": "fura",
    "furam": "fura",
    "furăm": "fura",
    "furând": "fura",
    "furându": "fura",
    "furară": "fura",
    "furarăm": "fura",
    "furarăți": "fura",
    "furase": "fura",
    "furasem": "fura",
    "furaseră": "fura",
    "furaserăm": "fura",
    "furaserăți": "fura",
    "furaseși": "fura",
    "furași": "fura",
    "furat": "fura",
    "furați": "fura",
    "furatu": "fura",
    "furau": "fura",
    "fure": "fura",
    "furi": "fura",
    "nefurând": "fura",
    "nefurându": "fura",
    "nemaifurând": "fura",
    "nemaifurându": "fura",
    "furaje": "furaj",
    "furajele": "furaj",
    "furajelor": "furaj",
    "furajul": "furaj",
    "furajului": "furaj",
    "furată": "furat",
    "furate": "furat",
    "furați": "furat",
    "furca": "furcă",
    "furci": "furcă",
    "furcii": "furcă",
    "furcile": "furcă",
    "furcilor": "furcă",
    "furculița": "furculiță",
    "furculițe": "furculiță",
    "furculiței": "furculiță",
    "furculițele": "furculiță",
    "furculițelor": "furculiță",
    "furgoneta": "furgonetă",
    "furgonete": "furgonetă",
    "furgonetei": "furgonetă",
    "furgonetele": "furgonetă",
    "furgonetelor": "furgonetă",
    "furibunda": "furibund",
    "furibundă": "furibund",
    "furibunde": "furibund",
    "furibundei": "furibund",
    "furibundele": "furibund",
    "furibundelor": "furibund",
    "furibundo": "furibund",
    "furibundul": "furibund",
    "furibundule": "furibund",
    "furibundului": "furibund",
    "furibunzi": "furibund",
    "furibunzii": "furibund",
    "furibunzilor": "furibund",
    "furia": "furie",
    "furiei": "furie",
    "furii": "furie",
    "furiile": "furie",
    "furiilor": "furie",
    "furioasa": "furios",
    "furioasă": "furios",
    "furioase": "furios",
    "furioasei": "furios",
    "furioasele": "furios",
    "furioaselor": "furios",
    "furioși": "furios",
    "furioșii": "furios",
    "furioșilor": "furios",
    "furiosul": "furios",
    "furiosului": "furios",
    "furișa": "furiș",
    "furișă": "furiș",
    "furișe": "furiș",
    "furișei": "furiș",
    "furișele": "furiș",
    "furișelor": "furiș",
    "furiși": "furiș",
    "furișii": "furiș",
    "furișilor": "furiș",
    "furișul": "furiș",
    "furișului": "furiș",
    "furișă": "furișa",
    "furișai": "furișa",
    "furișam": "furișa",
    "furișăm": "furișa",
    "furișând": "furișa",
    "furișându": "furișa",
    "furișară": "furișa",
    "furișarăm": "furișa",
    "furișarăți": "furișa",
    "furișase": "furișa",
    "furișasem": "furișa",
    "furișaseră": "furișa",
    "furișaserăm": "furișa",
    "furișaserăți": "furișa",
    "furișaseși": "furișa",
    "furișași": "furișa",
    "furișat": "furișa",
    "furișați": "furișa",
    "furișatu": "furișa",
    "furișau": "furișa",
    "furișează": "furișa",
    "furișez": "furișa",
    "furișeze": "furișa",
    "furișezi": "furișa",
    "nefurișând": "furișa",
    "nefurișându": "furișa",
    "nemaifurișând": "furișa",
    "nemaifurișându": "furișa",
    "furișată": "furișat",
    "furișate": "furișat",
    "furișați": "furișat",
    "furlandisea": "furlandisi",
    "furlandiseai": "furlandisi",
    "furlandiseam": "furlandisi",
    "furlandisească": "furlandisi",
    "furlandiseați": "furlandisi",
    "furlandiseau": "furlandisi",
    "furlandisesc": "furlandisi",
    "furlandisește": "furlandisi",
    "furlandisești": "furlandisi",
    "furlandisii": "furlandisi",
    "furlandisim": "furlandisi",
    "furlandisind": "furlandisi",
    "furlandisindu": "furlandisi",
    "furlandisiră": "furlandisi",
    "furlandisirăm": "furlandisi",
    "furlandisirăți": "furlandisi",
    "furlandisise": "furlandisi",
    "furlandisisem": "furlandisi",
    "furlandisiseră": "furlandisi",
    "furlandisiserăm": "furlandisi",
    "furlandisiserăți": "furlandisi",
    "furlandisiseși": "furlandisi",
    "furlandisiși": "furlandisi",
    "furlandisit": "furlandisi",
    "furlandisiți": "furlandisi",
    "furlandisitu": "furlandisi",
    "nefurlandisind": "furlandisi",
    "nefurlandisindu": "furlandisi",
    "nemaifurlandisind": "furlandisi",
    "nemaifurlandisindu": "furlandisi",
    "furlandisită": "furlandisit",
    "furlandisite": "furlandisit",
    "furlandisiți": "furlandisit",
    "furnale": "furnal",
    "furnalele": "furnal",
    "furnalelor": "furnal",
    "furnalul": "furnal",
    "furnalului": "furnal",
    "furnică": "furnica",
    "furnicând": "furnica",
    "furnicându": "furnica",
    "furnicară": "furnica",
    "furnicase": "furnica",
    "furnicaseră": "furnica",
    "furnicat": "furnica",
    "furnicatu": "furnica",
    "furnicau": "furnica",
    "furnice": "furnica",
    "nefurnicând": "furnica",
    "nefurnicându": "furnica",
    "nemaifurnicând": "furnica",
    "nemaifurnicându": "furnica",
    "furnica": "furnică",
    "furnici": "furnică",
    "furnicii": "furnică",
    "furnicile": "furnică",
    "furnicilor": "furnică",
    "furnicare": "furnicar",
    "furnicarele": "furnicar",
    "furnicarelor": "furnicar",
    "furnicarul": "furnicar",
    "furnicarului": "furnicar",
    "furnicarea": "furnicare",
    "furnicări": "furnicare",
    "furnicării": "furnicare",
    "furnicările": "furnicare",
    "furnicărilor": "furnicare",
    "furnicată": "furnicat",
    "furnicate": "furnicat",
    "furnicați": "furnicat",
    "furnicătura": "furnicătură",
    "furnicături": "furnicătură",
    "furnicăturii": "furnicătură",
    "furnicăturile": "furnicătură",
    "furnicăturilor": "furnicătură",
    "furnirul": "furnir",
    "furnirului": "furnir",
    "furniruri": "furnir",
    "furnirurile": "furnir",
    "furnirurilor": "furnir",
    "furniruia": "furnirui",
    "furniruiai": "furnirui",
    "furniruiam": "furnirui",
    "furniruiască": "furnirui",
    "furniruiați": "furnirui",
    "furniruiau": "furnirui",
    "furniruiesc": "furnirui",
    "furniruiește": "furnirui",
    "furniruiești": "furnirui",
    "furniruii": "furnirui",
    "furniruim": "furnirui",
    "furniruind": "furnirui",
    "furniruindu": "furnirui",
    "furniruiră": "furnirui",
    "furniruirăm": "furnirui",
    "furniruirăți": "furnirui",
    "furniruise": "furnirui",
    "furniruisem": "furnirui",
    "furniruiseră": "furnirui",
    "furniruiserăm": "furnirui",
    "furniruiserăți": "furnirui",
    "furniruiseși": "furnirui",
    "furniruiși": "furnirui",
    "furniruit": "furnirui",
    "furniruiți": "furnirui",
    "furniruitu": "furnirui",
    "nefurniruind": "furnirui",
    "nefurniruindu": "furnirui",
    "nemaifurniruind": "furnirui",
    "nemaifurniruindu": "furnirui",
    "furniruită": "furniruit",
    "furniruite": "furniruit",
    "furniruiți": "furniruit",
    "furnitura": "furnitură",
    "furnituri": "furnitură",
    "furniturii": "furnitură",
    "furniturile": "furnitură",
    "furniturilor": "furnitură",
    "furniză": "furniza",
    "furnizai": "furniza",
    "furnizam": "furniza",
    "furnizăm": "furniza",
    "furnizând": "furniza",
    "furnizându": "furniza",
    "furnizară": "furniza",
    "furnizarăm": "furniza",
    "furnizarăți": "furniza",
    "furnizase": "furniza",
    "furnizasem": "furniza",
    "furnizaseră": "furniza",
    "furnizaserăm": "furniza",
    "furnizaserăți": "furniza",
    "furnizaseși": "furniza",
    "furnizași": "furniza",
    "furnizat": "furniza",
    "furnizați": "furniza",
    "furnizatu": "furniza",
    "furnizau": "furniza",
    "furnizează": "furniza",
    "furnizez": "furniza",
    "furnizeze": "furniza",
    "furnizezi": "furniza",
    "nefurnizând": "furniza",
    "nefurnizându": "furniza",
    "nemaifurnizând": "furniza",
    "nemaifurnizându": "furniza",
    "furnizată": "furnizat",
    "furnizate": "furnizat",
    "furnizați": "furnizat",
    "furnizoarea": "furnizoare",
    "furnizoarei": "furnizoare",
    "furnizoarele": "furnizoare",
    "furnizoarelor": "furnizoare",
    "furnizoare": "furnizor",
    "furnizori": "furnizor",
    "furnizorii": "furnizor",
    "furnizorilor": "furnizor",
    "furnizorul": "furnizor",
    "furnizorului": "furnizor",
    "furoarea": "furoare",
    "furoareo": "furoare",
    "furori": "furoare",
    "furorii": "furoare",
    "furorile": "furoare",
    "furorilor": "furoare",
    "furoul": "furou",
    "furoului": "furou",
    "furouri": "furou",
    "furourile": "furou",
    "furourilor": "furou",
    "fursecul": "fursec",
    "fursecului": "fursec",
    "fursecuri": "fursec",
    "fursecurile": "fursec",
    "fursecurilor": "fursec",
    "furtul": "furt",
    "furtului": "furt",
    "furturi": "furt",
    "furturile": "furt",
    "furturilor": "furt",
    "furtișagul": "furtișag",
    "furtișagule": "furtișag",
    "furtișagului": "furtișag",
    "furtișaguri": "furtișag",
    "furtișagurile": "furtișag",
    "furtișagurilor": "furtișag",
    "furtunul": "furtun",
    "furtunului": "furtun",
    "furtunuri": "furtun",
    "furtunurile": "furtun",
    "furtunurilor": "furtun",
    "furtuna": "furtună",
    "furtuni": "furtună",
    "furtunii": "furtună",
    "furtunile": "furtună",
    "furtunilor": "furtună",
    "furtunoasa": "furtunos",
    "furtunoasă": "furtunos",
    "furtunoase": "furtunos",
    "furtunoasei": "furtunos",
    "furtunoasele": "furtunos",
    "furtunoaselor": "furtunos",
    "furtunoși": "furtunos",
    "furtunoșii": "furtunos",
    "furtunoșilor": "furtunos",
    "furtunosul": "furtunos",
    "furtunosului": "furtunos",
    "furunculi": "furuncul",
    "furunculii": "furuncul",
    "furunculilor": "furuncul",
    "furunculul": "furuncul",
    "furunculului": "furuncul",
    "fusul": "fus",
    "fusului": "fus",
    "fusuri": "fus",
    "fusurile": "fus",
    "fusurilor": "fus",
    "fusta": "fustă",
    "fuste": "fustă",
    "fustei": "fustă",
    "fustele": "fustă",
    "fustelor": "fustă",
    "futu": "fute",
    "fuzelaje": "fuzelaj",
    "fuzelajele": "fuzelaj",
    "fuzelajelor": "fuzelaj",
    "fuzelajul": "fuzelaj",
    "fuzelajului": "fuzelaj",
    "fuzibila": "fuzibil",
    "fuzibilă": "fuzibil",
    "fuzibile": "fuzibil",
    "fuzibilei": "fuzibil",
    "fuzibilele": "fuzibil",
    "fuzibilelor": "fuzibil",
    "fuzibili": "fuzibil",
    "fuzibilii": "fuzibil",
    "fuzibililor": "fuzibil",
    "fuzibilul": "fuzibil",
    "fuzibilului": "fuzibil",
    "fuzionă": "fuziona",
    "fuzionai": "fuziona",
    "fuzionam": "fuziona",
    "fuzionăm": "fuziona",
    "fuzionând": "fuziona",
    "fuzionându": "fuziona",
    "fuzionară": "fuziona",
    "fuzionarăm": "fuziona",
    "fuzionarăți": "fuziona",
    "fuzionase": "fuziona",
    "fuzionasem": "fuziona",
    "fuzionaseră": "fuziona",
    "fuzionaserăm": "fuziona",
    "fuzionaserăți": "fuziona",
    "fuzionaseși": "fuziona",
    "fuzionași": "fuziona",
    "fuzionat": "fuziona",
    "fuzionați": "fuziona",
    "fuzionatu": "fuziona",
    "fuzionau": "fuziona",
    "fuzionează": "fuziona",
    "fuzionez": "fuziona",
    "fuzioneze": "fuziona",
    "fuzionezi": "fuziona",
    "nefuzionând": "fuziona",
    "nefuzionându": "fuziona",
    "nemaifuzionând": "fuziona",
    "nemaifuzionându": "fuziona",
    "fuzionată": "fuzionat",
    "fuzionate": "fuzionat",
    "fuzionați": "fuzionat",
    "fuziunea": "fuziune",
    "fuziuni": "fuziune",
    "fuziunii": "fuziune",
    "fuziunile": "fuziune",
    "fuziunilor": "fuziune",
    "gabarite": "gabarit",
    "gabaritele": "gabarit",
    "gabaritelor": "gabarit",
    "gabaritul": "gabarit",
    "gabaritului": "gabarit",
    "găbjea": "găbji",
    "găbjeai": "găbji",
    "găbjeam": "găbji",
    "găbjească": "găbji",
    "găbjeați": "găbji",
    "găbjeau": "găbji",
    "găbjesc": "găbji",
    "găbjește": "găbji",
    "găbjești": "găbji",
    "găbjii": "găbji",
    "găbjim": "găbji",
    "găbjind": "găbji",
    "găbjindu": "găbji",
    "găbjiră": "găbji",
    "găbjirăm": "găbji",
    "găbjirăți": "găbji",
    "găbjise": "găbji",
    "găbjisem": "găbji",
    "găbjiseră": "găbji",
    "găbjiserăm": "găbji",
    "găbjiserăți": "găbji",
    "găbjiseși": "găbji",
    "găbjiși": "găbji",
    "găbjit": "găbji",
    "găbjiți": "găbji",
    "găbjitu": "găbji",
    "negăbjind": "găbji",
    "negăbjindu": "găbji",
    "nemaigăbjind": "găbji",
    "nemaigăbjindu": "găbji",
    "găbjită": "găbjit",
    "găbjite": "găbjit",
    "găbjiți": "găbjit",
    "Gabrielei": "Gabriela",
    "găbuia": "găbui",
    "găbuiai": "găbui",
    "găbuiam": "găbui",
    "găbuiască": "găbui",
    "găbuiați": "găbui",
    "găbuiau": "găbui",
    "găbuiesc": "găbui",
    "găbuiește": "găbui",
    "găbuiești": "găbui",
    "găbuii": "găbui",
    "găbuim": "găbui",
    "găbuind": "găbui",
    "găbuindu": "găbui",
    "găbuiră": "găbui",
    "găbuirăm": "găbui",
    "găbuirăți": "găbui",
    "găbuise": "găbui",
    "găbuisem": "găbui",
    "găbuiseră": "găbui",
    "găbuiserăm": "găbui",
    "găbuiserăți": "găbui",
    "găbuiseși": "găbui",
    "găbuiși": "găbui",
    "găbuit": "găbui",
    "găbuiți": "găbui",
    "găbuitu": "găbui",
    "negăbuind": "găbui",
    "negăbuindu": "găbui",
    "nemaigăbuind": "găbui",
    "nemaigăbuindu": "găbui",
    "găbuită": "găbuit",
    "găbuite": "găbuit",
    "găbuiți": "găbuit",
    "gâdele": "gâde",
    "gâdelui": "gâde",
    "gâzi": "gâde",
    "gâzii": "gâde",
    "gâzilor": "gâde",
    "gâdil": "gâdila",
    "gâdilă": "gâdila",
    "gâdilai": "gâdila",
    "gâdilam": "gâdila",
    "gâdilăm": "gâdila",
    "gâdilând": "gâdila",
    "gâdilându": "gâdila",
    "gâdilară": "gâdila",
    "gâdilarăm": "gâdila",
    "gâdilarăți": "gâdila",
    "gâdilase": "gâdila",
    "gâdilasem": "gâdila",
    "gâdilaseră": "gâdila",
    "gâdilaserăm": "gâdila",
    "gâdilaserăți": "gâdila",
    "gâdilaseși": "gâdila",
    "gâdilași": "gâdila",
    "gâdilat": "gâdila",
    "gâdilați": "gâdila",
    "gâdilatu": "gâdila",
    "gâdilau": "gâdila",
    "gâdile": "gâdila",
    "gâdili": "gâdila",
    "negâdilând": "gâdila",
    "negâdilându": "gâdila",
    "nemaigâdilând": "gâdila",
    "nemaigâdilându": "gâdila",
    "gâdilată": "gâdilat",
    "gâdilate": "gâdilat",
    "gâdilați": "gâdilat",
    "gâdilatul": "gâdilat",
    "gâdilatului": "gâdilat",
    "gâdilătura": "gâdilătură",
    "gâdilături": "gâdilătură",
    "gâdilăturii": "gâdilătură",
    "gâdilăturile": "gâdilătură",
    "gâdilăturilor": "gâdilătură",
    "gafa": "gafă",
    "gafe": "gafă",
    "gafei": "gafă",
    "gafele": "gafă",
    "gafelor": "gafă",
    "gâfâia": "gâfâi",
    "gâfâiai": "gâfâi",
    "gâfâiam": "gâfâi",
    "gâfâiați": "gâfâi",
    "gâfâiau": "gâfâi",
    "gâfâie": "gâfâi",
    "gâfâii": "gâfâi",
    "gâfâim": "gâfâi",
    "gâfâind": "gâfâi",
    "gâfâindu": "gâfâi",
    "gâfâiră": "gâfâi",
    "gâfâirăm": "gâfâi",
    "gâfâirăți": "gâfâi",
    "gâfâise": "gâfâi",
    "gâfâisem": "gâfâi",
    "gâfâiseră": "gâfâi",
    "gâfâiserăm": "gâfâi",
    "gâfâiserăți": "gâfâi",
    "gâfâiseși": "gâfâi",
    "gâfâiși": "gâfâi",
    "gâfâit": "gâfâi",
    "gâfâiți": "gâfâi",
    "gâfâitu": "gâfâi",
    "negâfâind": "gâfâi",
    "negâfâindu": "gâfâi",
    "nemaigâfâind": "gâfâi",
    "nemaigâfâindu": "gâfâi",
    "gâfâiala": "gâfâială",
    "gâfâieli": "gâfâială",
    "gâfâielii": "gâfâială",
    "gâfâielile": "gâfâială",
    "gâfâielilor": "gâfâială",
    "gâfâită": "gâfâit",
    "gâfâite": "gâfâit",
    "gâfâiți": "gâfâit",
    "gâfâitul": "gâfâit",
    "gâfâitului": "gâfâit",
    "gâfâitoare": "gâfâitor",
    "gâfâitoarea": "gâfâitor",
    "gâfâitoarei": "gâfâitor",
    "gâfâitoarele": "gâfâitor",
    "gâfâitoarelor": "gâfâitor",
    "gâfâitori": "gâfâitor",
    "gâfâitorii": "gâfâitor",
    "gâfâitorilor": "gâfâitor",
    "gâfâitorul": "gâfâitor",
    "gâfâitorului": "gâfâitor",
    "gâgâia": "gâgâi",
    "gâgâiai": "gâgâi",
    "gâgâiam": "gâgâi",
    "gâgâiați": "gâgâi",
    "gâgâiau": "gâgâi",
    "gâgâie": "gâgâi",
    "gâgâii": "gâgâi",
    "gâgâim": "gâgâi",
    "gâgâind": "gâgâi",
    "gâgâindu": "gâgâi",
    "gâgâiră": "gâgâi",
    "gâgâirăm": "gâgâi",
    "gâgâirăți": "gâgâi",
    "gâgâise": "gâgâi",
    "gâgâisem": "gâgâi",
    "gâgâiseră": "gâgâi",
    "gâgâiserăm": "gâgâi",
    "gâgâiserăți": "gâgâi",
    "gâgâiseși": "gâgâi",
    "gâgâiși": "gâgâi",
    "gâgâit": "gâgâi",
    "gâgâiți": "gâgâi",
    "gâgâitu": "gâgâi",
    "negâgâind": "gâgâi",
    "negâgâindu": "gâgâi",
    "nemaigâgâind": "gâgâi",
    "nemaigâgâindu": "gâgâi",
    "găgăia": "găgăi",
    "găgăiai": "găgăi",
    "găgăiam": "găgăi",
    "găgăiați": "găgăi",
    "găgăiau": "găgăi",
    "găgăie": "găgăi",
    "găgăii": "găgăi",
    "găgăim": "găgăi",
    "găgăind": "găgăi",
    "găgăindu": "găgăi",
    "găgăiră": "găgăi",
    "găgăirăm": "găgăi",
    "găgăirăți": "găgăi",
    "găgăise": "găgăi",
    "găgăisem": "găgăi",
    "găgăiseră": "găgăi",
    "găgăiserăm": "găgăi",
    "găgăiserăți": "găgăi",
    "găgăiseși": "găgăi",
    "găgăiși": "găgăi",
    "găgăit": "găgăi",
    "găgăiți": "găgăi",
    "găgăitu": "găgăi",
    "negăgăind": "găgăi",
    "negăgăindu": "găgăi",
    "nemaigăgăind": "găgăi",
    "nemaigăgăindu": "găgăi",
    "gâgâită": "gâgâit",
    "gâgâite": "gâgâit",
    "gâgâiți": "gâgâit",
    "gâgâitul": "gâgâit",
    "gâgâitului": "gâgâit",
    "găgăită": "găgăit",
    "găgăite": "găgăit",
    "găgăiți": "găgăit",
    "gaica": "gaică",
    "găici": "gaică",
    "găicii": "gaică",
    "găicile": "gaică",
    "găicilor": "gaică",
    "găină": "găina",
    "găinai": "găina",
    "găinam": "găina",
    "găinăm": "găina",
    "găinând": "găina",
    "găinându": "găina",
    "găinară": "găina",
    "găinarăm": "găina",
    "găinarăți": "găina",
    "găinase": "găina",
    "găinasem": "găina",
    "găinaseră": "găina",
    "găinaserăm": "găina",
    "găinaserăți": "găina",
    "găinaseși": "găina",
    "găinași": "găina",
    "găinat": "găina",
    "găinați": "găina",
    "găinatu": "găina",
    "găinau": "găina",
    "găinează": "găina",
    "găinez": "găina",
    "găineze": "găina",
    "găinezi": "găina",
    "negăinând": "găina",
    "negăinându": "găina",
    "nemaigăinând": "găina",
    "nemaigăinându": "găina",
    "găina": "găină",
    "găini": "găină",
    "găinii": "găină",
    "găinile": "găină",
    "găinilor": "găină",
    "găini-cu-mărgăritare": "găină-cu-mărgăritare",
    "găini-de-apă": "găină-de-apă",
    "găini-de-mare": "găină-de-mare",
    "găini-de-munte": "găină-de-munte",
    "găini-sălbatice": "găină-sălbatică",
    "găinată": "găinat",
    "găinate": "găinat",
    "găinați": "găinat",
    "găinațul": "găinaț",
    "găinațului": "găinaț",
    "găinațuri": "găinaț",
    "găinațurile": "găinaț",
    "găinațurilor": "găinaț",
    "găinăță": "găinăța",
    "găinățai": "găinăța",
    "găinățam": "găinăța",
    "găinățăm": "găinăța",
    "găinățând": "găinăța",
    "găinățându": "găinăța",
    "găinățară": "găinăța",
    "găinățarăm": "găinăța",
    "găinățarăți": "găinăța",
    "găinățase": "găinăța",
    "găinățasem": "găinăța",
    "găinățaseră": "găinăța",
    "găinățaserăm": "găinăța",
    "găinățaserăți": "găinăța",
    "găinățaseși": "găinăța",
    "găinățași": "găinăța",
    "găinățat": "găinăța",
    "găinățați": "găinăța",
    "găinățatu": "găinăța",
    "găinățau": "găinăța",
    "găinățează": "găinăța",
    "găinățez": "găinăța",
    "găinățeze": "găinăța",
    "găinățezi": "găinăța",
    "negăinățând": "găinăța",
    "negăinățându": "găinăța",
    "nemaigăinățând": "găinăța",
    "nemaigăinățându": "găinăța",
    "găinățată": "găinățat",
    "găinățate": "găinățat",
    "găinățați": "găinățat",
    "găinușe-de-baltă": "găinușă-de-baltă",
    "găinușa-de-seară": "găinușă-de-seară",
    "găinușa-galbenă": "găinușă-galbenă",
    "gaița": "gaiță",
    "gaițe": "gaiță",
    "gaiței": "gaiță",
    "gaițele": "gaiță",
    "gaițelor": "gaiță",
    "găitănea": "găităni",
    "găităneai": "găităni",
    "găităneam": "găităni",
    "găitănească": "găităni",
    "găităneați": "găităni",
    "găităneau": "găităni",
    "găitănesc": "găităni",
    "găitănește": "găităni",
    "găitănești": "găităni",
    "găitănii": "găităni",
    "găitănim": "găităni",
    "găitănind": "găităni",
    "găitănindu": "găităni",
    "găităniră": "găităni",
    "găitănirăm": "găităni",
    "găitănirăți": "găităni",
    "găitănise": "găităni",
    "găitănisem": "găităni",
    "găităniseră": "găităni",
    "găităniserăm": "găităni",
    "găităniserăți": "găităni",
    "găităniseși": "găităni",
    "găităniși": "găităni",
    "găitănit": "găităni",
    "găităniți": "găităni",
    "găitănitu": "găităni",
    "negăitănind": "găităni",
    "negăitănindu": "găităni",
    "nemaigăitănind": "găităni",
    "nemaigăitănindu": "găităni",
    "găitănită": "găitănit",
    "găitănite": "găitănit",
    "găităniți": "găitănit",
    "gajul": "gaj",
    "gajului": "gaj",
    "gajuri": "gaj",
    "gajurile": "gaj",
    "gajurilor": "gaj",
    "gâjâia": "gâjâi",
    "gâjâiai": "gâjâi",
    "gâjâiam": "gâjâi",
    "gâjâiați": "gâjâi",
    "gâjâiau": "gâjâi",
    "gâjâie": "gâjâi",
    "gâjâii": "gâjâi",
    "gâjâim": "gâjâi",
    "gâjâind": "gâjâi",
    "gâjâindu": "gâjâi",
    "gâjâiră": "gâjâi",
    "gâjâirăm": "gâjâi",
    "gâjâirăți": "gâjâi",
    "gâjâise": "gâjâi",
    "gâjâisem": "gâjâi",
    "gâjâiseră": "gâjâi",
    "gâjâiserăm": "gâjâi",
    "gâjâiserăți": "gâjâi",
    "gâjâiseși": "gâjâi",
    "gâjâiși": "gâjâi",
    "gâjâit": "gâjâi",
    "gâjâiți": "gâjâi",
    "gâjâitu": "gâjâi",
    "negâjâind": "gâjâi",
    "negâjâindu": "gâjâi",
    "nemaigâjâind": "gâjâi",
    "nemaigâjâindu": "gâjâi",
    "gâjâită": "gâjâit",
    "gâjâite": "gâjâit",
    "gâjâiți": "gâjâit",
    "gala": "gală",
    "gale": "gală",
    "galei": "gală",
    "galele": "gală",
    "galelor": "gală",
    "gălăgia": "gălăgie",
    "gălăgiei": "gălăgie",
    "gălăgii": "gălăgie",
    "gălăgioasa": "gălăgios",
    "gălăgioasă": "gălăgios",
    "gălăgioase": "gălăgios",
    "gălăgioasei": "gălăgios",
    "gălăgioasele": "gălăgios",
    "gălăgioaselor": "gălăgios",
    "gălăgioși": "gălăgios",
    "gălăgioșii": "gălăgios",
    "gălăgioșilor": "gălăgios",
    "gălăgiosul": "gălăgios",
    "gălăgiosului": "gălăgios",
    "galanta": "galant",
    "galantă": "galant",
    "galante": "galant",
    "galantei": "galant",
    "galantele": "galant",
    "galantelor": "galant",
    "galanți": "galant",
    "galanții": "galant",
    "galanților": "galant",
    "galantul": "galant",
    "galantului": "galant",
    "galantare": "galantar",
    "galantarele": "galantar",
    "galantarelor": "galantar",
    "galantarul": "galantar",
    "galantarului": "galantar",
    "galanteria": "galanterie",
    "galanteriei": "galanterie",
    "galanterii": "galanterie",
    "galanteriile": "galanterie",
    "galanteriilor": "galanterie",
    "Galațiul": "Galați",
    "Galațiului": "Galați",
    "galaxia": "galaxie",
    "galaxiei": "galaxie",
    "galaxii": "galaxie",
    "galaxiile": "galaxie",
    "galaxiilor": "galaxie",
    "gălbejeala": "gălbejeală",
    "gălbejeli": "gălbejeală",
    "gălbejelii": "gălbejeală",
    "gălbejelile": "gălbejeală",
    "gălbejelilor": "gălbejeală",
    "gălbejea": "gălbeji",
    "gălbejeai": "gălbeji",
    "gălbejeam": "gălbeji",
    "gălbejească": "gălbeji",
    "gălbejeați": "gălbeji",
    "gălbejeau": "gălbeji",
    "gălbejesc": "gălbeji",
    "gălbejește": "gălbeji",
    "gălbejești": "gălbeji",
    "gălbejii": "gălbeji",
    "gălbejim": "gălbeji",
    "gălbejind": "gălbeji",
    "gălbejindu": "gălbeji",
    "gălbejiră": "gălbeji",
    "gălbejirăm": "gălbeji",
    "gălbejirăți": "gălbeji",
    "gălbejise": "gălbeji",
    "gălbejisem": "gălbeji",
    "gălbejiseră": "gălbeji",
    "gălbejiserăm": "gălbeji",
    "gălbejiserăți": "gălbeji",
    "gălbejiseși": "gălbeji",
    "gălbejiși": "gălbeji",
    "gălbejit": "gălbeji",
    "gălbejiți": "gălbeji",
    "gălbejitu": "gălbeji",
    "negălbejind": "gălbeji",
    "negălbejindu": "gălbeji",
    "nemaigălbejind": "gălbeji",
    "nemaigălbejindu": "gălbeji",
    "gălbejita": "gălbejit",
    "gălbejită": "gălbejit",
    "gălbejite": "gălbejit",
    "gălbejitei": "gălbejit",
    "gălbejitele": "gălbejit",
    "gălbejitelor": "gălbejit",
    "gălbejiți": "gălbejit",
    "gălbejiții": "gălbejit",
    "gălbejiților": "gălbejit",
    "gălbejitul": "gălbejit",
    "gălbejitului": "gălbejit",
    "galbena": "galben",
    "galbenă": "galben",
    "galbene": "galben",
    "galbenei": "galben",
    "galbenele": "galben",
    "galbenelor": "galben",
    "galbeni": "galben",
    "galbenii": "galben",
    "galbenilor": "galben",
    "galbenul": "galben",
    "galbenului": "galben",
    "gălbeneala": "gălbeneală",
    "gălbenele": "gălbeneală",
    "gălbenelei": "gălbeneală",
    "gălbenelele": "gălbeneală",
    "gălbenelelor": "gălbeneală",
    "gălbenea": "gălbeni",
    "gălbeneai": "gălbeni",
    "gălbeneam": "gălbeni",
    "gălbenească": "gălbeni",
    "gălbeneați": "gălbeni",
    "gălbeneau": "gălbeni",
    "gălbenesc": "gălbeni",
    "gălbenește": "gălbeni",
    "gălbenești": "gălbeni",
    "gălbenii": "gălbeni",
    "gălbenim": "gălbeni",
    "gălbenind": "gălbeni",
    "gălbenindu": "gălbeni",
    "gălbeniră": "gălbeni",
    "gălbenirăm": "gălbeni",
    "gălbenirăți": "gălbeni",
    "gălbenise": "gălbeni",
    "gălbenisem": "gălbeni",
    "gălbeniseră": "gălbeni",
    "gălbeniserăm": "gălbeni",
    "gălbeniserăți": "gălbeni",
    "gălbeniseși": "gălbeni",
    "gălbeniși": "gălbeni",
    "gălbenit": "gălbeni",
    "gălbeniți": "gălbeni",
    "gălbenitu": "gălbeni",
    "negălbenind": "gălbeni",
    "negălbenindu": "gălbeni",
    "nemaigălbenind": "gălbeni",
    "nemaigălbenindu": "gălbeni",
    "gălbenită": "gălbenit",
    "gălbenite": "gălbenit",
    "gălbeniți": "gălbenit",
    "galben-lăptoasă": "galben-lăptos",
    "gălbenușul": "gălbenuș",
    "gălbenușului": "gălbenuș",
    "gălbenușuri": "gălbenuș",
    "gălbenușurile": "gălbenuș",
    "gălbenușurilor": "gălbenuș",
    "galben-vineții": "galben-vinețiu",
    "gălbuia": "gălbui",
    "gălbuie": "gălbui",
    "gălbuiei": "gălbui",
    "gălbuii": "gălbui",
    "gălbuile": "gălbui",
    "gălbuilor": "gălbui",
    "gălbuiul": "gălbui",
    "gălbuiului": "gălbui",
    "gâlca": "gâlcă",
    "gâlci": "gâlcă",
    "gâlcii": "gâlcă",
    "gâlcile": "gâlcă",
    "gâlcilor": "gâlcă",
    "gâlceava": "gâlceavă",
    "gâlcevi": "gâlceavă",
    "gâlcevii": "gâlceavă",
    "gâlcevile": "gâlceavă",
    "gâlcevilor": "gâlceavă",
    "gâlcevea": "gâlcevi",
    "gâlceveai": "gâlcevi",
    "gâlceveam": "gâlcevi",
    "gâlcevească": "gâlcevi",
    "gâlceveați": "gâlcevi",
    "gâlceveau": "gâlcevi",
    "gâlcevesc": "gâlcevi",
    "gâlcevește": "gâlcevi",
    "gâlcevești": "gâlcevi",
    "gâlcevii": "gâlcevi",
    "gâlcevim": "gâlcevi",
    "gâlcevind": "gâlcevi",
    "gâlcevindu": "gâlcevi",
    "gâlceviră": "gâlcevi",
    "gâlcevirăm": "gâlcevi",
    "gâlcevirăți": "gâlcevi",
    "gâlcevise": "gâlcevi",
    "gâlcevisem": "gâlcevi",
    "gâlceviseră": "gâlcevi",
    "gâlceviserăm": "gâlcevi",
    "gâlceviserăți": "gâlcevi",
    "gâlceviseși": "gâlcevi",
    "gâlceviși": "gâlcevi",
    "gâlcevit": "gâlcevi",
    "gâlceviți": "gâlcevi",
    "gâlcevitu": "gâlcevi",
    "negâlcevind": "gâlcevi",
    "negâlcevindu": "gâlcevi",
    "nemaigâlcevind": "gâlcevi",
    "nemaigâlcevindu": "gâlcevi",
    "gâlcevită": "gâlcevit",
    "gâlcevite": "gâlcevit",
    "gâlceviți": "gâlcevit",
    "gâlcevitoare": "gâlcevitor",
    "gâlcevitoarea": "gâlcevitor",
    "gâlcevitoarei": "gâlcevitor",
    "gâlcevitoarele": "gâlcevitor",
    "gâlcevitoarelor": "gâlcevitor",
    "gâlcevitori": "gâlcevitor",
    "gâlcevitorii": "gâlcevitor",
    "gâlcevitorilor": "gâlcevitor",
    "gâlcevitorul": "gâlcevitor",
    "gâlcevitorului": "gâlcevitor",
    "găleata": "găleată",
    "găleți": "găleată",
    "găleții": "găleată",
    "gălețile": "găleată",
    "găleților": "găleată",
    "galera": "galeră",
    "galere": "galeră",
    "galerei": "galeră",
    "galerele": "galeră",
    "galerelor": "galeră",
    "galeria": "galerie",
    "galeriei": "galerie",
    "galerii": "galerie",
    "galeriile": "galerie",
    "galeriilor": "galerie",
    "galeșa": "galeș",
    "galeșă": "galeș",
    "galeșe": "galeș",
    "galeșei": "galeș",
    "galeșele": "galeș",
    "galeșelor": "galeș",
    "galeși": "galeș",
    "galeșii": "galeș",
    "galeșilor": "galeș",
    "galeșul": "galeș",
    "galeșului": "galeș",
    "galeză": "galez",
    "galeze": "galez",
    "galezi": "galez",
    "gâlgâia": "gâlgâi",
    "gâlgâiai": "gâlgâi",
    "gâlgâiam": "gâlgâi",
    "gâlgâiați": "gâlgâi",
    "gâlgâiau": "gâlgâi",
    "gâlgâie": "gâlgâi",
    "gâlgâii": "gâlgâi",
    "gâlgâim": "gâlgâi",
    "gâlgâind": "gâlgâi",
    "gâlgâindu": "gâlgâi",
    "gâlgâiră": "gâlgâi",
    "gâlgâirăm": "gâlgâi",
    "gâlgâirăți": "gâlgâi",
    "gâlgâise": "gâlgâi",
    "gâlgâisem": "gâlgâi",
    "gâlgâiseră": "gâlgâi",
    "gâlgâiserăm": "gâlgâi",
    "gâlgâiserăți": "gâlgâi",
    "gâlgâiseși": "gâlgâi",
    "gâlgâiși": "gâlgâi",
    "gâlgâit": "gâlgâi",
    "gâlgâiți": "gâlgâi",
    "gâlgâitu": "gâlgâi",
    "negâlgâind": "gâlgâi",
    "negâlgâindu": "gâlgâi",
    "nemaigâlgâind": "gâlgâi",
    "nemaigâlgâindu": "gâlgâi",
    "gâlgâită": "gâlgâit",
    "gâlgâite": "gâlgâit",
    "gâlgâiți": "gâlgâit",
    "gâlgâitul": "gâlgâit",
    "gâlgâitului": "gâlgâit",
    "Ga": "galiu",
    "galiul": "galiu",
    "galiului": "galiu",
    "gal.": "galon",
    "galoane": "galon",
    "galoanele": "galon",
    "galoanelor": "galon",
    "galonul": "galon",
    "galonului": "galon",
    "galopul": "galop",
    "galopului": "galop",
    "galopuri": "galop",
    "galopurile": "galop",
    "galopurilor": "galop",
    "galopă": "galopa",
    "galopai": "galopa",
    "galopam": "galopa",
    "galopăm": "galopa",
    "galopând": "galopa",
    "galopându": "galopa",
    "galopară": "galopa",
    "galoparăm": "galopa",
    "galoparăți": "galopa",
    "galopase": "galopa",
    "galopasem": "galopa",
    "galopaseră": "galopa",
    "galopaserăm": "galopa",
    "galopaserăți": "galopa",
    "galopaseși": "galopa",
    "galopași": "galopa",
    "galopat": "galopa",
    "galopați": "galopa",
    "galopatu": "galopa",
    "galopau": "galopa",
    "galopează": "galopa",
    "galopez": "galopa",
    "galopeze": "galopa",
    "galopezi": "galopa",
    "negalopând": "galopa",
    "negalopându": "galopa",
    "nemaigalopând": "galopa",
    "nemaigalopându": "galopa",
    "galopată": "galopat",
    "galopate": "galopat",
    "galopați": "galopat",
    "galo-romană": "galo-roman",
    "galo-romane": "galo-roman",
    "galo-romani": "galo-roman",
    "galoși": "galoș",
    "galoșii": "galoș",
    "galoșilor": "galoș",
    "galoșul": "galoș",
    "galoșului": "galoș",
    "gălușca": "gălușcă",
    "găluști": "gălușcă",
    "găluștii": "gălușcă",
    "găluștile": "gălușcă",
    "găluștilor": "gălușcă",
    "galvanica": "galvanic",
    "galvanică": "galvanic",
    "galvanice": "galvanic",
    "galvanicei": "galvanic",
    "galvanicele": "galvanic",
    "galvanicelor": "galvanic",
    "galvanici": "galvanic",
    "galvanicii": "galvanic",
    "galvanicilor": "galvanic",
    "galvanicul": "galvanic",
    "galvanicului": "galvanic",
    "galvaniză": "galvaniza",
    "galvanizai": "galvaniza",
    "galvanizam": "galvaniza",
    "galvanizăm": "galvaniza",
    "galvanizând": "galvaniza",
    "galvanizându": "galvaniza",
    "galvanizară": "galvaniza",
    "galvanizarăm": "galvaniza",
    "galvanizarăți": "galvaniza",
    "galvanizase": "galvaniza",
    "galvanizasem": "galvaniza",
    "galvanizaseră": "galvaniza",
    "galvanizaserăm": "galvaniza",
    "galvanizaserăți": "galvaniza",
    "galvanizaseși": "galvaniza",
    "galvanizași": "galvaniza",
    "galvanizat": "galvaniza",
    "galvanizați": "galvaniza",
    "galvanizatu": "galvaniza",
    "galvanizau": "galvaniza",
    "galvanizează": "galvaniza",
    "galvanizez": "galvaniza",
    "galvanizeze": "galvaniza",
    "galvanizezi": "galvaniza",
    "negalvanizând": "galvaniza",
    "negalvanizându": "galvaniza",
    "nemaigalvanizând": "galvaniza",
    "nemaigalvanizându": "galvaniza",
    "galvanizată": "galvanizat",
    "galvanizate": "galvanizat",
    "galvanizați": "galvanizat",
    "gama": "gamă",
    "game": "gamă",
    "gamei": "gamă",
    "gamele": "gamă",
    "gamelor": "gamă",
    "gămălia": "gămălie",
    "gămăliei": "gămălie",
    "gămălii": "gămălie",
    "gămăliile": "gămălie",
    "gămăliilor": "gămălie",
    "gamba": "gambă",
    "gambe": "gambă",
    "gambei": "gambă",
    "gambele": "gambă",
    "gambelor": "gambă",
    "gamela": "gamelă",
    "gamele": "gamelă",
    "gamelei": "gamelă",
    "gamelele": "gamelă",
    "gamelelor": "gamelă",
    "gându": "gând",
    "gândul": "gând",
    "gândului": "gând",
    "gânduri": "gând",
    "gândurile": "gând",
    "gândurilor": "gând",
    "gândaci": "gândac",
    "gândacii": "gândac",
    "gândacilor": "gândac",
    "gândacul": "gândac",
    "gândacului": "gândac",
    "gândea": "gândi",
    "gândeai": "gândi",
    "gândeam": "gândi",
    "gândească": "gândi",
    "gândeați": "gândi",
    "gândeau": "gândi",
    "gândesc": "gândi",
    "gândește": "gândi",
    "gândești": "gândi",
    "gândii": "gândi",
    "gândim": "gândi",
    "gândind": "gândi",
    "gândindu": "gândi",
    "gândiră": "gândi",
    "gândirăm": "gândi",
    "gândirăți": "gândi",
    "gândise": "gândi",
    "gândisem": "gândi",
    "gândiseră": "gândi",
    "gândiserăm": "gândi",
    "gândiserăți": "gândi",
    "gândiseși": "gândi",
    "gândiși": "gândi",
    "gândit": "gândi",
    "gândiți": "gândi",
    "gânditu": "gândi",
    "negândind": "gândi",
    "negândindu": "gândi",
    "nemaigândind": "gândi",
    "nemaigândindu": "gândi",
    "gândirea": "gândire",
    "gândiri": "gândire",
    "gândirii": "gândire",
    "gândirile": "gândire",
    "gândirilor": "gândire",
    "gândita": "gândit",
    "gândită": "gândit",
    "gândite": "gândit",
    "gânditei": "gândit",
    "gânditele": "gândit",
    "gânditelor": "gândit",
    "gândiți": "gândit",
    "gândiții": "gândit",
    "gândiților": "gândit",
    "gânditul": "gândit",
    "gânditului": "gândit",
    "gânditoare": "gânditor",
    "gânditoarea": "gânditor",
    "gânditoarei": "gânditor",
    "gânditoarele": "gânditor",
    "gânditoarelor": "gânditor",
    "gânditori": "gânditor",
    "gânditorii": "gânditor",
    "gânditorilor": "gânditor",
    "gânditorul": "gânditor",
    "gânditorului": "gânditor",
    "gangul": "gang",
    "gangului": "gang",
    "ganguri": "gang",
    "gangurile": "gang",
    "gangurilor": "gang",
    "gângăveala": "gângăveală",
    "gângăvealo": "gângăveală",
    "gângăveli": "gângăveală",
    "gângăvelii": "gângăveală",
    "gângăvelile": "gângăveală",
    "gângăvelilor": "gângăveală",
    "gângăvea": "gângăvi",
    "gângăveai": "gângăvi",
    "gângăveam": "gângăvi",
    "gângăvească": "gângăvi",
    "gângăveați": "gângăvi",
    "gângăveau": "gângăvi",
    "gângăvesc": "gângăvi",
    "gângăvește": "gângăvi",
    "gângăvești": "gângăvi",
    "gângăvii": "gângăvi",
    "gângăvim": "gângăvi",
    "gângăvind": "gângăvi",
    "gângăvindu": "gângăvi",
    "gângăviră": "gângăvi",
    "gângăvirăm": "gângăvi",
    "gângăvirăți": "gângăvi",
    "gângăvise": "gângăvi",
    "gângăvisem": "gângăvi",
    "gângăviseră": "gângăvi",
    "gângăviserăm": "gângăvi",
    "gângăviserăți": "gângăvi",
    "gângăviseși": "gângăvi",
    "gângăviși": "gângăvi",
    "gângăvit": "gângăvi",
    "gângăviți": "gângăvi",
    "gângăvitu": "gângăvi",
    "negângăvind": "gângăvi",
    "negângăvindu": "gângăvi",
    "nemaigângăvind": "gângăvi",
    "nemaigângăvindu": "gângăvi",
    "gângăvită": "gângăvit",
    "gângăvite": "gângăvit",
    "gângăviți": "gângăvit",
    "gângăvitul": "gângăvit",
    "gângăvitului": "gângăvit",
    "ganglioane": "ganglion",
    "ganglioanele": "ganglion",
    "ganglioanelor": "ganglion",
    "ganglionul": "ganglion",
    "ganglionului": "ganglion",
    "gangrena": "gangrenă",
    "gangrene": "gangrenă",
    "gangrenei": "gangrenă",
    "gangrenele": "gangrenă",
    "gangrenelor": "gangrenă",
    "gangsteri": "gangster",
    "gangsterii": "gangster",
    "gangsterilor": "gangster",
    "gangsterul": "gangster",
    "gangsterului": "gangster",
    "gângurea": "gânguri",
    "gângureai": "gânguri",
    "gânguream": "gânguri",
    "gângurească": "gânguri",
    "gângureați": "gânguri",
    "gângureau": "gânguri",
    "gânguresc": "gânguri",
    "gângurește": "gânguri",
    "gângurești": "gânguri",
    "gângurii": "gânguri",
    "gângurim": "gânguri",
    "gângurind": "gânguri",
    "gângurindu": "gânguri",
    "gânguriră": "gânguri",
    "gângurirăm": "gânguri",
    "gângurirăți": "gânguri",
    "gângurise": "gânguri",
    "gângurisem": "gânguri",
    "gânguriseră": "gânguri",
    "gânguriserăm": "gânguri",
    "gânguriserăți": "gânguri",
    "gânguriseși": "gânguri",
    "gânguriși": "gânguri",
    "gângurit": "gânguri",
    "gânguriți": "gânguri",
    "gânguritu": "gânguri",
    "negângurind": "gânguri",
    "negângurindu": "gânguri",
    "nemaigângurind": "gânguri",
    "nemaigângurindu": "gânguri",
    "gângurită": "gângurit",
    "gângurite": "gângurit",
    "gânguriți": "gângurit",
    "gânguritul": "gângurit",
    "gânguritului": "gângurit",
    "găoacea": "găoace",
    "găoci": "găoace",
    "găocii": "găoace",
    "găocile": "găoace",
    "găocilor": "găoace",
    "gară": "gara",
    "garai": "gara",
    "garam": "gara",
    "garăm": "gara",
    "garând": "gara",
    "garându": "gara",
    "garară": "gara",
    "gararăm": "gara",
    "gararăți": "gara",
    "garase": "gara",
    "garasem": "gara",
    "garaseră": "gara",
    "garaserăm": "gara",
    "garaserăți": "gara",
    "garaseși": "gara",
    "garași": "gara",
    "garat": "gara",
    "garați": "gara",
    "garatu": "gara",
    "garau": "gara",
    "garează": "gara",
    "garez": "gara",
    "gareze": "gara",
    "garezi": "gara",
    "negarând": "gara",
    "negarându": "gara",
    "nemaigarând": "gara",
    "nemaigarându": "gara",
    "gara": "gară",
    "gări": "gară",
    "gării": "gară",
    "gările": "gară",
    "gărilor": "gară",
    "Gării_de_Nord": "Gara_de_Nord",
    "garafa": "garafă",
    "garafe": "garafă",
    "garafei": "garafă",
    "garafele": "garafă",
    "garafelor": "garafă",
    "garaje": "garaj",
    "garajele": "garaj",
    "garajelor": "garaj",
    "garajul": "garaj",
    "garajului": "garaj",
    "garanți": "garant",
    "garanții": "garant",
    "garanților": "garant",
    "garantul": "garant",
    "garantule": "garant",
    "garantului": "garant",
    "garantă": "garanta",
    "garantai": "garanta",
    "garantam": "garanta",
    "garantăm": "garanta",
    "garantând": "garanta",
    "garantându": "garanta",
    "garantară": "garanta",
    "garantarăm": "garanta",
    "garantarăți": "garanta",
    "garantase": "garanta",
    "garantasem": "garanta",
    "garantaseră": "garanta",
    "garantaserăm": "garanta",
    "garantaserăți": "garanta",
    "garantaseși": "garanta",
    "garantași": "garanta",
    "garantat": "garanta",
    "garantați": "garanta",
    "garantatu": "garanta",
    "garantau": "garanta",
    "garantează": "garanta",
    "garantez": "garanta",
    "garanteze": "garanta",
    "garantezi": "garanta",
    "negarantând": "garanta",
    "negarantându": "garanta",
    "nemaigarantând": "garanta",
    "nemaigarantându": "garanta",
    "garantarea": "garantare",
    "garantareo": "garantare",
    "garantări": "garantare",
    "garantării": "garantare",
    "garantările": "garantare",
    "garantărilor": "garantare",
    "garantată": "garantat",
    "garantate": "garantat",
    "garantați": "garantat",
    "garanția": "garanție",
    "garanției": "garanție",
    "garanții": "garanție",
    "garanțiile": "garanție",
    "garanțiilor": "garanție",
    "garată": "garat",
    "garate": "garat",
    "garați": "garat",
    "gârbova": "gârbov",
    "gârbovă": "gârbov",
    "gârbove": "gârbov",
    "gârbovei": "gârbov",
    "gârbovele": "gârbov",
    "gârbovelor": "gârbov",
    "gârbovi": "gârbov",
    "gârbovii": "gârbov",
    "gârbovilor": "gârbov",
    "gârbovul": "gârbov",
    "gârbovului": "gârbov",
    "gârbovea": "gârbovi",
    "gârboveai": "gârbovi",
    "gârboveam": "gârbovi",
    "gârbovească": "gârbovi",
    "gârboveați": "gârbovi",
    "gârboveau": "gârbovi",
    "gârbovesc": "gârbovi",
    "gârbovește": "gârbovi",
    "gârbovești": "gârbovi",
    "gârbovii": "gârbovi",
    "gârbovim": "gârbovi",
    "gârbovind": "gârbovi",
    "gârbovindu": "gârbovi",
    "gârboviră": "gârbovi",
    "gârbovirăm": "gârbovi",
    "gârbovirăți": "gârbovi",
    "gârbovise": "gârbovi",
    "gârbovisem": "gârbovi",
    "gârboviseră": "gârbovi",
    "gârboviserăm": "gârbovi",
    "gârboviserăți": "gârbovi",
    "gârboviseși": "gârbovi",
    "gârboviși": "gârbovi",
    "gârbovit": "gârbovi",
    "gârboviți": "gârbovi",
    "gârbovitu": "gârbovi",
    "negârbovind": "gârbovi",
    "negârbovindu": "gârbovi",
    "nemaigârbovind": "gârbovi",
    "nemaigârbovindu": "gârbovi",
    "gârbovită": "gârbovit",
    "gârbovite": "gârbovit",
    "gârboviți": "gârbovit",
    "gardul": "gard",
    "gardului": "gard",
    "garduri": "gard",
    "gardurile": "gard",
    "gardurilor": "gard",
    "garda": "gardă",
    "gărzi": "gardă",
    "gărzii": "gardă",
    "gărzile": "gardă",
    "gărzilor": "gardă",
    "garderobul": "garderob",
    "garderobului": "garderob",
    "garderoburi": "garderob",
    "garderoburile": "garderob",
    "garderoburilor": "garderob",
    "garderoba": "garderobă",
    "garderobe": "garderobă",
    "garderobei": "garderobă",
    "garderobele": "garderobă",
    "garderobelor": "garderobă",
    "gardianul": "gardian",
    "gardianului": "gardian",
    "gardieni": "gardian",
    "gardienii": "gardian",
    "gardienilor": "gardian",
    "gărduia": "gărdui",
    "gărduiai": "gărdui",
    "gărduiam": "gărdui",
    "gărduiască": "gărdui",
    "gărduiați": "gărdui",
    "gărduiau": "gărdui",
    "gărduiesc": "gărdui",
    "gărduiește": "gărdui",
    "gărduiești": "gărdui",
    "gărduii": "gărdui",
    "gărduim": "gărdui",
    "gărduind": "gărdui",
    "gărduindu": "gărdui",
    "gărduiră": "gărdui",
    "gărduirăm": "gărdui",
    "gărduirăți": "gărdui",
    "gărduise": "gărdui",
    "gărduisem": "gărdui",
    "gărduiseră": "gărdui",
    "gărduiserăm": "gărdui",
    "gărduiserăți": "gărdui",
    "gărduiseși": "gărdui",
    "gărduiși": "gărdui",
    "gărduit": "gărdui",
    "gărduiți": "gărdui",
    "gărduitu": "gărdui",
    "negărduind": "gărdui",
    "negărduindu": "gărdui",
    "nemaigărduind": "gărdui",
    "nemaigărduindu": "gărdui",
    "gărduită": "gărduit",
    "gărduite": "gărduit",
    "gărduiți": "gărduit",
    "gargarisea": "gargarisi",
    "gargariseai": "gargarisi",
    "gargariseam": "gargarisi",
    "gargarisească": "gargarisi",
    "gargariseați": "gargarisi",
    "gargariseau": "gargarisi",
    "gargarisesc": "gargarisi",
    "gargarisește": "gargarisi",
    "gargarisești": "gargarisi",
    "gargarisii": "gargarisi",
    "gargarisim": "gargarisi",
    "gargarisind": "gargarisi",
    "gargarisindu": "gargarisi",
    "gargarisiră": "gargarisi",
    "gargarisirăm": "gargarisi",
    "gargarisirăți": "gargarisi",
    "gargarisise": "gargarisi",
    "gargarisisem": "gargarisi",
    "gargarisiseră": "gargarisi",
    "gargarisiserăm": "gargarisi",
    "gargarisiserăți": "gargarisi",
    "gargarisiseși": "gargarisi",
    "gargarisiși": "gargarisi",
    "gargarisit": "gargarisi",
    "gargarisiți": "gargarisi",
    "gargarisitu": "gargarisi",
    "negargarisind": "gargarisi",
    "negargarisindu": "gargarisi",
    "nemaigargarisind": "gargarisi",
    "nemaigargarisindu": "gargarisi",
    "gargarisită": "gargarisit",
    "gargarisite": "gargarisit",
    "gargarisiți": "gargarisit",
    "gargariză": "gargariza",
    "gargarizai": "gargariza",
    "gargarizam": "gargariza",
    "gargarizăm": "gargariza",
    "gargarizând": "gargariza",
    "gargarizându": "gargariza",
    "gargarizară": "gargariza",
    "gargarizarăm": "gargariza",
    "gargarizarăți": "gargariza",
    "gargarizase": "gargariza",
    "gargarizasem": "gargariza",
    "gargarizaseră": "gargariza",
    "gargarizaserăm": "gargariza",
    "gargarizaserăți": "gargariza",
    "gargarizaseși": "gargariza",
    "gargarizași": "gargariza",
    "gargarizat": "gargariza",
    "gargarizați": "gargariza",
    "gargarizatu": "gargariza",
    "gargarizau": "gargariza",
    "gargarizează": "gargariza",
    "gargarizez": "gargariza",
    "gargarizeze": "gargariza",
    "gargarizezi": "gargariza",
    "negargarizând": "gargariza",
    "negargarizându": "gargariza",
    "nemaigargarizând": "gargariza",
    "nemaigargarizându": "gargariza",
    "gargarizată": "gargarizat",
    "gargarizate": "gargarizat",
    "gargarizați": "gargarizat",
    "gărgăuni": "gărgăun",
    "gărgăunii": "gărgăun",
    "gărgăunilor": "gărgăun",
    "gărgăunul": "gărgăun",
    "gărgăunului": "gărgăun",
    "gârla": "gârlă",
    "gârle": "gârlă",
    "gârlei": "gârlă",
    "gârlele": "gârlă",
    "gârlelor": "gârlă",
    "garnisea": "garnisi",
    "garniseai": "garnisi",
    "garniseam": "garnisi",
    "garnisească": "garnisi",
    "garniseați": "garnisi",
    "garniseau": "garnisi",
    "garnisesc": "garnisi",
    "garnisește": "garnisi",
    "garnisești": "garnisi",
    "garnisii": "garnisi",
    "garnisim": "garnisi",
    "garnisind": "garnisi",
    "garnisindu": "garnisi",
    "garnisiră": "garnisi",
    "garnisirăm": "garnisi",
    "garnisirăți": "garnisi",
    "garnisise": "garnisi",
    "garnisisem": "garnisi",
    "garnisiseră": "garnisi",
    "garnisiserăm": "garnisi",
    "garnisiserăți": "garnisi",
    "garnisiseși": "garnisi",
    "garnisiși": "garnisi",
    "garnisit": "garnisi",
    "garnisiți": "garnisi",
    "garnisitu": "garnisi",
    "negarnisind": "garnisi",
    "negarnisindu": "garnisi",
    "nemaigarnisind": "garnisi",
    "nemaigarnisindu": "garnisi",
    "garnisită": "garnisit",
    "garnisite": "garnisit",
    "garnisiți": "garnisit",
    "garnitura": "garnitură",
    "garnituri": "garnitură",
    "garniturii": "garnitură",
    "garniturile": "garnitură",
    "garniturilor": "garnitură",
    "garnizoana": "garnizoană",
    "garnizoane": "garnizoană",
    "garnizoanei": "garnizoană",
    "garnizoanele": "garnizoană",
    "garnizoanelor": "garnizoană",
    "garoafa": "garoafă",
    "garoafe": "garoafă",
    "garoafei": "garoafă",
    "garoafele": "garoafă",
    "garoafelor": "garoafă",
    "garsoniera": "garsonieră",
    "garsoniere": "garsonieră",
    "garsonierei": "garsonieră",
    "garsonierele": "garsonieră",
    "garsonierelor": "garsonieră",
    "gașca": "gașcă",
    "găști": "gașcă",
    "găștii": "gașcă",
    "găștile": "gașcă",
    "găștilor": "gașcă",
    "gâsca": "gâscă",
    "gâște": "gâscă",
    "gâștei": "gâscă",
    "gâștele": "gâscă",
    "gâștelor": "gâscă",
    "gâscani": "gâscan",
    "gâscanii": "gâscan",
    "gâscanilor": "gâscan",
    "gâscanul": "gâscan",
    "gâscanului": "gâscan",
    "găsea": "găsi",
    "găseai": "găsi",
    "găseam": "găsi",
    "găsească": "găsi",
    "găseați": "găsi",
    "găseau": "găsi",
    "găsesc": "găsi",
    "găsește": "găsi",
    "găsești": "găsi",
    "găsii": "găsi",
    "găsim": "găsi",
    "găsind": "găsi",
    "găsindu": "găsi",
    "găsiră": "găsi",
    "găsirăm": "găsi",
    "găsirăți": "găsi",
    "găsise": "găsi",
    "găsisem": "găsi",
    "găsiseră": "găsi",
    "găsiserăm": "găsi",
    "găsiserăți": "găsi",
    "găsiseși": "găsi",
    "găsiși": "găsi",
    "găsit": "găsi",
    "găsiți": "găsi",
    "găsitu": "găsi",
    "negăsind": "găsi",
    "negăsindu": "găsi",
    "nemaigăsind": "găsi",
    "nemaigăsindu": "găsi",
    "găsirea": "găsire",
    "găsiri": "găsire",
    "găsirii": "găsire",
    "găsită": "găsit",
    "găsite": "găsit",
    "găsiți": "găsit",
    "găsitori": "găsitor",
    "găsitorii": "găsitor",
    "găsitorilor": "găsitor",
    "găsitorul": "găsitor",
    "găsitorului": "găsitor",
    "gastronomia": "gastronomie",
    "gastronomiei": "gastronomie",
    "gastronomii": "gastronomie",
    "gâtul": "gât",
    "gâtului": "gât",
    "gâturi": "gât",
    "gâturile": "gât",
    "gâturilor": "gât",
    "găteje": "gătej",
    "gătejele": "gătej",
    "gătejelor": "gătej",
    "gătejul": "gătej",
    "gătejule": "gătej",
    "gătejului": "gătej",
    "gătea": "găti",
    "găteai": "găti",
    "găteam": "găti",
    "gătească": "găti",
    "găteați": "găti",
    "găteau": "găti",
    "gătesc": "găti",
    "gătește": "găti",
    "gătești": "găti",
    "gătii": "găti",
    "gătim": "găti",
    "gătind": "găti",
    "gătindu": "găti",
    "gătiră": "găti",
    "gătirăm": "găti",
    "gătirăți": "găti",
    "gătise": "găti",
    "gătisem": "găti",
    "gătiseră": "găti",
    "gătiserăm": "găti",
    "gătiserăți": "găti",
    "gătiseși": "găti",
    "gătiși": "găti",
    "gătit": "găti",
    "gătiți": "găti",
    "gătitu": "găti",
    "negătind": "găti",
    "negătindu": "găti",
    "nemaigătind": "găti",
    "nemaigătindu": "găti",
    "gătită": "gătit",
    "gătite": "gătit",
    "gătiți": "gătit",
    "gătitul": "gătit",
    "gătitului": "gătit",
    "gâtlejul": "gâtlej",
    "gâtlejului": "gâtlej",
    "gâtlejuri": "gâtlej",
    "gâtlejurile": "gâtlej",
    "gâtlejurilor": "gâtlej",
    "gâtuia": "gâtui",
    "gâtuiai": "gâtui",
    "gâtuiam": "gâtui",
    "gâtuiați": "gâtui",
    "gâtuiau": "gâtui",
    "gâtuie": "gâtui",
    "gâtuii": "gâtui",
    "gâtuim": "gâtui",
    "gâtuind": "gâtui",
    "gâtuindu": "gâtui",
    "gâtuiră": "gâtui",
    "gâtuirăm": "gâtui",
    "gâtuirăți": "gâtui",
    "gâtuise": "gâtui",
    "gâtuisem": "gâtui",
    "gâtuiseră": "gâtui",
    "gâtuiserăm": "gâtui",
    "gâtuiserăți": "gâtui",
    "gâtuiseși": "gâtui",
    "gâtuiși": "gâtui",
    "gâtuit": "gâtui",
    "gâtuiți": "gâtui",
    "gâtuitu": "gâtui",
    "negâtuind": "gâtui",
    "negâtuindu": "gâtui",
    "nemaigâtuind": "gâtui",
    "nemaigâtuindu": "gâtui",
    "gâtuită": "gâtuit",
    "gâtuite": "gâtuit",
    "gâtuiți": "gâtuit",
    "găunoasa": "găunos",
    "găunoasă": "găunos",
    "găunoase": "găunos",
    "găunoasei": "găunos",
    "găunoasele": "găunos",
    "găunoaselor": "găunos",
    "găunoși": "găunos",
    "găunoșii": "găunos",
    "găunoșilor": "găunos",
    "găunosul": "găunos",
    "găunosului": "găunos",
    "găunoșea": "găunoși",
    "găunoșeai": "găunoși",
    "găunoșeam": "găunoși",
    "găunoșească": "găunoși",
    "găunoșeați": "găunoși",
    "găunoșeau": "găunoși",
    "găunoșesc": "găunoși",
    "găunoșește": "găunoși",
    "găunoșești": "găunoși",
    "găunoșii": "găunoși",
    "găunoșim": "găunoși",
    "găunoșind": "găunoși",
    "găunoșindu": "găunoși",
    "găunoșiră": "găunoși",
    "găunoșirăm": "găunoși",
    "găunoșirăți": "găunoși",
    "găunoșise": "găunoși",
    "găunoșisem": "găunoși",
    "găunoșiseră": "găunoși",
    "găunoșiserăm": "găunoși",
    "găunoșiserăți": "găunoși",
    "găunoșiseși": "găunoși",
    "găunoșiși": "găunoși",
    "găunoșit": "găunoși",
    "găunoșiți": "găunoși",
    "găunoșitu": "găunoși",
    "negăunoșind": "găunoși",
    "negăunoșindu": "găunoși",
    "nemaigăunoșind": "găunoși",
    "nemaigăunoșindu": "găunoși",
    "găunoșită": "găunoșit",
    "găunoșite": "găunoșit",
    "găunoșiți": "găunoșit",
    "gaura": "gaură",
    "găuri": "gaură",
    "găurii": "gaură",
    "găurile": "gaură",
    "găurilor": "gaură",
    "găurea": "găuri",
    "găureai": "găuri",
    "găuream": "găuri",
    "găurească": "găuri",
    "găureați": "găuri",
    "găureau": "găuri",
    "găuresc": "găuri",
    "găurește": "găuri",
    "găurești": "găuri",
    "găurii": "găuri",
    "găurim": "găuri",
    "găurind": "găuri",
    "găurindu": "găuri",
    "găuriră": "găuri",
    "găurirăm": "găuri",
    "găurirăți": "găuri",
    "găurise": "găuri",
    "găurisem": "găuri",
    "găuriseră": "găuri",
    "găuriserăm": "găuri",
    "găuriserăți": "găuri",
    "găuriseși": "găuri",
    "găuriși": "găuri",
    "găurit": "găuri",
    "găuriți": "găuri",
    "găuritu": "găuri",
    "negăurind": "găuri",
    "negăurindu": "găuri",
    "nemaigăurind": "găuri",
    "nemaigăurindu": "găuri",
    "găurită": "găurit",
    "găurite": "găurit",
    "găuriți": "găurit",
    "găvozdea": "găvozdi",
    "găvozdeai": "găvozdi",
    "găvozdeam": "găvozdi",
    "găvozdească": "găvozdi",
    "găvozdeați": "găvozdi",
    "găvozdeau": "găvozdi",
    "găvozdesc": "găvozdi",
    "găvozdește": "găvozdi",
    "găvozdești": "găvozdi",
    "găvozdii": "găvozdi",
    "găvozdim": "găvozdi",
    "găvozdind": "găvozdi",
    "găvozdindu": "găvozdi",
    "găvozdiră": "găvozdi",
    "găvozdirăm": "găvozdi",
    "găvozdirăți": "găvozdi",
    "găvozdise": "găvozdi",
    "găvozdisem": "găvozdi",
    "găvozdiseră": "găvozdi",
    "găvozdiserăm": "găvozdi",
    "găvozdiserăți": "găvozdi",
    "găvozdiseși": "găvozdi",
    "găvozdiși": "găvozdi",
    "găvozdit": "găvozdi",
    "găvozdiți": "găvozdi",
    "găvozditu": "găvozdi",
    "negăvozdind": "găvozdi",
    "negăvozdindu": "găvozdi",
    "nemaigăvozdind": "găvozdi",
    "nemaigăvozdindu": "găvozdi",
    "găvozdită": "găvozdit",
    "găvozdite": "găvozdit",
    "găvozdiți": "găvozdit",
    "gaze": "gaz",
    "gazele": "gaz",
    "gazelor": "gaz",
    "gazul": "gaz",
    "gazului": "gaz",
    "gază": "gaza",
    "gazai": "gaza",
    "gazam": "gaza",
    "gazăm": "gaza",
    "gazând": "gaza",
    "gazându": "gaza",
    "gazară": "gaza",
    "gazarăm": "gaza",
    "gazarăți": "gaza",
    "gazase": "gaza",
    "gazasem": "gaza",
    "gazaseră": "gaza",
    "gazaserăm": "gaza",
    "gazaserăți": "gaza",
    "gazaseși": "gaza",
    "gazași": "gaza",
    "gazat": "gaza",
    "gazați": "gaza",
    "gazatu": "gaza",
    "gazau": "gaza",
    "gazează": "gaza",
    "gazez": "gaza",
    "gazeze": "gaza",
    "gazezi": "gaza",
    "negazând": "gaza",
    "negazându": "gaza",
    "nemaigazând": "gaza",
    "nemaigazându": "gaza",
    "gâza": "gâză",
    "gâze": "gâză",
    "gâzei": "gâză",
    "gâzele": "gâză",
    "gâzelor": "gâză",
    "gazată": "gazat",
    "gazate": "gazat",
    "gazați": "gazat",
    "gazda": "gazdă",
    "gazde": "gazdă",
    "gazdei": "gazdă",
    "gazdele": "gazdă",
    "gazdelor": "gazdă",
    "găzduia": "găzdui",
    "găzduiai": "găzdui",
    "găzduiam": "găzdui",
    "găzduiască": "găzdui",
    "găzduiați": "găzdui",
    "găzduiau": "găzdui",
    "găzduiesc": "găzdui",
    "găzduiește": "găzdui",
    "găzduiești": "găzdui",
    "găzduii": "găzdui",
    "găzduim": "găzdui",
    "găzduind": "găzdui",
    "găzduindu": "găzdui",
    "găzduiră": "găzdui",
    "găzduirăm": "găzdui",
    "găzduirăți": "găzdui",
    "găzduise": "găzdui",
    "găzduisem": "găzdui",
    "găzduiseră": "găzdui",
    "găzduiserăm": "găzdui",
    "găzduiserăți": "găzdui",
    "găzduiseși": "găzdui",
    "găzduiși": "găzdui",
    "găzduit": "găzdui",
    "găzduiți": "găzdui",
    "găzduitu": "găzdui",
    "negăzduind": "găzdui",
    "negăzduindu": "găzdui",
    "nemaigăzduind": "găzdui",
    "nemaigăzduindu": "găzdui",
    "găzduirea": "găzduire",
    "găzduiri": "găzduire",
    "găzduirii": "găzduire",
    "găzduirile": "găzduire",
    "găzduirilor": "găzduire",
    "găzduită": "găzduit",
    "găzduite": "găzduit",
    "găzduiți": "găzduit",
    "gazela": "gazelă",
    "gazele": "gazelă",
    "gazelei": "gazelă",
    "gazelele": "gazelă",
    "gazelelor": "gazelă",
    "gazeta": "gazetă",
    "gazete": "gazetă",
    "gazetei": "gazetă",
    "gazetele": "gazetă",
    "gazetelor": "gazetă",
    "gazetari": "gazetar",
    "gazetarii": "gazetar",
    "gazetarilor": "gazetar",
    "gazetarul": "gazetar",
    "gazetarului": "gazetar",
    "gazetăreasca": "gazetăresc",
    "gazetărească": "gazetăresc",
    "gazetăreasco": "gazetăresc",
    "gazetărescul": "gazetăresc",
    "gazetărescule": "gazetăresc",
    "gazetărescului": "gazetăresc",
    "gazetărești": "gazetăresc",
    "gazetăreștii": "gazetăresc",
    "gazetăreștile": "gazetăresc",
    "gazetăreștilor": "gazetăresc",
    "gazetioara": "gazetioară",
    "gazetioare": "gazetioară",
    "gazetioarei": "gazetioară",
    "gazetioarele": "gazetioară",
    "gazetioarelor": "gazetioară",
    "gazetioaro": "gazetioară",
    "gazific": "gazifica",
    "gazifică": "gazifica",
    "gazificai": "gazifica",
    "gazificam": "gazifica",
    "gazificăm": "gazifica",
    "gazificând": "gazifica",
    "gazificându": "gazifica",
    "gazificară": "gazifica",
    "gazificarăm": "gazifica",
    "gazificarăți": "gazifica",
    "gazificase": "gazifica",
    "gazificasem": "gazifica",
    "gazificaseră": "gazifica",
    "gazificaserăm": "gazifica",
    "gazificaserăți": "gazifica",
    "gazificaseși": "gazifica",
    "gazificași": "gazifica",
    "gazificat": "gazifica",
    "gazificați": "gazifica",
    "gazificatu": "gazifica",
    "gazificau": "gazifica",
    "gazifice": "gazifica",
    "gazifici": "gazifica",
    "negazificând": "gazifica",
    "negazificându": "gazifica",
    "nemaigazificând": "gazifica",
    "nemaigazificându": "gazifica",
    "gazificată": "gazificat",
    "gazificate": "gazificat",
    "gazificați": "gazificat",
    "gazonul": "gazon",
    "gazonului": "gazon",
    "gazonă": "gazona",
    "gazonai": "gazona",
    "gazonam": "gazona",
    "gazonăm": "gazona",
    "gazonând": "gazona",
    "gazonându": "gazona",
    "gazonară": "gazona",
    "gazonarăm": "gazona",
    "gazonarăți": "gazona",
    "gazonase": "gazona",
    "gazonasem": "gazona",
    "gazonaseră": "gazona",
    "gazonaserăm": "gazona",
    "gazonaserăți": "gazona",
    "gazonaseși": "gazona",
    "gazonași": "gazona",
    "gazonat": "gazona",
    "gazonați": "gazona",
    "gazonatu": "gazona",
    "gazonau": "gazona",
    "gazonează": "gazona",
    "gazonez": "gazona",
    "gazoneze": "gazona",
    "gazonezi": "gazona",
    "negazonând": "gazona",
    "negazonându": "gazona",
    "nemaigazonând": "gazona",
    "nemaigazonându": "gazona",
    "gazonată": "gazonat",
    "gazonate": "gazonat",
    "gazonați": "gazonat",
    "gazoasa": "gazos",
    "gazoasă": "gazos",
    "gazoase": "gazos",
    "gazoasei": "gazos",
    "gazoasele": "gazos",
    "gazoaselor": "gazos",
    "gazoși": "gazos",
    "gazoșii": "gazos",
    "gazoșilor": "gazos",
    "gazosul": "gazos",
    "gazosului": "gazos",
    "geci": "geacă",
    "gealați": "gealat",
    "gealații": "gealat",
    "gealaților": "gealat",
    "gealatul": "gealat",
    "gealatului": "gealat",
    "geamul": "geam",
    "geamului": "geam",
    "geamuri": "geam",
    "geamurile": "geam",
    "geamurilor": "geam",
    "geamăna": "geamăn",
    "geamănă": "geamăn",
    "geamăno": "geamăn",
    "geamănul": "geamăn",
    "geamănule": "geamăn",
    "geamănului": "geamăn",
    "gemene": "geamăn",
    "gemenei": "geamăn",
    "gemenele": "geamăn",
    "gemenelor": "geamăn",
    "gemeni": "geamăn",
    "gemenii": "geamăn",
    "gemenilor": "geamăn",
    "geamandura": "geamandură",
    "geamanduri": "geamandură",
    "geamandurii": "geamandură",
    "geamandurile": "geamandură",
    "geamandurilor": "geamandură",
    "geamantane": "geamantan",
    "geamantanele": "geamantan",
    "geamantanelor": "geamantan",
    "geamantanul": "geamantan",
    "geamantanului": "geamantan",
    "geamătul": "geamăt",
    "geamătului": "geamăt",
    "gemete": "geamăt",
    "gemetele": "geamăt",
    "gemetelor": "geamăt",
    "geambași": "geambaș",
    "geambașii": "geambaș",
    "geambașilor": "geambaș",
    "geambașul": "geambaș",
    "geambașule": "geambaș",
    "geambașului": "geambaș",
    "geamgii": "geamgiu",
    "geamgiii": "geamgiu",
    "geamgiilor": "geamgiu",
    "geamgiul": "geamgiu",
    "geamgiului": "geamgiu",
    "geana": "geană",
    "gene": "geană",
    "genei": "geană",
    "genele": "geană",
    "genelor": "geană",
    "geanta": "geantă",
    "genți": "geantă",
    "genții": "geantă",
    "gențile": "geantă",
    "genților": "geantă",
    "gelatina": "gelatină",
    "gelatine": "gelatină",
    "gelatinei": "gelatină",
    "gelatinele": "gelatină",
    "gelatinelor": "gelatină",
    "gelatiniză": "gelatiniza",
    "gelatinizai": "gelatiniza",
    "gelatinizam": "gelatiniza",
    "gelatinizăm": "gelatiniza",
    "gelatinizând": "gelatiniza",
    "gelatinizându": "gelatiniza",
    "gelatinizară": "gelatiniza",
    "gelatinizarăm": "gelatiniza",
    "gelatinizarăți": "gelatiniza",
    "gelatinizase": "gelatiniza",
    "gelatinizasem": "gelatiniza",
    "gelatinizaseră": "gelatiniza",
    "gelatinizaserăm": "gelatiniza",
    "gelatinizaserăți": "gelatiniza",
    "gelatinizaseși": "gelatiniza",
    "gelatinizași": "gelatiniza",
    "gelatinizat": "gelatiniza",
    "gelatinizați": "gelatiniza",
    "gelatinizatu": "gelatiniza",
    "gelatinizau": "gelatiniza",
    "gelatinizează": "gelatiniza",
    "gelatinizez": "gelatiniza",
    "gelatinizeze": "gelatiniza",
    "gelatinizezi": "gelatiniza",
    "negelatinizând": "gelatiniza",
    "negelatinizându": "gelatiniza",
    "nemaigelatinizând": "gelatiniza",
    "nemaigelatinizându": "gelatiniza",
    "gelatinizată": "gelatinizat",
    "gelatinizate": "gelatinizat",
    "gelatinizați": "gelatinizat",
    "gelatinoasa": "gelatinos",
    "gelatinoasă": "gelatinos",
    "gelatinoase": "gelatinos",
    "gelatinoasei": "gelatinos",
    "gelatinoasele": "gelatinos",
    "gelatinoaselor": "gelatinos",
    "gelatinoși": "gelatinos",
    "gelatinoșii": "gelatinos",
    "gelatinoșilor": "gelatinos",
    "gelatinosul": "gelatinos",
    "gelatinosului": "gelatinos",
    "gelific": "gelifica",
    "gelifică": "gelifica",
    "gelificai": "gelifica",
    "gelificam": "gelifica",
    "gelificăm": "gelifica",
    "gelificând": "gelifica",
    "gelificându": "gelifica",
    "gelificară": "gelifica",
    "gelificarăm": "gelifica",
    "gelificarăți": "gelifica",
    "gelificase": "gelifica",
    "gelificasem": "gelifica",
    "gelificaseră": "gelifica",
    "gelificaserăm": "gelifica",
    "gelificaserăți": "gelifica",
    "gelificaseși": "gelifica",
    "gelificași": "gelifica",
    "gelificat": "gelifica",
    "gelificați": "gelifica",
    "gelificatu": "gelifica",
    "gelificau": "gelifica",
    "gelifice": "gelifica",
    "gelifici": "gelifica",
    "negelificând": "gelifica",
    "negelificându": "gelifica",
    "nemaigelificând": "gelifica",
    "nemaigelificându": "gelifica",
    "gelificată": "gelificat",
    "gelificate": "gelificat",
    "gelificați": "gelificat",
    "geloasa": "gelos",
    "geloasă": "gelos",
    "geloase": "gelos",
    "geloasei": "gelos",
    "geloasele": "gelos",
    "geloaselor": "gelos",
    "geloși": "gelos",
    "geloșii": "gelos",
    "geloșilor": "gelos",
    "gelosul": "gelos",
    "gelosului": "gelos",
    "gelozia": "gelozie",
    "geloziei": "gelozie",
    "gelozii": "gelozie",
    "geloziile": "gelozie",
    "geloziilor": "gelozie",
    "geluia": "gelui",
    "geluiai": "gelui",
    "geluiam": "gelui",
    "geluiască": "gelui",
    "geluiați": "gelui",
    "geluiau": "gelui",
    "geluiesc": "gelui",
    "geluiește": "gelui",
    "geluiești": "gelui",
    "geluii": "gelui",
    "geluim": "gelui",
    "geluind": "gelui",
    "geluindu": "gelui",
    "geluiră": "gelui",
    "geluirăm": "gelui",
    "geluirăți": "gelui",
    "geluise": "gelui",
    "geluisem": "gelui",
    "geluiseră": "gelui",
    "geluiserăm": "gelui",
    "geluiserăți": "gelui",
    "geluiseși": "gelui",
    "geluiși": "gelui",
    "geluit": "gelui",
    "geluiți": "gelui",
    "geluitu": "gelui",
    "negeluind": "gelui",
    "negeluindu": "gelui",
    "nemaigeluind": "gelui",
    "nemaigeluindu": "gelui",
    "geluită": "geluit",
    "geluite": "geluit",
    "geluiți": "geluit",
    "gemul": "gem",
    "gemului": "gem",
    "gemuri": "gem",
    "gemurile": "gem",
    "gemurilor": "gem",
    "geamă": "geme",
    "gem": "geme",
    "gemă": "geme",
    "gemând": "geme",
    "gemându": "geme",
    "gemea": "geme",
    "gemeai": "geme",
    "gemeam": "geme",
    "gemeați": "geme",
    "gemeau": "geme",
    "gemem": "geme",
    "gemeți": "geme",
    "gemi": "geme",
    "gemu": "geme",
    "gemui": "geme",
    "gemură": "geme",
    "gemurăm": "geme",
    "gemurăți": "geme",
    "gemuse": "geme",
    "gemusem": "geme",
    "gemuseră": "geme",
    "gemuserăm": "geme",
    "gemuserăți": "geme",
    "gemuseși": "geme",
    "gemuși": "geme",
    "gemut": "geme",
    "gemutu": "geme",
    "negemând": "geme",
    "negemându": "geme",
    "nemaigemând": "geme",
    "nemaigemându": "geme",
    "gemută": "gemut",
    "gemute": "gemut",
    "gemuți": "gemut",
    "genul": "gen",
    "genului": "gen",
    "genuri": "gen",
    "genurile": "gen",
    "genurilor": "gen",
    "gena": "genă",
    "gene": "genă",
    "genei": "genă",
    "genele": "genă",
    "genelor": "genă",
    "genealogica": "genealogic",
    "genealogică": "genealogic",
    "genealogice": "genealogic",
    "genealogicei": "genealogic",
    "genealogicele": "genealogic",
    "genealogicelor": "genealogic",
    "genealogici": "genealogic",
    "genealogicii": "genealogic",
    "genealogicilor": "genealogic",
    "genealogicul": "genealogic",
    "genealogicului": "genealogic",
    "genealogia": "genealogie",
    "genealogiei": "genealogie",
    "genealogii": "genealogie",
    "genealogiile": "genealogie",
    "genealogiilor": "genealogie",
    "generă": "genera",
    "generai": "genera",
    "generam": "genera",
    "generăm": "genera",
    "generând": "genera",
    "generându": "genera",
    "generară": "genera",
    "generarăm": "genera",
    "generarăți": "genera",
    "generase": "genera",
    "generasem": "genera",
    "generaseră": "genera",
    "generaserăm": "genera",
    "generaserăți": "genera",
    "generaseși": "genera",
    "generași": "genera",
    "generat": "genera",
    "generați": "genera",
    "generatu": "genera",
    "generau": "genera",
    "generează": "genera",
    "generez": "genera",
    "genereze": "genera",
    "generezi": "genera",
    "negenerând": "genera",
    "negenerându": "genera",
    "nemaigenerând": "genera",
    "nemaigenerându": "genera",
    "G.": "General",
    "gen.": "general",
    "generala": "general",
    "generală": "general",
    "generale": "general",
    "generalei": "general",
    "generalele": "general",
    "generalelor": "general",
    "generali": "general",
    "generalii": "general",
    "generalilor": "general",
    "generalul": "general",
    "generalului": "general",
    "G-ral": "General",
    "generalitatea": "generalitate",
    "generalități": "generalitate",
    "generalității": "generalitate",
    "generalitățile": "generalitate",
    "generalităților": "generalitate",
    "generaliză": "generaliza",
    "generalizai": "generaliza",
    "generalizam": "generaliza",
    "generalizăm": "generaliza",
    "generalizând": "generaliza",
    "generalizându": "generaliza",
    "generalizară": "generaliza",
    "generalizarăm": "generaliza",
    "generalizarăți": "generaliza",
    "generalizase": "generaliza",
    "generalizasem": "generaliza",
    "generalizaseră": "generaliza",
    "generalizaserăm": "generaliza",
    "generalizaserăți": "generaliza",
    "generalizaseși": "generaliza",
    "generalizași": "generaliza",
    "generalizat": "generaliza",
    "generalizați": "generaliza",
    "generalizatu": "generaliza",
    "generalizau": "generaliza",
    "generalizează": "generaliza",
    "generalizez": "generaliza",
    "generalizeze": "generaliza",
    "generalizezi": "generaliza",
    "negeneralizând": "generaliza",
    "negeneralizându": "generaliza",
    "nemaigeneralizând": "generaliza",
    "nemaigeneralizându": "generaliza",
    "generalizabila": "generalizabil",
    "generalizabilă": "generalizabil",
    "generalizabile": "generalizabil",
    "generalizabilei": "generalizabil",
    "generalizabilele": "generalizabil",
    "generalizabilelor": "generalizabil",
    "generalizabili": "generalizabil",
    "generalizabilii": "generalizabil",
    "generalizabililor": "generalizabil",
    "generalizabilo": "generalizabil",
    "generalizabilul": "generalizabil",
    "generalizabilule": "generalizabil",
    "generalizabilului": "generalizabil",
    "generalizarea": "generalizare",
    "generalizări": "generalizare",
    "generalizării": "generalizare",
    "generalizările": "generalizare",
    "generalizărilor": "generalizare",
    "generalizată": "generalizat",
    "generalizate": "generalizat",
    "generalizați": "generalizat",
    "generalii-maiori": "general-maior",
    "generalilor-maiori": "general-maior",
    "generali-maiori": "general-maior",
    "generalul-maior": "general-maior",
    "generalului-maior": "general-maior",
    "generată": "generat",
    "generate": "generat",
    "generați": "generat",
    "generația": "generație",
    "generației": "generație",
    "generații": "generație",
    "generațiile": "generație",
    "generațiilor": "generație",
    "generatoarea": "generatoare",
    "generatoarei": "generatoare",
    "generatoarele": "generatoare",
    "generatoarelor": "generatoare",
    "generatoare": "generator",
    "generatoarele": "generator",
    "generatoarelor": "generator",
    "generatori": "generator",
    "generatorii": "generator",
    "generatorilor": "generator",
    "generatorul": "generator",
    "generatorului": "generator",
    "generica": "generic",
    "generică": "generic",
    "generice": "generic",
    "genericei": "generic",
    "genericele": "generic",
    "genericelor": "generic",
    "generici": "generic",
    "genericii": "generic",
    "genericilor": "generic",
    "genericul": "generic",
    "genericului": "generic",
    "generoasa": "generos",
    "generoasă": "generos",
    "generoase": "generos",
    "generoasei": "generos",
    "generoasele": "generos",
    "generoaselor": "generos",
    "generoși": "generos",
    "generoșii": "generos",
    "generoșilor": "generos",
    "generosul": "generos",
    "generosului": "generos",
    "generozitatea": "generozitate",
    "generozitateo": "generozitate",
    "generozități": "generozitate",
    "generozității": "generozitate",
    "genetica": "genetic",
    "genetică": "genetic",
    "genetice": "genetic",
    "geneticei": "genetic",
    "geneticele": "genetic",
    "geneticelor": "genetic",
    "genetici": "genetic",
    "geneticii": "genetic",
    "geneticilor": "genetic",
    "genetico": "genetic",
    "geneticul": "genetic",
    "geneticule": "genetic",
    "geneticului": "genetic",
    "genetica": "genetică",
    "genetici": "genetică",
    "geneticii": "genetică",
    "Genevei": "Geneva",
    "geneza": "geneză",
    "geneze": "geneză",
    "genezei": "geneză",
    "genezele": "geneză",
    "genezelor": "geneză",
    "geniala": "genial",
    "genială": "genial",
    "geniale": "genial",
    "genialei": "genial",
    "genialele": "genial",
    "genialelor": "genial",
    "geniali": "genial",
    "genialii": "genial",
    "genialilor": "genial",
    "genialul": "genial",
    "genialului": "genial",
    "genialitatea": "genialitate",
    "genialități": "genialitate",
    "genialității": "genialitate",
    "g.": "genitiv",
    "gen.": "genitiv",
    "genitive": "genitiv",
    "genitivele": "genitiv",
    "genitivelor": "genitiv",
    "genitivul": "genitiv",
    "genitivului": "genitiv",
    "genitivala": "genitival",
    "genitivală": "genitival",
    "genitivale": "genitival",
    "genitivalei": "genitival",
    "genitivalele": "genitival",
    "genitivalelor": "genitival",
    "genitivali": "genitival",
    "genitivalii": "genitival",
    "genitivalilor": "genitival",
    "genitivalul": "genitival",
    "genitivalului": "genitival",
    "genii": "geniu",
    "geniii": "geniu",
    "geniilor": "geniu",
    "geniul": "geniu",
    "geniului": "geniu",
    "genocide": "genocid",
    "genocidele": "genocid",
    "genocidelor": "genocid",
    "genocidul": "genocid",
    "genocidule": "genocid",
    "genocidului": "genocid",
    "gentila": "gentil",
    "gentilă": "gentil",
    "gentile": "gentil",
    "gentilei": "gentil",
    "gentilele": "gentil",
    "gentilelor": "gentil",
    "gentili": "gentil",
    "gentilii": "gentil",
    "gentililor": "gentil",
    "gentilul": "gentil",
    "gentilului": "gentil",
    "gentilețea": "gentilețe",
    "gentileți": "gentilețe",
    "gentileții": "gentilețe",
    "gentilica": "gentilic",
    "gentilică": "gentilic",
    "gentilice": "gentilic",
    "gentilicei": "gentilic",
    "gentilicele": "gentilic",
    "gentilicelor": "gentilic",
    "gentilici": "gentilic",
    "gentilicii": "gentilic",
    "gentilicilor": "gentilic",
    "gentilicul": "gentilic",
    "gentilicului": "gentilic",
    "genunchii": "genunchi",
    "genunchilor": "genunchi",
    "genunchiul": "genunchi",
    "genunchiului": "genunchi",
    "genunea": "genune",
    "genuneo": "genune",
    "genuni": "genune",
    "genunii": "genune",
    "genunile": "genune",
    "genunilor": "genune",
    "geofizica": "geofizică",
    "geofizici": "geofizică",
    "geofizicii": "geofizică",
    "geografi": "geograf",
    "geografii": "geograf",
    "geografilor": "geograf",
    "geograful": "geograf",
    "geografului": "geograf",
    "geografica": "geografic",
    "geografică": "geografic",
    "geografice": "geografic",
    "geograficei": "geografic",
    "geograficele": "geografic",
    "geograficelor": "geografic",
    "geografici": "geografic",
    "geograficii": "geografic",
    "geograficilor": "geografic",
    "geograficul": "geografic",
    "geograficului": "geografic",
    "geogr.": "geografie",
    "geografia": "geografie",
    "geografiei": "geografie",
    "geografii": "geografie",
    "geografiile": "geografie",
    "geografiilor": "geografie",
    "geologi": "geolog",
    "geologii": "geolog",
    "geologilor": "geolog",
    "geologul": "geolog",
    "geologului": "geolog",
    "geologica": "geologic",
    "geologică": "geologic",
    "geologice": "geologic",
    "geologicei": "geologic",
    "geologicele": "geologic",
    "geologicelor": "geologic",
    "geologici": "geologic",
    "geologicii": "geologic",
    "geologicilor": "geologic",
    "geologicul": "geologic",
    "geologicului": "geologic",
    "geol.": "geologie",
    "geologia": "geologie",
    "geologiei": "geologie",
    "geologii": "geologie",
    "geologiile": "geologie",
    "geologiilor": "geologie",
    "geometrica": "geometric",
    "geometrică": "geometric",
    "geometrice": "geometric",
    "geometricei": "geometric",
    "geometricele": "geometric",
    "geometricelor": "geometric",
    "geometrici": "geometric",
    "geometricii": "geometric",
    "geometricilor": "geometric",
    "geometricul": "geometric",
    "geometricului": "geometric",
    "geom.": "geometrie",
    "geometria": "geometrie",
    "geometriei": "geometrie",
    "geometrii": "geometrie",
    "geometriile": "geometrie",
    "geometriilor": "geometrie",
    "geometri": "geometru",
    "geometrii": "geometru",
    "geometrilor": "geometru",
    "geometrul": "geometru",
    "geometrului": "geometru",
    "Georgetei": "Georgeta",
    "georgiana": "georgian",
    "georgiană": "georgian",
    "georgianul": "georgian",
    "georgianului": "georgian",
    "georgiene": "georgian",
    "georgienei": "georgian",
    "georgienele": "georgian",
    "georgienelor": "georgian",
    "georgieni": "georgian",
    "georgienii": "georgian",
    "georgienilor": "georgian",
    "geo-staționară": "geo-staționar",
    "geo-staționare": "geo-staționar",
    "geo-staționari": "geo-staționar",
    "geo-strategică": "geo-strategic",
    "geo-strategice": "geo-strategic",
    "geo-strategici": "geo-strategic",
    "gerul": "ger",
    "gerului": "ger",
    "geruri": "ger",
    "gerurile": "ger",
    "gerurilor": "ger",
    "geriatri": "geriatru",
    "geriatrii": "geriatru",
    "geriatrilor": "geriatru",
    "geriatrul": "geriatru",
    "geriatrule": "geriatru",
    "geriatrului": "geriatru",
    "germana": "german",
    "germană": "german",
    "germane": "german",
    "germanei": "german",
    "germanele": "german",
    "germanelor": "german",
    "germani": "german",
    "germanii": "german",
    "germanilor": "german",
    "germanul": "german",
    "germanului": "german",
    "germ.": "germană",
    "germana": "germană",
    "germane": "germană",
    "germanei": "germană",
    "Germanie": "Germania",
    "Germaniei": "Germania",
    "Germanii": "Germania",
    "Ge": "germaniu",
    "germaniul": "germaniu",
    "germaniului": "germaniu",
    "germaniză": "germaniza",
    "germanizai": "germaniza",
    "germanizam": "germaniza",
    "germanizăm": "germaniza",
    "germanizând": "germaniza",
    "germanizându": "germaniza",
    "germanizară": "germaniza",
    "germanizarăm": "germaniza",
    "germanizarăți": "germaniza",
    "germanizase": "germaniza",
    "germanizasem": "germaniza",
    "germanizaseră": "germaniza",
    "germanizaserăm": "germaniza",
    "germanizaserăți": "germaniza",
    "germanizaseși": "germaniza",
    "germanizași": "germaniza",
    "germanizat": "germaniza",
    "germanizați": "germaniza",
    "germanizatu": "germaniza",
    "germanizau": "germaniza",
    "germanizează": "germaniza",
    "germanizez": "germaniza",
    "germanizeze": "germaniza",
    "germanizezi": "germaniza",
    "negermanizând": "germaniza",
    "negermanizându": "germaniza",
    "nemaigermanizând": "germaniza",
    "nemaigermanizându": "germaniza",
    "germanizată": "germanizat",
    "germanizate": "germanizat",
    "germanizați": "germanizat",
    "germene": "germen",
    "germenele": "germen",
    "germenelor": "germen",
    "germeni": "germen",
    "germenii": "germen",
    "germenilor": "germen",
    "germenul": "germen",
    "germenule": "germen",
    "germenului": "germen",
    "germină": "germina",
    "germinai": "germina",
    "germinam": "germina",
    "germinăm": "germina",
    "germinând": "germina",
    "germinându": "germina",
    "germinară": "germina",
    "germinarăm": "germina",
    "germinarăți": "germina",
    "germinase": "germina",
    "germinasem": "germina",
    "germinaseră": "germina",
    "germinaserăm": "germina",
    "germinaserăți": "germina",
    "germinaseși": "germina",
    "germinași": "germina",
    "germinat": "germina",
    "germinați": "germina",
    "germinatu": "germina",
    "germinau": "germina",
    "germinează": "germina",
    "germinez": "germina",
    "germineze": "germina",
    "germinezi": "germina",
    "negerminând": "germina",
    "negerminându": "germina",
    "nemaigerminând": "germina",
    "nemaigerminându": "germina",
    "germinarea": "germinare",
    "germinări": "germinare",
    "germinării": "germinare",
    "germinările": "germinare",
    "germinărilor": "germinare",
    "germinată": "germinat",
    "germinate": "germinat",
    "germinați": "germinat",
    "germinația": "germinație",
    "germinației": "germinație",
    "germinații": "germinație",
    "germinațiile": "germinație",
    "germinațiilor": "germinație",
    "gerontocrată": "gerontocrat",
    "geroasa": "geros",
    "geroasă": "geros",
    "geroase": "geros",
    "geroasei": "geros",
    "geroasele": "geros",
    "geroaselor": "geros",
    "geroși": "geros",
    "geroșii": "geros",
    "geroșilor": "geros",
    "gerosul": "geros",
    "gerosului": "geros",
    "geruia": "gerui",
    "geruiască": "gerui",
    "geruiau": "gerui",
    "geruiesc": "gerui",
    "geruiește": "gerui",
    "geruind": "gerui",
    "geruindu": "gerui",
    "geruiră": "gerui",
    "geruise": "gerui",
    "geruiseră": "gerui",
    "geruit": "gerui",
    "geruitu": "gerui",
    "negeruind": "gerui",
    "negeruindu": "gerui",
    "nemaigeruind": "gerui",
    "nemaigeruindu": "gerui",
    "geruită": "geruit",
    "geruite": "geruit",
    "geruiți": "geruit",
    "ger.": "gerunziu",
    "gerunzii": "gerunziu",
    "gerunziile": "gerunziu",
    "gerunziilor": "gerunziu",
    "gerunziul": "gerunziu",
    "gerunziului": "gerunziu",
    "gestul": "gest",
    "gestului": "gest",
    "gesturi": "gest",
    "gesturile": "gest",
    "gesturilor": "gest",
    "gestația": "gestație",
    "gestației": "gestație",
    "gestații": "gestație",
    "gestațiile": "gestație",
    "gestațiilor": "gestație",
    "gestațio": "gestație",
    "gestica": "gestică",
    "gestici": "gestică",
    "gesticii": "gestică",
    "gesticulă": "gesticula",
    "gesticulai": "gesticula",
    "gesticulam": "gesticula",
    "gesticulăm": "gesticula",
    "gesticulând": "gesticula",
    "gesticulându": "gesticula",
    "gesticulară": "gesticula",
    "gesticularăm": "gesticula",
    "gesticularăți": "gesticula",
    "gesticulase": "gesticula",
    "gesticulasem": "gesticula",
    "gesticulaseră": "gesticula",
    "gesticulaserăm": "gesticula",
    "gesticulaserăți": "gesticula",
    "gesticulaseși": "gesticula",
    "gesticulași": "gesticula",
    "gesticulat": "gesticula",
    "gesticulați": "gesticula",
    "gesticulatu": "gesticula",
    "gesticulau": "gesticula",
    "gesticulează": "gesticula",
    "gesticulez": "gesticula",
    "gesticuleze": "gesticula",
    "gesticulezi": "gesticula",
    "negesticulând": "gesticula",
    "negesticulându": "gesticula",
    "nemaigesticulând": "gesticula",
    "nemaigesticulându": "gesticula",
    "gesticulată": "gesticulat",
    "gesticulate": "gesticulat",
    "gesticulați": "gesticulat",
    "gestionă": "gestiona",
    "gestionai": "gestiona",
    "gestionam": "gestiona",
    "gestionăm": "gestiona",
    "gestionând": "gestiona",
    "gestionându": "gestiona",
    "gestionară": "gestiona",
    "gestionarăm": "gestiona",
    "gestionarăți": "gestiona",
    "gestionase": "gestiona",
    "gestionasem": "gestiona",
    "gestionaseră": "gestiona",
    "gestionaserăm": "gestiona",
    "gestionaserăți": "gestiona",
    "gestionaseși": "gestiona",
    "gestionași": "gestiona",
    "gestionat": "gestiona",
    "gestionați": "gestiona",
    "gestionatu": "gestiona",
    "gestionau": "gestiona",
    "gestionează": "gestiona",
    "gestionez": "gestiona",
    "gestioneze": "gestiona",
    "gestionezi": "gestiona",
    "gestionari": "gestionar",
    "gestionarii": "gestionar",
    "gestionarilor": "gestionar",
    "gestionarul": "gestionar",
    "gestionarului": "gestionar",
    "gestionarea": "gestionare",
    "gestionări": "gestionare",
    "gestionării": "gestionare",
    "gestionările": "gestionare",
    "gestionărilor": "gestionare",
    "gestionată": "gestionat",
    "gestionate": "gestionat",
    "gestionați": "gestionat",
    "gestiunea": "gestiune",
    "gestiuni": "gestiune",
    "gestiunii": "gestiune",
    "gestiunile": "gestiune",
    "gestiunilor": "gestiune",
    "geți": "get",
    "geții": "get",
    "geților": "get",
    "getul": "get",
    "getului": "get",
    "gheara": "gheară",
    "gheare": "gheară",
    "ghearei": "gheară",
    "ghearele": "gheară",
    "ghearelor": "gheară",
    "gheata": "gheată",
    "ghete": "gheată",
    "ghetei": "gheată",
    "ghetele": "gheată",
    "ghetelor": "gheată",
    "gheața": "gheață",
    "gheațo": "gheață",
    "gheți": "gheață",
    "gheții": "gheață",
    "ghețuri": "gheață",
    "ghețurile": "gheață",
    "ghețurilor": "gheață",
    "ghebul": "gheb",
    "ghebului": "gheb",
    "gheburi": "gheb",
    "gheburile": "gheb",
    "gheburilor": "gheb",
    "gheboasa": "ghebos",
    "gheboasă": "ghebos",
    "gheboase": "ghebos",
    "gheboasei": "ghebos",
    "gheboasele": "ghebos",
    "gheboaselor": "ghebos",
    "gheboși": "ghebos",
    "gheboșii": "ghebos",
    "gheboșilor": "ghebos",
    "ghebosul": "ghebos",
    "ghebosului": "ghebos",
    "gheboșă": "gheboșa",
    "gheboșai": "gheboșa",
    "gheboșam": "gheboșa",
    "gheboșăm": "gheboșa",
    "gheboșând": "gheboșa",
    "gheboșându": "gheboșa",
    "gheboșară": "gheboșa",
    "gheboșarăm": "gheboșa",
    "gheboșarăți": "gheboșa",
    "gheboșase": "gheboșa",
    "gheboșasem": "gheboșa",
    "gheboșaseră": "gheboșa",
    "gheboșaserăm": "gheboșa",
    "gheboșaserăți": "gheboșa",
    "gheboșaseși": "gheboșa",
    "gheboșași": "gheboșa",
    "gheboșat": "gheboșa",
    "gheboșați": "gheboșa",
    "gheboșatu": "gheboșa",
    "gheboșau": "gheboșa",
    "gheboșează": "gheboșa",
    "gheboșez": "gheboșa",
    "gheboșeze": "gheboșa",
    "gheboșezi": "gheboșa",
    "negheboșând": "gheboșa",
    "negheboșându": "gheboșa",
    "nemaigheboșând": "gheboșa",
    "nemaigheboșându": "gheboșa",
    "gheboșată": "gheboșat",
    "gheboșate": "gheboșat",
    "gheboșați": "gheboșat",
    "gheena": "gheenă",
    "gheene": "gheenă",
    "gheenei": "gheenă",
    "gheenele": "gheenă",
    "gheenelor": "gheenă",
    "gheeno": "gheenă",
    "gheișa": "gheișă",
    "gheișe": "gheișă",
    "gheișei": "gheișă",
    "gheișele": "gheișă",
    "gheișelor": "gheișă",
    "gheișo": "gheișă",
    "gheizere": "gheizer",
    "gheizerele": "gheizer",
    "gheizerelor": "gheizer",
    "gheizerul": "gheizer",
    "gheizerului": "gheizer",
    "gheme": "ghem",
    "ghemele": "ghem",
    "ghemelor": "ghem",
    "ghemul": "ghem",
    "ghemului": "ghem",
    "ghemotoace": "ghemotoc",
    "ghemotoacele": "ghemotoc",
    "ghemotoacelor": "ghemotoc",
    "ghemotocul": "ghemotoc",
    "ghemotocului": "ghemotoc",
    "ghemuia": "ghemui",
    "ghemuiai": "ghemui",
    "ghemuiam": "ghemui",
    "ghemuiască": "ghemui",
    "ghemuiați": "ghemui",
    "ghemuiau": "ghemui",
    "ghemuiesc": "ghemui",
    "ghemuiește": "ghemui",
    "ghemuiești": "ghemui",
    "ghemuii": "ghemui",
    "ghemuim": "ghemui",
    "ghemuind": "ghemui",
    "ghemuindu": "ghemui",
    "ghemuiră": "ghemui",
    "ghemuirăm": "ghemui",
    "ghemuirăți": "ghemui",
    "ghemuise": "ghemui",
    "ghemuisem": "ghemui",
    "ghemuiseră": "ghemui",
    "ghemuiserăm": "ghemui",
    "ghemuiserăți": "ghemui",
    "ghemuiseși": "ghemui",
    "ghemuiși": "ghemui",
    "ghemuit": "ghemui",
    "ghemuiți": "ghemui",
    "ghemuitu": "ghemui",
    "neghemuind": "ghemui",
    "neghemuindu": "ghemui",
    "nemaighemuind": "ghemui",
    "nemaighemuindu": "ghemui",
    "ghemuită": "ghemuit",
    "ghemuite": "ghemuit",
    "ghemuiți": "ghemuit",
    "ghena": "ghenă",
    "ghene": "ghenă",
    "ghenei": "ghenă",
    "ghenele": "ghenă",
    "ghenelor": "ghenă",
    "Gh.": "Gheorghe",
    "ghepardul": "ghepard",
    "ghepardului": "ghepard",
    "gheparzi": "ghepard",
    "gheparzii": "ghepard",
    "gheparzilor": "ghepard",
    "ghereta": "gheretă",
    "gherete": "gheretă",
    "gheretei": "gheretă",
    "gheretele": "gheretă",
    "gheretelor": "gheretă",
    "gherla": "gherlă",
    "gherle": "gherlă",
    "gherlei": "gherlă",
    "gherlele": "gherlă",
    "gherlelor": "gherlă",
    "gherlo": "gherlă",
    "ghesul": "ghes",
    "ghesului": "ghes",
    "ghesuri": "ghes",
    "ghesurile": "ghes",
    "ghesurilor": "ghes",
    "ghețari": "ghețar",
    "ghețarii": "ghețar",
    "ghețarilor": "ghețar",
    "ghețarul": "ghețar",
    "ghețarului": "ghețar",
    "ghețușul": "ghețuș",
    "ghețușului": "ghețuș",
    "ghețușuri": "ghețuș",
    "ghețușurile": "ghețuș",
    "ghețușurilor": "ghețuș",
    "ghetuța": "ghetuță",
    "ghetuțe": "ghetuță",
    "ghetuței": "ghetuță",
    "ghetuțele": "ghetuță",
    "ghetuțelor": "ghetuță",
    "ghetuțo": "ghetuță",
    "ghicea": "ghici",
    "ghiceai": "ghici",
    "ghiceam": "ghici",
    "ghicească": "ghici",
    "ghiceați": "ghici",
    "ghiceau": "ghici",
    "ghicesc": "ghici",
    "ghicește": "ghici",
    "ghicești": "ghici",
    "ghicii": "ghici",
    "ghicim": "ghici",
    "ghicind": "ghici",
    "ghicindu": "ghici",
    "ghiciră": "ghici",
    "ghicirăm": "ghici",
    "ghicirăți": "ghici",
    "ghicise": "ghici",
    "ghicisem": "ghici",
    "ghiciseră": "ghici",
    "ghiciserăm": "ghici",
    "ghiciserăți": "ghici",
    "ghiciseși": "ghici",
    "ghiciși": "ghici",
    "ghicit": "ghici",
    "ghiciți": "ghici",
    "ghicitu": "ghici",
    "neghicind": "ghici",
    "neghicindu": "ghici",
    "nemaighicind": "ghici",
    "nemaighicindu": "ghici",
    "ghicită": "ghicit",
    "ghicite": "ghicit",
    "ghiciți": "ghicit",
    "ghicitul": "ghicit",
    "ghicitului": "ghicit",
    "ghicituri": "ghicit",
    "ghiciturile": "ghicit",
    "ghiciturilor": "ghicit",
    "ghicitoarea": "ghicitoare",
    "ghicitoarei": "ghicitoare",
    "ghicitorele": "ghicitoare",
    "ghicitorelor": "ghicitoare",
    "ghicitori": "ghicitoare",
    "ghicitorii": "ghicitoare",
    "ghicitorile": "ghicitoare",
    "ghicitorilor": "ghicitoare",
    "ghidul": "ghid",
    "ghidului": "ghid",
    "ghizi": "ghid",
    "ghizii": "ghid",
    "ghizilor": "ghid",
    "ghidă": "ghida",
    "ghidai": "ghida",
    "ghidam": "ghida",
    "ghidăm": "ghida",
    "ghidând": "ghida",
    "ghidându": "ghida",
    "ghidară": "ghida",
    "ghidarăm": "ghida",
    "ghidarăți": "ghida",
    "ghidase": "ghida",
    "ghidasem": "ghida",
    "ghidaseră": "ghida",
    "ghidaserăm": "ghida",
    "ghidaserăți": "ghida",
    "ghidaseși": "ghida",
    "ghidași": "ghida",
    "ghidat": "ghida",
    "ghidați": "ghida",
    "ghidatu": "ghida",
    "ghidau": "ghida",
    "ghidează": "ghida",
    "ghidez": "ghida",
    "ghideze": "ghida",
    "ghidezi": "ghida",
    "neghidând": "ghida",
    "neghidându": "ghida",
    "nemaighidând": "ghida",
    "nemaighidându": "ghida",
    "ghidată": "ghidat",
    "ghidate": "ghidat",
    "ghidați": "ghidat",
    "ghidoane": "ghidon",
    "ghidoanele": "ghidon",
    "ghidoanelor": "ghidon",
    "ghidonul": "ghidon",
    "ghidonului": "ghidon",
    "ghidușa": "ghiduș",
    "ghidușă": "ghiduș",
    "ghidușe": "ghiduș",
    "ghidușei": "ghiduș",
    "ghidușele": "ghiduș",
    "ghidușelor": "ghiduș",
    "ghiduși": "ghiduș",
    "ghidușii": "ghiduș",
    "ghidușilor": "ghiduș",
    "ghidușul": "ghiduș",
    "ghidușului": "ghiduș",
    "ghidușia": "ghidușie",
    "ghidușiei": "ghidușie",
    "ghidușii": "ghidușie",
    "ghidușiile": "ghidușie",
    "ghidușiilor": "ghidușie",
    "ghiftuia": "ghiftui",
    "ghiftuiai": "ghiftui",
    "ghiftuiam": "ghiftui",
    "ghiftuiască": "ghiftui",
    "ghiftuiați": "ghiftui",
    "ghiftuiau": "ghiftui",
    "ghiftuiesc": "ghiftui",
    "ghiftuiește": "ghiftui",
    "ghiftuiești": "ghiftui",
    "ghiftuii": "ghiftui",
    "ghiftuim": "ghiftui",
    "ghiftuind": "ghiftui",
    "ghiftuindu": "ghiftui",
    "ghiftuiră": "ghiftui",
    "ghiftuirăm": "ghiftui",
    "ghiftuirăți": "ghiftui",
    "ghiftuise": "ghiftui",
    "ghiftuisem": "ghiftui",
    "ghiftuiseră": "ghiftui",
    "ghiftuiserăm": "ghiftui",
    "ghiftuiserăți": "ghiftui",
    "ghiftuiseși": "ghiftui",
    "ghiftuiși": "ghiftui",
    "ghiftuit": "ghiftui",
    "ghiftuiți": "ghiftui",
    "ghiftuitu": "ghiftui",
    "neghiftuind": "ghiftui",
    "neghiftuindu": "ghiftui",
    "nemaighiftuind": "ghiftui",
    "nemaighiftuindu": "ghiftui",
    "ghiftuiala": "ghiftuială",
    "ghiftuieli": "ghiftuială",
    "ghiftuielii": "ghiftuială",
    "ghiftuită": "ghiftuit",
    "ghiftuite": "ghiftuit",
    "ghiftuiți": "ghiftuit",
    "ghigosea": "ghigosi",
    "ghigoseai": "ghigosi",
    "ghigoseam": "ghigosi",
    "ghigosească": "ghigosi",
    "ghigoseați": "ghigosi",
    "ghigoseau": "ghigosi",
    "ghigosesc": "ghigosi",
    "ghigosește": "ghigosi",
    "ghigosești": "ghigosi",
    "ghigosii": "ghigosi",
    "ghigosim": "ghigosi",
    "ghigosind": "ghigosi",
    "ghigosindu": "ghigosi",
    "ghigosiră": "ghigosi",
    "ghigosirăm": "ghigosi",
    "ghigosirăți": "ghigosi",
    "ghigosise": "ghigosi",
    "ghigosisem": "ghigosi",
    "ghigosiseră": "ghigosi",
    "ghigosiserăm": "ghigosi",
    "ghigosiserăți": "ghigosi",
    "ghigosiseși": "ghigosi",
    "ghigosiși": "ghigosi",
    "ghigosit": "ghigosi",
    "ghigosiți": "ghigosi",
    "ghigositu": "ghigosi",
    "neghigosind": "ghigosi",
    "neghigosindu": "ghigosi",
    "nemaighigosind": "ghigosi",
    "nemaighigosindu": "ghigosi",
    "ghigosită": "ghigosit",
    "ghigosite": "ghigosit",
    "ghigosiți": "ghigosit",
    "ghilea": "ghili",
    "ghileai": "ghili",
    "ghileam": "ghili",
    "ghilească": "ghili",
    "ghileați": "ghili",
    "ghileau": "ghili",
    "ghilesc": "ghili",
    "ghilește": "ghili",
    "ghilești": "ghili",
    "ghilii": "ghili",
    "ghilim": "ghili",
    "ghilind": "ghili",
    "ghilindu": "ghili",
    "ghiliră": "ghili",
    "ghilirăm": "ghili",
    "ghilirăți": "ghili",
    "ghilise": "ghili",
    "ghilisem": "ghili",
    "ghiliseră": "ghili",
    "ghiliserăm": "ghili",
    "ghiliserăți": "ghili",
    "ghiliseși": "ghili",
    "ghiliși": "ghili",
    "ghilit": "ghili",
    "ghiliți": "ghili",
    "ghilitu": "ghili",
    "neghilind": "ghili",
    "neghilindu": "ghili",
    "nemaighilind": "ghili",
    "nemaighilindu": "ghili",
    "ghilimelele": "ghilimele",
    "ghilimelelor": "ghilimele",
    "ghilită": "ghilit",
    "ghilite": "ghilit",
    "ghiliți": "ghilit",
    "ghilosea": "ghilosi",
    "ghiloseai": "ghilosi",
    "ghiloseam": "ghilosi",
    "ghilosească": "ghilosi",
    "ghiloseați": "ghilosi",
    "ghiloseau": "ghilosi",
    "ghilosesc": "ghilosi",
    "ghilosește": "ghilosi",
    "ghilosești": "ghilosi",
    "ghilosii": "ghilosi",
    "ghilosim": "ghilosi",
    "ghilosind": "ghilosi",
    "ghilosindu": "ghilosi",
    "ghilosiră": "ghilosi",
    "ghilosirăm": "ghilosi",
    "ghilosirăți": "ghilosi",
    "ghilosise": "ghilosi",
    "ghilosisem": "ghilosi",
    "ghilosiseră": "ghilosi",
    "ghilosiserăm": "ghilosi",
    "ghilosiserăți": "ghilosi",
    "ghilosiseși": "ghilosi",
    "ghilosiși": "ghilosi",
    "ghilosit": "ghilosi",
    "ghilosiți": "ghilosi",
    "ghilositu": "ghilosi",
    "neghilosind": "ghilosi",
    "neghilosindu": "ghilosi",
    "nemaighilosind": "ghilosi",
    "nemaighilosindu": "ghilosi",
    "ghilosită": "ghilosit",
    "ghilosite": "ghilosit",
    "ghilosiți": "ghilosit",
    "ghilotină": "ghilotina",
    "ghilotinai": "ghilotina",
    "ghilotinam": "ghilotina",
    "ghilotinăm": "ghilotina",
    "ghilotinând": "ghilotina",
    "ghilotinându": "ghilotina",
    "ghilotinară": "ghilotina",
    "ghilotinarăm": "ghilotina",
    "ghilotinarăți": "ghilotina",
    "ghilotinase": "ghilotina",
    "ghilotinasem": "ghilotina",
    "ghilotinaseră": "ghilotina",
    "ghilotinaserăm": "ghilotina",
    "ghilotinaserăți": "ghilotina",
    "ghilotinaseși": "ghilotina",
    "ghilotinași": "ghilotina",
    "ghilotinat": "ghilotina",
    "ghilotinați": "ghilotina",
    "ghilotinatu": "ghilotina",
    "ghilotinau": "ghilotina",
    "ghilotinează": "ghilotina",
    "ghilotinez": "ghilotina",
    "ghilotineze": "ghilotina",
    "ghilotinezi": "ghilotina",
    "neghilotinând": "ghilotina",
    "neghilotinându": "ghilotina",
    "nemaighilotinând": "ghilotina",
    "nemaighilotinându": "ghilotina",
    "ghilotina": "ghilotină",
    "ghilotine": "ghilotină",
    "ghilotinei": "ghilotină",
    "ghilotinele": "ghilotină",
    "ghilotinelor": "ghilotină",
    "ghilotinată": "ghilotinat",
    "ghilotinate": "ghilotinat",
    "ghilotinați": "ghilotinat",
    "ghimpata": "ghimpat",
    "ghimpată": "ghimpat",
    "ghimpate": "ghimpat",
    "ghimpatei": "ghimpat",
    "ghimpatele": "ghimpat",
    "ghimpatelor": "ghimpat",
    "ghimpați": "ghimpat",
    "ghimpații": "ghimpat",
    "ghimpaților": "ghimpat",
    "ghimpatul": "ghimpat",
    "ghimpatului": "ghimpat",
    "ghimpele": "ghimpe",
    "ghimpelui": "ghimpe",
    "ghimpi": "ghimpe",
    "ghimpii": "ghimpe",
    "ghimpilor": "ghimpe",
    "ghinda": "ghindă",
    "ghinde": "ghindă",
    "ghindei": "ghindă",
    "ghindele": "ghindă",
    "ghindelor": "ghindă",
    "ghinioane": "ghinion",
    "ghinioanele": "ghinion",
    "ghinioanelor": "ghinion",
    "ghinionul": "ghinion",
    "ghinionului": "ghinion",
    "ghinioniști": "ghinionist",
    "ghinioniștii": "ghinionist",
    "ghinioniștilor": "ghinionist",
    "ghinionistul": "ghinionist",
    "ghinionistului": "ghinionist",
    "ghintul": "ghint",
    "ghintule": "ghint",
    "ghintului": "ghint",
    "ghinturi": "ghint",
    "ghinturile": "ghint",
    "ghinturilor": "ghint",
    "giuvaer": "ghint",
    "giuvaere": "ghint",
    "giuvaerele": "ghint",
    "giuvaerelor": "ghint",
    "giuvaerul": "ghint",
    "giuvaerule": "ghint",
    "giuvaerului": "ghint",
    "ghintuia": "ghintui",
    "ghintuiai": "ghintui",
    "ghintuiam": "ghintui",
    "ghintuiască": "ghintui",
    "ghintuiați": "ghintui",
    "ghintuiau": "ghintui",
    "ghintuiesc": "ghintui",
    "ghintuiește": "ghintui",
    "ghintuiești": "ghintui",
    "ghintuii": "ghintui",
    "ghintuim": "ghintui",
    "ghintuind": "ghintui",
    "ghintuindu": "ghintui",
    "ghintuiră": "ghintui",
    "ghintuirăm": "ghintui",
    "ghintuirăți": "ghintui",
    "ghintuise": "ghintui",
    "ghintuisem": "ghintui",
    "ghintuiseră": "ghintui",
    "ghintuiserăm": "ghintui",
    "ghintuiserăți": "ghintui",
    "ghintuiseși": "ghintui",
    "ghintuiși": "ghintui",
    "ghintuit": "ghintui",
    "ghintuiți": "ghintui",
    "ghintuitu": "ghintui",
    "neghintuind": "ghintui",
    "neghintuindu": "ghintui",
    "nemaighintuind": "ghintui",
    "nemaighintuindu": "ghintui",
    "ghintuită": "ghintuit",
    "ghintuite": "ghintuit",
    "ghintuiți": "ghintuit",
    "ghioaga": "ghioagă",
    "ghioage": "ghioagă",
    "ghioagei": "ghioagă",
    "ghioagele": "ghioagă",
    "ghioagelor": "ghioagă",
    "ghiocei": "ghiocel",
    "ghioceii": "ghiocel",
    "ghioceilor": "ghiocel",
    "ghiocelul": "ghiocel",
    "ghiocelului": "ghiocel",
    "ghiontul": "ghiont",
    "ghiontului": "ghiont",
    "ghionturi": "ghiont",
    "ghionturile": "ghiont",
    "ghionturilor": "ghiont",
    "ghiontea": "ghionti",
    "ghionteai": "ghionti",
    "ghionteam": "ghionti",
    "ghiontească": "ghionti",
    "ghionteați": "ghionti",
    "ghionteau": "ghionti",
    "ghiontesc": "ghionti",
    "ghiontește": "ghionti",
    "ghiontești": "ghionti",
    "ghiontii": "ghionti",
    "ghiontim": "ghionti",
    "ghiontind": "ghionti",
    "ghiontindu": "ghionti",
    "ghiontiră": "ghionti",
    "ghiontirăm": "ghionti",
    "ghiontirăți": "ghionti",
    "ghiontise": "ghionti",
    "ghiontisem": "ghionti",
    "ghiontiseră": "ghionti",
    "ghiontiserăm": "ghionti",
    "ghiontiserăți": "ghionti",
    "ghiontiseși": "ghionti",
    "ghiontiși": "ghionti",
    "ghiontit": "ghionti",
    "ghiontiți": "ghionti",
    "ghiontitu": "ghionti",
    "neghiontind": "ghionti",
    "neghiontindu": "ghionti",
    "nemaighiontind": "ghionti",
    "nemaighiontindu": "ghionti",
    "ghiontită": "ghiontit",
    "ghiontite": "ghiontit",
    "ghiontiți": "ghiontit",
    "ghiorțăia": "ghiorțăi",
    "ghiorțăiai": "ghiorțăi",
    "ghiorțăiam": "ghiorțăi",
    "ghiorțăiați": "ghiorțăi",
    "ghiorțăiau": "ghiorțăi",
    "ghiorțăie": "ghiorțăi",
    "ghiorțăii": "ghiorțăi",
    "ghiorțăim": "ghiorțăi",
    "ghiorțăind": "ghiorțăi",
    "ghiorțăindu": "ghiorțăi",
    "ghiorțăiră": "ghiorțăi",
    "ghiorțăirăm": "ghiorțăi",
    "ghiorțăirăți": "ghiorțăi",
    "ghiorțăise": "ghiorțăi",
    "ghiorțăisem": "ghiorțăi",
    "ghiorțăiseră": "ghiorțăi",
    "ghiorțăiserăm": "ghiorțăi",
    "ghiorțăiserăți": "ghiorțăi",
    "ghiorțăiseși": "ghiorțăi",
    "ghiorțăiși": "ghiorțăi",
    "ghiorțăit": "ghiorțăi",
    "ghiorțăiți": "ghiorțăi",
    "ghiorțăitu": "ghiorțăi",
    "neghiorțăind": "ghiorțăi",
    "neghiorțăindu": "ghiorțăi",
    "nemaighiorțăind": "ghiorțăi",
    "nemaighiorțăindu": "ghiorțăi",
    "ghiorțăită": "ghiorțăit",
    "ghiorțăite": "ghiorțăit",
    "ghiorțăiți": "ghiorțăit",
    "ghioșă": "ghioșa",
    "ghioșai": "ghioșa",
    "ghioșam": "ghioșa",
    "ghioșăm": "ghioșa",
    "ghioșând": "ghioșa",
    "ghioșându": "ghioșa",
    "ghioșară": "ghioșa",
    "ghioșarăm": "ghioșa",
    "ghioșarăți": "ghioșa",
    "ghioșase": "ghioșa",
    "ghioșasem": "ghioșa",
    "ghioșaseră": "ghioșa",
    "ghioșaserăm": "ghioșa",
    "ghioșaserăți": "ghioșa",
    "ghioșaseși": "ghioșa",
    "ghioșași": "ghioșa",
    "ghioșat": "ghioșa",
    "ghioșați": "ghioșa",
    "ghioșatu": "ghioșa",
    "ghioșau": "ghioșa",
    "ghioșează": "ghioșa",
    "ghioșez": "ghioșa",
    "ghioșeze": "ghioșa",
    "ghioșezi": "ghioșa",
    "neghioșând": "ghioșa",
    "neghioșându": "ghioșa",
    "nemaighioșând": "ghioșa",
    "nemaighioșându": "ghioșa",
    "ghioșată": "ghioșat",
    "ghioșate": "ghioșat",
    "ghioșați": "ghioșat",
    "ghiozdane": "ghiozdan",
    "ghiozdanele": "ghiozdan",
    "ghiozdanelor": "ghiozdan",
    "ghiozdanul": "ghiozdan",
    "ghiozdanului": "ghiozdan",
    "ghipsul": "ghips",
    "ghipsului": "ghips",
    "ghipsuri": "ghips",
    "ghipsurile": "ghips",
    "ghipsurilor": "ghips",
    "ghirlanda": "ghirlandă",
    "ghirlande": "ghirlandă",
    "ghirlandei": "ghirlandă",
    "ghirlandele": "ghirlandă",
    "ghirlandelor": "ghirlandă",
    "ghișee": "ghișeu",
    "ghișeele": "ghișeu",
    "ghișeelor": "ghișeu",
    "ghișeul": "ghișeu",
    "ghișeului": "ghișeu",
    "ghiuleaua": "ghiulea",
    "ghiulele": "ghiulea",
    "ghiulelei": "ghiulea",
    "ghiulelele": "ghiulea",
    "ghiulelelor": "ghiulea",
    "ghivece": "ghiveci",
    "ghivecele": "ghiveci",
    "ghivecelor": "ghiveci",
    "ghiveciul": "ghiveci",
    "ghiveciului": "ghiveci",
    "ghiventul": "ghivent",
    "ghiventului": "ghivent",
    "ghiventuri": "ghivent",
    "ghiventurile": "ghivent",
    "ghiventurilor": "ghivent",
    "ghizduia": "ghizdui",
    "ghizduiai": "ghizdui",
    "ghizduiam": "ghizdui",
    "ghizduiască": "ghizdui",
    "ghizduiați": "ghizdui",
    "ghizduiau": "ghizdui",
    "ghizduiesc": "ghizdui",
    "ghizduiește": "ghizdui",
    "ghizduiești": "ghizdui",
    "ghizduii": "ghizdui",
    "ghizduim": "ghizdui",
    "ghizduind": "ghizdui",
    "ghizduindu": "ghizdui",
    "ghizduiră": "ghizdui",
    "ghizduirăm": "ghizdui",
    "ghizduirăți": "ghizdui",
    "ghizduise": "ghizdui",
    "ghizduisem": "ghizdui",
    "ghizduiseră": "ghizdui",
    "ghizduiserăm": "ghizdui",
    "ghizduiserăți": "ghizdui",
    "ghizduiseși": "ghizdui",
    "ghizduiși": "ghizdui",
    "ghizduit": "ghizdui",
    "ghizduiți": "ghizdui",
    "ghizduitu": "ghizdui",
    "neghizduind": "ghizdui",
    "neghizduindu": "ghizdui",
    "nemaighizduind": "ghizdui",
    "nemaighizduindu": "ghizdui",
    "ghizduită": "ghizduit",
    "ghizduite": "ghizduit",
    "ghizduiți": "ghizduit",
    "giganți": "gigant",
    "giganții": "gigant",
    "giganților": "gigant",
    "gigantul": "gigant",
    "gigantului": "gigant",
    "gigantica": "gigantic",
    "gigantică": "gigantic",
    "gigantice": "gigantic",
    "giganticei": "gigantic",
    "giganticele": "gigantic",
    "giganticelor": "gigantic",
    "gigantici": "gigantic",
    "giganticii": "gigantic",
    "giganticilor": "gigantic",
    "giganticul": "gigantic",
    "giganticului": "gigantic",
    "gigantomahia": "gigantomahie",
    "gigantomahiei": "gigantomahie",
    "gigantomahii": "gigantomahie",
    "gigantomahiile": "gigantomahie",
    "gigantomahiilor": "gigantomahie",
    "gimnaști": "gimnast",
    "gimnaștii": "gimnast",
    "gimnaștilor": "gimnast",
    "gimnastul": "gimnast",
    "gimnastului": "gimnast",
    "gimnasta": "gimnastă",
    "gimnaste": "gimnastă",
    "gimnastei": "gimnastă",
    "gimnastele": "gimnastă",
    "gimnastelor": "gimnastă",
    "gimnastica": "gimnastic",
    "gimnastică": "gimnastic",
    "gimnastice": "gimnastic",
    "gimnasticei": "gimnastic",
    "gimnasticele": "gimnastic",
    "gimnasticelor": "gimnastic",
    "gimnastici": "gimnastic",
    "gimnasticii": "gimnastic",
    "gimnasticilor": "gimnastic",
    "gimnasticul": "gimnastic",
    "gimnasticului": "gimnastic",
    "gimnastica": "gimnastică",
    "gimnastici": "gimnastică",
    "gimnasticii": "gimnastică",
    "gimnasticile": "gimnastică",
    "gimnasticilor": "gimnastică",
    "gimnazii": "gimnaziu",
    "gimnaziile": "gimnaziu",
    "gimnaziilor": "gimnaziu",
    "gimnaziul": "gimnaziu",
    "gimnaziului": "gimnaziu",
    "ginul": "gin",
    "ginului": "gin",
    "ginuri": "gin",
    "ginurile": "gin",
    "ginurilor": "gin",
    "ginecologia": "ginecologie",
    "ginecologiei": "ginecologie",
    "ginecologii": "ginecologie",
    "ginecologiile": "ginecologie",
    "ginecologiilor": "ginecologie",
    "ginecologio": "ginecologie",
    "ginerele": "ginere",
    "ginerelui": "ginere",
    "gineri": "ginere",
    "ginerii": "ginere",
    "ginerilor": "ginere",
    "ginerea": "gineri",
    "ginereai": "gineri",
    "gineream": "gineri",
    "ginerească": "gineri",
    "ginereați": "gineri",
    "ginereau": "gineri",
    "gineresc": "gineri",
    "ginerește": "gineri",
    "ginerești": "gineri",
    "ginerii": "gineri",
    "ginerim": "gineri",
    "ginerind": "gineri",
    "ginerindu": "gineri",
    "gineriră": "gineri",
    "ginerirăm": "gineri",
    "ginerirăți": "gineri",
    "ginerise": "gineri",
    "ginerisem": "gineri",
    "gineriseră": "gineri",
    "gineriserăm": "gineri",
    "gineriserăți": "gineri",
    "gineriseși": "gineri",
    "gineriși": "gineri",
    "ginerit": "gineri",
    "gineriți": "gineri",
    "gineritu": "gineri",
    "neginerind": "gineri",
    "neginerindu": "gineri",
    "nemaiginerind": "gineri",
    "nemaiginerindu": "gineri",
    "ginerită": "ginerit",
    "ginerite": "ginerit",
    "gineriți": "ginerit",
    "gingașa": "gingaș",
    "gingașă": "gingaș",
    "gingașe": "gingaș",
    "gingașei": "gingaș",
    "gingașele": "gingaș",
    "gingașelor": "gingaș",
    "gingași": "gingaș",
    "gingașii": "gingaș",
    "gingașilor": "gingaș",
    "gingașul": "gingaș",
    "gingașului": "gingaș",
    "gingășia": "gingășie",
    "gingășiei": "gingășie",
    "gingășii": "gingășie",
    "gingășiile": "gingășie",
    "gingășiilor": "gingășie",
    "gingia": "gingie",
    "gingiei": "gingie",
    "gingii": "gingie",
    "gingiile": "gingie",
    "gingiilor": "gingie",
    "ginea": "gini",
    "gineai": "gini",
    "gineam": "gini",
    "ginească": "gini",
    "gineați": "gini",
    "gineau": "gini",
    "ginesc": "gini",
    "ginește": "gini",
    "ginești": "gini",
    "ginii": "gini",
    "ginim": "gini",
    "ginind": "gini",
    "ginindu": "gini",
    "giniră": "gini",
    "ginirăm": "gini",
    "ginirăți": "gini",
    "ginise": "gini",
    "ginisem": "gini",
    "giniseră": "gini",
    "giniserăm": "gini",
    "giniserăți": "gini",
    "giniseși": "gini",
    "giniși": "gini",
    "ginit": "gini",
    "giniți": "gini",
    "ginitu": "gini",
    "neginind": "gini",
    "neginindu": "gini",
    "nemaiginind": "gini",
    "nemaiginindu": "gini",
    "ginită": "ginit",
    "ginite": "ginit",
    "giniți": "ginit",
    "gipsul": "gips",
    "gipsului": "gips",
    "gipsuri": "gips",
    "gipsurile": "gips",
    "gipsurilor": "gips",
    "girul": "gir",
    "girului": "gir",
    "giruri": "gir",
    "girurile": "gir",
    "girurilor": "gir",
    "giră": "gira",
    "girai": "gira",
    "giram": "gira",
    "girăm": "gira",
    "girând": "gira",
    "girându": "gira",
    "girară": "gira",
    "girarăm": "gira",
    "girarăți": "gira",
    "girase": "gira",
    "girasem": "gira",
    "giraseră": "gira",
    "giraserăm": "gira",
    "giraserăți": "gira",
    "giraseși": "gira",
    "girași": "gira",
    "girat": "gira",
    "girați": "gira",
    "giratu": "gira",
    "girau": "gira",
    "girează": "gira",
    "girez": "gira",
    "gireze": "gira",
    "girezi": "gira",
    "negirând": "gira",
    "negirându": "gira",
    "nemaigirând": "gira",
    "nemaigirându": "gira",
    "girafa": "girafă",
    "girafe": "girafă",
    "girafei": "girafă",
    "girafele": "girafă",
    "girafelor": "girafă",
    "girată": "girat",
    "girate": "girat",
    "girați": "girat",
    "girofarul": "girofar",
    "girofarului": "girofar",
    "girofaruri": "girofar",
    "girofarurile": "girofar",
    "girofarurilor": "girofar",
    "giroscoape": "giroscop",
    "giroscoapele": "giroscop",
    "giroscoapelor": "giroscop",
    "giroscopul": "giroscop",
    "giroscopului": "giroscop",
    "giugiulea": "giugiuli",
    "giugiuleai": "giugiuli",
    "giugiuleam": "giugiuli",
    "giugiulească": "giugiuli",
    "giugiuleați": "giugiuli",
    "giugiuleau": "giugiuli",
    "giugiulesc": "giugiuli",
    "giugiulește": "giugiuli",
    "giugiulești": "giugiuli",
    "giugiulii": "giugiuli",
    "giugiulim": "giugiuli",
    "giugiulind": "giugiuli",
    "giugiulindu": "giugiuli",
    "giugiuliră": "giugiuli",
    "giugiulirăm": "giugiuli",
    "giugiulirăți": "giugiuli",
    "giugiulise": "giugiuli",
    "giugiulisem": "giugiuli",
    "giugiuliseră": "giugiuli",
    "giugiuliserăm": "giugiuli",
    "giugiuliserăți": "giugiuli",
    "giugiuliseși": "giugiuli",
    "giugiuliși": "giugiuli",
    "giugiulit": "giugiuli",
    "giugiuliți": "giugiuli",
    "giugiulitu": "giugiuli",
    "negiugiulind": "giugiuli",
    "negiugiulindu": "giugiuli",
    "nemaigiugiulind": "giugiuli",
    "nemaigiugiulindu": "giugiuli",
    "giugiulită": "giugiulit",
    "giugiulite": "giugiulit",
    "giugiuliți": "giugiulit",
    "giulgiul": "giulgiu",
    "giulgiului": "giulgiu",
    "giulgiuri": "giulgiu",
    "giulgiurile": "giulgiu",
    "giulgiurilor": "giulgiu",
    "giumbușlucul": "giumbușluc",
    "giumbușlucului": "giumbușluc",
    "giumbușlucuri": "giumbușluc",
    "giumbușlucurile": "giumbușluc",
    "giumbușlucurilor": "giumbușluc",
    "giuvaergii": "giuvaergiu",
    "giuvaergiii": "giuvaergiu",
    "giuvaergiilor": "giuvaergiu",
    "giuvaergiul": "giuvaergiu",
    "giuvaergiule": "giuvaergiu",
    "giuvaergiului": "giuvaergiu",
    "giuvaiere": "giuvaier",
    "giuvaierele": "giuvaier",
    "giuvaierelor": "giuvaier",
    "giuvaierul": "giuvaier",
    "giuvaierule": "giuvaier",
    "giuvaierului": "giuvaier",
    "giuvaiergii": "giuvaiergiu",
    "giuvaiergiii": "giuvaiergiu",
    "giuvaiergiilor": "giuvaiergiu",
    "giuvaiergiul": "giuvaiergiu",
    "giuvaiergiului": "giuvaiergiu",
    "giuvaiericalele": "giuvaiericale",
    "giuvaiericalelor": "giuvaiericale",
    "glaciala": "glacial",
    "glacială": "glacial",
    "glaciale": "glacial",
    "glacialei": "glacial",
    "glacialele": "glacial",
    "glacialelor": "glacial",
    "glaciali": "glacial",
    "glacialii": "glacial",
    "glacialilor": "glacial",
    "glacialul": "glacial",
    "glacialului": "glacial",
    "glacialitatea": "glacialitate",
    "glacialitateo": "glacialitate",
    "glaciara": "glaciar",
    "glaciară": "glaciar",
    "glaciare": "glaciar",
    "glaciarei": "glaciar",
    "glaciarele": "glaciar",
    "glaciarelor": "glaciar",
    "glaciari": "glaciar",
    "glaciarii": "glaciar",
    "glaciarilor": "glaciar",
    "glaciarul": "glaciar",
    "glaciarului": "glaciar",
    "gladiatori": "gladiator",
    "gladiatorii": "gladiator",
    "gladiatorilor": "gladiator",
    "gladiatorul": "gladiator",
    "gladiatorului": "gladiator",
    "gladiola": "gladiolă",
    "gladiole": "gladiolă",
    "gladiolei": "gladiolă",
    "gladiolele": "gladiolă",
    "gladiolelor": "gladiolă",
    "glanda": "glandă",
    "glande": "glandă",
    "glandei": "glandă",
    "glandele": "glandă",
    "glandelor": "glandă",
    "glasul": "glas",
    "glasului": "glas",
    "glasuri": "glas",
    "glasurile": "glas",
    "glasurilor": "glas",
    "glasă": "glasa",
    "glasai": "glasa",
    "glasam": "glasa",
    "glasăm": "glasa",
    "glasând": "glasa",
    "glasându": "glasa",
    "glasară": "glasa",
    "glasarăm": "glasa",
    "glasarăți": "glasa",
    "glasase": "glasa",
    "glasasem": "glasa",
    "glasaseră": "glasa",
    "glasaserăm": "glasa",
    "glasaserăți": "glasa",
    "glasaseși": "glasa",
    "glasași": "glasa",
    "glasat": "glasa",
    "glasați": "glasa",
    "glasatu": "glasa",
    "glasau": "glasa",
    "glasează": "glasa",
    "glasez": "glasa",
    "glaseze": "glasa",
    "glasezi": "glasa",
    "neglasând": "glasa",
    "neglasându": "glasa",
    "nemaiglasând": "glasa",
    "nemaiglasându": "glasa",
    "glasată": "glasat",
    "glasate": "glasat",
    "glasați": "glasat",
    "glaspapirul": "glaspapir",
    "glaspapirului": "glaspapir",
    "glastra": "glastră",
    "glastre": "glastră",
    "glastrei": "glastră",
    "glastrele": "glastră",
    "glastrelor": "glastră",
    "glăsuia": "glăsui",
    "glăsuiai": "glăsui",
    "glăsuiam": "glăsui",
    "glăsuiască": "glăsui",
    "glăsuiați": "glăsui",
    "glăsuiau": "glăsui",
    "glăsuiesc": "glăsui",
    "glăsuiește": "glăsui",
    "glăsuiești": "glăsui",
    "glăsuii": "glăsui",
    "glăsuim": "glăsui",
    "glăsuind": "glăsui",
    "glăsuindu": "glăsui",
    "glăsuiră": "glăsui",
    "glăsuirăm": "glăsui",
    "glăsuirăți": "glăsui",
    "glăsuise": "glăsui",
    "glăsuisem": "glăsui",
    "glăsuiseră": "glăsui",
    "glăsuiserăm": "glăsui",
    "glăsuiserăți": "glăsui",
    "glăsuiseși": "glăsui",
    "glăsuiși": "glăsui",
    "glăsuit": "glăsui",
    "glăsuiți": "glăsui",
    "glăsuitu": "glăsui",
    "neglăsuind": "glăsui",
    "neglăsuindu": "glăsui",
    "nemaiglăsuind": "glăsui",
    "nemaiglăsuindu": "glăsui",
    "glăsuirea": "glăsuire",
    "glăsuireo": "glăsuire",
    "glăsuiri": "glăsuire",
    "glăsuirii": "glăsuire",
    "glăsuirile": "glăsuire",
    "glăsuirilor": "glăsuire",
    "glăsuită": "glăsuit",
    "glăsuite": "glăsuit",
    "glăsuiți": "glăsuit",
    "glasvandul": "glasvand",
    "glasvandului": "glasvand",
    "glasvanduri": "glasvand",
    "glasvandurile": "glasvand",
    "glasvandurilor": "glasvand",
    "glazură": "glazura",
    "glazurai": "glazura",
    "glazuram": "glazura",
    "glazurăm": "glazura",
    "glazurând": "glazura",
    "glazurându": "glazura",
    "glazurară": "glazura",
    "glazurarăm": "glazura",
    "glazurarăți": "glazura",
    "glazurase": "glazura",
    "glazurasem": "glazura",
    "glazuraseră": "glazura",
    "glazuraserăm": "glazura",
    "glazuraserăți": "glazura",
    "glazuraseși": "glazura",
    "glazurași": "glazura",
    "glazurat": "glazura",
    "glazurați": "glazura",
    "glazuratu": "glazura",
    "glazurau": "glazura",
    "glazurează": "glazura",
    "glazurez": "glazura",
    "glazureze": "glazura",
    "glazurezi": "glazura",
    "neglazurând": "glazura",
    "neglazurându": "glazura",
    "nemaiglazurând": "glazura",
    "nemaiglazurându": "glazura",
    "glazura": "glazură",
    "glazuri": "glazură",
    "glazurii": "glazură",
    "glazurile": "glazură",
    "glazurilor": "glazură",
    "glazurată": "glazurat",
    "glazurate": "glazurat",
    "glazurați": "glazurat",
    "glezna": "gleznă",
    "glezne": "gleznă",
    "gleznei": "gleznă",
    "gleznele": "gleznă",
    "gleznelor": "gleznă",
    "glicemii": "glicemie",
    "glicerina": "glicerină",
    "glicerine": "glicerină",
    "glicerinei": "glicerină",
    "glia": "glie",
    "gliei": "glie",
    "glii": "glie",
    "gliile": "glie",
    "gliilor": "glie",
    "glisă": "glisa",
    "glisai": "glisa",
    "glisam": "glisa",
    "glisăm": "glisa",
    "glisând": "glisa",
    "glisându": "glisa",
    "glisară": "glisa",
    "glisarăm": "glisa",
    "glisarăți": "glisa",
    "glisase": "glisa",
    "glisasem": "glisa",
    "glisaseră": "glisa",
    "glisaserăm": "glisa",
    "glisaserăți": "glisa",
    "glisaseși": "glisa",
    "glisași": "glisa",
    "glisat": "glisa",
    "glisați": "glisa",
    "glisatu": "glisa",
    "glisau": "glisa",
    "glisează": "glisa",
    "glisez": "glisa",
    "gliseze": "glisa",
    "glisezi": "glisa",
    "neglisând": "glisa",
    "neglisându": "glisa",
    "nemaiglisând": "glisa",
    "nemaiglisându": "glisa",
    "glisanta": "glisant",
    "glisantă": "glisant",
    "glisante": "glisant",
    "glisantei": "glisant",
    "glisantele": "glisant",
    "glisantelor": "glisant",
    "glisanți": "glisant",
    "glisanții": "glisant",
    "glisanților": "glisant",
    "glisantul": "glisant",
    "glisantului": "glisant",
    "glisată": "glisat",
    "glisate": "glisat",
    "glisați": "glisat",
    "gloata": "gloată",
    "gloate": "gloată",
    "gloatei": "gloată",
    "gloatele": "gloată",
    "gloatelor": "gloată",
    "globi": "glob",
    "globii": "glob",
    "globilor": "glob",
    "globul": "glob",
    "globului": "glob",
    "globuri": "glob",
    "globurile": "glob",
    "globurilor": "glob",
    "globala": "global",
    "globală": "global",
    "globale": "global",
    "globalei": "global",
    "globalele": "global",
    "globalelor": "global",
    "globali": "global",
    "globalii": "global",
    "globalilor": "global",
    "globalul": "global",
    "globalului": "global",
    "globalitatea": "globalitate",
    "globalități": "globalitate",
    "globalității": "globalitate",
    "globalitățile": "globalitate",
    "globalităților": "globalitate",
    "globea": "globi",
    "globeai": "globi",
    "globeam": "globi",
    "globească": "globi",
    "globeați": "globi",
    "globeau": "globi",
    "globesc": "globi",
    "globește": "globi",
    "globești": "globi",
    "globii": "globi",
    "globim": "globi",
    "globind": "globi",
    "globindu": "globi",
    "globiră": "globi",
    "globirăm": "globi",
    "globirăți": "globi",
    "globise": "globi",
    "globisem": "globi",
    "globiseră": "globi",
    "globiserăm": "globi",
    "globiserăți": "globi",
    "globiseși": "globi",
    "globiși": "globi",
    "globit": "globi",
    "globiți": "globi",
    "globitu": "globi",
    "neglobind": "globi",
    "neglobindu": "globi",
    "nemaiglobind": "globi",
    "nemaiglobindu": "globi",
    "globită": "globit",
    "globite": "globit",
    "globiți": "globit",
    "globula": "globulă",
    "globule": "globulă",
    "globulei": "globulă",
    "globulele": "globulă",
    "globulelor": "globulă",
    "globulara": "globular",
    "globulară": "globular",
    "globulare": "globular",
    "globularei": "globular",
    "globularele": "globular",
    "globularelor": "globular",
    "globulari": "globular",
    "globularii": "globular",
    "globularilor": "globular",
    "globularul": "globular",
    "globularului": "globular",
    "glodul": "glod",
    "glodului": "glod",
    "gloduri": "glod",
    "glodurile": "glod",
    "glodurilor": "glod",
    "glodea": "glodi",
    "glodeai": "glodi",
    "glodeam": "glodi",
    "glodească": "glodi",
    "glodeați": "glodi",
    "glodeau": "glodi",
    "glodesc": "glodi",
    "glodește": "glodi",
    "glodești": "glodi",
    "glodii": "glodi",
    "glodim": "glodi",
    "glodind": "glodi",
    "glodindu": "glodi",
    "glodiră": "glodi",
    "glodirăm": "glodi",
    "glodirăți": "glodi",
    "glodise": "glodi",
    "glodisem": "glodi",
    "glodiseră": "glodi",
    "glodiserăm": "glodi",
    "glodiserăți": "glodi",
    "glodiseși": "glodi",
    "glodiși": "glodi",
    "glodit": "glodi",
    "glodiți": "glodi",
    "gloditu": "glodi",
    "neglodind": "glodi",
    "neglodindu": "glodi",
    "nemaiglodind": "glodi",
    "nemaiglodindu": "glodi",
    "glodită": "glodit",
    "glodite": "glodit",
    "glodiți": "glodit",
    "gloanțe": "glonț",
    "gloanțele": "glonț",
    "gloanțelor": "glonț",
    "glonțul": "glonț",
    "glonțului": "glonț",
    "gloria": "glorie",
    "gloriei": "glorie",
    "glorii": "glorie",
    "gloriile": "glorie",
    "gloriilor": "glorie",
    "glorific": "glorifica",
    "glorifică": "glorifica",
    "glorificai": "glorifica",
    "glorificam": "glorifica",
    "glorificăm": "glorifica",
    "glorificând": "glorifica",
    "glorificându": "glorifica",
    "glorificară": "glorifica",
    "glorificarăm": "glorifica",
    "glorificarăți": "glorifica",
    "glorificase": "glorifica",
    "glorificasem": "glorifica",
    "glorificaseră": "glorifica",
    "glorificaserăm": "glorifica",
    "glorificaserăți": "glorifica",
    "glorificaseși": "glorifica",
    "glorificași": "glorifica",
    "glorificat": "glorifica",
    "glorificați": "glorifica",
    "glorificatu": "glorifica",
    "glorificau": "glorifica",
    "glorifice": "glorifica",
    "glorifici": "glorifica",
    "neglorificând": "glorifica",
    "neglorificându": "glorifica",
    "nemaiglorificând": "glorifica",
    "nemaiglorificându": "glorifica",
    "glorificată": "glorificat",
    "glorificate": "glorificat",
    "glorificați": "glorificat",
    "glorioasa": "glorios",
    "glorioasă": "glorios",
    "glorioase": "glorios",
    "glorioasei": "glorios",
    "glorioasele": "glorios",
    "glorioaselor": "glorios",
    "glorioși": "glorios",
    "glorioșii": "glorios",
    "glorioșilor": "glorios",
    "gloriosul": "glorios",
    "gloriosului": "glorios",
    "glosă": "glosa",
    "glosai": "glosa",
    "glosam": "glosa",
    "glosăm": "glosa",
    "glosând": "glosa",
    "glosându": "glosa",
    "glosară": "glosa",
    "glosarăm": "glosa",
    "glosarăți": "glosa",
    "glosase": "glosa",
    "glosasem": "glosa",
    "glosaseră": "glosa",
    "glosaserăm": "glosa",
    "glosaserăți": "glosa",
    "glosaseși": "glosa",
    "glosași": "glosa",
    "glosat": "glosa",
    "glosați": "glosa",
    "glosatu": "glosa",
    "glosau": "glosa",
    "glosează": "glosa",
    "glosez": "glosa",
    "gloseze": "glosa",
    "glosezi": "glosa",
    "neglosând": "glosa",
    "neglosându": "glosa",
    "nemaiglosând": "glosa",
    "nemaiglosându": "glosa",
    "glosa": "glosă",
    "glose": "glosă",
    "glosei": "glosă",
    "glosele": "glosă",
    "gloselor": "glosă",
    "glosare": "glosar",
    "glosarele": "glosar",
    "glosarelor": "glosar",
    "glosarul": "glosar",
    "glosarului": "glosar",
    "glosată": "glosat",
    "glosate": "glosat",
    "glosați": "glosat",
    "glucoza": "glucoză",
    "glucoze": "glucoză",
    "glucozei": "glucoză",
    "glucozele": "glucoză",
    "glucozelor": "glucoză",
    "gluga": "glugă",
    "glugi": "glugă",
    "glugii": "glugă",
    "glugile": "glugă",
    "glugilor": "glugă",
    "gluma": "glumă",
    "glume": "glumă",
    "glumei": "glumă",
    "glumele": "glumă",
    "glumelor": "glumă",
    "glumeața": "glumeață",
    "glumeațo": "glumeață",
    "glumețe": "glumeață",
    "glumeței": "glumeață",
    "glumețele": "glumeață",
    "glumețelor": "glumeață",
    "glumeața": "glumeț",
    "glumeață": "glumeț",
    "glumețe": "glumeț",
    "glumeței": "glumeț",
    "glumețele": "glumeț",
    "glumețelor": "glumeț",
    "glumeți": "glumeț",
    "glumeții": "glumeț",
    "glumeților": "glumeț",
    "glumețul": "glumeț",
    "glumețule": "glumeț",
    "glumețului": "glumeț",
    "glumea": "glumi",
    "glumeai": "glumi",
    "glumeam": "glumi",
    "glumească": "glumi",
    "glumeați": "glumi",
    "glumeau": "glumi",
    "glumesc": "glumi",
    "glumește": "glumi",
    "glumești": "glumi",
    "glumii": "glumi",
    "glumim": "glumi",
    "glumind": "glumi",
    "glumindu": "glumi",
    "glumiră": "glumi",
    "glumirăm": "glumi",
    "glumirăți": "glumi",
    "glumise": "glumi",
    "glumisem": "glumi",
    "glumiseră": "glumi",
    "glumiserăm": "glumi",
    "glumiserăți": "glumi",
    "glumiseși": "glumi",
    "glumiși": "glumi",
    "glumit": "glumi",
    "glumiți": "glumi",
    "glumitu": "glumi",
    "neglumind": "glumi",
    "neglumindu": "glumi",
    "nemaiglumind": "glumi",
    "nemaiglumindu": "glumi",
    "glumită": "glumit",
    "glumite": "glumit",
    "glumiți": "glumit",
    "goana": "goană",
    "goane": "goană",
    "goanei": "goană",
    "goanele": "goană",
    "goanelor": "goană",
    "goarna": "goarnă",
    "goarne": "goarnă",
    "goarnei": "goarnă",
    "goarnele": "goarnă",
    "goarnelor": "goarnă",
    "goeleta": "goeletă",
    "goelete": "goeletă",
    "goeletei": "goeletă",
    "goeletele": "goeletă",
    "goeletelor": "goeletă",
    "gofră": "gofra",
    "gofrai": "gofra",
    "gofram": "gofra",
    "gofrăm": "gofra",
    "gofrând": "gofra",
    "gofrându": "gofra",
    "gofrară": "gofra",
    "gofrarăm": "gofra",
    "gofrarăți": "gofra",
    "gofrase": "gofra",
    "gofrasem": "gofra",
    "gofraseră": "gofra",
    "gofraserăm": "gofra",
    "gofraserăți": "gofra",
    "gofraseși": "gofra",
    "gofrași": "gofra",
    "gofrat": "gofra",
    "gofrați": "gofra",
    "gofratu": "gofra",
    "gofrau": "gofra",
    "gofrează": "gofra",
    "gofrez": "gofra",
    "gofreze": "gofra",
    "gofrezi": "gofra",
    "negofrând": "gofra",
    "negofrându": "gofra",
    "nemaigofrând": "gofra",
    "nemaigofrându": "gofra",
    "gofrată": "gofrat",
    "gofrate": "gofrat",
    "gofrați": "gofrat",
    "gogea": "gogi",
    "gogeai": "gogi",
    "gogeam": "gogi",
    "gogească": "gogi",
    "gogeați": "gogi",
    "gogeau": "gogi",
    "gogesc": "gogi",
    "gogește": "gogi",
    "gogești": "gogi",
    "gogii": "gogi",
    "gogim": "gogi",
    "gogind": "gogi",
    "gogindu": "gogi",
    "gogiră": "gogi",
    "gogirăm": "gogi",
    "gogirăți": "gogi",
    "gogise": "gogi",
    "gogisem": "gogi",
    "gogiseră": "gogi",
    "gogiserăm": "gogi",
    "gogiserăți": "gogi",
    "gogiseși": "gogi",
    "gogiși": "gogi",
    "gogit": "gogi",
    "gogiți": "gogi",
    "gogitu": "gogi",
    "negogind": "gogi",
    "negogindu": "gogi",
    "nemaigogind": "gogi",
    "nemaigogindu": "gogi",
    "gogită": "gogit",
    "gogite": "gogit",
    "gogiți": "gogit",
    "gogoașa": "gogoașă",
    "gogoși": "gogoașă",
    "gogoșii": "gogoașă",
    "gogoșile": "gogoașă",
    "gogoșilor": "gogoașă",
    "gogomani": "gogoman",
    "gogomanii": "gogoman",
    "gogomanilor": "gogoman",
    "gogomanul": "gogoman",
    "gogomanului": "gogoman",
    "gogomănia": "gogomănie",
    "gogomăniei": "gogomănie",
    "gogomănii": "gogomănie",
    "gogomăniile": "gogomănie",
    "gogomăniilor": "gogomănie",
    "gogoneaua": "gogonea",
    "gogonele": "gogonea",
    "gogonelei": "gogonea",
    "gogonelele": "gogonea",
    "gogonelelor": "gogonea",
    "gogorița": "gogoriță",
    "gogorițe": "gogoriță",
    "gogoriței": "gogoriță",
    "gogorițele": "gogoriță",
    "gogorițelor": "gogoriță",
    "gogoșari": "gogoșar",
    "gogoșarii": "gogoșar",
    "gogoșarilor": "gogoșar",
    "gogoșarul": "gogoșar",
    "gogoșarului": "gogoșar",
    "goala": "gol",
    "goală": "gol",
    "goală-goluță": "gol",
    "goale": "gol",
    "goalei": "gol",
    "goalele": "gol",
    "goalelor": "gol",
    "goi": "gol",
    "goii": "gol",
    "goilor": "gol",
    "golul": "gol",
    "golului": "gol",
    "goluri": "gol",
    "golurile": "gol",
    "golurilor": "gol",
    "golani": "golan",
    "golanii": "golan",
    "golanilor": "golan",
    "golanul": "golan",
    "golanului": "golan",
    "Goldsteinismului": "Goldsteinism",
    "golful": "golf",
    "golfului": "golf",
    "golfuri": "golf",
    "golfurile": "golf",
    "golfurilor": "golf",
    "goale-goluțe": "gol-goluț",
    "goi-goluți": "gol-goluț",
    "golea": "goli",
    "goleai": "goli",
    "goleam": "goli",
    "golească": "goli",
    "goleați": "goli",
    "goleau": "goli",
    "golesc": "goli",
    "golește": "goli",
    "golești": "goli",
    "golii": "goli",
    "golim": "goli",
    "golind": "goli",
    "golindu": "goli",
    "goliră": "goli",
    "golirăm": "goli",
    "golirăți": "goli",
    "golise": "goli",
    "golisem": "goli",
    "goliseră": "goli",
    "goliserăm": "goli",
    "goliserăți": "goli",
    "goliseși": "goli",
    "goliși": "goli",
    "golit": "goli",
    "goliți": "goli",
    "golitu": "goli",
    "negolind": "goli",
    "negolindu": "goli",
    "nemaigolind": "goli",
    "nemaigolindu": "goli",
    "goliciunea": "goliciune",
    "goliciuni": "goliciune",
    "goliciunii": "goliciune",
    "goliciunile": "goliciune",
    "goliciunilor": "goliciune",
    "golită": "golit",
    "golite": "golit",
    "goliți": "golit",
    "gologani": "gologan",
    "gologanii": "gologan",
    "gologanilor": "gologan",
    "gologanul": "gologan",
    "gologanului": "gologan",
    "gologănea": "gologăni",
    "gologăneai": "gologăni",
    "gologăneam": "gologăni",
    "gologănească": "gologăni",
    "gologăneați": "gologăni",
    "gologăneau": "gologăni",
    "gologănesc": "gologăni",
    "gologănește": "gologăni",
    "gologănești": "gologăni",
    "gologănii": "gologăni",
    "gologănim": "gologăni",
    "gologănind": "gologăni",
    "gologănindu": "gologăni",
    "gologăniră": "gologăni",
    "gologănirăm": "gologăni",
    "gologănirăți": "gologăni",
    "gologănise": "gologăni",
    "gologănisem": "gologăni",
    "gologăniseră": "gologăni",
    "gologăniserăm": "gologăni",
    "gologăniserăți": "gologăni",
    "gologăniseși": "gologăni",
    "gologăniși": "gologăni",
    "gologănit": "gologăni",
    "gologăniți": "gologăni",
    "gologănitu": "gologăni",
    "negologănind": "gologăni",
    "negologănindu": "gologăni",
    "nemaigologănind": "gologăni",
    "nemaigologănindu": "gologăni",
    "gologănită": "gologănit",
    "gologănite": "gologănit",
    "gologăniți": "gologănit",
    "goală-pușcă": "gol-pușcă",
    "goale-pușcă": "gol-pușcă",
    "goi-pușcă": "gol-pușcă",
    "gondola": "gondolă",
    "gondole": "gondolă",
    "gondolei": "gondolă",
    "gondolele": "gondolă",
    "gondolelor": "gondolă",
    "gonflă": "gonfla",
    "gonflai": "gonfla",
    "gonflam": "gonfla",
    "gonflăm": "gonfla",
    "gonflând": "gonfla",
    "gonflându": "gonfla",
    "gonflară": "gonfla",
    "gonflarăm": "gonfla",
    "gonflarăți": "gonfla",
    "gonflase": "gonfla",
    "gonflasem": "gonfla",
    "gonflaseră": "gonfla",
    "gonflaserăm": "gonfla",
    "gonflaserăți": "gonfla",
    "gonflaseși": "gonfla",
    "gonflași": "gonfla",
    "gonflat": "gonfla",
    "gonflați": "gonfla",
    "gonflatu": "gonfla",
    "gonflau": "gonfla",
    "gonflează": "gonfla",
    "gonflez": "gonfla",
    "gonfleze": "gonfla",
    "gonflezi": "gonfla",
    "negonflând": "gonfla",
    "negonflându": "gonfla",
    "nemaigonflând": "gonfla",
    "nemaigonflându": "gonfla",
    "gonflată": "gonflat",
    "gonflate": "gonflat",
    "gonflați": "gonflat",
    "gongul": "gong",
    "gongului": "gong",
    "gonguri": "gong",
    "gongurile": "gong",
    "gongurilor": "gong",
    "gonea": "goni",
    "goneai": "goni",
    "goneam": "goni",
    "gonească": "goni",
    "goneați": "goni",
    "goneau": "goni",
    "gonesc": "goni",
    "gonește": "goni",
    "gonești": "goni",
    "gonii": "goni",
    "gonim": "goni",
    "gonind": "goni",
    "gonindu": "goni",
    "goniră": "goni",
    "gonirăm": "goni",
    "gonirăți": "goni",
    "gonise": "goni",
    "gonisem": "goni",
    "goniseră": "goni",
    "goniserăm": "goni",
    "goniserăți": "goni",
    "goniseși": "goni",
    "goniși": "goni",
    "gonit": "goni",
    "goniți": "goni",
    "gonitu": "goni",
    "negonind": "goni",
    "negonindu": "goni",
    "nemaigonind": "goni",
    "nemaigonindu": "goni",
    "gonită": "gonit",
    "gonite": "gonit",
    "goniți": "gonit",
    "gorila": "gorilă",
    "gorile": "gorilă",
    "gorilei": "gorilă",
    "gorilele": "gorilă",
    "gorilelor": "gorilă",
    "gospodari": "gospodar",
    "gospodarii": "gospodar",
    "gospodarilor": "gospodar",
    "gospodarul": "gospodar",
    "gospodarului": "gospodar",
    "gospodărea": "gospodări",
    "gospodăreai": "gospodări",
    "gospodăream": "gospodări",
    "gospodărească": "gospodări",
    "gospodăreați": "gospodări",
    "gospodăreau": "gospodări",
    "gospodăresc": "gospodări",
    "gospodărește": "gospodări",
    "gospodărești": "gospodări",
    "gospodării": "gospodări",
    "gospodărim": "gospodări",
    "gospodărind": "gospodări",
    "gospodărindu": "gospodări",
    "gospodăriră": "gospodări",
    "gospodărirăm": "gospodări",
    "gospodărirăți": "gospodări",
    "gospodărise": "gospodări",
    "gospodărisem": "gospodări",
    "gospodăriseră": "gospodări",
    "gospodăriserăm": "gospodări",
    "gospodăriserăți": "gospodări",
    "gospodăriseși": "gospodări",
    "gospodăriși": "gospodări",
    "gospodărit": "gospodări",
    "gospodăriți": "gospodări",
    "gospodăritu": "gospodări",
    "negospodărind": "gospodări",
    "negospodărindu": "gospodări",
    "nemaigospodărind": "gospodări",
    "nemaigospodărindu": "gospodări",
    "gospodăria": "gospodărie",
    "gospodăriei": "gospodărie",
    "gospodării": "gospodărie",
    "gospodăriile": "gospodărie",
    "gospodăriilor": "gospodărie",
    "gospodărirea": "gospodărire",
    "gospodăriri": "gospodărire",
    "gospodăririi": "gospodărire",
    "gospodăririle": "gospodărire",
    "gospodăririlor": "gospodărire",
    "gospodărită": "gospodărit",
    "gospodărite": "gospodărit",
    "gospodăriți": "gospodărit",
    "gospodăroasa": "gospodăros",
    "gospodăroasă": "gospodăros",
    "gospodăroase": "gospodăros",
    "gospodăroasei": "gospodăros",
    "gospodăroasele": "gospodăros",
    "gospodăroaselor": "gospodăros",
    "gospodăroaso": "gospodăros",
    "gospodăroși": "gospodăros",
    "gospodăroșii": "gospodăros",
    "gospodăroșilor": "gospodăros",
    "gospodărosul": "gospodăros",
    "gospodărosule": "gospodăros",
    "gospodărosului": "gospodăros",
    "gospodina": "gospodină",
    "gospodine": "gospodină",
    "gospodinei": "gospodină",
    "gospodinele": "gospodină",
    "gospodinelor": "gospodină",
    "graba": "grabă",
    "grabe": "grabă",
    "grabei": "grabă",
    "grăbea": "grăbi",
    "grăbeai": "grăbi",
    "grăbeam": "grăbi",
    "grăbească": "grăbi",
    "grăbeați": "grăbi",
    "grăbeau": "grăbi",
    "grăbesc": "grăbi",
    "grăbește": "grăbi",
    "grăbești": "grăbi",
    "grăbii": "grăbi",
    "grăbim": "grăbi",
    "grăbind": "grăbi",
    "grăbindu": "grăbi",
    "grăbiră": "grăbi",
    "grăbirăm": "grăbi",
    "grăbirăți": "grăbi",
    "grăbise": "grăbi",
    "grăbisem": "grăbi",
    "grăbiseră": "grăbi",
    "grăbiserăm": "grăbi",
    "grăbiserăți": "grăbi",
    "grăbiseși": "grăbi",
    "grăbiși": "grăbi",
    "grăbit": "grăbi",
    "grăbiți": "grăbi",
    "grăbitu": "grăbi",
    "negrăbind": "grăbi",
    "negrăbindu": "grăbi",
    "nemaigrăbind": "grăbi",
    "nemaigrăbindu": "grăbi",
    "grăbirea": "grăbire",
    "grăbireo": "grăbire",
    "grăbiri": "grăbire",
    "grăbirii": "grăbire",
    "grăbirile": "grăbire",
    "grăbirilor": "grăbire",
    "grăbita": "grăbit",
    "grăbită": "grăbit",
    "grăbite": "grăbit",
    "grăbitei": "grăbit",
    "grăbitele": "grăbit",
    "grăbitelor": "grăbit",
    "grăbiți": "grăbit",
    "grăbiții": "grăbit",
    "grăbiților": "grăbit",
    "grăbito": "grăbit",
    "grăbitul": "grăbit",
    "grăbitule": "grăbit",
    "grăbitului": "grăbit",
    "grabnica": "grabnic",
    "grabnică": "grabnic",
    "grabnice": "grabnic",
    "grabnicei": "grabnic",
    "grabnicele": "grabnic",
    "grabnicelor": "grabnic",
    "grabnici": "grabnic",
    "grabnicii": "grabnic",
    "grabnicilor": "grabnic",
    "grabnicul": "grabnic",
    "grabnicului": "grabnic",
    "grade": "grad",
    "gradele": "grad",
    "gradelor": "grad",
    "gradul": "grad",
    "gradului": "grad",
    "gradă": "grada",
    "gradai": "grada",
    "gradam": "grada",
    "gradăm": "grada",
    "gradând": "grada",
    "gradându": "grada",
    "gradară": "grada",
    "gradarăm": "grada",
    "gradarăți": "grada",
    "gradase": "grada",
    "gradasem": "grada",
    "gradaseră": "grada",
    "gradaserăm": "grada",
    "gradaserăți": "grada",
    "gradaseși": "grada",
    "gradași": "grada",
    "gradat": "grada",
    "gradați": "grada",
    "gradatu": "grada",
    "gradau": "grada",
    "gradează": "grada",
    "gradez": "grada",
    "gradeze": "grada",
    "gradezi": "grada",
    "negradând": "grada",
    "negradându": "grada",
    "nemaigradând": "grada",
    "nemaigradându": "grada",
    "gradata": "gradat",
    "gradată": "gradat",
    "gradate": "gradat",
    "gradatei": "gradat",
    "gradatele": "gradat",
    "gradatelor": "gradat",
    "gradați": "gradat",
    "gradații": "gradat",
    "gradaților": "gradat",
    "gradatul": "gradat",
    "gradatului": "gradat",
    "gradația": "gradație",
    "gradației": "gradație",
    "gradații": "gradație",
    "gradațiile": "gradație",
    "gradațiilor": "gradație",
    "grădina": "grădină",
    "grădini": "grădină",
    "grădinii": "grădină",
    "grădinile": "grădină",
    "grădinilor": "grădină",
    "grădinari": "grădinar",
    "grădinarii": "grădinar",
    "grădinarilor": "grădinar",
    "grădinarul": "grădinar",
    "grădinarului": "grădinar",
    "grădinărea": "grădinări",
    "grădinăreai": "grădinări",
    "grădinăream": "grădinări",
    "grădinărească": "grădinări",
    "grădinăreați": "grădinări",
    "grădinăreau": "grădinări",
    "grădinăresc": "grădinări",
    "grădinărește": "grădinări",
    "grădinărești": "grădinări",
    "grădinării": "grădinări",
    "grădinărim": "grădinări",
    "grădinărind": "grădinări",
    "grădinărindu": "grădinări",
    "grădinăriră": "grădinări",
    "grădinărirăm": "grădinări",
    "grădinărirăți": "grădinări",
    "grădinărise": "grădinări",
    "grădinărisem": "grădinări",
    "grădinăriseră": "grădinări",
    "grădinăriserăm": "grădinări",
    "grădinăriserăți": "grădinări",
    "grădinăriseși": "grădinări",
    "grădinăriși": "grădinări",
    "grădinărit": "grădinări",
    "grădinăriți": "grădinări",
    "grădinăritu": "grădinări",
    "negrădinărind": "grădinări",
    "negrădinărindu": "grădinări",
    "nemaigrădinărind": "grădinări",
    "nemaigrădinărindu": "grădinări",
    "grădinărită": "grădinărit",
    "grădinărite": "grădinărit",
    "grădinăriți": "grădinărit",
    "grădinăritul": "grădinărit",
    "grădinăritului": "grădinărit",
    "grădinița": "grădiniță",
    "grădinițe": "grădiniță",
    "grădiniței": "grădiniță",
    "grădinițele": "grădiniță",
    "grădinițelor": "grădiniță",
    "grafica": "grafic",
    "grafică": "grafic",
    "grafice": "grafic",
    "graficei": "grafic",
    "graficele": "grafic",
    "graficelor": "grafic",
    "grafici": "grafic",
    "graficii": "grafic",
    "graficilor": "grafic",
    "graficul": "grafic",
    "graficului": "grafic",
    "grafica": "grafică",
    "graficele": "grafică",
    "grafici": "grafică",
    "graficii": "grafică",
    "graficilor": "grafică",
    "graficianul": "grafician",
    "graficianului": "grafician",
    "graficieni": "grafician",
    "graficienii": "grafician",
    "graficienilor": "grafician",
    "grafiei": "grafie",
    "grafii": "grafie",
    "grafitiză": "grafitiza",
    "grafitizai": "grafitiza",
    "grafitizam": "grafitiza",
    "grafitizăm": "grafitiza",
    "grafitizând": "grafitiza",
    "grafitizându": "grafitiza",
    "grafitizară": "grafitiza",
    "grafitizarăm": "grafitiza",
    "grafitizarăți": "grafitiza",
    "grafitizase": "grafitiza",
    "grafitizasem": "grafitiza",
    "grafitizaseră": "grafitiza",
    "grafitizaserăm": "grafitiza",
    "grafitizaserăți": "grafitiza",
    "grafitizaseși": "grafitiza",
    "grafitizași": "grafitiza",
    "grafitizat": "grafitiza",
    "grafitizați": "grafitiza",
    "grafitizatu": "grafitiza",
    "grafitizau": "grafitiza",
    "grafitizează": "grafitiza",
    "grafitizez": "grafitiza",
    "grafitizeze": "grafitiza",
    "grafitizezi": "grafitiza",
    "negrafitizând": "grafitiza",
    "negrafitizându": "grafitiza",
    "nemaigrafitizând": "grafitiza",
    "nemaigrafitizându": "grafitiza",
    "grafitizată": "grafitizat",
    "grafitizate": "grafitizat",
    "grafitizați": "grafitizat",
    "grafologia": "grafologie",
    "grafologiei": "grafologie",
    "grafologii": "grafologie",
    "graiul": "grai",
    "graiului": "grai",
    "graiuri": "grai",
    "graiurile": "grai",
    "graiurilor": "grai",
    "grăia": "grăi",
    "grăiai": "grăi",
    "grăiam": "grăi",
    "grăiască": "grăi",
    "grăiați": "grăi",
    "grăiau": "grăi",
    "grăiesc": "grăi",
    "grăiește": "grăi",
    "grăiești": "grăi",
    "grăii": "grăi",
    "grăim": "grăi",
    "grăind": "grăi",
    "grăindu": "grăi",
    "grăiră": "grăi",
    "grăirăm": "grăi",
    "grăirăți": "grăi",
    "grăise": "grăi",
    "grăisem": "grăi",
    "grăiseră": "grăi",
    "grăiserăm": "grăi",
    "grăiserăți": "grăi",
    "grăiseși": "grăi",
    "grăiși": "grăi",
    "grăit": "grăi",
    "grăiți": "grăi",
    "grăitu": "grăi",
    "negrăind": "grăi",
    "negrăindu": "grăi",
    "nemaigrăind": "grăi",
    "nemaigrăindu": "grăi",
    "grăită": "grăit",
    "grăite": "grăit",
    "grăiți": "grăit",
    "grăitoare": "grăitor",
    "grăitoarea": "grăitor",
    "grăitoarei": "grăitor",
    "grăitoarele": "grăitor",
    "grăitoarelor": "grăitor",
    "grăitori": "grăitor",
    "grăitorii": "grăitor",
    "grăitorilor": "grăitor",
    "grăitorul": "grăitor",
    "grăitorului": "grăitor",
    "grajdul": "grajd",
    "grajdului": "grajd",
    "grajduri": "grajd",
    "grajdurile": "grajd",
    "grajdurilor": "grajd",
    "grăjdari": "grăjdar",
    "grăjdarii": "grăjdar",
    "grăjdarilor": "grăjdar",
    "grăjdarul": "grăjdar",
    "grăjdarului": "grăjdar",
    "g": "gram",
    "grame": "gram",
    "gramele": "gram",
    "gramelor": "gram",
    "gramul": "gram",
    "gramului": "gram",
    "g.cal.": "gram_calorie",
    "g.cm": "gram_centimetru",
    "grămada": "grămadă",
    "grămezi": "grămadă",
    "grămezii": "grămadă",
    "grămezile": "grămadă",
    "grămezilor": "grămadă",
    "grămădea": "grămădi",
    "grămădeai": "grămădi",
    "grămădeam": "grămădi",
    "grămădească": "grămădi",
    "grămădeați": "grămădi",
    "grămădeau": "grămădi",
    "grămădesc": "grămădi",
    "grămădește": "grămădi",
    "grămădești": "grămădi",
    "grămădii": "grămădi",
    "grămădim": "grămădi",
    "grămădind": "grămădi",
    "grămădindu": "grămădi",
    "grămădiră": "grămădi",
    "grămădirăm": "grămădi",
    "grămădirăți": "grămădi",
    "grămădise": "grămădi",
    "grămădisem": "grămădi",
    "grămădiseră": "grămădi",
    "grămădiserăm": "grămădi",
    "grămădiserăți": "grămădi",
    "grămădiseși": "grămădi",
    "grămădiși": "grămădi",
    "grămădit": "grămădi",
    "grămădiți": "grămădi",
    "grămăditu": "grămădi",
    "negrămădind": "grămădi",
    "negrămădindu": "grămădi",
    "nemaigrămădind": "grămădi",
    "nemaigrămădindu": "grămădi",
    "grămădită": "grămădit",
    "grămădite": "grămădit",
    "grămădiți": "grămădit",
    "grămăjoara": "grămăjoară",
    "grămăjoare": "grămăjoară",
    "grămăjoarei": "grămăjoară",
    "grămăjoarele": "grămăjoară",
    "grămăjoarelor": "grămăjoară",
    "grămătici": "grămătic",
    "grămăticii": "grămătic",
    "grămăticilor": "grămătic",
    "grămăticul": "grămătic",
    "grămăticule": "grămătic",
    "grămăticului": "grămătic",
    "gr.": "gramatică",
    "gram.": "gramatică",
    "grama.": "gramatică",
    "gramatica": "gramatică",
    "gramatici": "gramatică",
    "gramaticii": "gramatică",
    "gramaticile": "gramatică",
    "gramaticilor": "gramatică",
    "gramaticala": "gramatical",
    "gramaticală": "gramatical",
    "gramaticale": "gramatical",
    "gramaticalei": "gramatical",
    "gramaticalele": "gramatical",
    "gramaticalelor": "gramatical",
    "gramaticali": "gramatical",
    "gramaticalii": "gramatical",
    "gramaticalilor": "gramatical",
    "gramaticalul": "gramatical",
    "gramaticalului": "gramatical",
    "gramaticaliză": "gramaticaliza",
    "gramaticalizai": "gramaticaliza",
    "gramaticalizam": "gramaticaliza",
    "gramaticalizăm": "gramaticaliza",
    "gramaticalizând": "gramaticaliza",
    "gramaticalizându": "gramaticaliza",
    "gramaticalizară": "gramaticaliza",
    "gramaticalizarăm": "gramaticaliza",
    "gramaticalizarăți": "gramaticaliza",
    "gramaticalizase": "gramaticaliza",
    "gramaticalizasem": "gramaticaliza",
    "gramaticalizaseră": "gramaticaliza",
    "gramaticalizaserăm": "gramaticaliza",
    "gramaticalizaserăți": "gramaticaliza",
    "gramaticalizaseși": "gramaticaliza",
    "gramaticalizași": "gramaticaliza",
    "gramaticalizat": "gramaticaliza",
    "gramaticalizați": "gramaticaliza",
    "gramaticalizatu": "gramaticaliza",
    "gramaticalizau": "gramaticaliza",
    "gramaticalizează": "gramaticaliza",
    "gramaticalizez": "gramaticaliza",
    "gramaticalizeze": "gramaticaliza",
    "gramaticalizezi": "gramaticaliza",
    "negramaticalizând": "gramaticaliza",
    "negramaticalizându": "gramaticaliza",
    "nemaigramaticalizând": "gramaticaliza",
    "nemaigramaticalizându": "gramaticaliza",
    "gramaticalizată": "gramaticalizat",
    "gramaticalizate": "gramaticalizat",
    "gramaticalizați": "gramaticalizat",
    "gramofoane": "gramofon",
    "gramofoanele": "gramofon",
    "gramofoanelor": "gramofon",
    "gramofonul": "gramofon",
    "gramofonului": "gramofon",
    "grânare": "grânar",
    "grânarele": "grânar",
    "grânarelor": "grânar",
    "grânarul": "grânar",
    "grânarului": "grânar",
    "grandilocventa": "grandilocvent",
    "grandilocventă": "grandilocvent",
    "grandilocvente": "grandilocvent",
    "grandilocventei": "grandilocvent",
    "grandilocventele": "grandilocvent",
    "grandilocventelor": "grandilocvent",
    "grandilocvenți": "grandilocvent",
    "grandilocvenții": "grandilocvent",
    "grandilocvenților": "grandilocvent",
    "grandilocventul": "grandilocvent",
    "grandilocventului": "grandilocvent",
    "grandioasa": "grandios",
    "grandioasă": "grandios",
    "grandioase": "grandios",
    "grandioasei": "grandios",
    "grandioasele": "grandios",
    "grandioaselor": "grandios",
    "grandioși": "grandios",
    "grandioșii": "grandios",
    "grandioșilor": "grandios",
    "grandiosul": "grandios",
    "grandiosului": "grandios",
    "grandoarea": "grandoare",
    "grandori": "grandoare",
    "grandorii": "grandoare",
    "grandorile": "grandoare",
    "grandorilor": "grandoare",
    "granguri": "grangur",
    "grangurii": "grangur",
    "grangurilor": "grangur",
    "grangurul": "grangur",
    "grangurului": "grangur",
    "grăniceri": "grănicer",
    "grănicerii": "grănicer",
    "grănicerilor": "grănicer",
    "grănicerul": "grănicer",
    "grănicerului": "grănicer",
    "grănicereasca": "grăniceresc",
    "grănicerească": "grăniceresc",
    "grănicereasco": "grăniceresc",
    "grănicerescul": "grăniceresc",
    "grănicerescule": "grăniceresc",
    "grănicerescului": "grăniceresc",
    "grănicerești": "grăniceresc",
    "grănicereștii": "grăniceresc",
    "grănicereștile": "grăniceresc",
    "grănicereștilor": "grăniceresc",
    "granitul": "granit",
    "granitului": "granit",
    "granituri": "granit",
    "graniturile": "granit",
    "graniturilor": "granit",
    "granița": "graniță",
    "granițe": "graniță",
    "graniței": "graniță",
    "granițele": "graniță",
    "granițelor": "graniță",
    "granulă": "granula",
    "granulai": "granula",
    "granulam": "granula",
    "granulăm": "granula",
    "granulând": "granula",
    "granulându": "granula",
    "granulară": "granula",
    "granularăm": "granula",
    "granularăți": "granula",
    "granulase": "granula",
    "granulasem": "granula",
    "granulaseră": "granula",
    "granulaserăm": "granula",
    "granulaserăți": "granula",
    "granulaseși": "granula",
    "granulași": "granula",
    "granulat": "granula",
    "granulați": "granula",
    "granulatu": "granula",
    "granulau": "granula",
    "granulează": "granula",
    "granulez": "granula",
    "granuleze": "granula",
    "granulezi": "granula",
    "negranulând": "granula",
    "negranulându": "granula",
    "nemaigranulând": "granula",
    "nemaigranulându": "granula",
    "granula": "granulă",
    "granule": "granulă",
    "granulei": "granulă",
    "granulele": "granulă",
    "granulelor": "granulă",
    "granulată": "granulat",
    "granulate": "granulat",
    "granulați": "granulat",
    "grapa": "grapă",
    "grape": "grapă",
    "grapei": "grapă",
    "grapele": "grapă",
    "grapelor": "grapă",
    "grăpă": "grăpa",
    "grăpai": "grăpa",
    "grăpam": "grăpa",
    "grăpăm": "grăpa",
    "grăpând": "grăpa",
    "grăpându": "grăpa",
    "grăpară": "grăpa",
    "grăparăm": "grăpa",
    "grăparăți": "grăpa",
    "grăpase": "grăpa",
    "grăpasem": "grăpa",
    "grăpaseră": "grăpa",
    "grăpaserăm": "grăpa",
    "grăpaserăți": "grăpa",
    "grăpaseși": "grăpa",
    "grăpași": "grăpa",
    "grăpat": "grăpa",
    "grăpați": "grăpa",
    "grăpatu": "grăpa",
    "grăpau": "grăpa",
    "grăpează": "grăpa",
    "grăpez": "grăpa",
    "grăpeze": "grăpa",
    "grăpezi": "grăpa",
    "negrăpând": "grăpa",
    "negrăpându": "grăpa",
    "nemaigrăpând": "grăpa",
    "nemaigrăpându": "grăpa",
    "grăpată": "grăpat",
    "grăpate": "grăpat",
    "grăpați": "grăpat",
    "grasa": "gras",
    "grasă": "gras",
    "grase": "gras",
    "grasei": "gras",
    "grasele": "gras",
    "graselor": "gras",
    "grași": "gras",
    "grașii": "gras",
    "grașilor": "gras",
    "grasul": "gras",
    "grasului": "gras",
    "grăsana": "grăsan",
    "grăsană": "grăsan",
    "grăsane": "grăsan",
    "grăsanei": "grăsan",
    "grăsanele": "grăsan",
    "grăsanelor": "grăsan",
    "grăsani": "grăsan",
    "grăsanii": "grăsan",
    "grăsanilor": "grăsan",
    "grăsanul": "grăsan",
    "grăsanului": "grăsan",
    "grăsana": "grăsană",
    "grăsane": "grăsană",
    "grăsanei": "grăsană",
    "grăsanele": "grăsană",
    "grăsanelor": "grăsană",
    "graseiai": "graseia",
    "graseiam": "graseia",
    "graseiară": "graseia",
    "graseiarăm": "graseia",
    "graseiarăți": "graseia",
    "graseiase": "graseia",
    "graseiasem": "graseia",
    "graseiaseră": "graseia",
    "graseiaserăm": "graseia",
    "graseiaserăți": "graseia",
    "graseiaseși": "graseia",
    "graseiași": "graseia",
    "graseiat": "graseia",
    "graseiați": "graseia",
    "graseiatu": "graseia",
    "graseiau": "graseia",
    "graseie": "graseia",
    "graseiează": "graseia",
    "graseiem": "graseia",
    "graseiez": "graseia",
    "graseieze": "graseia",
    "graseiezi": "graseia",
    "graseind": "graseia",
    "graseindu": "graseia",
    "negraseiând": "graseia",
    "negraseiându": "graseia",
    "nemaigraseiând": "graseia",
    "nemaigraseiându": "graseia",
    "graseiată": "graseiat",
    "graseiate": "graseiat",
    "graseiați": "graseiat",
    "grăsimea": "grăsime",
    "grăsimi": "grăsime",
    "grăsimii": "grăsime",
    "grăsimile": "grăsime",
    "grăsimilor": "grăsime",
    "grăsulia": "grăsuliu",
    "grăsulie": "grăsuliu",
    "grăsuliei": "grăsuliu",
    "grăsulii": "grăsuliu",
    "grăsuliii": "grăsuliu",
    "grăsuliile": "grăsuliu",
    "grăsuliilor": "grăsuliu",
    "grăsuliul": "grăsuliu",
    "grăsuliului": "grăsuliu",
    "grăsuna": "grăsun",
    "grăsună": "grăsun",
    "grăsune": "grăsun",
    "grăsunei": "grăsun",
    "grăsunele": "grăsun",
    "grăsunelor": "grăsun",
    "grăsuni": "grăsun",
    "grăsunii": "grăsun",
    "grăsunilor": "grăsun",
    "grăsunul": "grăsun",
    "grăsunului": "grăsun",
    "grăsuța": "grăsuț",
    "grăsuță": "grăsuț",
    "grăsuțe": "grăsuț",
    "grăsuței": "grăsuț",
    "grăsuțele": "grăsuț",
    "grăsuțelor": "grăsuț",
    "grăsuți": "grăsuț",
    "grăsuții": "grăsuț",
    "grăsuților": "grăsuț",
    "grăsuțul": "grăsuț",
    "grăsuțului": "grăsuț",
    "grătare": "grătar",
    "grătarele": "grătar",
    "grătarelor": "grătar",
    "grătarul": "grătar",
    "grătarului": "grătar",
    "grațiai": "grația",
    "grațiam": "grația",
    "grațiară": "grația",
    "grațiarăm": "grația",
    "grațiarăți": "grația",
    "grațiase": "grația",
    "grațiasem": "grația",
    "grațiaseră": "grația",
    "grațiaserăm": "grația",
    "grațiaserăți": "grația",
    "grațiaseși": "grația",
    "grațiași": "grația",
    "grațiat": "grația",
    "grațiați": "grația",
    "grațiatu": "grația",
    "grațiau": "grația",
    "grațiază": "grația",
    "grație": "grația",
    "grațiem": "grația",
    "grațiez": "grația",
    "grațieze": "grația",
    "grațiezi": "grația",
    "grațiind": "grația",
    "grațiindu": "grația",
    "negrațiind": "grația",
    "negrațiindu": "grația",
    "nemaigrațiind": "grația",
    "nemaigrațiindu": "grația",
    "grațiată": "grațiat",
    "grațiate": "grațiat",
    "grațiați": "grațiat",
    "gratia": "gratie",
    "gratiei": "gratie",
    "gratii": "gratie",
    "gratiile": "gratie",
    "gratiilor": "gratie",
    "grația": "grație",
    "grației": "grație",
    "grații": "grație",
    "grațiile": "grație",
    "grațiilor": "grație",
    "grațierea": "grațiere",
    "grațieri": "grațiere",
    "grațierii": "grațiere",
    "grațierile": "grațiere",
    "grațierilor": "grațiere",
    "gratific": "gratifica",
    "gratifică": "gratifica",
    "gratificai": "gratifica",
    "gratificam": "gratifica",
    "gratificăm": "gratifica",
    "gratificând": "gratifica",
    "gratificându": "gratifica",
    "gratificară": "gratifica",
    "gratificarăm": "gratifica",
    "gratificarăți": "gratifica",
    "gratificase": "gratifica",
    "gratificasem": "gratifica",
    "gratificaseră": "gratifica",
    "gratificaserăm": "gratifica",
    "gratificaserăți": "gratifica",
    "gratificaseși": "gratifica",
    "gratificași": "gratifica",
    "gratificat": "gratifica",
    "gratificați": "gratifica",
    "gratificatu": "gratifica",
    "gratificau": "gratifica",
    "gratifice": "gratifica",
    "gratifici": "gratifica",
    "negratificând": "gratifica",
    "negratificându": "gratifica",
    "nemaigratificând": "gratifica",
    "nemaigratificându": "gratifica",
    "gratificată": "gratificat",
    "gratificate": "gratificat",
    "gratificați": "gratificat",
    "gratificația": "gratificație",
    "gratificației": "gratificație",
    "gratificații": "gratificație",
    "gratificațiile": "gratificație",
    "gratificațiilor": "gratificație",
    "gratină": "gratina",
    "gratinai": "gratina",
    "gratinam": "gratina",
    "gratinăm": "gratina",
    "gratinând": "gratina",
    "gratinându": "gratina",
    "gratinară": "gratina",
    "gratinarăm": "gratina",
    "gratinarăți": "gratina",
    "gratinase": "gratina",
    "gratinasem": "gratina",
    "gratinaseră": "gratina",
    "gratinaserăm": "gratina",
    "gratinaserăți": "gratina",
    "gratinaseși": "gratina",
    "gratinași": "gratina",
    "gratinat": "gratina",
    "gratinați": "gratina",
    "gratinatu": "gratina",
    "gratinau": "gratina",
    "gratinează": "gratina",
    "gratinez": "gratina",
    "gratineze": "gratina",
    "gratinezi": "gratina",
    "negratinând": "gratina",
    "negratinându": "gratina",
    "nemaigratinând": "gratina",
    "nemaigratinându": "gratina",
    "gratinată": "gratinat",
    "gratinate": "gratinat",
    "gratinați": "gratinat",
    "grațioasa": "grațios",
    "grațioasă": "grațios",
    "grațioase": "grațios",
    "grațioasei": "grațios",
    "grațioasele": "grațios",
    "grațioaselor": "grațios",
    "grațioși": "grațios",
    "grațioșii": "grațios",
    "grațioșilor": "grațios",
    "grațiosul": "grațios",
    "grațiosului": "grațios",
    "gr.": "gratis",
    "gratitudinea": "gratitudine",
    "gratitudineo": "gratitudine",
    "gratitudini": "gratitudine",
    "gratitudinii": "gratitudine",
    "gratitudinile": "gratitudine",
    "gratitudinilor": "gratitudine",
    "gratuita": "gratuit",
    "gratuită": "gratuit",
    "gratuite": "gratuit",
    "gratuitei": "gratuit",
    "gratuitele": "gratuit",
    "gratuitelor": "gratuit",
    "gratuiți": "gratuit",
    "gratuiții": "gratuit",
    "gratuiților": "gratuit",
    "gratuitul": "gratuit",
    "gratuitului": "gratuit",
    "gratuitatea": "gratuitate",
    "gratuitateo": "gratuitate",
    "grâie": "grâu",
    "grâiele": "grâu",
    "grâielor": "grâu",
    "grâne": "grâu",
    "grânele": "grâu",
    "grânelor": "grâu",
    "grâul": "grâu",
    "grâului": "grâu",
    "grăuntele": "grăunte",
    "grăuntelui": "grăunte",
    "grăunți": "grăunte",
    "grăunții": "grăunte",
    "grăunților": "grăunte",
    "grauri": "graur",
    "graurii": "graur",
    "graurilor": "graur",
    "graurul": "graur",
    "graurului": "graur",
    "grava": "grav",
    "gravă": "grav",
    "grave": "grav",
    "gravei": "grav",
    "gravele": "grav",
    "gravelor": "grav",
    "gravi": "grav",
    "gravii": "grav",
    "gravilor": "grav",
    "gravul": "grav",
    "gravului": "grav",
    "gravă": "grava",
    "gravai": "grava",
    "gravam": "grava",
    "gravăm": "grava",
    "gravând": "grava",
    "gravându": "grava",
    "gravară": "grava",
    "gravarăm": "grava",
    "gravarăți": "grava",
    "gravase": "grava",
    "gravasem": "grava",
    "gravaseră": "grava",
    "gravaserăm": "grava",
    "gravaserăți": "grava",
    "gravaseși": "grava",
    "gravași": "grava",
    "gravat": "grava",
    "gravați": "grava",
    "gravatu": "grava",
    "gravau": "grava",
    "gravează": "grava",
    "gravez": "grava",
    "graveze": "grava",
    "gravezi": "grava",
    "negravând": "grava",
    "negravându": "grava",
    "nemaigravând": "grava",
    "nemaigravându": "grava",
    "gravată": "gravat",
    "gravate": "gravat",
    "gravați": "gravat",
    "gravida": "gravidă",
    "gravide": "gravidă",
    "gravidei": "gravidă",
    "gravidele": "gravidă",
    "gravidelor": "gravidă",
    "graviditatea": "graviditate",
    "gravidități": "graviditate",
    "gravidității": "graviditate",
    "gravită": "gravita",
    "gravitai": "gravita",
    "gravitam": "gravita",
    "gravităm": "gravita",
    "gravitând": "gravita",
    "gravitându": "gravita",
    "gravitară": "gravita",
    "gravitarăm": "gravita",
    "gravitarăți": "gravita",
    "gravitase": "gravita",
    "gravitasem": "gravita",
    "gravitaseră": "gravita",
    "gravitaserăm": "gravita",
    "gravitaserăți": "gravita",
    "gravitaseși": "gravita",
    "gravitași": "gravita",
    "gravitat": "gravita",
    "gravitați": "gravita",
    "gravitatu": "gravita",
    "gravitau": "gravita",
    "gravitează": "gravita",
    "gravitez": "gravita",
    "graviteze": "gravita",
    "gravitezi": "gravita",
    "negravitând": "gravita",
    "negravitându": "gravita",
    "nemaigravitând": "gravita",
    "nemaigravitându": "gravita",
    "gravitată": "gravitat",
    "gravitate": "gravitat",
    "gravitați": "gravitat",
    "gravitatea": "gravitate",
    "gravități": "gravitate",
    "gravității": "gravitate",
    "gravitația": "gravitație",
    "gravitației": "gravitație",
    "gravitații": "gravitație",
    "gravitațiile": "gravitație",
    "gravitațiilor": "gravitație",
    "gravura": "gravură",
    "gravuri": "gravură",
    "gravurii": "gravură",
    "gravurile": "gravură",
    "gravurilor": "gravură",
    "greaca": "greacă",
    "greața": "greață",
    "greți": "greață",
    "greții": "greață",
    "grețuri": "greață",
    "grețurile": "greață",
    "grețurilor": "greață",
    "greblă": "grebla",
    "greblai": "grebla",
    "greblam": "grebla",
    "greblăm": "grebla",
    "greblând": "grebla",
    "greblându": "grebla",
    "greblară": "grebla",
    "greblarăm": "grebla",
    "greblarăți": "grebla",
    "greblase": "grebla",
    "greblasem": "grebla",
    "greblaseră": "grebla",
    "greblaserăm": "grebla",
    "greblaserăți": "grebla",
    "greblaseși": "grebla",
    "greblași": "grebla",
    "greblat": "grebla",
    "greblați": "grebla",
    "greblatu": "grebla",
    "greblau": "grebla",
    "greblează": "grebla",
    "greblez": "grebla",
    "grebleze": "grebla",
    "greblezi": "grebla",
    "negreblând": "grebla",
    "negreblându": "grebla",
    "nemaigreblând": "grebla",
    "nemaigreblându": "grebla",
    "grebla": "greblă",
    "greble": "greblă",
    "greblei": "greblă",
    "greblele": "greblă",
    "greblelor": "greblă",
    "greblată": "greblat",
    "greblate": "greblat",
    "greblați": "greblat",
    "grece": "grec",
    "grecei": "grec",
    "grecele": "grec",
    "grecelor": "grec",
    "greci": "grec",
    "grecii": "grec",
    "grecilor": "grec",
    "grecul": "grec",
    "grecului": "grec",
    "greceasca": "grecesc",
    "grecească": "grecesc",
    "grecescul": "grecesc",
    "grecescului": "grecesc",
    "grecești": "grecesc",
    "greceștii": "grecesc",
    "greceștile": "grecesc",
    "greceștilor": "grecesc",
    "Greciei": "Grecia",
    "greciză": "greciza",
    "grecizai": "greciza",
    "grecizam": "greciza",
    "grecizăm": "greciza",
    "grecizând": "greciza",
    "grecizându": "greciza",
    "grecizară": "greciza",
    "grecizarăm": "greciza",
    "grecizarăți": "greciza",
    "grecizase": "greciza",
    "grecizasem": "greciza",
    "grecizaseră": "greciza",
    "grecizaserăm": "greciza",
    "grecizaserăți": "greciza",
    "grecizaseși": "greciza",
    "grecizași": "greciza",
    "grecizat": "greciza",
    "grecizați": "greciza",
    "grecizatu": "greciza",
    "grecizau": "greciza",
    "grecizează": "greciza",
    "grecizez": "greciza",
    "grecizeze": "greciza",
    "grecizezi": "greciza",
    "negrecizând": "greciza",
    "negrecizându": "greciza",
    "nemaigrecizând": "greciza",
    "nemaigrecizându": "greciza",
    "grecizată": "grecizat",
    "grecizate": "grecizat",
    "grecizați": "grecizat",
    "grecoaica": "grecoaică",
    "grecoaice": "grecoaică",
    "grecoaicei": "grecoaică",
    "grecoaicele": "grecoaică",
    "grecoaicelor": "grecoaică",
    "greco-catolică": "greco-catolic",
    "greco-catolice": "greco-catolic",
    "greco-catolici": "greco-catolic",
    "greco-catolicii": "greco-catolic",
    "greco-catolicilor": "greco-catolic",
    "greco-catolicul": "greco-catolic",
    "greco-catolicule": "greco-catolic",
    "greco-catolicului": "greco-catolic",
    "greco-catolica": "greco-catolică",
    "greco-catolice": "greco-catolică",
    "greco-catolicei": "greco-catolică",
    "greco-catolicele": "greco-catolică",
    "greco-catolicelor": "greco-catolică",
    "greco-catolico": "greco-catolică",
    "grefă": "grefa",
    "grefai": "grefa",
    "grefam": "grefa",
    "grefăm": "grefa",
    "grefând": "grefa",
    "grefându": "grefa",
    "grefară": "grefa",
    "grefarăm": "grefa",
    "grefarăți": "grefa",
    "grefase": "grefa",
    "grefasem": "grefa",
    "grefaseră": "grefa",
    "grefaserăm": "grefa",
    "grefaserăți": "grefa",
    "grefaseși": "grefa",
    "grefași": "grefa",
    "grefat": "grefa",
    "grefați": "grefa",
    "grefatu": "grefa",
    "grefau": "grefa",
    "grefează": "grefa",
    "grefez": "grefa",
    "grefeze": "grefa",
    "grefezi": "grefa",
    "negrefând": "grefa",
    "negrefându": "grefa",
    "negresând": "grefa",
    "negresându": "grefa",
    "nemaigrefând": "grefa",
    "nemaigrefându": "grefa",
    "nemaigresând": "grefa",
    "nemaigresându": "grefa",
    "grefa": "grefă",
    "grefe": "grefă",
    "grefei": "grefă",
    "grefele": "grefă",
    "grefelor": "grefă",
    "grefată": "grefat",
    "grefate": "grefat",
    "grefați": "grefat",
    "grefieri": "grefier",
    "grefierii": "grefier",
    "grefierilor": "grefier",
    "grefierul": "grefier",
    "grefierule": "grefier",
    "grefierului": "grefier",
    "greieri": "greier",
    "greierii": "greier",
    "greierilor": "greier",
    "greierul": "greier",
    "greierului": "greier",
    "grenada": "grenadă",
    "grenade": "grenadă",
    "grenadei": "grenadă",
    "grenadele": "grenadă",
    "grenadelor": "grenadă",
    "greoaia": "greoi",
    "greoaie": "greoi",
    "greoaiei": "greoi",
    "greoaiele": "greoi",
    "greoaielor": "greoi",
    "greoii": "greoi",
    "greoilor": "greoi",
    "greoiul": "greoi",
    "greoiului": "greoi",
    "grepfrutul": "grepfrut",
    "grepfrutului": "grepfrut",
    "grepfruturi": "grepfrut",
    "grepfruturile": "grepfrut",
    "grepfruturilor": "grepfrut",
    "greșul": "greș",
    "greșului": "greș",
    "greșuri": "greș",
    "greșurile": "greș",
    "greșurilor": "greș",
    "gresă": "gresa",
    "gresai": "gresa",
    "gresam": "gresa",
    "gresăm": "gresa",
    "gresând": "gresa",
    "gresându": "gresa",
    "gresară": "gresa",
    "gresarăm": "gresa",
    "gresarăți": "gresa",
    "gresase": "gresa",
    "gresasem": "gresa",
    "gresaseră": "gresa",
    "gresaserăm": "gresa",
    "gresaserăți": "gresa",
    "gresaseși": "gresa",
    "gresași": "gresa",
    "gresat": "gresa",
    "gresați": "gresa",
    "gresatu": "gresa",
    "gresau": "gresa",
    "gresează": "gresa",
    "greseze": "gresa",
    "gresezi": "gresa",
    "negresând": "gresa",
    "negresându": "gresa",
    "nemaigresând": "gresa",
    "nemaigresându": "gresa",
    "gresată": "gresat",
    "gresate": "gresat",
    "gresați": "gresat",
    "greșeala": "greșeală",
    "greșeli": "greșeală",
    "greșelii": "greșeală",
    "greșelile": "greșeală",
    "greșelilor": "greșeală",
    "greșea": "greși",
    "greșeai": "greși",
    "greșeam": "greși",
    "greșească": "greși",
    "greșeați": "greși",
    "greșeau": "greși",
    "greșesc": "greși",
    "greșește": "greși",
    "greșești": "greși",
    "greșii": "greși",
    "greșim": "greși",
    "greșind": "greși",
    "greșindu": "greși",
    "greșiră": "greși",
    "greșirăm": "greși",
    "greșirăți": "greși",
    "greșise": "greși",
    "greșisem": "greși",
    "greșiseră": "greși",
    "greșiserăm": "greși",
    "greșiserăți": "greși",
    "greșiseși": "greși",
    "greșiși": "greși",
    "greșit": "greși",
    "greșiți": "greși",
    "greșitu": "greși",
    "negreșind": "greși",
    "negreșindu": "greși",
    "nemaigreșind": "greși",
    "nemaigreșindu": "greși",
    "gresia": "gresie",
    "gresiei": "gresie",
    "gresii": "gresie",
    "gresiile": "gresie",
    "gresiilor": "gresie",
    "greșita": "greșit",
    "greșită": "greșit",
    "greșite": "greșit",
    "greșitei": "greșit",
    "greșitele": "greșit",
    "greșitelor": "greșit",
    "greșiți": "greșit",
    "greșiții": "greșit",
    "greșiților": "greșit",
    "greșitul": "greșit",
    "greșitului": "greșit",
    "grețoasa": "grețos",
    "grețoasă": "grețos",
    "grețoase": "grețos",
    "grețoasei": "grețos",
    "grețoasele": "grețos",
    "grețoaselor": "grețos",
    "grețoși": "grețos",
    "grețoșii": "grețos",
    "grețoșilor": "grețos",
    "grețosul": "grețos",
    "grețosului": "grețos",
    "grea": "greu",
    "greaua": "greu",
    "grei": "greu",
    "greii": "greu",
    "greilor": "greu",
    "grele": "greu",
    "grelei": "greu",
    "grelele": "greu",
    "grelelor": "greu",
    "greul": "greu",
    "greului": "greu",
    "greut.": "greutate",
    "greutatea": "greutate",
    "greutăți": "greutate",
    "greutății": "greutate",
    "greutățile": "greutate",
    "greutăților": "greutate",
    "grevă": "greva",
    "grevai": "greva",
    "grevam": "greva",
    "grevăm": "greva",
    "grevând": "greva",
    "grevându": "greva",
    "grevară": "greva",
    "grevarăm": "greva",
    "grevarăți": "greva",
    "grevase": "greva",
    "grevasem": "greva",
    "grevaseră": "greva",
    "grevaserăm": "greva",
    "grevaserăți": "greva",
    "grevaseși": "greva",
    "grevași": "greva",
    "grevat": "greva",
    "grevați": "greva",
    "grevatu": "greva",
    "grevau": "greva",
    "grevează": "greva",
    "grevez": "greva",
    "greveze": "greva",
    "grevezi": "greva",
    "negrevând": "greva",
    "negrevându": "greva",
    "nemaigrevând": "greva",
    "nemaigrevându": "greva",
    "greva": "grevă",
    "greve": "grevă",
    "grevei": "grevă",
    "grevele": "grevă",
    "grevelor": "grevă",
    "grevată": "grevat",
    "grevate": "grevat",
    "grevați": "grevat",
    "grevista": "grevist",
    "grevistă": "grevist",
    "greviste": "grevist",
    "grevistei": "grevist",
    "grevistele": "grevist",
    "grevistelor": "grevist",
    "greviști": "grevist",
    "greviștii": "grevist",
    "greviștilor": "grevist",
    "grevisto": "grevist",
    "grevistul": "grevist",
    "grevistule": "grevist",
    "grevistului": "grevist",
    "griul": "gri",
    "griului": "gri",
    "griuri": "gri",
    "griurile": "gri",
    "griurilor": "gri",
    "Gr.": "Grigore",
    "grija": "grijă",
    "griji": "grijă",
    "grijii": "grijă",
    "grijile": "grijă",
    "grijilor": "grijă",
    "grijea": "griji",
    "grijeai": "griji",
    "grijeam": "griji",
    "grijească": "griji",
    "grijeați": "griji",
    "grijeau": "griji",
    "grijesc": "griji",
    "grijește": "griji",
    "grijești": "griji",
    "grijii": "griji",
    "grijim": "griji",
    "grijind": "griji",
    "grijindu": "griji",
    "grijiră": "griji",
    "grijirăm": "griji",
    "grijirăți": "griji",
    "grijise": "griji",
    "grijisem": "griji",
    "grijiseră": "griji",
    "grijiserăm": "griji",
    "grijiserăți": "griji",
    "grijiseși": "griji",
    "grijiși": "griji",
    "grijit": "griji",
    "grijiți": "griji",
    "grijitu": "griji",
    "negrijind": "griji",
    "negrijindu": "griji",
    "nemaigrijind": "griji",
    "nemaigrijindu": "griji",
    "grijită": "grijit",
    "grijite": "grijit",
    "grijiți": "grijit",
    "grijulia": "grijuliu",
    "grijulie": "grijuliu",
    "grijuliei": "grijuliu",
    "grijulii": "grijuliu",
    "grijuliii": "grijuliu",
    "grijuliile": "grijuliu",
    "grijuliilor": "grijuliu",
    "grijuliul": "grijuliu",
    "grijuliului": "grijuliu",
    "grilajul": "grilaj",
    "grilajului": "grilaj",
    "grilajuri": "grilaj",
    "grilajurile": "grilaj",
    "grilajurilor": "grilaj",
    "grimă": "grima",
    "grimai": "grima",
    "grimam": "grima",
    "grimăm": "grima",
    "grimând": "grima",
    "grimându": "grima",
    "grimară": "grima",
    "grimarăm": "grima",
    "grimarăți": "grima",
    "grimase": "grima",
    "grimasem": "grima",
    "grimaseră": "grima",
    "grimaserăm": "grima",
    "grimaserăți": "grima",
    "grimaseși": "grima",
    "grimași": "grima",
    "grimat": "grima",
    "grimați": "grima",
    "grimatu": "grima",
    "grimau": "grima",
    "grimează": "grima",
    "grimez": "grima",
    "grimeze": "grima",
    "grimezi": "grima",
    "negrimând": "grima",
    "negrimându": "grima",
    "nemaigrimând": "grima",
    "nemaigrimându": "grima",
    "grimasa": "grimasă",
    "grimase": "grimasă",
    "grimasei": "grimasă",
    "grimasele": "grimasă",
    "grimaselor": "grimasă",
    "grimată": "grimat",
    "grimate": "grimat",
    "grimați": "grimat",
    "grinda": "grindă",
    "grinzi": "grindă",
    "grinzii": "grindă",
    "grinzile": "grindă",
    "grinzilor": "grindă",
    "grindină": "grindina",
    "grindinând": "grindina",
    "grindinându": "grindina",
    "grindinară": "grindina",
    "grindinase": "grindina",
    "grindinaseră": "grindina",
    "grindinat": "grindina",
    "grindinatu": "grindina",
    "grindinau": "grindina",
    "grindine": "grindina",
    "negrindinând": "grindina",
    "negrindinându": "grindina",
    "nemaigrindinând": "grindina",
    "nemaigrindinându": "grindina",
    "grindina": "grindină",
    "grindini": "grindină",
    "grindinii": "grindină",
    "grindinile": "grindină",
    "grindinilor": "grindină",
    "grindinată": "grindinat",
    "grindinate": "grindinat",
    "grindinați": "grindinat",
    "gripă": "gripa",
    "gripai": "gripa",
    "gripam": "gripa",
    "gripăm": "gripa",
    "gripând": "gripa",
    "gripându": "gripa",
    "gripară": "gripa",
    "griparăm": "gripa",
    "griparăți": "gripa",
    "gripase": "gripa",
    "gripasem": "gripa",
    "gripaseră": "gripa",
    "gripaserăm": "gripa",
    "gripaserăți": "gripa",
    "gripaseși": "gripa",
    "gripași": "gripa",
    "gripat": "gripa",
    "gripați": "gripa",
    "gripatu": "gripa",
    "gripau": "gripa",
    "gripează": "gripa",
    "gripez": "gripa",
    "gripeze": "gripa",
    "gripezi": "gripa",
    "negripând": "gripa",
    "negripându": "gripa",
    "nemaigripând": "gripa",
    "nemaigripându": "gripa",
    "gripa": "gripă",
    "gripe": "gripă",
    "gripei": "gripă",
    "gripele": "gripă",
    "gripelor": "gripă",
    "gripată": "gripat",
    "gripate": "gripat",
    "gripați": "gripat",
    "grișul": "griș",
    "grișului": "griș",
    "Griviței": "Grivița",
    "griză": "griza",
    "grizai": "griza",
    "grizam": "griza",
    "grizăm": "griza",
    "grizând": "griza",
    "grizându": "griza",
    "grizară": "griza",
    "grizarăm": "griza",
    "grizarăți": "griza",
    "grizase": "griza",
    "grizasem": "griza",
    "grizaseră": "griza",
    "grizaserăm": "griza",
    "grizaserăți": "griza",
    "grizaseși": "griza",
    "grizași": "griza",
    "grizat": "griza",
    "grizați": "griza",
    "grizatu": "griza",
    "grizau": "griza",
    "grizează": "griza",
    "grizez": "griza",
    "grizeze": "griza",
    "grizezi": "griza",
    "negrizând": "griza",
    "negrizându": "griza",
    "nemaigrizând": "griza",
    "nemaigrizându": "griza",
    "grizată": "grizat",
    "grizate": "grizat",
    "grizați": "grizat",
    "groapa": "groapă",
    "gropi": "groapă",
    "gropii": "groapă",
    "gropile": "groapă",
    "gropilor": "groapă",
    "groaza": "groază",
    "groaze": "groază",
    "groazei": "groază",
    "groazele": "groază",
    "groazelor": "groază",
    "groazo": "groază",
    "groaznica": "groaznic",
    "groaznică": "groaznic",
    "groaznice": "groaznic",
    "groaznicei": "groaznic",
    "groaznicele": "groaznic",
    "groaznicelor": "groaznic",
    "groaznici": "groaznic",
    "groaznicii": "groaznic",
    "groaznicilor": "groaznic",
    "groaznicul": "groaznic",
    "groaznicului": "groaznic",
    "grohăia": "grohăi",
    "grohăiai": "grohăi",
    "grohăiam": "grohăi",
    "grohăiați": "grohăi",
    "grohăiau": "grohăi",
    "grohăie": "grohăi",
    "grohăii": "grohăi",
    "grohăim": "grohăi",
    "grohăind": "grohăi",
    "grohăindu": "grohăi",
    "grohăiră": "grohăi",
    "grohăirăm": "grohăi",
    "grohăirăți": "grohăi",
    "grohăise": "grohăi",
    "grohăisem": "grohăi",
    "grohăiseră": "grohăi",
    "grohăiserăm": "grohăi",
    "grohăiserăți": "grohăi",
    "grohăiseși": "grohăi",
    "grohăiși": "grohăi",
    "grohăit": "grohăi",
    "grohăiți": "grohăi",
    "grohăitu": "grohăi",
    "negrohăind": "grohăi",
    "negrohăindu": "grohăi",
    "nemaigrohăind": "grohăi",
    "nemaigrohăindu": "grohăi",
    "grohăiala": "grohăială",
    "grohăieli": "grohăială",
    "grohăielii": "grohăială",
    "grohăielile": "grohăială",
    "grohăielilor": "grohăială",
    "grohăită": "grohăit",
    "grohăite": "grohăit",
    "grohăiți": "grohăit",
    "grohăitura": "grohăitură",
    "grohăituri": "grohăitură",
    "grohăiturii": "grohăitură",
    "grohăiturile": "grohăitură",
    "grohăiturilor": "grohăitură",
    "grohăituro": "grohăitură",
    "grohotea": "grohoti",
    "grohoteai": "grohoti",
    "grohoteam": "grohoti",
    "grohotească": "grohoti",
    "grohoteați": "grohoti",
    "grohoteau": "grohoti",
    "grohotesc": "grohoti",
    "grohotește": "grohoti",
    "grohotești": "grohoti",
    "grohotii": "grohoti",
    "grohotim": "grohoti",
    "grohotind": "grohoti",
    "grohotindu": "grohoti",
    "grohotiră": "grohoti",
    "grohotirăm": "grohoti",
    "grohotirăți": "grohoti",
    "grohotise": "grohoti",
    "grohotisem": "grohoti",
    "grohotiseră": "grohoti",
    "grohotiserăm": "grohoti",
    "grohotiserăți": "grohoti",
    "grohotiseși": "grohoti",
    "grohotiși": "grohoti",
    "grohotit": "grohoti",
    "grohotiți": "grohoti",
    "grohotitu": "grohoti",
    "negrohotind": "grohoti",
    "negrohotindu": "grohoti",
    "nemaigrohotind": "grohoti",
    "nemaigrohotindu": "grohoti",
    "grohotită": "grohotit",
    "grohotite": "grohotit",
    "grohotiți": "grohotit",
    "gropari": "gropar",
    "groparii": "gropar",
    "groparilor": "gropar",
    "groparul": "gropar",
    "groparului": "gropar",
    "gropița": "gropiță",
    "gropițe": "gropiță",
    "gropiței": "gropiță",
    "gropițele": "gropiță",
    "gropițelor": "gropiță",
    "groasa": "gros",
    "groasă": "gros",
    "groase": "gros",
    "groasei": "gros",
    "groasele": "gros",
    "groaselor": "gros",
    "groși": "gros",
    "groșii": "gros",
    "groșilor": "gros",
    "grosul": "gros",
    "grosului": "gros",
    "grosimea": "grosime",
    "grosimi": "grosime",
    "grosimii": "grosime",
    "grosimile": "grosime",
    "grosimilor": "grosime",
    "grosolana": "grosolan",
    "grosolană": "grosolan",
    "grosolane": "grosolan",
    "grosolanei": "grosolan",
    "grosolanele": "grosolan",
    "grosolanelor": "grosolan",
    "grosolani": "grosolan",
    "grosolanii": "grosolan",
    "grosolanilor": "grosolan",
    "grosolanul": "grosolan",
    "grosolanului": "grosolan",
    "grosolănia": "grosolănie",
    "grosolăniei": "grosolănie",
    "grosolănii": "grosolănie",
    "grosolăniile": "grosolănie",
    "grosolăniilor": "grosolănie",
    "grota": "grotă",
    "grote": "grotă",
    "grotei": "grotă",
    "grotele": "grotă",
    "grotelor": "grotă",
    "groteasca": "grotesc",
    "grotească": "grotesc",
    "grotescul": "grotesc",
    "grotescului": "grotesc",
    "grotești": "grotesc",
    "groteștii": "grotesc",
    "groteștile": "grotesc",
    "groteștilor": "grotesc",
    "grozava": "grozav",
    "grozavă": "grozav",
    "grozave": "grozav",
    "grozavei": "grozav",
    "grozavele": "grozav",
    "grozavelor": "grozav",
    "grozavi": "grozav",
    "grozavii": "grozav",
    "grozavilor": "grozav",
    "grozavul": "grozav",
    "grozavului": "grozav",
    "Grozăveștiul": "Grozăvești",
    "Grozăveștiului": "Grozăvești",
    "grozăvea": "grozăvi",
    "grozăveai": "grozăvi",
    "grozăveam": "grozăvi",
    "grozăvească": "grozăvi",
    "grozăveați": "grozăvi",
    "grozăveau": "grozăvi",
    "grozăvesc": "grozăvi",
    "grozăvește": "grozăvi",
    "grozăvești": "grozăvi",
    "grozăvii": "grozăvi",
    "grozăvim": "grozăvi",
    "grozăvind": "grozăvi",
    "grozăvindu": "grozăvi",
    "grozăviră": "grozăvi",
    "grozăvirăm": "grozăvi",
    "grozăvirăți": "grozăvi",
    "grozăvise": "grozăvi",
    "grozăvisem": "grozăvi",
    "grozăviseră": "grozăvi",
    "grozăviserăm": "grozăvi",
    "grozăviserăți": "grozăvi",
    "grozăviseși": "grozăvi",
    "grozăviși": "grozăvi",
    "grozăvit": "grozăvi",
    "grozăviți": "grozăvi",
    "grozăvitu": "grozăvi",
    "negrozăvind": "grozăvi",
    "negrozăvindu": "grozăvi",
    "nemaigrozăvind": "grozăvi",
    "nemaigrozăvindu": "grozăvi",
    "grozăvia": "grozăvie",
    "grozăviei": "grozăvie",
    "grozăvii": "grozăvie",
    "grozăviile": "grozăvie",
    "grozăviilor": "grozăvie",
    "grozăvită": "grozăvit",
    "grozăvite": "grozăvit",
    "grozăviți": "grozăvit",
    "grumaji": "grumaz",
    "grumajii": "grumaz",
    "grumajilor": "grumaz",
    "grumazul": "grumaz",
    "grumazului": "grumaz",
    "grumazuri": "grumaz",
    "grumazurile": "grumaz",
    "grumazurilor": "grumaz",
    "grunduia": "grundui",
    "grunduiai": "grundui",
    "grunduiam": "grundui",
    "grunduiască": "grundui",
    "grunduiați": "grundui",
    "grunduiau": "grundui",
    "grunduiesc": "grundui",
    "grunduiește": "grundui",
    "grunduiești": "grundui",
    "grunduii": "grundui",
    "grunduim": "grundui",
    "grunduind": "grundui",
    "grunduindu": "grundui",
    "grunduiră": "grundui",
    "grunduirăm": "grundui",
    "grunduirăți": "grundui",
    "grunduise": "grundui",
    "grunduisem": "grundui",
    "grunduiseră": "grundui",
    "grunduiserăm": "grundui",
    "grunduiserăți": "grundui",
    "grunduiseși": "grundui",
    "grunduiși": "grundui",
    "grunduit": "grundui",
    "grunduiți": "grundui",
    "grunduitu": "grundui",
    "negrunduind": "grundui",
    "negrunduindu": "grundui",
    "nemaigrunduind": "grundui",
    "nemaigrunduindu": "grundui",
    "grunduită": "grunduit",
    "grunduite": "grunduit",
    "grunduiți": "grunduit",
    "grunjoasa": "grunjos",
    "grunjoasă": "grunjos",
    "grunjoase": "grunjos",
    "grunjoasei": "grunjos",
    "grunjoasele": "grunjos",
    "grunjoaselor": "grunjos",
    "grunjoși": "grunjos",
    "grunjoșii": "grunjos",
    "grunjoșilor": "grunjos",
    "grunjosul": "grunjos",
    "grunjosului": "grunjos",
    "grujilor": "grunz",
    "grunji": "grunz",
    "grunjii": "grunz",
    "grunzul": "grunz",
    "grunzului": "grunz",
    "grupul": "grup",
    "grupului": "grup",
    "grupuri": "grup",
    "grupurile": "grup",
    "grupurilor": "grup",
    "grupă": "grupa",
    "grupai": "grupa",
    "grupam": "grupa",
    "grupăm": "grupa",
    "grupând": "grupa",
    "grupându": "grupa",
    "grupară": "grupa",
    "gruparăm": "grupa",
    "gruparăți": "grupa",
    "grupase": "grupa",
    "grupasem": "grupa",
    "grupaseră": "grupa",
    "grupaserăm": "grupa",
    "grupaserăți": "grupa",
    "grupaseși": "grupa",
    "grupași": "grupa",
    "grupat": "grupa",
    "grupați": "grupa",
    "grupatu": "grupa",
    "grupau": "grupa",
    "grupează": "grupa",
    "grupez": "grupa",
    "grupeze": "grupa",
    "grupezi": "grupa",
    "negrupând": "grupa",
    "negrupându": "grupa",
    "nemaigrupând": "grupa",
    "nemaigrupându": "grupa",
    "grupa": "grupă",
    "grupe": "grupă",
    "grupei": "grupă",
    "grupele": "grupă",
    "grupelor": "grupă",
    "grupaje": "grupaj",
    "grupajele": "grupaj",
    "grupajelor": "grupaj",
    "grupajul": "grupaj",
    "grupajule": "grupaj",
    "grupajului": "grupaj",
    "gruparea": "grupare",
    "grupări": "grupare",
    "grupării": "grupare",
    "grupările": "grupare",
    "grupărilor": "grupare",
    "grupată": "grupat",
    "grupate": "grupat",
    "grupați": "grupat",
    "GPL": "Grupul_Parlamentar_Liberal",
    "gubernia": "gubernie",
    "guberniei": "gubernie",
    "gubernii": "gubernie",
    "guberniile": "gubernie",
    "guberniilor": "gubernie",
    "gubernio": "gubernie",
    "gudroane": "gudron",
    "gudroanele": "gudron",
    "gudroanelor": "gudron",
    "gudronul": "gudron",
    "gudronului": "gudron",
    "gudronă": "gudrona",
    "gudronai": "gudrona",
    "gudronam": "gudrona",
    "gudronăm": "gudrona",
    "gudronând": "gudrona",
    "gudronându": "gudrona",
    "gudronară": "gudrona",
    "gudronarăm": "gudrona",
    "gudronarăți": "gudrona",
    "gudronase": "gudrona",
    "gudronasem": "gudrona",
    "gudronaseră": "gudrona",
    "gudronaserăm": "gudrona",
    "gudronaserăți": "gudrona",
    "gudronaseși": "gudrona",
    "gudronași": "gudrona",
    "gudronat": "gudrona",
    "gudronați": "gudrona",
    "gudronatu": "gudrona",
    "gudronau": "gudrona",
    "gudronează": "gudrona",
    "gudronez": "gudrona",
    "gudroneze": "gudrona",
    "gudronezi": "gudrona",
    "negudronând": "gudrona",
    "negudronându": "gudrona",
    "nemaigudronând": "gudrona",
    "nemaigudronându": "gudrona",
    "gudronata": "gudronat",
    "gudronată": "gudronat",
    "gudronate": "gudronat",
    "gudronatei": "gudronat",
    "gudronatele": "gudronat",
    "gudronatelor": "gudronat",
    "gudronați": "gudronat",
    "gudronații": "gudronat",
    "gudronaților": "gudronat",
    "gudronatul": "gudronat",
    "gudronatului": "gudronat",
    "gudur": "gudura",
    "gudură": "gudura",
    "gudurai": "gudura",
    "guduram": "gudura",
    "gudurăm": "gudura",
    "gudurând": "gudura",
    "gudurându": "gudura",
    "gudurară": "gudura",
    "gudurarăm": "gudura",
    "gudurarăți": "gudura",
    "gudurase": "gudura",
    "gudurasem": "gudura",
    "guduraseră": "gudura",
    "guduraserăm": "gudura",
    "guduraserăți": "gudura",
    "guduraseși": "gudura",
    "gudurași": "gudura",
    "gudurat": "gudura",
    "gudurați": "gudura",
    "guduratu": "gudura",
    "gudurau": "gudura",
    "gudure": "gudura",
    "guduri": "gudura",
    "negudurând": "gudura",
    "negudurându": "gudura",
    "nemaigudurând": "gudura",
    "nemaigudurându": "gudura",
    "gudurată": "gudurat",
    "gudurate": "gudurat",
    "gudurați": "gudurat",
    "guiț": "guița",
    "guiță": "guița",
    "guițai": "guița",
    "guițam": "guița",
    "guițăm": "guița",
    "guițând": "guița",
    "guițându": "guița",
    "guițară": "guița",
    "guițarăm": "guița",
    "guițarăți": "guița",
    "guițase": "guița",
    "guițasem": "guița",
    "guițaseră": "guița",
    "guițaserăm": "guița",
    "guițaserăți": "guița",
    "guițaseși": "guița",
    "guițași": "guița",
    "guițat": "guița",
    "guițați": "guița",
    "guițatu": "guița",
    "guițau": "guița",
    "guițe": "guița",
    "guiți": "guița",
    "neguițând": "guița",
    "neguițându": "guița",
    "nemaiguițând": "guița",
    "nemaiguițându": "guița",
    "guițată": "guițat",
    "guițate": "guițat",
    "guițați": "guițat",
    "guițatul": "guițat",
    "guițatului": "guițat",
    "guițături": "guițat",
    "guițăturile": "guițat",
    "guițăturilor": "guițat",
    "gulașul": "gulaș",
    "gulașului": "gulaș",
    "gulere": "guler",
    "gulerele": "guler",
    "gulerelor": "guler",
    "gulerul": "guler",
    "gulerului": "guler",
    "gulia": "gulie",
    "guliei": "gulie",
    "gulii": "gulie",
    "guliile": "gulie",
    "guliilor": "gulie",
    "gumă": "guma",
    "gumai": "guma",
    "gumam": "guma",
    "gumăm": "guma",
    "gumând": "guma",
    "gumându": "guma",
    "gumară": "guma",
    "gumarăm": "guma",
    "gumarăți": "guma",
    "gumase": "guma",
    "gumasem": "guma",
    "gumaseră": "guma",
    "gumaserăm": "guma",
    "gumaserăți": "guma",
    "gumaseși": "guma",
    "gumași": "guma",
    "gumat": "guma",
    "gumați": "guma",
    "gumatu": "guma",
    "gumau": "guma",
    "gumează": "guma",
    "gumez": "guma",
    "gumeze": "guma",
    "gumezi": "guma",
    "negumând": "guma",
    "negumându": "guma",
    "nemaigumând": "guma",
    "nemaigumându": "guma",
    "guma": "gumă",
    "gume": "gumă",
    "gumei": "gumă",
    "gumele": "gumă",
    "gumelor": "gumă",
    "gumată": "gumat",
    "gumate": "gumat",
    "gumați": "gumat",
    "gunoaie": "gunoi",
    "gunoaiele": "gunoi",
    "gunoaielor": "gunoi",
    "gunoia": "gunoi",
    "gunoiai": "gunoi",
    "gunoiam": "gunoi",
    "gunoiască": "gunoi",
    "gunoiați": "gunoi",
    "gunoiau": "gunoi",
    "gunoiesc": "gunoi",
    "gunoiește": "gunoi",
    "gunoiești": "gunoi",
    "gunoii": "gunoi",
    "gunoim": "gunoi",
    "gunoind": "gunoi",
    "gunoindu": "gunoi",
    "gunoiră": "gunoi",
    "gunoirăm": "gunoi",
    "gunoirăți": "gunoi",
    "gunoise": "gunoi",
    "gunoisem": "gunoi",
    "gunoiseră": "gunoi",
    "gunoiserăm": "gunoi",
    "gunoiserăți": "gunoi",
    "gunoiseși": "gunoi",
    "gunoiși": "gunoi",
    "gunoit": "gunoi",
    "gunoiți": "gunoi",
    "gunoitu": "gunoi",
    "gunoiul": "gunoi",
    "gunoiului": "gunoi",
    "negunoind": "gunoi",
    "negunoindu": "gunoi",
    "nemaigunoind": "gunoi",
    "nemaigunoindu": "gunoi",
    "gunoieri": "gunoier",
    "gunoierii": "gunoier",
    "gunoierilor": "gunoier",
    "gunoierul": "gunoier",
    "gunoierului": "gunoier",
    "gunoită": "gunoit",
    "gunoite": "gunoit",
    "gunoiți": "gunoit",
    "gura": "gură",
    "guri": "gură",
    "gurii": "gură",
    "gurile": "gură",
    "gurilor": "gură",
    "gura-de-lup": "gură-de-lup",
    "guri-de-lup": "gură-de-lup",
    "gurii-de-lup": "gură-de-lup",
    "gurile-de-lup": "gură-de-lup",
    "gurilor-de-lup": "gură-de-lup",
    "gurăia": "gurăi",
    "gurăiai": "gurăi",
    "gurăiam": "gurăi",
    "gurăiați": "gurăi",
    "gurăiau": "gurăi",
    "gurăie": "gurăi",
    "gurăii": "gurăi",
    "gurăim": "gurăi",
    "gurăind": "gurăi",
    "gurăindu": "gurăi",
    "gurăiră": "gurăi",
    "gurăirăm": "gurăi",
    "gurăirăți": "gurăi",
    "gurăise": "gurăi",
    "gurăisem": "gurăi",
    "gurăiseră": "gurăi",
    "gurăiserăm": "gurăi",
    "gurăiserăți": "gurăi",
    "gurăiseși": "gurăi",
    "gurăiși": "gurăi",
    "gurăit": "gurăi",
    "gurăiți": "gurăi",
    "gurăitu": "gurăi",
    "negurăind": "gurăi",
    "negurăindu": "gurăi",
    "nemaigurăind": "gurăi",
    "nemaigurăindu": "gurăi",
    "gurăită": "gurăit",
    "gurăite": "gurăit",
    "gurăiți": "gurăit",
    "gurii-leului": "gura-leului",
    "guraliva": "guraliv",
    "guralivă": "guraliv",
    "guralive": "guraliv",
    "guralivei": "guraliv",
    "guralivele": "guraliv",
    "guralivelor": "guraliv",
    "guralivi": "guraliv",
    "guralivii": "guraliv",
    "guralivilor": "guraliv",
    "guralivul": "guraliv",
    "guralivului": "guraliv",
    "gurii-lupului": "gura-lupului",
    "gurguiai": "gurguia",
    "gurguiam": "gurguia",
    "gurguiară": "gurguia",
    "gurguiarăm": "gurguia",
    "gurguiarăți": "gurguia",
    "gurguiase": "gurguia",
    "gurguiasem": "gurguia",
    "gurguiaseră": "gurguia",
    "gurguiaserăm": "gurguia",
    "gurguiaserăți": "gurguia",
    "gurguiaseși": "gurguia",
    "gurguiași": "gurguia",
    "gurguiat": "gurguia",
    "gurguiați": "gurguia",
    "gurguiatu": "gurguia",
    "gurguiau": "gurguia",
    "gurguiază": "gurguia",
    "gurguie": "gurguia",
    "gurguiem": "gurguia",
    "gurguiez": "gurguia",
    "gurguieze": "gurguia",
    "gurguiezi": "gurguia",
    "gurguiind": "gurguia",
    "gurguiindu": "gurguia",
    "negurguiind": "gurguia",
    "negurguiindu": "gurguia",
    "nemaigurguiind": "gurguia",
    "nemaigurguiindu": "gurguia",
    "gurguiată": "gurguiat",
    "gurguiate": "gurguiat",
    "gurguiați": "gurguiat",
    "gurluia": "gurlui",
    "gurluiai": "gurlui",
    "gurluiam": "gurlui",
    "gurluiați": "gurlui",
    "gurluiau": "gurlui",
    "gurluie": "gurlui",
    "gurluii": "gurlui",
    "gurluim": "gurlui",
    "gurluind": "gurlui",
    "gurluindu": "gurlui",
    "gurluiră": "gurlui",
    "gurluirăm": "gurlui",
    "gurluirăți": "gurlui",
    "gurluise": "gurlui",
    "gurluisem": "gurlui",
    "gurluiseră": "gurlui",
    "gurluiserăm": "gurlui",
    "gurluiserăți": "gurlui",
    "gurluiseși": "gurlui",
    "gurluiși": "gurlui",
    "gurluit": "gurlui",
    "gurluiți": "gurlui",
    "gurluitu": "gurlui",
    "negurluind": "gurlui",
    "negurluindu": "gurlui",
    "nemaigurluind": "gurlui",
    "nemaigurluindu": "gurlui",
    "gurluită": "gurluit",
    "gurluite": "gurluit",
    "gurluiți": "gurluit",
    "gurul": "guru",
    "gurule": "guru",
    "gurului": "guru",
    "gușa": "gușă",
    "guși": "gușă",
    "gușii": "gușă",
    "gușile": "gușă",
    "gușilor": "gușă",
    "gușei-porumbelului": "gușa-porumbelului",
    "gușata": "gușat",
    "gușată": "gușat",
    "gușate": "gușat",
    "gușatei": "gușat",
    "gușatele": "gușat",
    "gușatelor": "gușat",
    "gușați": "gușat",
    "gușații": "gușat",
    "gușaților": "gușat",
    "gușatul": "gușat",
    "gușatului": "gușat",
    "gustul": "gust",
    "gustului": "gust",
    "gusturi": "gust",
    "gusturile": "gust",
    "gusturilor": "gust",
    "gust": "gusta",
    "gustă": "gusta",
    "gustai": "gusta",
    "gustam": "gusta",
    "gustăm": "gusta",
    "gustând": "gusta",
    "gustându": "gusta",
    "gustară": "gusta",
    "gustarăm": "gusta",
    "gustarăți": "gusta",
    "gustase": "gusta",
    "gustasem": "gusta",
    "gustaseră": "gusta",
    "gustaserăm": "gusta",
    "gustaserăți": "gusta",
    "gustaseși": "gusta",
    "gustași": "gusta",
    "gustat": "gusta",
    "gustați": "gusta",
    "gustatu": "gusta",
    "gustau": "gusta",
    "guste": "gusta",
    "guști": "gusta",
    "negustând": "gusta",
    "negustându": "gusta",
    "nemaigustând": "gusta",
    "nemaigustându": "gusta",
    "gustarea": "gustare",
    "gustări": "gustare",
    "gustării": "gustare",
    "gustările": "gustare",
    "gustărilor": "gustare",
    "gustată": "gustat",
    "gustate": "gustat",
    "gustați": "gustat",
    "gușteri": "gușter",
    "gușterii": "gușter",
    "gușterilor": "gușter",
    "gușterul": "gușter",
    "gușterului": "gușter",
    "gustoasa": "gustos",
    "gustoasă": "gustos",
    "gustoase": "gustos",
    "gustoasei": "gustos",
    "gustoasele": "gustos",
    "gustoaselor": "gustos",
    "gustoși": "gustos",
    "gustoșii": "gustos",
    "gustoșilor": "gustos",
    "gustosul": "gustos",
    "gustosului": "gustos",
    "guta": "gută",
    "gutuii": "gutui",
    "gutuilor": "gutui",
    "gutuiul": "gutui",
    "gutuiului": "gutui",
    "gutui": "gutuie",
    "gutuia": "gutuie",
    "gutuii": "gutuie",
    "gutuile": "gutuie",
    "gutuilor": "gutuie",
    "guturaiul": "guturai",
    "guturaiului": "guturai",
    "guturaiuri": "guturai",
    "guturaiurile": "guturai",
    "guturaiurilor": "guturai",
    "guverne": "guvern",
    "guvernele": "guvern",
    "guvernelor": "guvern",
    "guvernu'": "guvern",
    "guvernul": "guvern",
    "guvernului": "guvern",
    "guvernă": "guverna",
    "guvernai": "guverna",
    "guvernam": "guverna",
    "guvernăm": "guverna",
    "guvernând": "guverna",
    "guvernându": "guverna",
    "guvernară": "guverna",
    "guvernarăm": "guverna",
    "guvernarăți": "guverna",
    "guvernase": "guverna",
    "guvernasem": "guverna",
    "guvernaseră": "guverna",
    "guvernaserăm": "guverna",
    "guvernaserăți": "guverna",
    "guvernaseși": "guverna",
    "guvernași": "guverna",
    "guvernat": "guverna",
    "guvernați": "guverna",
    "guvernatu": "guverna",
    "guvernau": "guverna",
    "guvernează": "guverna",
    "guvernez": "guverna",
    "guverneze": "guverna",
    "guvernezi": "guverna",
    "neguvernând": "guverna",
    "neguvernându": "guverna",
    "nemaiguvernând": "guverna",
    "nemaiguvernându": "guverna",
    "guvernământul": "guvernământ",
    "guvernământului": "guvernământ",
    "guvernăminte": "guvernământ",
    "guvernămintele": "guvernământ",
    "guvernămintelor": "guvernământ",
    "guvernamentala": "guvernamental",
    "guvernamentală": "guvernamental",
    "guvernamentale": "guvernamental",
    "guvernamentalei": "guvernamental",
    "guvernamentalele": "guvernamental",
    "guvernamentalelor": "guvernamental",
    "guvernamentali": "guvernamental",
    "guvernamentalii": "guvernamental",
    "guvernamentalilor": "guvernamental",
    "guvernamentalul": "guvernamental",
    "guvernamentalului": "guvernamental",
    "guvernanta": "guvernant",
    "guvernantă": "guvernant",
    "guvernante": "guvernant",
    "guvernantei": "guvernant",
    "guvernantele": "guvernant",
    "guvernantelor": "guvernant",
    "guvernanți": "guvernant",
    "guvernanții": "guvernant",
    "guvernanților": "guvernant",
    "guvernanto": "guvernant",
    "guvernantul": "guvernant",
    "guvernantule": "guvernant",
    "guvernantului": "guvernant",
    "guvernanta": "guvernantă",
    "guvernante": "guvernantă",
    "guvernantei": "guvernantă",
    "guvernantele": "guvernantă",
    "guvernantelor": "guvernantă",
    "guvernarea": "guvernare",
    "guvernareo": "guvernare",
    "guvernări": "guvernare",
    "guvernării": "guvernare",
    "guvernările": "guvernare",
    "guvernărilor": "guvernare",
    "guvernată": "guvernat",
    "guvernate": "guvernat",
    "guvernați": "guvernat",
    "guvernatori": "guvernator",
    "guvernatorii": "guvernator",
    "guvernatorilor": "guvernator",
    "guvernatorul": "guvernator",
    "guvernatorule": "guvernator",
    "guvernatorului": "guvernator",
    "guzgani": "guzgan",
    "guzganii": "guzgan",
    "guzganilor": "guzgan",
    "guzganul": "guzgan",
    "guzganului": "guzgan",
    "habarul": "habar",
    "habarului": "habar",
    "hăbăucea": "hăbăuci",
    "hăbăuceai": "hăbăuci",
    "hăbăuceam": "hăbăuci",
    "hăbăucească": "hăbăuci",
    "hăbăuceați": "hăbăuci",
    "hăbăuceau": "hăbăuci",
    "hăbăucesc": "hăbăuci",
    "hăbăucește": "hăbăuci",
    "hăbăucești": "hăbăuci",
    "hăbăucii": "hăbăuci",
    "hăbăucim": "hăbăuci",
    "hăbăucind": "hăbăuci",
    "hăbăucindu": "hăbăuci",
    "hăbăuciră": "hăbăuci",
    "hăbăucirăm": "hăbăuci",
    "hăbăucirăți": "hăbăuci",
    "hăbăucise": "hăbăuci",
    "hăbăucisem": "hăbăuci",
    "hăbăuciseră": "hăbăuci",
    "hăbăuciserăm": "hăbăuci",
    "hăbăuciserăți": "hăbăuci",
    "hăbăuciseși": "hăbăuci",
    "hăbăuciși": "hăbăuci",
    "hăbăucit": "hăbăuci",
    "hăbăuciți": "hăbăuci",
    "hăbăucitu": "hăbăuci",
    "nehăbăucind": "hăbăuci",
    "nehăbăucindu": "hăbăuci",
    "nemaihăbăucind": "hăbăuci",
    "nemaihăbăucindu": "hăbăuci",
    "hăbăucită": "hăbăucit",
    "hăbăucite": "hăbăucit",
    "hăbăuciți": "hăbăucit",
    "habotnica": "habotnic",
    "habotnică": "habotnic",
    "habotnice": "habotnic",
    "habotnicei": "habotnic",
    "habotnicele": "habotnic",
    "habotnicelor": "habotnic",
    "habotnici": "habotnic",
    "habotnicii": "habotnic",
    "habotnicilor": "habotnic",
    "habotnicul": "habotnic",
    "habotnicului": "habotnic",
    "habsburgica": "habsburgic",
    "habsburgică": "habsburgic",
    "habsburgice": "habsburgic",
    "habsburgicei": "habsburgic",
    "habsburgicele": "habsburgic",
    "habsburgicelor": "habsburgic",
    "habsburgici": "habsburgic",
    "habsburgicii": "habsburgic",
    "habsburgicilor": "habsburgic",
    "habsburgicul": "habsburgic",
    "habsburgicului": "habsburgic",
    "hăbucea": "hăbuci",
    "hăbuceai": "hăbuci",
    "hăbuceam": "hăbuci",
    "hăbucească": "hăbuci",
    "hăbuceați": "hăbuci",
    "hăbuceau": "hăbuci",
    "hăbucesc": "hăbuci",
    "hăbucește": "hăbuci",
    "hăbucești": "hăbuci",
    "hăbucii": "hăbuci",
    "hăbucim": "hăbuci",
    "hăbucind": "hăbuci",
    "hăbucindu": "hăbuci",
    "hăbuciră": "hăbuci",
    "hăbucirăm": "hăbuci",
    "hăbucirăți": "hăbuci",
    "hăbucise": "hăbuci",
    "hăbucisem": "hăbuci",
    "hăbuciseră": "hăbuci",
    "hăbuciserăm": "hăbuci",
    "hăbuciserăți": "hăbuci",
    "hăbuciseși": "hăbuci",
    "hăbuciși": "hăbuci",
    "hăbucit": "hăbuci",
    "hăbuciți": "hăbuci",
    "hăbucitu": "hăbuci",
    "nehăbucind": "hăbuci",
    "nehăbucindu": "hăbuci",
    "nemaihăbucind": "hăbuci",
    "nemaihăbucindu": "hăbuci",
    "hăbucită": "hăbucit",
    "hăbucite": "hăbucit",
    "hăbuciți": "hăbucit",
    "h.n.": "hac_nocte",
    "hâcâia": "hâcâi",
    "hâcâiai": "hâcâi",
    "hâcâiam": "hâcâi",
    "hâcâiați": "hâcâi",
    "hâcâiau": "hâcâi",
    "hâcâie": "hâcâi",
    "hâcâii": "hâcâi",
    "hâcâim": "hâcâi",
    "hâcâind": "hâcâi",
    "hâcâindu": "hâcâi",
    "hâcâiră": "hâcâi",
    "hâcâirăm": "hâcâi",
    "hâcâirăți": "hâcâi",
    "hâcâise": "hâcâi",
    "hâcâisem": "hâcâi",
    "hâcâiseră": "hâcâi",
    "hâcâiserăm": "hâcâi",
    "hâcâiserăți": "hâcâi",
    "hâcâiseși": "hâcâi",
    "hâcâiși": "hâcâi",
    "hâcâit": "hâcâi",
    "hâcâiți": "hâcâi",
    "hâcâitu": "hâcâi",
    "nehâcâind": "hâcâi",
    "nehâcâindu": "hâcâi",
    "nemaihâcâind": "hâcâi",
    "nemaihâcâindu": "hâcâi",
    "hâcâită": "hâcâit",
    "hâcâite": "hâcâit",
    "hâcâiți": "hâcâit",
    "hăcuia": "hăcui",
    "hăcuiai": "hăcui",
    "hăcuiam": "hăcui",
    "hăcuiască": "hăcui",
    "hăcuiați": "hăcui",
    "hăcuiau": "hăcui",
    "hăcuiesc": "hăcui",
    "hăcuiește": "hăcui",
    "hăcuiești": "hăcui",
    "hăcuii": "hăcui",
    "hăcuim": "hăcui",
    "hăcuind": "hăcui",
    "hăcuindu": "hăcui",
    "hăcuiră": "hăcui",
    "hăcuirăm": "hăcui",
    "hăcuirăți": "hăcui",
    "hăcuise": "hăcui",
    "hăcuisem": "hăcui",
    "hăcuiseră": "hăcui",
    "hăcuiserăm": "hăcui",
    "hăcuiserăți": "hăcui",
    "hăcuiseși": "hăcui",
    "hăcuiși": "hăcui",
    "hăcuit": "hăcui",
    "hăcuiți": "hăcui",
    "hăcuitu": "hăcui",
    "nehăcuind": "hăcui",
    "nehăcuindu": "hăcui",
    "nemaihăcuind": "hăcui",
    "nemaihăcuindu": "hăcui",
    "hăcuită": "hăcuit",
    "hăcuite": "hăcuit",
    "hăcuiți": "hăcuit",
    "hâda": "hâd",
    "hâdă": "hâd",
    "hâde": "hâd",
    "hâdei": "hâd",
    "hâdele": "hâd",
    "hâdelor": "hâd",
    "hâdul": "hâd",
    "hâdului": "hâd",
    "hâzi": "hâd",
    "hâzii": "hâd",
    "hâzilor": "hâd",
    "Hădăreniul": "Hădăreni",
    "Hădăreniului": "Hădăreni",
    "Hadesul": "Hades",
    "Hadesului": "Hades",
    "Hagieniul": "Hagieni",
    "Hagieniului": "Hagieni",
    "hâia": "hâi",
    "hâiai": "hâi",
    "hâiam": "hâi",
    "hâiască": "hâi",
    "hâiați": "hâi",
    "hâiau": "hâi",
    "hâiesc": "hâi",
    "hâiește": "hâi",
    "hâiești": "hâi",
    "hâii": "hâi",
    "hâim": "hâi",
    "hâind": "hâi",
    "hâindu": "hâi",
    "hâiră": "hâi",
    "hâirăm": "hâi",
    "hâirăți": "hâi",
    "hâise": "hâi",
    "hâisem": "hâi",
    "hâiseră": "hâi",
    "hâiserăm": "hâi",
    "hâiserăți": "hâi",
    "hâiseși": "hâi",
    "hâiși": "hâi",
    "hâit": "hâi",
    "hâiți": "hâi",
    "hâitu": "hâi",
    "nehâind": "hâi",
    "nehâindu": "hâi",
    "nemaihâind": "hâi",
    "nemaihâindu": "hâi",
    "hăia": "hăi",
    "hăiai": "hăi",
    "hăiam": "hăi",
    "hăiască": "hăi",
    "hăiați": "hăi",
    "hăiau": "hăi",
    "hăiesc": "hăi",
    "hăiește": "hăi",
    "hăiești": "hăi",
    "hăii": "hăi",
    "hăim": "hăi",
    "hăind": "hăi",
    "hăindu": "hăi",
    "hăiră": "hăi",
    "hăirăm": "hăi",
    "hăirăți": "hăi",
    "hăise": "hăi",
    "hăisem": "hăi",
    "hăiseră": "hăi",
    "hăiserăm": "hăi",
    "hăiserăți": "hăi",
    "hăiseși": "hăi",
    "hăiși": "hăi",
    "hăit": "hăi",
    "hăiți": "hăi",
    "hăitu": "hăi",
    "nehăind": "hăi",
    "nehăindu": "hăi",
    "nemaihăind": "hăi",
    "nemaihăindu": "hăi",
    "haidamaci": "haidamac",
    "haidamacii": "haidamac",
    "haidamacilor": "haidamac",
    "haidamacul": "haidamac",
    "haidamacule": "haidamac",
    "haidamacului": "haidamac",
    "haiduci": "haiduc",
    "haiducii": "haiduc",
    "haiducilor": "haiduc",
    "haiducul": "haiduc",
    "haiducului": "haiduc",
    "haiducea": "haiduci",
    "haiduceai": "haiduci",
    "haiduceam": "haiduci",
    "haiducească": "haiduci",
    "haiduceați": "haiduci",
    "haiduceau": "haiduci",
    "haiducesc": "haiduci",
    "haiducește": "haiduci",
    "haiducești": "haiduci",
    "haiducii": "haiduci",
    "haiducim": "haiduci",
    "haiducind": "haiduci",
    "haiducindu": "haiduci",
    "haiduciră": "haiduci",
    "haiducirăm": "haiduci",
    "haiducirăți": "haiduci",
    "haiducise": "haiduci",
    "haiducisem": "haiduci",
    "haiduciseră": "haiduci",
    "haiduciserăm": "haiduci",
    "haiduciserăți": "haiduci",
    "haiduciseși": "haiduci",
    "haiduciși": "haiduci",
    "haiducit": "haiduci",
    "haiduciți": "haiduci",
    "haiducitu": "haiduci",
    "nehaiducind": "haiduci",
    "nehaiducindu": "haiduci",
    "nemaihaiducind": "haiduci",
    "nemaihaiducindu": "haiduci",
    "haiducia": "haiducie",
    "haiduciei": "haiducie",
    "haiducii": "haiducie",
    "haiduciile": "haiducie",
    "haiduciilor": "haiducie",
    "haiducită": "haiducit",
    "haiducite": "haiducit",
    "haiduciți": "haiducit",
    "haimanale": "haimana",
    "haimanalei": "haimana",
    "haimanalele": "haimana",
    "haimanalelor": "haimana",
    "haimanaua": "haimana",
    "hăimănea": "hăimăni",
    "hăimăneai": "hăimăni",
    "hăimăneam": "hăimăni",
    "hăimănească": "hăimăni",
    "hăimăneați": "hăimăni",
    "hăimăneau": "hăimăni",
    "hăimănesc": "hăimăni",
    "hăimănește": "hăimăni",
    "hăimănești": "hăimăni",
    "hăimănii": "hăimăni",
    "hăimănim": "hăimăni",
    "hăimănind": "hăimăni",
    "hăimănindu": "hăimăni",
    "hăimăniră": "hăimăni",
    "hăimănirăm": "hăimăni",
    "hăimănirăți": "hăimăni",
    "hăimănise": "hăimăni",
    "hăimănisem": "hăimăni",
    "hăimăniseră": "hăimăni",
    "hăimăniserăm": "hăimăni",
    "hăimăniserăți": "hăimăni",
    "hăimăniseși": "hăimăni",
    "hăimăniși": "hăimăni",
    "hăimănit": "hăimăni",
    "hăimăniți": "hăimăni",
    "hăimănitu": "hăimăni",
    "nehăimănind": "hăimăni",
    "nehăimănindu": "hăimăni",
    "nemaihăimănind": "hăimăni",
    "nemaihăimănindu": "hăimăni",
    "hăimănită": "hăimănit",
    "hăimănite": "hăimănit",
    "hăimăniți": "hăimănit",
    "haina": "hain",
    "haină": "hain",
    "haine": "hain",
    "hainei": "hain",
    "hainele": "hain",
    "hainelor": "hain",
    "haini": "hain",
    "hainii": "hain",
    "hainilor": "hain",
    "hainul": "hain",
    "hainului": "hain",
    "haina": "haină",
    "haine": "haină",
    "hainei": "haină",
    "hainele": "haină",
    "hainelor": "haină",
    "hainea": "haini",
    "haineai": "haini",
    "haineam": "haini",
    "hainească": "haini",
    "haineați": "haini",
    "haineau": "haini",
    "hainesc": "haini",
    "hainește": "haini",
    "hainești": "haini",
    "hainii": "haini",
    "hainim": "haini",
    "hainind": "haini",
    "hainindu": "haini",
    "hainiră": "haini",
    "hainirăm": "haini",
    "hainirăți": "haini",
    "hainise": "haini",
    "hainisem": "haini",
    "hainiseră": "haini",
    "hainiserăm": "haini",
    "hainiserăți": "haini",
    "hainiseși": "haini",
    "hainiși": "haini",
    "hainit": "haini",
    "hainiți": "haini",
    "hainitu": "haini",
    "nehainind": "haini",
    "nehainindu": "haini",
    "nemaihainind": "haini",
    "nemaihainindu": "haini",
    "hainită": "hainit",
    "hainite": "hainit",
    "hainiți": "hainit",
    "hăinuța": "hăinuță",
    "hăinuțe": "hăinuță",
    "hăinuței": "hăinuță",
    "hăinuțele": "hăinuță",
    "hăinuțelor": "hăinuță",
    "hâită": "hâit",
    "hâite": "hâit",
    "hâiți": "hâit",
    "hăită": "hăit",
    "hăite": "hăit",
    "hăiți": "hăit",
    "haita": "haită",
    "haite": "haită",
    "haitei": "haită",
    "haitele": "haită",
    "haitelor": "haită",
    "hăitași": "hăitaș",
    "hăitașii": "hăitaș",
    "hăitașilor": "hăitaș",
    "hăitașul": "hăitaș",
    "hăitașului": "hăitaș",
    "hăituia": "hăitui",
    "hăituiai": "hăitui",
    "hăituiam": "hăitui",
    "hăituiască": "hăitui",
    "hăituiați": "hăitui",
    "hăituiau": "hăitui",
    "hăituiesc": "hăitui",
    "hăituiește": "hăitui",
    "hăituiești": "hăitui",
    "hăituii": "hăitui",
    "hăituim": "hăitui",
    "hăituind": "hăitui",
    "hăituindu": "hăitui",
    "hăituiră": "hăitui",
    "hăituirăm": "hăitui",
    "hăituirăți": "hăitui",
    "hăituise": "hăitui",
    "hăituisem": "hăitui",
    "hăituiseră": "hăitui",
    "hăituiserăm": "hăitui",
    "hăituiserăți": "hăitui",
    "hăituiseși": "hăitui",
    "hăituiși": "hăitui",
    "hăituit": "hăitui",
    "hăituiți": "hăitui",
    "hăituitu": "hăitui",
    "nehăituind": "hăitui",
    "nehăituindu": "hăitui",
    "nemaihăituind": "hăitui",
    "nemaihăituindu": "hăitui",
    "hăituirea": "hăituire",
    "hăituireo": "hăituire",
    "hăituiri": "hăituire",
    "hăituirii": "hăituire",
    "hăituirile": "hăituire",
    "hăituirilor": "hăituire",
    "hăituită": "hăituit",
    "hăituite": "hăituit",
    "hăituiți": "hăituit",
    "halul": "hal",
    "halului": "hal",
    "haluri": "hal",
    "halurile": "hal",
    "halurilor": "hal",
    "hala": "hală",
    "hale": "hală",
    "halei": "hală",
    "halele": "hală",
    "halelor": "hală",
    "hălăduia": "hălădui",
    "hălăduiai": "hălădui",
    "hălăduiam": "hălădui",
    "hălăduiască": "hălădui",
    "hălăduiați": "hălădui",
    "hălăduiau": "hălădui",
    "hălăduiesc": "hălădui",
    "hălăduiește": "hălădui",
    "hălăduiești": "hălădui",
    "hălăduii": "hălădui",
    "hălăduim": "hălădui",
    "hălăduind": "hălădui",
    "hălăduindu": "hălădui",
    "hălăduiră": "hălădui",
    "hălăduirăm": "hălădui",
    "hălăduirăți": "hălădui",
    "hălăduise": "hălădui",
    "hălăduisem": "hălădui",
    "hălăduiseră": "hălădui",
    "hălăduiserăm": "hălădui",
    "hălăduiserăți": "hălădui",
    "hălăduiseși": "hălădui",
    "hălăduiși": "hălădui",
    "hălăduit": "hălădui",
    "hălăduiți": "hălădui",
    "hălăduitu": "hălădui",
    "nehălăduind": "hălădui",
    "nehălăduindu": "hălădui",
    "nemaihălăduind": "hălădui",
    "nemaihălăduindu": "hălădui",
    "hălăduită": "hălăduit",
    "hălăduite": "hălăduit",
    "hălăduiți": "hălăduit",
    "hălălăia": "hălălăi",
    "hălălăiai": "hălălăi",
    "hălălăiam": "hălălăi",
    "hălălăiască": "hălălăi",
    "hălălăiați": "hălălăi",
    "hălălăiau": "hălălăi",
    "hălălăiesc": "hălălăi",
    "hălălăiește": "hălălăi",
    "hălălăiești": "hălălăi",
    "hălălăii": "hălălăi",
    "hălălăim": "hălălăi",
    "hălălăind": "hălălăi",
    "hălălăindu": "hălălăi",
    "hălălăiră": "hălălăi",
    "hălălăirăm": "hălălăi",
    "hălălăirăți": "hălălăi",
    "hălălăise": "hălălăi",
    "hălălăisem": "hălălăi",
    "hălălăiseră": "hălălăi",
    "hălălăiserăm": "hălălăi",
    "hălălăiserăți": "hălălăi",
    "hălălăiseși": "hălălăi",
    "hălălăiși": "hălălăi",
    "hălălăit": "hălălăi",
    "hălălăiți": "hălălăi",
    "hălălăitu": "hălălăi",
    "nehălălăind": "hălălăi",
    "nehălălăindu": "hălălăi",
    "nemaihălălăind": "hălălăi",
    "nemaihălălăindu": "hălălăi",
    "hălălăită": "hălălăit",
    "hălălăite": "hălălăit",
    "hălălăiți": "hălălăit",
    "halate": "halat",
    "halatele": "halat",
    "halatelor": "halat",
    "halatul": "halat",
    "halatului": "halat",
    "halba": "halbă",
    "halbe": "halbă",
    "halbei": "halbă",
    "halbele": "halbă",
    "halbelor": "halbă",
    "halca": "halcă",
    "hălci": "halcă",
    "hălcii": "halcă",
    "hălcile": "halcă",
    "hălcilor": "halcă",
    "hălcuța": "hălcuță",
    "hălcuțe": "hălcuță",
    "hălcuței": "hălcuță",
    "hălcuțele": "hălcuță",
    "hălcuțelor": "hălcuță",
    "hălcuțo": "hălcuță",
    "halea": "hali",
    "haleai": "hali",
    "haleam": "hali",
    "halească": "hali",
    "haleați": "hali",
    "haleau": "hali",
    "halesc": "hali",
    "halește": "hali",
    "halești": "hali",
    "halii": "hali",
    "halim": "hali",
    "halind": "hali",
    "halindu": "hali",
    "haliră": "hali",
    "halirăm": "hali",
    "halirăți": "hali",
    "halise": "hali",
    "halisem": "hali",
    "haliseră": "hali",
    "haliserăm": "hali",
    "haliserăți": "hali",
    "haliseși": "hali",
    "haliși": "hali",
    "halit": "hali",
    "haliți": "hali",
    "halitu": "hali",
    "nehalind": "hali",
    "nehalindu": "hali",
    "nemaihalind": "hali",
    "nemaihalindu": "hali",
    "halită": "halit",
    "halite": "halit",
    "haliți": "halit",
    "hălpăia": "hălpăi",
    "hălpăiai": "hălpăi",
    "hălpăiam": "hălpăi",
    "hălpăiați": "hălpăi",
    "hălpăiau": "hălpăi",
    "hălpăie": "hălpăi",
    "hălpăii": "hălpăi",
    "hălpăim": "hălpăi",
    "hălpăind": "hălpăi",
    "hălpăindu": "hălpăi",
    "hălpăiră": "hălpăi",
    "hălpăirăm": "hălpăi",
    "hălpăirăți": "hălpăi",
    "hălpăise": "hălpăi",
    "hălpăisem": "hălpăi",
    "hălpăiseră": "hălpăi",
    "hălpăiserăm": "hălpăi",
    "hălpăiserăți": "hălpăi",
    "hălpăiseși": "hălpăi",
    "hălpăiși": "hălpăi",
    "hălpăit": "hălpăi",
    "hălpăiți": "hălpăi",
    "hălpăitu": "hălpăi",
    "nehălpăind": "hălpăi",
    "nehălpăindu": "hălpăi",
    "nemaihălpăind": "hălpăi",
    "nemaihălpăindu": "hălpăi",
    "hălpăită": "hălpăit",
    "hălpăite": "hălpăit",
    "hălpăiți": "hălpăit",
    "halta": "haltă",
    "halte": "haltă",
    "haltei": "haltă",
    "haltele": "haltă",
    "haltelor": "haltă",
    "haltera": "halteră",
    "haltere": "halteră",
    "halterei": "halteră",
    "halterele": "halteră",
    "halterelor": "halteră",
    "halterofili": "halterofil",
    "halterofilii": "halterofil",
    "halterofililor": "halterofil",
    "halterofilul": "halterofil",
    "halterofilului": "halterofil",
    "halucină": "halucina",
    "halucinai": "halucina",
    "halucinam": "halucina",
    "halucinăm": "halucina",
    "halucinând": "halucina",
    "halucinându": "halucina",
    "halucinară": "halucina",
    "halucinarăm": "halucina",
    "halucinarăți": "halucina",
    "halucinase": "halucina",
    "halucinasem": "halucina",
    "halucinaseră": "halucina",
    "halucinaserăm": "halucina",
    "halucinaserăți": "halucina",
    "halucinaseși": "halucina",
    "halucinași": "halucina",
    "halucinat": "halucina",
    "halucinați": "halucina",
    "halucinatu": "halucina",
    "halucinau": "halucina",
    "halucinează": "halucina",
    "halucinez": "halucina",
    "halucineze": "halucina",
    "halucinezi": "halucina",
    "nehalucinând": "halucina",
    "nehalucinându": "halucina",
    "nemaihalucinând": "halucina",
    "nemaihalucinându": "halucina",
    "halucinată": "halucinat",
    "halucinate": "halucinat",
    "halucinați": "halucinat",
    "halucinația": "halucinație",
    "halucinației": "halucinație",
    "halucinații": "halucinație",
    "halucinațiile": "halucinație",
    "halucinațiilor": "halucinație",
    "hamul": "ham",
    "hamului": "ham",
    "hamuri": "ham",
    "hamurile": "ham",
    "hamurilor": "ham",
    "hamace": "hamac",
    "hamacele": "hamac",
    "hamacelor": "hamac",
    "hamacul": "hamac",
    "hamacului": "hamac",
    "hamacuri": "hamac",
    "hamacurile": "hamac",
    "hamacurilor": "hamac",
    "hămăia": "hămăi",
    "hămăiai": "hămăi",
    "hămăiam": "hămăi",
    "hămăiați": "hămăi",
    "hămăiau": "hămăi",
    "hămăie": "hămăi",
    "hămăii": "hămăi",
    "hămăim": "hămăi",
    "hămăind": "hămăi",
    "hămăindu": "hămăi",
    "hămăiră": "hămăi",
    "hămăirăm": "hămăi",
    "hămăirăți": "hămăi",
    "hămăise": "hămăi",
    "hămăisem": "hămăi",
    "hămăiseră": "hămăi",
    "hămăiserăm": "hămăi",
    "hămăiserăți": "hămăi",
    "hămăiseși": "hămăi",
    "hămăiși": "hămăi",
    "hămăit": "hămăi",
    "hămăiți": "hămăi",
    "hămăitu": "hămăi",
    "nehămăind": "hămăi",
    "nehămăindu": "hămăi",
    "nemaihămăind": "hămăi",
    "nemaihămăindu": "hămăi",
    "hămăită": "hămăit",
    "hămăite": "hămăit",
    "hămăiți": "hămăit",
    "hămăitul": "hămăit",
    "hămăitului": "hămăit",
    "hămăituri": "hămăit",
    "hămăiturile": "hămăit",
    "hămăiturilor": "hămăit",
    "hamali": "hamal",
    "hamalii": "hamal",
    "hamalilor": "hamal",
    "hamalul": "hamal",
    "hamalului": "hamal",
    "hambare": "hambar",
    "hambarele": "hambar",
    "hambarelor": "hambar",
    "hambarul": "hambar",
    "hambarului": "hambar",
    "hămesea": "hămesi",
    "hămeseai": "hămesi",
    "hămeseam": "hămesi",
    "hămesească": "hămesi",
    "hămeseați": "hămesi",
    "hămeseau": "hămesi",
    "hămesesc": "hămesi",
    "hămesește": "hămesi",
    "hămesești": "hămesi",
    "hămesii": "hămesi",
    "hămesim": "hămesi",
    "hămesind": "hămesi",
    "hămesindu": "hămesi",
    "hămesiră": "hămesi",
    "hămesirăm": "hămesi",
    "hămesirăți": "hămesi",
    "hămesise": "hămesi",
    "hămesisem": "hămesi",
    "hămesiseră": "hămesi",
    "hămesiserăm": "hămesi",
    "hămesiserăți": "hămesi",
    "hămesiseși": "hămesi",
    "hămesiși": "hămesi",
    "hămesit": "hămesi",
    "hămesiți": "hămesi",
    "hămesitu": "hămesi",
    "nehămesind": "hămesi",
    "nehămesindu": "hămesi",
    "nemaihămesind": "hămesi",
    "nemaihămesindu": "hămesi",
    "hămesita": "hămesit",
    "hămesită": "hămesit",
    "hămesite": "hămesit",
    "hămesitei": "hămesit",
    "hămesitele": "hămesit",
    "hămesitelor": "hămesit",
    "hămesiți": "hămesit",
    "hămesiții": "hămesit",
    "hămesiților": "hămesit",
    "hămesitul": "hămesit",
    "hămesitului": "hămesit",
    "hămuia": "hămui",
    "hămuiai": "hămui",
    "hămuiam": "hămui",
    "hămuiască": "hămui",
    "hămuiați": "hămui",
    "hămuiau": "hămui",
    "hămuiesc": "hămui",
    "hămuiește": "hămui",
    "hămuiești": "hămui",
    "hămuii": "hămui",
    "hămuim": "hămui",
    "hămuind": "hămui",
    "hămuindu": "hămui",
    "hămuiră": "hămui",
    "hămuirăm": "hămui",
    "hămuirăți": "hămui",
    "hămuise": "hămui",
    "hămuisem": "hămui",
    "hămuiseră": "hămui",
    "hămuiserăm": "hămui",
    "hămuiserăți": "hămui",
    "hămuiseși": "hămui",
    "hămuiși": "hămui",
    "hămuit": "hămui",
    "hămuiți": "hămui",
    "hămuitu": "hămui",
    "nehămuind": "hămui",
    "nehămuindu": "hămui",
    "nemaihămuind": "hămui",
    "nemaihămuindu": "hămui",
    "hămuită": "hămuit",
    "hămuite": "hămuit",
    "hămuiți": "hămuit",
    "hanul": "han",
    "hanului": "han",
    "hanuri": "han",
    "hanurile": "han",
    "hanurilor": "han",
    "handbalul": "handbal",
    "handbalului": "handbal",
    "handicapul": "handicap",
    "handicapului": "handicap",
    "handicapuri": "handicap",
    "handicapurile": "handicap",
    "handicapurilor": "handicap",
    "handicapă": "handicapa",
    "handicapai": "handicapa",
    "handicapam": "handicapa",
    "handicapăm": "handicapa",
    "handicapând": "handicapa",
    "handicapându": "handicapa",
    "handicapară": "handicapa",
    "handicaparăm": "handicapa",
    "handicaparăți": "handicapa",
    "handicapase": "handicapa",
    "handicapasem": "handicapa",
    "handicapaseră": "handicapa",
    "handicapaserăm": "handicapa",
    "handicapaserăți": "handicapa",
    "handicapaseși": "handicapa",
    "handicapași": "handicapa",
    "handicapat": "handicapa",
    "handicapați": "handicapa",
    "handicapatu": "handicapa",
    "handicapau": "handicapa",
    "handicapează": "handicapa",
    "handicapez": "handicapa",
    "handicapeze": "handicapa",
    "handicapezi": "handicapa",
    "nehandicapând": "handicapa",
    "nehandicapându": "handicapa",
    "nemaihandicapând": "handicapa",
    "nemaihandicapându": "handicapa",
    "handicapată": "handicapat",
    "handicapate": "handicapat",
    "handicapați": "handicapat",
    "hangul": "hang",
    "hangule": "hang",
    "hangului": "hang",
    "hanguri": "hang",
    "hangurile": "hang",
    "hangurilor": "hang",
    "hangare": "hangar",
    "hangarele": "hangar",
    "hangarelor": "hangar",
    "hangarul": "hangar",
    "hangarului": "hangar",
    "hangița": "hangiță",
    "hangițe": "hangiță",
    "hangiței": "hangiță",
    "hangițele": "hangiță",
    "hangițelor": "hangiță",
    "hangii": "hangiu",
    "hangiii": "hangiu",
    "hangiilor": "hangiu",
    "hangiul": "hangiu",
    "hangiului": "hangiu",
    "hanorace": "hanorac",
    "hanoracele": "hanorac",
    "hanoracelor": "hanorac",
    "hanoracul": "hanorac",
    "hanoracului": "hanorac",
    "han-tătari": "han-tătar",
    "haosul": "haos",
    "haosului": "haos",
    "haosuri": "haos",
    "haosurile": "haos",
    "haosurilor": "haos",
    "haotica": "haotic",
    "haotică": "haotic",
    "haotice": "haotic",
    "haoticei": "haotic",
    "haoticele": "haotic",
    "haoticelor": "haotic",
    "haotici": "haotic",
    "haoticii": "haotic",
    "haoticilor": "haotic",
    "haoticul": "haotic",
    "haoticului": "haotic",
    "hăpăia": "hăpăi",
    "hăpăiai": "hăpăi",
    "hăpăiam": "hăpăi",
    "hăpăiască": "hăpăi",
    "hăpăiați": "hăpăi",
    "hăpăiau": "hăpăi",
    "hăpăiesc": "hăpăi",
    "hăpăiește": "hăpăi",
    "hăpăiești": "hăpăi",
    "hăpăii": "hăpăi",
    "hăpăim": "hăpăi",
    "hăpăind": "hăpăi",
    "hăpăindu": "hăpăi",
    "hăpăiră": "hăpăi",
    "hăpăirăm": "hăpăi",
    "hăpăirăți": "hăpăi",
    "hăpăise": "hăpăi",
    "hăpăisem": "hăpăi",
    "hăpăiseră": "hăpăi",
    "hăpăiserăm": "hăpăi",
    "hăpăiserăți": "hăpăi",
    "hăpăiseși": "hăpăi",
    "hăpăiși": "hăpăi",
    "hăpăit": "hăpăi",
    "hăpăiți": "hăpăi",
    "hăpăitu": "hăpăi",
    "nehăpăind": "hăpăi",
    "nehăpăindu": "hăpăi",
    "nemaihăpăind": "hăpăi",
    "nemaihăpăindu": "hăpăi",
    "hăpăită": "hăpăit",
    "hăpăite": "hăpăit",
    "hăpăiți": "hăpăit",
    "hapsâna": "hapsân",
    "hapsână": "hapsân",
    "hapsâne": "hapsân",
    "hapsânei": "hapsân",
    "hapsânele": "hapsân",
    "hapsânelor": "hapsân",
    "hapsâni": "hapsân",
    "hapsânii": "hapsân",
    "hapsânilor": "hapsân",
    "hapsânul": "hapsân",
    "hapsânului": "hapsân",
    "harul": "har",
    "harului": "har",
    "haruri": "har",
    "harurile": "har",
    "harurilor": "har",
    "harababura": "harababură",
    "harababuri": "harababură",
    "harababurii": "harababură",
    "harababurile": "harababură",
    "harababurilor": "harababură",
    "hărățea": "hărăți",
    "hărățeai": "hărăți",
    "hărățeam": "hărăți",
    "hărățească": "hărăți",
    "hărățeați": "hărăți",
    "hărățeau": "hărăți",
    "hărățesc": "hărăți",
    "hărățește": "hărăți",
    "hărățești": "hărăți",
    "hărății": "hărăți",
    "hărățim": "hărăți",
    "hărățind": "hărăți",
    "hărățindu": "hărăți",
    "hărățiră": "hărăți",
    "hărățirăm": "hărăți",
    "hărățirăți": "hărăți",
    "hărățise": "hărăți",
    "hărățisem": "hărăți",
    "hărățiseră": "hărăți",
    "hărățiserăm": "hărăți",
    "hărățiserăți": "hărăți",
    "hărățiseși": "hărăți",
    "hărățiși": "hărăți",
    "hărățit": "hărăți",
    "hărățiți": "hărăți",
    "hărățitu": "hărăți",
    "nehărățind": "hărăți",
    "nehărățindu": "hărăți",
    "nemaihărățind": "hărăți",
    "nemaihărățindu": "hărăți",
    "hărățită": "hărățit",
    "hărățite": "hărățit",
    "hărățiți": "hărățit",
    "hărăzea": "hărăzi",
    "hărăzeai": "hărăzi",
    "hărăzeam": "hărăzi",
    "hărăzească": "hărăzi",
    "hărăzeați": "hărăzi",
    "hărăzeau": "hărăzi",
    "hărăzesc": "hărăzi",
    "hărăzește": "hărăzi",
    "hărăzești": "hărăzi",
    "hărăzii": "hărăzi",
    "hărăzim": "hărăzi",
    "hărăzind": "hărăzi",
    "hărăzindu": "hărăzi",
    "hărăziră": "hărăzi",
    "hărăzirăm": "hărăzi",
    "hărăzirăți": "hărăzi",
    "hărăzise": "hărăzi",
    "hărăzisem": "hărăzi",
    "hărăziseră": "hărăzi",
    "hărăziserăm": "hărăzi",
    "hărăziserăți": "hărăzi",
    "hărăziseși": "hărăzi",
    "hărăziși": "hărăzi",
    "hărăzit": "hărăzi",
    "hărăziți": "hărăzi",
    "hărăzitu": "hărăzi",
    "nehărăzind": "hărăzi",
    "nehărăzindu": "hărăzi",
    "nemaihărăzind": "hărăzi",
    "nemaihărăzindu": "hărăzi",
    "hărăzită": "hărăzit",
    "hărăzite": "hărăzit",
    "hărăziți": "hărăzit",
    "hârbul": "hârb",
    "hârbului": "hârb",
    "hârburi": "hârb",
    "hârburile": "hârb",
    "hârburilor": "hârb",
    "hârbuia": "hârbui",
    "hârbuiai": "hârbui",
    "hârbuiam": "hârbui",
    "hârbuiască": "hârbui",
    "hârbuiați": "hârbui",
    "hârbuiau": "hârbui",
    "hârbuiesc": "hârbui",
    "hârbuiește": "hârbui",
    "hârbuiești": "hârbui",
    "hârbuii": "hârbui",
    "hârbuim": "hârbui",
    "hârbuind": "hârbui",
    "hârbuindu": "hârbui",
    "hârbuiră": "hârbui",
    "hârbuirăm": "hârbui",
    "hârbuirăți": "hârbui",
    "hârbuise": "hârbui",
    "hârbuisem": "hârbui",
    "hârbuiseră": "hârbui",
    "hârbuiserăm": "hârbui",
    "hârbuiserăți": "hârbui",
    "hârbuiseși": "hârbui",
    "hârbuiși": "hârbui",
    "hârbuit": "hârbui",
    "hârbuiți": "hârbui",
    "hârbuitu": "hârbui",
    "nehârbuind": "hârbui",
    "nehârbuindu": "hârbui",
    "nemaihârbuind": "hârbui",
    "nemaihârbuindu": "hârbui",
    "hârbuită": "hârbuit",
    "hârbuite": "hârbuit",
    "hârbuiți": "hârbuit",
    "hârcâia": "hârcâi",
    "hârcâiai": "hârcâi",
    "hârcâiam": "hârcâi",
    "hârcâiați": "hârcâi",
    "hârcâiau": "hârcâi",
    "hârcâie": "hârcâi",
    "hârcâii": "hârcâi",
    "hârcâim": "hârcâi",
    "hârcâind": "hârcâi",
    "hârcâindu": "hârcâi",
    "hârcâiră": "hârcâi",
    "hârcâirăm": "hârcâi",
    "hârcâirăți": "hârcâi",
    "hârcâise": "hârcâi",
    "hârcâisem": "hârcâi",
    "hârcâiseră": "hârcâi",
    "hârcâiserăm": "hârcâi",
    "hârcâiserăți": "hârcâi",
    "hârcâiseși": "hârcâi",
    "hârcâiși": "hârcâi",
    "hârcâit": "hârcâi",
    "hârcâiți": "hârcâi",
    "hârcâitu": "hârcâi",
    "nehârcâind": "hârcâi",
    "nehârcâindu": "hârcâi",
    "nemaihârcâind": "hârcâi",
    "nemaihârcâindu": "hârcâi",
    "hârcâită": "hârcâit",
    "hârcâite": "hârcâit",
    "hârcâiți": "hârcâit",
    "hârciogi": "hârciog",
    "hârciogii": "hârciog",
    "hârciogilor": "hârciog",
    "hârciogul": "hârciog",
    "hârciogului": "hârciog",
    "hârdaie": "hârdău",
    "hârdaiele": "hârdău",
    "hârdaielor": "hârdău",
    "hârdăul": "hârdău",
    "hârdăului": "hârdău",
    "hardughia": "hardughie",
    "hardughiei": "hardughie",
    "hardughii": "hardughie",
    "hardughiile": "hardughie",
    "hardughiilor": "hardughie",
    "Harghitei": "Harghita",
    "hărhătea": "hărhăti",
    "hărhăteai": "hărhăti",
    "hărhăteam": "hărhăti",
    "hărhătească": "hărhăti",
    "hărhăteați": "hărhăti",
    "hărhăteau": "hărhăti",
    "hărhătesc": "hărhăti",
    "hărhătește": "hărhăti",
    "hărhătești": "hărhăti",
    "hărhătii": "hărhăti",
    "hărhătim": "hărhăti",
    "hărhătind": "hărhăti",
    "hărhătindu": "hărhăti",
    "hărhătiră": "hărhăti",
    "hărhătirăm": "hărhăti",
    "hărhătirăți": "hărhăti",
    "hărhătise": "hărhăti",
    "hărhătisem": "hărhăti",
    "hărhătiseră": "hărhăti",
    "hărhătiserăm": "hărhăti",
    "hărhătiserăți": "hărhăti",
    "hărhătiseși": "hărhăti",
    "hărhătiși": "hărhăti",
    "hărhătit": "hărhăti",
    "hărhătiți": "hărhăti",
    "hărhătitu": "hărhăti",
    "nehărhătind": "hărhăti",
    "nehărhătindu": "hărhăti",
    "nemaihărhătind": "hărhăti",
    "nemaihărhătindu": "hărhăti",
    "hărhătită": "hărhătit",
    "hărhătite": "hărhătit",
    "hărhătiți": "hărhătit",
    "hârjoana": "hârjoană",
    "hârjoane": "hârjoană",
    "hârjoanei": "hârjoană",
    "hârjoanele": "hârjoană",
    "hârjoanelor": "hârjoană",
    "hârjoano": "hârjoană",
    "hârjoneala": "hârjoneală",
    "hârjoneli": "hârjoneală",
    "hârjonelii": "hârjoneală",
    "hârjonelile": "hârjoneală",
    "hârjonelilor": "hârjoneală",
    "hârjonea": "hârjoni",
    "hârjoneai": "hârjoni",
    "hârjoneam": "hârjoni",
    "hârjonească": "hârjoni",
    "hârjoneați": "hârjoni",
    "hârjoneau": "hârjoni",
    "hârjonesc": "hârjoni",
    "hârjonește": "hârjoni",
    "hârjonești": "hârjoni",
    "hârjonii": "hârjoni",
    "hârjonim": "hârjoni",
    "hârjonind": "hârjoni",
    "hârjonindu": "hârjoni",
    "hârjoniră": "hârjoni",
    "hârjonirăm": "hârjoni",
    "hârjonirăți": "hârjoni",
    "hârjonise": "hârjoni",
    "hârjonisem": "hârjoni",
    "hârjoniseră": "hârjoni",
    "hârjoniserăm": "hârjoni",
    "hârjoniserăți": "hârjoni",
    "hârjoniseși": "hârjoni",
    "hârjoniși": "hârjoni",
    "hârjonit": "hârjoni",
    "hârjoniți": "hârjoni",
    "hârjonitu": "hârjoni",
    "nehârjonind": "hârjoni",
    "nehârjonindu": "hârjoni",
    "nemaihârjonind": "hârjoni",
    "nemaihârjonindu": "hârjoni",
    "hârjonită": "hârjonit",
    "hârjonite": "hârjonit",
    "hârjoniți": "hârjonit",
    "hârlețe": "hârleț",
    "hârlețele": "hârleț",
    "hârlețelor": "hârleț",
    "hârlețul": "hârleț",
    "hârlețului": "hârleț",
    "harnașă": "harnașa",
    "harnașai": "harnașa",
    "harnașam": "harnașa",
    "harnașăm": "harnașa",
    "harnașând": "harnașa",
    "harnașându": "harnașa",
    "harnașară": "harnașa",
    "harnașarăm": "harnașa",
    "harnașarăți": "harnașa",
    "harnașase": "harnașa",
    "harnașasem": "harnașa",
    "harnașaseră": "harnașa",
    "harnașaserăm": "harnașa",
    "harnașaserăți": "harnașa",
    "harnașaseși": "harnașa",
    "harnașași": "harnașa",
    "harnașat": "harnașa",
    "harnașați": "harnașa",
    "harnașatu": "harnașa",
    "harnașau": "harnașa",
    "harnașează": "harnașa",
    "harnașez": "harnașa",
    "harnașeze": "harnașa",
    "harnașezi": "harnașa",
    "neharnașând": "harnașa",
    "neharnașându": "harnașa",
    "nemaiharnașând": "harnașa",
    "nemaiharnașându": "harnașa",
    "harnașată": "harnașat",
    "harnașate": "harnașat",
    "harnașați": "harnașat",
    "harnica": "harnic",
    "harnică": "harnic",
    "harnice": "harnic",
    "harnicei": "harnic",
    "harnicele": "harnic",
    "harnicelor": "harnic",
    "harnici": "harnic",
    "harnicii": "harnic",
    "harnicilor": "harnic",
    "harnicul": "harnic",
    "harnicului": "harnic",
    "hărnicea": "hărnici",
    "hărniceai": "hărnici",
    "hărniceam": "hărnici",
    "hărnicească": "hărnici",
    "hărniceați": "hărnici",
    "hărniceau": "hărnici",
    "hărnicesc": "hărnici",
    "hărnicește": "hărnici",
    "hărnicești": "hărnici",
    "hărnicii": "hărnici",
    "hărnicim": "hărnici",
    "hărnicind": "hărnici",
    "hărnicindu": "hărnici",
    "hărniciră": "hărnici",
    "hărnicirăm": "hărnici",
    "hărnicirăți": "hărnici",
    "hărnicise": "hărnici",
    "hărnicisem": "hărnici",
    "hărniciseră": "hărnici",
    "hărniciserăm": "hărnici",
    "hărniciserăți": "hărnici",
    "hărniciseși": "hărnici",
    "hărniciși": "hărnici",
    "hărnicit": "hărnici",
    "hărniciți": "hărnici",
    "hărnicitu": "hărnici",
    "nehărnicind": "hărnici",
    "nehărnicindu": "hărnici",
    "nemaihărnicind": "hărnici",
    "nemaihărnicindu": "hărnici",
    "hărnicia": "hărnicie",
    "hărniciei": "hărnicie",
    "hărnicii": "hărnicie",
    "hărniciile": "hărnicie",
    "hărniciilor": "hărnicie",
    "hărnicită": "hărnicit",
    "hărnicite": "hărnicit",
    "hărniciți": "hărnicit",
    "harpa": "harpă",
    "harpe": "harpă",
    "harpei": "harpă",
    "harpele": "harpă",
    "harpelor": "harpă",
    "harpiști": "harpist",
    "harpiștii": "harpist",
    "harpiștilor": "harpist",
    "harpistul": "harpist",
    "harpistului": "harpist",
    "harpoane": "harpon",
    "harpoanele": "harpon",
    "harpoanelor": "harpon",
    "harponul": "harpon",
    "harponului": "harpon",
    "hârșâia": "hârșâi",
    "hârșâiai": "hârșâi",
    "hârșâiam": "hârșâi",
    "hârșâiați": "hârșâi",
    "hârșâiau": "hârșâi",
    "hârșâie": "hârșâi",
    "hârșâii": "hârșâi",
    "hârșâim": "hârșâi",
    "hârșâind": "hârșâi",
    "hârșâindu": "hârșâi",
    "hârșâiră": "hârșâi",
    "hârșâirăm": "hârșâi",
    "hârșâirăți": "hârșâi",
    "hârșâise": "hârșâi",
    "hârșâisem": "hârșâi",
    "hârșâiseră": "hârșâi",
    "hârșâiserăm": "hârșâi",
    "hârșâiserăți": "hârșâi",
    "hârșâiseși": "hârșâi",
    "hârșâiși": "hârșâi",
    "hârșâit": "hârșâi",
    "hârșâiți": "hârșâi",
    "hârșâitu": "hârșâi",
    "nehârșâind": "hârșâi",
    "nehârșâindu": "hârșâi",
    "nemaihârșâind": "hârșâi",
    "nemaihârșâindu": "hârșâi",
    "hârșâită": "hârșâit",
    "hârșâite": "hârșâit",
    "hârșâiți": "hârșâit",
    "hârsea": "hârsi",
    "hârseai": "hârsi",
    "hârseam": "hârsi",
    "hârsească": "hârsi",
    "hârseați": "hârsi",
    "hârseau": "hârsi",
    "hârsesc": "hârsi",
    "hârsește": "hârsi",
    "hârsești": "hârsi",
    "hârsii": "hârsi",
    "hârsim": "hârsi",
    "hârsind": "hârsi",
    "hârsindu": "hârsi",
    "hârsiră": "hârsi",
    "hârsirăm": "hârsi",
    "hârsirăți": "hârsi",
    "hârsise": "hârsi",
    "hârsisem": "hârsi",
    "hârsiseră": "hârsi",
    "hârsiserăm": "hârsi",
    "hârsiserăți": "hârsi",
    "hârsiseși": "hârsi",
    "hârsiși": "hârsi",
    "hârsit": "hârsi",
    "hârsiți": "hârsi",
    "hârsitu": "hârsi",
    "nehârsind": "hârsi",
    "nehârsindu": "hârsi",
    "nemaihârsind": "hârsi",
    "nemaihârsindu": "hârsi",
    "hârsită": "hârsit",
    "hârsite": "hârsit",
    "hârsiți": "hârsit",
    "hărșnea": "hărșni",
    "hărșneai": "hărșni",
    "hărșneam": "hărșni",
    "hărșnească": "hărșni",
    "hărșneați": "hărșni",
    "hărșneau": "hărșni",
    "hărșnesc": "hărșni",
    "hărșnește": "hărșni",
    "hărșnești": "hărșni",
    "hărșnii": "hărșni",
    "hărșnim": "hărșni",
    "hărșnind": "hărșni",
    "hărșnindu": "hărșni",
    "hărșniră": "hărșni",
    "hărșnirăm": "hărșni",
    "hărșnirăți": "hărșni",
    "hărșnise": "hărșni",
    "hărșnisem": "hărșni",
    "hărșniseră": "hărșni",
    "hărșniserăm": "hărșni",
    "hărșniserăți": "hărșni",
    "hărșniseși": "hărșni",
    "hărșniși": "hărșni",
    "hărșnit": "hărșni",
    "hărșniți": "hărșni",
    "hărșnitu": "hărșni",
    "nehărșnind": "hărșni",
    "nehărșnindu": "hărșni",
    "nemaihărșnind": "hărșni",
    "nemaihărșnindu": "hărșni",
    "hărșnită": "hărșnit",
    "hărșnite": "hărșnit",
    "hărșniți": "hărșnit",
    "harta": "hartă",
    "hărți": "hartă",
    "hărții": "hartă",
    "hărțile": "hartă",
    "hărților": "hartă",
    "harța": "harță",
    "harțe": "harță",
    "harței": "harță",
    "hărtănea": "hărtăni",
    "hărtăneai": "hărtăni",
    "hărtăneam": "hărtăni",
    "hărtănească": "hărtăni",
    "hărtăneați": "hărtăni",
    "hărtăneau": "hărtăni",
    "hărtănesc": "hărtăni",
    "hărtănește": "hărtăni",
    "hărtănești": "hărtăni",
    "hărtănii": "hărtăni",
    "hărtănim": "hărtăni",
    "hărtănind": "hărtăni",
    "hărtănindu": "hărtăni",
    "hărtăniră": "hărtăni",
    "hărtănirăm": "hărtăni",
    "hărtănirăți": "hărtăni",
    "hărtănise": "hărtăni",
    "hărtănisem": "hărtăni",
    "hărtăniseră": "hărtăni",
    "hărtăniserăm": "hărtăni",
    "hărtăniserăți": "hărtăni",
    "hărtăniseși": "hărtăni",
    "hărtăniși": "hărtăni",
    "hărtănit": "hărtăni",
    "hărtăniți": "hărtăni",
    "hărtănitu": "hărtăni",
    "nehărtănind": "hărtăni",
    "nehărtănindu": "hărtăni",
    "nemaihărtănind": "hărtăni",
    "nemaihărtănindu": "hărtăni",
    "hărtănită": "hărtănit",
    "hărtănite": "hărtănit",
    "hărtăniți": "hărtănit",
    "hârt.": "hârtie",
    "hârtia": "hârtie",
    "hârtiei": "hârtie",
    "hârtii": "hârtie",
    "hârtiile": "hârtie",
    "hârtiilor": "hârtie",
    "hârtiuța": "hârtiuță",
    "hârtiuțe": "hârtiuță",
    "hârtiuței": "hârtiuță",
    "hârtiuțele": "hârtiuță",
    "hârtiuțelor": "hârtiuță",
    "hârțoage": "hârțoagă",
    "hârțoagei": "hârțoagă",
    "hârțoagele": "hârțoagă",
    "hârțoagelor": "hârțoagă",
    "hartoia": "hartoi",
    "hartoiai": "hartoi",
    "hartoiam": "hartoi",
    "hartoiască": "hartoi",
    "hartoiați": "hartoi",
    "hartoiau": "hartoi",
    "hartoiesc": "hartoi",
    "hartoiește": "hartoi",
    "hartoiești": "hartoi",
    "hartoii": "hartoi",
    "hartoim": "hartoi",
    "hartoind": "hartoi",
    "hartoindu": "hartoi",
    "hartoiră": "hartoi",
    "hartoirăm": "hartoi",
    "hartoirăți": "hartoi",
    "hartoise": "hartoi",
    "hartoisem": "hartoi",
    "hartoiseră": "hartoi",
    "hartoiserăm": "hartoi",
    "hartoiserăți": "hartoi",
    "hartoiseși": "hartoi",
    "hartoiși": "hartoi",
    "hartoit": "hartoi",
    "hartoiți": "hartoi",
    "hartoitu": "hartoi",
    "nehartoind": "hartoi",
    "nehartoindu": "hartoi",
    "nemaihartoind": "hartoi",
    "nemaihartoindu": "hartoi",
    "hartoită": "hartoit",
    "hartoite": "hartoit",
    "hartoiți": "hartoit",
    "hârtoape": "hârtop",
    "hârtoapele": "hârtop",
    "hârtoapelor": "hârtop",
    "hârtopul": "hârtop",
    "hârtopului": "hârtop",
    "hărțuia": "hărțui",
    "hărțuiai": "hărțui",
    "hărțuiam": "hărțui",
    "hărțuiască": "hărțui",
    "hărțuiați": "hărțui",
    "hărțuiau": "hărțui",
    "hărțuiesc": "hărțui",
    "hărțuiește": "hărțui",
    "hărțuiești": "hărțui",
    "hărțuii": "hărțui",
    "hărțuim": "hărțui",
    "hărțuind": "hărțui",
    "hărțuindu": "hărțui",
    "hărțuiră": "hărțui",
    "hărțuirăm": "hărțui",
    "hărțuirăți": "hărțui",
    "hărțuise": "hărțui",
    "hărțuisem": "hărțui",
    "hărțuiseră": "hărțui",
    "hărțuiserăm": "hărțui",
    "hărțuiserăți": "hărțui",
    "hărțuiseși": "hărțui",
    "hărțuiși": "hărțui",
    "hărțuit": "hărțui",
    "hărțuiți": "hărțui",
    "hărțuitu": "hărțui",
    "nehărțuind": "hărțui",
    "nehărțuindu": "hărțui",
    "nemaihărțuind": "hărțui",
    "nemaihărțuindu": "hărțui",
    "hărțuiala": "hărțuială",
    "hărțuieli": "hărțuială",
    "hărțuielii": "hărțuială",
    "hărțuielile": "hărțuială",
    "hărțuielilor": "hărțuială",
    "hărțuită": "hărțuit",
    "hărțuite": "hărțuit",
    "hărțuiți": "hărțuit",
    "hâșâia": "hâșâi",
    "hâșâiai": "hâșâi",
    "hâșâiam": "hâșâi",
    "hâșâiască": "hâșâi",
    "hâșâiați": "hâșâi",
    "hâșâiau": "hâșâi",
    "hâșâiesc": "hâșâi",
    "hâșâiește": "hâșâi",
    "hâșâiești": "hâșâi",
    "hâșâii": "hâșâi",
    "hâșâim": "hâșâi",
    "hâșâind": "hâșâi",
    "hâșâindu": "hâșâi",
    "hâșâiră": "hâșâi",
    "hâșâirăm": "hâșâi",
    "hâșâirăți": "hâșâi",
    "hâșâise": "hâșâi",
    "hâșâisem": "hâșâi",
    "hâșâiseră": "hâșâi",
    "hâșâiserăm": "hâșâi",
    "hâșâiserăți": "hâșâi",
    "hâșâiseși": "hâșâi",
    "hâșâiși": "hâșâi",
    "hâșâit": "hâșâi",
    "hâșâiți": "hâșâi",
    "hâșâitu": "hâșâi",
    "nehâșâind": "hâșâi",
    "nehâșâindu": "hâșâi",
    "nemaihâșâind": "hâșâi",
    "nemaihâșâindu": "hâșâi",
    "hâșâită": "hâșâit",
    "hâșâite": "hâșâit",
    "hâșâiți": "hâșâit",
    "hașură": "hașura",
    "hașurai": "hașura",
    "hașuram": "hașura",
    "hașurăm": "hașura",
    "hașurând": "hașura",
    "hașurându": "hașura",
    "hașurară": "hașura",
    "hașurarăm": "hașura",
    "hașurarăți": "hașura",
    "hașurase": "hașura",
    "hașurasem": "hașura",
    "hașuraseră": "hașura",
    "hașuraserăm": "hașura",
    "hașuraserăți": "hașura",
    "hașuraseși": "hașura",
    "hașurași": "hașura",
    "hașurat": "hașura",
    "hașurați": "hașura",
    "hașuratu": "hașura",
    "hașurau": "hașura",
    "hașurează": "hașura",
    "hașurez": "hașura",
    "hașureze": "hașura",
    "hașurezi": "hașura",
    "nehașurând": "hașura",
    "nehașurându": "hașura",
    "nemaihașurând": "hașura",
    "nemaihașurându": "hașura",
    "hașura": "hașură",
    "hașuri": "hașură",
    "hașurii": "hașură",
    "hașurile": "hașură",
    "hașurilor": "hașură",
    "hașurată": "hașurat",
    "hașurate": "hașurat",
    "hașurați": "hașurat",
    "hățul": "hăț",
    "hățului": "hăț",
    "hățuri": "hăț",
    "hățurile": "hăț",
    "hățurilor": "hăț",
    "hâțâia": "hâțâi",
    "hâțâiai": "hâțâi",
    "hâțâiam": "hâțâi",
    "hâțâiați": "hâțâi",
    "hâțâiau": "hâțâi",
    "hâțâie": "hâțâi",
    "hâțâii": "hâțâi",
    "hâțâim": "hâțâi",
    "hâțâind": "hâțâi",
    "hâțâindu": "hâțâi",
    "hâțâiră": "hâțâi",
    "hâțâirăm": "hâțâi",
    "hâțâirăți": "hâțâi",
    "hâțâise": "hâțâi",
    "hâțâisem": "hâțâi",
    "hâțâiseră": "hâțâi",
    "hâțâiserăm": "hâțâi",
    "hâțâiserăți": "hâțâi",
    "hâțâiseși": "hâțâi",
    "hâțâiși": "hâțâi",
    "hâțâit": "hâțâi",
    "hâțâiți": "hâțâi",
    "hâțâitu": "hâțâi",
    "nehâțâind": "hâțâi",
    "nehâțâindu": "hâțâi",
    "nemaihâțâind": "hâțâi",
    "nemaihâțâindu": "hâțâi",
    "hâțâită": "hâțâit",
    "hâțâite": "hâțâit",
    "hâțâiți": "hâțâit",
    "hâțân": "hâțâna",
    "hâțână": "hâțâna",
    "hâțânai": "hâțâna",
    "hâțânam": "hâțâna",
    "hâțânăm": "hâțâna",
    "hâțânând": "hâțâna",
    "hâțânându": "hâțâna",
    "hâțânară": "hâțâna",
    "hâțânarăm": "hâțâna",
    "hâțânarăți": "hâțâna",
    "hâțânase": "hâțâna",
    "hâțânasem": "hâțâna",
    "hâțânaseră": "hâțâna",
    "hâțânaserăm": "hâțâna",
    "hâțânaserăți": "hâțâna",
    "hâțânaseși": "hâțâna",
    "hâțânași": "hâțâna",
    "hâțânat": "hâțâna",
    "hâțânați": "hâțâna",
    "hâțânatu": "hâțâna",
    "hâțânau": "hâțâna",
    "hâțâne": "hâțâna",
    "hâțâni": "hâțâna",
    "nehâțânând": "hâțâna",
    "nehâțânându": "hâțâna",
    "nemaihâțânând": "hâțâna",
    "nemaihâțânându": "hâțâna",
    "hâțânată": "hâțânat",
    "hâțânate": "hâțânat",
    "hâțânați": "hâțânat",
    "hatârul": "hatâr",
    "hatârului": "hatâr",
    "hatâruri": "hatâr",
    "hatârurile": "hatâr",
    "hatârurilor": "hatâr",
    "hătcăia": "hătcăi",
    "hătcăiai": "hătcăi",
    "hătcăiam": "hătcăi",
    "hătcăiască": "hătcăi",
    "hătcăiați": "hătcăi",
    "hătcăiau": "hătcăi",
    "hătcăiesc": "hătcăi",
    "hătcăiește": "hătcăi",
    "hătcăiești": "hătcăi",
    "hătcăii": "hătcăi",
    "hătcăim": "hătcăi",
    "hătcăind": "hătcăi",
    "hătcăindu": "hătcăi",
    "hătcăiră": "hătcăi",
    "hătcăirăm": "hătcăi",
    "hătcăirăți": "hătcăi",
    "hătcăise": "hătcăi",
    "hătcăisem": "hătcăi",
    "hătcăiseră": "hătcăi",
    "hătcăiserăm": "hătcăi",
    "hătcăiserăți": "hătcăi",
    "hătcăiseși": "hătcăi",
    "hătcăiși": "hătcăi",
    "hătcăit": "hătcăi",
    "hătcăiți": "hătcăi",
    "hătcăitu": "hătcăi",
    "nehătcăind": "hătcăi",
    "nehătcăindu": "hătcăi",
    "nemaihătcăind": "hătcăi",
    "nemaihătcăindu": "hătcăi",
    "hătcăită": "hătcăit",
    "hătcăite": "hătcăit",
    "hătcăiți": "hătcăit",
    "hătea": "hăti",
    "hăteai": "hăti",
    "hăteam": "hăti",
    "hătească": "hăti",
    "hăteați": "hăti",
    "hăteau": "hăti",
    "hătesc": "hăti",
    "hătește": "hăti",
    "hătești": "hăti",
    "hătii": "hăti",
    "hătim": "hăti",
    "hătind": "hăti",
    "hătindu": "hăti",
    "hătiră": "hăti",
    "hătirăm": "hăti",
    "hătirăți": "hăti",
    "hătise": "hăti",
    "hătisem": "hăti",
    "hătiseră": "hăti",
    "hătiserăm": "hăti",
    "hătiserăți": "hăti",
    "hătiseși": "hăti",
    "hătiși": "hăti",
    "hătit": "hăti",
    "hătiți": "hăti",
    "hătitu": "hăti",
    "nehătind": "hăti",
    "nehătindu": "hăti",
    "nemaihătind": "hăti",
    "nemaihătindu": "hăti",
    "hățea": "hăți",
    "hățeai": "hăți",
    "hățeam": "hăți",
    "hățească": "hăți",
    "hățeați": "hăți",
    "hățeau": "hăți",
    "hățesc": "hăți",
    "hățește": "hăți",
    "hățești": "hăți",
    "hății": "hăți",
    "hățim": "hăți",
    "hățind": "hăți",
    "hățindu": "hăți",
    "hățiră": "hăți",
    "hățirăm": "hăți",
    "hățirăți": "hăți",
    "hățise": "hăți",
    "hățisem": "hăți",
    "hățiseră": "hăți",
    "hățiserăm": "hăți",
    "hățiserăți": "hăți",
    "hățiseși": "hăți",
    "hățiși": "hăți",
    "hățit": "hăți",
    "hățiți": "hăți",
    "hățitu": "hăți",
    "nehățind": "hăți",
    "nehățindu": "hăți",
    "nemaihățind": "hăți",
    "nemaihățindu": "hăți",
    "hățișul": "hățiș",
    "hățișului": "hățiș",
    "hățișuri": "hățiș",
    "hățișurile": "hățiș",
    "hățișurilor": "hățiș",
    "hătită": "hătit",
    "hătite": "hătit",
    "hătiți": "hătit",
    "hățită": "hățit",
    "hățite": "hățit",
    "hățiți": "hățit",
    "hățuia": "hățui",
    "hățuiai": "hățui",
    "hățuiam": "hățui",
    "hățuiască": "hățui",
    "hățuiați": "hățui",
    "hățuiau": "hățui",
    "hățuiesc": "hățui",
    "hățuiește": "hățui",
    "hățuiești": "hățui",
    "hățuii": "hățui",
    "hățuim": "hățui",
    "hățuind": "hățui",
    "hățuindu": "hățui",
    "hățuiră": "hățui",
    "hățuirăm": "hățui",
    "hățuirăți": "hățui",
    "hățuise": "hățui",
    "hățuisem": "hățui",
    "hățuiseră": "hățui",
    "hățuiserăm": "hățui",
    "hățuiserăți": "hățui",
    "hățuiseși": "hățui",
    "hățuiși": "hățui",
    "hățuit": "hățui",
    "hățuiți": "hățui",
    "hățuitu": "hățui",
    "nehățuind": "hățui",
    "nehățuindu": "hățui",
    "nemaihățuind": "hățui",
    "nemaihățuindu": "hățui",
    "hățuită": "hățuit",
    "hățuite": "hățuit",
    "hățuiți": "hățuit",
    "hăul": "hău",
    "hăule": "hău",
    "hăului": "hău",
    "hăuri": "hău",
    "hăurile": "hău",
    "hăurilor": "hău",
    "hăulea": "hăuli",
    "hăuleai": "hăuli",
    "hăuleam": "hăuli",
    "hăulească": "hăuli",
    "hăuleați": "hăuli",
    "hăuleau": "hăuli",
    "hăulesc": "hăuli",
    "hăulește": "hăuli",
    "hăulești": "hăuli",
    "hăulii": "hăuli",
    "hăulim": "hăuli",
    "hăulind": "hăuli",
    "hăulindu": "hăuli",
    "hăuliră": "hăuli",
    "hăulirăm": "hăuli",
    "hăulirăți": "hăuli",
    "hăulise": "hăuli",
    "hăulisem": "hăuli",
    "hăuliseră": "hăuli",
    "hăuliserăm": "hăuli",
    "hăuliserăți": "hăuli",
    "hăuliseși": "hăuli",
    "hăuliși": "hăuli",
    "hăulit": "hăuli",
    "hăuliți": "hăuli",
    "hăulitu": "hăuli",
    "nehăulind": "hăuli",
    "nehăulindu": "hăuli",
    "nemaihăulind": "hăuli",
    "nemaihăulindu": "hăuli",
    "hăulită": "hăulit",
    "hăulite": "hăulit",
    "hăuliți": "hăulit",
    "havă": "hava",
    "havai": "hava",
    "havam": "hava",
    "havăm": "hava",
    "havând": "hava",
    "havându": "hava",
    "havară": "hava",
    "havarăm": "hava",
    "havarăți": "hava",
    "havase": "hava",
    "havasem": "hava",
    "havaseră": "hava",
    "havaserăm": "hava",
    "havaserăți": "hava",
    "havaseși": "hava",
    "havași": "hava",
    "havat": "hava",
    "havați": "hava",
    "havatu": "hava",
    "havau": "hava",
    "havează": "hava",
    "havez": "hava",
    "haveze": "hava",
    "havezi": "hava",
    "nehavând": "hava",
    "nehavându": "hava",
    "nemaihavând": "hava",
    "nemaihavându": "hava",
    "havată": "havat",
    "havate": "havat",
    "havați": "havat",
    "havuzul": "havuz",
    "havuzului": "havuz",
    "havuzuri": "havuz",
    "havuzurile": "havuz",
    "havuzurilor": "havuz",
    "hazul": "haz",
    "hazului": "haz",
    "hazuri": "haz",
    "hazurile": "haz",
    "hazurilor": "haz",
    "hazardul": "hazard",
    "hazardului": "hazard",
    "hazarduri": "hazard",
    "hazardurile": "hazard",
    "hazardurilor": "hazard",
    "hazardă": "hazarda",
    "hazardai": "hazarda",
    "hazardam": "hazarda",
    "hazardăm": "hazarda",
    "hazardând": "hazarda",
    "hazardându": "hazarda",
    "hazardară": "hazarda",
    "hazardarăm": "hazarda",
    "hazardarăți": "hazarda",
    "hazardase": "hazarda",
    "hazardasem": "hazarda",
    "hazardaseră": "hazarda",
    "hazardaserăm": "hazarda",
    "hazardaserăți": "hazarda",
    "hazardaseși": "hazarda",
    "hazardași": "hazarda",
    "hazardat": "hazarda",
    "hazardați": "hazarda",
    "hazardatu": "hazarda",
    "hazardau": "hazarda",
    "hazardează": "hazarda",
    "hazardez": "hazarda",
    "hazardeze": "hazarda",
    "hazardezi": "hazarda",
    "nehazardând": "hazarda",
    "nehazardându": "hazarda",
    "nemaihazardând": "hazarda",
    "nemaihazardându": "hazarda",
    "hazardata": "hazardat",
    "hazardată": "hazardat",
    "hazardate": "hazardat",
    "hazardatei": "hazardat",
    "hazardatele": "hazardat",
    "hazardatelor": "hazardat",
    "hazardați": "hazardat",
    "hazardații": "hazardat",
    "hazardaților": "hazardat",
    "hazardatul": "hazardat",
    "hazardatului": "hazardat",
    "hâzea": "hâzi",
    "hâzeai": "hâzi",
    "hâzeam": "hâzi",
    "hâzească": "hâzi",
    "hâzeați": "hâzi",
    "hâzeau": "hâzi",
    "hâzesc": "hâzi",
    "hâzește": "hâzi",
    "hâzești": "hâzi",
    "hâzii": "hâzi",
    "hâzim": "hâzi",
    "hâzind": "hâzi",
    "hâzindu": "hâzi",
    "hâziră": "hâzi",
    "hâzirăm": "hâzi",
    "hâzirăți": "hâzi",
    "hâzise": "hâzi",
    "hâzisem": "hâzi",
    "hâziseră": "hâzi",
    "hâziserăm": "hâzi",
    "hâziserăți": "hâzi",
    "hâziseși": "hâzi",
    "hâziși": "hâzi",
    "hâzit": "hâzi",
    "hâziți": "hâzi",
    "hâzitu": "hâzi",
    "nehâzind": "hâzi",
    "nehâzindu": "hâzi",
    "nemaihâzind": "hâzi",
    "nemaihâzindu": "hâzi",
    "hâzită": "hâzit",
    "hâzite": "hâzit",
    "hâziți": "hâzit",
    "hazlia": "hazliu",
    "hazlie": "hazliu",
    "hazliei": "hazliu",
    "hazlii": "hazliu",
    "hazliii": "hazliu",
    "hazliile": "hazliu",
    "hazliilor": "hazliu",
    "hazliul": "hazliu",
    "hazliului": "hazliu",
    "ha": "hectar",
    "hectare": "hectar",
    "hectarele": "hectar",
    "hectarelor": "hectar",
    "hectarul": "hectar",
    "hectarului": "hectar",
    "hectograme": "hectogram",
    "hg": "hectogram",
    "hectolitrica": "hectolitric",
    "hectolitrică": "hectolitric",
    "hectolitrice": "hectolitric",
    "hectolitrici": "hectolitric",
    "hectolitri": "hectolitru",
    "hl": "hectolitru",
    "hectometri": "hectometru",
    "hm": "hectometru",
    "hedonistica": "hedonistic",
    "hedonistică": "hedonistic",
    "hedonistice": "hedonistic",
    "hedonisticei": "hedonistic",
    "hedonisticele": "hedonistic",
    "hedonisticelor": "hedonistic",
    "hedonistici": "hedonistic",
    "hedonisticii": "hedonistic",
    "hedonisticilor": "hedonistic",
    "hedonistico": "hedonistic",
    "hedonisticul": "hedonistic",
    "hedonisticule": "hedonistic",
    "hedonisticului": "hedonistic",
    "hegemonia": "hegemonie",
    "hegemoniei": "hegemonie",
    "hegemonii": "hegemonie",
    "hegemoniile": "hegemonie",
    "hegemoniilor": "hegemonie",
    "heleștee": "heleșteu",
    "heleșteele": "heleșteu",
    "heleșteelor": "heleșteu",
    "heleșteul": "heleșteu",
    "heleșteului": "heleșteu",
    "helicoptere": "helicopter",
    "helicopterele": "helicopter",
    "helicopterelor": "helicopter",
    "helicopterul": "helicopter",
    "helicopterului": "helicopter",
    "hematia": "hematie",
    "hematiei": "hematie",
    "hematii": "hematie",
    "hematiile": "hematie",
    "hematiilor": "hematie",
    "hematologia": "hematologie",
    "hematologiei": "hematologie",
    "hematologii": "hematologie",
    "hematologiile": "hematologie",
    "hematologiilor": "hematologie",
    "hematologio": "hematologie",
    "hemoglobina": "hemoglobină",
    "hemoglobine": "hemoglobină",
    "hemoglobinei": "hemoglobină",
    "hemograma": "hemogramă",
    "hemograme": "hemogramă",
    "hemogramei": "hemogramă",
    "hemogramele": "hemogramă",
    "hemogramelor": "hemogramă",
    "hemoragia": "hemoragie",
    "hemoragiei": "hemoragie",
    "hemoragii": "hemoragie",
    "hemoragiile": "hemoragie",
    "hemoragiilor": "hemoragie",
    "hepatita": "hepatită",
    "hepatite": "hepatită",
    "hepatitei": "hepatită",
    "hepatitele": "hepatită",
    "hepatitelor": "hepatită",
    "Herei": "Hera",
    "heraldica": "heraldică",
    "heraldici": "heraldică",
    "heraldicii": "heraldică",
    "herghelia": "herghelie",
    "hergheliei": "herghelie",
    "herghelii": "herghelie",
    "hergheliile": "herghelie",
    "hergheliilor": "herghelie",
    "heringi": "hering",
    "heringii": "hering",
    "heringilor": "hering",
    "heringul": "hering",
    "heringului": "hering",
    "hermina": "hermină",
    "hermine": "hermină",
    "herminei": "hermină",
    "herminele": "hermină",
    "herminelor": "hermină",
    "hernia": "hernie",
    "herniei": "hernie",
    "hernii": "hernie",
    "herniile": "hernie",
    "herniilor": "hernie",
    "hertzi": "hertz",
    "Hz": "hertz",
    "heruvimi": "heruvim",
    "heruvimii": "heruvim",
    "heruvimilor": "heruvim",
    "heruvimul": "heruvim",
    "heruvimule": "heruvim",
    "heruvimului": "heruvim",
    "heteroclita": "heteroclit",
    "heteroclită": "heteroclit",
    "heteroclite": "heteroclit",
    "heteroclitei": "heteroclit",
    "heteroclitele": "heteroclit",
    "heteroclitelor": "heteroclit",
    "heterocliți": "heteroclit",
    "heterocliții": "heteroclit",
    "heterocliților": "heteroclit",
    "heteroclitul": "heteroclit",
    "heteroclitului": "heteroclit",
    "hexagoane": "hexagon",
    "hexagoanele": "hexagon",
    "hexagoanelor": "hexagon",
    "hexagonul": "hexagon",
    "hexagonului": "hexagon",
    "hexagonala": "hexagonal",
    "hexagonală": "hexagonal",
    "hexagonale": "hexagonal",
    "hexagonalei": "hexagonal",
    "hexagonalele": "hexagonal",
    "hexagonalelor": "hexagonal",
    "hexagonali": "hexagonal",
    "hexagonalii": "hexagonal",
    "hexagonalilor": "hexagonal",
    "hexagonalul": "hexagonal",
    "hexagonalului": "hexagonal",
    "hexametri": "hexametru",
    "hexametrii": "hexametru",
    "hexametrilor": "hexametru",
    "hexametrul": "hexametru",
    "hexametrului": "hexametru",
    "hiba": "hibă",
    "hibe": "hibă",
    "hibei": "hibă",
    "hibele": "hibă",
    "hibelor": "hibă",
    "hibo": "hibă",
    "hibernă": "hiberna",
    "hibernai": "hiberna",
    "hibernam": "hiberna",
    "hibernăm": "hiberna",
    "hibernând": "hiberna",
    "hibernându": "hiberna",
    "hibernară": "hiberna",
    "hibernarăm": "hiberna",
    "hibernarăți": "hiberna",
    "hibernase": "hiberna",
    "hibernasem": "hiberna",
    "hibernaseră": "hiberna",
    "hibernaserăm": "hiberna",
    "hibernaserăți": "hiberna",
    "hibernaseși": "hiberna",
    "hibernași": "hiberna",
    "hibernat": "hiberna",
    "hibernați": "hiberna",
    "hibernatu": "hiberna",
    "hibernau": "hiberna",
    "hibernează": "hiberna",
    "hibernez": "hiberna",
    "hiberneze": "hiberna",
    "hibernezi": "hiberna",
    "nehibernând": "hiberna",
    "nehibernându": "hiberna",
    "nemaihibernând": "hiberna",
    "nemaihibernându": "hiberna",
    "hibernala": "hibernal",
    "hibernală": "hibernal",
    "hibernale": "hibernal",
    "hibernalei": "hibernal",
    "hibernalele": "hibernal",
    "hibernalelor": "hibernal",
    "hibernali": "hibernal",
    "hibernalii": "hibernal",
    "hibernalilor": "hibernal",
    "hibernalo": "hibernal",
    "hibernalul": "hibernal",
    "hibernalule": "hibernal",
    "hibernalului": "hibernal",
    "hibernarea": "hibernare",
    "hibernări": "hibernare",
    "hibernării": "hibernare",
    "hibernările": "hibernare",
    "hibernărilor": "hibernare",
    "hibernată": "hibernat",
    "hibernate": "hibernat",
    "hibernați": "hibernat",
    "hibridul": "hibrid",
    "hibridului": "hibrid",
    "hibrizi": "hibrid",
    "hibrizii": "hibrid",
    "hibrizilor": "hibrid",
    "hibridă": "hibrida",
    "hibridai": "hibrida",
    "hibridam": "hibrida",
    "hibridăm": "hibrida",
    "hibridând": "hibrida",
    "hibridându": "hibrida",
    "hibridară": "hibrida",
    "hibridarăm": "hibrida",
    "hibridarăți": "hibrida",
    "hibridase": "hibrida",
    "hibridasem": "hibrida",
    "hibridaseră": "hibrida",
    "hibridaserăm": "hibrida",
    "hibridaserăți": "hibrida",
    "hibridaseși": "hibrida",
    "hibridași": "hibrida",
    "hibridat": "hibrida",
    "hibridați": "hibrida",
    "hibridatu": "hibrida",
    "hibridau": "hibrida",
    "hibridează": "hibrida",
    "hibridez": "hibrida",
    "hibrideze": "hibrida",
    "hibridezi": "hibrida",
    "nehibridând": "hibrida",
    "nehibridându": "hibrida",
    "nemaihibridând": "hibrida",
    "nemaihibridându": "hibrida",
    "hibridată": "hibridat",
    "hibridate": "hibridat",
    "hibridați": "hibridat",
    "hibridiză": "hibridiza",
    "hibridizai": "hibridiza",
    "hibridizam": "hibridiza",
    "hibridizăm": "hibridiza",
    "hibridizând": "hibridiza",
    "hibridizându": "hibridiza",
    "hibridizară": "hibridiza",
    "hibridizarăm": "hibridiza",
    "hibridizarăți": "hibridiza",
    "hibridizase": "hibridiza",
    "hibridizasem": "hibridiza",
    "hibridizaseră": "hibridiza",
    "hibridizaserăm": "hibridiza",
    "hibridizaserăți": "hibridiza",
    "hibridizaseși": "hibridiza",
    "hibridizași": "hibridiza",
    "hibridizat": "hibridiza",
    "hibridizați": "hibridiza",
    "hibridizatu": "hibridiza",
    "hibridizau": "hibridiza",
    "nehibridizând": "hibridiza",
    "nehibridizându": "hibridiza",
    "nemaihibridizând": "hibridiza",
    "nemaihibridizându": "hibridiza",
    "hibridizată": "hibridizat",
    "hibridizate": "hibridizat",
    "hibridizați": "hibridizat",
    "hicăia": "hicăi",
    "hicăiai": "hicăi",
    "hicăiam": "hicăi",
    "hicăiască": "hicăi",
    "hicăiați": "hicăi",
    "hicăiau": "hicăi",
    "hicăiesc": "hicăi",
    "hicăiește": "hicăi",
    "hicăiești": "hicăi",
    "hicăii": "hicăi",
    "hicăim": "hicăi",
    "hicăind": "hicăi",
    "hicăindu": "hicăi",
    "hicăiră": "hicăi",
    "hicăirăm": "hicăi",
    "hicăirăți": "hicăi",
    "hicăise": "hicăi",
    "hicăisem": "hicăi",
    "hicăiseră": "hicăi",
    "hicăiserăm": "hicăi",
    "hicăiserăți": "hicăi",
    "hicăiseși": "hicăi",
    "hicăiși": "hicăi",
    "hicăit": "hicăi",
    "hicăiți": "hicăi",
    "hicăitu": "hicăi",
    "nehicăind": "hicăi",
    "nehicăindu": "hicăi",
    "nemaihicăind": "hicăi",
    "nemaihicăindu": "hicăi",
    "hicăită": "hicăit",
    "hicăite": "hicăit",
    "hicăiți": "hicăit",
    "hidoasa": "hidos",
    "hidoasă": "hidos",
    "hidoase": "hidos",
    "hidoasei": "hidos",
    "hidoasele": "hidos",
    "hidoaselor": "hidos",
    "hidoși": "hidos",
    "hidoșii": "hidos",
    "hidoșilor": "hidos",
    "hidosul": "hidos",
    "hidosului": "hidos",
    "hidrați": "hidrat",
    "hidrații": "hidrat",
    "hidraților": "hidrat",
    "hidratul": "hidrat",
    "hidratului": "hidrat",
    "hidrată": "hidrata",
    "hidratai": "hidrata",
    "hidratam": "hidrata",
    "hidratăm": "hidrata",
    "hidratând": "hidrata",
    "hidratându": "hidrata",
    "hidratară": "hidrata",
    "hidratarăm": "hidrata",
    "hidratarăți": "hidrata",
    "hidratase": "hidrata",
    "hidratasem": "hidrata",
    "hidrataseră": "hidrata",
    "hidrataserăm": "hidrata",
    "hidrataserăți": "hidrata",
    "hidrataseși": "hidrata",
    "hidratași": "hidrata",
    "hidratat": "hidrata",
    "hidratați": "hidrata",
    "hidratatu": "hidrata",
    "hidratau": "hidrata",
    "hidratează": "hidrata",
    "hidratez": "hidrata",
    "hidrateze": "hidrata",
    "hidratezi": "hidrata",
    "nehidratând": "hidrata",
    "nehidratându": "hidrata",
    "nemaihidratând": "hidrata",
    "nemaihidratându": "hidrata",
    "hidratată": "hidratat",
    "hidratate": "hidratat",
    "hidratați": "hidratat",
    "hidraulica": "hidraulic",
    "hidraulică": "hidraulic",
    "hidraulice": "hidraulic",
    "hidraulicei": "hidraulic",
    "hidraulicele": "hidraulic",
    "hidraulicelor": "hidraulic",
    "hidraulici": "hidraulic",
    "hidraulicii": "hidraulic",
    "hidraulicilor": "hidraulic",
    "hidraulicul": "hidraulic",
    "hidraulicului": "hidraulic",
    "hidraulica": "hidraulică",
    "hidraulici": "hidraulică",
    "hidraulicii": "hidraulică",
    "hidraulicile": "hidraulică",
    "hidraulicilor": "hidraulică",
    "hidroavioane": "hidroavion",
    "hidroavioanele": "hidroavion",
    "hidroavioanelor": "hidroavion",
    "hidroavionul": "hidroavion",
    "hidroavionului": "hidroavion",
    "hidrocarbura": "hidrocarbură",
    "hidrocarburi": "hidrocarbură",
    "hidrocarburii": "hidrocarbură",
    "hidrocarburile": "hidrocarbură",
    "hidrocarburilor": "hidrocarbură",
    "hidrocentrala": "hidrocentrală",
    "hidrocentrale": "hidrocentrală",
    "hidrocentralei": "hidrocentrală",
    "hidrocentralele": "hidrocentrală",
    "hidrocentralelor": "hidrocentrală",
    "H": "hidrogen",
    "hidrogenul": "hidrogen",
    "hidrogenului": "hidrogen",
    "hidrogenă": "hidrogena",
    "hidrogenai": "hidrogena",
    "hidrogenam": "hidrogena",
    "hidrogenăm": "hidrogena",
    "hidrogenând": "hidrogena",
    "hidrogenându": "hidrogena",
    "hidrogenară": "hidrogena",
    "hidrogenarăm": "hidrogena",
    "hidrogenarăți": "hidrogena",
    "hidrogenase": "hidrogena",
    "hidrogenasem": "hidrogena",
    "hidrogenaseră": "hidrogena",
    "hidrogenaserăm": "hidrogena",
    "hidrogenaserăți": "hidrogena",
    "hidrogenaseși": "hidrogena",
    "hidrogenași": "hidrogena",
    "hidrogenat": "hidrogena",
    "hidrogenați": "hidrogena",
    "hidrogenatu": "hidrogena",
    "hidrogenau": "hidrogena",
    "hidrogenează": "hidrogena",
    "hidrogenez": "hidrogena",
    "hidrogeneze": "hidrogena",
    "hidrogenezi": "hidrogena",
    "nehidrogenând": "hidrogena",
    "nehidrogenându": "hidrogena",
    "nemaihidrogenând": "hidrogena",
    "nemaihidrogenându": "hidrogena",
    "hidrogenată": "hidrogenat",
    "hidrogenate": "hidrogenat",
    "hidrogenați": "hidrogenat",
    "hiena": "hienă",
    "hiene": "hienă",
    "hienei": "hienă",
    "hienele": "hienă",
    "hienelor": "hienă",
    "hieratica": "hieratic",
    "hieratică": "hieratic",
    "hieratice": "hieratic",
    "hieraticei": "hieratic",
    "hieraticele": "hieratic",
    "hieraticelor": "hieratic",
    "hieratici": "hieratic",
    "hieraticii": "hieratic",
    "hieraticilor": "hieratic",
    "hieratico": "hieratic",
    "hieraticul": "hieratic",
    "hieraticule": "hieratic",
    "hieraticului": "hieratic",
    "hieroglifa": "hieroglifă",
    "hieroglife": "hieroglifă",
    "hieroglifei": "hieroglifă",
    "hieroglifele": "hieroglifă",
    "hieroglifelor": "hieroglifă",
    "himera": "himeră",
    "himere": "himeră",
    "himerei": "himeră",
    "himerele": "himeră",
    "himerelor": "himeră",
    "himerica": "himeric",
    "himerică": "himeric",
    "himerice": "himeric",
    "himericei": "himeric",
    "himericele": "himeric",
    "himericelor": "himeric",
    "himerici": "himeric",
    "himericii": "himeric",
    "himericilor": "himeric",
    "himericul": "himeric",
    "himericului": "himeric",
    "hindusa": "hindus",
    "hindusă": "hindus",
    "hinduse": "hindus",
    "hindusei": "hindus",
    "hindusele": "hindus",
    "hinduselor": "hindus",
    "hinduși": "hindus",
    "hindușii": "hindus",
    "hindușilor": "hindus",
    "hindusul": "hindus",
    "hindusului": "hindus",
    "hingheri": "hingher",
    "hingherii": "hingher",
    "hingherilor": "hingher",
    "hingherul": "hingher",
    "hingherului": "hingher",
    "hiperbola": "hiperbolă",
    "hiperbole": "hiperbolă",
    "hiperbolei": "hiperbolă",
    "hiperbolele": "hiperbolă",
    "hiperbolelor": "hiperbolă",
    "hipertensiunea": "hipertensiune",
    "hipertensiuni": "hipertensiune",
    "hipertensiunii": "hipertensiune",
    "hipertrofiai": "hipertrofia",
    "hipertrofiam": "hipertrofia",
    "hipertrofiară": "hipertrofia",
    "hipertrofiarăm": "hipertrofia",
    "hipertrofiarăți": "hipertrofia",
    "hipertrofiase": "hipertrofia",
    "hipertrofiasem": "hipertrofia",
    "hipertrofiaseră": "hipertrofia",
    "hipertrofiaserăm": "hipertrofia",
    "hipertrofiaserăți": "hipertrofia",
    "hipertrofiaseși": "hipertrofia",
    "hipertrofiași": "hipertrofia",
    "hipertrofiat": "hipertrofia",
    "hipertrofiați": "hipertrofia",
    "hipertrofiatu": "hipertrofia",
    "hipertrofiau": "hipertrofia",
    "hipertrofiază": "hipertrofia",
    "hipertrofie": "hipertrofia",
    "hipertrofiem": "hipertrofia",
    "hipertrofiez": "hipertrofia",
    "hipertrofieze": "hipertrofia",
    "hipertrofiezi": "hipertrofia",
    "hipertrofiind": "hipertrofia",
    "hipertrofiindu": "hipertrofia",
    "nehipertrofiind": "hipertrofia",
    "nehipertrofiindu": "hipertrofia",
    "nemaihipertrofiind": "hipertrofia",
    "nemaihipertrofiindu": "hipertrofia",
    "hipertrofiată": "hipertrofiat",
    "hipertrofiate": "hipertrofiat",
    "hipertrofiați": "hipertrofiat",
    "hipertrofia": "hipertrofie",
    "hipertrofiei": "hipertrofie",
    "hipertrofii": "hipertrofie",
    "hipica": "hipic",
    "hipică": "hipic",
    "hipice": "hipic",
    "hipicei": "hipic",
    "hipicele": "hipic",
    "hipicelor": "hipic",
    "hipici": "hipic",
    "hipicii": "hipic",
    "hipicilor": "hipic",
    "hipicul": "hipic",
    "hipicului": "hipic",
    "hipismul": "hipism",
    "hipismului": "hipism",
    "hipnotica": "hipnotic",
    "hipnotică": "hipnotic",
    "hipnotice": "hipnotic",
    "hipnoticei": "hipnotic",
    "hipnoticele": "hipnotic",
    "hipnoticelor": "hipnotic",
    "hipnotici": "hipnotic",
    "hipnoticii": "hipnotic",
    "hipnoticilor": "hipnotic",
    "hipnoticul": "hipnotic",
    "hipnoticului": "hipnotic",
    "hipnotismul": "hipnotism",
    "hipnotismului": "hipnotism",
    "hipnotiză": "hipnotiza",
    "hipnotizai": "hipnotiza",
    "hipnotizam": "hipnotiza",
    "hipnotizăm": "hipnotiza",
    "hipnotizând": "hipnotiza",
    "hipnotizându": "hipnotiza",
    "hipnotizară": "hipnotiza",
    "hipnotizarăm": "hipnotiza",
    "hipnotizarăți": "hipnotiza",
    "hipnotizase": "hipnotiza",
    "hipnotizasem": "hipnotiza",
    "hipnotizaseră": "hipnotiza",
    "hipnotizaserăm": "hipnotiza",
    "hipnotizaserăți": "hipnotiza",
    "hipnotizaseși": "hipnotiza",
    "hipnotizași": "hipnotiza",
    "hipnotizat": "hipnotiza",
    "hipnotizați": "hipnotiza",
    "hipnotizatu": "hipnotiza",
    "hipnotizau": "hipnotiza",
    "hipnotizează": "hipnotiza",
    "hipnotizez": "hipnotiza",
    "hipnotizeze": "hipnotiza",
    "hipnotizezi": "hipnotiza",
    "nehipnotizând": "hipnotiza",
    "nehipnotizându": "hipnotiza",
    "nemaihipnotizând": "hipnotiza",
    "nemaihipnotizându": "hipnotiza",
    "hipnotizată": "hipnotizat",
    "hipnotizate": "hipnotizat",
    "hipnotizați": "hipnotizat",
    "hipnoza": "hipnoză",
    "hipnoze": "hipnoză",
    "hipnozei": "hipnoză",
    "hipnozele": "hipnoză",
    "hipnozelor": "hipnoză",
    "hipodermica": "hipodermic",
    "hipodermică": "hipodermic",
    "hipodermice": "hipodermic",
    "hipodermicei": "hipodermic",
    "hipodermicele": "hipodermic",
    "hipodermicelor": "hipodermic",
    "hipodermici": "hipodermic",
    "hipodermicii": "hipodermic",
    "hipodermicilor": "hipodermic",
    "hipodermicul": "hipodermic",
    "hipodermicului": "hipodermic",
    "hipodromul": "hipodrom",
    "hipodromului": "hipodrom",
    "hipodromuri": "hipodrom",
    "hipodromurile": "hipodrom",
    "hipodromurilor": "hipodrom",
    "hipofiza": "hipofiză",
    "hipofize": "hipofiză",
    "hipofizei": "hipofiză",
    "hipofizele": "hipofiză",
    "hipofizelor": "hipofiză",
    "hipopotami": "hipopotam",
    "hipopotamii": "hipopotam",
    "hipopotamilor": "hipopotam",
    "hipopotamul": "hipopotam",
    "hipopotamului": "hipopotam",
    "hipotensiunea": "hipotensiune",
    "hipotensiuni": "hipotensiune",
    "hipotensiunii": "hipotensiune",
    "hiritisea": "hiritisi",
    "hiritiseai": "hiritisi",
    "hiritiseam": "hiritisi",
    "hiritisească": "hiritisi",
    "hiritiseați": "hiritisi",
    "hiritiseau": "hiritisi",
    "hiritisesc": "hiritisi",
    "hiritisește": "hiritisi",
    "hiritisești": "hiritisi",
    "hiritisii": "hiritisi",
    "hiritisim": "hiritisi",
    "hiritisind": "hiritisi",
    "hiritisindu": "hiritisi",
    "hiritisiră": "hiritisi",
    "hiritisirăm": "hiritisi",
    "hiritisirăți": "hiritisi",
    "hiritisise": "hiritisi",
    "hiritisisem": "hiritisi",
    "hiritisiseră": "hiritisi",
    "hiritisiserăm": "hiritisi",
    "hiritisiserăți": "hiritisi",
    "hiritisiseși": "hiritisi",
    "hiritisiși": "hiritisi",
    "hiritisit": "hiritisi",
    "hiritisiți": "hiritisi",
    "hiritisitu": "hiritisi",
    "nehiritisind": "hiritisi",
    "nehiritisindu": "hiritisi",
    "nemaihiritisind": "hiritisi",
    "nemaihiritisindu": "hiritisi",
    "hiritisită": "hiritisit",
    "hiritisite": "hiritisit",
    "hiritisiți": "hiritisit",
    "hirotonea": "hirotoni",
    "hirotoneai": "hirotoni",
    "hirotoneam": "hirotoni",
    "hirotonească": "hirotoni",
    "hirotoneați": "hirotoni",
    "hirotoneau": "hirotoni",
    "hirotonesc": "hirotoni",
    "hirotonește": "hirotoni",
    "hirotonești": "hirotoni",
    "hirotonii": "hirotoni",
    "hirotonim": "hirotoni",
    "hirotonind": "hirotoni",
    "hirotonindu": "hirotoni",
    "hirotoniră": "hirotoni",
    "hirotonirăm": "hirotoni",
    "hirotonirăți": "hirotoni",
    "hirotonise": "hirotoni",
    "hirotonisem": "hirotoni",
    "hirotoniseră": "hirotoni",
    "hirotoniserăm": "hirotoni",
    "hirotoniserăți": "hirotoni",
    "hirotoniseși": "hirotoni",
    "hirotoniși": "hirotoni",
    "hirotonit": "hirotoni",
    "hirotoniți": "hirotoni",
    "hirotonitu": "hirotoni",
    "nehirotonind": "hirotoni",
    "nehirotonindu": "hirotoni",
    "nemaihirotonind": "hirotoni",
    "nemaihirotonindu": "hirotoni",
    "hirotonia": "hirotonie",
    "hirotoniei": "hirotonie",
    "hirotonii": "hirotonie",
    "hirotoniile": "hirotonie",
    "hirotoniilor": "hirotonie",
    "hirotonio": "hirotonie",
    "hirotonirea": "hirotonire",
    "hirotonireo": "hirotonire",
    "hirotoniri": "hirotonire",
    "hirotonirii": "hirotonire",
    "hirotonirile": "hirotonire",
    "hirotonirilor": "hirotonire",
    "hirotonisea": "hirotonisi",
    "hirotoniseai": "hirotonisi",
    "hirotoniseam": "hirotonisi",
    "hirotonisească": "hirotonisi",
    "hirotoniseați": "hirotonisi",
    "hirotoniseau": "hirotonisi",
    "hirotonisesc": "hirotonisi",
    "hirotonisește": "hirotonisi",
    "hirotonisești": "hirotonisi",
    "hirotonisii": "hirotonisi",
    "hirotonisim": "hirotonisi",
    "hirotonisind": "hirotonisi",
    "hirotonisindu": "hirotonisi",
    "hirotonisiră": "hirotonisi",
    "hirotonisirăm": "hirotonisi",
    "hirotonisirăți": "hirotonisi",
    "hirotonisise": "hirotonisi",
    "hirotonisisem": "hirotonisi",
    "hirotonisiseră": "hirotonisi",
    "hirotonisiserăm": "hirotonisi",
    "hirotonisiserăți": "hirotonisi",
    "hirotonisiseși": "hirotonisi",
    "hirotonisiși": "hirotonisi",
    "hirotonisit": "hirotonisi",
    "hirotonisiți": "hirotonisi",
    "hirotonisitu": "hirotonisi",
    "nehirotonisind": "hirotonisi",
    "nehirotonisindu": "hirotonisi",
    "nemaihirotonisind": "hirotonisi",
    "nemaihirotonisindu": "hirotonisi",
    "hirotonisirea": "hirotonisire",
    "hirotonisireo": "hirotonisire",
    "hirotonisiri": "hirotonisire",
    "hirotonisirii": "hirotonisire",
    "hirotonisirile": "hirotonisire",
    "hirotonisirilor": "hirotonisire",
    "hirotonisită": "hirotonisit",
    "hirotonisite": "hirotonisit",
    "hirotonisiți": "hirotonisit",
    "hirotonită": "hirotonit",
    "hirotonite": "hirotonit",
    "hirotoniți": "hirotonit",
    "hitul": "hit",
    "hitule": "hit",
    "hitului": "hit",
    "hituri": "hit",
    "hiturile": "hit",
    "hiturilor": "hit",
    "hitlerismul": "hitlerism",
    "hitlerismului": "hitlerism",
    "hitlerista": "hitlerist",
    "hitleristă": "hitlerist",
    "hitleriste": "hitlerist",
    "hitleristei": "hitlerist",
    "hitleristele": "hitlerist",
    "hitleristelor": "hitlerist",
    "hitleriști": "hitlerist",
    "hitleriștii": "hitlerist",
    "hitleriștilor": "hitlerist",
    "hitleristo": "hitlerist",
    "hitleristul": "hitlerist",
    "hitleristule": "hitlerist",
    "hitleristului": "hitlerist",
    "hlizea": "hlizi",
    "hlizeai": "hlizi",
    "hlizeam": "hlizi",
    "hlizească": "hlizi",
    "hlizeați": "hlizi",
    "hlizeau": "hlizi",
    "hlizesc": "hlizi",
    "hlizește": "hlizi",
    "hlizești": "hlizi",
    "hlizii": "hlizi",
    "hlizim": "hlizi",
    "hlizind": "hlizi",
    "hlizindu": "hlizi",
    "hliziră": "hlizi",
    "hlizirăm": "hlizi",
    "hlizirăți": "hlizi",
    "hlizise": "hlizi",
    "hlizisem": "hlizi",
    "hliziseră": "hlizi",
    "hliziserăm": "hlizi",
    "hliziserăți": "hlizi",
    "hliziseși": "hlizi",
    "hliziși": "hlizi",
    "hlizit": "hlizi",
    "hliziți": "hlizi",
    "hlizitu": "hlizi",
    "nehlizind": "hlizi",
    "nehlizindu": "hlizi",
    "nemaihlizind": "hlizi",
    "nemaihlizindu": "hlizi",
    "hlizită": "hlizit",
    "hlizite": "hlizit",
    "hliziți": "hlizit",
    "hoarda": "hoardă",
    "hoarde": "hoardă",
    "hoardei": "hoardă",
    "hoardele": "hoardă",
    "hoardelor": "hoardă",
    "h.a.": "hoc_anno",
    "h.l.": "hoc_loco",
    "h.m.": "hoc_mense",
    "hocheiul": "hochei",
    "hocheiului": "hochei",
    "hodorogea": "hodorogi",
    "hodorogeai": "hodorogi",
    "hodorogeam": "hodorogi",
    "hodorogească": "hodorogi",
    "hodorogeați": "hodorogi",
    "hodorogeau": "hodorogi",
    "hodorogesc": "hodorogi",
    "hodorogește": "hodorogi",
    "hodorogești": "hodorogi",
    "hodorogii": "hodorogi",
    "hodorogim": "hodorogi",
    "hodorogind": "hodorogi",
    "hodorogindu": "hodorogi",
    "hodorogiră": "hodorogi",
    "hodorogirăm": "hodorogi",
    "hodorogirăți": "hodorogi",
    "hodorogise": "hodorogi",
    "hodorogisem": "hodorogi",
    "hodorogiseră": "hodorogi",
    "hodorogiserăm": "hodorogi",
    "hodorogiserăți": "hodorogi",
    "hodorogiseși": "hodorogi",
    "hodorogiși": "hodorogi",
    "hodorogit": "hodorogi",
    "hodorogiți": "hodorogi",
    "hodorogitu": "hodorogi",
    "nehodorogind": "hodorogi",
    "nehodorogindu": "hodorogi",
    "nemaihodorogind": "hodorogi",
    "nemaihodorogindu": "hodorogi",
    "hodorogita": "hodorogit",
    "hodorogită": "hodorogit",
    "hodorogite": "hodorogit",
    "hodorogitei": "hodorogit",
    "hodorogitele": "hodorogit",
    "hodorogitelor": "hodorogit",
    "hodorogiți": "hodorogit",
    "hodorogiții": "hodorogit",
    "hodorogiților": "hodorogit",
    "hodorogitul": "hodorogit",
    "hodorogitului": "hodorogit",
    "hohote": "hohot",
    "hohotele": "hohot",
    "hohotelor": "hohot",
    "hohotul": "hohot",
    "hohotului": "hohot",
    "hohotea": "hohoti",
    "hohoteai": "hohoti",
    "hohoteam": "hohoti",
    "hohotească": "hohoti",
    "hohoteați": "hohoti",
    "hohoteau": "hohoti",
    "hohotesc": "hohoti",
    "hohotește": "hohoti",
    "hohotești": "hohoti",
    "hohotii": "hohoti",
    "hohotim": "hohoti",
    "hohotind": "hohoti",
    "hohotindu": "hohoti",
    "hohotiră": "hohoti",
    "hohotirăm": "hohoti",
    "hohotirăți": "hohoti",
    "hohotise": "hohoti",
    "hohotisem": "hohoti",
    "hohotiseră": "hohoti",
    "hohotiserăm": "hohoti",
    "hohotiserăți": "hohoti",
    "hohotiseși": "hohoti",
    "hohotiși": "hohoti",
    "hohotit": "hohoti",
    "hohotiți": "hohoti",
    "hohotitu": "hohoti",
    "nehohotind": "hohoti",
    "nehohotindu": "hohoti",
    "nemaihohotind": "hohoti",
    "nemaihohotindu": "hohoti",
    "hohotită": "hohotit",
    "hohotite": "hohotit",
    "hohotiți": "hohotit",
    "hoinari": "hoinar",
    "hoinarii": "hoinar",
    "hoinarilor": "hoinar",
    "hoinarul": "hoinar",
    "hoinarului": "hoinar",
    "hoinărea": "hoinări",
    "hoinăreai": "hoinări",
    "hoinăream": "hoinări",
    "hoinărească": "hoinări",
    "hoinăreați": "hoinări",
    "hoinăreau": "hoinări",
    "hoinăresc": "hoinări",
    "hoinărește": "hoinări",
    "hoinărești": "hoinări",
    "hoinării": "hoinări",
    "hoinărim": "hoinări",
    "hoinărind": "hoinări",
    "hoinărindu": "hoinări",
    "hoinăriră": "hoinări",
    "hoinărirăm": "hoinări",
    "hoinărirăți": "hoinări",
    "hoinărise": "hoinări",
    "hoinărisem": "hoinări",
    "hoinăriseră": "hoinări",
    "hoinăriserăm": "hoinări",
    "hoinăriserăți": "hoinări",
    "hoinăriseși": "hoinări",
    "hoinăriși": "hoinări",
    "hoinărit": "hoinări",
    "hoinăriți": "hoinări",
    "hoinăritu": "hoinări",
    "nehoinărind": "hoinări",
    "nehoinărindu": "hoinări",
    "nemaihoinărind": "hoinări",
    "nemaihoinărindu": "hoinări",
    "hoinărită": "hoinărit",
    "hoinărite": "hoinărit",
    "hoinăriți": "hoinărit",
    "hoitul": "hoit",
    "hoitului": "hoit",
    "hoituri": "hoit",
    "hoiturile": "hoit",
    "hoiturilor": "hoit",
    "hojbăia": "hojbăi",
    "hojbăiai": "hojbăi",
    "hojbăiam": "hojbăi",
    "hojbăiați": "hojbăi",
    "hojbăiau": "hojbăi",
    "hojbăie": "hojbăi",
    "hojbăii": "hojbăi",
    "hojbăim": "hojbăi",
    "hojbăind": "hojbăi",
    "hojbăindu": "hojbăi",
    "hojbăiră": "hojbăi",
    "hojbăirăm": "hojbăi",
    "hojbăirăți": "hojbăi",
    "hojbăise": "hojbăi",
    "hojbăisem": "hojbăi",
    "hojbăiseră": "hojbăi",
    "hojbăiserăm": "hojbăi",
    "hojbăiserăți": "hojbăi",
    "hojbăiseși": "hojbăi",
    "hojbăiși": "hojbăi",
    "hojbăit": "hojbăi",
    "hojbăiți": "hojbăi",
    "hojbăitu": "hojbăi",
    "nehojbăind": "hojbăi",
    "nehojbăindu": "hojbăi",
    "nemaihojbăind": "hojbăi",
    "nemaihojbăindu": "hojbăi",
    "hojbăită": "hojbăit",
    "hojbăite": "hojbăit",
    "hojbăiți": "hojbăit",
    "holul": "hol",
    "holului": "hol",
    "holuri": "hol",
    "holurile": "hol",
    "holurilor": "hol",
    "holbă": "holba",
    "holbai": "holba",
    "holbam": "holba",
    "holbăm": "holba",
    "holbând": "holba",
    "holbându": "holba",
    "holbară": "holba",
    "holbarăm": "holba",
    "holbarăți": "holba",
    "holbase": "holba",
    "holbasem": "holba",
    "holbaseră": "holba",
    "holbaserăm": "holba",
    "holbaserăți": "holba",
    "holbaseși": "holba",
    "holbași": "holba",
    "holbat": "holba",
    "holbați": "holba",
    "holbatu": "holba",
    "holbau": "holba",
    "holbează": "holba",
    "holbez": "holba",
    "holbeze": "holba",
    "holbezi": "holba",
    "neholbând": "holba",
    "neholbându": "holba",
    "nemaiholbând": "holba",
    "nemaiholbându": "holba",
    "holbata": "holbat",
    "holbată": "holbat",
    "holbate": "holbat",
    "holbatei": "holbat",
    "holbatele": "holbat",
    "holbatelor": "holbat",
    "holbați": "holbat",
    "holbații": "holbat",
    "holbaților": "holbat",
    "holbatul": "holbat",
    "holbatului": "holbat",
    "holda": "holdă",
    "holde": "holdă",
    "holdei": "holdă",
    "holdele": "holdă",
    "holdelor": "holdă",
    "holera": "holeră",
    "holere": "holeră",
    "holerei": "holeră",
    "holerele": "holeră",
    "holerelor": "holeră",
    "Ho": "holmiu",
    "holmiul": "holmiu",
    "holmiului": "holmiu",
    "holteia": "holtei",
    "holteiai": "holtei",
    "holteiam": "holtei",
    "holteiască": "holtei",
    "holteiați": "holtei",
    "holteiau": "holtei",
    "holteiesc": "holtei",
    "holteiește": "holtei",
    "holteiești": "holtei",
    "holteii": "holtei",
    "holteilor": "holtei",
    "holteim": "holtei",
    "holteind": "holtei",
    "holteindu": "holtei",
    "holteiră": "holtei",
    "holteirăm": "holtei",
    "holteirăți": "holtei",
    "holteise": "holtei",
    "holteisem": "holtei",
    "holteiseră": "holtei",
    "holteiserăm": "holtei",
    "holteiserăți": "holtei",
    "holteiseși": "holtei",
    "holteiși": "holtei",
    "holteit": "holtei",
    "holteiți": "holtei",
    "holteitu": "holtei",
    "holteiul": "holtei",
    "holteiului": "holtei",
    "neholteind": "holtei",
    "neholteindu": "holtei",
    "nemaiholteind": "holtei",
    "nemaiholteindu": "holtei",
    "holteită": "holteit",
    "holteite": "holteit",
    "holteiți": "holteit",
    "homerica": "homeric",
    "homerică": "homeric",
    "homerice": "homeric",
    "homericei": "homeric",
    "homericele": "homeric",
    "homericelor": "homeric",
    "homerici": "homeric",
    "homericii": "homeric",
    "homericilor": "homeric",
    "homericul": "homeric",
    "homericului": "homeric",
    "homeridul": "homerid",
    "homeridului": "homerid",
    "homerizi": "homerid",
    "homerizii": "homerid",
    "homerizilor": "homerid",
    "homosexuali": "homosexual",
    "homosexualii": "homosexual",
    "homosexualilor": "homosexual",
    "homosexualul": "homosexual",
    "homosexualului": "homosexual",
    "homosexualitatea": "homosexualitate",
    "homosexualități": "homosexualitate",
    "homosexualității": "homosexualitate",
    "hondrănea": "hondrăni",
    "hondrăneai": "hondrăni",
    "hondrăneam": "hondrăni",
    "hondrănească": "hondrăni",
    "hondrăneați": "hondrăni",
    "hondrăneau": "hondrăni",
    "hondrănesc": "hondrăni",
    "hondrănește": "hondrăni",
    "hondrănești": "hondrăni",
    "hondrănii": "hondrăni",
    "hondrănim": "hondrăni",
    "hondrănind": "hondrăni",
    "hondrănindu": "hondrăni",
    "hondrăniră": "hondrăni",
    "hondrănirăm": "hondrăni",
    "hondrănirăți": "hondrăni",
    "hondrănise": "hondrăni",
    "hondrănisem": "hondrăni",
    "hondrăniseră": "hondrăni",
    "hondrăniserăm": "hondrăni",
    "hondrăniserăți": "hondrăni",
    "hondrăniseși": "hondrăni",
    "hondrăniși": "hondrăni",
    "hondrănit": "hondrăni",
    "hondrăniți": "hondrăni",
    "hondrănitu": "hondrăni",
    "nehondrănind": "hondrăni",
    "nehondrănindu": "hondrăni",
    "nemaihondrănind": "hondrăni",
    "nemaihondrănindu": "hondrăni",
    "hondrănită": "hondrănit",
    "hondrănite": "hondrănit",
    "hondrăniți": "hondrănit",
    "Hong-Kongul": "Hong-Kong",
    "Hong-Kongului": "Hong-Kong",
    "honipsea": "honipsi",
    "honipseai": "honipsi",
    "honipseam": "honipsi",
    "honipsească": "honipsi",
    "honipseați": "honipsi",
    "honipseau": "honipsi",
    "honipsesc": "honipsi",
    "honipsește": "honipsi",
    "honipsești": "honipsi",
    "honipsii": "honipsi",
    "honipsim": "honipsi",
    "honipsind": "honipsi",
    "honipsindu": "honipsi",
    "honipsiră": "honipsi",
    "honipsirăm": "honipsi",
    "honipsirăți": "honipsi",
    "honipsise": "honipsi",
    "honipsisem": "honipsi",
    "honipsiseră": "honipsi",
    "honipsiserăm": "honipsi",
    "honipsiserăți": "honipsi",
    "honipsiseși": "honipsi",
    "honipsiși": "honipsi",
    "honipsit": "honipsi",
    "honipsiți": "honipsi",
    "honipsitu": "honipsi",
    "nehonipsind": "honipsi",
    "nehonipsindu": "honipsi",
    "nemaihonipsind": "honipsi",
    "nemaihonipsindu": "honipsi",
    "honipsită": "honipsit",
    "honipsite": "honipsit",
    "honipsiți": "honipsit",
    "honuia": "honui",
    "honuiai": "honui",
    "honuiam": "honui",
    "honuiască": "honui",
    "honuiați": "honui",
    "honuiau": "honui",
    "honuiesc": "honui",
    "honuiește": "honui",
    "honuiești": "honui",
    "honuii": "honui",
    "honuim": "honui",
    "honuind": "honui",
    "honuindu": "honui",
    "honuiră": "honui",
    "honuirăm": "honui",
    "honuirăți": "honui",
    "honuise": "honui",
    "honuisem": "honui",
    "honuiseră": "honui",
    "honuiserăm": "honui",
    "honuiserăți": "honui",
    "honuiseși": "honui",
    "honuiși": "honui",
    "honuit": "honui",
    "honuiți": "honui",
    "honuitu": "honui",
    "nehonuind": "honui",
    "nehonuindu": "honui",
    "nemaihonuind": "honui",
    "nemaihonuindu": "honui",
    "honuită": "honuit",
    "honuite": "honuit",
    "honuiți": "honuit",
    "hopul": "hop",
    "hopului": "hop",
    "hopuri": "hop",
    "hopurile": "hop",
    "hopurilor": "hop",
    "hopăia": "hopăi",
    "hopăiai": "hopăi",
    "hopăiam": "hopăi",
    "hopăiați": "hopăi",
    "hopăiau": "hopăi",
    "hopăie": "hopăi",
    "hopăii": "hopăi",
    "hopăim": "hopăi",
    "hopăind": "hopăi",
    "hopăindu": "hopăi",
    "hopăiră": "hopăi",
    "hopăirăm": "hopăi",
    "hopăirăți": "hopăi",
    "hopăise": "hopăi",
    "hopăisem": "hopăi",
    "hopăiseră": "hopăi",
    "hopăiserăm": "hopăi",
    "hopăiserăți": "hopăi",
    "hopăiseși": "hopăi",
    "hopăiși": "hopăi",
    "hopăit": "hopăi",
    "hopăiți": "hopăi",
    "hopăitu": "hopăi",
    "nehopăind": "hopăi",
    "nehopăindu": "hopăi",
    "nemaihopăind": "hopăi",
    "nemaihopăindu": "hopăi",
    "hopăită": "hopăit",
    "hopăite": "hopăit",
    "hopăiți": "hopăit",
    "hopliți": "hoplit",
    "hopliții": "hoplit",
    "hopliților": "hoplit",
    "hoplitul": "hoplit",
    "hoplitului": "hoplit",
    "hora": "horă",
    "hore": "horă",
    "horei": "horă",
    "horele": "horă",
    "horelor": "horă",
    "horăia": "horăi",
    "horăiai": "horăi",
    "horăiam": "horăi",
    "horăiați": "horăi",
    "horăiau": "horăi",
    "horăie": "horăi",
    "horăii": "horăi",
    "horăim": "horăi",
    "horăind": "horăi",
    "horăindu": "horăi",
    "horăiră": "horăi",
    "horăirăm": "horăi",
    "horăirăți": "horăi",
    "horăise": "horăi",
    "horăisem": "horăi",
    "horăiseră": "horăi",
    "horăiserăm": "horăi",
    "horăiserăți": "horăi",
    "horăiseși": "horăi",
    "horăiși": "horăi",
    "horăit": "horăi",
    "horăiți": "horăi",
    "horăitu": "horăi",
    "nehorăind": "horăi",
    "nehorăindu": "horăi",
    "nemaihorăind": "horăi",
    "nemaihorăindu": "horăi",
    "horăită": "horăit",
    "horăite": "horăit",
    "horăiți": "horăit",
    "horcăia": "horcăi",
    "horcăiai": "horcăi",
    "horcăiam": "horcăi",
    "horcăiați": "horcăi",
    "horcăiau": "horcăi",
    "horcăie": "horcăi",
    "horcăii": "horcăi",
    "horcăim": "horcăi",
    "horcăind": "horcăi",
    "horcăindu": "horcăi",
    "horcăiră": "horcăi",
    "horcăirăm": "horcăi",
    "horcăirăți": "horcăi",
    "horcăise": "horcăi",
    "horcăisem": "horcăi",
    "horcăiseră": "horcăi",
    "horcăiserăm": "horcăi",
    "horcăiserăți": "horcăi",
    "horcăiseși": "horcăi",
    "horcăiși": "horcăi",
    "horcăit": "horcăi",
    "horcăiți": "horcăi",
    "horcăitu": "horcăi",
    "nehorcăind": "horcăi",
    "nehorcăindu": "horcăi",
    "nemaihorcăind": "horcăi",
    "nemaihorcăindu": "horcăi",
    "horcăită": "horcăit",
    "horcăite": "horcăit",
    "horcăiți": "horcăit",
    "horcăitul": "horcăit",
    "horcăitului": "horcăit",
    "horcăituri": "horcăit",
    "horcăiturile": "horcăit",
    "horcăiturilor": "horcăit",
    "horea": "hori",
    "horeai": "hori",
    "hoream": "hori",
    "horească": "hori",
    "horeați": "hori",
    "horeau": "hori",
    "horesc": "hori",
    "horește": "hori",
    "horești": "hori",
    "horii": "hori",
    "horim": "hori",
    "horind": "hori",
    "horindu": "hori",
    "horiră": "hori",
    "horirăm": "hori",
    "horirăți": "hori",
    "horise": "hori",
    "horisem": "hori",
    "horiseră": "hori",
    "horiserăm": "hori",
    "horiserăți": "hori",
    "horiseși": "hori",
    "horiși": "hori",
    "horit": "hori",
    "horiți": "hori",
    "horitu": "hori",
    "nehorind": "hori",
    "nehorindu": "hori",
    "nemaihorind": "hori",
    "nemaihorindu": "hori",
    "horită": "horit",
    "horite": "horit",
    "horiți": "horit",
    "hormoni": "hormon",
    "hormonii": "hormon",
    "hormonilor": "hormon",
    "hormonul": "hormon",
    "hormonului": "hormon",
    "hornul": "horn",
    "hornului": "horn",
    "hornuri": "horn",
    "hornurile": "horn",
    "hornurilor": "horn",
    "hornari": "hornar",
    "hornarii": "hornar",
    "hornarilor": "hornar",
    "hornarul": "hornar",
    "hornarului": "hornar",
    "horoscoape": "horoscop",
    "horoscoapele": "horoscop",
    "horoscoapelor": "horoscop",
    "horoscopul": "horoscop",
    "horoscopului": "horoscop",
    "horoscopuri": "horoscop",
    "horoscopurile": "horoscop",
    "horoscopurilor": "horoscop",
    "horpăea": "horpăi",
    "horpăeai": "horpăi",
    "horpăeam": "horpăi",
    "horpăească": "horpăi",
    "horpăeați": "horpăi",
    "horpăeau": "horpăi",
    "horpăesc": "horpăi",
    "horpăește": "horpăi",
    "horpăești": "horpăi",
    "horpăia": "horpăi",
    "horpăiai": "horpăi",
    "horpăiam": "horpăi",
    "horpăiați": "horpăi",
    "horpăiau": "horpăi",
    "horpăie": "horpăi",
    "horpăii": "horpăi",
    "horpăim": "horpăi",
    "horpăind": "horpăi",
    "horpăindu": "horpăi",
    "horpăiră": "horpăi",
    "horpăirăm": "horpăi",
    "horpăirăți": "horpăi",
    "horpăise": "horpăi",
    "horpăisem": "horpăi",
    "horpăiseră": "horpăi",
    "horpăiserăm": "horpăi",
    "horpăiserăți": "horpăi",
    "horpăiseși": "horpăi",
    "horpăiși": "horpăi",
    "horpăit": "horpăi",
    "horpăiți": "horpăi",
    "horpăitu": "horpăi",
    "nehorpăind": "horpăi",
    "nehorpăindu": "horpăi",
    "nemaihorpăind": "horpăi",
    "nemaihorpăindu": "horpăi",
    "horpăită": "horpăit",
    "horpăite": "horpăit",
    "horpăiți": "horpăit",
    "hortensia": "hortensie",
    "hortensiei": "hortensie",
    "hortensii": "hortensie",
    "hortensiile": "hortensie",
    "hortensiilor": "hortensie",
    "horticola": "horticol",
    "horticolă": "horticol",
    "horticole": "horticol",
    "horticolei": "horticol",
    "horticolele": "horticol",
    "horticolelor": "horticol",
    "horticoli": "horticol",
    "horticolii": "horticol",
    "horticolilor": "horticol",
    "horticolul": "horticol",
    "horticolului": "horticol",
    "horticultori": "horticultor",
    "horticultorii": "horticultor",
    "horticultorilor": "horticultor",
    "horticultorul": "horticultor",
    "horticultorului": "horticultor",
    "hort.": "horticultură",
    "horticultura": "horticultură",
    "horticulturi": "horticultură",
    "horticulturii": "horticultură",
    "H.": "Hospital",
    "hoți": "hoț",
    "hoții": "hoț",
    "hoților": "hoț",
    "hoțul": "hoț",
    "hoțului": "hoț",
    "hotare": "hotar",
    "hotarele": "hotar",
    "hotarelor": "hotar",
    "hotarul": "hotar",
    "hotarului": "hotar",
    "hotărârea": "hotărâre",
    "hotărâri": "hotărâre",
    "hotărârii": "hotărâre",
    "hotărârile": "hotărâre",
    "hotărârilor": "hotărâre",
    "H.G.": "Hotărârea_Guvernamentală",
    "hotărâta": "hotărât",
    "hotărâtă": "hotărât",
    "hotărâte": "hotărât",
    "hotărâtei": "hotărât",
    "hotărâtele": "hotărât",
    "hotărâtelor": "hotărât",
    "hotărâți": "hotărât",
    "hotărâții": "hotărât",
    "hotărâților": "hotărât",
    "hotărâtul": "hotărât",
    "hotărâtului": "hotărât",
    "hotărâtoare": "hotărâtor",
    "hotărâtoarea": "hotărâtor",
    "hotărâtoarei": "hotărâtor",
    "hotărâtoarele": "hotărâtor",
    "hotărâtoarelor": "hotărâtor",
    "hotărâtori": "hotărâtor",
    "hotărâtorii": "hotărâtor",
    "hotărâtorilor": "hotărâtor",
    "hotărâtorul": "hotărâtor",
    "hotărâtorului": "hotărâtor",
    "hotăra": "hotărî",
    "hotărai": "hotărî",
    "hotărâi": "hotărî",
    "hotăram": "hotărî",
    "hotărâm": "hotărî",
    "hotărând": "hotărî",
    "hotărându": "hotărî",
    "hotărâră": "hotărî",
    "hotărârăm": "hotărî",
    "hotărârăți": "hotărî",
    "hotărăsc": "hotărî",
    "hotărască": "hotărî",
    "hotărâse": "hotărî",
    "hotărâsem": "hotărî",
    "hotărâseră": "hotărî",
    "hotărâserăm": "hotărî",
    "hotărâserăți": "hotărî",
    "hotărâseși": "hotărî",
    "hotărâși": "hotărî",
    "hotărăște": "hotărî",
    "hotărăști": "hotărî",
    "hotărât": "hotărî",
    "hotărați": "hotărî",
    "hotărâți": "hotărî",
    "hotărâtu": "hotărî",
    "hotărau": "hotărî",
    "nehotărând": "hotărî",
    "nehotărându": "hotărî",
    "nemaihotărând": "hotărî",
    "nemaihotărându": "hotărî",
    "hotărnicea": "hotărnici",
    "hotărniceai": "hotărnici",
    "hotărniceam": "hotărnici",
    "hotărnicească": "hotărnici",
    "hotărniceați": "hotărnici",
    "hotărniceau": "hotărnici",
    "hotărnicesc": "hotărnici",
    "hotărnicește": "hotărnici",
    "hotărnicești": "hotărnici",
    "hotărnicii": "hotărnici",
    "hotărnicim": "hotărnici",
    "hotărnicind": "hotărnici",
    "hotărnicindu": "hotărnici",
    "hotărniciră": "hotărnici",
    "hotărnicirăm": "hotărnici",
    "hotărnicirăți": "hotărnici",
    "hotărnicise": "hotărnici",
    "hotărnicisem": "hotărnici",
    "hotărniciseră": "hotărnici",
    "hotărniciserăm": "hotărnici",
    "hotărniciserăți": "hotărnici",
    "hotărniciseși": "hotărnici",
    "hotărniciși": "hotărnici",
    "hotărnicit": "hotărnici",
    "hotărniciți": "hotărnici",
    "hotărnicitu": "hotărnici",
    "nehotărnicind": "hotărnici",
    "nehotărnicindu": "hotărnici",
    "nemaihotărnicind": "hotărnici",
    "nemaihotărnicindu": "hotărnici",
    "hotărnicită": "hotărnicit",
    "hotărnicite": "hotărnicit",
    "hotărniciți": "hotărnicit",
    "hot.": "hotel",
    "hotelul": "hotel",
    "hotelului": "hotel",
    "hoteluri": "hotel",
    "hotelurile": "hotel",
    "hotelurilor": "hotel",
    "hoteliere": "hotelier",
    "hotelieri": "hotelier",
    "hotelierii": "hotelier",
    "hoțea": "hoți",
    "hoțeai": "hoți",
    "hoțeam": "hoți",
    "hoțească": "hoți",
    "hoțeați": "hoți",
    "hoțeau": "hoți",
    "hoțesc": "hoți",
    "hoțește": "hoți",
    "hoțești": "hoți",
    "hoții": "hoți",
    "hoțim": "hoți",
    "hoțind": "hoți",
    "hoțindu": "hoți",
    "hoțiră": "hoți",
    "hoțirăm": "hoți",
    "hoțirăți": "hoți",
    "hoțise": "hoți",
    "hoțisem": "hoți",
    "hoțiseră": "hoți",
    "hoțiserăm": "hoți",
    "hoțiserăți": "hoți",
    "hoțiseși": "hoți",
    "hoțiși": "hoți",
    "hoțit": "hoți",
    "hoțiți": "hoți",
    "hoțitu": "hoți",
    "nehoțind": "hoți",
    "nehoțindu": "hoți",
    "nemaihoțind": "hoți",
    "nemaihoțindu": "hoți",
    "hoția": "hoție",
    "hoției": "hoție",
    "hoții": "hoție",
    "hoțiile": "hoție",
    "hoțiilor": "hoție",
    "hoțită": "hoțit",
    "hoțite": "hoțit",
    "hoțiți": "hoțit",
    "hramul": "hram",
    "hramule": "hram",
    "hramului": "hram",
    "hramuri": "hram",
    "hramurile": "hram",
    "hramurilor": "hram",
    "hrana": "hrană",
    "hrane": "hrană",
    "hranei": "hrană",
    "hranele": "hrană",
    "hranelor": "hrană",
    "hrănea": "hrăni",
    "hrăneai": "hrăni",
    "hrăneam": "hrăni",
    "hrănească": "hrăni",
    "hrăneați": "hrăni",
    "hrăneau": "hrăni",
    "hrănesc": "hrăni",
    "hrănește": "hrăni",
    "hrănești": "hrăni",
    "hrănii": "hrăni",
    "hrănim": "hrăni",
    "hrănind": "hrăni",
    "hrănindu": "hrăni",
    "hrăniră": "hrăni",
    "hrănirăm": "hrăni",
    "hrănirăți": "hrăni",
    "hrănise": "hrăni",
    "hrănisem": "hrăni",
    "hrăniseră": "hrăni",
    "hrăniserăm": "hrăni",
    "hrăniserăți": "hrăni",
    "hrăniseși": "hrăni",
    "hrăniși": "hrăni",
    "hrănit": "hrăni",
    "hrăniți": "hrăni",
    "hrănitu": "hrăni",
    "nehrănind": "hrăni",
    "nehrănindu": "hrăni",
    "nemaihrănind": "hrăni",
    "nemaihrănindu": "hrăni",
    "hrănirea": "hrănire",
    "hrănireo": "hrănire",
    "hrăniri": "hrănire",
    "hrănirii": "hrănire",
    "hrănirile": "hrănire",
    "hrănirilor": "hrănire",
    "hrănita": "hrănit",
    "hrănită": "hrănit",
    "hrănite": "hrănit",
    "hrănitei": "hrănit",
    "hrănitele": "hrănit",
    "hrănitelor": "hrănit",
    "hrăniți": "hrănit",
    "hrăniții": "hrănit",
    "hrăniților": "hrănit",
    "hrănitul": "hrănit",
    "hrănitului": "hrănit",
    "hrănitoare": "hrănitor",
    "hrănitoarea": "hrănitor",
    "hrănitoarei": "hrănitor",
    "hrănitoarele": "hrănitor",
    "hrănitoarelor": "hrănitor",
    "hrănitori": "hrănitor",
    "hrănitorii": "hrănitor",
    "hrănitorilor": "hrănitor",
    "hrănitorul": "hrănitor",
    "hrănitorului": "hrănitor",
    "hrăpăreața": "hrăpăreț",
    "hrăpăreață": "hrăpăreț",
    "hrăpărețe": "hrăpăreț",
    "hrăpăreței": "hrăpăreț",
    "hrăpărețele": "hrăpăreț",
    "hrăpărețelor": "hrăpăreț",
    "hrăpăreți": "hrăpăreț",
    "hrăpăreții": "hrăpăreț",
    "hrăpăreților": "hrăpăreț",
    "hrăpărețul": "hrăpăreț",
    "hrăpărețului": "hrăpăreț",
    "hreanul": "hrean",
    "hreanului": "hrean",
    "hrentuia": "hrentui",
    "hrentuiai": "hrentui",
    "hrentuiam": "hrentui",
    "hrentuiască": "hrentui",
    "hrentuiați": "hrentui",
    "hrentuiau": "hrentui",
    "hrentuiesc": "hrentui",
    "hrentuiește": "hrentui",
    "hrentuiești": "hrentui",
    "hrentuii": "hrentui",
    "hrentuim": "hrentui",
    "hrentuind": "hrentui",
    "hrentuindu": "hrentui",
    "hrentuiră": "hrentui",
    "hrentuirăm": "hrentui",
    "hrentuirăți": "hrentui",
    "hrentuise": "hrentui",
    "hrentuisem": "hrentui",
    "hrentuiseră": "hrentui",
    "hrentuiserăm": "hrentui",
    "hrentuiserăți": "hrentui",
    "hrentuiseși": "hrentui",
    "hrentuiși": "hrentui",
    "hrentuit": "hrentui",
    "hrentuiți": "hrentui",
    "hrentuitu": "hrentui",
    "nehrentuind": "hrentui",
    "nehrentuindu": "hrentui",
    "nemaihrentuind": "hrentui",
    "nemaihrentuindu": "hrentui",
    "hrentuită": "hrentuit",
    "hrentuite": "hrentuit",
    "hrentuiți": "hrentuit",
    "hrepcuia": "hrepcui",
    "hrepcuiai": "hrepcui",
    "hrepcuiam": "hrepcui",
    "hrepcuiască": "hrepcui",
    "hrepcuiați": "hrepcui",
    "hrepcuiau": "hrepcui",
    "hrepcuiesc": "hrepcui",
    "hrepcuiește": "hrepcui",
    "hrepcuiești": "hrepcui",
    "hrepcuii": "hrepcui",
    "hrepcuim": "hrepcui",
    "hrepcuind": "hrepcui",
    "hrepcuindu": "hrepcui",
    "hrepcuiră": "hrepcui",
    "hrepcuirăm": "hrepcui",
    "hrepcuirăți": "hrepcui",
    "hrepcuise": "hrepcui",
    "hrepcuisem": "hrepcui",
    "hrepcuiseră": "hrepcui",
    "hrepcuiserăm": "hrepcui",
    "hrepcuiserăți": "hrepcui",
    "hrepcuiseși": "hrepcui",
    "hrepcuiși": "hrepcui",
    "hrepcuit": "hrepcui",
    "hrepcuiți": "hrepcui",
    "hrepcuitu": "hrepcui",
    "nehrepcuind": "hrepcui",
    "nehrepcuindu": "hrepcui",
    "nemaihrepcuind": "hrepcui",
    "nemaihrepcuindu": "hrepcui",
    "hrepcuită": "hrepcuit",
    "hrepcuite": "hrepcuit",
    "hrepcuiți": "hrepcuit",
    "Hristosul": "Hristos",
    "Hristosului": "Hristos",
    "huciuia": "huciui",
    "huciuiai": "huciui",
    "huciuiam": "huciui",
    "huciuiască": "huciui",
    "huciuiați": "huciui",
    "huciuiau": "huciui",
    "huciuiesc": "huciui",
    "huciuiește": "huciui",
    "huciuiești": "huciui",
    "huciuii": "huciui",
    "huciuim": "huciui",
    "huciuind": "huciui",
    "huciuindu": "huciui",
    "huciuiră": "huciui",
    "huciuirăm": "huciui",
    "huciuirăți": "huciui",
    "huciuise": "huciui",
    "huciuisem": "huciui",
    "huciuiseră": "huciui",
    "huciuiserăm": "huciui",
    "huciuiserăți": "huciui",
    "huciuiseși": "huciui",
    "huciuiși": "huciui",
    "huciuit": "huciui",
    "huciuiți": "huciui",
    "huciuitu": "huciui",
    "nehuciuind": "huciui",
    "nehuciuindu": "huciui",
    "nemaihuciuind": "huciui",
    "nemaihuciuindu": "huciui",
    "huciuită": "huciuit",
    "huciuite": "huciuit",
    "huciuiți": "huciuit",
    "huhur": "huhura",
    "huhură": "huhura",
    "huhurai": "huhura",
    "huhuram": "huhura",
    "huhurăm": "huhura",
    "huhurând": "huhura",
    "huhurându": "huhura",
    "huhurară": "huhura",
    "huhurarăm": "huhura",
    "huhurarăți": "huhura",
    "huhurase": "huhura",
    "huhurasem": "huhura",
    "huhuraseră": "huhura",
    "huhuraserăm": "huhura",
    "huhuraserăți": "huhura",
    "huhuraseși": "huhura",
    "huhurași": "huhura",
    "huhurat": "huhura",
    "huhurați": "huhura",
    "huhuratu": "huhura",
    "huhurau": "huhura",
    "huhure": "huhura",
    "huhuri": "huhura",
    "nehuhurând": "huhura",
    "nehuhurându": "huhura",
    "nemaihuhurând": "huhura",
    "nemaihuhurându": "huhura",
    "huhurată": "huhurat",
    "huhurate": "huhurat",
    "huhurați": "huhurat",
    "huhurezi": "huhurez",
    "huhurezii": "huhurez",
    "huhurezilor": "huhurez",
    "huhurezul": "huhurez",
    "huhurezule": "huhurez",
    "huhurezului": "huhurez",
    "huea": "hui",
    "hueai": "hui",
    "hueam": "hui",
    "huească": "hui",
    "hueați": "hui",
    "hueau": "hui",
    "huește": "hui",
    "huii": "hui",
    "huind": "hui",
    "huindu": "hui",
    "huiră": "hui",
    "huirăm": "hui",
    "huirăți": "hui",
    "huise": "hui",
    "huisem": "hui",
    "huiseră": "hui",
    "huiserăm": "hui",
    "huiserăți": "hui",
    "huiseși": "hui",
    "huiși": "hui",
    "huit": "hui",
    "huiți": "hui",
    "huitu": "hui",
    "nehuind": "hui",
    "nehuindu": "hui",
    "nemaihuind": "hui",
    "nemaihuindu": "hui",
    "huiduia": "huidui",
    "huiduiai": "huidui",
    "huiduiam": "huidui",
    "huiduiască": "huidui",
    "huiduiați": "huidui",
    "huiduiau": "huidui",
    "huiduiesc": "huidui",
    "huiduiește": "huidui",
    "huiduiești": "huidui",
    "huiduii": "huidui",
    "huiduim": "huidui",
    "huiduind": "huidui",
    "huiduindu": "huidui",
    "huiduiră": "huidui",
    "huiduirăm": "huidui",
    "huiduirăți": "huidui",
    "huiduise": "huidui",
    "huiduisem": "huidui",
    "huiduiseră": "huidui",
    "huiduiserăm": "huidui",
    "huiduiserăți": "huidui",
    "huiduiseși": "huidui",
    "huiduiși": "huidui",
    "huiduit": "huidui",
    "huiduiți": "huidui",
    "huiduitu": "huidui",
    "nehuiduind": "huidui",
    "nehuiduindu": "huidui",
    "nemaihuiduind": "huidui",
    "nemaihuiduindu": "huidui",
    "huiduiala": "huiduială",
    "huiduieli": "huiduială",
    "huiduielii": "huiduială",
    "huiduielile": "huiduială",
    "huiduielilor": "huiduială",
    "huiduită": "huiduit",
    "huiduite": "huiduit",
    "huiduiți": "huiduit",
    "huila": "huilă",
    "huile": "huilă",
    "huilei": "huilă",
    "huilele": "huilă",
    "huilelor": "huilă",
    "huită": "huit",
    "huite": "huit",
    "huiți": "huit",
    "huiț": "huița",
    "huiță": "huița",
    "huițai": "huița",
    "huițam": "huița",
    "huițăm": "huița",
    "huițând": "huița",
    "huițându": "huița",
    "huițară": "huița",
    "huițarăm": "huița",
    "huițarăți": "huița",
    "huițase": "huița",
    "huițasem": "huița",
    "huițaseră": "huița",
    "huițaserăm": "huița",
    "huițaserăți": "huița",
    "huițaseși": "huița",
    "huițași": "huița",
    "huițat": "huița",
    "huițați": "huița",
    "huițatu": "huița",
    "huițau": "huița",
    "huițe": "huița",
    "huiți": "huița",
    "nehuițând": "huița",
    "nehuițându": "huița",
    "nemaihuițând": "huița",
    "nemaihuițându": "huița",
    "huițată": "huițat",
    "huițate": "huițat",
    "huițați": "huițat",
    "hula": "hulă",
    "hule": "hulă",
    "hulei": "hulă",
    "hulele": "hulă",
    "hulelor": "hulă",
    "hulea": "huli",
    "huleai": "huli",
    "huleam": "huli",
    "hulească": "huli",
    "huleați": "huli",
    "huleau": "huli",
    "hulesc": "huli",
    "hulește": "huli",
    "hulești": "huli",
    "hulii": "huli",
    "hulim": "huli",
    "hulind": "huli",
    "hulindu": "huli",
    "huliră": "huli",
    "hulirăm": "huli",
    "hulirăți": "huli",
    "hulise": "huli",
    "hulisem": "huli",
    "huliseră": "huli",
    "huliserăm": "huli",
    "huliserăți": "huli",
    "huliseși": "huli",
    "huliși": "huli",
    "hulit": "huli",
    "huliți": "huli",
    "hulitu": "huli",
    "nehulind": "huli",
    "nehulindu": "huli",
    "nemaihulind": "huli",
    "nemaihulindu": "huli",
    "huligani": "huligan",
    "huliganii": "huligan",
    "huliganilor": "huligan",
    "huliganul": "huligan",
    "huliganului": "huligan",
    "huliganismul": "huliganism",
    "huliganismului": "huliganism",
    "hulită": "hulit",
    "hulite": "hulit",
    "huliți": "hulit",
    "huluba": "hulub",
    "hulubă": "hulub",
    "hulube": "hulub",
    "hulubei": "hulub",
    "hulubele": "hulub",
    "hulubelor": "hulub",
    "hulubi": "hulub",
    "hulubii": "hulub",
    "hulubilor": "hulub",
    "hulubul": "hulub",
    "hulubului": "hulub",
    "huluba": "hulubă",
    "hulube": "hulubă",
    "hulubei": "hulubă",
    "hulubele": "hulubă",
    "hulubelor": "hulubă",
    "huma": "humă",
    "hume": "humă",
    "humei": "humă",
    "humele": "humă",
    "humelor": "humă",
    "humuia": "humui",
    "humuiai": "humui",
    "humuiam": "humui",
    "humuiască": "humui",
    "humuiați": "humui",
    "humuiau": "humui",
    "humuiesc": "humui",
    "humuiește": "humui",
    "humuiești": "humui",
    "humuii": "humui",
    "humuim": "humui",
    "humuind": "humui",
    "humuindu": "humui",
    "humuiră": "humui",
    "humuirăm": "humui",
    "humuirăți": "humui",
    "humuise": "humui",
    "humuisem": "humui",
    "humuiseră": "humui",
    "humuiserăm": "humui",
    "humuiserăți": "humui",
    "humuiseși": "humui",
    "humuiși": "humui",
    "humuit": "humui",
    "humuiți": "humui",
    "humuitu": "humui",
    "nehumuind": "humui",
    "nehumuindu": "humui",
    "nemaihumuind": "humui",
    "nemaihumuindu": "humui",
    "humuită": "humuit",
    "humuite": "humuit",
    "humuiți": "humuit",
    "huni": "hun",
    "hunii": "hun",
    "hunilor": "hun",
    "hunul": "hun",
    "hunule": "hun",
    "hunului": "hun",
    "hurduc": "hurduca",
    "hurducă": "hurduca",
    "hurducai": "hurduca",
    "hurducam": "hurduca",
    "hurducăm": "hurduca",
    "hurducând": "hurduca",
    "hurducându": "hurduca",
    "hurducară": "hurduca",
    "hurducarăm": "hurduca",
    "hurducarăți": "hurduca",
    "hurducase": "hurduca",
    "hurducasem": "hurduca",
    "hurducaseră": "hurduca",
    "hurducaserăm": "hurduca",
    "hurducaserăți": "hurduca",
    "hurducaseși": "hurduca",
    "hurducași": "hurduca",
    "hurducat": "hurduca",
    "hurducați": "hurduca",
    "hurducatu": "hurduca",
    "hurducau": "hurduca",
    "hurduce": "hurduca",
    "hurduci": "hurduca",
    "nehurducând": "hurduca",
    "nehurducându": "hurduca",
    "nemaihurducând": "hurduca",
    "nemaihurducându": "hurduca",
    "hurducăia": "hurducăi",
    "hurducăiai": "hurducăi",
    "hurducăiam": "hurducăi",
    "hurducăiați": "hurducăi",
    "hurducăiau": "hurducăi",
    "hurducăie": "hurducăi",
    "hurducăii": "hurducăi",
    "hurducăim": "hurducăi",
    "hurducăind": "hurducăi",
    "hurducăindu": "hurducăi",
    "hurducăiră": "hurducăi",
    "hurducăirăm": "hurducăi",
    "hurducăirăți": "hurducăi",
    "hurducăise": "hurducăi",
    "hurducăisem": "hurducăi",
    "hurducăiseră": "hurducăi",
    "hurducăiserăm": "hurducăi",
    "hurducăiserăți": "hurducăi",
    "hurducăiseși": "hurducăi",
    "hurducăiși": "hurducăi",
    "hurducăit": "hurducăi",
    "hurducăiți": "hurducăi",
    "hurducăitu": "hurducăi",
    "nehurducăind": "hurducăi",
    "nehurducăindu": "hurducăi",
    "nemaihurducăind": "hurducăi",
    "nemaihurducăindu": "hurducăi",
    "hurducăită": "hurducăit",
    "hurducăite": "hurducăit",
    "hurducăiți": "hurducăit",
    "hurducăitul": "hurducăit",
    "hurducăitului": "hurducăit",
    "hurducăituri": "hurducăit",
    "hurducăiturile": "hurducăit",
    "hurducăiturilor": "hurducăit",
    "hurducarea": "hurducare",
    "hurducareo": "hurducare",
    "hurducări": "hurducare",
    "hurducării": "hurducare",
    "hurducările": "hurducare",
    "hurducărilor": "hurducare",
    "hurducată": "hurducat",
    "hurducate": "hurducat",
    "hurducați": "hurducat",
    "hurducătura": "hurducătură",
    "hurducături": "hurducătură",
    "hurducăturii": "hurducătură",
    "hurducăturile": "hurducătură",
    "hurducăturilor": "hurducătură",
    "hurduia": "hurdui",
    "hurduiai": "hurdui",
    "hurduiam": "hurdui",
    "hurduiască": "hurdui",
    "hurduiați": "hurdui",
    "hurduiau": "hurdui",
    "hurduiesc": "hurdui",
    "hurduiește": "hurdui",
    "hurduiești": "hurdui",
    "hurduii": "hurdui",
    "hurduim": "hurdui",
    "hurduind": "hurdui",
    "hurduindu": "hurdui",
    "hurduiră": "hurdui",
    "hurduirăm": "hurdui",
    "hurduirăți": "hurdui",
    "hurduise": "hurdui",
    "hurduisem": "hurdui",
    "hurduiseră": "hurdui",
    "hurduiserăm": "hurdui",
    "hurduiserăți": "hurdui",
    "hurduiseși": "hurdui",
    "hurduiși": "hurdui",
    "hurduit": "hurdui",
    "hurduiți": "hurdui",
    "hurduitu": "hurdui",
    "nehurduind": "hurdui",
    "nehurduindu": "hurdui",
    "nemaihurduind": "hurdui",
    "nemaihurduindu": "hurdui",
    "hurduită": "hurduit",
    "hurduite": "hurduit",
    "hurduiți": "hurduit",
    "huruia": "hurui",
    "huruiai": "hurui",
    "huruiam": "hurui",
    "huruiați": "hurui",
    "huruiau": "hurui",
    "huruie": "hurui",
    "huruii": "hurui",
    "huruim": "hurui",
    "huruind": "hurui",
    "huruindu": "hurui",
    "huruiră": "hurui",
    "huruirăm": "hurui",
    "huruirăți": "hurui",
    "huruise": "hurui",
    "huruisem": "hurui",
    "huruiseră": "hurui",
    "huruiserăm": "hurui",
    "huruiserăți": "hurui",
    "huruiseși": "hurui",
    "huruiși": "hurui",
    "huruit": "hurui",
    "huruiți": "hurui",
    "huruitu": "hurui",
    "nehuruind": "hurui",
    "nehuruindu": "hurui",
    "nemaihuruind": "hurui",
    "nemaihuruindu": "hurui",
    "huruită": "huruit",
    "huruite": "huruit",
    "huruiți": "huruit",
    "huruitul": "huruit",
    "huruitului": "huruit",
    "huruituri": "huruit",
    "huruiturile": "huruit",
    "huruiturilor": "huruit",
    "husa": "husă",
    "huse": "husă",
    "husei": "husă",
    "husele": "husă",
    "huselor": "husă",
    "hutupea": "hutupi",
    "hutupeai": "hutupi",
    "hutupeam": "hutupi",
    "hutupească": "hutupi",
    "hutupeați": "hutupi",
    "hutupeau": "hutupi",
    "hutupesc": "hutupi",
    "hutupește": "hutupi",
    "hutupești": "hutupi",
    "hutupii": "hutupi",
    "hutupim": "hutupi",
    "hutupind": "hutupi",
    "hutupindu": "hutupi",
    "hutupiră": "hutupi",
    "hutupirăm": "hutupi",
    "hutupirăți": "hutupi",
    "hutupise": "hutupi",
    "hutupisem": "hutupi",
    "hutupiseră": "hutupi",
    "hutupiserăm": "hutupi",
    "hutupiserăți": "hutupi",
    "hutupiseși": "hutupi",
    "hutupiși": "hutupi",
    "hutupit": "hutupi",
    "hutupiți": "hutupi",
    "hutupitu": "hutupi",
    "nehutupind": "hutupi",
    "nehutupindu": "hutupi",
    "nemaihutupind": "hutupi",
    "nemaihutupindu": "hutupi",
    "hutupită": "hutupit",
    "hutupite": "hutupit",
    "hutupiți": "hutupit",
    "huțuț": "huțuța",
    "huțuță": "huțuța",
    "huțuțai": "huțuța",
    "huțuțam": "huțuța",
    "huțuțăm": "huțuța",
    "huțuțând": "huțuța",
    "huțuțându": "huțuța",
    "huțuțară": "huțuța",
    "huțuțarăm": "huțuța",
    "huțuțarăți": "huțuța",
    "huțuțase": "huțuța",
    "huțuțasem": "huțuța",
    "huțuțaseră": "huțuța",
    "huțuțaserăm": "huțuța",
    "huțuțaserăți": "huțuța",
    "huțuțaseși": "huțuța",
    "huțuțași": "huțuța",
    "huțuțat": "huțuța",
    "huțuțați": "huțuța",
    "huțuțatu": "huțuța",
    "huțuțau": "huțuța",
    "huțuțe": "huțuța",
    "huțuți": "huțuța",
    "nehuțuțând": "huțuța",
    "nehuțuțându": "huțuța",
    "nemaihuțuțând": "huțuța",
    "nemaihuțuțându": "huțuța",
    "huțuțată": "huțuțat",
    "huțuțate": "huțuțat",
    "huțuțați": "huțuțat",
    "huzdup": "huzdupa",
    "huzdupă": "huzdupa",
    "huzdupai": "huzdupa",
    "huzdupam": "huzdupa",
    "huzdupăm": "huzdupa",
    "huzdupând": "huzdupa",
    "huzdupându": "huzdupa",
    "huzdupară": "huzdupa",
    "huzduparăm": "huzdupa",
    "huzduparăți": "huzdupa",
    "huzdupase": "huzdupa",
    "huzdupasem": "huzdupa",
    "huzdupaseră": "huzdupa",
    "huzdupaserăm": "huzdupa",
    "huzdupaserăți": "huzdupa",
    "huzdupaseși": "huzdupa",
    "huzdupași": "huzdupa",
    "huzdupat": "huzdupa",
    "huzdupați": "huzdupa",
    "huzdupatu": "huzdupa",
    "huzdupau": "huzdupa",
    "huzdupe": "huzdupa",
    "huzdupi": "huzdupa",
    "nehuzdupând": "huzdupa",
    "nehuzdupându": "huzdupa",
    "nemaihuzdupând": "huzdupa",
    "nemaihuzdupându": "huzdupa",
    "huzdupată": "huzdupat",
    "huzdupate": "huzdupat",
    "huzdupați": "huzdupat",
    "huzurul": "huzur",
    "huzurului": "huzur",
    "huzurea": "huzuri",
    "huzureai": "huzuri",
    "huzuream": "huzuri",
    "huzurească": "huzuri",
    "huzureați": "huzuri",
    "huzureau": "huzuri",
    "huzuresc": "huzuri",
    "huzurește": "huzuri",
    "huzurești": "huzuri",
    "huzurii": "huzuri",
    "huzurim": "huzuri",
    "huzurind": "huzuri",
    "huzurindu": "huzuri",
    "huzuriră": "huzuri",
    "huzurirăm": "huzuri",
    "huzurirăți": "huzuri",
    "huzurise": "huzuri",
    "huzurisem": "huzuri",
    "huzuriseră": "huzuri",
    "huzuriserăm": "huzuri",
    "huzuriserăți": "huzuri",
    "huzuriseși": "huzuri",
    "huzuriși": "huzuri",
    "huzurit": "huzuri",
    "huzuriți": "huzuri",
    "huzuritu": "huzuri",
    "nehuzurind": "huzuri",
    "nehuzurindu": "huzuri",
    "nemaihuzurind": "huzuri",
    "nemaihuzurindu": "huzuri",
    "huzurită": "huzurit",
    "huzurite": "huzurit",
    "huzuriți": "huzurit",
    "Hydră": "Hydra",
    "Hydrei": "Hydra",
    "iadul": "iad",
    "iadului": "iad",
    "iaduri": "iad",
    "iadurile": "iad",
    "iadurilor": "iad",
    "iahtul": "iaht",
    "iahtului": "iaht",
    "iahturi": "iaht",
    "iahturile": "iaht",
    "iahturilor": "iaht",
    "iambi": "iamb",
    "iambii": "iamb",
    "iambilor": "iamb",
    "iambul": "iamb",
    "iambului": "iamb",
    "iambica": "iambic",
    "iambică": "iambic",
    "iambice": "iambic",
    "iambicei": "iambic",
    "iambicele": "iambic",
    "iambicelor": "iambic",
    "iambici": "iambic",
    "iambicii": "iambic",
    "iambicilor": "iambic",
    "iambicul": "iambic",
    "iambicului": "iambic",
    "ian.": "ianuarie",
    "iapa": "iapă",
    "iepe": "iapă",
    "iepei": "iapă",
    "iepele": "iapă",
    "iepelor": "iapă",
    "iarba": "iarbă",
    "ierbi": "iarbă",
    "ierbii": "iarbă",
    "ierburi": "iarbă",
    "ierburile": "iarbă",
    "ierburilor": "iarbă",
    "iarna": "iarnă",
    "ierni": "iarnă",
    "iernii": "iarnă",
    "iernile": "iarnă",
    "iernilor": "iarnă",
    "iasca": "iască",
    "Iașii": "Iași",
    "Iașilor": "Iași",
    "Iașiul": "Iași",
    "Iașiului": "Iași",
    "iasomia": "iasomie",
    "iasomiei": "iasomie",
    "iasomii": "iasomie",
    "iasomiile": "iasomie",
    "iasomiilor": "iasomie",
    "iatagane": "iatagan",
    "iataganele": "iatagan",
    "iataganelor": "iatagan",
    "iataganul": "iatagan",
    "iataganului": "iatagan",
    "iaurtul": "iaurt",
    "iaurtului": "iaurt",
    "iaurturi": "iaurt",
    "iaurturile": "iaurt",
    "iaurturilor": "iaurt",
    "iazul": "iaz",
    "iazului": "iaz",
    "iazuri": "iaz",
    "iazurile": "iaz",
    "iazurilor": "iaz",
    "iberica": "iberic",
    "iberică": "iberic",
    "iberice": "iberic",
    "ibericei": "iberic",
    "ibericele": "iberic",
    "ibericelor": "iberic",
    "iberici": "iberic",
    "ibericii": "iberic",
    "ibericilor": "iberic",
    "ibericul": "iberic",
    "ibericului": "iberic",
    "ib.": "ibidem",
    "ibid.": "ibidem",
    "ibovnica": "ibovnică",
    "ibovnice": "ibovnică",
    "ibovnicei": "ibovnică",
    "ibovnicele": "ibovnică",
    "ibovnicelor": "ibovnică",
    "ibovnico": "ibovnică",
    "ibrice": "ibric",
    "ibricele": "ibric",
    "ibricelor": "ibric",
    "ibricul": "ibric",
    "ibricului": "ibric",
    "icneala": "icneală",
    "icneli": "icneală",
    "icnelii": "icneală",
    "icnelile": "icneală",
    "icnelilor": "icneală",
    "icnete": "icnet",
    "icnetele": "icnet",
    "icnetelor": "icnet",
    "icnetul": "icnet",
    "icnetului": "icnet",
    "icnea": "icni",
    "icneai": "icni",
    "icneam": "icni",
    "icnească": "icni",
    "icneați": "icni",
    "icneau": "icni",
    "icnesc": "icni",
    "icnește": "icni",
    "icnești": "icni",
    "icnii": "icni",
    "icnim": "icni",
    "icnind": "icni",
    "icnindu": "icni",
    "icniră": "icni",
    "icnirăm": "icni",
    "icnirăți": "icni",
    "icnise": "icni",
    "icnisem": "icni",
    "icniseră": "icni",
    "icniserăm": "icni",
    "icniserăți": "icni",
    "icniseși": "icni",
    "icniși": "icni",
    "icnit": "icni",
    "icniți": "icni",
    "icnitu": "icni",
    "neicnind": "icni",
    "neicnindu": "icni",
    "nemaiicnind": "icni",
    "nemaiicnindu": "icni",
    "icnită": "icnit",
    "icnite": "icnit",
    "icniți": "icnit",
    "icoana": "icoană",
    "icoane": "icoană",
    "icoanei": "icoană",
    "icoanele": "icoană",
    "icoanelor": "icoană",
    "iconari": "iconar",
    "iconarii": "iconar",
    "iconarilor": "iconar",
    "iconarul": "iconar",
    "iconarule": "iconar",
    "iconarului": "iconar",
    "iconografia": "iconografie",
    "iconografiei": "iconografie",
    "iconografii": "iconografie",
    "iconografiile": "iconografie",
    "iconografiilor": "iconografie",
    "iconografio": "iconografie",
    "icra": "icră",
    "icre": "icră",
    "icrei": "icră",
    "icrele": "icră",
    "icrelor": "icră",
    "ictere": "icter",
    "icterele": "icter",
    "icterelor": "icter",
    "icterul": "icter",
    "icterului": "icter",
    "i.e.": "id_est",
    "ideala": "ideal",
    "ideală": "ideal",
    "ideale": "ideal",
    "idealei": "ideal",
    "idealele": "ideal",
    "idealelor": "ideal",
    "ideali": "ideal",
    "idealii": "ideal",
    "idealilor": "ideal",
    "idealul": "ideal",
    "idealului": "ideal",
    "idealuri": "ideal",
    "idealurile": "ideal",
    "idealurilor": "ideal",
    "idealismul": "idealism",
    "idealismului": "idealism",
    "idealiști": "idealist",
    "idealiștii": "idealist",
    "idealiștilor": "idealist",
    "idealistul": "idealist",
    "idealistului": "idealist",
    "idealiză": "idealiza",
    "idealizai": "idealiza",
    "idealizam": "idealiza",
    "idealizăm": "idealiza",
    "idealizând": "idealiza",
    "idealizându": "idealiza",
    "idealizară": "idealiza",
    "idealizarăm": "idealiza",
    "idealizarăți": "idealiza",
    "idealizase": "idealiza",
    "idealizasem": "idealiza",
    "idealizaseră": "idealiza",
    "idealizaserăm": "idealiza",
    "idealizaserăți": "idealiza",
    "idealizaseși": "idealiza",
    "idealizași": "idealiza",
    "idealizat": "idealiza",
    "idealizați": "idealiza",
    "idealizatu": "idealiza",
    "idealizau": "idealiza",
    "idealizează": "idealiza",
    "idealizez": "idealiza",
    "idealizeze": "idealiza",
    "idealizezi": "idealiza",
    "neidealizând": "idealiza",
    "neidealizându": "idealiza",
    "nemaiidealizând": "idealiza",
    "nemaiidealizându": "idealiza",
    "idealizată": "idealizat",
    "idealizate": "idealizat",
    "idealizați": "idealizat",
    "ideea": "idee",
    "idei": "idee",
    "ideii": "idee",
    "ideile": "idee",
    "ideilor": "idee",
    "id.": "idem",
    "i.q.": "idem_quod",
    "identica": "identic",
    "identică": "identic",
    "identice": "identic",
    "identicei": "identic",
    "identicele": "identic",
    "identicelor": "identic",
    "identici": "identic",
    "identicii": "identic",
    "identicilor": "identic",
    "identicul": "identic",
    "identicului": "identic",
    "identific": "identifica",
    "identifică": "identifica",
    "identificai": "identifica",
    "identificam": "identifica",
    "identificăm": "identifica",
    "identificând": "identifica",
    "identificându": "identifica",
    "identificară": "identifica",
    "identificarăm": "identifica",
    "identificarăți": "identifica",
    "identificase": "identifica",
    "identificasem": "identifica",
    "identificaseră": "identifica",
    "identificaserăm": "identifica",
    "identificaserăți": "identifica",
    "identificaseși": "identifica",
    "identificași": "identifica",
    "identificat": "identifica",
    "identificați": "identifica",
    "identificatu": "identifica",
    "identificau": "identifica",
    "identifice": "identifica",
    "identifici": "identifica",
    "neidentificând": "identifica",
    "neidentificându": "identifica",
    "nemaiidentificând": "identifica",
    "nemaiidentificându": "identifica",
    "identificabila": "identificabil",
    "identificabilă": "identificabil",
    "identificabile": "identificabil",
    "identificabilei": "identificabil",
    "identificabilele": "identificabil",
    "identificabilelor": "identificabil",
    "identificabili": "identificabil",
    "identificabilii": "identificabil",
    "identificabililor": "identificabil",
    "identificabilul": "identificabil",
    "identificabilului": "identificabil",
    "identificarea": "identificare",
    "identificări": "identificare",
    "identificării": "identificare",
    "identificările": "identificare",
    "identificărilor": "identificare",
    "identificată": "identificat",
    "identificate": "identificat",
    "identificați": "identificat",
    "identitatea": "identitate",
    "identități": "identitate",
    "identității": "identitate",
    "identitățile": "identitate",
    "identităților": "identitate",
    "ideologi": "ideolog",
    "ideologii": "ideolog",
    "ideologilor": "ideolog",
    "ideologul": "ideolog",
    "ideologului": "ideolog",
    "ideologica": "ideologic",
    "ideologică": "ideologic",
    "ideologice": "ideologic",
    "ideologicei": "ideologic",
    "ideologicele": "ideologic",
    "ideologicelor": "ideologic",
    "ideologici": "ideologic",
    "ideologicii": "ideologic",
    "ideologicilor": "ideologic",
    "ideologicul": "ideologic",
    "ideologicului": "ideologic",
    "ideologia": "ideologie",
    "ideologiei": "ideologie",
    "ideologii": "ideologie",
    "ideologiile": "ideologie",
    "ideologiilor": "ideologie",
    "idila": "idilă",
    "idile": "idilă",
    "idilei": "idilă",
    "idilele": "idilă",
    "idilelor": "idilă",
    "idilica": "idilic",
    "idilică": "idilic",
    "idilice": "idilic",
    "idilicei": "idilic",
    "idilicele": "idilic",
    "idilicelor": "idilic",
    "idilici": "idilic",
    "idilicii": "idilic",
    "idilicilor": "idilic",
    "idilicul": "idilic",
    "idilicului": "idilic",
    "idiliză": "idiliza",
    "idilizai": "idiliza",
    "idilizam": "idiliza",
    "idilizăm": "idiliza",
    "idilizând": "idiliza",
    "idilizându": "idiliza",
    "idilizară": "idiliza",
    "idilizarăm": "idiliza",
    "idilizarăți": "idiliza",
    "idilizase": "idiliza",
    "idilizasem": "idiliza",
    "idilizaseră": "idiliza",
    "idilizaserăm": "idiliza",
    "idilizaserăți": "idiliza",
    "idilizaseși": "idiliza",
    "idilizași": "idiliza",
    "idilizat": "idiliza",
    "idilizați": "idiliza",
    "idilizatu": "idiliza",
    "idilizau": "idiliza",
    "idilizează": "idiliza",
    "idilizez": "idiliza",
    "idilizeze": "idiliza",
    "idilizezi": "idiliza",
    "neidilizând": "idiliza",
    "neidilizându": "idiliza",
    "nemaiidilizând": "idiliza",
    "nemaiidilizându": "idiliza",
    "idilizată": "idilizat",
    "idilizate": "idilizat",
    "idilizați": "idilizat",
    "idiomul": "idiom",
    "idiomului": "idiom",
    "idiomuri": "idiom",
    "idiomurile": "idiom",
    "idiomurilor": "idiom",
    "idiomatica": "idiomatic",
    "idiomatică": "idiomatic",
    "idiomatice": "idiomatic",
    "idiomaticei": "idiomatic",
    "idiomaticele": "idiomatic",
    "idiomaticelor": "idiomatic",
    "idiomatici": "idiomatic",
    "idiomaticii": "idiomatic",
    "idiomaticilor": "idiomatic",
    "idiomaticul": "idiomatic",
    "idiomaticului": "idiomatic",
    "idioata": "idiot",
    "idioată": "idiot",
    "idioate": "idiot",
    "idioatei": "idiot",
    "idioatele": "idiot",
    "idioatelor": "idiot",
    "idioți": "idiot",
    "idioții": "idiot",
    "idioților": "idiot",
    "idiotul": "idiot",
    "idiotului": "idiot",
    "idioțenia": "idioțenie",
    "idioțeniei": "idioțenie",
    "idioțenii": "idioțenie",
    "idioțeniile": "idioțenie",
    "idioțeniilor": "idioțenie",
    "idiotiză": "idiotiza",
    "idiotizai": "idiotiza",
    "idiotizam": "idiotiza",
    "idiotizăm": "idiotiza",
    "idiotizând": "idiotiza",
    "idiotizându": "idiotiza",
    "idiotizară": "idiotiza",
    "idiotizarăm": "idiotiza",
    "idiotizarăți": "idiotiza",
    "idiotizase": "idiotiza",
    "idiotizasem": "idiotiza",
    "idiotizaseră": "idiotiza",
    "idiotizaserăm": "idiotiza",
    "idiotizaserăți": "idiotiza",
    "idiotizaseși": "idiotiza",
    "idiotizași": "idiotiza",
    "idiotizat": "idiotiza",
    "idiotizați": "idiotiza",
    "idiotizatu": "idiotiza",
    "idiotizau": "idiotiza",
    "idiotizează": "idiotiza",
    "idiotizez": "idiotiza",
    "idiotizeze": "idiotiza",
    "idiotizezi": "idiotiza",
    "neidiotizând": "idiotiza",
    "neidiotizându": "idiotiza",
    "nemaiidiotizând": "idiotiza",
    "nemaiidiotizându": "idiotiza",
    "idiotizată": "idiotizat",
    "idiotizate": "idiotizat",
    "idiotizați": "idiotizat",
    "idișul": "idiș",
    "idișului": "idiș",
    "idoli": "idol",
    "idolii": "idol",
    "idolilor": "idol",
    "idolul": "idol",
    "idolului": "idol",
    "idolatriză": "idolatriza",
    "idolatrizai": "idolatriza",
    "idolatrizam": "idolatriza",
    "idolatrizăm": "idolatriza",
    "idolatrizând": "idolatriza",
    "idolatrizându": "idolatriza",
    "idolatrizară": "idolatriza",
    "idolatrizarăm": "idolatriza",
    "idolatrizarăți": "idolatriza",
    "idolatrizase": "idolatriza",
    "idolatrizasem": "idolatriza",
    "idolatrizaseră": "idolatriza",
    "idolatrizaserăm": "idolatriza",
    "idolatrizaserăți": "idolatriza",
    "idolatrizaseși": "idolatriza",
    "idolatrizași": "idolatriza",
    "idolatrizat": "idolatriza",
    "idolatrizați": "idolatriza",
    "idolatrizatu": "idolatriza",
    "idolatrizau": "idolatriza",
    "idolatrizează": "idolatriza",
    "idolatrizez": "idolatriza",
    "idolatrizeze": "idolatriza",
    "idolatrizezi": "idolatriza",
    "neidolatrizând": "idolatriza",
    "neidolatrizându": "idolatriza",
    "nemaiidolatrizând": "idolatriza",
    "nemaiidolatrizându": "idolatriza",
    "idolatrizată": "idolatrizat",
    "idolatrizate": "idolatrizat",
    "idolatrizați": "idolatrizat",
    "ia": "ie",
    "iei": "ie",
    "ii": "ie",
    "iile": "ie",
    "iilor": "ie",
    "iedul": "ied",
    "iedului": "ied",
    "iezi": "ied",
    "iezii": "ied",
    "iezilor": "ied",
    "iedera": "iederă",
    "iedere": "iederă",
    "iederei": "iederă",
    "iederele": "iederă",
    "iederelor": "iederă",
    "ieftina": "ieftin",
    "ieftină": "ieftin",
    "ieftine": "ieftin",
    "ieftinei": "ieftin",
    "ieftinele": "ieftin",
    "ieftinelor": "ieftin",
    "ieftini": "ieftin",
    "ieftinii": "ieftin",
    "ieftinilor": "ieftin",
    "ieftinul": "ieftin",
    "ieftinului": "ieftin",
    "ieftinea": "ieftini",
    "ieftineai": "ieftini",
    "ieftineam": "ieftini",
    "ieftinească": "ieftini",
    "ieftineați": "ieftini",
    "ieftineau": "ieftini",
    "ieftinesc": "ieftini",
    "ieftinește": "ieftini",
    "ieftinești": "ieftini",
    "ieftinii": "ieftini",
    "ieftinim": "ieftini",
    "ieftinind": "ieftini",
    "ieftinindu": "ieftini",
    "ieftiniră": "ieftini",
    "ieftinirăm": "ieftini",
    "ieftinirăți": "ieftini",
    "ieftinise": "ieftini",
    "ieftinisem": "ieftini",
    "ieftiniseră": "ieftini",
    "ieftiniserăm": "ieftini",
    "ieftiniserăți": "ieftini",
    "ieftiniseși": "ieftini",
    "ieftiniși": "ieftini",
    "ieftinit": "ieftini",
    "ieftiniți": "ieftini",
    "ieftinitu": "ieftini",
    "neieftinind": "ieftini",
    "neieftinindu": "ieftini",
    "nemaiieftinind": "ieftini",
    "nemaiieftinindu": "ieftini",
    "ieftinită": "ieftinit",
    "ieftinite": "ieftinit",
    "ieftiniți": "ieftinit",
    "ienupărul": "ienupăr",
    "ienupărului": "ienupăr",
    "ienuperi": "ienupăr",
    "ienuperii": "ienupăr",
    "ienuperilor": "ienupăr",
    "iepurele": "iepure",
    "iepurelui": "iepure",
    "iepuri": "iepure",
    "iepurii": "iepure",
    "iepurilor": "iepure",
    "iepuroaica": "iepuroaică",
    "iepuroaice": "iepuroaică",
    "iepuroaicei": "iepuroaică",
    "iepuroaicele": "iepuroaică",
    "iepuroaicelor": "iepuroaică",
    "ierarhi": "ierarh",
    "ierarhii": "ierarh",
    "ierarhilor": "ierarh",
    "ierarhul": "ierarh",
    "ierarhule": "ierarh",
    "ierarhului": "ierarh",
    "ierarhica": "ierarhic",
    "ierarhică": "ierarhic",
    "ierarhice": "ierarhic",
    "ierarhicei": "ierarhic",
    "ierarhicele": "ierarhic",
    "ierarhicelor": "ierarhic",
    "ierarhici": "ierarhic",
    "ierarhicii": "ierarhic",
    "ierarhicilor": "ierarhic",
    "ierarhicul": "ierarhic",
    "ierarhicului": "ierarhic",
    "ierarhia": "ierarhie",
    "ierarhiei": "ierarhie",
    "ierarhii": "ierarhie",
    "ierarhiile": "ierarhie",
    "ierarhiilor": "ierarhie",
    "ierarhiză": "ierarhiza",
    "ierarhizai": "ierarhiza",
    "ierarhizam": "ierarhiza",
    "ierarhizăm": "ierarhiza",
    "ierarhizând": "ierarhiza",
    "ierarhizându": "ierarhiza",
    "ierarhizară": "ierarhiza",
    "ierarhizarăm": "ierarhiza",
    "ierarhizarăți": "ierarhiza",
    "ierarhizase": "ierarhiza",
    "ierarhizasem": "ierarhiza",
    "ierarhizaseră": "ierarhiza",
    "ierarhizaserăm": "ierarhiza",
    "ierarhizaserăți": "ierarhiza",
    "ierarhizaseși": "ierarhiza",
    "ierarhizași": "ierarhiza",
    "ierarhizat": "ierarhiza",
    "ierarhizați": "ierarhiza",
    "ierarhizatu": "ierarhiza",
    "ierarhizau": "ierarhiza",
    "ierarhizează": "ierarhiza",
    "ierarhizez": "ierarhiza",
    "ierarhizeze": "ierarhiza",
    "ierarhizezi": "ierarhiza",
    "neierarhizând": "ierarhiza",
    "neierarhizându": "ierarhiza",
    "nemaiierarhizând": "ierarhiza",
    "nemaiierarhizându": "ierarhiza",
    "ierarhizarea": "ierarhizare",
    "ierarhizări": "ierarhizare",
    "ierarhizării": "ierarhizare",
    "ierarhizările": "ierarhizare",
    "ierarhizărilor": "ierarhizare",
    "ierarhizata": "ierarhizat",
    "ierarhizată": "ierarhizat",
    "ierarhizate": "ierarhizat",
    "ierarhizatei": "ierarhizat",
    "ierarhizatele": "ierarhizat",
    "ierarhizatelor": "ierarhizat",
    "ierarhizați": "ierarhizat",
    "ierarhizații": "ierarhizat",
    "ierarhizaților": "ierarhizat",
    "ierarhizatul": "ierarhizat",
    "ierarhizatului": "ierarhizat",
    "ierbare": "ierbar",
    "ierbarele": "ierbar",
    "ierbarelor": "ierbar",
    "ierbarul": "ierbar",
    "ierbarului": "ierbar",
    "ierbivora": "ierbivor",
    "ierbivoră": "ierbivor",
    "ierbivore": "ierbivor",
    "ierbivorei": "ierbivor",
    "ierbivorele": "ierbivor",
    "ierbivorelor": "ierbivor",
    "ierbivori": "ierbivor",
    "ierbivorii": "ierbivor",
    "ierbivorilor": "ierbivor",
    "ierbivorul": "ierbivor",
    "ierbivorului": "ierbivor",
    "iernă": "ierna",
    "iernai": "ierna",
    "iernam": "ierna",
    "iernăm": "ierna",
    "iernând": "ierna",
    "iernându": "ierna",
    "iernară": "ierna",
    "iernarăm": "ierna",
    "iernarăți": "ierna",
    "iernase": "ierna",
    "iernasem": "ierna",
    "iernaseră": "ierna",
    "iernaserăm": "ierna",
    "iernaserăți": "ierna",
    "iernaseși": "ierna",
    "iernași": "ierna",
    "iernat": "ierna",
    "iernați": "ierna",
    "iernatu": "ierna",
    "iernau": "ierna",
    "iernează": "ierna",
    "iernez": "ierna",
    "ierneze": "ierna",
    "iernezi": "ierna",
    "neiernând": "ierna",
    "neiernându": "ierna",
    "nemaiiernând": "ierna",
    "nemaiiernându": "ierna",
    "iernată": "iernat",
    "iernate": "iernat",
    "iernați": "iernat",
    "ieromonahi": "ieromonah",
    "ieromonahii": "ieromonah",
    "ieromonahilor": "ieromonah",
    "ieromonahul": "ieromonah",
    "ieromonahule": "ieromonah",
    "ieromonahului": "ieromonah",
    "iartă": "ierta",
    "iert": "ierta",
    "iertă": "ierta",
    "iertai": "ierta",
    "iertam": "ierta",
    "iertăm": "ierta",
    "iertând": "ierta",
    "iertându": "ierta",
    "iertară": "ierta",
    "iertarăm": "ierta",
    "iertarăți": "ierta",
    "iertase": "ierta",
    "iertasem": "ierta",
    "iertaseră": "ierta",
    "iertaserăm": "ierta",
    "iertaserăți": "ierta",
    "iertaseși": "ierta",
    "iertași": "ierta",
    "iertat": "ierta",
    "iertați": "ierta",
    "iertatu": "ierta",
    "iertau": "ierta",
    "ierte": "ierta",
    "ierți": "ierta",
    "neiertând": "ierta",
    "neiertându": "ierta",
    "neiertat": "ierta",
    "nemaiiertând": "ierta",
    "nemaiiertându": "ierta",
    "iertarea": "iertare",
    "iertări": "iertare",
    "iertării": "iertare",
    "iertările": "iertare",
    "iertărilor": "iertare",
    "iertată": "iertat",
    "iertate": "iertat",
    "iertați": "iertat",
    "Ierusalimul": "Ierusalim",
    "Ierusalimului": "Ierusalim",
    "ieșeana": "ieșean",
    "ieșeană": "ieșean",
    "ieșeano": "ieșean",
    "ieșeanul": "ieșean",
    "ieșeanule": "ieșean",
    "ieșeanului": "ieșean",
    "ieșene": "ieșean",
    "ieșenei": "ieșean",
    "ieșenele": "ieșean",
    "ieșenelor": "ieșean",
    "ieșeni": "ieșean",
    "ieșenii": "ieșean",
    "ieșenilor": "ieșean",
    "iasă": "ieși",
    "ies": "ieși",
    "iesă": "ieși",
    "ieșât": "ieși",
    "iese": "ieși",
    "ieșea": "ieși",
    "ieșeai": "ieși",
    "ieșeam": "ieși",
    "ieșeați": "ieși",
    "ieșeau": "ieși",
    "ieși'": "ieși",
    "ieșii": "ieși",
    "ieșim": "ieși",
    "ieșind": "ieși",
    "ieșindu": "ieși",
    "ieșiră": "ieși",
    "ieșirăm": "ieși",
    "ieșirăți": "ieși",
    "ieșise": "ieși",
    "ieșisem": "ieși",
    "ieșiseră": "ieși",
    "ieșiserăm": "ieși",
    "ieșiserăți": "ieși",
    "ieșiseși": "ieși",
    "ieșiși": "ieși",
    "ieșit": "ieși",
    "ieșiți": "ieși",
    "ieșitu": "ieși",
    "neieșind": "ieși",
    "neieșindu": "ieși",
    "nemaiieșind": "ieși",
    "nemaiieșindu": "ieși",
    "ieșirea": "ieșire",
    "ieșiri": "ieșire",
    "ieșirii": "ieșire",
    "ieșirile": "ieșire",
    "ieșirilor": "ieșire",
    "ieși'": "ieșit",
    "ieșita": "ieșit",
    "ieșită": "ieșit",
    "ieșite": "ieșit",
    "ieșitei": "ieșit",
    "ieșitele": "ieșit",
    "ieșitelor": "ieșit",
    "ieșiți": "ieșit",
    "ieșiții": "ieșit",
    "ieșiților": "ieșit",
    "ieșito": "ieșit",
    "ieșitul": "ieșit",
    "ieșitule": "ieșit",
    "ieșitului": "ieșit",
    "ieslea": "iesle",
    "ieslei": "iesle",
    "ieslele": "iesle",
    "ieslelor": "iesle",
    "iezere": "iezer",
    "iezerele": "iezer",
    "iezerelor": "iezer",
    "iezerul": "iezer",
    "iezerului": "iezer",
    "iezea": "iezi",
    "iezeai": "iezi",
    "iezeam": "iezi",
    "iezească": "iezi",
    "iezeați": "iezi",
    "iezeau": "iezi",
    "iezesc": "iezi",
    "iezește": "iezi",
    "iezești": "iezi",
    "iezii": "iezi",
    "iezim": "iezi",
    "iezind": "iezi",
    "iezindu": "iezi",
    "ieziră": "iezi",
    "iezirăm": "iezi",
    "iezirăți": "iezi",
    "iezise": "iezi",
    "iezisem": "iezi",
    "ieziseră": "iezi",
    "ieziserăm": "iezi",
    "ieziserăți": "iezi",
    "ieziseși": "iezi",
    "ieziși": "iezi",
    "iezit": "iezi",
    "ieziți": "iezi",
    "iezitu": "iezi",
    "neiezind": "iezi",
    "neiezindu": "iezi",
    "nemaiiezind": "iezi",
    "nemaiiezindu": "iezi",
    "iezită": "iezit",
    "iezite": "iezit",
    "ieziți": "iezit",
    "ifose": "ifos",
    "ifosele": "ifos",
    "ifoselor": "ifos",
    "ifosul": "ifos",
    "ifosului": "ifos",
    "igiena": "igienă",
    "igienica": "igienic",
    "igienică": "igienic",
    "igienice": "igienic",
    "igienicei": "igienic",
    "igienicele": "igienic",
    "igienicelor": "igienic",
    "igienici": "igienic",
    "igienicii": "igienic",
    "igienicilor": "igienic",
    "igienicul": "igienic",
    "igienicului": "igienic",
    "igienizarea": "igienizare",
    "igienizareo": "igienizare",
    "igienizări": "igienizare",
    "igienizării": "igienizare",
    "igienizările": "igienizare",
    "igienizărilor": "igienizare",
    "ignifuga": "ignifug",
    "ignifugă": "ignifug",
    "ignifuge": "ignifug",
    "ignifugei": "ignifug",
    "ignifugele": "ignifug",
    "ignifugelor": "ignifug",
    "ignifugi": "ignifug",
    "ignifugii": "ignifug",
    "ignifugilor": "ignifug",
    "ignifugul": "ignifug",
    "ignifugului": "ignifug",
    "ignor": "ignora",
    "ignoră": "ignora",
    "ignorai": "ignora",
    "ignoram": "ignora",
    "ignorăm": "ignora",
    "ignorând": "ignora",
    "ignorându": "ignora",
    "ignorară": "ignora",
    "ignorarăm": "ignora",
    "ignorarăți": "ignora",
    "ignorase": "ignora",
    "ignorasem": "ignora",
    "ignoraseră": "ignora",
    "ignoraserăm": "ignora",
    "ignoraserăți": "ignora",
    "ignoraseși": "ignora",
    "ignorași": "ignora",
    "ignorat": "ignora",
    "ignorați": "ignora",
    "ignoratu": "ignora",
    "ignorau": "ignora",
    "ignore": "ignora",
    "ignorează": "ignora",
    "ignorez": "ignora",
    "ignoreze": "ignora",
    "ignorezi": "ignora",
    "ignori": "ignora",
    "neignorând": "ignora",
    "neignorându": "ignora",
    "nemaiignorând": "ignora",
    "nemaiignorându": "ignora",
    "ignoranta": "ignorant",
    "ignorantă": "ignorant",
    "ignorante": "ignorant",
    "ignorantei": "ignorant",
    "ignorantele": "ignorant",
    "ignorantelor": "ignorant",
    "ignoranți": "ignorant",
    "ignoranții": "ignorant",
    "ignoranților": "ignorant",
    "ignorantul": "ignorant",
    "ignorantului": "ignorant",
    "ignoranța": "ignoranță",
    "ignoranțe": "ignoranță",
    "ignoranței": "ignoranță",
    "ignorarea": "ignorare",
    "ignorareo": "ignorare",
    "ignorări": "ignorare",
    "ignorării": "ignorare",
    "ignorările": "ignorare",
    "ignorărilor": "ignorare",
    "ignorată": "ignorat",
    "ignorate": "ignorat",
    "ignorați": "ignorat",
    "igrasia": "igrasie",
    "igrasiei": "igrasie",
    "igrasii": "igrasie",
    "igrasiile": "igrasie",
    "igrasiilor": "igrasie",
    "igrasioasa": "igrasios",
    "igrasioasă": "igrasios",
    "igrasioase": "igrasios",
    "igrasioasei": "igrasios",
    "igrasioasele": "igrasios",
    "igrasioaselor": "igrasios",
    "igrasioși": "igrasios",
    "igrasioșii": "igrasios",
    "igrasioșilor": "igrasios",
    "igrasiosul": "igrasios",
    "igrasiosului": "igrasios",
    "Iisuse": "Iisus",
    "ilaritatea": "ilaritate",
    "ilarități": "ilaritate",
    "ilarității": "ilaritate",
    "ilegala": "ilegal",
    "ilegală": "ilegal",
    "ilegale": "ilegal",
    "ilegalei": "ilegal",
    "ilegalele": "ilegal",
    "ilegalelor": "ilegal",
    "ilegali": "ilegal",
    "ilegalii": "ilegal",
    "ilegalilor": "ilegal",
    "ilegalul": "ilegal",
    "ilegalului": "ilegal",
    "ilegaliști": "ilegalist",
    "ilegaliștii": "ilegalist",
    "ilegaliștilor": "ilegalist",
    "ilegalistul": "ilegalist",
    "ilegalistului": "ilegalist",
    "ilegalitatea": "ilegalitate",
    "ilegalități": "ilegalitate",
    "ilegalității": "ilegalitate",
    "ilegalitățile": "ilegalitate",
    "ilegalităților": "ilegalitate",
    "ilegaliză": "ilegaliza",
    "ilegalizai": "ilegaliza",
    "ilegalizam": "ilegaliza",
    "ilegalizăm": "ilegaliza",
    "ilegalizând": "ilegaliza",
    "ilegalizându": "ilegaliza",
    "ilegalizară": "ilegaliza",
    "ilegalizarăm": "ilegaliza",
    "ilegalizarăți": "ilegaliza",
    "ilegalizase": "ilegaliza",
    "ilegalizasem": "ilegaliza",
    "ilegalizaseră": "ilegaliza",
    "ilegalizaserăm": "ilegaliza",
    "ilegalizaserăți": "ilegaliza",
    "ilegalizaseși": "ilegaliza",
    "ilegalizași": "ilegaliza",
    "ilegalizat": "ilegaliza",
    "ilegalizați": "ilegaliza",
    "ilegalizatu": "ilegaliza",
    "ilegalizau": "ilegaliza",
    "ilegalizează": "ilegaliza",
    "ilegalizez": "ilegaliza",
    "ilegalizeze": "ilegaliza",
    "ilegalizezi": "ilegaliza",
    "neilegalizând": "ilegaliza",
    "neilegalizându": "ilegaliza",
    "nemaiilegalizând": "ilegaliza",
    "nemaiilegalizându": "ilegaliza",
    "ilegalizată": "ilegalizat",
    "ilegalizate": "ilegalizat",
    "ilegalizați": "ilegalizat",
    "Ilfovul": "Ilfov",
    "Ilfovului": "Ilfov",
    "Il": "Iliada",
    "Il.": "Iliada",
    "Iliadă": "Iliada",
    "Iliadei": "Iliada",
    "ilicita": "ilicit",
    "ilicită": "ilicit",
    "ilicite": "ilicit",
    "ilicitei": "ilicit",
    "ilicitele": "ilicit",
    "ilicitelor": "ilicit",
    "iliciți": "ilicit",
    "iliciții": "ilicit",
    "iliciților": "ilicit",
    "ilicito": "ilicit",
    "ilicitul": "ilicit",
    "ilicitule": "ilicit",
    "ilicitului": "ilicit",
    "iliescismul": "iliescism",
    "iliescismului": "iliescism",
    "Ilincăi": "Ilinca",
    "Ilincii": "Ilinca",
    "ilizibila": "ilizibil",
    "ilizibilă": "ilizibil",
    "ilizibile": "ilizibil",
    "ilizibilei": "ilizibil",
    "ilizibilele": "ilizibil",
    "ilizibilelor": "ilizibil",
    "ilizibili": "ilizibil",
    "ilizibilii": "ilizibil",
    "ilizibililor": "ilizibil",
    "ilizibilul": "ilizibil",
    "ilizibilului": "ilizibil",
    "ilogica": "ilogic",
    "ilogică": "ilogic",
    "ilogice": "ilogic",
    "ilogicei": "ilogic",
    "ilogicele": "ilogic",
    "ilogicelor": "ilogic",
    "ilogici": "ilogic",
    "ilogicii": "ilogic",
    "ilogicilor": "ilogic",
    "ilogicul": "ilogic",
    "ilogicului": "ilogic",
    "ilumină": "ilumina",
    "iluminai": "ilumina",
    "iluminam": "ilumina",
    "iluminăm": "ilumina",
    "iluminând": "ilumina",
    "iluminându": "ilumina",
    "iluminară": "ilumina",
    "iluminarăm": "ilumina",
    "iluminarăți": "ilumina",
    "iluminase": "ilumina",
    "iluminasem": "ilumina",
    "iluminaseră": "ilumina",
    "iluminaserăm": "ilumina",
    "iluminaserăți": "ilumina",
    "iluminaseși": "ilumina",
    "iluminași": "ilumina",
    "iluminat": "ilumina",
    "iluminați": "ilumina",
    "iluminatu": "ilumina",
    "iluminau": "ilumina",
    "iluminează": "ilumina",
    "iluminez": "ilumina",
    "ilumineze": "ilumina",
    "iluminezi": "ilumina",
    "neiluminând": "ilumina",
    "neiluminându": "ilumina",
    "nemaiiluminând": "ilumina",
    "nemaiiluminându": "ilumina",
    "iluminarea": "iluminare",
    "iluminareo": "iluminare",
    "iluminări": "iluminare",
    "iluminării": "iluminare",
    "iluminările": "iluminare",
    "iluminărilor": "iluminare",
    "iluminată": "iluminat",
    "iluminate": "iluminat",
    "iluminați": "iluminat",
    "iluminatul": "iluminat",
    "iluminatului": "iluminat",
    "iluminația": "iluminație",
    "iluminației": "iluminație",
    "iluminații": "iluminație",
    "iluminațiile": "iluminație",
    "iluminațiilor": "iluminație",
    "iluminismul": "iluminism",
    "iluminismului": "iluminism",
    "ilustră": "ilustra",
    "ilustrai": "ilustra",
    "ilustram": "ilustra",
    "ilustrăm": "ilustra",
    "ilustrând": "ilustra",
    "ilustrându": "ilustra",
    "ilustrară": "ilustra",
    "ilustrarăm": "ilustra",
    "ilustrarăți": "ilustra",
    "ilustrase": "ilustra",
    "ilustrasem": "ilustra",
    "ilustraseră": "ilustra",
    "ilustraserăm": "ilustra",
    "ilustraserăți": "ilustra",
    "ilustraseși": "ilustra",
    "ilustrași": "ilustra",
    "ilustrat": "ilustra",
    "ilustrați": "ilustra",
    "ilustratu": "ilustra",
    "ilustrau": "ilustra",
    "ilustrează": "ilustra",
    "ilustrez": "ilustra",
    "ilustreze": "ilustra",
    "ilustrezi": "ilustra",
    "neilustrând": "ilustra",
    "neilustrându": "ilustra",
    "nemaiilustrând": "ilustra",
    "nemaiilustrându": "ilustra",
    "ilustrarea": "ilustrare",
    "ilustrări": "ilustrare",
    "ilustrării": "ilustrare",
    "ilustrările": "ilustrare",
    "ilustrărilor": "ilustrare",
    "ilustrata": "ilustrat",
    "ilustrată": "ilustrat",
    "ilustrate": "ilustrat",
    "ilustratei": "ilustrat",
    "ilustratele": "ilustrat",
    "ilustratelor": "ilustrat",
    "ilustrați": "ilustrat",
    "ilustrații": "ilustrat",
    "ilustraților": "ilustrat",
    "ilustratul": "ilustrat",
    "ilustratului": "ilustrat",
    "ilustrata": "ilustrată",
    "ilustrate": "ilustrată",
    "ilustratei": "ilustrată",
    "ilustratele": "ilustrată",
    "ilustratelor": "ilustrată",
    "ilustrația": "ilustrație",
    "ilustrației": "ilustrație",
    "ilustrații": "ilustrație",
    "ilustrațiile": "ilustrație",
    "ilustrațiilor": "ilustrație",
    "ilustrativa": "ilustrativ",
    "ilustrativă": "ilustrativ",
    "ilustrative": "ilustrativ",
    "ilustrativei": "ilustrativ",
    "ilustrativele": "ilustrativ",
    "ilustrativelor": "ilustrativ",
    "ilustrativi": "ilustrativ",
    "ilustrativii": "ilustrativ",
    "ilustrativilor": "ilustrativ",
    "ilustrativul": "ilustrativ",
    "ilustrativului": "ilustrativ",
    "ilustra": "ilustru",
    "ilustră": "ilustru",
    "ilustre": "ilustru",
    "ilustrei": "ilustru",
    "ilustrele": "ilustru",
    "ilustrelor": "ilustru",
    "iluștri": "ilustru",
    "iluștrii": "ilustru",
    "iluștrilor": "ilustru",
    "ilustrul": "ilustru",
    "ilustrului": "ilustru",
    "iluzia": "iluzie",
    "iluziei": "iluzie",
    "iluzii": "iluzie",
    "iluziile": "iluzie",
    "iluziilor": "iluzie",
    "iluzionă": "iluziona",
    "iluzionai": "iluziona",
    "iluzionam": "iluziona",
    "iluzionăm": "iluziona",
    "iluzionând": "iluziona",
    "iluzionându": "iluziona",
    "iluzionară": "iluziona",
    "iluzionarăm": "iluziona",
    "iluzionarăți": "iluziona",
    "iluzionase": "iluziona",
    "iluzionasem": "iluziona",
    "iluzionaseră": "iluziona",
    "iluzionaserăm": "iluziona",
    "iluzionaserăți": "iluziona",
    "iluzionaseși": "iluziona",
    "iluzionași": "iluziona",
    "iluzionat": "iluziona",
    "iluzionați": "iluziona",
    "iluzionatu": "iluziona",
    "iluzionau": "iluziona",
    "iluzionează": "iluziona",
    "iluzionez": "iluziona",
    "iluzioneze": "iluziona",
    "iluzionezi": "iluziona",
    "neiluzionând": "iluziona",
    "neiluzionându": "iluziona",
    "nemaiiluzionând": "iluziona",
    "nemaiiluzionându": "iluziona",
    "iluzionarea": "iluzionare",
    "iluzionări": "iluzionare",
    "iluzionării": "iluzionare",
    "iluzionările": "iluzionare",
    "iluzionărilor": "iluzionare",
    "iluzionată": "iluzionat",
    "iluzionate": "iluzionat",
    "iluzionați": "iluzionat",
    "iluzionismul": "iluzionism",
    "iluzionismului": "iluzionism",
    "iluzioniști": "iluzionist",
    "iluzioniștii": "iluzionist",
    "iluzioniștilor": "iluzionist",
    "iluzionistul": "iluzionist",
    "iluzionistului": "iluzionist",
    "iluzoria": "iluzoriu",
    "iluzorie": "iluzoriu",
    "iluzoriei": "iluzoriu",
    "iluzorii": "iluzoriu",
    "iluzoriii": "iluzoriu",
    "iluzoriile": "iluzoriu",
    "iluzoriilor": "iluzoriu",
    "iluzoriul": "iluzoriu",
    "iluzoriului": "iluzoriu",
    "imaculata": "imaculat",
    "imaculată": "imaculat",
    "imaculate": "imaculat",
    "imaculatei": "imaculat",
    "imaculatele": "imaculat",
    "imaculatelor": "imaculat",
    "imaculați": "imaculat",
    "imaculații": "imaculat",
    "imaculaților": "imaculat",
    "imaculatul": "imaculat",
    "imaculatului": "imaculat",
    "imagină": "imagina",
    "imaginai": "imagina",
    "imaginam": "imagina",
    "imaginăm": "imagina",
    "imaginând": "imagina",
    "imaginându": "imagina",
    "imaginară": "imagina",
    "imaginarăm": "imagina",
    "imaginarăți": "imagina",
    "imaginase": "imagina",
    "imaginasem": "imagina",
    "imaginaseră": "imagina",
    "imaginaserăm": "imagina",
    "imaginaserăți": "imagina",
    "imaginaseși": "imagina",
    "imaginași": "imagina",
    "imaginat": "imagina",
    "imaginați": "imagina",
    "imaginatu": "imagina",
    "imaginau": "imagina",
    "imaginează": "imagina",
    "imaginez": "imagina",
    "imagineze": "imagina",
    "imaginezi": "imagina",
    "neimaginând": "imagina",
    "neimaginându": "imagina",
    "neimaginat": "imagina",
    "nemaiimaginând": "imagina",
    "nemaiimaginându": "imagina",
    "imaginabila": "imaginabil",
    "imaginabilă": "imaginabil",
    "imaginabile": "imaginabil",
    "imaginabilei": "imaginabil",
    "imaginabilele": "imaginabil",
    "imaginabilelor": "imaginabil",
    "imaginabili": "imaginabil",
    "imaginabilii": "imaginabil",
    "imaginabililor": "imaginabil",
    "imaginabilul": "imaginabil",
    "imaginabilului": "imaginabil",
    "imaginara": "imaginar",
    "imaginară": "imaginar",
    "imaginare": "imaginar",
    "imaginarei": "imaginar",
    "imaginarele": "imaginar",
    "imaginarelor": "imaginar",
    "imaginari": "imaginar",
    "imaginarii": "imaginar",
    "imaginarilor": "imaginar",
    "imaginarul": "imaginar",
    "imaginarului": "imaginar",
    "imaginată": "imaginat",
    "imaginate": "imaginat",
    "imaginați": "imaginat",
    "imaginația": "imaginație",
    "imaginației": "imaginație",
    "imaginații": "imaginație",
    "imaginațiile": "imaginație",
    "imaginațiilor": "imaginație",
    "imaginea": "imagine",
    "imagini": "imagine",
    "imaginii": "imagine",
    "imaginile": "imagine",
    "imaginilor": "imagine",
    "imanența": "imanență",
    "imanențe": "imanență",
    "imanenței": "imanență",
    "imanențele": "imanență",
    "imanențelor": "imanență",
    "imanențo": "imanență",
    "imateriala": "imaterial",
    "imaterială": "imaterial",
    "imateriale": "imaterial",
    "imaterialei": "imaterial",
    "imaterialele": "imaterial",
    "imaterialelor": "imaterial",
    "imateriali": "imaterial",
    "imaterialii": "imaterial",
    "imaterialilor": "imaterial",
    "imaterialul": "imaterial",
    "imaterialului": "imaterial",
    "imatura": "imatur",
    "imatură": "imatur",
    "imature": "imatur",
    "imaturei": "imatur",
    "imaturele": "imatur",
    "imaturelor": "imatur",
    "imaturi": "imatur",
    "imaturii": "imatur",
    "imaturilor": "imatur",
    "imaturul": "imatur",
    "imaturului": "imatur",
    "imaturitatea": "imaturitate",
    "imaturități": "imaturitate",
    "imaturității": "imaturitate",
    "îmbâcsea": "îmbâcsi",
    "îmbâcseai": "îmbâcsi",
    "îmbâcseam": "îmbâcsi",
    "îmbâcsească": "îmbâcsi",
    "îmbâcseați": "îmbâcsi",
    "îmbâcseau": "îmbâcsi",
    "îmbâcsesc": "îmbâcsi",
    "îmbâcsește": "îmbâcsi",
    "îmbâcsești": "îmbâcsi",
    "îmbâcsii": "îmbâcsi",
    "îmbâcsim": "îmbâcsi",
    "îmbâcsind": "îmbâcsi",
    "îmbâcsindu": "îmbâcsi",
    "îmbâcsiră": "îmbâcsi",
    "îmbâcsirăm": "îmbâcsi",
    "îmbâcsirăți": "îmbâcsi",
    "îmbâcsise": "îmbâcsi",
    "îmbâcsisem": "îmbâcsi",
    "îmbâcsiseră": "îmbâcsi",
    "îmbâcsiserăm": "îmbâcsi",
    "îmbâcsiserăți": "îmbâcsi",
    "îmbâcsiseși": "îmbâcsi",
    "îmbâcsiși": "îmbâcsi",
    "îmbâcsit": "îmbâcsi",
    "îmbâcsiți": "îmbâcsi",
    "îmbâcsitu": "îmbâcsi",
    "neîmbâcsind": "îmbâcsi",
    "neîmbâcsindu": "îmbâcsi",
    "nemaiîmbâcsind": "îmbâcsi",
    "nemaiîmbâcsindu": "îmbâcsi",
    "îmbâcsită": "îmbâcsit",
    "îmbâcsite": "îmbâcsit",
    "îmbâcsiți": "îmbâcsit",
    "îmbăiai": "îmbăia",
    "îmbăiam": "îmbăia",
    "îmbăiară": "îmbăia",
    "îmbăiarăm": "îmbăia",
    "îmbăiarăți": "îmbăia",
    "îmbăiase": "îmbăia",
    "îmbăiasem": "îmbăia",
    "îmbăiaseră": "îmbăia",
    "îmbăiaserăm": "îmbăia",
    "îmbăiaserăți": "îmbăia",
    "îmbăiaseși": "îmbăia",
    "îmbăiași": "îmbăia",
    "îmbăiat": "îmbăia",
    "îmbăiați": "îmbăia",
    "îmbăiatu": "îmbăia",
    "îmbăiau": "îmbăia",
    "îmbăiază": "îmbăia",
    "îmbăie": "îmbăia",
    "îmbăiem": "îmbăia",
    "îmbăiez": "îmbăia",
    "îmbăieze": "îmbăia",
    "îmbăiezi": "îmbăia",
    "îmbăind": "îmbăia",
    "îmbăindu": "îmbăia",
    "neîmbăiind": "îmbăia",
    "neîmbăiindu": "îmbăia",
    "nemaiîmbăiind": "îmbăia",
    "nemaiîmbăiindu": "îmbăia",
    "îmbăiată": "îmbăiat",
    "îmbăiate": "îmbăiat",
    "îmbăiați": "îmbăiat",
    "îmbălă": "îmbăla",
    "îmbălai": "îmbăla",
    "îmbălam": "îmbăla",
    "îmbălăm": "îmbăla",
    "îmbălând": "îmbăla",
    "îmbălându": "îmbăla",
    "îmbălară": "îmbăla",
    "îmbălarăm": "îmbăla",
    "îmbălarăți": "îmbăla",
    "îmbălase": "îmbăla",
    "îmbălasem": "îmbăla",
    "îmbălaseră": "îmbăla",
    "îmbălaserăm": "îmbăla",
    "îmbălaserăți": "îmbăla",
    "îmbălaseși": "îmbăla",
    "îmbălași": "îmbăla",
    "îmbălat": "îmbăla",
    "îmbălați": "îmbăla",
    "îmbălatu": "îmbăla",
    "îmbălau": "îmbăla",
    "îmbălează": "îmbăla",
    "îmbălez": "îmbăla",
    "îmbăleze": "îmbăla",
    "îmbălezi": "îmbăla",
    "neîmbălând": "îmbăla",
    "neîmbălându": "îmbăla",
    "nemaiîmbălând": "îmbăla",
    "nemaiîmbălându": "îmbăla",
    "îmbălată": "îmbălat",
    "îmbălate": "îmbălat",
    "îmbălați": "îmbălat",
    "îmbăloșă": "îmbăloșa",
    "îmbăloșai": "îmbăloșa",
    "îmbăloșam": "îmbăloșa",
    "îmbăloșăm": "îmbăloșa",
    "îmbăloșând": "îmbăloșa",
    "îmbăloșându": "îmbăloșa",
    "îmbăloșară": "îmbăloșa",
    "îmbăloșarăm": "îmbăloșa",
    "îmbăloșarăți": "îmbăloșa",
    "îmbăloșase": "îmbăloșa",
    "îmbăloșasem": "îmbăloșa",
    "îmbăloșaseră": "îmbăloșa",
    "îmbăloșaserăm": "îmbăloșa",
    "îmbăloșaserăți": "îmbăloșa",
    "îmbăloșaseși": "îmbăloșa",
    "îmbăloșași": "îmbăloșa",
    "îmbăloșat": "îmbăloșa",
    "îmbăloșați": "îmbăloșa",
    "îmbăloșatu": "îmbăloșa",
    "îmbăloșau": "îmbăloșa",
    "îmbăloșează": "îmbăloșa",
    "îmbăloșez": "îmbăloșa",
    "îmbăloșeze": "îmbăloșa",
    "îmbăloșezi": "îmbăloșa",
    "neîmbăloșând": "îmbăloșa",
    "neîmbăloșându": "îmbăloșa",
    "nemaiîmbăloșând": "îmbăloșa",
    "nemaiîmbăloșându": "îmbăloșa",
    "îmbăloșată": "îmbăloșat",
    "îmbăloșate": "îmbăloșat",
    "îmbăloșați": "îmbăloșat",
    "îmbălsămă": "îmbălsăma",
    "îmbălsămai": "îmbălsăma",
    "îmbălsămam": "îmbălsăma",
    "îmbălsămăm": "îmbălsăma",
    "îmbălsămând": "îmbălsăma",
    "îmbălsămându": "îmbălsăma",
    "îmbălsămară": "îmbălsăma",
    "îmbălsămarăm": "îmbălsăma",
    "îmbălsămarăți": "îmbălsăma",
    "îmbălsămase": "îmbălsăma",
    "îmbălsămasem": "îmbălsăma",
    "îmbălsămaseră": "îmbălsăma",
    "îmbălsămaserăm": "îmbălsăma",
    "îmbălsămaserăți": "îmbălsăma",
    "îmbălsămaseși": "îmbălsăma",
    "îmbălsămași": "îmbălsăma",
    "îmbălsămat": "îmbălsăma",
    "îmbălsămați": "îmbălsăma",
    "îmbălsămatu": "îmbălsăma",
    "îmbălsămau": "îmbălsăma",
    "îmbălsămează": "îmbălsăma",
    "îmbălsămez": "îmbălsăma",
    "îmbălsămeze": "îmbălsăma",
    "îmbălsămezi": "îmbălsăma",
    "neîmbălsămând": "îmbălsăma",
    "neîmbălsămându": "îmbălsăma",
    "nemaiîmbălsămând": "îmbălsăma",
    "nemaiîmbălsămându": "îmbălsăma",
    "îmbălsămarea": "îmbălsămare",
    "îmbălsămareo": "îmbălsămare",
    "îmbălsămări": "îmbălsămare",
    "îmbălsămării": "îmbălsămare",
    "îmbălsămările": "îmbălsămare",
    "îmbălsămărilor": "îmbălsămare",
    "îmbălsămată": "îmbălsămat",
    "îmbălsămate": "îmbălsămat",
    "îmbălsămați": "îmbălsămat",
    "îmbărbătă": "îmbărbăta",
    "îmbărbătai": "îmbărbăta",
    "îmbărbătam": "îmbărbăta",
    "îmbărbătăm": "îmbărbăta",
    "îmbărbătând": "îmbărbăta",
    "îmbărbătându": "îmbărbăta",
    "îmbărbătară": "îmbărbăta",
    "îmbărbătarăm": "îmbărbăta",
    "îmbărbătarăți": "îmbărbăta",
    "îmbărbătase": "îmbărbăta",
    "îmbărbătasem": "îmbărbăta",
    "îmbărbătaseră": "îmbărbăta",
    "îmbărbătaserăm": "îmbărbăta",
    "îmbărbătaserăți": "îmbărbăta",
    "îmbărbătaseși": "îmbărbăta",
    "îmbărbătași": "îmbărbăta",
    "îmbărbătat": "îmbărbăta",
    "îmbărbătați": "îmbărbăta",
    "îmbărbătatu": "îmbărbăta",
    "îmbărbătau": "îmbărbăta",
    "îmbărbătează": "îmbărbăta",
    "îmbărbătez": "îmbărbăta",
    "îmbărbăteze": "îmbărbăta",
    "îmbărbătezi": "îmbărbăta",
    "neîmbărbătând": "îmbărbăta",
    "neîmbărbătându": "îmbărbăta",
    "nemaiîmbărbătând": "îmbărbăta",
    "nemaiîmbărbătându": "îmbărbăta",
    "îmbărbătarea": "îmbărbătare",
    "îmbărbătări": "îmbărbătare",
    "îmbărbătării": "îmbărbătare",
    "îmbărbătările": "îmbărbătare",
    "îmbărbătărilor": "îmbărbătare",
    "îmbărbătată": "îmbărbătat",
    "îmbărbătate": "îmbărbătat",
    "îmbărbătați": "îmbărbătat",
    "îmbarc": "îmbarca",
    "îmbarcă": "îmbarca",
    "îmbarcai": "îmbarca",
    "îmbarcam": "îmbarca",
    "îmbarcăm": "îmbarca",
    "îmbarcând": "îmbarca",
    "îmbarcându": "îmbarca",
    "îmbarcară": "îmbarca",
    "îmbarcarăm": "îmbarca",
    "îmbarcarăți": "îmbarca",
    "îmbarcase": "îmbarca",
    "îmbarcasem": "îmbarca",
    "îmbarcaseră": "îmbarca",
    "îmbarcaserăm": "îmbarca",
    "îmbarcaserăți": "îmbarca",
    "îmbarcaseși": "îmbarca",
    "îmbarcași": "îmbarca",
    "îmbarcat": "îmbarca",
    "îmbarcați": "îmbarca",
    "îmbarcatu": "îmbarca",
    "îmbarcau": "îmbarca",
    "îmbarce": "îmbarca",
    "îmbarci": "îmbarca",
    "neîmbarcând": "îmbarca",
    "neîmbarcându": "îmbarca",
    "nemaiîmbarcând": "îmbarca",
    "nemaiîmbarcându": "îmbarca",
    "îmbarcarea": "îmbarcare",
    "îmbarcări": "îmbarcare",
    "îmbarcării": "îmbarcare",
    "îmbarcările": "îmbarcare",
    "îmbarcărilor": "îmbarcare",
    "îmbarcată": "îmbarcat",
    "îmbarcate": "îmbarcat",
    "îmbarcați": "îmbarcat",
    "îmbârlig": "îmbârliga",
    "îmbârligă": "îmbârliga",
    "îmbârligai": "îmbârliga",
    "îmbârligam": "îmbârliga",
    "îmbârligăm": "îmbârliga",
    "îmbârligând": "îmbârliga",
    "îmbârligându": "îmbârliga",
    "îmbârligară": "îmbârliga",
    "îmbârligarăm": "îmbârliga",
    "îmbârligarăți": "îmbârliga",
    "îmbârligase": "îmbârliga",
    "îmbârligasem": "îmbârliga",
    "îmbârligaseră": "îmbârliga",
    "îmbârligaserăm": "îmbârliga",
    "îmbârligaserăți": "îmbârliga",
    "îmbârligaseși": "îmbârliga",
    "îmbârligași": "îmbârliga",
    "îmbârligat": "îmbârliga",
    "îmbârligați": "îmbârliga",
    "îmbârligatu": "îmbârliga",
    "îmbârligau": "îmbârliga",
    "îmbârlige": "îmbârliga",
    "îmbârligi": "îmbârliga",
    "neîmbârligând": "îmbârliga",
    "neîmbârligându": "îmbârliga",
    "nemaiîmbârligând": "îmbârliga",
    "nemaiîmbârligându": "îmbârliga",
    "îmbârligată": "îmbârligat",
    "îmbârligate": "îmbârligat",
    "îmbârligați": "îmbârligat",
    "îmbăt": "îmbăta",
    "îmbată": "îmbăta",
    "îmbătă": "îmbăta",
    "îmbătai": "îmbăta",
    "îmbătam": "îmbăta",
    "îmbătăm": "îmbăta",
    "îmbătând": "îmbăta",
    "îmbătându": "îmbăta",
    "îmbătară": "îmbăta",
    "îmbătarăm": "îmbăta",
    "îmbătarăți": "îmbăta",
    "îmbătase": "îmbăta",
    "îmbătasem": "îmbăta",
    "îmbătaseră": "îmbăta",
    "îmbătaserăm": "îmbăta",
    "îmbătaserăți": "îmbăta",
    "îmbătaseși": "îmbăta",
    "îmbătași": "îmbăta",
    "îmbătat": "îmbăta",
    "îmbătați": "îmbăta",
    "îmbătatu": "îmbăta",
    "îmbătau": "îmbăta",
    "îmbete": "îmbăta",
    "îmbeți": "îmbăta",
    "neîmbătând": "îmbăta",
    "neîmbătându": "îmbăta",
    "nemaiîmbătând": "îmbăta",
    "nemaiîmbătându": "îmbăta",
    "imbatabila": "imbatabil",
    "imbatabilă": "imbatabil",
    "imbatabile": "imbatabil",
    "imbatabilei": "imbatabil",
    "imbatabilele": "imbatabil",
    "imbatabilelor": "imbatabil",
    "imbatabili": "imbatabil",
    "imbatabilii": "imbatabil",
    "imbatabililor": "imbatabil",
    "imbatabilul": "imbatabil",
    "imbatabilului": "imbatabil",
    "îmbătată": "îmbătat",
    "îmbătate": "îmbătat",
    "îmbătați": "îmbătat",
    "îmbătătoare": "îmbătător",
    "îmbătătoarea": "îmbătător",
    "îmbătătoarei": "îmbătător",
    "îmbătătoarele": "îmbătător",
    "îmbătătoarelor": "îmbătător",
    "îmbătători": "îmbătător",
    "îmbătătorii": "îmbătător",
    "îmbătătorilor": "îmbătător",
    "îmbătătorul": "îmbătător",
    "îmbătătorului": "îmbătător",
    "îmbățoșă": "îmbățoșa",
    "îmbățoșai": "îmbățoșa",
    "îmbățoșam": "îmbățoșa",
    "îmbățoșăm": "îmbățoșa",
    "îmbățoșând": "îmbățoșa",
    "îmbățoșându": "îmbățoșa",
    "îmbățoșară": "îmbățoșa",
    "îmbățoșarăm": "îmbățoșa",
    "îmbățoșarăți": "îmbățoșa",
    "îmbățoșase": "îmbățoșa",
    "îmbățoșasem": "îmbățoșa",
    "îmbățoșaseră": "îmbățoșa",
    "îmbățoșaserăm": "îmbățoșa",
    "îmbățoșaserăți": "îmbățoșa",
    "îmbățoșaseși": "îmbățoșa",
    "îmbățoșași": "îmbățoșa",
    "îmbățoșat": "îmbățoșa",
    "îmbățoșați": "îmbățoșa",
    "îmbățoșatu": "îmbățoșa",
    "îmbățoșau": "îmbățoșa",
    "îmbățoșează": "îmbățoșa",
    "îmbățoșez": "îmbățoșa",
    "îmbățoșeze": "îmbățoșa",
    "îmbățoșezi": "îmbățoșa",
    "neîmbățoșând": "îmbățoșa",
    "neîmbățoșându": "îmbățoșa",
    "nemaiîmbățoșând": "îmbățoșa",
    "nemaiîmbățoșându": "îmbățoșa",
    "îmbățoșată": "îmbățoșat",
    "îmbățoșate": "îmbățoșat",
    "îmbățoșați": "îmbățoșat",
    "îmbătrânea": "îmbătrâni",
    "îmbătrâneai": "îmbătrâni",
    "îmbătrâneam": "îmbătrâni",
    "îmbătrânească": "îmbătrâni",
    "îmbătrâneați": "îmbătrâni",
    "îmbătrâneau": "îmbătrâni",
    "îmbătrânesc": "îmbătrâni",
    "îmbătrânește": "îmbătrâni",
    "îmbătrânești": "îmbătrâni",
    "îmbătrânii": "îmbătrâni",
    "îmbătrânim": "îmbătrâni",
    "îmbătrânind": "îmbătrâni",
    "îmbătrânindu": "îmbătrâni",
    "îmbătrâniră": "îmbătrâni",
    "îmbătrânirăm": "îmbătrâni",
    "îmbătrânirăți": "îmbătrâni",
    "îmbătrânise": "îmbătrâni",
    "îmbătrânisem": "îmbătrâni",
    "îmbătrâniseră": "îmbătrâni",
    "îmbătrâniserăm": "îmbătrâni",
    "îmbătrâniserăți": "îmbătrâni",
    "îmbătrâniseși": "îmbătrâni",
    "îmbătrâniși": "îmbătrâni",
    "îmbătrânit": "îmbătrâni",
    "îmbătrâniți": "îmbătrâni",
    "îmbătrânitu": "îmbătrâni",
    "neîmbătrânind": "îmbătrâni",
    "neîmbătrânindu": "îmbătrâni",
    "nemaiîmbătrânind": "îmbătrâni",
    "nemaiîmbătrânindu": "îmbătrâni",
    "îmbătrânirea": "îmbătrânire",
    "îmbătrâniri": "îmbătrânire",
    "îmbătrânirii": "îmbătrânire",
    "îmbătrânirile": "îmbătrânire",
    "îmbătrânirilor": "îmbătrânire",
    "îmbătrânită": "îmbătrânit",
    "îmbătrânite": "îmbătrânit",
    "îmbătrâniți": "îmbătrânit",
    "imbecila": "imbecil",
    "imbecilă": "imbecil",
    "imbecile": "imbecil",
    "imbecilei": "imbecil",
    "imbecilele": "imbecil",
    "imbecilelor": "imbecil",
    "imbecili": "imbecil",
    "imbecilii": "imbecil",
    "imbecililor": "imbecil",
    "imbecilul": "imbecil",
    "imbecilului": "imbecil",
    "imbecilitatea": "imbecilitate",
    "imbecilități": "imbecilitate",
    "imbecilității": "imbecilitate",
    "imbeciliză": "imbeciliza",
    "imbecilizai": "imbeciliza",
    "imbecilizam": "imbeciliza",
    "imbecilizăm": "imbeciliza",
    "imbecilizând": "imbeciliza",
    "imbecilizându": "imbeciliza",
    "imbecilizară": "imbeciliza",
    "imbecilizarăm": "imbeciliza",
    "imbecilizarăți": "imbeciliza",
    "imbecilizase": "imbeciliza",
    "imbecilizasem": "imbeciliza",
    "imbecilizaseră": "imbeciliza",
    "imbecilizaserăm": "imbeciliza",
    "imbecilizaserăți": "imbeciliza",
    "imbecilizaseși": "imbeciliza",
    "imbecilizași": "imbeciliza",
    "imbecilizat": "imbeciliza",
    "imbecilizați": "imbeciliza",
    "imbecilizatu": "imbeciliza",
    "imbecilizau": "imbeciliza",
    "imbecilizează": "imbeciliza",
    "imbecilizez": "imbeciliza",
    "imbecilizeze": "imbeciliza",
    "imbecilizezi": "imbeciliza",
    "neimbecilizând": "imbeciliza",
    "neimbecilizându": "imbeciliza",
    "nemaiimbecilizând": "imbeciliza",
    "nemaiimbecilizându": "imbeciliza",
    "imbecilizată": "imbecilizat",
    "imbecilizate": "imbecilizat",
    "imbecilizați": "imbecilizat",
    "îmbelșugă": "îmbelșuga",
    "îmbelșugai": "îmbelșuga",
    "îmbelșugam": "îmbelșuga",
    "îmbelșugăm": "îmbelșuga",
    "îmbelșugând": "îmbelșuga",
    "îmbelșugându": "îmbelșuga",
    "îmbelșugară": "îmbelșuga",
    "îmbelșugarăm": "îmbelșuga",
    "îmbelșugarăți": "îmbelșuga",
    "îmbelșugase": "îmbelșuga",
    "îmbelșugasem": "îmbelșuga",
    "îmbelșugaseră": "îmbelșuga",
    "îmbelșugaserăm": "îmbelșuga",
    "îmbelșugaserăți": "îmbelșuga",
    "îmbelșugaseși": "îmbelșuga",
    "îmbelșugași": "îmbelșuga",
    "îmbelșugat": "îmbelșuga",
    "îmbelșugați": "îmbelșuga",
    "îmbelșugatu": "îmbelșuga",
    "îmbelșugau": "îmbelșuga",
    "îmbelșughează": "îmbelșuga",
    "îmbelșughez": "îmbelșuga",
    "îmbelșugheze": "îmbelșuga",
    "îmbelșughezi": "îmbelșuga",
    "neîmbelșugând": "îmbelșuga",
    "neîmbelșugându": "îmbelșuga",
    "nemaiîmbelșugând": "îmbelșuga",
    "nemaiîmbelșugându": "îmbelșuga",
    "îmbelșugata": "îmbelșugat",
    "îmbelșugată": "îmbelșugat",
    "îmbelșugate": "îmbelșugat",
    "îmbelșugatei": "îmbelșugat",
    "îmbelșugatele": "îmbelșugat",
    "îmbelșugatelor": "îmbelșugat",
    "îmbelșugați": "îmbelșugat",
    "îmbelșugații": "îmbelșugat",
    "îmbelșugaților": "îmbelșugat",
    "îmbelșugatul": "îmbelșugat",
    "îmbelșugatului": "îmbelșugat",
    "imberba": "imberb",
    "imberbă": "imberb",
    "imberbe": "imberb",
    "imberbei": "imberb",
    "imberbele": "imberb",
    "imberbelor": "imberb",
    "imberbi": "imberb",
    "imberbii": "imberb",
    "imberbilor": "imberb",
    "imberbul": "imberb",
    "imberbului": "imberb",
    "îmbiai": "îmbia",
    "îmbiam": "îmbia",
    "îmbiară": "îmbia",
    "îmbiarăm": "îmbia",
    "îmbiarăți": "îmbia",
    "îmbiase": "îmbia",
    "îmbiasem": "îmbia",
    "îmbiaseră": "îmbia",
    "îmbiaserăm": "îmbia",
    "îmbiaserăți": "îmbia",
    "îmbiaseși": "îmbia",
    "îmbiași": "îmbia",
    "îmbiat": "îmbia",
    "îmbiați": "îmbia",
    "îmbiatu": "îmbia",
    "îmbiau": "îmbia",
    "îmbie": "îmbia",
    "îmbiem": "îmbia",
    "îmbii": "îmbia",
    "îmbiind": "îmbia",
    "îmbiindu": "îmbia",
    "neîmbiind": "îmbia",
    "neîmbiindu": "îmbia",
    "nemaiîmbiind": "îmbia",
    "nemaiîmbiindu": "îmbia",
    "îmbiată": "îmbiat",
    "îmbiate": "îmbiat",
    "îmbiați": "îmbiat",
    "îmbib": "îmbiba",
    "îmbibă": "îmbiba",
    "îmbibai": "îmbiba",
    "îmbibam": "îmbiba",
    "îmbibăm": "îmbiba",
    "îmbibând": "îmbiba",
    "îmbibându": "îmbiba",
    "îmbibară": "îmbiba",
    "îmbibarăm": "îmbiba",
    "îmbibarăți": "îmbiba",
    "îmbibase": "îmbiba",
    "îmbibasem": "îmbiba",
    "îmbibaseră": "îmbiba",
    "îmbibaserăm": "îmbiba",
    "îmbibaserăți": "îmbiba",
    "îmbibaseși": "îmbiba",
    "îmbibași": "îmbiba",
    "îmbibat": "îmbiba",
    "îmbibați": "îmbiba",
    "îmbibatu": "îmbiba",
    "îmbibau": "îmbiba",
    "îmbibe": "îmbiba",
    "îmbibi": "îmbiba",
    "neîmbibând": "îmbiba",
    "neîmbibându": "îmbiba",
    "nemaiîmbibând": "îmbiba",
    "nemaiîmbibându": "îmbiba",
    "îmbibată": "îmbibat",
    "îmbibate": "îmbibat",
    "îmbibați": "îmbibat",
    "îmbietoare": "îmbietor",
    "îmbietoarea": "îmbietor",
    "îmbietoarei": "îmbietor",
    "îmbietoarele": "îmbietor",
    "îmbietoarelor": "îmbietor",
    "îmbietori": "îmbietor",
    "îmbietorii": "îmbietor",
    "îmbietorilor": "îmbietor",
    "îmbietorul": "îmbietor",
    "îmbietorului": "îmbietor",
    "îmbin": "îmbina",
    "îmbină": "îmbina",
    "îmbinai": "îmbina",
    "îmbinam": "îmbina",
    "îmbinăm": "îmbina",
    "îmbinând": "îmbina",
    "îmbinându": "îmbina",
    "îmbinară": "îmbina",
    "îmbinarăm": "îmbina",
    "îmbinarăți": "îmbina",
    "îmbinase": "îmbina",
    "îmbinasem": "îmbina",
    "îmbinaseră": "îmbina",
    "îmbinaserăm": "îmbina",
    "îmbinaserăți": "îmbina",
    "îmbinaseși": "îmbina",
    "îmbinași": "îmbina",
    "îmbinat": "îmbina",
    "îmbinați": "îmbina",
    "îmbinatu": "îmbina",
    "îmbinau": "îmbina",
    "îmbine": "îmbina",
    "îmbini": "îmbina",
    "neîmbinând": "îmbina",
    "neîmbinându": "îmbina",
    "nemaiîmbinând": "îmbina",
    "nemaiîmbinându": "îmbina",
    "îmbinarea": "îmbinare",
    "îmbinări": "îmbinare",
    "îmbinării": "îmbinare",
    "îmbinările": "îmbinare",
    "îmbinărilor": "îmbinare",
    "îmbinată": "îmbinat",
    "îmbinate": "îmbinat",
    "îmbinați": "îmbinat",
    "îmblănea": "îmblăni",
    "îmblăneai": "îmblăni",
    "îmblăneam": "îmblăni",
    "îmblănească": "îmblăni",
    "îmblăneați": "îmblăni",
    "îmblăneau": "îmblăni",
    "îmblănesc": "îmblăni",
    "îmblănește": "îmblăni",
    "îmblănești": "îmblăni",
    "îmblănii": "îmblăni",
    "îmblănim": "îmblăni",
    "îmblănind": "îmblăni",
    "îmblănindu": "îmblăni",
    "îmblăniră": "îmblăni",
    "îmblănirăm": "îmblăni",
    "îmblănirăți": "îmblăni",
    "îmblănise": "îmblăni",
    "îmblănisem": "îmblăni",
    "îmblăniseră": "îmblăni",
    "îmblăniserăm": "îmblăni",
    "îmblăniserăți": "îmblăni",
    "îmblăniseși": "îmblăni",
    "îmblăniși": "îmblăni",
    "îmblănit": "îmblăni",
    "îmblăniți": "îmblăni",
    "îmblănitu": "îmblăni",
    "neîmblănind": "îmblăni",
    "neîmblănindu": "îmblăni",
    "nemaiîmblănind": "îmblăni",
    "nemaiîmblănindu": "îmblăni",
    "îmblănita": "îmblănit",
    "îmblănită": "îmblănit",
    "îmblănite": "îmblănit",
    "îmblănitei": "îmblănit",
    "îmblănitele": "îmblănit",
    "îmblănitelor": "îmblănit",
    "îmblăniți": "îmblănit",
    "îmblăniții": "îmblănit",
    "îmblăniților": "îmblănit",
    "îmblănitul": "îmblănit",
    "îmblănitului": "îmblănit",
    "îmblânzea": "îmblânzi",
    "îmblânzeai": "îmblânzi",
    "îmblânzeam": "îmblânzi",
    "îmblânzească": "îmblânzi",
    "îmblânzeați": "îmblânzi",
    "îmblânzeau": "îmblânzi",
    "îmblânzesc": "îmblânzi",
    "îmblânzește": "îmblânzi",
    "îmblânzești": "îmblânzi",
    "îmblânzii": "îmblânzi",
    "îmblânzim": "îmblânzi",
    "îmblânzind": "îmblânzi",
    "îmblânzindu": "îmblânzi",
    "îmblânziră": "îmblânzi",
    "îmblânzirăm": "îmblânzi",
    "îmblânzirăți": "îmblânzi",
    "îmblânzise": "îmblânzi",
    "îmblânzisem": "îmblânzi",
    "îmblânziseră": "îmblânzi",
    "îmblânziserăm": "îmblânzi",
    "îmblânziserăți": "îmblânzi",
    "îmblânziseși": "îmblânzi",
    "îmblânziși": "îmblânzi",
    "îmblânzit": "îmblânzi",
    "îmblânziți": "îmblânzi",
    "îmblânzitu": "îmblânzi",
    "neîmblânzind": "îmblânzi",
    "neîmblânzindu": "îmblânzi",
    "nemaiîmblânzind": "îmblânzi",
    "nemaiîmblânzindu": "îmblânzi",
    "îmblânzirea": "îmblânzire",
    "îmblânzireo": "îmblânzire",
    "îmblânziri": "îmblânzire",
    "îmblânzirii": "îmblânzire",
    "îmblânzirile": "îmblânzire",
    "îmblânzirilor": "îmblânzire",
    "îmblânzită": "îmblânzit",
    "îmblânzite": "îmblânzit",
    "îmblânziți": "îmblânzit",
    "îmbobocea": "îmboboci",
    "îmboboceai": "îmboboci",
    "îmboboceam": "îmboboci",
    "îmbobocească": "îmboboci",
    "îmboboceați": "îmboboci",
    "îmboboceau": "îmboboci",
    "îmbobocesc": "îmboboci",
    "îmbobocește": "îmboboci",
    "îmbobocești": "îmboboci",
    "îmbobocii": "îmboboci",
    "îmbobocim": "îmboboci",
    "îmbobocind": "îmboboci",
    "îmbobocindu": "îmboboci",
    "îmbobociră": "îmboboci",
    "îmbobocirăm": "îmboboci",
    "îmbobocirăți": "îmboboci",
    "îmbobocise": "îmboboci",
    "îmbobocisem": "îmboboci",
    "îmbobociseră": "îmboboci",
    "îmbobociserăm": "îmboboci",
    "îmbobociserăți": "îmboboci",
    "îmbobociseși": "îmboboci",
    "îmbobociși": "îmboboci",
    "îmbobocit": "îmboboci",
    "îmbobociți": "îmboboci",
    "îmbobocitu": "îmboboci",
    "neîmbobocind": "îmboboci",
    "neîmbobocindu": "îmboboci",
    "nemaiîmbobocind": "îmboboci",
    "nemaiîmbobocindu": "îmboboci",
    "îmbobocită": "îmbobocit",
    "îmbobocite": "îmbobocit",
    "îmbobociți": "îmbobocit",
    "îmbogățea": "îmbogăți",
    "îmbogățeai": "îmbogăți",
    "îmbogățeam": "îmbogăți",
    "îmbogățească": "îmbogăți",
    "îmbogățeați": "îmbogăți",
    "îmbogățeau": "îmbogăți",
    "îmbogățesc": "îmbogăți",
    "îmbogățește": "îmbogăți",
    "îmbogățești": "îmbogăți",
    "îmbogății": "îmbogăți",
    "îmbogățim": "îmbogăți",
    "îmbogățind": "îmbogăți",
    "îmbogățindu": "îmbogăți",
    "îmbogățiră": "îmbogăți",
    "îmbogățirăm": "îmbogăți",
    "îmbogățirăți": "îmbogăți",
    "îmbogățise": "îmbogăți",
    "îmbogățisem": "îmbogăți",
    "îmbogățiseră": "îmbogăți",
    "îmbogățiserăm": "îmbogăți",
    "îmbogățiserăți": "îmbogăți",
    "îmbogățiseși": "îmbogăți",
    "îmbogățiși": "îmbogăți",
    "îmbogățit": "îmbogăți",
    "îmbogățiți": "îmbogăți",
    "îmbogățitu": "îmbogăți",
    "neîmbogățind": "îmbogăți",
    "neîmbogățindu": "îmbogăți",
    "nemaiîmbogățind": "îmbogăți",
    "nemaiîmbogățindu": "îmbogăți",
    "îmbogățirea": "îmbogățire",
    "îmbogățiri": "îmbogățire",
    "îmbogățirii": "îmbogățire",
    "îmbogățirile": "îmbogățire",
    "îmbogățirilor": "îmbogățire",
    "îmbogățită": "îmbogățit",
    "îmbogățite": "îmbogățit",
    "îmbogățiți": "îmbogățit",
    "îmbolbojea": "îmbolboji",
    "îmbolbojeai": "îmbolboji",
    "îmbolbojeam": "îmbolboji",
    "îmbolbojească": "îmbolboji",
    "îmbolbojeați": "îmbolboji",
    "îmbolbojeau": "îmbolboji",
    "îmbolbojesc": "îmbolboji",
    "îmbolbojește": "îmbolboji",
    "îmbolbojești": "îmbolboji",
    "îmbolbojii": "îmbolboji",
    "îmbolbojim": "îmbolboji",
    "îmbolbojind": "îmbolboji",
    "îmbolbojindu": "îmbolboji",
    "îmbolbojiră": "îmbolboji",
    "îmbolbojirăm": "îmbolboji",
    "îmbolbojirăți": "îmbolboji",
    "îmbolbojise": "îmbolboji",
    "îmbolbojisem": "îmbolboji",
    "îmbolbojiseră": "îmbolboji",
    "îmbolbojiserăm": "îmbolboji",
    "îmbolbojiserăți": "îmbolboji",
    "îmbolbojiseși": "îmbolboji",
    "îmbolbojiși": "îmbolboji",
    "îmbolbojit": "îmbolboji",
    "îmbolbojiți": "îmbolboji",
    "îmbolbojitu": "îmbolboji",
    "neîmbolbojind": "îmbolboji",
    "neîmbolbojindu": "îmbolboji",
    "nemaiîmbolbojind": "îmbolboji",
    "nemaiîmbolbojindu": "îmbolboji",
    "îmbolbojită": "îmbolbojit",
    "îmbolbojite": "îmbolbojit",
    "îmbolbojiți": "îmbolbojit",
    "imboldul": "imbold",
    "imboldului": "imbold",
    "imbolduri": "imbold",
    "imboldurile": "imbold",
    "imboldurilor": "imbold",
    "îmboldea": "îmboldi",
    "îmboldeai": "îmboldi",
    "îmboldeam": "îmboldi",
    "îmboldească": "îmboldi",
    "îmboldeați": "îmboldi",
    "îmboldeau": "îmboldi",
    "îmboldesc": "îmboldi",
    "îmboldește": "îmboldi",
    "îmboldești": "îmboldi",
    "îmboldii": "îmboldi",
    "îmboldim": "îmboldi",
    "îmboldind": "îmboldi",
    "îmboldindu": "îmboldi",
    "îmboldiră": "îmboldi",
    "îmboldirăm": "îmboldi",
    "îmboldirăți": "îmboldi",
    "îmboldise": "îmboldi",
    "îmboldisem": "îmboldi",
    "îmboldiseră": "îmboldi",
    "îmboldiserăm": "îmboldi",
    "îmboldiserăți": "îmboldi",
    "îmboldiseși": "îmboldi",
    "îmboldiși": "îmboldi",
    "îmboldit": "îmboldi",
    "îmboldiți": "îmboldi",
    "îmbolditu": "îmboldi",
    "neîmboldind": "îmboldi",
    "neîmboldindu": "îmboldi",
    "nemaiîmboldind": "îmboldi",
    "nemaiîmboldindu": "îmboldi",
    "îmboldită": "îmboldit",
    "îmboldite": "îmboldit",
    "îmboldiți": "îmboldit",
    "îmbolnăvea": "îmbolnăvi",
    "îmbolnăveai": "îmbolnăvi",
    "îmbolnăveam": "îmbolnăvi",
    "îmbolnăvească": "îmbolnăvi",
    "îmbolnăveați": "îmbolnăvi",
    "îmbolnăveau": "îmbolnăvi",
    "îmbolnăvesc": "îmbolnăvi",
    "îmbolnăvește": "îmbolnăvi",
    "îmbolnăvești": "îmbolnăvi",
    "îmbolnăvii": "îmbolnăvi",
    "îmbolnăvim": "îmbolnăvi",
    "îmbolnăvind": "îmbolnăvi",
    "îmbolnăvindu": "îmbolnăvi",
    "îmbolnăviră": "îmbolnăvi",
    "îmbolnăvirăm": "îmbolnăvi",
    "îmbolnăvirăți": "îmbolnăvi",
    "îmbolnăvise": "îmbolnăvi",
    "îmbolnăvisem": "îmbolnăvi",
    "îmbolnăviseră": "îmbolnăvi",
    "îmbolnăviserăm": "îmbolnăvi",
    "îmbolnăviserăți": "îmbolnăvi",
    "îmbolnăviseși": "îmbolnăvi",
    "îmbolnăviși": "îmbolnăvi",
    "îmbolnăvit": "îmbolnăvi",
    "îmbolnăviți": "îmbolnăvi",
    "îmbolnăvitu": "îmbolnăvi",
    "neîmbolnăvind": "îmbolnăvi",
    "neîmbolnăvindu": "îmbolnăvi",
    "nemaiîmbolnăvind": "îmbolnăvi",
    "nemaiîmbolnăvindu": "îmbolnăvi",
    "îmbolnăvirea": "îmbolnăvire",
    "îmbolnăvireo": "îmbolnăvire",
    "îmbolnăviri": "îmbolnăvire",
    "îmbolnăvirii": "îmbolnăvire",
    "îmbolnăvirile": "îmbolnăvire",
    "îmbolnăvirilor": "îmbolnăvire",
    "îmbolnăvită": "îmbolnăvit",
    "îmbolnăvite": "îmbolnăvit",
    "îmbolnăviți": "îmbolnăvit",
    "îmbrac": "îmbrăca",
    "îmbracă": "îmbrăca",
    "îmbrăcă": "îmbrăca",
    "îmbrăcai": "îmbrăca",
    "îmbrăcam": "îmbrăca",
    "îmbrăcăm": "îmbrăca",
    "îmbrăcând": "îmbrăca",
    "îmbrăcându": "îmbrăca",
    "îmbrăcară": "îmbrăca",
    "îmbrăcarăm": "îmbrăca",
    "îmbrăcarăți": "îmbrăca",
    "îmbrăcase": "îmbrăca",
    "îmbrăcasem": "îmbrăca",
    "îmbrăcaseră": "îmbrăca",
    "îmbrăcaserăm": "îmbrăca",
    "îmbrăcaserăți": "îmbrăca",
    "îmbrăcaseși": "îmbrăca",
    "îmbrăcași": "îmbrăca",
    "îmbrăcat": "îmbrăca",
    "îmbrăcați": "îmbrăca",
    "îmbrăcatu": "îmbrăca",
    "îmbrăcau": "îmbrăca",
    "îmbrace": "îmbrăca",
    "îmbraci": "îmbrăca",
    "neîmbrăcând": "îmbrăca",
    "neîmbrăcându": "îmbrăca",
    "nemaiîmbrăcând": "îmbrăca",
    "nemaiîmbrăcându": "îmbrăca",
    "îmbrăcămintea": "îmbrăcăminte",
    "îmbrăcămintei": "îmbrăcăminte",
    "îmbrăcăminți": "îmbrăcăminte",
    "îmbrăcăminții": "îmbrăcăminte",
    "îmbrăcămințile": "îmbrăcăminte",
    "îmbrăcăminților": "îmbrăcăminte",
    "îmbrăcată": "îmbrăcat",
    "îmbrăcate": "îmbrăcat",
    "îmbrăcați": "îmbrăcat",
    "îmbrăcatul": "îmbrăcat",
    "îmbrăcatului": "îmbrăcat",
    "îmbrâncea": "îmbrânci",
    "îmbrânceai": "îmbrânci",
    "îmbrânceam": "îmbrânci",
    "îmbrâncească": "îmbrânci",
    "îmbrânceați": "îmbrânci",
    "îmbrânceau": "îmbrânci",
    "îmbrâncesc": "îmbrânci",
    "îmbrâncește": "îmbrânci",
    "îmbrâncești": "îmbrânci",
    "îmbrâncii": "îmbrânci",
    "îmbrâncim": "îmbrânci",
    "îmbrâncind": "îmbrânci",
    "îmbrâncindu": "îmbrânci",
    "îmbrânciră": "îmbrânci",
    "îmbrâncirăm": "îmbrânci",
    "îmbrâncirăți": "îmbrânci",
    "îmbrâncise": "îmbrânci",
    "îmbrâncisem": "îmbrânci",
    "îmbrânciseră": "îmbrânci",
    "îmbrânciserăm": "îmbrânci",
    "îmbrânciserăți": "îmbrânci",
    "îmbrânciseși": "îmbrânci",
    "îmbrânciși": "îmbrânci",
    "îmbrâncit": "îmbrânci",
    "îmbrânciți": "îmbrânci",
    "îmbrâncitu": "îmbrânci",
    "neîmbrâncind": "îmbrânci",
    "neîmbrâncindu": "îmbrânci",
    "nemaiîmbrâncind": "îmbrânci",
    "nemaiîmbrâncindu": "îmbrânci",
    "îmbrâncită": "îmbrâncit",
    "îmbrâncite": "îmbrâncit",
    "îmbrânciți": "îmbrâncit",
    "îmbrățișă": "îmbrățișa",
    "îmbrățișai": "îmbrățișa",
    "îmbrățișam": "îmbrățișa",
    "îmbrățișăm": "îmbrățișa",
    "îmbrățișând": "îmbrățișa",
    "îmbrățișându": "îmbrățișa",
    "îmbrățișară": "îmbrățișa",
    "îmbrățișarăm": "îmbrățișa",
    "îmbrățișarăți": "îmbrățișa",
    "îmbrățișase": "îmbrățișa",
    "îmbrățișasem": "îmbrățișa",
    "îmbrățișaseră": "îmbrățișa",
    "îmbrățișaserăm": "îmbrățișa",
    "îmbrățișaserăți": "îmbrățișa",
    "îmbrățișaseși": "îmbrățișa",
    "îmbrățișași": "îmbrățișa",
    "îmbrățișat": "îmbrățișa",
    "îmbrățișați": "îmbrățișa",
    "îmbrățișatu": "îmbrățișa",
    "îmbrățișau": "îmbrățișa",
    "îmbrățișează": "îmbrățișa",
    "îmbrățișez": "îmbrățișa",
    "îmbrățișeze": "îmbrățișa",
    "îmbrățișezi": "îmbrățișa",
    "neîmbrățișând": "îmbrățișa",
    "neîmbrățișându": "îmbrățișa",
    "nemaiîmbrățișând": "îmbrățișa",
    "nemaiîmbrățișându": "îmbrățișa",
    "îmbrățișarea": "îmbrățișare",
    "îmbrățișări": "îmbrățișare",
    "îmbrățișării": "îmbrățișare",
    "îmbrățișările": "îmbrățișare",
    "îmbrățișărilor": "îmbrățișare",
    "îmbrățișată": "îmbrățișat",
    "îmbrățișate": "îmbrățișat",
    "îmbrățișați": "îmbrățișat",
    "îmbrobodea": "îmbrobodi",
    "îmbrobodeai": "îmbrobodi",
    "îmbrobodeam": "îmbrobodi",
    "îmbrobodească": "îmbrobodi",
    "îmbrobodeați": "îmbrobodi",
    "îmbrobodeau": "îmbrobodi",
    "îmbrobodesc": "îmbrobodi",
    "îmbrobodește": "îmbrobodi",
    "îmbrobodești": "îmbrobodi",
    "îmbrobodii": "îmbrobodi",
    "îmbrobodim": "îmbrobodi",
    "îmbrobodind": "îmbrobodi",
    "îmbrobodindu": "îmbrobodi",
    "îmbrobodiră": "îmbrobodi",
    "îmbrobodirăm": "îmbrobodi",
    "îmbrobodirăți": "îmbrobodi",
    "îmbrobodise": "îmbrobodi",
    "îmbrobodisem": "îmbrobodi",
    "îmbrobodiseră": "îmbrobodi",
    "îmbrobodiserăm": "îmbrobodi",
    "îmbrobodiserăți": "îmbrobodi",
    "îmbrobodiseși": "îmbrobodi",
    "îmbrobodiși": "îmbrobodi",
    "îmbrobodit": "îmbrobodi",
    "îmbrobodiți": "îmbrobodi",
    "îmbroboditu": "îmbrobodi",
    "neîmbrobodind": "îmbrobodi",
    "neîmbrobodindu": "îmbrobodi",
    "nemaiîmbrobodind": "îmbrobodi",
    "nemaiîmbrobodindu": "îmbrobodi",
    "îmbrobodită": "îmbrobodit",
    "îmbrobodite": "îmbrobodit",
    "îmbrobodiți": "îmbrobodit",
    "îmbuc": "îmbuca",
    "îmbucă": "îmbuca",
    "îmbucai": "îmbuca",
    "îmbucam": "îmbuca",
    "îmbucăm": "îmbuca",
    "îmbucând": "îmbuca",
    "îmbucându": "îmbuca",
    "îmbucară": "îmbuca",
    "îmbucarăm": "îmbuca",
    "îmbucarăți": "îmbuca",
    "îmbucase": "îmbuca",
    "îmbucasem": "îmbuca",
    "îmbucaseră": "îmbuca",
    "îmbucaserăm": "îmbuca",
    "îmbucaserăți": "îmbuca",
    "îmbucaseși": "îmbuca",
    "îmbucași": "îmbuca",
    "îmbucat": "îmbuca",
    "îmbucați": "îmbuca",
    "îmbucatu": "îmbuca",
    "îmbucau": "îmbuca",
    "îmbuce": "îmbuca",
    "îmbuci": "îmbuca",
    "neîmbucând": "îmbuca",
    "neîmbucându": "îmbuca",
    "nemaiîmbucând": "îmbuca",
    "nemaiîmbucându": "îmbuca",
    "îmbucarea": "îmbucare",
    "îmbucareo": "îmbucare",
    "îmbucări": "îmbucare",
    "îmbucării": "îmbucare",
    "îmbucările": "îmbucare",
    "îmbucărilor": "îmbucare",
    "îmbucată": "îmbucat",
    "îmbucate": "îmbucat",
    "îmbucați": "îmbucat",
    "îmbucătățea": "îmbucătăți",
    "îmbucătățeai": "îmbucătăți",
    "îmbucătățeam": "îmbucătăți",
    "îmbucătățească": "îmbucătăți",
    "îmbucătățeați": "îmbucătăți",
    "îmbucătățeau": "îmbucătăți",
    "îmbucătățesc": "îmbucătăți",
    "îmbucătățește": "îmbucătăți",
    "îmbucătățești": "îmbucătăți",
    "îmbucătății": "îmbucătăți",
    "îmbucătățim": "îmbucătăți",
    "îmbucătățind": "îmbucătăți",
    "îmbucătățindu": "îmbucătăți",
    "îmbucătățiră": "îmbucătăți",
    "îmbucătățirăm": "îmbucătăți",
    "îmbucătățirăți": "îmbucătăți",
    "îmbucătățise": "îmbucătăți",
    "îmbucătățisem": "îmbucătăți",
    "îmbucătățiseră": "îmbucătăți",
    "îmbucătățiserăm": "îmbucătăți",
    "îmbucătățiserăți": "îmbucătăți",
    "îmbucătățiseși": "îmbucătăți",
    "îmbucătățiși": "îmbucătăți",
    "îmbucătățit": "îmbucătăți",
    "îmbucătățiți": "îmbucătăți",
    "îmbucătățitu": "îmbucătăți",
    "neîmbucătățind": "îmbucătăți",
    "neîmbucătățindu": "îmbucătăți",
    "nemaiîmbucătățind": "îmbucătăți",
    "nemaiîmbucătățindu": "îmbucătăți",
    "îmbucătățită": "îmbucătățit",
    "îmbucătățite": "îmbucătățit",
    "îmbucătățiți": "îmbucătățit",
    "îmbucățea": "îmbucăți",
    "îmbucățeai": "îmbucăți",
    "îmbucățeam": "îmbucăți",
    "îmbucățească": "îmbucăți",
    "îmbucățeați": "îmbucăți",
    "îmbucățeau": "îmbucăți",
    "îmbucățesc": "îmbucăți",
    "îmbucățește": "îmbucăți",
    "îmbucățești": "îmbucăți",
    "îmbucății": "îmbucăți",
    "îmbucățim": "îmbucăți",
    "îmbucățind": "îmbucăți",
    "îmbucățindu": "îmbucăți",
    "îmbucățiră": "îmbucăți",
    "îmbucățirăm": "îmbucăți",
    "îmbucățirăți": "îmbucăți",
    "îmbucățise": "îmbucăți",
    "îmbucățisem": "îmbucăți",
    "îmbucățiseră": "îmbucăți",
    "îmbucățiserăm": "îmbucăți",
    "îmbucățiserăți": "îmbucăți",
    "îmbucățiseși": "îmbucăți",
    "îmbucățiși": "îmbucăți",
    "îmbucățit": "îmbucăți",
    "îmbucățiți": "îmbucăți",
    "îmbucățitu": "îmbucăți",
    "neîmbucățind": "îmbucăți",
    "neîmbucățindu": "îmbucăți",
    "nemaiîmbucățind": "îmbucăți",
    "nemaiîmbucățindu": "îmbucăți",
    "îmbucățită": "îmbucățit",
    "îmbucățite": "îmbucățit",
    "îmbucățiți": "îmbucățit",
    "îmbucătura": "îmbucătură",
    "îmbucături": "îmbucătură",
    "îmbucăturii": "îmbucătură",
    "îmbucăturile": "îmbucătură",
    "îmbucăturilor": "îmbucătură",
    "îmbucur": "îmbucura",
    "îmbucură": "îmbucura",
    "îmbucurai": "îmbucura",
    "îmbucuram": "îmbucura",
    "îmbucurăm": "îmbucura",
    "îmbucurând": "îmbucura",
    "îmbucurându": "îmbucura",
    "îmbucurară": "îmbucura",
    "îmbucurarăm": "îmbucura",
    "îmbucurarăți": "îmbucura",
    "îmbucurase": "îmbucura",
    "îmbucurasem": "îmbucura",
    "îmbucuraseră": "îmbucura",
    "îmbucuraserăm": "îmbucura",
    "îmbucuraserăți": "îmbucura",
    "îmbucuraseși": "îmbucura",
    "îmbucurași": "îmbucura",
    "îmbucurat": "îmbucura",
    "îmbucurați": "îmbucura",
    "îmbucuratu": "îmbucura",
    "îmbucurau": "îmbucura",
    "îmbucure": "îmbucura",
    "îmbucuri": "îmbucura",
    "neîmbucurând": "îmbucura",
    "neîmbucurându": "îmbucura",
    "nemaiîmbucurând": "îmbucura",
    "nemaiîmbucurându": "îmbucura",
    "îmbucurată": "îmbucurat",
    "îmbucurate": "îmbucurat",
    "îmbucurați": "îmbucurat",
    "îmbucurătoare": "îmbucurător",
    "îmbucurătoarea": "îmbucurător",
    "îmbucurătoarei": "îmbucurător",
    "îmbucurătoarele": "îmbucurător",
    "îmbucurătoarelor": "îmbucurător",
    "îmbucurători": "îmbucurător",
    "îmbucurătorii": "îmbucurător",
    "îmbucurătorilor": "îmbucurător",
    "îmbucurătorul": "îmbucurător",
    "îmbucurătorului": "îmbucurător",
    "îmbufnă": "îmbufna",
    "îmbufnai": "îmbufna",
    "îmbufnam": "îmbufna",
    "îmbufnăm": "îmbufna",
    "îmbufnând": "îmbufna",
    "îmbufnându": "îmbufna",
    "îmbufnară": "îmbufna",
    "îmbufnarăm": "îmbufna",
    "îmbufnarăți": "îmbufna",
    "îmbufnase": "îmbufna",
    "îmbufnasem": "îmbufna",
    "îmbufnaseră": "îmbufna",
    "îmbufnaserăm": "îmbufna",
    "îmbufnaserăți": "îmbufna",
    "îmbufnaseși": "îmbufna",
    "îmbufnași": "îmbufna",
    "îmbufnat": "îmbufna",
    "îmbufnați": "îmbufna",
    "îmbufnatu": "îmbufna",
    "îmbufnau": "îmbufna",
    "îmbufnează": "îmbufna",
    "îmbufnez": "îmbufna",
    "îmbufneze": "îmbufna",
    "îmbufnezi": "îmbufna",
    "neîmbufnând": "îmbufna",
    "neîmbufnându": "îmbufna",
    "nemaiîmbufnând": "îmbufna",
    "nemaiîmbufnându": "îmbufna",
    "îmbufnata": "îmbufnat",
    "îmbufnată": "îmbufnat",
    "îmbufnate": "îmbufnat",
    "îmbufnatei": "îmbufnat",
    "îmbufnatele": "îmbufnat",
    "îmbufnatelor": "îmbufnat",
    "îmbufnați": "îmbufnat",
    "îmbufnații": "îmbufnat",
    "îmbufnaților": "îmbufnat",
    "îmbufnatul": "îmbufnat",
    "îmbufnatului": "îmbufnat",
    "îmbuib": "îmbuiba",
    "îmbuibă": "îmbuiba",
    "îmbuibai": "îmbuiba",
    "îmbuibam": "îmbuiba",
    "îmbuibăm": "îmbuiba",
    "îmbuibând": "îmbuiba",
    "îmbuibându": "îmbuiba",
    "îmbuibară": "îmbuiba",
    "îmbuibarăm": "îmbuiba",
    "îmbuibarăți": "îmbuiba",
    "îmbuibase": "îmbuiba",
    "îmbuibasem": "îmbuiba",
    "îmbuibaseră": "îmbuiba",
    "îmbuibaserăm": "îmbuiba",
    "îmbuibaserăți": "îmbuiba",
    "îmbuibaseși": "îmbuiba",
    "îmbuibași": "îmbuiba",
    "îmbuibat": "îmbuiba",
    "îmbuibați": "îmbuiba",
    "îmbuibatu": "îmbuiba",
    "îmbuibau": "îmbuiba",
    "îmbuibe": "îmbuiba",
    "îmbuibi": "îmbuiba",
    "neîmbuibând": "îmbuiba",
    "neîmbuibându": "îmbuiba",
    "nemaiîmbuibând": "îmbuiba",
    "nemaiîmbuibându": "îmbuiba",
    "îmbuibată": "îmbuibat",
    "îmbuibate": "îmbuibat",
    "îmbuibați": "îmbuibat",
    "îmbujoră": "îmbujora",
    "îmbujorai": "îmbujora",
    "îmbujoram": "îmbujora",
    "îmbujorăm": "îmbujora",
    "îmbujorând": "îmbujora",
    "îmbujorându": "îmbujora",
    "îmbujorară": "îmbujora",
    "îmbujorarăm": "îmbujora",
    "îmbujorarăți": "îmbujora",
    "îmbujorase": "îmbujora",
    "îmbujorasem": "îmbujora",
    "îmbujoraseră": "îmbujora",
    "îmbujoraserăm": "îmbujora",
    "îmbujoraserăți": "îmbujora",
    "îmbujoraseși": "îmbujora",
    "îmbujorași": "îmbujora",
    "îmbujorat": "îmbujora",
    "îmbujorați": "îmbujora",
    "îmbujoratu": "îmbujora",
    "îmbujorau": "îmbujora",
    "îmbujorează": "îmbujora",
    "îmbujorez": "îmbujora",
    "îmbujoreze": "îmbujora",
    "îmbujorezi": "îmbujora",
    "neîmbujorând": "îmbujora",
    "neîmbujorându": "îmbujora",
    "nemaiîmbujorând": "îmbujora",
    "nemaiîmbujorându": "îmbujora",
    "îmbujorată": "îmbujorat",
    "îmbujorate": "îmbujorat",
    "îmbujorați": "îmbujorat",
    "îmbulzeala": "îmbulzeală",
    "îmbulzeli": "îmbulzeală",
    "îmbulzelii": "îmbulzeală",
    "îmbulzelile": "îmbulzeală",
    "îmbulzelilor": "îmbulzeală",
    "îmbulzea": "îmbulzi",
    "îmbulzeai": "îmbulzi",
    "îmbulzeam": "îmbulzi",
    "îmbulzească": "îmbulzi",
    "îmbulzeați": "îmbulzi",
    "îmbulzeau": "îmbulzi",
    "îmbulzesc": "îmbulzi",
    "îmbulzește": "îmbulzi",
    "îmbulzești": "îmbulzi",
    "îmbulzii": "îmbulzi",
    "îmbulzim": "îmbulzi",
    "îmbulzind": "îmbulzi",
    "îmbulzindu": "îmbulzi",
    "îmbulziră": "îmbulzi",
    "îmbulzirăm": "îmbulzi",
    "îmbulzirăți": "îmbulzi",
    "îmbulzise": "îmbulzi",
    "îmbulzisem": "îmbulzi",
    "îmbulziseră": "îmbulzi",
    "îmbulziserăm": "îmbulzi",
    "îmbulziserăți": "îmbulzi",
    "îmbulziseși": "îmbulzi",
    "îmbulziși": "îmbulzi",
    "îmbulzit": "îmbulzi",
    "îmbulziți": "îmbulzi",
    "îmbulzitu": "îmbulzi",
    "neîmbulzind": "îmbulzi",
    "neîmbulzindu": "îmbulzi",
    "nemaiîmbulzind": "îmbulzi",
    "nemaiîmbulzindu": "îmbulzi",
    "îmbulzită": "îmbulzit",
    "îmbulzite": "îmbulzit",
    "îmbulziți": "îmbulzit",
    "îmbună": "îmbuna",
    "îmbunai": "îmbuna",
    "îmbunam": "îmbuna",
    "îmbunăm": "îmbuna",
    "îmbunând": "îmbuna",
    "îmbunându": "îmbuna",
    "îmbunară": "îmbuna",
    "îmbunarăm": "îmbuna",
    "îmbunarăți": "îmbuna",
    "îmbunase": "îmbuna",
    "îmbunasem": "îmbuna",
    "îmbunaseră": "îmbuna",
    "îmbunaserăm": "îmbuna",
    "îmbunaserăți": "îmbuna",
    "îmbunaseși": "îmbuna",
    "îmbunași": "îmbuna",
    "îmbunat": "îmbuna",
    "îmbunați": "îmbuna",
    "îmbunatu": "îmbuna",
    "îmbunau": "îmbuna",
    "îmbunează": "îmbuna",
    "îmbunez": "îmbuna",
    "îmbuneze": "îmbuna",
    "îmbunezi": "îmbuna",
    "neîmbunând": "îmbuna",
    "neîmbunându": "îmbuna",
    "nemaiîmbunând": "îmbuna",
    "nemaiîmbunându": "îmbuna",
    "îmbunată": "îmbunat",
    "îmbunate": "îmbunat",
    "îmbunați": "îmbunat",
    "îmbunătățea": "îmbunătăți",
    "îmbunătățeai": "îmbunătăți",
    "îmbunătățeam": "îmbunătăți",
    "îmbunătățească": "îmbunătăți",
    "îmbunătățeați": "îmbunătăți",
    "îmbunătățeau": "îmbunătăți",
    "îmbunătățesc": "îmbunătăți",
    "îmbunătățește": "îmbunătăți",
    "îmbunătățești": "îmbunătăți",
    "îmbunătății": "îmbunătăți",
    "îmbunătățim": "îmbunătăți",
    "îmbunătățind": "îmbunătăți",
    "îmbunătățindu": "îmbunătăți",
    "îmbunătățiră": "îmbunătăți",
    "îmbunătățirăm": "îmbunătăți",
    "îmbunătățirăți": "îmbunătăți",
    "îmbunătățise": "îmbunătăți",
    "îmbunătățisem": "îmbunătăți",
    "îmbunătățiseră": "îmbunătăți",
    "îmbunătățiserăm": "îmbunătăți",
    "îmbunătățiserăți": "îmbunătăți",
    "îmbunătățiseși": "îmbunătăți",
    "îmbunătățiși": "îmbunătăți",
    "îmbunătățit": "îmbunătăți",
    "îmbunătățiți": "îmbunătăți",
    "îmbunătățitu": "îmbunătăți",
    "neîmbunătățind": "îmbunătăți",
    "neîmbunătățindu": "îmbunătăți",
    "nemaiîmbunătățind": "îmbunătăți",
    "nemaiîmbunătățindu": "îmbunătăți",
    "îmbunătățirea": "îmbunătățire",
    "îmbunătățiri": "îmbunătățire",
    "îmbunătățirii": "îmbunătățire",
    "îmbunătățirile": "îmbunătățire",
    "îmbunătățirilor": "îmbunătățire",
    "îmbunătățita": "îmbunătățit",
    "îmbunătățită": "îmbunătățit",
    "îmbunătățite": "îmbunătățit",
    "îmbunătățitei": "îmbunătățit",
    "îmbunătățitele": "îmbunătățit",
    "îmbunătățitelor": "îmbunătățit",
    "îmbunătățiți": "îmbunătățit",
    "îmbunătățiții": "îmbunătățit",
    "îmbunătățiților": "îmbunătățit",
    "îmbunătățito": "îmbunătățit",
    "îmbunătățitul": "îmbunătățit",
    "îmbunătățitule": "îmbunătățit",
    "îmbunătățitului": "îmbunătățit",
    "îmburghezea": "îmburghezi",
    "îmburghezeai": "îmburghezi",
    "îmburghezeam": "îmburghezi",
    "îmburghezească": "îmburghezi",
    "îmburghezeați": "îmburghezi",
    "îmburghezeau": "îmburghezi",
    "îmburghezesc": "îmburghezi",
    "îmburghezește": "îmburghezi",
    "îmburghezești": "îmburghezi",
    "îmburghezii": "îmburghezi",
    "îmburghezim": "îmburghezi",
    "îmburghezind": "îmburghezi",
    "îmburghezindu": "îmburghezi",
    "îmburgheziră": "îmburghezi",
    "îmburghezirăm": "îmburghezi",
    "îmburghezirăți": "îmburghezi",
    "îmburghezise": "îmburghezi",
    "îmburghezisem": "îmburghezi",
    "îmburgheziseră": "îmburghezi",
    "îmburgheziserăm": "îmburghezi",
    "îmburgheziserăți": "îmburghezi",
    "îmburgheziseși": "îmburghezi",
    "îmburgheziși": "îmburghezi",
    "îmburghezit": "îmburghezi",
    "îmburgheziți": "îmburghezi",
    "îmburghezitu": "îmburghezi",
    "neîmburghezind": "îmburghezi",
    "neîmburghezindu": "îmburghezi",
    "nemaiîmburghezind": "îmburghezi",
    "nemaiîmburghezindu": "îmburghezi",
    "îmburghezită": "îmburghezit",
    "îmburghezite": "îmburghezit",
    "îmburgheziți": "îmburghezit",
    "îmbuteliă": "îmbutelia",
    "îmbuteliai": "îmbutelia",
    "îmbuteliam": "îmbutelia",
    "îmbuteliăm": "îmbutelia",
    "îmbuteliând": "îmbutelia",
    "îmbuteliându": "îmbutelia",
    "îmbuteliară": "îmbutelia",
    "îmbuteliarăm": "îmbutelia",
    "îmbuteliarăți": "îmbutelia",
    "îmbuteliase": "îmbutelia",
    "îmbuteliasem": "îmbutelia",
    "îmbuteliaseră": "îmbutelia",
    "îmbuteliaserăm": "îmbutelia",
    "îmbuteliaserăți": "îmbutelia",
    "îmbuteliaseși": "îmbutelia",
    "îmbuteliași": "îmbutelia",
    "îmbuteliat": "îmbutelia",
    "îmbuteliați": "îmbutelia",
    "îmbuteliatu": "îmbutelia",
    "îmbuteliau": "îmbutelia",
    "îmbuteliează": "îmbutelia",
    "îmbuteliez": "îmbutelia",
    "îmbutelieze": "îmbutelia",
    "îmbuteliezi": "îmbutelia",
    "neîmbuteliând": "îmbutelia",
    "neîmbuteliându": "îmbutelia",
    "nemaiîmbuteliând": "îmbutelia",
    "nemaiîmbuteliându": "îmbutelia",
    "îmbuteliată": "îmbuteliat",
    "îmbuteliate": "îmbuteliat",
    "îmbuteliați": "îmbuteliat",
    "imediata": "imediat",
    "imediată": "imediat",
    "imediate": "imediat",
    "imediatei": "imediat",
    "imediatele": "imediat",
    "imediatelor": "imediat",
    "imediați": "imediat",
    "imediații": "imediat",
    "imediaților": "imediat",
    "imediatul": "imediat",
    "imediatului": "imediat",
    "imemoriala": "imemorial",
    "imemorială": "imemorial",
    "imemoriale": "imemorial",
    "imemorialei": "imemorial",
    "imemorialele": "imemorial",
    "imemorialelor": "imemorial",
    "imemoriali": "imemorial",
    "imemorialii": "imemorial",
    "imemorialilor": "imemorial",
    "imemorialo": "imemorial",
    "imemorialul": "imemorial",
    "imemorialule": "imemorial",
    "imemorialului": "imemorial",
    "imensa": "imens",
    "imensă": "imens",
    "imense": "imens",
    "imensei": "imens",
    "imensele": "imens",
    "imenselor": "imens",
    "imenși": "imens",
    "imenșii": "imens",
    "imenșilor": "imens",
    "imensul": "imens",
    "imensului": "imens",
    "imensitatea": "imensitate",
    "imensități": "imensitate",
    "imensității": "imensitate",
    "imersiunea": "imersiune",
    "imersiuni": "imersiune",
    "imersiunii": "imersiune",
    "imersiunile": "imersiune",
    "imersiunilor": "imersiune",
    "îm'": "îmi",
    "imigră": "imigra",
    "imigrai": "imigra",
    "imigram": "imigra",
    "imigrăm": "imigra",
    "imigrând": "imigra",
    "imigrându": "imigra",
    "imigrară": "imigra",
    "imigrarăm": "imigra",
    "imigrarăți": "imigra",
    "imigrase": "imigra",
    "imigrasem": "imigra",
    "imigraseră": "imigra",
    "imigraserăm": "imigra",
    "imigraserăți": "imigra",
    "imigraseși": "imigra",
    "imigrași": "imigra",
    "imigrat": "imigra",
    "imigrați": "imigra",
    "imigratu": "imigra",
    "imigrau": "imigra",
    "imigrează": "imigra",
    "imigrez": "imigra",
    "imigreze": "imigra",
    "imigrezi": "imigra",
    "neimigrând": "imigra",
    "neimigrându": "imigra",
    "nemaiimigrând": "imigra",
    "nemaiimigrându": "imigra",
    "imigranți": "imigrant",
    "imigranții": "imigrant",
    "imigranților": "imigrant",
    "imigrantul": "imigrant",
    "imigrantului": "imigrant",
    "imigrată": "imigrat",
    "imigrate": "imigrat",
    "imigrați": "imigrat",
    "iminenta": "iminent",
    "iminentă": "iminent",
    "iminente": "iminent",
    "iminentei": "iminent",
    "iminentele": "iminent",
    "iminentelor": "iminent",
    "iminenți": "iminent",
    "iminenții": "iminent",
    "iminenților": "iminent",
    "iminentul": "iminent",
    "iminentului": "iminent",
    "imit": "imita",
    "imită": "imita",
    "imitai": "imita",
    "imitam": "imita",
    "imităm": "imita",
    "imitând": "imita",
    "imitându": "imita",
    "imitară": "imita",
    "imitarăm": "imita",
    "imitarăți": "imita",
    "imitase": "imita",
    "imitasem": "imita",
    "imitaseră": "imita",
    "imitaserăm": "imita",
    "imitaserăți": "imita",
    "imitaseși": "imita",
    "imitași": "imita",
    "imitat": "imita",
    "imitați": "imita",
    "imitatu": "imita",
    "imitau": "imita",
    "imite": "imita",
    "imiți": "imita",
    "neimitând": "imita",
    "neimitându": "imita",
    "nemaiimitând": "imita",
    "nemaiimitându": "imita",
    "imitarea": "imitare",
    "imitareo": "imitare",
    "imitări": "imitare",
    "imitării": "imitare",
    "imitările": "imitare",
    "imitărilor": "imitare",
    "imitată": "imitat",
    "imitate": "imitat",
    "imitați": "imitat",
    "imitația": "imitație",
    "imitației": "imitație",
    "imitații": "imitație",
    "imitațiile": "imitație",
    "imitațiilor": "imitație",
    "imitativa": "imitativ",
    "imitativă": "imitativ",
    "imitative": "imitativ",
    "imitativei": "imitativ",
    "imitativele": "imitativ",
    "imitativelor": "imitativ",
    "imitativi": "imitativ",
    "imitativii": "imitativ",
    "imitativilor": "imitativ",
    "imitativo": "imitativ",
    "imitativul": "imitativ",
    "imitativule": "imitativ",
    "imitativului": "imitativ",
    "imitatoare": "imitator",
    "imitatoarea": "imitator",
    "imitatoarei": "imitator",
    "imitatoarele": "imitator",
    "imitatoarelor": "imitator",
    "imitatori": "imitator",
    "imitatorii": "imitator",
    "imitatorilor": "imitator",
    "imitatorul": "imitator",
    "imitatorului": "imitator",
    "imixtiunea": "imixtiune",
    "imixtiuni": "imixtiune",
    "imixtiunii": "imixtiune",
    "imixtiunile": "imixtiune",
    "imixtiunilor": "imixtiune",
    "imnul": "imn",
    "imnului": "imn",
    "imnuri": "imn",
    "imnurile": "imn",
    "imnurilor": "imn",
    "imobila": "imobil",
    "imobilă": "imobil",
    "imobile": "imobil",
    "imobilei": "imobil",
    "imobilele": "imobil",
    "imobilelor": "imobil",
    "imobili": "imobil",
    "imobilii": "imobil",
    "imobililor": "imobil",
    "imobilul": "imobil",
    "imobilului": "imobil",
    "imobiliara": "imobiliar",
    "imobiliară": "imobiliar",
    "imobiliare": "imobiliar",
    "imobiliarei": "imobiliar",
    "imobiliarele": "imobiliar",
    "imobiliarelor": "imobiliar",
    "imobiliari": "imobiliar",
    "imobiliarii": "imobiliar",
    "imobiliarilor": "imobiliar",
    "imobiliarul": "imobiliar",
    "imobiliarului": "imobiliar",
    "imobilismul": "imobilism",
    "imobilismului": "imobilism",
    "imobilitatea": "imobilitate",
    "imobilități": "imobilitate",
    "imobilității": "imobilitate",
    "imobiliză": "imobiliza",
    "imobilizai": "imobiliza",
    "imobilizam": "imobiliza",
    "imobilizăm": "imobiliza",
    "imobilizând": "imobiliza",
    "imobilizându": "imobiliza",
    "imobilizară": "imobiliza",
    "imobilizarăm": "imobiliza",
    "imobilizarăți": "imobiliza",
    "imobilizase": "imobiliza",
    "imobilizasem": "imobiliza",
    "imobilizaseră": "imobiliza",
    "imobilizaserăm": "imobiliza",
    "imobilizaserăți": "imobiliza",
    "imobilizaseși": "imobiliza",
    "imobilizași": "imobiliza",
    "imobilizat": "imobiliza",
    "imobilizați": "imobiliza",
    "imobilizatu": "imobiliza",
    "imobilizau": "imobiliza",
    "imobilizează": "imobiliza",
    "imobilizez": "imobiliza",
    "imobilizeze": "imobiliza",
    "imobilizezi": "imobiliza",
    "neimobilizând": "imobiliza",
    "neimobilizându": "imobiliza",
    "nemaiimobilizând": "imobiliza",
    "nemaiimobilizându": "imobiliza",
    "imobilizarea": "imobilizare",
    "imobilizări": "imobilizare",
    "imobilizării": "imobilizare",
    "imobilizările": "imobilizare",
    "imobilizărilor": "imobilizare",
    "imobilizată": "imobilizat",
    "imobilizate": "imobilizat",
    "imobilizați": "imobilizat",
    "imolă": "imola",
    "imolai": "imola",
    "imolam": "imola",
    "imolăm": "imola",
    "imolând": "imola",
    "imolându": "imola",
    "imolară": "imola",
    "imolarăm": "imola",
    "imolarăți": "imola",
    "imolase": "imola",
    "imolasem": "imola",
    "imolaseră": "imola",
    "imolaserăm": "imola",
    "imolaserăți": "imola",
    "imolaseși": "imola",
    "imolași": "imola",
    "imolat": "imola",
    "imolați": "imola",
    "imolatu": "imola",
    "imolau": "imola",
    "imolează": "imola",
    "imolez": "imola",
    "imoleze": "imola",
    "imolezi": "imola",
    "neimolând": "imola",
    "neimolându": "imola",
    "nemaiimolând": "imola",
    "nemaiimolându": "imola",
    "imolată": "imolat",
    "imolate": "imolat",
    "imolați": "imolat",
    "imorala": "imoral",
    "imorală": "imoral",
    "imorale": "imoral",
    "imoralei": "imoral",
    "imoralele": "imoral",
    "imoralelor": "imoral",
    "imorali": "imoral",
    "imoralii": "imoral",
    "imoralilor": "imoral",
    "imoralul": "imoral",
    "imoralului": "imoral",
    "imoralitatea": "imoralitate",
    "imoralități": "imoralitate",
    "imoralității": "imoralitate",
    "imoralitățile": "imoralitate",
    "imoralităților": "imoralitate",
    "imortaliză": "imortaliza",
    "imortalizai": "imortaliza",
    "imortalizam": "imortaliza",
    "imortalizăm": "imortaliza",
    "imortalizând": "imortaliza",
    "imortalizându": "imortaliza",
    "imortalizară": "imortaliza",
    "imortalizarăm": "imortaliza",
    "imortalizarăți": "imortaliza",
    "imortalizase": "imortaliza",
    "imortalizasem": "imortaliza",
    "imortalizaseră": "imortaliza",
    "imortalizaserăm": "imortaliza",
    "imortalizaserăți": "imortaliza",
    "imortalizaseși": "imortaliza",
    "imortalizași": "imortaliza",
    "imortalizat": "imortaliza",
    "imortalizați": "imortaliza",
    "imortalizatu": "imortaliza",
    "imortalizau": "imortaliza",
    "imortalizează": "imortaliza",
    "imortalizez": "imortaliza",
    "imortalizeze": "imortaliza",
    "imortalizezi": "imortaliza",
    "neimortalizând": "imortaliza",
    "neimortalizându": "imortaliza",
    "nemaiimortalizând": "imortaliza",
    "nemaiimortalizându": "imortaliza",
    "imortalizată": "imortalizat",
    "imortalizate": "imortalizat",
    "imortalizați": "imortalizat",
    "împac": "împăca",
    "împacă": "împăca",
    "împăcă": "împăca",
    "împăcai": "împăca",
    "împăcam": "împăca",
    "împăcăm": "împăca",
    "împăcând": "împăca",
    "împăcându": "împăca",
    "împăcară": "împăca",
    "împăcarăm": "împăca",
    "împăcarăți": "împăca",
    "împăcase": "împăca",
    "împăcasem": "împăca",
    "împăcaseră": "împăca",
    "împăcaserăm": "împăca",
    "împăcaserăți": "împăca",
    "împăcaseși": "împăca",
    "împăcași": "împăca",
    "împăcat": "împăca",
    "împăcați": "împăca",
    "împăcatu": "împăca",
    "împăcau": "împăca",
    "împace": "împăca",
    "împaci": "împăca",
    "neîmpăcând": "împăca",
    "neîmpăcându": "împăca",
    "nemaiîmpăcând": "împăca",
    "nemaiîmpăcându": "împăca",
    "împăcarea": "împăcare",
    "împăcări": "împăcare",
    "împăcării": "împăcare",
    "împăcările": "împăcare",
    "împăcărilor": "împăcare",
    "împăcată": "împăcat",
    "împăcate": "împăcat",
    "împăcați": "împăcat",
    "împachetă": "împacheta",
    "împachetai": "împacheta",
    "împachetam": "împacheta",
    "împachetăm": "împacheta",
    "împachetând": "împacheta",
    "împachetându": "împacheta",
    "împachetară": "împacheta",
    "împachetarăm": "împacheta",
    "împachetarăți": "împacheta",
    "împachetase": "împacheta",
    "împachetasem": "împacheta",
    "împachetaseră": "împacheta",
    "împachetaserăm": "împacheta",
    "împachetaserăți": "împacheta",
    "împachetaseși": "împacheta",
    "împachetași": "împacheta",
    "împachetat": "împacheta",
    "împachetați": "împacheta",
    "împachetatu": "împacheta",
    "împachetau": "împacheta",
    "împachetează": "împacheta",
    "împachetez": "împacheta",
    "împacheteze": "împacheta",
    "împachetezi": "împacheta",
    "neîmpachetând": "împacheta",
    "neîmpachetându": "împacheta",
    "nemaiîmpachetând": "împacheta",
    "nemaiîmpachetându": "împacheta",
    "împachetarea": "împachetare",
    "împachetări": "împachetare",
    "împachetării": "împachetare",
    "împachetările": "împachetare",
    "împachetărilor": "împachetare",
    "împachetată": "împachetat",
    "împachetate": "împachetat",
    "împachetați": "împachetat",
    "impacientă": "impacienta",
    "impacientai": "impacienta",
    "impacientam": "impacienta",
    "impacientăm": "impacienta",
    "impacientând": "impacienta",
    "impacientându": "impacienta",
    "impacientară": "impacienta",
    "impacientarăm": "impacienta",
    "impacientarăți": "impacienta",
    "impacientase": "impacienta",
    "impacientasem": "impacienta",
    "impacientaseră": "impacienta",
    "impacientaserăm": "impacienta",
    "impacientaserăți": "impacienta",
    "impacientaseși": "impacienta",
    "impacientași": "impacienta",
    "impacientat": "impacienta",
    "impacientați": "impacienta",
    "impacientatu": "impacienta",
    "impacientau": "impacienta",
    "impacientează": "impacienta",
    "impacientez": "impacienta",
    "impacienteze": "impacienta",
    "impacientezi": "impacienta",
    "neimpacientând": "impacienta",
    "neimpacientându": "impacienta",
    "nemaiimpacientând": "impacienta",
    "nemaiimpacientându": "impacienta",
    "impacientată": "impacientat",
    "impacientate": "impacientat",
    "impacientați": "impacientat",
    "împăciuia": "împăciui",
    "împăciuiai": "împăciui",
    "împăciuiam": "împăciui",
    "împăciuiască": "împăciui",
    "împăciuiați": "împăciui",
    "împăciuiau": "împăciui",
    "împăciuiesc": "împăciui",
    "împăciuiește": "împăciui",
    "împăciuiești": "împăciui",
    "împăciuii": "împăciui",
    "împăciuim": "împăciui",
    "împăciuind": "împăciui",
    "împăciuindu": "împăciui",
    "împăciuiră": "împăciui",
    "împăciuirăm": "împăciui",
    "împăciuirăți": "împăciui",
    "împăciuise": "împăciui",
    "împăciuisem": "împăciui",
    "împăciuiseră": "împăciui",
    "împăciuiserăm": "împăciui",
    "împăciuiserăți": "împăciui",
    "împăciuiseși": "împăciui",
    "împăciuiși": "împăciui",
    "împăciuit": "împăciui",
    "împăciuiți": "împăciui",
    "împăciuitu": "împăciui",
    "neîmpăciuind": "împăciui",
    "neîmpăciuindu": "împăciui",
    "nemaiîmpăciuind": "împăciui",
    "nemaiîmpăciuindu": "împăciui",
    "împăciuirea": "împăciuire",
    "împăciuiri": "împăciuire",
    "împăciuirii": "împăciuire",
    "împăciuirile": "împăciuire",
    "împăciuirilor": "împăciuire",
    "împăciuită": "împăciuit",
    "împăciuite": "împăciuit",
    "împăciuiți": "împăciuit",
    "împăciuitoare": "împăciuitor",
    "împăciuitoarea": "împăciuitor",
    "împăciuitoarei": "împăciuitor",
    "împăciuitoarele": "împăciuitor",
    "împăciuitoarelor": "împăciuitor",
    "împăciuitori": "împăciuitor",
    "împăciuitorii": "împăciuitor",
    "împăciuitorilor": "împăciuitor",
    "împăciuitorul": "împăciuitor",
    "împăciuitorului": "împăciuitor",
    "impactul": "impact",
    "impactule": "impact",
    "impactului": "impact",
    "impacturi": "impact",
    "impacturile": "impact",
    "impacturilor": "impact",
    "împădurea": "împăduri",
    "împădureai": "împăduri",
    "împăduream": "împăduri",
    "împădurească": "împăduri",
    "împădureați": "împăduri",
    "împădureau": "împăduri",
    "împăduresc": "împăduri",
    "împădurește": "împăduri",
    "împădurești": "împăduri",
    "împădurii": "împăduri",
    "împădurim": "împăduri",
    "împădurind": "împăduri",
    "împădurindu": "împăduri",
    "împăduriră": "împăduri",
    "împădurirăm": "împăduri",
    "împădurirăți": "împăduri",
    "împădurise": "împăduri",
    "împădurisem": "împăduri",
    "împăduriseră": "împăduri",
    "împăduriserăm": "împăduri",
    "împăduriserăți": "împăduri",
    "împăduriseși": "împăduri",
    "împăduriși": "împăduri",
    "împădurit": "împăduri",
    "împăduriți": "împăduri",
    "împăduritu": "împăduri",
    "neîmpădurind": "împăduri",
    "neîmpădurindu": "împăduri",
    "nemaiîmpădurind": "împăduri",
    "nemaiîmpădurindu": "împăduri",
    "împădurirea": "împădurire",
    "împăduriri": "împădurire",
    "împăduririi": "împădurire",
    "împăduririle": "împădurire",
    "împăduririlor": "împădurire",
    "împădurită": "împădurit",
    "împădurite": "împădurit",
    "împăduriți": "împădurit",
    "împăiă": "împăia",
    "împăiai": "împăia",
    "împăiam": "împăia",
    "împăiăm": "împăia",
    "împăiară": "împăia",
    "împăiarăm": "împăia",
    "împăiarăți": "împăia",
    "împăiase": "împăia",
    "împăiasem": "împăia",
    "împăiaseră": "împăia",
    "împăiaserăm": "împăia",
    "împăiaserăți": "împăia",
    "împăiaseși": "împăia",
    "împăiași": "împăia",
    "împăiat": "împăia",
    "împăiați": "împăia",
    "împăiatu": "împăia",
    "împăiau": "împăia",
    "împăiază": "împăia",
    "împăiez": "împăia",
    "împăieze": "împăia",
    "împăiezi": "împăia",
    "împăind": "împăia",
    "împăindu": "împăia",
    "neîmpăiând": "împăia",
    "neîmpăiându": "împăia",
    "nemaiîmpăiând": "împăia",
    "nemaiîmpăiându": "împăia",
    "împăiata": "împăiat",
    "împăiată": "împăiat",
    "împăiate": "împăiat",
    "împăiatei": "împăiat",
    "împăiatele": "împăiat",
    "împăiatelor": "împăiat",
    "împăiați": "împăiat",
    "împăiații": "împăiat",
    "împăiaților": "împăiat",
    "împăiatul": "împăiat",
    "împăiatului": "împăiat",
    "împăienjenea": "împăienjeni",
    "împăienjeneai": "împăienjeni",
    "împăienjeneam": "împăienjeni",
    "împăienjenească": "împăienjeni",
    "împăienjeneați": "împăienjeni",
    "împăienjeneau": "împăienjeni",
    "împăienjenesc": "împăienjeni",
    "împăienjenește": "împăienjeni",
    "împăienjenești": "împăienjeni",
    "împăienjenii": "împăienjeni",
    "împăienjenim": "împăienjeni",
    "împăienjenind": "împăienjeni",
    "împăienjenindu": "împăienjeni",
    "împăienjeniră": "împăienjeni",
    "împăienjenirăm": "împăienjeni",
    "împăienjenirăți": "împăienjeni",
    "împăienjenise": "împăienjeni",
    "împăienjenisem": "împăienjeni",
    "împăienjeniseră": "împăienjeni",
    "împăienjeniserăm": "împăienjeni",
    "împăienjeniserăți": "împăienjeni",
    "împăienjeniseși": "împăienjeni",
    "împăienjeniși": "împăienjeni",
    "împăienjenit": "împăienjeni",
    "împăienjeniți": "împăienjeni",
    "împăienjenitu": "împăienjeni",
    "neîmpăienjenind": "împăienjeni",
    "neîmpăienjenindu": "împăienjeni",
    "nemaiîmpăienjenind": "împăienjeni",
    "nemaiîmpăienjenindu": "împăienjeni",
    "împăienjenită": "împăienjenit",
    "împăienjenite": "împăienjenit",
    "împăienjeniți": "împăienjenit",
    "împământenea": "împământeni",
    "împământeneai": "împământeni",
    "împământeneam": "împământeni",
    "împământenească": "împământeni",
    "împământeneați": "împământeni",
    "împământeneau": "împământeni",
    "împământenesc": "împământeni",
    "împământenește": "împământeni",
    "împământenești": "împământeni",
    "împământenii": "împământeni",
    "împământenim": "împământeni",
    "împământenind": "împământeni",
    "împământenindu": "împământeni",
    "împământeniră": "împământeni",
    "împământenirăm": "împământeni",
    "împământenirăți": "împământeni",
    "împământenise": "împământeni",
    "împământenisem": "împământeni",
    "împământeniseră": "împământeni",
    "împământeniserăm": "împământeni",
    "împământeniserăți": "împământeni",
    "împământeniseși": "împământeni",
    "împământeniși": "împământeni",
    "împământenit": "împământeni",
    "împământeniți": "împământeni",
    "împământenitu": "împământeni",
    "neîmpământenind": "împământeni",
    "neîmpământenindu": "împământeni",
    "nemaiîmpământenind": "împământeni",
    "nemaiîmpământenindu": "împământeni",
    "împământenită": "împământenit",
    "împământenite": "împământenit",
    "împământeniți": "împământenit",
    "împănă": "împăna",
    "împănai": "împăna",
    "împănam": "împăna",
    "împănăm": "împăna",
    "împănând": "împăna",
    "împănându": "împăna",
    "împănară": "împăna",
    "împănarăm": "împăna",
    "împănarăți": "împăna",
    "împănase": "împăna",
    "împănasem": "împăna",
    "împănaseră": "împăna",
    "împănaserăm": "împăna",
    "împănaserăți": "împăna",
    "împănaseși": "împăna",
    "împănași": "împăna",
    "împănat": "împăna",
    "împănați": "împăna",
    "împănatu": "împăna",
    "împănau": "împăna",
    "împănează": "împăna",
    "împănez": "împăna",
    "împăneze": "împăna",
    "împănezi": "împăna",
    "neîmpănând": "împăna",
    "neîmpănându": "împăna",
    "nemaiîmpănând": "împăna",
    "nemaiîmpănându": "împăna",
    "împănată": "împănat",
    "împănate": "împănat",
    "împănați": "împănat",
    "împânzea": "împânzi",
    "împânzeai": "împânzi",
    "împânzeam": "împânzi",
    "împânzească": "împânzi",
    "împânzeați": "împânzi",
    "împânzeau": "împânzi",
    "împânzesc": "împânzi",
    "împânzește": "împânzi",
    "împânzești": "împânzi",
    "împânzii": "împânzi",
    "împânzim": "împânzi",
    "împânzind": "împânzi",
    "împânzindu": "împânzi",
    "împânziră": "împânzi",
    "împânzirăm": "împânzi",
    "împânzirăți": "împânzi",
    "împânzise": "împânzi",
    "împânzisem": "împânzi",
    "împânziseră": "împânzi",
    "împânziserăm": "împânzi",
    "împânziserăți": "împânzi",
    "împânziseși": "împânzi",
    "împânziși": "împânzi",
    "împânzit": "împânzi",
    "împânziți": "împânzi",
    "împânzitu": "împânzi",
    "neîmpânzind": "împânzi",
    "neîmpânzindu": "împânzi",
    "nemaiîmpânzind": "împânzi",
    "nemaiîmpânzindu": "împânzi",
    "împânzită": "împânzit",
    "împânzite": "împânzit",
    "împânziți": "împânzit",
    "impara": "impar",
    "impară": "impar",
    "impare": "impar",
    "imparei": "impar",
    "imparele": "impar",
    "imparelor": "impar",
    "impari": "impar",
    "imparii": "impar",
    "imparilor": "impar",
    "imparul": "impar",
    "imparului": "impar",
    "împărate": "împărat",
    "împărați": "împărat",
    "împărații": "împărat",
    "împăraților": "împărat",
    "împăratul": "împărat",
    "împăratului": "împărat",
    "împărăteasa": "împărăteasă",
    "împărătese": "împărăteasă",
    "împărătesei": "împărăteasă",
    "împărătesele": "împărăteasă",
    "împărăteselor": "împărăteasă",
    "împărăteasca": "împărătesc",
    "împărătească": "împărătesc",
    "împărăteasco": "împărătesc",
    "împărătescul": "împărătesc",
    "împărătescule": "împărătesc",
    "împărătescului": "împărătesc",
    "împărătești": "împărătesc",
    "împărăteștii": "împărătesc",
    "împărăteștile": "împărătesc",
    "împărăteștilor": "împărătesc",
    "împărățea": "împărăți",
    "împărățeai": "împărăți",
    "împărățeam": "împărăți",
    "împărățească": "împărăți",
    "împărățeați": "împărăți",
    "împărățeau": "împărăți",
    "împărățesc": "împărăți",
    "împărățește": "împărăți",
    "împărățești": "împărăți",
    "împărății": "împărăți",
    "împărățim": "împărăți",
    "împărățind": "împărăți",
    "împărățindu": "împărăți",
    "împărățiră": "împărăți",
    "împărățirăm": "împărăți",
    "împărățirăți": "împărăți",
    "împărățise": "împărăți",
    "împărățisem": "împărăți",
    "împărățiseră": "împărăți",
    "împărățiserăm": "împărăți",
    "împărățiserăți": "împărăți",
    "împărățiseși": "împărăți",
    "împărățiși": "împărăți",
    "împărățit": "împărăți",
    "împărățiți": "împărăți",
    "împărățitu": "împărăți",
    "neîmpărățind": "împărăți",
    "neîmpărățindu": "împărăți",
    "nemaiîmpărățind": "împărăți",
    "nemaiîmpărățindu": "împărăți",
    "împărăția": "împărăție",
    "împărăției": "împărăție",
    "împărății": "împărăție",
    "împărățiile": "împărăție",
    "împărățiilor": "împărăție",
    "împărățită": "împărățit",
    "împărățite": "împărățit",
    "împărățiți": "împărățit",
    "impardonabila": "impardonabil",
    "impardonabilă": "impardonabil",
    "impardonabile": "impardonabil",
    "impardonabilei": "impardonabil",
    "impardonabilele": "impardonabil",
    "impardonabilelor": "impardonabil",
    "impardonabili": "impardonabil",
    "impardonabilii": "impardonabil",
    "impardonabililor": "impardonabil",
    "impardonabilo": "impardonabil",
    "impardonabilul": "impardonabil",
    "impardonabilule": "impardonabil",
    "impardonabilului": "impardonabil",
    "împăroșă": "împăroșa",
    "împăroșai": "împăroșa",
    "împăroșam": "împăroșa",
    "împăroșăm": "împăroșa",
    "împăroșând": "împăroșa",
    "împăroșându": "împăroșa",
    "împăroșară": "împăroșa",
    "împăroșarăm": "împăroșa",
    "împăroșarăți": "împăroșa",
    "împăroșase": "împăroșa",
    "împăroșasem": "împăroșa",
    "împăroșaseră": "împăroșa",
    "împăroșaserăm": "împăroșa",
    "împăroșaserăți": "împăroșa",
    "împăroșaseși": "împăroșa",
    "împăroșași": "împăroșa",
    "împăroșat": "împăroșa",
    "împăroșați": "împăroșa",
    "împăroșatu": "împăroșa",
    "împăroșau": "împăroșa",
    "împăroșează": "împăroșa",
    "împăroșez": "împăroșa",
    "împăroșeze": "împăroșa",
    "împăroșezi": "împăroșa",
    "neîmpăroșând": "împăroșa",
    "neîmpăroșându": "împăroșa",
    "nemaiîmpăroșând": "împăroșa",
    "nemaiîmpăroșându": "împăroșa",
    "împăroșată": "împăroșat",
    "împăroșate": "împăroșat",
    "împăroșați": "împăroșat",
    "împărtășania": "împărtășanie",
    "împărtășaniei": "împărtășanie",
    "împărtășanii": "împărtășanie",
    "împărtășaniile": "împărtășanie",
    "împărtășaniilor": "împărtășanie",
    "împărtășanio": "împărtășanie",
    "împărtășea": "împărtăși",
    "împărtășeai": "împărtăși",
    "împărtășeam": "împărtăși",
    "împărtășească": "împărtăși",
    "împărtășeați": "împărtăși",
    "împărtășeau": "împărtăși",
    "împărtășesc": "împărtăși",
    "împărtășește": "împărtăși",
    "împărtășești": "împărtăși",
    "împărtășii": "împărtăși",
    "împărtășim": "împărtăși",
    "împărtășind": "împărtăși",
    "împărtășindu": "împărtăși",
    "împărtășiră": "împărtăși",
    "împărtășirăm": "împărtăși",
    "împărtășirăți": "împărtăși",
    "împărtășise": "împărtăși",
    "împărtășisem": "împărtăși",
    "împărtășiseră": "împărtăși",
    "împărtășiserăm": "împărtăși",
    "împărtășiserăți": "împărtăși",
    "împărtășiseși": "împărtăși",
    "împărtășiși": "împărtăși",
    "împărtășit": "împărtăși",
    "împărtășiți": "împărtăși",
    "împărtășitu": "împărtăși",
    "neîmpărtășind": "împărtăși",
    "neîmpărtășindu": "împărtăși",
    "nemaiîmpărtășind": "împărtăși",
    "nemaiîmpărtășindu": "împărtăși",
    "împărtășirea": "împărtășire",
    "împărtășireo": "împărtășire",
    "împărtășiri": "împărtășire",
    "împărtășirii": "împărtășire",
    "împărtășirile": "împărtășire",
    "împărtășirilor": "împărtășire",
    "împărtășită": "împărtășit",
    "împărtășite": "împărtășit",
    "împărtășiți": "împărtășit",
    "împărțeala": "împărțeală",
    "împărțeli": "împărțeală",
    "împărțelii": "împărțeală",
    "împărțelile": "împărțeală",
    "împărțelilor": "împărțeală",
    "împart": "împărți",
    "împartă": "împărți",
    "împarte": "împărți",
    "împărțea": "împărți",
    "împărțeai": "împărți",
    "împărțeam": "împărți",
    "împărțeați": "împărți",
    "împărțeau": "împărți",
    "împarți": "împărți",
    "împărții": "împărți",
    "împărțim": "împărți",
    "împărțind": "împărți",
    "împărțindu": "împărți",
    "împărțiră": "împărți",
    "împărțirăm": "împărți",
    "împărțirăți": "împărți",
    "împărțise": "împărți",
    "împărțisem": "împărți",
    "împărțiseră": "împărți",
    "împărțiserăm": "împărți",
    "împărțiserăți": "împărți",
    "împărțiseși": "împărți",
    "împărțiși": "împărți",
    "împărțit": "împărți",
    "împărțiți": "împărți",
    "împărțitu": "împărți",
    "neîmpărțind": "împărți",
    "neîmpărțindu": "împărți",
    "nemaiîmpărțind": "împărți",
    "nemaiîmpărțindu": "împărți",
    "imparțiala": "imparțial",
    "imparțială": "imparțial",
    "imparțiale": "imparțial",
    "imparțialei": "imparțial",
    "imparțialele": "imparțial",
    "imparțialelor": "imparțial",
    "imparțiali": "imparțial",
    "imparțialii": "imparțial",
    "imparțialilor": "imparțial",
    "imparțialul": "imparțial",
    "imparțialului": "imparțial",
    "imparțialitatea": "imparțialitate",
    "imparțialități": "imparțialitate",
    "imparțialității": "imparțialitate",
    "împărțirea": "împărțire",
    "împărțiri": "împărțire",
    "împărțirii": "împărțire",
    "împărțirile": "împărțire",
    "împărțirilor": "împărțire",
    "împărțită": "împărțit",
    "împărțite": "împărțit",
    "împărțiți": "împărțit",
    "împărțitori": "împărțitor",
    "împărțitorii": "împărțitor",
    "împărțitorilor": "împărțitor",
    "împărțitorul": "împărțitor",
    "împărțitorului": "împărțitor",
    "impasul": "impas",
    "impasului": "impas",
    "impasuri": "impas",
    "impasurile": "impas",
    "impasurilor": "impas",
    "impasibila": "impasibil",
    "impasibilă": "impasibil",
    "impasibile": "impasibil",
    "impasibilei": "impasibil",
    "impasibilele": "impasibil",
    "impasibilelor": "impasibil",
    "impasibili": "impasibil",
    "impasibilii": "impasibil",
    "impasibililor": "impasibil",
    "impasibilul": "impasibil",
    "impasibilului": "impasibil",
    "împătimea": "împătimi",
    "împătimeai": "împătimi",
    "împătimeam": "împătimi",
    "împătimească": "împătimi",
    "împătimeați": "împătimi",
    "împătimeau": "împătimi",
    "împătimesc": "împătimi",
    "împătimește": "împătimi",
    "împătimești": "împătimi",
    "împătimii": "împătimi",
    "împătimim": "împătimi",
    "împătimind": "împătimi",
    "împătimindu": "împătimi",
    "împătimiră": "împătimi",
    "împătimirăm": "împătimi",
    "împătimirăți": "împătimi",
    "împătimise": "împătimi",
    "împătimisem": "împătimi",
    "împătimiseră": "împătimi",
    "împătimiserăm": "împătimi",
    "împătimiserăți": "împătimi",
    "împătimiseși": "împătimi",
    "împătimiși": "împătimi",
    "împătimit": "împătimi",
    "împătimiți": "împătimi",
    "împătimitu": "împătimi",
    "neîmpătimind": "împătimi",
    "neîmpătimindu": "împătimi",
    "nemaiîmpătimind": "împătimi",
    "nemaiîmpătimindu": "împătimi",
    "împătimită": "împătimit",
    "împătimite": "împătimit",
    "împătimiți": "împătimit",
    "împătrea": "împătri",
    "împătreai": "împătri",
    "împătream": "împătri",
    "împătrească": "împătri",
    "împătreați": "împătri",
    "împătreau": "împătri",
    "împătresc": "împătri",
    "împătrește": "împătri",
    "împătrești": "împătri",
    "împătrii": "împătri",
    "împătrim": "împătri",
    "împătrind": "împătri",
    "împătrindu": "împătri",
    "împătriră": "împătri",
    "împătrirăm": "împătri",
    "împătrirăți": "împătri",
    "împătrise": "împătri",
    "împătrisem": "împătri",
    "împătriseră": "împătri",
    "împătriserăm": "împătri",
    "împătriserăți": "împătri",
    "împătriseși": "împătri",
    "împătriși": "împătri",
    "împătrit": "împătri",
    "împătriți": "împătri",
    "împătritu": "împătri",
    "neîmpătrind": "împătri",
    "neîmpătrindu": "împătri",
    "nemaiîmpătrind": "împătri",
    "nemaiîmpătrindu": "împătri",
    "împătrita": "împătrit",
    "împătrită": "împătrit",
    "împătrite": "împătrit",
    "împătritei": "împătrit",
    "împătritele": "împătrit",
    "împătritelor": "împătrit",
    "împătriți": "împătrit",
    "împătriții": "împătrit",
    "împătriților": "împătrit",
    "împătritul": "împătrit",
    "împătritului": "împătrit",
    "împăturea": "împături",
    "împătureai": "împături",
    "împătuream": "împături",
    "împăturească": "împături",
    "împătureați": "împături",
    "împătureau": "împături",
    "împăturesc": "împături",
    "împăturește": "împături",
    "împăturești": "împături",
    "împăturii": "împături",
    "împăturim": "împături",
    "împăturind": "împături",
    "împăturindu": "împături",
    "împăturiră": "împături",
    "împăturirăm": "împături",
    "împăturirăți": "împături",
    "împăturise": "împături",
    "împăturisem": "împături",
    "împăturiseră": "împături",
    "împăturiserăm": "împături",
    "împăturiserăți": "împături",
    "împăturiseși": "împături",
    "împăturiși": "împături",
    "împăturit": "împături",
    "împăturiți": "împături",
    "împăturitu": "împături",
    "neîmpăturind": "împături",
    "neîmpăturindu": "împături",
    "nemaiîmpăturind": "împături",
    "nemaiîmpăturindu": "împături",
    "împăturită": "împăturit",
    "împăturite": "împăturit",
    "împăturiți": "împăturit",
    "împăună": "împăuna",
    "împăunai": "împăuna",
    "împăunam": "împăuna",
    "împăunăm": "împăuna",
    "împăunând": "împăuna",
    "împăunându": "împăuna",
    "împăunară": "împăuna",
    "împăunarăm": "împăuna",
    "împăunarăți": "împăuna",
    "împăunase": "împăuna",
    "împăunasem": "împăuna",
    "împăunaseră": "împăuna",
    "împăunaserăm": "împăuna",
    "împăunaserăți": "împăuna",
    "împăunaseși": "împăuna",
    "împăunași": "împăuna",
    "împăunat": "împăuna",
    "împăunați": "împăuna",
    "împăunatu": "împăuna",
    "împăunau": "împăuna",
    "împăunează": "împăuna",
    "împăunez": "împăuna",
    "împăuneze": "împăuna",
    "împăunezi": "împăuna",
    "neîmpăunând": "împăuna",
    "neîmpăunându": "împăuna",
    "nemaiîmpăunând": "împăuna",
    "nemaiîmpăunându": "împăuna",
    "împăunată": "împăunat",
    "împăunate": "împăunat",
    "împăunați": "împăunat",
    "impecabila": "impecabil",
    "impecabilă": "impecabil",
    "impecabile": "impecabil",
    "impecabilei": "impecabil",
    "impecabilele": "impecabil",
    "impecabilelor": "impecabil",
    "impecabili": "impecabil",
    "impecabilii": "impecabil",
    "impecabililor": "impecabil",
    "impecabilul": "impecabil",
    "impecabilului": "impecabil",
    "impedanța": "impedanță",
    "impedanțe": "impedanță",
    "impedanței": "impedanță",
    "Z.": "impedanță",
    "impedimente": "impediment",
    "impedimentele": "impediment",
    "impedimentelor": "impediment",
    "impedimentul": "impediment",
    "impedimentului": "impediment",
    "împeliță": "împelița",
    "împelițai": "împelița",
    "împelițam": "împelița",
    "împelițăm": "împelița",
    "împelițând": "împelița",
    "împelițându": "împelița",
    "împelițară": "împelița",
    "împelițarăm": "împelița",
    "împelițarăți": "împelița",
    "împelițase": "împelița",
    "împelițasem": "împelița",
    "împelițaseră": "împelița",
    "împelițaserăm": "împelița",
    "împelițaserăți": "împelița",
    "împelițaseși": "împelița",
    "împelițași": "împelița",
    "împelițat": "împelița",
    "împelițați": "împelița",
    "împelițatu": "împelița",
    "împelițau": "împelița",
    "împelițează": "împelița",
    "împelițez": "împelița",
    "împelițeze": "împelița",
    "împelițezi": "împelița",
    "neîmpelițând": "împelița",
    "neîmpelițându": "împelița",
    "nemaiîmpelițând": "împelița",
    "nemaiîmpelițându": "împelița",
    "împelițată": "împelițat",
    "împelițate": "împelițat",
    "împelițați": "împelițat",
    "impenetrabila": "impenetrabil",
    "impenetrabilă": "impenetrabil",
    "impenetrabile": "impenetrabil",
    "impenetrabilei": "impenetrabil",
    "impenetrabilele": "impenetrabil",
    "impenetrabilelor": "impenetrabil",
    "impenetrabili": "impenetrabil",
    "impenetrabilii": "impenetrabil",
    "impenetrabililor": "impenetrabil",
    "impenetrabilul": "impenetrabil",
    "impenetrabilului": "impenetrabil",
    "imper.": "imperativ",
    "imperativa": "imperativ",
    "imperativă": "imperativ",
    "imperative": "imperativ",
    "imperativei": "imperativ",
    "imperativele": "imperativ",
    "imperativelor": "imperativ",
    "imperativi": "imperativ",
    "imperativii": "imperativ",
    "imperativilor": "imperativ",
    "imperativul": "imperativ",
    "imperativului": "imperativ",
    "imperceptibila": "imperceptibil",
    "imperceptibilă": "imperceptibil",
    "imperceptibile": "imperceptibil",
    "imperceptibilei": "imperceptibil",
    "imperceptibilele": "imperceptibil",
    "imperceptibilelor": "imperceptibil",
    "imperceptibili": "imperceptibil",
    "imperceptibilii": "imperceptibil",
    "imperceptibililor": "imperceptibil",
    "imperceptibilul": "imperceptibil",
    "imperceptibilului": "imperceptibil",
    "împereche": "împerechea",
    "împerecheai": "împerechea",
    "împerecheam": "împerechea",
    "împerecheară": "împerechea",
    "împerechearăm": "împerechea",
    "împerechearăți": "împerechea",
    "împerechease": "împerechea",
    "împerecheasem": "împerechea",
    "împerecheaseră": "împerechea",
    "împerecheaserăm": "împerechea",
    "împerecheaserăți": "împerechea",
    "împerecheaseși": "împerechea",
    "împerecheași": "împerechea",
    "împerecheat": "împerechea",
    "împerecheați": "împerechea",
    "împerecheatu": "împerechea",
    "împerecheau": "împerechea",
    "împerechează": "împerechea",
    "împerechem": "împerechea",
    "împerechez": "împerechea",
    "împerecheze": "împerechea",
    "împerechezi": "împerechea",
    "împerechind": "împerechea",
    "împerechindu": "împerechea",
    "împerecheată": "împerecheat",
    "împerecheate": "împerecheat",
    "împerecheați": "împerecheat",
    "împerecherea": "împerechere",
    "împerechereo": "împerechere",
    "împerecheri": "împerechere",
    "împerecherii": "împerechere",
    "împerecherile": "împerechere",
    "împerecherilor": "împerechere",
    "imperf.": "imperfect",
    "imperfecta": "imperfect",
    "imperfectă": "imperfect",
    "imperfecte": "imperfect",
    "imperfectei": "imperfect",
    "imperfectele": "imperfect",
    "imperfectelor": "imperfect",
    "imperfecți": "imperfect",
    "imperfecții": "imperfect",
    "imperfecților": "imperfect",
    "imperfectul": "imperfect",
    "imperfectului": "imperfect",
    "imperfecțiunea": "imperfecțiune",
    "imperfecțiuni": "imperfecțiune",
    "imperfecțiunii": "imperfecțiune",
    "imperfecțiunile": "imperfecțiune",
    "imperfecțiunilor": "imperfecțiune",
    "imperiala": "imperial",
    "imperială": "imperial",
    "imperiale": "imperial",
    "imperialei": "imperial",
    "imperialele": "imperial",
    "imperialelor": "imperial",
    "imperiali": "imperial",
    "imperialii": "imperial",
    "imperialilor": "imperial",
    "imperialul": "imperial",
    "imperialului": "imperial",
    "imperialisme": "imperialism",
    "imperialismele": "imperialism",
    "imperialismelor": "imperialism",
    "imperialismul": "imperialism",
    "imperialismule": "imperialism",
    "imperialismului": "imperialism",
    "imperialista": "imperialist",
    "imperialistă": "imperialist",
    "imperialiste": "imperialist",
    "imperialistei": "imperialist",
    "imperialistele": "imperialist",
    "imperialistelor": "imperialist",
    "imperialiști": "imperialist",
    "imperialiștii": "imperialist",
    "imperialiștilor": "imperialist",
    "imperialistul": "imperialist",
    "imperialistului": "imperialist",
    "imperioasa": "imperios",
    "imperioasă": "imperios",
    "imperioase": "imperios",
    "imperioasei": "imperios",
    "imperioasele": "imperios",
    "imperioaselor": "imperios",
    "imperioși": "imperios",
    "imperioșii": "imperios",
    "imperioșilor": "imperios",
    "imperiosul": "imperios",
    "imperiosului": "imperios",
    "imperii": "imperiu",
    "imperiii": "imperiu",
    "imperiilor": "imperiu",
    "imperiul": "imperiu",
    "imperiului": "imperiu",
    "impermeabila": "impermeabil",
    "impermeabilă": "impermeabil",
    "impermeabile": "impermeabil",
    "impermeabilei": "impermeabil",
    "impermeabilele": "impermeabil",
    "impermeabilelor": "impermeabil",
    "impermeabili": "impermeabil",
    "impermeabilii": "impermeabil",
    "impermeabililor": "impermeabil",
    "impermeabilul": "impermeabil",
    "impermeabilului": "impermeabil",
    "impermeabiliză": "impermeabiliza",
    "impermeabilizai": "impermeabiliza",
    "impermeabilizam": "impermeabiliza",
    "impermeabilizăm": "impermeabiliza",
    "impermeabilizând": "impermeabiliza",
    "impermeabilizându": "impermeabiliza",
    "impermeabilizară": "impermeabiliza",
    "impermeabilizarăm": "impermeabiliza",
    "impermeabilizarăți": "impermeabiliza",
    "impermeabilizase": "impermeabiliza",
    "impermeabilizasem": "impermeabiliza",
    "impermeabilizaseră": "impermeabiliza",
    "impermeabilizaserăm": "impermeabiliza",
    "impermeabilizaserăți": "impermeabiliza",
    "impermeabilizaseși": "impermeabiliza",
    "impermeabilizași": "impermeabiliza",
    "impermeabilizat": "impermeabiliza",
    "impermeabilizați": "impermeabiliza",
    "impermeabilizatu": "impermeabiliza",
    "impermeabilizau": "impermeabiliza",
    "impermeabilizează": "impermeabiliza",
    "impermeabilizez": "impermeabiliza",
    "impermeabilizeze": "impermeabiliza",
    "impermeabilizezi": "impermeabiliza",
    "neimpermeabilizând": "impermeabiliza",
    "neimpermeabilizându": "impermeabiliza",
    "nemaiimpermeabilizând": "impermeabiliza",
    "nemaiimpermeabilizându": "impermeabiliza",
    "impermeabilizată": "impermeabilizat",
    "impermeabilizate": "impermeabilizat",
    "impermeabilizați": "impermeabilizat",
    "impers.": "impersonal",
    "impersonala": "impersonal",
    "impersonală": "impersonal",
    "impersonale": "impersonal",
    "impersonalei": "impersonal",
    "impersonalele": "impersonal",
    "impersonalelor": "impersonal",
    "impersonali": "impersonal",
    "impersonalii": "impersonal",
    "impersonalilor": "impersonal",
    "impersonalul": "impersonal",
    "impersonalului": "impersonal",
    "impertinenta": "impertinent",
    "impertinentă": "impertinent",
    "impertinente": "impertinent",
    "impertinentei": "impertinent",
    "impertinentele": "impertinent",
    "impertinentelor": "impertinent",
    "impertinenți": "impertinent",
    "impertinenții": "impertinent",
    "impertinenților": "impertinent",
    "impertinentul": "impertinent",
    "impertinentului": "impertinent",
    "impertinența": "impertinență",
    "impertinențe": "impertinență",
    "impertinenței": "impertinență",
    "impertinențele": "impertinență",
    "impertinențelor": "impertinență",
    "imperturbabila": "imperturbabil",
    "imperturbabilă": "imperturbabil",
    "imperturbabile": "imperturbabil",
    "imperturbabilei": "imperturbabil",
    "imperturbabilele": "imperturbabil",
    "imperturbabilelor": "imperturbabil",
    "imperturbabili": "imperturbabil",
    "imperturbabilii": "imperturbabil",
    "imperturbabililor": "imperturbabil",
    "imperturbabilul": "imperturbabil",
    "imperturbabilului": "imperturbabil",
    "impestă": "impesta",
    "impestai": "impesta",
    "impestam": "impesta",
    "impestăm": "impesta",
    "impestând": "impesta",
    "impestându": "impesta",
    "impestară": "impesta",
    "impestarăm": "impesta",
    "impestarăți": "impesta",
    "impestase": "impesta",
    "impestasem": "impesta",
    "impestaseră": "impesta",
    "impestaserăm": "impesta",
    "impestaserăți": "impesta",
    "impestaseși": "impesta",
    "impestași": "impesta",
    "impestat": "impesta",
    "impestați": "impesta",
    "impestatu": "impesta",
    "impestau": "impesta",
    "impestează": "impesta",
    "impestez": "impesta",
    "impesteze": "impesta",
    "impestezi": "impesta",
    "neimpestând": "impesta",
    "neimpestându": "impesta",
    "nemaiimpestând": "impesta",
    "nemaiimpestându": "impesta",
    "impestată": "impestat",
    "impestate": "impestat",
    "impestați": "impestat",
    "împestriță": "împestrița",
    "împestrițai": "împestrița",
    "împestrițam": "împestrița",
    "împestrițăm": "împestrița",
    "împestrițând": "împestrița",
    "împestrițându": "împestrița",
    "împestrițară": "împestrița",
    "împestrițarăm": "împestrița",
    "împestrițarăți": "împestrița",
    "împestrițase": "împestrița",
    "împestrițasem": "împestrița",
    "împestrițaseră": "împestrița",
    "împestrițaserăm": "împestrița",
    "împestrițaserăți": "împestrița",
    "împestrițaseși": "împestrița",
    "împestrițași": "împestrița",
    "împestrițat": "împestrița",
    "împestrițați": "împestrița",
    "împestrițatu": "împestrița",
    "împestrițau": "împestrița",
    "împestrițează": "împestrița",
    "împestrițez": "împestrița",
    "împestrițeze": "împestrița",
    "împestrițezi": "împestrița",
    "neîmpestrițând": "împestrița",
    "neîmpestrițându": "împestrița",
    "nemaiîmpestrițând": "împestrița",
    "nemaiîmpestrițându": "împestrița",
    "împestrițarea": "împestrițare",
    "împestrițareo": "împestrițare",
    "împestrițări": "împestrițare",
    "împestrițării": "împestrițare",
    "împestrițările": "împestrițare",
    "împestrițărilor": "împestrițare",
    "împestrițată": "împestrițat",
    "împestrițate": "împestrițat",
    "împestrițați": "împestrițat",
    "împețea": "împeți",
    "împețeai": "împeți",
    "împețeam": "împeți",
    "împețească": "împeți",
    "împețeați": "împeți",
    "împețeau": "împeți",
    "împețesc": "împeți",
    "împețește": "împeți",
    "împețești": "împeți",
    "împeții": "împeți",
    "împețim": "împeți",
    "împețind": "împeți",
    "împețindu": "împeți",
    "împețiră": "împeți",
    "împețirăm": "împeți",
    "împețirăți": "împeți",
    "împețise": "împeți",
    "împețisem": "împeți",
    "împețiseră": "împeți",
    "împețiserăm": "împeți",
    "împețiserăți": "împeți",
    "împețiseși": "împeți",
    "împețiși": "împeți",
    "împețit": "împeți",
    "împețiți": "împeți",
    "împețitu": "împeți",
    "neîmpețind": "împeți",
    "neîmpețindu": "împeți",
    "nemaiîmpețind": "împeți",
    "nemaiîmpețindu": "împeți",
    "împețită": "împețit",
    "împețite": "împețit",
    "împețiți": "împețit",
    "impetuoasa": "impetuos",
    "impetuoasă": "impetuos",
    "impetuoase": "impetuos",
    "impetuoasei": "impetuos",
    "impetuoasele": "impetuos",
    "impetuoaselor": "impetuos",
    "impetuoși": "impetuos",
    "impetuoșii": "impetuos",
    "impetuoșilor": "impetuos",
    "impetuosul": "impetuos",
    "impetuosului": "impetuos",
    "impetuozitatea": "impetuozitate",
    "impetuozități": "impetuozitate",
    "impetuozității": "impetuozitate",
    "împiciorogă": "împicioroga",
    "împiciorogai": "împicioroga",
    "împiciorogam": "împicioroga",
    "împiciorogăm": "împicioroga",
    "împiciorogând": "împicioroga",
    "împiciorogându": "împicioroga",
    "împiciorogară": "împicioroga",
    "împiciorogarăm": "împicioroga",
    "împiciorogarăți": "împicioroga",
    "împiciorogase": "împicioroga",
    "împiciorogasem": "împicioroga",
    "împiciorogaseră": "împicioroga",
    "împiciorogaserăm": "împicioroga",
    "împiciorogaserăți": "împicioroga",
    "împiciorogaseși": "împicioroga",
    "împiciorogași": "împicioroga",
    "împiciorogat": "împicioroga",
    "împiciorogați": "împicioroga",
    "împiciorogatu": "împicioroga",
    "împiciorogau": "împicioroga",
    "împicioroghează": "împicioroga",
    "împicioroghez": "împicioroga",
    "împiciorogheze": "împicioroga",
    "împicioroghezi": "împicioroga",
    "neîmpiciorogând": "împicioroga",
    "neîmpiciorogându": "împicioroga",
    "nemaiîmpiciorogând": "împicioroga",
    "nemaiîmpiciorogându": "împicioroga",
    "împiciorogată": "împiciorogat",
    "împiciorogate": "împiciorogat",
    "împiciorogați": "împiciorogat",
    "împiedic": "împiedica",
    "împiedică": "împiedica",
    "împiedicai": "împiedica",
    "împiedicam": "împiedica",
    "împiedicăm": "împiedica",
    "împiedicând": "împiedica",
    "împiedicându": "împiedica",
    "împiedicară": "împiedica",
    "împiedicarăm": "împiedica",
    "împiedicarăți": "împiedica",
    "împiedicase": "împiedica",
    "împiedicasem": "împiedica",
    "împiedicaseră": "împiedica",
    "împiedicaserăm": "împiedica",
    "împiedicaserăți": "împiedica",
    "împiedicaseși": "împiedica",
    "împiedicași": "împiedica",
    "împiedicat": "împiedica",
    "împiedicați": "împiedica",
    "împiedicatu": "împiedica",
    "împiedicau": "împiedica",
    "împiedice": "împiedica",
    "împiedici": "împiedica",
    "neîmpiedicând": "împiedica",
    "neîmpiedicându": "împiedica",
    "nemaiîmpiedicând": "împiedica",
    "nemaiîmpiedicându": "împiedica",
    "împiedicarea": "împiedicare",
    "împiedicareo": "împiedicare",
    "împiedicări": "împiedicare",
    "împiedicării": "împiedicare",
    "împiedicările": "împiedicare",
    "împiedicărilor": "împiedicare",
    "împiedicată": "împiedicat",
    "împiedicate": "împiedicat",
    "împiedicați": "împiedicat",
    "împieptoșă": "împieptoșa",
    "împieptoșai": "împieptoșa",
    "împieptoșam": "împieptoșa",
    "împieptoșăm": "împieptoșa",
    "împieptoșând": "împieptoșa",
    "împieptoșându": "împieptoșa",
    "împieptoșară": "împieptoșa",
    "împieptoșarăm": "împieptoșa",
    "împieptoșarăți": "împieptoșa",
    "împieptoșase": "împieptoșa",
    "împieptoșasem": "împieptoșa",
    "împieptoșaseră": "împieptoșa",
    "împieptoșaserăm": "împieptoșa",
    "împieptoșaserăți": "împieptoșa",
    "împieptoșaseși": "împieptoșa",
    "împieptoșași": "împieptoșa",
    "împieptoșat": "împieptoșa",
    "împieptoșați": "împieptoșa",
    "împieptoșatu": "împieptoșa",
    "împieptoșau": "împieptoșa",
    "împieptoșează": "împieptoșa",
    "împieptoșez": "împieptoșa",
    "împieptoșeze": "împieptoșa",
    "împieptoșezi": "împieptoșa",
    "neîmpieptoșând": "împieptoșa",
    "neîmpieptoșându": "împieptoșa",
    "nemaiîmpieptoșând": "împieptoșa",
    "nemaiîmpieptoșându": "împieptoșa",
    "împieptoșată": "împieptoșat",
    "împieptoșate": "împieptoșat",
    "împieptoșați": "împieptoșat",
    "impietă": "impieta",
    "impietai": "impieta",
    "impietam": "impieta",
    "impietăm": "impieta",
    "impietând": "impieta",
    "impietându": "impieta",
    "impietară": "impieta",
    "impietarăm": "impieta",
    "impietarăți": "impieta",
    "impietase": "impieta",
    "impietasem": "impieta",
    "impietaseră": "impieta",
    "impietaserăm": "impieta",
    "impietaserăți": "impieta",
    "impietaseși": "impieta",
    "impietași": "impieta",
    "impietat": "impieta",
    "impietați": "impieta",
    "impietatu": "impieta",
    "impietau": "impieta",
    "impietează": "impieta",
    "impietez": "impieta",
    "impieteze": "impieta",
    "impietezi": "impieta",
    "neimpietând": "impieta",
    "neimpietându": "impieta",
    "nemaiimpietând": "impieta",
    "nemaiimpietându": "impieta",
    "impietată": "impietat",
    "impietate": "impietat",
    "impietați": "impietat",
    "impietatea": "impietate",
    "impietăți": "impietate",
    "impietății": "impietate",
    "împietrea": "împietri",
    "împietreai": "împietri",
    "împietream": "împietri",
    "împietrească": "împietri",
    "împietreați": "împietri",
    "împietreau": "împietri",
    "împietresc": "împietri",
    "împietrește": "împietri",
    "împietrești": "împietri",
    "împietrii": "împietri",
    "împietrim": "împietri",
    "împietrind": "împietri",
    "împietrindu": "împietri",
    "împietriră": "împietri",
    "împietrirăm": "împietri",
    "împietrirăți": "împietri",
    "împietrise": "împietri",
    "împietrisem": "împietri",
    "împietriseră": "împietri",
    "împietriserăm": "împietri",
    "împietriserăți": "împietri",
    "împietriseși": "împietri",
    "împietriși": "împietri",
    "împietrit": "împietri",
    "împietriți": "împietri",
    "împietritu": "împietri",
    "neîmpietrind": "împietri",
    "neîmpietrindu": "împietri",
    "nemaiîmpietrind": "împietri",
    "nemaiîmpietrindu": "împietri",
    "împietrirea": "împietrire",
    "împietrireo": "împietrire",
    "împietriri": "împietrire",
    "împietririi": "împietrire",
    "împietririle": "împietrire",
    "împietririlor": "împietrire",
    "împietrita": "împietrit",
    "împietrită": "împietrit",
    "împietrite": "împietrit",
    "împietritei": "împietrit",
    "împietritele": "împietrit",
    "împietritelor": "împietrit",
    "împietriți": "împietrit",
    "împietriții": "împietrit",
    "împietriților": "împietrit",
    "împietritul": "împietrit",
    "împietritului": "împietrit",
    "împilă": "împila",
    "împilai": "împila",
    "împilam": "împila",
    "împilăm": "împila",
    "împilând": "împila",
    "împilându": "împila",
    "împilară": "împila",
    "împilarăm": "împila",
    "împilarăți": "împila",
    "împilase": "împila",
    "împilasem": "împila",
    "împilaseră": "împila",
    "împilaserăm": "împila",
    "împilaserăți": "împila",
    "împilaseși": "împila",
    "împilași": "împila",
    "împilat": "împila",
    "împilați": "împila",
    "împilatu": "împila",
    "împilau": "împila",
    "împilează": "împila",
    "împilez": "împila",
    "împileze": "împila",
    "împilezi": "împila",
    "neîmpilând": "împila",
    "neîmpilându": "împila",
    "nemaiîmpilând": "împila",
    "nemaiîmpilându": "împila",
    "împilată": "împilat",
    "împilate": "împilat",
    "împilați": "împilat",
    "împing": "împinge",
    "împingă": "împinge",
    "împingând": "împinge",
    "împingându": "împinge",
    "împingea": "împinge",
    "împingeai": "împinge",
    "împingeam": "împinge",
    "împingeați": "împinge",
    "împingeau": "împinge",
    "împingem": "împinge",
    "împingeți": "împinge",
    "împingi": "împinge",
    "împins": "împinge",
    "împinse": "împinge",
    "împinsei": "împinge",
    "împinseră": "împinge",
    "împinserăm": "împinge",
    "împinserăți": "împinge",
    "împinsese": "împinge",
    "împinsesem": "împinge",
    "împinseseră": "împinge",
    "împinseserăm": "împinge",
    "împinseserăți": "împinge",
    "împinseseși": "împinge",
    "împinseși": "împinge",
    "împinsu": "împinge",
    "neîmpingând": "împinge",
    "neîmpingându": "împinge",
    "nemaiîmpingând": "împinge",
    "nemaiîmpingându": "împinge",
    "împingerea": "împingere",
    "împingeri": "împingere",
    "împingerii": "împingere",
    "împingerile": "împingere",
    "împingerilor": "împingere",
    "împinsă": "împins",
    "împinse": "împins",
    "împinși": "împins",
    "implacabila": "implacabil",
    "implacabilă": "implacabil",
    "implacabile": "implacabil",
    "implacabilei": "implacabil",
    "implacabilele": "implacabil",
    "implacabilelor": "implacabil",
    "implacabili": "implacabil",
    "implacabilii": "implacabil",
    "implacabililor": "implacabil",
    "implacabilul": "implacabil",
    "implacabilului": "implacabil",
    "implantă": "implanta",
    "implantai": "implanta",
    "implantam": "implanta",
    "implantăm": "implanta",
    "implantând": "implanta",
    "implantându": "implanta",
    "implantară": "implanta",
    "implantarăm": "implanta",
    "implantarăți": "implanta",
    "implantase": "implanta",
    "implantasem": "implanta",
    "implantaseră": "implanta",
    "implantaserăm": "implanta",
    "implantaserăți": "implanta",
    "implantaseși": "implanta",
    "implantași": "implanta",
    "implantat": "implanta",
    "implantați": "implanta",
    "implantatu": "implanta",
    "implantau": "implanta",
    "implantează": "implanta",
    "implantez": "implanta",
    "implanteze": "implanta",
    "implantezi": "implanta",
    "neimplantând": "implanta",
    "neimplantându": "implanta",
    "nemaiimplantând": "implanta",
    "nemaiimplantându": "implanta",
    "împlânt": "împlânta",
    "împlântă": "împlânta",
    "împlântai": "împlânta",
    "împlântam": "împlânta",
    "împlântăm": "împlânta",
    "împlântând": "împlânta",
    "împlântându": "împlânta",
    "împlântară": "împlânta",
    "împlântarăm": "împlânta",
    "împlântarăți": "împlânta",
    "împlântase": "împlânta",
    "împlântasem": "împlânta",
    "împlântaseră": "împlânta",
    "împlântaserăm": "împlânta",
    "împlântaserăți": "împlânta",
    "împlântaseși": "împlânta",
    "împlântași": "împlânta",
    "împlântat": "împlânta",
    "împlântați": "împlânta",
    "împlântatu": "împlânta",
    "împlântau": "împlânta",
    "împlânte": "împlânta",
    "împlânți": "împlânta",
    "neîmplântând": "împlânta",
    "neîmplântându": "împlânta",
    "nemaiîmplântând": "împlânta",
    "nemaiîmplântându": "împlânta",
    "implantată": "implantat",
    "implantate": "implantat",
    "implantați": "implantat",
    "împlântată": "împlântat",
    "împlântate": "împlântat",
    "împlântați": "împlântat",
    "implementăm": "implementa",
    "implementând": "implementa",
    "implementându": "implementa",
    "implementat": "implementa",
    "implementați": "implementa",
    "implementează": "implementa",
    "implementez": "implementa",
    "implementeze": "implementa",
    "implementezi": "implementa",
    "implementarea": "implementare",
    "implementareo": "implementare",
    "implementări": "implementare",
    "implementării": "implementare",
    "implementările": "implementare",
    "implementărilor": "implementare",
    "implementată": "implementat",
    "implementate": "implementat",
    "implementați": "implementat",
    "împletea": "împleti",
    "împleteai": "împleti",
    "împleteam": "împleti",
    "împletească": "împleti",
    "împleteați": "împleti",
    "împleteau": "împleti",
    "împletesc": "împleti",
    "împletește": "împleti",
    "împletești": "împleti",
    "împletii": "împleti",
    "împletim": "împleti",
    "împletind": "împleti",
    "împletindu": "împleti",
    "împletiră": "împleti",
    "împletirăm": "împleti",
    "împletirăți": "împleti",
    "împletise": "împleti",
    "împletisem": "împleti",
    "împletiseră": "împleti",
    "împletiserăm": "împleti",
    "împletiserăți": "împleti",
    "împletiseși": "împleti",
    "împletiși": "împleti",
    "împletit": "împleti",
    "împletiți": "împleti",
    "împletitu": "împleti",
    "neîmpletind": "împleti",
    "neîmpletindu": "împleti",
    "nemaiîmpletind": "împleti",
    "nemaiîmpletindu": "împleti",
    "împleticea": "împletici",
    "împleticeai": "împletici",
    "împleticeam": "împletici",
    "împleticească": "împletici",
    "împleticeați": "împletici",
    "împleticeau": "împletici",
    "împleticesc": "împletici",
    "împleticește": "împletici",
    "împleticești": "împletici",
    "împleticii": "împletici",
    "împleticim": "împletici",
    "împleticind": "împletici",
    "împleticindu": "împletici",
    "împleticiră": "împletici",
    "împleticirăm": "împletici",
    "împleticirăți": "împletici",
    "împleticise": "împletici",
    "împleticisem": "împletici",
    "împleticiseră": "împletici",
    "împleticiserăm": "împletici",
    "împleticiserăți": "împletici",
    "împleticiseși": "împletici",
    "împleticiși": "împletici",
    "împleticit": "împletici",
    "împleticiți": "împletici",
    "împleticitu": "împletici",
    "neîmpleticind": "împletici",
    "neîmpleticindu": "împletici",
    "nemaiîmpleticind": "împletici",
    "nemaiîmpleticindu": "împletici",
    "împleticită": "împleticit",
    "împleticite": "împleticit",
    "împleticiți": "împleticit",
    "împletită": "împletit",
    "împletite": "împletit",
    "împletiți": "împletit",
    "împletitura": "împletitură",
    "împletituri": "împletitură",
    "împletiturii": "împletitură",
    "împletiturile": "împletitură",
    "împletiturilor": "împletitură",
    "implic": "implica",
    "implică": "implica",
    "implicai": "implica",
    "implicam": "implica",
    "implicăm": "implica",
    "implicând": "implica",
    "implicându": "implica",
    "implicară": "implica",
    "implicarăm": "implica",
    "implicarăți": "implica",
    "implicase": "implica",
    "implicasem": "implica",
    "implicaseră": "implica",
    "implicaserăm": "implica",
    "implicaserăți": "implica",
    "implicaseși": "implica",
    "implicași": "implica",
    "implicat": "implica",
    "implicați": "implica",
    "implicatu": "implica",
    "implicau": "implica",
    "implice": "implica",
    "implici": "implica",
    "neimplicând": "implica",
    "neimplicându": "implica",
    "nemaiimplicând": "implica",
    "nemaiimplicându": "implica",
    "implicarea": "implicare",
    "implicareo": "implicare",
    "implicări": "implicare",
    "implicării": "implicare",
    "implicările": "implicare",
    "implicărilor": "implicare",
    "implicată": "implicat",
    "implicate": "implicat",
    "implicați": "implicat",
    "implicația": "implicație",
    "implicației": "implicație",
    "implicații": "implicație",
    "implicațiile": "implicație",
    "implicațiilor": "implicație",
    "implicita": "implicit",
    "implicită": "implicit",
    "implicite": "implicit",
    "implicitei": "implicit",
    "implicitele": "implicit",
    "implicitelor": "implicit",
    "impliciți": "implicit",
    "impliciții": "implicit",
    "impliciților": "implicit",
    "implicitul": "implicit",
    "implicitului": "implicit",
    "împlinea": "împlini",
    "împlineai": "împlini",
    "împlineam": "împlini",
    "împlinească": "împlini",
    "împlineați": "împlini",
    "împlineau": "împlini",
    "împlinesc": "împlini",
    "împlinește": "împlini",
    "împlinești": "împlini",
    "împlinii": "împlini",
    "împlinim": "împlini",
    "împlinind": "împlini",
    "împlinindu": "împlini",
    "împliniră": "împlini",
    "împlinirăm": "împlini",
    "împlinirăți": "împlini",
    "împlinise": "împlini",
    "împlinisem": "împlini",
    "împliniseră": "împlini",
    "împliniserăm": "împlini",
    "împliniserăți": "împlini",
    "împliniseși": "împlini",
    "împliniși": "împlini",
    "împlinit": "împlini",
    "împliniți": "împlini",
    "împlinitu": "împlini",
    "neîmplinind": "împlini",
    "neîmplinindu": "împlini",
    "nemaiîmplinind": "împlini",
    "nemaiîmplinindu": "împlini",
    "împlinirea": "împlinire",
    "împliniri": "împlinire",
    "împlinirii": "împlinire",
    "împlinirile": "împlinire",
    "împlinirilor": "împlinire",
    "împlinită": "împlinit",
    "împlinite": "împlinit",
    "împliniți": "împlinit",
    "implor": "implora",
    "imploră": "implora",
    "implorai": "implora",
    "imploram": "implora",
    "implorăm": "implora",
    "implorând": "implora",
    "implorându": "implora",
    "implorară": "implora",
    "implorarăm": "implora",
    "implorarăți": "implora",
    "implorase": "implora",
    "implorasem": "implora",
    "imploraseră": "implora",
    "imploraserăm": "implora",
    "imploraserăți": "implora",
    "imploraseși": "implora",
    "implorași": "implora",
    "implorat": "implora",
    "implorați": "implora",
    "imploratu": "implora",
    "implorau": "implora",
    "implore": "implora",
    "implori": "implora",
    "neimplorând": "implora",
    "neimplorându": "implora",
    "nemaiimplorând": "implora",
    "nemaiimplorându": "implora",
    "implorarea": "implorare",
    "implorări": "implorare",
    "implorării": "implorare",
    "implorările": "implorare",
    "implorărilor": "implorare",
    "implorată": "implorat",
    "implorate": "implorat",
    "implorați": "implorat",
    "implozia": "implozie",
    "imploziei": "implozie",
    "implozii": "implozie",
    "imploziile": "implozie",
    "imploziilor": "implozie",
    "împodobea": "împodobi",
    "împodobeai": "împodobi",
    "împodobeam": "împodobi",
    "împodobească": "împodobi",
    "împodobeați": "împodobi",
    "împodobeau": "împodobi",
    "împodobesc": "împodobi",
    "împodobește": "împodobi",
    "împodobești": "împodobi",
    "împodobii": "împodobi",
    "împodobim": "împodobi",
    "împodobind": "împodobi",
    "împodobindu": "împodobi",
    "împodobiră": "împodobi",
    "împodobirăm": "împodobi",
    "împodobirăți": "împodobi",
    "împodobise": "împodobi",
    "împodobisem": "împodobi",
    "împodobiseră": "împodobi",
    "împodobiserăm": "împodobi",
    "împodobiserăți": "împodobi",
    "împodobiseși": "împodobi",
    "împodobiși": "împodobi",
    "împodobit": "împodobi",
    "împodobiți": "împodobi",
    "împodobitu": "împodobi",
    "neîmpodobind": "împodobi",
    "neîmpodobindu": "împodobi",
    "nemaiîmpodobind": "împodobi",
    "nemaiîmpodobindu": "împodobi",
    "împodobirea": "împodobire",
    "împodobiri": "împodobire",
    "împodobirii": "împodobire",
    "împodobirile": "împodobire",
    "împodobirilor": "împodobire",
    "împodobită": "împodobit",
    "împodobite": "împodobit",
    "împodobiți": "împodobit",
    "impolitețea": "impolitețe",
    "impoliteți": "impolitețe",
    "impoliteții": "impolitețe",
    "impolitețuri": "impolitețe",
    "impolitețurile": "impolitețe",
    "impolitețurilor": "impolitețe",
    "imponderabila": "imponderabil",
    "imponderabilă": "imponderabil",
    "imponderabile": "imponderabil",
    "imponderabilei": "imponderabil",
    "imponderabilele": "imponderabil",
    "imponderabilelor": "imponderabil",
    "imponderabili": "imponderabil",
    "imponderabilii": "imponderabil",
    "imponderabililor": "imponderabil",
    "imponderabilul": "imponderabil",
    "imponderabilului": "imponderabil",
    "imponderabilitatea": "imponderabilitate",
    "imponderabilități": "imponderabilitate",
    "imponderabilității": "imponderabilitate",
    "împopoțonă": "împopoțona",
    "împopoțonai": "împopoțona",
    "împopoțonam": "împopoțona",
    "împopoțonăm": "împopoțona",
    "împopoțonând": "împopoțona",
    "împopoțonându": "împopoțona",
    "împopoțonară": "împopoțona",
    "împopoțonarăm": "împopoțona",
    "împopoțonarăți": "împopoțona",
    "împopoțonase": "împopoțona",
    "împopoțonasem": "împopoțona",
    "împopoțonaseră": "împopoțona",
    "împopoțonaserăm": "împopoțona",
    "împopoțonaserăți": "împopoțona",
    "împopoțonaseși": "împopoțona",
    "împopoțonași": "împopoțona",
    "împopoțonat": "împopoțona",
    "împopoțonați": "împopoțona",
    "împopoțonatu": "împopoțona",
    "împopoțonau": "împopoțona",
    "împopoțonează": "împopoțona",
    "împopoțonez": "împopoțona",
    "împopoțoneze": "împopoțona",
    "împopoțonezi": "împopoțona",
    "neîmpopoțonând": "împopoțona",
    "neîmpopoțonându": "împopoțona",
    "nemaiîmpopoțonând": "împopoțona",
    "nemaiîmpopoțonându": "împopoțona",
    "împopoțonată": "împopoțonat",
    "împopoțonate": "împopoțonat",
    "împopoțonați": "împopoțonat",
    "impopulara": "impopular",
    "impopulară": "impopular",
    "impopulare": "impopular",
    "impopularei": "impopular",
    "impopularele": "impopular",
    "impopularelor": "impopular",
    "impopulari": "impopular",
    "impopularii": "impopular",
    "impopularilor": "impopular",
    "impopularo": "impopular",
    "impopularul": "impopular",
    "impopularule": "impopular",
    "impopularului": "impopular",
    "importul": "import",
    "importului": "import",
    "importuri": "import",
    "importurile": "import",
    "importurilor": "import",
    "import": "importa",
    "importă": "importa",
    "importai": "importa",
    "importam": "importa",
    "importăm": "importa",
    "importând": "importa",
    "importându": "importa",
    "importară": "importa",
    "importarăm": "importa",
    "importarăți": "importa",
    "importase": "importa",
    "importasem": "importa",
    "importaseră": "importa",
    "importaserăm": "importa",
    "importaserăți": "importa",
    "importaseși": "importa",
    "importași": "importa",
    "importat": "importa",
    "importați": "importa",
    "importatu": "importa",
    "importau": "importa",
    "importe": "importa",
    "imporți": "importa",
    "neimportând": "importa",
    "neimportându": "importa",
    "nemaiimportându": "importa",
    "importanta": "important",
    "importantă": "important",
    "importante": "important",
    "importantei": "important",
    "importantele": "important",
    "importantelor": "important",
    "importanți": "important",
    "importanții": "important",
    "importanților": "important",
    "importantul": "important",
    "importantului": "important",
    "importanța": "importanță",
    "importanțe": "importanță",
    "importanței": "importanță",
    "importata": "importat",
    "importată": "importat",
    "importate": "importat",
    "importatei": "importat",
    "importatele": "importat",
    "importatelor": "importat",
    "importați": "importat",
    "importații": "importat",
    "importaților": "importat",
    "importatul": "importat",
    "importatului": "importat",
    "importatoarea": "importatoare",
    "importatoarei": "importatoare",
    "importatoarele": "importatoare",
    "importatoarelor": "importatoare",
    "importatoare": "importator",
    "importatori": "importator",
    "importatorii": "importator",
    "importatorilor": "importator",
    "importatorul": "importator",
    "importatorului": "importator",
    "Imp.Exp.": "Import-Export",
    "IMPEX": "Import-Export",
    "importună": "importuna",
    "importunai": "importuna",
    "importunam": "importuna",
    "importunăm": "importuna",
    "importunând": "importuna",
    "importunându": "importuna",
    "importunară": "importuna",
    "importunarăm": "importuna",
    "importunarăți": "importuna",
    "importunase": "importuna",
    "importunasem": "importuna",
    "importunaseră": "importuna",
    "importunaserăm": "importuna",
    "importunaserăți": "importuna",
    "importunaseși": "importuna",
    "importunași": "importuna",
    "importunat": "importuna",
    "importunați": "importuna",
    "importunatu": "importuna",
    "importunau": "importuna",
    "importunează": "importuna",
    "importunez": "importuna",
    "importuneze": "importuna",
    "importunezi": "importuna",
    "neimportunând": "importuna",
    "neimportunându": "importuna",
    "nemaiimportunând": "importuna",
    "nemaiimportunându": "importuna",
    "importunată": "importunat",
    "importunate": "importunat",
    "importunați": "importunat",
    "imposibila": "imposibil",
    "imposibilă": "imposibil",
    "imposibile": "imposibil",
    "imposibilei": "imposibil",
    "imposibilele": "imposibil",
    "imposibilelor": "imposibil",
    "imposibili": "imposibil",
    "imposibilii": "imposibil",
    "imposibililor": "imposibil",
    "imposibilul": "imposibil",
    "imposibilului": "imposibil",
    "imposibilitatea": "imposibilitate",
    "imposibilități": "imposibilitate",
    "imposibilității": "imposibilitate",
    "impostori": "impostor",
    "impostorii": "impostor",
    "impostorilor": "impostor",
    "impostorul": "impostor",
    "impostorului": "impostor",
    "impostura": "impostură",
    "imposturi": "impostură",
    "imposturii": "impostură",
    "imposturile": "impostură",
    "imposturilor": "impostură",
    "impotenta": "impotent",
    "impotentă": "impotent",
    "impotente": "impotent",
    "impotentei": "impotent",
    "impotentele": "impotent",
    "impotentelor": "impotent",
    "impotenți": "impotent",
    "impotenții": "impotent",
    "impotenților": "impotent",
    "impotentul": "impotent",
    "impotentului": "impotent",
    "impotența": "impotență",
    "impotențe": "impotență",
    "impotenței": "impotență",
    "împotmolea": "împotmoli",
    "împotmoleai": "împotmoli",
    "împotmoleam": "împotmoli",
    "împotmolească": "împotmoli",
    "împotmoleați": "împotmoli",
    "împotmoleau": "împotmoli",
    "împotmolesc": "împotmoli",
    "împotmolește": "împotmoli",
    "împotmolești": "împotmoli",
    "împotmolii": "împotmoli",
    "împotmolim": "împotmoli",
    "împotmolind": "împotmoli",
    "împotmolindu": "împotmoli",
    "împotmoliră": "împotmoli",
    "împotmolirăm": "împotmoli",
    "împotmolirăți": "împotmoli",
    "împotmolise": "împotmoli",
    "împotmolisem": "împotmoli",
    "împotmoliseră": "împotmoli",
    "împotmoliserăm": "împotmoli",
    "împotmoliserăți": "împotmoli",
    "împotmoliseși": "împotmoli",
    "împotmoliși": "împotmoli",
    "împotmolit": "împotmoli",
    "împotmoliți": "împotmoli",
    "împotmolitu": "împotmoli",
    "neîmpotmolind": "împotmoli",
    "neîmpotmolindu": "împotmoli",
    "nemaiîmpotmolind": "împotmoli",
    "nemaiîmpotmolindu": "împotmoli",
    "împotmolită": "împotmolit",
    "împotmolite": "împotmolit",
    "împotmoliți": "împotmolit",
    "împotrivea": "împotrivi",
    "împotriveai": "împotrivi",
    "împotriveam": "împotrivi",
    "împotrivească": "împotrivi",
    "împotriveați": "împotrivi",
    "împotriveau": "împotrivi",
    "împotrivesc": "împotrivi",
    "împotrivește": "împotrivi",
    "împotrivești": "împotrivi",
    "împotrivii": "împotrivi",
    "împotrivim": "împotrivi",
    "împotrivind": "împotrivi",
    "împotrivindu": "împotrivi",
    "împotriviră": "împotrivi",
    "împotrivirăm": "împotrivi",
    "împotrivirăți": "împotrivi",
    "împotrivise": "împotrivi",
    "împotrivisem": "împotrivi",
    "împotriviseră": "împotrivi",
    "împotriviserăm": "împotrivi",
    "împotriviserăți": "împotrivi",
    "împotriviseși": "împotrivi",
    "împotriviși": "împotrivi",
    "împotrivit": "împotrivi",
    "împotriviți": "împotrivi",
    "împotrivitu": "împotrivi",
    "neîmpotrivind": "împotrivi",
    "neîmpotrivindu": "împotrivi",
    "nemaiîmpotrivind": "împotrivi",
    "nemaiîmpotrivindu": "împotrivi",
    "împotrivirea": "împotrivire",
    "împotriviri": "împotrivire",
    "împotrivirii": "împotrivire",
    "împotrivirile": "împotrivire",
    "împotrivirilor": "împotrivire",
    "împotrivită": "împotrivit",
    "împotrivite": "împotrivit",
    "împotriviți": "împotrivit",
    "împovără": "împovăra",
    "împovărai": "împovăra",
    "împovăram": "împovăra",
    "împovărăm": "împovăra",
    "împovărând": "împovăra",
    "împovărându": "împovăra",
    "împovărară": "împovăra",
    "împovărarăm": "împovăra",
    "împovărarăți": "împovăra",
    "împovărase": "împovăra",
    "împovărasem": "împovăra",
    "împovăraseră": "împovăra",
    "împovăraserăm": "împovăra",
    "împovăraserăți": "împovăra",
    "împovăraseși": "împovăra",
    "împovărași": "împovăra",
    "împovărat": "împovăra",
    "împovărați": "împovăra",
    "împovăratu": "împovăra",
    "împovărau": "împovăra",
    "împovărează": "împovăra",
    "împovărez": "împovăra",
    "împovăreze": "împovăra",
    "împovărezi": "împovăra",
    "neîmpovărând": "împovăra",
    "neîmpovărându": "împovăra",
    "nemaiîmpovărând": "împovăra",
    "nemaiîmpovărându": "împovăra",
    "împovărată": "împovărat",
    "împovărate": "împovărat",
    "împovărați": "împovărat",
    "împovărătoare": "împovărător",
    "împovărătoarea": "împovărător",
    "împovărătoarei": "împovărător",
    "împovărătoarele": "împovărător",
    "împovărătoarelor": "împovărător",
    "împovărătoareo": "împovărător",
    "împovărători": "împovărător",
    "împovărătorii": "împovărător",
    "împovărătorilor": "împovărător",
    "împovărătorul": "împovărător",
    "împovărătorule": "împovărător",
    "împovărătorului": "împovărător",
    "impozabila": "impozabil",
    "impozabilă": "impozabil",
    "impozabile": "impozabil",
    "impozabilei": "impozabil",
    "impozabilele": "impozabil",
    "impozabilelor": "impozabil",
    "impozabili": "impozabil",
    "impozabilii": "impozabil",
    "impozabililor": "impozabil",
    "impozabilul": "impozabil",
    "impozabilului": "impozabil",
    "impozanta": "impozant",
    "impozantă": "impozant",
    "impozante": "impozant",
    "impozantei": "impozant",
    "impozantele": "impozant",
    "impozantelor": "impozant",
    "impozanți": "impozant",
    "impozanții": "impozant",
    "impozanților": "impozant",
    "impozantul": "impozant",
    "impozantului": "impozant",
    "impozite": "impozit",
    "impozitele": "impozit",
    "impozitelor": "impozit",
    "impozitul": "impozit",
    "impozitului": "impozit",
    "împrăștiai": "împrăștia",
    "împrăștiam": "împrăștia",
    "împrăștiară": "împrăștia",
    "împrăștiarăm": "împrăștia",
    "împrăștiarăți": "împrăștia",
    "împrăștiase": "împrăștia",
    "împrăștiasem": "împrăștia",
    "împrăștiaseră": "împrăștia",
    "împrăștiaserăm": "împrăștia",
    "împrăștiaserăți": "împrăștia",
    "împrăștiaseși": "împrăștia",
    "împrăștiași": "împrăștia",
    "împrăștiat": "împrăștia",
    "împrăștiați": "împrăștia",
    "împrăștiatu": "împrăștia",
    "împrăștiau": "împrăștia",
    "împrăștie": "împrăștia",
    "împrăștiem": "împrăștia",
    "împrăștii": "împrăștia",
    "împrăștiind": "împrăștia",
    "împrăștiindu": "împrăștia",
    "neîmprăștiind": "împrăștia",
    "neîmprăștiindu": "împrăștia",
    "nemaiîmprăștiind": "împrăștia",
    "nemaiîmprăștiindu": "împrăștia",
    "împrăștiată": "împrăștiat",
    "împrăștiate": "împrăștiat",
    "împrăștiați": "împrăștiat",
    "imprecisa": "imprecis",
    "imprecisă": "imprecis",
    "imprecise": "imprecis",
    "imprecisei": "imprecis",
    "imprecisele": "imprecis",
    "impreciselor": "imprecis",
    "impreciși": "imprecis",
    "imprecișii": "imprecis",
    "imprecișilor": "imprecis",
    "imprecisul": "imprecis",
    "imprecisului": "imprecis",
    "impregnă": "impregna",
    "impregnai": "impregna",
    "impregnam": "impregna",
    "impregnăm": "impregna",
    "impregnând": "impregna",
    "impregnându": "impregna",
    "impregnară": "impregna",
    "impregnarăm": "impregna",
    "impregnarăți": "impregna",
    "impregnase": "impregna",
    "impregnasem": "impregna",
    "impregnaseră": "impregna",
    "impregnaserăm": "impregna",
    "impregnaserăți": "impregna",
    "impregnaseși": "impregna",
    "impregnași": "impregna",
    "impregnat": "impregna",
    "impregnați": "impregna",
    "impregnatu": "impregna",
    "impregnau": "impregna",
    "impregnează": "impregna",
    "impregnez": "impregna",
    "impregneze": "impregna",
    "impregnezi": "impregna",
    "neimpregnând": "impregna",
    "neimpregnându": "impregna",
    "nemaiimpregnând": "impregna",
    "nemaiimpregnându": "impregna",
    "impregnată": "impregnat",
    "impregnate": "impregnat",
    "impregnați": "impregnat",
    "împrejmuia": "împrejmui",
    "împrejmuiai": "împrejmui",
    "împrejmuiam": "împrejmui",
    "împrejmuiască": "împrejmui",
    "împrejmuiați": "împrejmui",
    "împrejmuiau": "împrejmui",
    "împrejmuiesc": "împrejmui",
    "împrejmuiește": "împrejmui",
    "împrejmuiești": "împrejmui",
    "împrejmuii": "împrejmui",
    "împrejmuim": "împrejmui",
    "împrejmuind": "împrejmui",
    "împrejmuindu": "împrejmui",
    "împrejmuiră": "împrejmui",
    "împrejmuirăm": "împrejmui",
    "împrejmuirăți": "împrejmui",
    "împrejmuise": "împrejmui",
    "împrejmuisem": "împrejmui",
    "împrejmuiseră": "împrejmui",
    "împrejmuiserăm": "împrejmui",
    "împrejmuiserăți": "împrejmui",
    "împrejmuiseși": "împrejmui",
    "împrejmuiși": "împrejmui",
    "împrejmuit": "împrejmui",
    "împrejmuiți": "împrejmui",
    "împrejmuitu": "împrejmui",
    "neîmprejmuind": "împrejmui",
    "neîmprejmuindu": "împrejmui",
    "nemaiîmprejmuind": "împrejmui",
    "nemaiîmprejmuindu": "împrejmui",
    "împrejmuită": "împrejmuit",
    "împrejmuite": "împrejmuit",
    "împrejmuiți": "împrejmuit",
    "împrejmuitoare": "împrejmuitor",
    "împrejmuitoarea": "împrejmuitor",
    "împrejmuitoarei": "împrejmuitor",
    "împrejmuitoarele": "împrejmuitor",
    "împrejmuitoarelor": "împrejmuitor",
    "împrejmuitoareo": "împrejmuitor",
    "împrejmuitori": "împrejmuitor",
    "împrejmuitorii": "împrejmuitor",
    "împrejmuitorilor": "împrejmuitor",
    "împrejmuitorul": "împrejmuitor",
    "împrejmuitorule": "împrejmuitor",
    "împrejmuitorului": "împrejmuitor",
    "împrejur": "împrejura",
    "împrejură": "împrejura",
    "împrejurai": "împrejura",
    "împrejuram": "împrejura",
    "împrejurăm": "împrejura",
    "împrejurând": "împrejura",
    "împrejurându": "împrejura",
    "împrejurară": "împrejura",
    "împrejurarăm": "împrejura",
    "împrejurarăți": "împrejura",
    "împrejurase": "împrejura",
    "împrejurasem": "împrejura",
    "împrejuraseră": "împrejura",
    "împrejuraserăm": "împrejura",
    "împrejuraserăți": "împrejura",
    "împrejuraseși": "împrejura",
    "împrejurași": "împrejura",
    "împrejurat": "împrejura",
    "împrejurați": "împrejura",
    "împrejuratu": "împrejura",
    "împrejurau": "împrejura",
    "împrejure": "împrejura",
    "împrejuri": "împrejura",
    "neîmprejurând": "împrejura",
    "neîmprejurându": "împrejura",
    "nemaiîmprejurând": "împrejura",
    "nemaiîmprejurându": "împrejura",
    "împrejurarea": "împrejurare",
    "împrejurări": "împrejurare",
    "împrejurării": "împrejurare",
    "împrejurările": "împrejurare",
    "împrejurărilor": "împrejurare",
    "împrejurată": "împrejurat",
    "împrejurate": "împrejurat",
    "împrejurați": "împrejurat",
    "împrejurimea": "împrejurime",
    "împrejurimi": "împrejurime",
    "împrejurimii": "împrejurime",
    "împrejurimile": "împrejurime",
    "împrejurimilor": "împrejurime",
    "impresari": "impresar",
    "impresarii": "impresar",
    "impresarilor": "impresar",
    "impresarul": "impresar",
    "impresarului": "impresar",
    "imprescriptibila": "imprescriptibil",
    "imprescriptibilă": "imprescriptibil",
    "imprescriptibile": "imprescriptibil",
    "imprescriptibilei": "imprescriptibil",
    "imprescriptibilele": "imprescriptibil",
    "imprescriptibilelor": "imprescriptibil",
    "imprescriptibili": "imprescriptibil",
    "imprescriptibilii": "imprescriptibil",
    "imprescriptibililor": "imprescriptibil",
    "imprescriptibilul": "imprescriptibil",
    "imprescriptibilului": "imprescriptibil",
    "impresia": "impresie",
    "impresiei": "impresie",
    "impresii": "impresie",
    "impresiile": "impresie",
    "impresiilor": "impresie",
    "impresionă": "impresiona",
    "impresionai": "impresiona",
    "impresionam": "impresiona",
    "impresionăm": "impresiona",
    "impresionând": "impresiona",
    "impresionându": "impresiona",
    "impresionară": "impresiona",
    "impresionarăm": "impresiona",
    "impresionarăți": "impresiona",
    "impresionase": "impresiona",
    "impresionasem": "impresiona",
    "impresionaseră": "impresiona",
    "impresionaserăm": "impresiona",
    "impresionaserăți": "impresiona",
    "impresionaseși": "impresiona",
    "impresionași": "impresiona",
    "impresionat": "impresiona",
    "impresionați": "impresiona",
    "impresionatu": "impresiona",
    "impresionau": "impresiona",
    "impresionează": "impresiona",
    "impresionez": "impresiona",
    "impresioneze": "impresiona",
    "impresionezi": "impresiona",
    "neimpresionând": "impresiona",
    "neimpresionându": "impresiona",
    "nemaiimpresionând": "impresiona",
    "nemaiimpresionându": "impresiona",
    "impresionanta": "impresionant",
    "impresionantă": "impresionant",
    "impresionante": "impresionant",
    "impresionantei": "impresionant",
    "impresionantele": "impresionant",
    "impresionantelor": "impresionant",
    "impresionanți": "impresionant",
    "impresionanții": "impresionant",
    "impresionanților": "impresionant",
    "impresionantul": "impresionant",
    "impresionantului": "impresionant",
    "impresionată": "impresionat",
    "impresionate": "impresionat",
    "impresionați": "impresionat",
    "impresionismul": "impresionism",
    "impresionismului": "impresionism",
    "impresionista": "impresionist",
    "impresionistă": "impresionist",
    "impresioniste": "impresionist",
    "impresionistei": "impresionist",
    "impresionistele": "impresionist",
    "impresionistelor": "impresionist",
    "impresioniști": "impresionist",
    "impresioniștii": "impresionist",
    "impresioniștilor": "impresionist",
    "impresionistul": "impresionist",
    "impresionistului": "impresionist",
    "împresoară": "împresura",
    "împresoare": "împresura",
    "împresor": "împresura",
    "împresori": "împresura",
    "împresură": "împresura",
    "împresurai": "împresura",
    "împresuram": "împresura",
    "împresurăm": "împresura",
    "împresurând": "împresura",
    "împresurându": "împresura",
    "împresurară": "împresura",
    "împresurarăm": "împresura",
    "împresurarăți": "împresura",
    "împresurase": "împresura",
    "împresurasem": "împresura",
    "împresuraseră": "împresura",
    "împresuraserăm": "împresura",
    "împresuraserăți": "împresura",
    "împresuraseși": "împresura",
    "împresurași": "împresura",
    "împresurat": "împresura",
    "împresurați": "împresura",
    "împresuratu": "împresura",
    "împresurau": "împresura",
    "neîmpresurând": "împresura",
    "neîmpresurându": "împresura",
    "nemaiîmpresurând": "împresura",
    "nemaiîmpresurându": "împresura",
    "împresurată": "împresurat",
    "împresurate": "împresurat",
    "împresurați": "împresurat",
    "împreună": "împreuna",
    "împreunai": "împreuna",
    "împreunam": "împreuna",
    "împreunăm": "împreuna",
    "împreunând": "împreuna",
    "împreunându": "împreuna",
    "împreunară": "împreuna",
    "împreunarăm": "împreuna",
    "împreunarăți": "împreuna",
    "împreunase": "împreuna",
    "împreunasem": "împreuna",
    "împreunaseră": "împreuna",
    "împreunaserăm": "împreuna",
    "împreunaserăți": "împreuna",
    "împreunaseși": "împreuna",
    "împreunași": "împreuna",
    "împreunat": "împreuna",
    "împreunați": "împreuna",
    "împreunatu": "împreuna",
    "împreunau": "împreuna",
    "împreunează": "împreuna",
    "împreunez": "împreuna",
    "împreuneze": "împreuna",
    "împreunezi": "împreuna",
    "neîmpreunând": "împreuna",
    "neîmpreunându": "împreuna",
    "nemaiîmpreunând": "împreuna",
    "nemaiîmpreunându": "împreuna",
    "împreunarea": "împreunare",
    "împreunări": "împreunare",
    "împreunării": "împreunare",
    "împreunările": "împreunare",
    "împreunărilor": "împreunare",
    "împreunată": "împreunat",
    "împreunate": "împreunat",
    "împreunați": "împreunat",
    "imprevizibila": "imprevizibil",
    "imprevizibilă": "imprevizibil",
    "imprevizibile": "imprevizibil",
    "imprevizibilei": "imprevizibil",
    "imprevizibilele": "imprevizibil",
    "imprevizibilelor": "imprevizibil",
    "imprevizibili": "imprevizibil",
    "imprevizibilii": "imprevizibil",
    "imprevizibililor": "imprevizibil",
    "imprevizibilul": "imprevizibil",
    "imprevizibilului": "imprevizibil",
    "împricină": "împricina",
    "împricinai": "împricina",
    "împricinam": "împricina",
    "împricinăm": "împricina",
    "împricinând": "împricina",
    "împricinându": "împricina",
    "împricinară": "împricina",
    "împricinarăm": "împricina",
    "împricinarăți": "împricina",
    "împricinase": "împricina",
    "împricinasem": "împricina",
    "împricinaseră": "împricina",
    "împricinaserăm": "împricina",
    "împricinaserăți": "împricina",
    "împricinaseși": "împricina",
    "împricinași": "împricina",
    "împricinat": "împricina",
    "împricinați": "împricina",
    "împricinatu": "împricina",
    "împricinau": "împricina",
    "împricinează": "împricina",
    "împricinez": "împricina",
    "împricineze": "împricina",
    "împricinezi": "împricina",
    "neîmpricinând": "împricina",
    "neîmpricinându": "împricina",
    "nemaiîmpricinând": "împricina",
    "nemaiîmpricinându": "împricina",
    "împricinată": "împricinat",
    "împricinate": "împricinat",
    "împricinați": "împricinat",
    "împrietenea": "împrieteni",
    "împrieteneai": "împrieteni",
    "împrieteneam": "împrieteni",
    "împrietenească": "împrieteni",
    "împrieteneați": "împrieteni",
    "împrieteneau": "împrieteni",
    "împrietenesc": "împrieteni",
    "împrietenește": "împrieteni",
    "împrietenești": "împrieteni",
    "împrietenii": "împrieteni",
    "împrietenim": "împrieteni",
    "împrietenind": "împrieteni",
    "împrietenindu": "împrieteni",
    "împrieteniră": "împrieteni",
    "împrietenirăm": "împrieteni",
    "împrietenirăți": "împrieteni",
    "împrietenise": "împrieteni",
    "împrietenisem": "împrieteni",
    "împrieteniseră": "împrieteni",
    "împrieteniserăm": "împrieteni",
    "împrieteniserăți": "împrieteni",
    "împrieteniseși": "împrieteni",
    "împrieteniși": "împrieteni",
    "împrietenit": "împrieteni",
    "împrieteniți": "împrieteni",
    "împrietenitu": "împrieteni",
    "neîmprietenind": "împrieteni",
    "neîmprietenindu": "împrieteni",
    "nemaiîmprietenind": "împrieteni",
    "nemaiîmprietenindu": "împrieteni",
    "împrietenită": "împrietenit",
    "împrietenite": "împrietenit",
    "împrieteniți": "împrietenit",
    "imprim": "imprima",
    "imprimă": "imprima",
    "imprimai": "imprima",
    "imprimam": "imprima",
    "imprimăm": "imprima",
    "imprimând": "imprima",
    "imprimându": "imprima",
    "imprimară": "imprima",
    "imprimarăm": "imprima",
    "imprimarăți": "imprima",
    "imprimase": "imprima",
    "imprimasem": "imprima",
    "imprimaseră": "imprima",
    "imprimaserăm": "imprima",
    "imprimaserăți": "imprima",
    "imprimaseși": "imprima",
    "imprimași": "imprima",
    "imprimat": "imprima",
    "imprimați": "imprima",
    "imprimatu": "imprima",
    "imprimau": "imprima",
    "imprime": "imprima",
    "imprimi": "imprima",
    "neimprimând": "imprima",
    "neimprimându": "imprima",
    "nemaiimprimând": "imprima",
    "nemaiimprimându": "imprima",
    "imprimarea": "imprimare",
    "imprimareo": "imprimare",
    "imprimări": "imprimare",
    "imprimării": "imprimare",
    "imprimările": "imprimare",
    "imprimărilor": "imprimare",
    "imprimata": "imprimat",
    "imprimată": "imprimat",
    "imprimate": "imprimat",
    "imprimatei": "imprimat",
    "imprimatele": "imprimat",
    "imprimatelor": "imprimat",
    "imprimați": "imprimat",
    "imprimații": "imprimat",
    "imprimaților": "imprimat",
    "imprimatul": "imprimat",
    "imprimatului": "imprimat",
    "împrimăvără": "împrimăvăra",
    "împrimăvărai": "împrimăvăra",
    "împrimăvăram": "împrimăvăra",
    "împrimăvărăm": "împrimăvăra",
    "împrimăvărând": "împrimăvăra",
    "împrimăvărându": "împrimăvăra",
    "împrimăvărară": "împrimăvăra",
    "împrimăvărarăm": "împrimăvăra",
    "împrimăvărarăți": "împrimăvăra",
    "împrimăvărase": "împrimăvăra",
    "împrimăvărasem": "împrimăvăra",
    "împrimăvăraseră": "împrimăvăra",
    "împrimăvăraserăm": "împrimăvăra",
    "împrimăvăraserăți": "împrimăvăra",
    "împrimăvăraseși": "împrimăvăra",
    "împrimăvărași": "împrimăvăra",
    "împrimăvărat": "împrimăvăra",
    "împrimăvărați": "împrimăvăra",
    "împrimăvăratu": "împrimăvăra",
    "împrimăvărau": "împrimăvăra",
    "împrimăvărează": "împrimăvăra",
    "împrimăvărez": "împrimăvăra",
    "împrimăvăreze": "împrimăvăra",
    "împrimăvărezi": "împrimăvăra",
    "neîmprimăvărând": "împrimăvăra",
    "neîmprimăvărându": "împrimăvăra",
    "nemaiîmprimăvărând": "împrimăvăra",
    "nemaiîmprimăvărându": "împrimăvăra",
    "împrimăvărată": "împrimăvărat",
    "împrimăvărate": "împrimăvărat",
    "împrimăvărați": "împrimăvărat",
    "imprimeria": "imprimerie",
    "imprimeriei": "imprimerie",
    "imprimerii": "imprimerie",
    "imprimeriile": "imprimerie",
    "imprimeriilor": "imprimerie",
    "imprimeul": "imprimeu",
    "imprimeului": "imprimeu",
    "imprimeuri": "imprimeu",
    "imprimeurile": "imprimeu",
    "imprimeurilor": "imprimeu",
    "improbabila": "improbabil",
    "improbabilă": "improbabil",
    "improbabile": "improbabil",
    "improbabilei": "improbabil",
    "improbabilele": "improbabil",
    "improbabilelor": "improbabil",
    "improbabili": "improbabil",
    "improbabilii": "improbabil",
    "improbabililor": "improbabil",
    "improbabilul": "improbabil",
    "improbabilului": "improbabil",
    "împroprietărea": "împroprietări",
    "împroprietăreai": "împroprietări",
    "împroprietăream": "împroprietări",
    "împroprietărească": "împroprietări",
    "împroprietăreați": "împroprietări",
    "împroprietăreau": "împroprietări",
    "împroprietăresc": "împroprietări",
    "împroprietărește": "împroprietări",
    "împroprietărești": "împroprietări",
    "împroprietării": "împroprietări",
    "împroprietărim": "împroprietări",
    "împroprietărind": "împroprietări",
    "împroprietărindu": "împroprietări",
    "împroprietăriră": "împroprietări",
    "împroprietărirăm": "împroprietări",
    "împroprietărirăți": "împroprietări",
    "împroprietărise": "împroprietări",
    "împroprietărisem": "împroprietări",
    "împroprietăriseră": "împroprietări",
    "împroprietăriserăm": "împroprietări",
    "împroprietăriserăți": "împroprietări",
    "împroprietăriseși": "împroprietări",
    "împroprietăriși": "împroprietări",
    "împroprietărit": "împroprietări",
    "împroprietăriți": "împroprietări",
    "împroprietăritu": "împroprietări",
    "neîmproprietărind": "împroprietări",
    "neîmproprietărindu": "împroprietări",
    "nemaiîmproprietărind": "împroprietări",
    "nemaiîmproprietărindu": "împroprietări",
    "împroprietărită": "împroprietărit",
    "împroprietărite": "împroprietărit",
    "împroprietăriți": "împroprietărit",
    "impropria": "impropriu",
    "improprie": "impropriu",
    "impropriei": "impropriu",
    "improprii": "impropriu",
    "impropriii": "impropriu",
    "impropriile": "impropriu",
    "impropriilor": "impropriu",
    "impropriul": "impropriu",
    "impropriului": "impropriu",
    "împroașcă": "împroșca",
    "împroaște": "împroșca",
    "împroșc": "împroșca",
    "împroșcă": "împroșca",
    "împroșcai": "împroșca",
    "împroșcam": "împroșca",
    "împroșcăm": "împroșca",
    "împroșcând": "împroșca",
    "împroșcându": "împroșca",
    "împroșcară": "împroșca",
    "împroșcarăm": "împroșca",
    "împroșcarăți": "împroșca",
    "împroșcase": "împroșca",
    "împroșcasem": "împroșca",
    "împroșcaseră": "împroșca",
    "împroșcaserăm": "împroșca",
    "împroșcaserăți": "împroșca",
    "împroșcaseși": "împroșca",
    "împroșcași": "împroșca",
    "împroșcat": "împroșca",
    "împroșcați": "împroșca",
    "împroșcatu": "împroșca",
    "împroșcau": "împroșca",
    "împroști": "împroșca",
    "neîmproșcând": "împroșca",
    "neîmproșcându": "împroșca",
    "nemaiîmproșcând": "împroșca",
    "nemaiîmproșcându": "împroșca",
    "împroșcată": "împroșcat",
    "împroșcate": "împroșcat",
    "împroșcați": "împroșcat",
    "împrospătă": "împrospăta",
    "împrospătai": "împrospăta",
    "împrospătam": "împrospăta",
    "împrospătăm": "împrospăta",
    "împrospătând": "împrospăta",
    "împrospătându": "împrospăta",
    "împrospătară": "împrospăta",
    "împrospătarăm": "împrospăta",
    "împrospătarăți": "împrospăta",
    "împrospătase": "împrospăta",
    "împrospătasem": "împrospăta",
    "împrospătaseră": "împrospăta",
    "împrospătaserăm": "împrospăta",
    "împrospătaserăți": "împrospăta",
    "împrospătaseși": "împrospăta",
    "împrospătași": "împrospăta",
    "împrospătat": "împrospăta",
    "împrospătați": "împrospăta",
    "împrospătatu": "împrospăta",
    "împrospătau": "împrospăta",
    "împrospătează": "împrospăta",
    "împrospătez": "împrospăta",
    "împrospăteze": "împrospăta",
    "împrospătezi": "împrospăta",
    "neîmprospătând": "împrospăta",
    "neîmprospătându": "împrospăta",
    "nemaiîmprospătând": "împrospăta",
    "nemaiîmprospătându": "împrospăta",
    "împrospătată": "împrospătat",
    "împrospătate": "împrospătat",
    "împrospătați": "împrospătat",
    "împrospătătoare": "împrospătător",
    "împrospătătoarea": "împrospătător",
    "împrospătătoarei": "împrospătător",
    "împrospătătoarele": "împrospătător",
    "împrospătătoarelor": "împrospătător",
    "împrospătătoareo": "împrospătător",
    "împrospătători": "împrospătător",
    "împrospătătorii": "împrospătător",
    "împrospătătorilor": "împrospătător",
    "împrospătătorul": "împrospătător",
    "împrospătătorule": "împrospătător",
    "împrospătătorului": "împrospătător",
    "improviză": "improviza",
    "improvizai": "improviza",
    "improvizam": "improviza",
    "improvizăm": "improviza",
    "improvizând": "improviza",
    "improvizându": "improviza",
    "improvizară": "improviza",
    "improvizarăm": "improviza",
    "improvizarăți": "improviza",
    "improvizase": "improviza",
    "improvizasem": "improviza",
    "improvizaseră": "improviza",
    "improvizaserăm": "improviza",
    "improvizaserăți": "improviza",
    "improvizaseși": "improviza",
    "improvizași": "improviza",
    "improvizat": "improviza",
    "improvizați": "improviza",
    "improvizatu": "improviza",
    "improvizau": "improviza",
    "improvizează": "improviza",
    "improvizez": "improviza",
    "improvizeze": "improviza",
    "improvizezi": "improviza",
    "neimprovizând": "improviza",
    "neimprovizându": "improviza",
    "nemaiimprovizând": "improviza",
    "nemaiimprovizându": "improviza",
    "improvizată": "improvizat",
    "improvizate": "improvizat",
    "improvizați": "improvizat",
    "improvizația": "improvizație",
    "improvizației": "improvizație",
    "improvizații": "improvizație",
    "improvizațiile": "improvizație",
    "improvizațiilor": "improvizație",
    "imprudenta": "imprudent",
    "imprudentă": "imprudent",
    "imprudente": "imprudent",
    "imprudentei": "imprudent",
    "imprudentele": "imprudent",
    "imprudentelor": "imprudent",
    "imprudenți": "imprudent",
    "imprudenții": "imprudent",
    "imprudenților": "imprudent",
    "imprudentul": "imprudent",
    "imprudentului": "imprudent",
    "imprudența": "imprudență",
    "imprudențe": "imprudență",
    "imprudenței": "imprudență",
    "imprudențele": "imprudență",
    "imprudențelor": "imprudență",
    "împrumutul": "împrumut",
    "împrumutului": "împrumut",
    "împrumuturi": "împrumut",
    "împrumuturile": "împrumut",
    "împrumuturilor": "împrumut",
    "împrumut": "împrumuta",
    "împrumută": "împrumuta",
    "împrumutai": "împrumuta",
    "împrumutam": "împrumuta",
    "împrumutăm": "împrumuta",
    "împrumutând": "împrumuta",
    "împrumutându": "împrumuta",
    "împrumutară": "împrumuta",
    "împrumutarăm": "împrumuta",
    "împrumutarăți": "împrumuta",
    "împrumutase": "împrumuta",
    "împrumutasem": "împrumuta",
    "împrumutaseră": "împrumuta",
    "împrumutaserăm": "împrumuta",
    "împrumutaserăți": "împrumuta",
    "împrumutaseși": "împrumuta",
    "împrumutași": "împrumuta",
    "împrumutat": "împrumuta",
    "împrumutați": "împrumuta",
    "împrumutatu": "împrumuta",
    "împrumutau": "împrumuta",
    "împrumute": "împrumuta",
    "împrumuți": "împrumuta",
    "neîmprumutând": "împrumuta",
    "neîmprumutându": "împrumuta",
    "nemaiîmprumutând": "împrumuta",
    "nemaiîmprumutându": "împrumuta",
    "împrumutată": "împrumutat",
    "împrumutate": "împrumutat",
    "împrumutați": "împrumutat",
    "împui": "împuia",
    "împuiai": "împuia",
    "împuiam": "împuia",
    "împuiară": "împuia",
    "împuiarăm": "împuia",
    "împuiarăți": "împuia",
    "împuiase": "împuia",
    "împuiasem": "împuia",
    "împuiaseră": "împuia",
    "împuiaserăm": "împuia",
    "împuiaserăți": "împuia",
    "împuiaseși": "împuia",
    "împuiași": "împuia",
    "împuiat": "împuia",
    "împuiați": "împuia",
    "împuiatu": "împuia",
    "împuiau": "împuia",
    "împuie": "împuia",
    "împuiem": "împuia",
    "împuind": "împuia",
    "împuindu": "împuia",
    "neîmpuiind": "împuia",
    "neîmpuiindu": "împuia",
    "nemaiîmpuiind": "împuia",
    "nemaiîmpuiindu": "împuia",
    "împuiată": "împuiat",
    "împuiate": "împuiat",
    "împuiați": "împuiat",
    "impulsul": "impuls",
    "impulsului": "impuls",
    "impulsuri": "impuls",
    "impulsurile": "impuls",
    "impulsurilor": "impuls",
    "impulsionă": "impulsiona",
    "impulsionai": "impulsiona",
    "impulsionam": "impulsiona",
    "impulsionăm": "impulsiona",
    "impulsionând": "impulsiona",
    "impulsionându": "impulsiona",
    "impulsionară": "impulsiona",
    "impulsionarăm": "impulsiona",
    "impulsionarăți": "impulsiona",
    "impulsionase": "impulsiona",
    "impulsionasem": "impulsiona",
    "impulsionaseră": "impulsiona",
    "impulsionaserăm": "impulsiona",
    "impulsionaserăți": "impulsiona",
    "impulsionaseși": "impulsiona",
    "impulsionași": "impulsiona",
    "impulsionat": "impulsiona",
    "impulsionați": "impulsiona",
    "impulsionatu": "impulsiona",
    "impulsionau": "impulsiona",
    "impulsionează": "impulsiona",
    "impulsionez": "impulsiona",
    "impulsioneze": "impulsiona",
    "impulsionezi": "impulsiona",
    "neimpulsionând": "impulsiona",
    "neimpulsionându": "impulsiona",
    "nemaiimpulsionând": "impulsiona",
    "nemaiimpulsionându": "impulsiona",
    "impulsionată": "impulsionat",
    "impulsionate": "impulsionat",
    "impulsionați": "impulsionat",
    "impulsiva": "impulsiv",
    "impulsivă": "impulsiv",
    "impulsive": "impulsiv",
    "impulsivei": "impulsiv",
    "impulsivele": "impulsiv",
    "impulsivelor": "impulsiv",
    "impulsivi": "impulsiv",
    "impulsivii": "impulsiv",
    "impulsivilor": "impulsiv",
    "impulsivul": "impulsiv",
    "impulsivului": "impulsiv",
    "impulsivitatea": "impulsivitate",
    "impulsivități": "impulsivitate",
    "impulsivității": "impulsivitate",
    "impulsivitățile": "impulsivitate",
    "impulsivităților": "impulsivitate",
    "impunătoare": "impunător",
    "impunătoarea": "impunător",
    "impunătoarei": "impunător",
    "impunătoarele": "impunător",
    "impunătoarelor": "impunător",
    "impunători": "impunător",
    "impunătorii": "impunător",
    "impunătorilor": "impunător",
    "impunătorul": "impunător",
    "impunătorului": "impunător",
    "impui": "impune",
    "impun": "impune",
    "impună": "impune",
    "impunând": "impune",
    "impunându": "impune",
    "impunea": "impune",
    "impuneai": "impune",
    "impuneam": "impune",
    "impuneați": "impune",
    "impuneau": "impune",
    "impunem": "impune",
    "impuneți": "impune",
    "impus": "impune",
    "impuse": "impune",
    "impusei": "impune",
    "impuseră": "impune",
    "impuserăm": "impune",
    "impuserăți": "impune",
    "impusese": "impune",
    "impusesem": "impune",
    "impuseseră": "impune",
    "impuseserăm": "impune",
    "impuseserăți": "impune",
    "impuseseși": "impune",
    "impuseși": "impune",
    "impusu": "impune",
    "neimpunând": "impune",
    "neimpunându": "impune",
    "nemaiimpunând": "impune",
    "nemaiimpunându": "impune",
    "impunerea": "impunere",
    "impuneri": "impunere",
    "impunerii": "impunere",
    "impunerile": "impunere",
    "impunerilor": "impunere",
    "împung": "împunge",
    "împungă": "împunge",
    "împungând": "împunge",
    "împungându": "împunge",
    "împungea": "împunge",
    "împungeai": "împunge",
    "împungeam": "împunge",
    "împungeați": "împunge",
    "împungeau": "împunge",
    "împungem": "împunge",
    "împungeți": "împunge",
    "împungi": "împunge",
    "împuns": "împunge",
    "împunse": "împunge",
    "împunsei": "împunge",
    "împunseră": "împunge",
    "împunserăm": "împunge",
    "împunserăți": "împunge",
    "împunsese": "împunge",
    "împunsesem": "împunge",
    "împunseseră": "împunge",
    "împunseserăm": "împunge",
    "împunseserăți": "împunge",
    "împunseseși": "împunge",
    "împunseși": "împunge",
    "împunsu": "împunge",
    "neîmpungând": "împunge",
    "neîmpungându": "împunge",
    "nemaiîmpungând": "împunge",
    "nemaiîmpungându": "împunge",
    "împunsă": "împuns",
    "împunse": "împuns",
    "împunși": "împuns",
    "împunsătura": "împunsătură",
    "împunsături": "împunsătură",
    "împunsăturii": "împunsătură",
    "împunsăturile": "împunsătură",
    "împunsăturilor": "împunsătură",
    "impura": "impur",
    "impură": "impur",
    "impure": "impur",
    "impurei": "impur",
    "impurele": "impur",
    "impurelor": "impur",
    "impuri": "impur",
    "impurii": "impur",
    "impurilor": "impur",
    "impurul": "impur",
    "impurului": "impur",
    "impuritatea": "impuritate",
    "impurități": "impuritate",
    "impurității": "impuritate",
    "impuritățile": "impuritate",
    "impurităților": "impuritate",
    "împurpură": "împurpura",
    "împurpurai": "împurpura",
    "împurpuram": "împurpura",
    "împurpurăm": "împurpura",
    "împurpurând": "împurpura",
    "împurpurându": "împurpura",
    "împurpurară": "împurpura",
    "împurpurarăm": "împurpura",
    "împurpurarăți": "împurpura",
    "împurpurase": "împurpura",
    "împurpurasem": "împurpura",
    "împurpuraseră": "împurpura",
    "împurpuraserăm": "împurpura",
    "împurpuraserăți": "împurpura",
    "împurpuraseși": "împurpura",
    "împurpurași": "împurpura",
    "împurpurat": "împurpura",
    "împurpurați": "împurpura",
    "împurpuratu": "împurpura",
    "împurpurau": "împurpura",
    "împurpurează": "împurpura",
    "împurpurez": "împurpura",
    "împurpureze": "împurpura",
    "împurpurezi": "împurpura",
    "neîmpurpurând": "împurpura",
    "neîmpurpurându": "împurpura",
    "nemaiîmpurpurând": "împurpura",
    "nemaiîmpurpurându": "împurpura",
    "împurpurată": "împurpurat",
    "împurpurate": "împurpurat",
    "împurpurați": "împurpurat",
    "impusă": "impus",
    "impuse": "impus",
    "impuși": "impus",
    "împușc": "împușca",
    "împușcă": "împușca",
    "împușcai": "împușca",
    "împușcam": "împușca",
    "împușcăm": "împușca",
    "împușcând": "împușca",
    "împușcându": "împușca",
    "împușcară": "împușca",
    "împușcarăm": "împușca",
    "împușcarăți": "împușca",
    "împușcase": "împușca",
    "împușcasem": "împușca",
    "împușcaseră": "împușca",
    "împușcaserăm": "împușca",
    "împușcaserăți": "împușca",
    "împușcaseși": "împușca",
    "împușcași": "împușca",
    "împușcat": "împușca",
    "împușcați": "împușca",
    "împușcatu": "împușca",
    "împușcau": "împușca",
    "împuște": "împușca",
    "împuști": "împușca",
    "neîmpușcând": "împușca",
    "neîmpușcându": "împușca",
    "nemaiîmpușcând": "împușca",
    "nemaiîmpușcându": "împușca",
    "împușcarea": "împușcare",
    "împușcareo": "împușcare",
    "împușcări": "împușcare",
    "împușcării": "împușcare",
    "împușcările": "împușcare",
    "împușcărilor": "împușcare",
    "împușcată": "împușcat",
    "împușcate": "împușcat",
    "împușcați": "împușcat",
    "împușcătura": "împușcătură",
    "împușcături": "împușcătură",
    "împușcăturii": "împușcătură",
    "împușcăturile": "împușcătură",
    "împușcăturilor": "împușcătură",
    "imput": "imputa",
    "impută": "imputa",
    "imputai": "imputa",
    "imputam": "imputa",
    "imputăm": "imputa",
    "imputând": "imputa",
    "imputându": "imputa",
    "imputară": "imputa",
    "imputarăm": "imputa",
    "imputarăți": "imputa",
    "imputase": "imputa",
    "imputasem": "imputa",
    "imputaseră": "imputa",
    "imputaserăm": "imputa",
    "imputaserăți": "imputa",
    "imputaseși": "imputa",
    "imputași": "imputa",
    "imputat": "imputa",
    "imputați": "imputa",
    "imputatu": "imputa",
    "imputau": "imputa",
    "impute": "imputa",
    "impuți": "imputa",
    "neimputând": "imputa",
    "neimputându": "imputa",
    "nemaiimputând": "imputa",
    "nemaiimputându": "imputa",
    "imputarea": "imputare",
    "imputări": "imputare",
    "imputării": "imputare",
    "imputările": "imputare",
    "imputărilor": "imputare",
    "imputată": "imputat",
    "imputate": "imputat",
    "imputați": "imputat",
    "împuternicea": "împuternici",
    "împuterniceai": "împuternici",
    "împuterniceam": "împuternici",
    "împuternicească": "împuternici",
    "împuterniceați": "împuternici",
    "împuterniceau": "împuternici",
    "împuternicesc": "împuternici",
    "împuternicește": "împuternici",
    "împuternicești": "împuternici",
    "împuternicii": "împuternici",
    "împuternicim": "împuternici",
    "împuternicind": "împuternici",
    "împuternicindu": "împuternici",
    "împuterniciră": "împuternici",
    "împuternicirăm": "împuternici",
    "împuternicirăți": "împuternici",
    "împuternicise": "împuternici",
    "împuternicisem": "împuternici",
    "împuterniciseră": "împuternici",
    "împuterniciserăm": "împuternici",
    "împuterniciserăți": "împuternici",
    "împuterniciseși": "împuternici",
    "împuterniciși": "împuternici",
    "împuternicit": "împuternici",
    "împuterniciți": "împuternici",
    "împuternicitu": "împuternici",
    "neîmputernicind": "împuternici",
    "neîmputernicindu": "împuternici",
    "nemaiîmputernicind": "împuternici",
    "nemaiîmputernicindu": "împuternici",
    "împuternicirea": "împuternicire",
    "împuternicireo": "împuternicire",
    "împuterniciri": "împuternicire",
    "împuternicirii": "împuternicire",
    "împuternicirile": "împuternicire",
    "împuternicirilor": "împuternicire",
    "împuternicita": "împuternicit",
    "împuternicită": "împuternicit",
    "împuternicite": "împuternicit",
    "împuternicitei": "împuternicit",
    "împuternicitele": "împuternicit",
    "împuternicitelor": "împuternicit",
    "împuterniciți": "împuternicit",
    "împuterniciții": "împuternicit",
    "împuterniciților": "împuternicit",
    "împuternicito": "împuternicit",
    "împuternicitul": "împuternicit",
    "împuternicitule": "împuternicit",
    "împuternicitului": "împuternicit",
    "împut": "împuți",
    "împută": "împuți",
    "împute": "împuți",
    "împuțea": "împuți",
    "împuțeai": "împuți",
    "împuțeam": "împuți",
    "împuțeați": "împuți",
    "împuțeau": "împuți",
    "împuții": "împuți",
    "împuțim": "împuți",
    "împuțind": "împuți",
    "împuțindu": "împuți",
    "împuțiră": "împuți",
    "împuțirăm": "împuți",
    "împuțirăți": "împuți",
    "împuțise": "împuți",
    "împuțisem": "împuți",
    "împuțiseră": "împuți",
    "împuțiserăm": "împuți",
    "împuțiserăți": "împuți",
    "împuțiseși": "împuți",
    "împuțiși": "împuți",
    "împuțit": "împuți",
    "împuțiți": "împuți",
    "împuțitu": "împuți",
    "neîmpuțind": "împuți",
    "neîmpuțindu": "împuți",
    "nemaiîmpuțind": "împuți",
    "nemaiîmpuțindu": "împuți",
    "împuțină": "împuțina",
    "împuținai": "împuțina",
    "împuținam": "împuțina",
    "împuținăm": "împuțina",
    "împuținând": "împuțina",
    "împuținându": "împuțina",
    "împuținară": "împuțina",
    "împuținarăm": "împuțina",
    "împuținarăți": "împuțina",
    "împuținase": "împuțina",
    "împuținasem": "împuțina",
    "împuținaseră": "împuțina",
    "împuținaserăm": "împuțina",
    "împuținaserăți": "împuțina",
    "împuținaseși": "împuțina",
    "împuținași": "împuțina",
    "împuținat": "împuțina",
    "împuținați": "împuțina",
    "împuținatu": "împuțina",
    "împuținau": "împuțina",
    "împuținează": "împuțina",
    "împuținez": "împuțina",
    "împuțineze": "împuțina",
    "împuținezi": "împuțina",
    "neîmpuținând": "împuțina",
    "neîmpuținându": "împuțina",
    "nemaiîmpuținând": "împuțina",
    "nemaiîmpuținându": "împuțina",
    "împuținată": "împuținat",
    "împuținate": "împuținat",
    "împuținați": "împuținat",
    "împuțita": "împuțit",
    "împuțită": "împuțit",
    "împuțite": "împuțit",
    "împuțitei": "împuțit",
    "împuțitele": "împuțit",
    "împuțitelor": "împuțit",
    "împuțiți": "împuțit",
    "împuțiții": "împuțit",
    "împuțiților": "împuțit",
    "împuțitul": "împuțit",
    "împuțitului": "împuțit",
    "imuabila": "imuabil",
    "imuabilă": "imuabil",
    "imuabile": "imuabil",
    "imuabilei": "imuabil",
    "imuabilele": "imuabil",
    "imuabilelor": "imuabil",
    "imuabili": "imuabil",
    "imuabilii": "imuabil",
    "imuabililor": "imuabil",
    "imuabilul": "imuabil",
    "imuabilului": "imuabil",
    "imuna": "imun",
    "imună": "imun",
    "imune": "imun",
    "imunei": "imun",
    "imunele": "imun",
    "imunelor": "imun",
    "imuni": "imun",
    "imunii": "imun",
    "imunilor": "imun",
    "imunul": "imun",
    "imunului": "imun",
    "imunda": "imund",
    "imundă": "imund",
    "imunde": "imund",
    "imundei": "imund",
    "imundele": "imund",
    "imundelor": "imund",
    "imundo": "imund",
    "imundul": "imund",
    "imundule": "imund",
    "imundului": "imund",
    "imunzi": "imund",
    "imunzii": "imund",
    "imunzilor": "imund",
    "imunitatea": "imunitate",
    "imunități": "imunitate",
    "imunității": "imunitate",
    "imuniză": "imuniza",
    "imunizai": "imuniza",
    "imunizam": "imuniza",
    "imunizăm": "imuniza",
    "imunizând": "imuniza",
    "imunizându": "imuniza",
    "imunizară": "imuniza",
    "imunizarăm": "imuniza",
    "imunizarăți": "imuniza",
    "imunizase": "imuniza",
    "imunizasem": "imuniza",
    "imunizaseră": "imuniza",
    "imunizaserăm": "imuniza",
    "imunizaserăți": "imuniza",
    "imunizaseși": "imuniza",
    "imunizași": "imuniza",
    "imunizat": "imuniza",
    "imunizați": "imuniza",
    "imunizatu": "imuniza",
    "imunizau": "imuniza",
    "imunizează": "imuniza",
    "imunizez": "imuniza",
    "imunizeze": "imuniza",
    "imunizezi": "imuniza",
    "neimunizând": "imuniza",
    "neimunizându": "imuniza",
    "nemaiimunizând": "imuniza",
    "nemaiimunizându": "imuniza",
    "imunizată": "imunizat",
    "imunizate": "imunizat",
    "imunizați": "imunizat",
    "inul": "in",
    "inului": "in",
    "inuri": "in",
    "inurile": "in",
    "inurilor": "in",
    "inabordabila": "inabordabil",
    "inabordabilă": "inabordabil",
    "inabordabile": "inabordabil",
    "inabordabilei": "inabordabil",
    "inabordabilele": "inabordabil",
    "inabordabilelor": "inabordabil",
    "inabordabili": "inabordabil",
    "inabordabilii": "inabordabil",
    "inabordabililor": "inabordabil",
    "inabordabilul": "inabordabil",
    "inabordabilului": "inabordabil",
    "înăbuș": "înăbuși",
    "înăbușă": "înăbuși",
    "înăbușe": "înăbuși",
    "înăbușea": "înăbuși",
    "înăbușeai": "înăbuși",
    "înăbușeam": "înăbuși",
    "înăbușeați": "înăbuși",
    "înăbușeau": "înăbuși",
    "înăbușii": "înăbuși",
    "înăbușim": "înăbuși",
    "înăbușind": "înăbuși",
    "înăbușindu": "înăbuși",
    "înăbușiră": "înăbuși",
    "înăbușirăm": "înăbuși",
    "înăbușirăți": "înăbuși",
    "înăbușise": "înăbuși",
    "înăbușisem": "înăbuși",
    "înăbușiseră": "înăbuși",
    "înăbușiserăm": "înăbuși",
    "înăbușiserăți": "înăbuși",
    "înăbușiseși": "înăbuși",
    "înăbușiși": "înăbuși",
    "înăbușit": "înăbuși",
    "înăbușiți": "înăbuși",
    "înăbușitu": "înăbuși",
    "neînăbușind": "înăbuși",
    "neînăbușindu": "înăbuși",
    "nemaiînăbușind": "înăbuși",
    "nemaiînăbușindu": "înăbuși",
    "înăbușirea": "înăbușire",
    "înăbușiri": "înăbușire",
    "înăbușirii": "înăbușire",
    "înăbușirile": "înăbușire",
    "înăbușirilor": "înăbușire",
    "înăbușită": "înăbușit",
    "înăbușite": "înăbușit",
    "înăbușiți": "înăbușit",
    "înăbușitoare": "înăbușitor",
    "înăbușitoarea": "înăbușitor",
    "înăbușitoarei": "înăbușitor",
    "înăbușitoarele": "înăbușitor",
    "înăbușitoarelor": "înăbușitor",
    "înăbușitori": "înăbușitor",
    "înăbușitorii": "înăbușitor",
    "înăbușitorilor": "înăbușitor",
    "înăbușitorul": "înăbușitor",
    "înăbușitorului": "înăbușitor",
    "inacceptabila": "inacceptabil",
    "inacceptabilă": "inacceptabil",
    "inacceptabile": "inacceptabil",
    "inacceptabilei": "inacceptabil",
    "inacceptabilele": "inacceptabil",
    "inacceptabilelor": "inacceptabil",
    "inacceptabili": "inacceptabil",
    "inacceptabilii": "inacceptabil",
    "inacceptabililor": "inacceptabil",
    "inacceptabilul": "inacceptabil",
    "inacceptabilului": "inacceptabil",
    "inaccesibila": "inaccesibil",
    "inaccesibilă": "inaccesibil",
    "inaccesibile": "inaccesibil",
    "inaccesibilei": "inaccesibil",
    "inaccesibilele": "inaccesibil",
    "inaccesibilelor": "inaccesibil",
    "inaccesibili": "inaccesibil",
    "inaccesibilii": "inaccesibil",
    "inaccesibililor": "inaccesibil",
    "inaccesibilul": "inaccesibil",
    "inaccesibilului": "inaccesibil",
    "înăclăia": "înăclăi",
    "înăclăiai": "înăclăi",
    "înăclăiam": "înăclăi",
    "înăclăiască": "înăclăi",
    "înăclăiați": "înăclăi",
    "înăclăiau": "înăclăi",
    "înăclăiesc": "înăclăi",
    "înăclăiește": "înăclăi",
    "înăclăiești": "înăclăi",
    "înăclăii": "înăclăi",
    "înăclăim": "înăclăi",
    "înăclăind": "înăclăi",
    "înăclăindu": "înăclăi",
    "înăclăiră": "înăclăi",
    "înăclăirăm": "înăclăi",
    "înăclăirăți": "înăclăi",
    "înăclăise": "înăclăi",
    "înăclăisem": "înăclăi",
    "înăclăiseră": "înăclăi",
    "înăclăiserăm": "înăclăi",
    "înăclăiserăți": "înăclăi",
    "înăclăiseși": "înăclăi",
    "înăclăiși": "înăclăi",
    "înăclăit": "înăclăi",
    "înăclăiți": "înăclăi",
    "înăclăitu": "înăclăi",
    "neînăclăind": "înăclăi",
    "neînăclăindu": "înăclăi",
    "nemaiînăclăind": "înăclăi",
    "nemaiînăclăindu": "înăclăi",
    "înăclăită": "înăclăit",
    "înăclăite": "înăclăit",
    "înăclăiți": "înăclăit",
    "înăcrea": "înăcri",
    "înăcreai": "înăcri",
    "înăcream": "înăcri",
    "înăcrească": "înăcri",
    "înăcreați": "înăcri",
    "înăcreau": "înăcri",
    "înăcresc": "înăcri",
    "înăcrește": "înăcri",
    "înăcrești": "înăcri",
    "înăcrii": "înăcri",
    "înăcrim": "înăcri",
    "înăcrind": "înăcri",
    "înăcrindu": "înăcri",
    "înăcriră": "înăcri",
    "înăcrirăm": "înăcri",
    "înăcrirăți": "înăcri",
    "înăcrise": "înăcri",
    "înăcrisem": "înăcri",
    "înăcriseră": "înăcri",
    "înăcriserăm": "înăcri",
    "înăcriserăți": "înăcri",
    "înăcriseși": "înăcri",
    "înăcriși": "înăcri",
    "înăcrit": "înăcri",
    "înăcriți": "înăcri",
    "înăcritu": "înăcri",
    "neînăcrind": "înăcri",
    "neînăcrindu": "înăcri",
    "nemaiînăcrind": "înăcri",
    "nemaiînăcrindu": "înăcri",
    "înăcrită": "înăcrit",
    "înăcrite": "înăcrit",
    "înăcriți": "înăcrit",
    "inactiva": "inactiv",
    "inactivă": "inactiv",
    "inactive": "inactiv",
    "inactivei": "inactiv",
    "inactivele": "inactiv",
    "inactivelor": "inactiv",
    "inactivi": "inactiv",
    "inactivii": "inactiv",
    "inactivilor": "inactiv",
    "inactivul": "inactiv",
    "inactivului": "inactiv",
    "inactivitatea": "inactivitate",
    "inactivități": "inactivitate",
    "inactivității": "inactivitate",
    "inadaptabila": "inadaptabil",
    "inadaptabilă": "inadaptabil",
    "inadaptabile": "inadaptabil",
    "inadaptabilei": "inadaptabil",
    "inadaptabilele": "inadaptabil",
    "inadaptabilelor": "inadaptabil",
    "inadaptabili": "inadaptabil",
    "inadaptabilii": "inadaptabil",
    "inadaptabililor": "inadaptabil",
    "inadaptabilul": "inadaptabil",
    "inadaptabilului": "inadaptabil",
    "inadecvata": "inadecvat",
    "inadecvată": "inadecvat",
    "inadecvate": "inadecvat",
    "inadecvatei": "inadecvat",
    "inadecvatele": "inadecvat",
    "inadecvatelor": "inadecvat",
    "inadecvați": "inadecvat",
    "inadecvații": "inadecvat",
    "inadecvaților": "inadecvat",
    "inadecvatul": "inadecvat",
    "inadecvatului": "inadecvat",
    "inadmisibila": "inadmisibil",
    "inadmisibilă": "inadmisibil",
    "inadmisibile": "inadmisibil",
    "inadmisibilei": "inadmisibil",
    "inadmisibilele": "inadmisibil",
    "inadmisibilelor": "inadmisibil",
    "inadmisibili": "inadmisibil",
    "inadmisibilii": "inadmisibil",
    "inadmisibililor": "inadmisibil",
    "inadmisibilul": "inadmisibil",
    "inadmisibilului": "inadmisibil",
    "înădușea": "înăduși",
    "înădușeai": "înăduși",
    "înădușeam": "înăduși",
    "înădușească": "înăduși",
    "înădușeați": "înăduși",
    "înădușeau": "înăduși",
    "înădușesc": "înăduși",
    "înădușește": "înăduși",
    "înădușești": "înăduși",
    "înădușii": "înăduși",
    "înădușim": "înăduși",
    "înădușind": "înăduși",
    "înădușindu": "înăduși",
    "înădușiră": "înăduși",
    "înădușirăm": "înăduși",
    "înădușirăți": "înăduși",
    "înădușise": "înăduși",
    "înădușisem": "înăduși",
    "înădușiseră": "înăduși",
    "înădușiserăm": "înăduși",
    "înădușiserăți": "înăduși",
    "înădușiseși": "înăduși",
    "înădușiși": "înăduși",
    "înădușit": "înăduși",
    "înădușiți": "înăduși",
    "înădușitu": "înăduși",
    "neînădușind": "înăduși",
    "neînădușindu": "înăduși",
    "nemaiînădușind": "înăduși",
    "nemaiînădușindu": "înăduși",
    "înădușită": "înădușit",
    "înădușite": "înădușit",
    "înădușiți": "înădușit",
    "inadvertența": "inadvertență",
    "inadvertențe": "inadvertență",
    "inadvertenței": "inadvertență",
    "inadvertențele": "inadvertență",
    "inadvertențelor": "inadvertență",
    "înaintă": "înainta",
    "înaintai": "înainta",
    "înaintam": "înainta",
    "înaintăm": "înainta",
    "înaintând": "înainta",
    "înaintându": "înainta",
    "înaintară": "înainta",
    "înaintarăm": "înainta",
    "înaintarăți": "înainta",
    "înaintase": "înainta",
    "înaintasem": "înainta",
    "înaintaseră": "înainta",
    "înaintaserăm": "înainta",
    "înaintaserăți": "înainta",
    "înaintaseși": "înainta",
    "înaintași": "înainta",
    "înaintat": "înainta",
    "înaintați": "înainta",
    "înaintatu": "înainta",
    "înaintau": "înainta",
    "înaintează": "înainta",
    "înaintez": "înainta",
    "înainteze": "înainta",
    "înaintezi": "înainta",
    "neînaintând": "înainta",
    "neînaintându": "înainta",
    "nemaiînaintând": "înainta",
    "nemaiînaintându": "înainta",
    "înaintarea": "înaintare",
    "înaintări": "înaintare",
    "înaintării": "înaintare",
    "înaintările": "înaintare",
    "înaintărilor": "înaintare",
    "înaintașa": "înaintaș",
    "înaintașă": "înaintaș",
    "înaintașe": "înaintaș",
    "înaintașei": "înaintaș",
    "înaintașele": "înaintaș",
    "înaintașelor": "înaintaș",
    "înaintași": "înaintaș",
    "înaintașii": "înaintaș",
    "înaintașilor": "înaintaș",
    "înaintașo": "înaintaș",
    "înaintașul": "înaintaș",
    "înaintașule": "înaintaș",
    "înaintașului": "înaintaș",
    "înaintata": "înaintat",
    "înaintată": "înaintat",
    "înaintate": "înaintat",
    "înaintatei": "înaintat",
    "înaintatele": "înaintat",
    "înaintatelor": "înaintat",
    "înaintați": "înaintat",
    "înaintații": "înaintat",
    "înaintaților": "înaintat",
    "înaintatul": "înaintat",
    "înaintatului": "înaintat",
    "î.e.n.": "înaintea_erei_noastre",
    "î.Cr.": "înaite_de_Cristos",
    "înălbăstrea": "înălbăstri",
    "înălbăstreai": "înălbăstri",
    "înălbăstream": "înălbăstri",
    "înălbăstrească": "înălbăstri",
    "înălbăstreați": "înălbăstri",
    "înălbăstreau": "înălbăstri",
    "înălbăstresc": "înălbăstri",
    "înălbăstrește": "înălbăstri",
    "înălbăstrești": "înălbăstri",
    "înălbăstrii": "înălbăstri",
    "înălbăstrim": "înălbăstri",
    "înălbăstrind": "înălbăstri",
    "înălbăstrindu": "înălbăstri",
    "înălbăstriră": "înălbăstri",
    "înălbăstrirăm": "înălbăstri",
    "înălbăstrirăți": "înălbăstri",
    "înălbăstrise": "înălbăstri",
    "înălbăstrisem": "înălbăstri",
    "înălbăstriseră": "înălbăstri",
    "înălbăstriserăm": "înălbăstri",
    "înălbăstriserăți": "înălbăstri",
    "înălbăstriseși": "înălbăstri",
    "înălbăstriși": "înălbăstri",
    "înălbăstrit": "înălbăstri",
    "înălbăstriți": "înălbăstri",
    "înălbăstritu": "înălbăstri",
    "neînălbăstrind": "înălbăstri",
    "neînălbăstrindu": "înălbăstri",
    "nemaiînălbăstrind": "înălbăstri",
    "nemaiînălbăstrindu": "înălbăstri",
    "înălbăstrită": "înălbăstrit",
    "înălbăstrite": "înălbăstrit",
    "înălbăstriți": "înălbăstrit",
    "înălbea": "înălbi",
    "înălbeai": "înălbi",
    "înălbeam": "înălbi",
    "înălbească": "înălbi",
    "înălbeați": "înălbi",
    "înălbeau": "înălbi",
    "înălbesc": "înălbi",
    "înălbește": "înălbi",
    "înălbești": "înălbi",
    "înălbii": "înălbi",
    "înălbim": "înălbi",
    "înălbind": "înălbi",
    "înălbindu": "înălbi",
    "înălbiră": "înălbi",
    "înălbirăm": "înălbi",
    "înălbirăți": "înălbi",
    "înălbise": "înălbi",
    "înălbisem": "înălbi",
    "înălbiseră": "înălbi",
    "înălbiserăm": "înălbi",
    "înălbiserăți": "înălbi",
    "înălbiseși": "înălbi",
    "înălbiși": "înălbi",
    "înălbit": "înălbi",
    "înălbiți": "înălbi",
    "înălbitu": "înălbi",
    "neînălbind": "înălbi",
    "neînălbindu": "înălbi",
    "nemaiînălbind": "înălbi",
    "nemaiînălbindu": "înălbi",
    "înălbită": "înălbit",
    "înălbite": "înălbit",
    "înălbiți": "înălbit",
    "inalienabila": "inalienabil",
    "inalienabilă": "inalienabil",
    "inalienabile": "inalienabil",
    "inalienabilei": "inalienabil",
    "inalienabilele": "inalienabil",
    "inalienabilelor": "inalienabil",
    "inalienabili": "inalienabil",
    "inalienabilii": "inalienabil",
    "inalienabililor": "inalienabil",
    "inalienabilul": "inalienabil",
    "inalienabilului": "inalienabil",
    "înalta": "înalt",
    "înaltă": "înalt",
    "înalte": "înalt",
    "înaltei": "înalt",
    "înaltele": "înalt",
    "înaltelor": "înalt",
    "înalți": "înalt",
    "înalții": "înalt",
    "înalților": "înalt",
    "înaltul": "înalt",
    "înaltului": "înalt",
    "înalț": "înălța",
    "înalță": "înălța",
    "înălță": "înălța",
    "înălțai": "înălța",
    "înălțam": "înălța",
    "înălțăm": "înălța",
    "înălțând": "înălța",
    "înălțându": "înălța",
    "înălțară": "înălța",
    "înălțarăm": "înălța",
    "înălțarăți": "înălța",
    "înălțase": "înălța",
    "înălțasem": "înălța",
    "înălțaseră": "înălța",
    "înălțaserăm": "înălța",
    "înălțaserăți": "înălța",
    "înălțaseși": "înălța",
    "înălțași": "înălța",
    "înălțat": "înălța",
    "înălțați": "înălța",
    "înălțatu": "înălța",
    "înălțau": "înălța",
    "înalțe": "înălța",
    "înalți": "înălța",
    "neînălțând": "înălța",
    "neînălțându": "înălța",
    "nemaiînălțând": "înălța",
    "nemaiînălțându": "înălța",
    "înălțarea": "înălțare",
    "înălțareo": "înălțare",
    "înălțări": "înălțare",
    "înălțării": "înălțare",
    "înălțările": "înălțare",
    "înălțărilor": "înălțare",
    "înălțată": "înălțat",
    "înălțate": "înălțat",
    "înălțați": "înălțat",
    "înălțătoare": "înălțător",
    "înălțătoarea": "înălțător",
    "înălțătoarei": "înălțător",
    "înălțătoarele": "înălțător",
    "înălțătoarelor": "înălțător",
    "înălțătoareo": "înălțător",
    "înălțători": "înălțător",
    "înălțătorii": "înălțător",
    "înălțătorilor": "înălțător",
    "înălțătorul": "înălțător",
    "înălțătorule": "înălțător",
    "înălțătorului": "înălțător",
    "înălțimea": "înălțime",
    "înălțimi": "înălțime",
    "înălțimii": "înălțime",
    "înălțimile": "înălțime",
    "înălțimilor": "înălțime",
    "I.C.A.": "înaltul_Comandament_Aliat",
    "inamica": "inamic",
    "inamică": "inamic",
    "inamice": "inamic",
    "inamicei": "inamic",
    "inamicele": "inamic",
    "inamicelor": "inamic",
    "inamici": "inamic",
    "inamicii": "inamic",
    "inamicilor": "inamic",
    "inamicul": "inamic",
    "inamicului": "inamic",
    "înamoră": "înamora",
    "înamorai": "înamora",
    "înamoram": "înamora",
    "înamorăm": "înamora",
    "înamorând": "înamora",
    "înamorându": "înamora",
    "înamorară": "înamora",
    "înamorarăm": "înamora",
    "înamorarăți": "înamora",
    "înamorase": "înamora",
    "înamorasem": "înamora",
    "înamoraseră": "înamora",
    "înamoraserăm": "înamora",
    "înamoraserăți": "înamora",
    "înamoraseși": "înamora",
    "înamorași": "înamora",
    "înamorat": "înamora",
    "înamorați": "înamora",
    "înamoratu": "înamora",
    "înamorau": "înamora",
    "înamorează": "înamora",
    "înamorez": "înamora",
    "înamoreze": "înamora",
    "înamorezi": "înamora",
    "neînamorând": "înamora",
    "neînamorându": "înamora",
    "nemaiînamorând": "înamora",
    "nemaiînamorându": "înamora",
    "înamorată": "înamorat",
    "înamorate": "înamorat",
    "înamorați": "înamorat",
    "inaniția": "inaniție",
    "inaniției": "inaniție",
    "inaniții": "inaniție",
    "inanițiile": "inaniție",
    "inanițiilor": "inaniție",
    "inanițio": "inaniție",
    "inapetența": "inapetență",
    "inapetențe": "inapetență",
    "inapetenței": "inapetență",
    "inapetențele": "inapetență",
    "inapetențelor": "inapetență",
    "inapetențo": "inapetență",
    "inaplicabila": "inaplicabil",
    "inaplicabilă": "inaplicabil",
    "inaplicabile": "inaplicabil",
    "inaplicabilei": "inaplicabil",
    "inaplicabilele": "inaplicabil",
    "inaplicabilelor": "inaplicabil",
    "inaplicabili": "inaplicabil",
    "inaplicabilii": "inaplicabil",
    "inaplicabililor": "inaplicabil",
    "inaplicabilul": "inaplicabil",
    "inaplicabilului": "inaplicabil",
    "înapoiă": "înapoia",
    "înapoiai": "înapoia",
    "înapoiam": "înapoia",
    "înapoiară": "înapoia",
    "înapoiarăm": "înapoia",
    "înapoiarăți": "înapoia",
    "înapoiase": "înapoia",
    "înapoiasem": "înapoia",
    "înapoiaseră": "înapoia",
    "înapoiaserăm": "înapoia",
    "înapoiaserăți": "înapoia",
    "înapoiaseși": "înapoia",
    "înapoiași": "înapoia",
    "înapoiat": "înapoia",
    "înapoiați": "înapoia",
    "înapoiatu": "înapoia",
    "înapoiau": "înapoia",
    "înapoiază": "înapoia",
    "înapoiem": "înapoia",
    "înapoiez": "înapoia",
    "înapoieze": "înapoia",
    "înapoiezi": "înapoia",
    "înapoind": "înapoia",
    "înapoindu": "înapoia",
    "neînapoiând": "înapoia",
    "neînapoiându": "înapoia",
    "nemaiînapoiând": "înapoia",
    "nemaiînapoiându": "înapoia",
    "înapoiata": "înapoiat",
    "înapoiată": "înapoiat",
    "înapoiate": "înapoiat",
    "înapoiatei": "înapoiat",
    "înapoiatele": "înapoiat",
    "înapoiatelor": "înapoiat",
    "înapoiați": "înapoiat",
    "înapoiații": "înapoiat",
    "înapoiaților": "înapoiat",
    "înapoiatul": "înapoiat",
    "înapoiatului": "înapoiat",
    "înapoierea": "înapoiere",
    "înapoieri": "înapoiere",
    "înapoierii": "înapoiere",
    "înapoierile": "înapoiere",
    "înapoierilor": "înapoiere",
    "inapta": "inapt",
    "inaptă": "inapt",
    "inapte": "inapt",
    "inaptei": "inapt",
    "inaptele": "inapt",
    "inaptelor": "inapt",
    "inapți": "inapt",
    "inapții": "inapt",
    "inapților": "inapt",
    "inaptul": "inapt",
    "inaptului": "inapt",
    "înaripă": "înaripa",
    "înaripai": "înaripa",
    "înaripam": "înaripa",
    "înaripăm": "înaripa",
    "înaripând": "înaripa",
    "înaripându": "înaripa",
    "înaripară": "înaripa",
    "înariparăm": "înaripa",
    "înariparăți": "înaripa",
    "înaripase": "înaripa",
    "înaripasem": "înaripa",
    "înaripaseră": "înaripa",
    "înaripaserăm": "înaripa",
    "înaripaserăți": "înaripa",
    "înaripaseși": "înaripa",
    "înaripași": "înaripa",
    "înaripat": "înaripa",
    "înaripați": "înaripa",
    "înaripatu": "înaripa",
    "înaripau": "înaripa",
    "înaripează": "înaripa",
    "înaripez": "înaripa",
    "înaripeze": "înaripa",
    "înaripezi": "înaripa",
    "neînaripând": "înaripa",
    "neînaripându": "înaripa",
    "nemaiînaripând": "înaripa",
    "nemaiînaripându": "înaripa",
    "înariparea": "înaripare",
    "înaripareo": "înaripare",
    "înaripări": "înaripare",
    "înaripării": "înaripare",
    "înaripările": "înaripare",
    "înaripărilor": "înaripare",
    "înaripata": "înaripat",
    "înaripată": "înaripat",
    "înaripate": "înaripat",
    "înaripatei": "înaripat",
    "înaripatele": "înaripat",
    "înaripatelor": "înaripat",
    "înaripați": "înaripat",
    "înaripații": "înaripat",
    "înaripaților": "înaripat",
    "înaripato": "înaripat",
    "înaripatul": "înaripat",
    "înaripatule": "înaripat",
    "înaripatului": "înaripat",
    "înarmă": "înarma",
    "înarmai": "înarma",
    "înarmam": "înarma",
    "înarmăm": "înarma",
    "înarmând": "înarma",
    "înarmându": "înarma",
    "înarmară": "înarma",
    "înarmarăm": "înarma",
    "înarmarăți": "înarma",
    "înarmase": "înarma",
    "înarmasem": "înarma",
    "înarmaseră": "înarma",
    "înarmaserăm": "înarma",
    "înarmaserăți": "înarma",
    "înarmaseși": "înarma",
    "înarmași": "înarma",
    "înarmat": "înarma",
    "înarmați": "înarma",
    "înarmatu": "înarma",
    "înarmau": "înarma",
    "înarmează": "înarma",
    "înarmez": "înarma",
    "înarmeze": "înarma",
    "înarmezi": "înarma",
    "neînarmând": "înarma",
    "neînarmându": "înarma",
    "nemaiînarmând": "înarma",
    "nemaiînarmându": "înarma",
    "înarmarea": "înarmare",
    "înarmări": "înarmare",
    "înarmării": "înarmare",
    "înarmările": "înarmare",
    "înarmărilor": "înarmare",
    "înarmată": "înarmat",
    "înarmate": "înarmat",
    "înarmați": "înarmat",
    "înăsprea": "înăspri",
    "înăspreai": "înăspri",
    "înăspream": "înăspri",
    "înăsprească": "înăspri",
    "înăspreați": "înăspri",
    "înăspreau": "înăspri",
    "înăspresc": "înăspri",
    "înăsprește": "înăspri",
    "înăsprești": "înăspri",
    "înăsprii": "înăspri",
    "înăsprim": "înăspri",
    "înăsprind": "înăspri",
    "înăsprindu": "înăspri",
    "înăspriră": "înăspri",
    "înăsprirăm": "înăspri",
    "înăsprirăți": "înăspri",
    "înăsprise": "înăspri",
    "înăsprisem": "înăspri",
    "înăspriseră": "înăspri",
    "înăspriserăm": "înăspri",
    "înăspriserăți": "înăspri",
    "înăspriseși": "înăspri",
    "înăspriși": "înăspri",
    "înăsprit": "înăspri",
    "înăspriți": "înăspri",
    "înăspritu": "înăspri",
    "neînăsprind": "înăspri",
    "neînăsprindu": "înăspri",
    "nemaiînăsprind": "înăspri",
    "nemaiînăsprindu": "înăspri",
    "înăsprirea": "înăsprire",
    "înăspriri": "înăsprire",
    "înăspririi": "înăsprire",
    "înăspririle": "înăsprire",
    "înăspririlor": "înăsprire",
    "înăsprită": "înăsprit",
    "înăsprite": "înăsprit",
    "înăspriți": "înăsprit",
    "inaugură": "inaugura",
    "inaugurai": "inaugura",
    "inauguram": "inaugura",
    "inaugurăm": "inaugura",
    "inaugurând": "inaugura",
    "inaugurându": "inaugura",
    "inaugurară": "inaugura",
    "inaugurarăm": "inaugura",
    "inaugurarăți": "inaugura",
    "inaugurase": "inaugura",
    "inaugurasem": "inaugura",
    "inauguraseră": "inaugura",
    "inauguraserăm": "inaugura",
    "inauguraserăți": "inaugura",
    "inauguraseși": "inaugura",
    "inaugurași": "inaugura",
    "inaugurat": "inaugura",
    "inaugurați": "inaugura",
    "inauguratu": "inaugura",
    "inaugurau": "inaugura",
    "inaugurează": "inaugura",
    "inaugurez": "inaugura",
    "inaugureze": "inaugura",
    "inaugurezi": "inaugura",
    "neinaugurând": "inaugura",
    "neinaugurându": "inaugura",
    "nemaiinaugurând": "inaugura",
    "nemaiinaugurându": "inaugura",
    "inaugurala": "inaugural",
    "inaugurală": "inaugural",
    "inaugurale": "inaugural",
    "inauguralei": "inaugural",
    "inauguralele": "inaugural",
    "inauguralelor": "inaugural",
    "inaugurali": "inaugural",
    "inauguralii": "inaugural",
    "inauguralilor": "inaugural",
    "inauguralo": "inaugural",
    "inauguralul": "inaugural",
    "inauguralule": "inaugural",
    "inauguralului": "inaugural",
    "inaugurarea": "inaugurare",
    "inaugurări": "inaugurare",
    "inaugurării": "inaugurare",
    "inaugurările": "inaugurare",
    "inaugurărilor": "inaugurare",
    "inaugurată": "inaugurat",
    "inaugurate": "inaugurat",
    "inaugurați": "inaugurat",
    "înavuțea": "înavuți",
    "înavuțeai": "înavuți",
    "înavuțeam": "înavuți",
    "înavuțească": "înavuți",
    "înavuțeați": "înavuți",
    "înavuțeau": "înavuți",
    "înavuțesc": "înavuți",
    "înavuțește": "înavuți",
    "înavuțești": "înavuți",
    "înavuții": "înavuți",
    "înavuțim": "înavuți",
    "înavuțind": "înavuți",
    "înavuțindu": "înavuți",
    "înavuțiră": "înavuți",
    "înavuțirăm": "înavuți",
    "înavuțirăți": "înavuți",
    "înavuțise": "înavuți",
    "înavuțisem": "înavuți",
    "înavuțiseră": "înavuți",
    "înavuțiserăm": "înavuți",
    "înavuțiserăți": "înavuți",
    "înavuțiseși": "înavuți",
    "înavuțiși": "înavuți",
    "înavuțit": "înavuți",
    "înavuțiți": "înavuți",
    "înavuțitu": "înavuți",
    "neînavuțind": "înavuți",
    "neînavuțindu": "înavuți",
    "nemaiînavuțind": "înavuți",
    "nemaiînavuțindu": "înavuți",
    "înavuțită": "înavuțit",
    "înavuțite": "înavuțit",
    "înavuțiți": "înavuțit",
    "încadră": "încadra",
    "încadrai": "încadra",
    "încadram": "încadra",
    "încadrăm": "încadra",
    "încadrând": "încadra",
    "încadrându": "încadra",
    "încadrară": "încadra",
    "încadrarăm": "încadra",
    "încadrarăți": "încadra",
    "încadrase": "încadra",
    "încadrasem": "încadra",
    "încadraseră": "încadra",
    "încadraserăm": "încadra",
    "încadraserăți": "încadra",
    "încadraseși": "încadra",
    "încadrași": "încadra",
    "încadrat": "încadra",
    "încadrați": "încadra",
    "încadratu": "încadra",
    "încadrau": "încadra",
    "încadrează": "încadra",
    "încadrez": "încadra",
    "încadreze": "încadra",
    "încadrezi": "încadra",
    "neîncadrând": "încadra",
    "neîncadrându": "încadra",
    "nemaiîncadrând": "încadra",
    "nemaiîncadrându": "încadra",
    "încadrarea": "încadrare",
    "încadrareo": "încadrare",
    "încadrări": "încadrare",
    "încadrării": "încadrare",
    "încadrările": "încadrare",
    "încadrărilor": "încadrare",
    "încadrată": "încadrat",
    "încadrate": "încadrat",
    "încadrați": "încadrat",
    "încaier": "încăiera",
    "încaieră": "încăiera",
    "încăieră": "încăiera",
    "încăierai": "încăiera",
    "încăieram": "încăiera",
    "încăierăm": "încăiera",
    "încăierând": "încăiera",
    "încăierându": "încăiera",
    "încăierară": "încăiera",
    "încăierarăm": "încăiera",
    "încăierarăți": "încăiera",
    "încăierase": "încăiera",
    "încăierasem": "încăiera",
    "încăieraseră": "încăiera",
    "încăieraserăm": "încăiera",
    "încăieraserăți": "încăiera",
    "încăieraseși": "încăiera",
    "încăierași": "încăiera",
    "încăierat": "încăiera",
    "încăierați": "încăiera",
    "încăieratu": "încăiera",
    "încăierau": "încăiera",
    "încaiere": "încăiera",
    "încaieri": "încăiera",
    "neîncăierând": "încăiera",
    "neîncăierându": "încăiera",
    "nemaiîncăierând": "încăiera",
    "nemaiîncăierându": "încăiera",
    "încăierarea": "încăierare",
    "încăierări": "încăierare",
    "încăierării": "încăierare",
    "încăierările": "încăierare",
    "încăierărilor": "încăierare",
    "încăierată": "încăierat",
    "încăierate": "încăierat",
    "încăierați": "încăierat",
    "încâină": "încâina",
    "încâinai": "încâina",
    "încâinam": "încâina",
    "încâinăm": "încâina",
    "încâinând": "încâina",
    "încâinându": "încâina",
    "încâinară": "încâina",
    "încâinarăm": "încâina",
    "încâinarăți": "încâina",
    "încâinase": "încâina",
    "încâinasem": "încâina",
    "încâinaseră": "încâina",
    "încâinaserăm": "încâina",
    "încâinaserăți": "încâina",
    "încâinaseși": "încâina",
    "încâinași": "încâina",
    "încâinat": "încâina",
    "încâinați": "încâina",
    "încâinatu": "încâina",
    "încâinau": "încâina",
    "încâinează": "încâina",
    "încâinez": "încâina",
    "încâineze": "încâina",
    "încâinezi": "încâina",
    "neîncâinând": "încâina",
    "neîncâinându": "încâina",
    "nemaiîncâinând": "încâina",
    "nemaiîncâinându": "încâina",
    "încâinată": "încâinat",
    "încâinate": "încâinat",
    "încâinați": "încâinat",
    "încalc": "încălca",
    "încalcă": "încălca",
    "încălcă": "încălca",
    "încălcai": "încălca",
    "încălcam": "încălca",
    "încălcăm": "încălca",
    "încălcând": "încălca",
    "încălcându": "încălca",
    "încălcară": "încălca",
    "încălcarăm": "încălca",
    "încălcarăți": "încălca",
    "încălcase": "încălca",
    "încălcasem": "încălca",
    "încălcaseră": "încălca",
    "încălcaserăm": "încălca",
    "încălcaserăți": "încălca",
    "încălcaseși": "încălca",
    "încălcași": "încălca",
    "încălcat": "încălca",
    "încălcați": "încălca",
    "încălcatu": "încălca",
    "încălcau": "încălca",
    "încalce": "încălca",
    "încalci": "încălca",
    "neîncălcând": "încălca",
    "neîncălcându": "încălca",
    "nemaiîncălcând": "încălca",
    "nemaiîncălcându": "încălca",
    "încălcarea": "încălcare",
    "încălcări": "încălcare",
    "încălcării": "încălcare",
    "încălcările": "încălcare",
    "încălcărilor": "încălcare",
    "încălcată": "încălcat",
    "încălcate": "încălcat",
    "încălcați": "încălcat",
    "încâlcea": "încâlci",
    "încâlceai": "încâlci",
    "încâlceam": "încâlci",
    "încâlcească": "încâlci",
    "încâlceați": "încâlci",
    "încâlceau": "încâlci",
    "încâlcesc": "încâlci",
    "încâlcește": "încâlci",
    "încâlcești": "încâlci",
    "încâlcii": "încâlci",
    "încâlcim": "încâlci",
    "încâlcind": "încâlci",
    "încâlcindu": "încâlci",
    "încâlciră": "încâlci",
    "încâlcirăm": "încâlci",
    "încâlcirăți": "încâlci",
    "încâlcise": "încâlci",
    "încâlcisem": "încâlci",
    "încâlciseră": "încâlci",
    "încâlciserăm": "încâlci",
    "încâlciserăți": "încâlci",
    "încâlciseși": "încâlci",
    "încâlciși": "încâlci",
    "încâlcit": "încâlci",
    "încâlciți": "încâlci",
    "încâlcitu": "încâlci",
    "neîncâlcind": "încâlci",
    "neîncâlcindu": "încâlci",
    "nemaiîncâlcind": "încâlci",
    "nemaiîncâlcindu": "încâlci",
    "încâlcita": "încâlcit",
    "încâlcită": "încâlcit",
    "încâlcite": "încâlcit",
    "încâlcitei": "încâlcit",
    "încâlcitele": "încâlcit",
    "încâlcitelor": "încâlcit",
    "încâlciți": "încâlcit",
    "încâlciții": "încâlcit",
    "încâlciților": "încâlcit",
    "încâlcitul": "încâlcit",
    "încâlcitului": "încâlcit",
    "incalculabila": "incalculabil",
    "incalculabilă": "incalculabil",
    "incalculabile": "incalculabil",
    "incalculabilei": "incalculabil",
    "incalculabilele": "incalculabil",
    "incalculabilelor": "incalculabil",
    "incalculabili": "incalculabil",
    "incalculabilii": "incalculabil",
    "incalculabililor": "incalculabil",
    "incalculabilul": "incalculabil",
    "incalculabilului": "incalculabil",
    "încalec": "încăleca",
    "încalecă": "încăleca",
    "încălecă": "încăleca",
    "încălecai": "încăleca",
    "încălecam": "încăleca",
    "încălecăm": "încăleca",
    "încălecând": "încăleca",
    "încălecându": "încăleca",
    "încălecară": "încăleca",
    "încălecarăm": "încăleca",
    "încălecarăți": "încăleca",
    "încălecase": "încăleca",
    "încălecasem": "încăleca",
    "încălecaseră": "încăleca",
    "încălecaserăm": "încăleca",
    "încălecaserăți": "încăleca",
    "încălecaseși": "încăleca",
    "încălecași": "încăleca",
    "încălecat": "încăleca",
    "încălecați": "încăleca",
    "încălecatu": "încăleca",
    "încălecau": "încăleca",
    "încalece": "încăleca",
    "încaleci": "încăleca",
    "neîncălecând": "încăleca",
    "neîncălecându": "încăleca",
    "nemaiîncălecând": "încăleca",
    "nemaiîncălecându": "încăleca",
    "încălecată": "încălecat",
    "încălecate": "încălecat",
    "încălecați": "încălecat",
    "incalificabila": "incalificabil",
    "incalificabilă": "incalificabil",
    "incalificabile": "incalificabil",
    "incalificabilei": "incalificabil",
    "incalificabilele": "incalificabil",
    "incalificabilelor": "incalificabil",
    "incalificabili": "incalificabil",
    "incalificabilii": "incalificabil",
    "incalificabililor": "incalificabil",
    "incalificabilo": "incalificabil",
    "incalificabilul": "incalificabil",
    "incalificabilule": "incalificabil",
    "incalificabilului": "incalificabil",
    "încalț": "încălța",
    "încalță": "încălța",
    "încălță": "încălța",
    "încălțai": "încălța",
    "încălțam": "încălța",
    "încălțăm": "încălța",
    "încălțând": "încălța",
    "încălțându": "încălța",
    "încălțară": "încălța",
    "încălțarăm": "încălța",
    "încălțarăți": "încălța",
    "încălțase": "încălța",
    "încălțasem": "încălța",
    "încălțaseră": "încălța",
    "încălțaserăm": "încălța",
    "încălțaserăți": "încălța",
    "încălțaseși": "încălța",
    "încălțași": "încălța",
    "încălțat": "încălța",
    "încălțați": "încălța",
    "încălțatu": "încălța",
    "încălțau": "încălța",
    "încalțe": "încălța",
    "încalți": "încălța",
    "neîncălțând": "încălța",
    "neîncălțându": "încălța",
    "nemaiîncălțând": "încălța",
    "nemaiîncălțându": "încălța",
    "îmbrăcămintei": "încălțăminte",
    "încălțămintea": "încălțăminte",
    "încălțămintei": "încălțăminte",
    "încălțăminți": "încălțăminte",
    "încălțăminții": "încălțăminte",
    "încălțămințile": "încălțăminte",
    "încălțăminților": "încălțăminte",
    "încălțarea": "încălțare",
    "încălțareo": "încălțare",
    "încălțări": "încălțare",
    "încălțării": "încălțare",
    "încălțările": "încălțare",
    "încălțărilor": "încălțare",
    "încălțată": "încălțat",
    "încălțate": "încălțat",
    "încălțați": "încălțat",
    "încălțătoare": "încălțător",
    "încălțătoarele": "încălțător",
    "încălțătoarelor": "încălțător",
    "încălțătorul": "încălțător",
    "încălțătorului": "încălțător",
    "încălușă": "încălușa",
    "încălușai": "încălușa",
    "încălușam": "încălușa",
    "încălușăm": "încălușa",
    "încălușând": "încălușa",
    "încălușându": "încălușa",
    "încălușară": "încălușa",
    "încălușarăm": "încălușa",
    "încălușarăți": "încălușa",
    "încălușase": "încălușa",
    "încălușasem": "încălușa",
    "încălușaseră": "încălușa",
    "încălușaserăm": "încălușa",
    "încălușaserăți": "încălușa",
    "încălușaseși": "încălușa",
    "încălușași": "încălușa",
    "încălușat": "încălușa",
    "încălușați": "încălușa",
    "încălușatu": "încălușa",
    "încălușau": "încălușa",
    "încălușează": "încălușa",
    "încălușez": "încălușa",
    "încălușeze": "încălușa",
    "încălușezi": "încălușa",
    "neîncălușând": "încălușa",
    "neîncălușându": "încălușa",
    "nemaiîncălușând": "încălușa",
    "nemaiîncălușându": "încălușa",
    "încălușată": "încălușat",
    "încălușate": "încălușat",
    "încălușați": "încălușat",
    "încălzea": "încălzi",
    "încălzeai": "încălzi",
    "încălzeam": "încălzi",
    "încălzească": "încălzi",
    "încălzeați": "încălzi",
    "încălzeau": "încălzi",
    "încălzesc": "încălzi",
    "încălzește": "încălzi",
    "încălzești": "încălzi",
    "încălzii": "încălzi",
    "încălzim": "încălzi",
    "încălzind": "încălzi",
    "încălzindu": "încălzi",
    "încălziră": "încălzi",
    "încălzirăm": "încălzi",
    "încălzirăți": "încălzi",
    "încălzise": "încălzi",
    "încălzisem": "încălzi",
    "încălziseră": "încălzi",
    "încălziserăm": "încălzi",
    "încălziserăți": "încălzi",
    "încălziseși": "încălzi",
    "încălziși": "încălzi",
    "încălzit": "încălzi",
    "încălziți": "încălzi",
    "încălzitu": "încălzi",
    "neîncălzind": "încălzi",
    "neîncălzindu": "încălzi",
    "nemaiîncălzind": "încălzi",
    "nemaiîncălzindu": "încălzi",
    "încălzirea": "încălzire",
    "încălziri": "încălzire",
    "încălzirii": "încălzire",
    "încălzirile": "încălzire",
    "încălzirilor": "încălzire",
    "încălzită": "încălzit",
    "încălzite": "încălzit",
    "încălziți": "încălzit",
    "încălzitoare": "încălzitor",
    "încălzitoarea": "încălzitor",
    "încălzitoarei": "încălzitor",
    "încălzitoarele": "încălzitor",
    "încălzitoarelor": "încălzitor",
    "încălzitoareo": "încălzitor",
    "încălzitori": "încălzitor",
    "încălzitorii": "încălzitor",
    "încălzitorilor": "încălzitor",
    "încălzitorul": "încălzitor",
    "încălzitorule": "încălzitor",
    "încălzitorului": "încălzitor",
    "incandescenta": "incandescent",
    "incandescentă": "incandescent",
    "incandescente": "incandescent",
    "incandescentei": "incandescent",
    "incandescentele": "incandescent",
    "incandescentelor": "incandescent",
    "incandescenți": "incandescent",
    "incandescenții": "incandescent",
    "incandescenților": "incandescent",
    "incandescentul": "incandescent",
    "incandescentului": "incandescent",
    "incandescența": "incandescență",
    "incandescențe": "incandescență",
    "incandescenței": "incandescență",
    "incandescențele": "incandescență",
    "incandescențelor": "incandescență",
    "incandescențo": "incandescență",
    "încânt": "încânta",
    "încântă": "încânta",
    "încântai": "încânta",
    "încântam": "încânta",
    "încântăm": "încânta",
    "încântând": "încânta",
    "încântându": "încânta",
    "încântară": "încânta",
    "încântarăm": "încânta",
    "încântarăți": "încânta",
    "încântase": "încânta",
    "încântasem": "încânta",
    "încântaseră": "încânta",
    "încântaserăm": "încânta",
    "încântaserăți": "încânta",
    "încântaseși": "încânta",
    "încântași": "încânta",
    "încântat": "încânta",
    "încântați": "încânta",
    "încântatu": "încânta",
    "încântau": "încânta",
    "încânte": "încânta",
    "încânți": "încânta",
    "neîncântând": "încânta",
    "neîncântându": "încânta",
    "nemaiîncântând": "încânta",
    "nemaiîncântându": "încânta",
    "încântarea": "încântare",
    "încântări": "încântare",
    "încântării": "încântare",
    "încântata": "încântat",
    "încântată": "încântat",
    "încântate": "încântat",
    "încântatei": "încântat",
    "încântatele": "încântat",
    "încântatelor": "încântat",
    "încântați": "încântat",
    "încântații": "încântat",
    "încântaților": "încântat",
    "încântatul": "încântat",
    "încântatului": "încântat",
    "încântătoare": "încântător",
    "încântătoarea": "încântător",
    "încântătoarei": "încântător",
    "încântătoarele": "încântător",
    "încântătoarelor": "încântător",
    "încântători": "încântător",
    "încântătorii": "încântător",
    "încântătorilor": "încântător",
    "încântătorul": "încântător",
    "încântătorului": "încântător",
    "incapabila": "incapabil",
    "incapabilă": "incapabil",
    "incapabile": "incapabil",
    "incapabilei": "incapabil",
    "incapabilele": "incapabil",
    "incapabilelor": "incapabil",
    "incapabili": "incapabil",
    "incapabilii": "incapabil",
    "incapabililor": "incapabil",
    "incapabilul": "incapabil",
    "incapabilului": "incapabil",
    "incapacitatea": "incapacitate",
    "incapacități": "incapacitate",
    "incapacității": "incapacitate",
    "incapacitățile": "incapacitate",
    "incapacităților": "incapacitate",
    "încăpățână": "încăpățâna",
    "încăpățânai": "încăpățâna",
    "încăpățânam": "încăpățâna",
    "încăpățânăm": "încăpățâna",
    "încăpățânând": "încăpățâna",
    "încăpățânându": "încăpățâna",
    "încăpățânară": "încăpățâna",
    "încăpățânarăm": "încăpățâna",
    "încăpățânarăți": "încăpățâna",
    "încăpățânase": "încăpățâna",
    "încăpățânasem": "încăpățâna",
    "încăpățânaseră": "încăpățâna",
    "încăpățânaserăm": "încăpățâna",
    "încăpățânaserăți": "încăpățâna",
    "încăpățânaseși": "încăpățâna",
    "încăpățânași": "încăpățâna",
    "încăpățânat": "încăpățâna",
    "încăpățânați": "încăpățâna",
    "încăpățânatu": "încăpățâna",
    "încăpățânau": "încăpățâna",
    "încăpățânează": "încăpățâna",
    "încăpățânez": "încăpățâna",
    "încăpățâneze": "încăpățâna",
    "încăpățânezi": "încăpățâna",
    "neîncăpățânând": "încăpățâna",
    "neîncăpățânându": "încăpățâna",
    "nemaiîncăpățânând": "încăpățâna",
    "nemaiîncăpățânându": "încăpățâna",
    "încăpățânarea": "încăpățânare",
    "încăpățânări": "încăpățânare",
    "încăpățânării": "încăpățânare",
    "încăpățânările": "încăpățânare",
    "încăpățânărilor": "încăpățânare",
    "încăpățânata": "încăpățânat",
    "încăpățânată": "încăpățânat",
    "încăpățânate": "încăpățânat",
    "încăpățânatei": "încăpățânat",
    "încăpățânatele": "încăpățânat",
    "încăpățânatelor": "încăpățânat",
    "încăpățânați": "încăpățânat",
    "încăpățânații": "încăpățânat",
    "încăpățânaților": "încăpățânat",
    "încăpățânatul": "încăpățânat",
    "încăpățânatului": "încăpățânat",
    "încăpătoare": "încăpător",
    "încăpătoarea": "încăpător",
    "încăpătoarei": "încăpător",
    "încăpătoarele": "încăpător",
    "încăpătoarelor": "încăpător",
    "încăpători": "încăpător",
    "încăpătorii": "încăpător",
    "încăpătorilor": "încăpător",
    "încăpătorul": "încăpător",
    "încăpătorului": "încăpător",
    "încap": "încăpea",
    "încapă": "încăpea",
    "încăpând": "încăpea",
    "încăpându": "încăpea",
    "încape": "încăpea",
    "încăpeai": "încăpea",
    "încăpeam": "încăpea",
    "încăpeați": "încăpea",
    "încăpeau": "încăpea",
    "încăpem": "încăpea",
    "încăpeți": "încăpea",
    "încapi": "încăpea",
    "încăpu": "încăpea",
    "încăpui": "încăpea",
    "încăpură": "încăpea",
    "încăpurăm": "încăpea",
    "încăpurăți": "încăpea",
    "încăpuse": "încăpea",
    "încăpusem": "încăpea",
    "încăpuseră": "încăpea",
    "încăpuserăm": "încăpea",
    "încăpuserăți": "încăpea",
    "încăpuseși": "încăpea",
    "încăpuși": "încăpea",
    "încăput": "încăpea",
    "încăputu": "încăpea",
    "neîncăpând": "încăpea",
    "neîncăpându": "încăpea",
    "nemaiîncăpând": "încăpea",
    "nemaiîncăpându": "încăpea",
    "încăperea": "încăpere",
    "încăperi": "încăpere",
    "încăperii": "încăpere",
    "încăperile": "încăpere",
    "încăperilor": "încăpere",
    "încapsulă": "încapsula",
    "încapsulai": "încapsula",
    "încapsulam": "încapsula",
    "încapsulăm": "încapsula",
    "încapsulând": "încapsula",
    "încapsulându": "încapsula",
    "încapsulară": "încapsula",
    "încapsularăm": "încapsula",
    "încapsularăți": "încapsula",
    "încapsulase": "încapsula",
    "încapsulasem": "încapsula",
    "încapsulaseră": "încapsula",
    "încapsulaserăm": "încapsula",
    "încapsulaserăți": "încapsula",
    "încapsulaseși": "încapsula",
    "încapsulași": "încapsula",
    "încapsulat": "încapsula",
    "încapsulați": "încapsula",
    "încapsulatu": "încapsula",
    "încapsulau": "încapsula",
    "încapsulează": "încapsula",
    "încapsulez": "încapsula",
    "încapsuleze": "încapsula",
    "încapsulezi": "încapsula",
    "neîncapsulând": "încapsula",
    "neîncapsulându": "încapsula",
    "nemaiîncapsulând": "încapsula",
    "nemaiîncapsulându": "încapsula",
    "încapsulată": "încapsulat",
    "încapsulate": "încapsulat",
    "încapsulați": "încapsulat",
    "încăpuia": "încăpui",
    "încăpuiai": "încăpui",
    "încăpuiam": "încăpui",
    "încăpuiască": "încăpui",
    "încăpuiați": "încăpui",
    "încăpuiau": "încăpui",
    "încăpuiesc": "încăpui",
    "încăpuiește": "încăpui",
    "încăpuiești": "încăpui",
    "încăpuii": "încăpui",
    "încăpuim": "încăpui",
    "încăpuind": "încăpui",
    "încăpuindu": "încăpui",
    "încăpuiră": "încăpui",
    "încăpuirăm": "încăpui",
    "încăpuirăți": "încăpui",
    "încăpuise": "încăpui",
    "încăpuisem": "încăpui",
    "încăpuiseră": "încăpui",
    "încăpuiserăm": "încăpui",
    "încăpuiserăți": "încăpui",
    "încăpuiseși": "încăpui",
    "încăpuiși": "încăpui",
    "încăpuit": "încăpui",
    "încăpuiți": "încăpui",
    "încăpuitu": "încăpui",
    "neîncăpuind": "încăpui",
    "neîncăpuindu": "încăpui",
    "nemaiîncăpuind": "încăpui",
    "nemaiîncăpuindu": "încăpui",
    "încăpuită": "încăpuit",
    "încăpuite": "încăpuit",
    "încăpuiți": "încăpuit",
    "încăpușa": "încăpuși",
    "încăpușai": "încăpuși",
    "încăpușam": "încăpuși",
    "încăpușați": "încăpuși",
    "încăpușească": "încăpuși",
    "încăpușeau": "încăpuși",
    "încăpușesc": "încăpuși",
    "încăpușește": "încăpuși",
    "încăpușești": "încăpuși",
    "încăpușii": "încăpuși",
    "încăpușim": "încăpuși",
    "încăpușind": "încăpuși",
    "încăpușindu": "încăpuși",
    "încăpușiră": "încăpuși",
    "încăpușirăm": "încăpuși",
    "încăpușirăți": "încăpuși",
    "încăpușise": "încăpuși",
    "încăpușisem": "încăpuși",
    "încăpușiseră": "încăpuși",
    "încăpușiserăm": "încăpuși",
    "încăpușiserăți": "încăpuși",
    "încăpușiseși": "încăpuși",
    "încăpușiși": "încăpuși",
    "încăpușit": "încăpuși",
    "încăpușiți": "încăpuși",
    "încăpușitu": "încăpuși",
    "neîncăpușind": "încăpuși",
    "neîncăpușindu": "încăpuși",
    "nemaiîncăpușind": "încăpuși",
    "nemaiîncăpușindu": "încăpuși",
    "încăpușită": "încăpușit",
    "încăpușite": "încăpușit",
    "încăpușiți": "încăpușit",
    "încăpută": "încăput",
    "încăpute": "încăput",
    "încăpuți": "încăput",
    "încăpută": "încăputa",
    "încăputai": "încăputa",
    "încăputam": "încăputa",
    "încăputăm": "încăputa",
    "încăputând": "încăputa",
    "încăputându": "încăputa",
    "încăputară": "încăputa",
    "încăputarăm": "încăputa",
    "încăputarăți": "încăputa",
    "încăputase": "încăputa",
    "încăputasem": "încăputa",
    "încăputaseră": "încăputa",
    "încăputaserăm": "încăputa",
    "încăputaserăți": "încăputa",
    "încăputaseși": "încăputa",
    "încăputași": "încăputa",
    "încăputat": "încăputa",
    "încăputați": "încăputa",
    "încăputatu": "încăputa",
    "încăputau": "încăputa",
    "încăputează": "încăputa",
    "încăputez": "încăputa",
    "încăputeze": "încăputa",
    "încăputezi": "încăputa",
    "neîncăputând": "încăputa",
    "neîncăputându": "încăputa",
    "nemaiîncăputând": "încăputa",
    "nemaiîncăputându": "încăputa",
    "încăputată": "încăputat",
    "încăputate": "încăputat",
    "încăputați": "încăputat",
    "încarc": "încărca",
    "încarcă": "încărca",
    "încărcă": "încărca",
    "încărcai": "încărca",
    "încărcam": "încărca",
    "încărcăm": "încărca",
    "încărcând": "încărca",
    "încărcându": "încărca",
    "încărcară": "încărca",
    "încărcarăm": "încărca",
    "încărcarăți": "încărca",
    "încărcase": "încărca",
    "încărcasem": "încărca",
    "încărcaseră": "încărca",
    "încărcaserăm": "încărca",
    "încărcaserăți": "încărca",
    "încărcaseși": "încărca",
    "încărcași": "încărca",
    "încărcat": "încărca",
    "încărcați": "încărca",
    "încărcatu": "încărca",
    "încărcau": "încărca",
    "încarce": "încărca",
    "încarci": "încărca",
    "neîncărcând": "încărca",
    "neîncărcându": "încărca",
    "nemaiîncărcând": "încărca",
    "nemaiîncărcându": "încărca",
    "încărcarea": "încărcare",
    "încărcări": "încărcare",
    "încărcării": "încărcare",
    "încărcările": "încărcare",
    "încărcărilor": "încărcare",
    "încărcata": "încărcat",
    "încărcată": "încărcat",
    "încărcate": "încărcat",
    "încărcatei": "încărcat",
    "încărcatele": "încărcat",
    "încărcatelor": "încărcat",
    "încărcați": "încărcat",
    "încărcații": "încărcat",
    "încărcaților": "încărcat",
    "încărcatul": "încărcat",
    "încărcatului": "încărcat",
    "încărcătoare": "încărcător",
    "încărcătoarea": "încărcător",
    "încărcătoarei": "încărcător",
    "încărcătoarele": "încărcător",
    "încărcătoarelor": "încărcător",
    "încărcătoareo": "încărcător",
    "încărcători": "încărcător",
    "încărcătorii": "încărcător",
    "încărcătorilor": "încărcător",
    "încărcătorul": "încărcător",
    "încărcătorule": "încărcător",
    "încărcătorului": "încărcător",
    "încărcătura": "încărcătură",
    "încărcături": "încărcătură",
    "încărcăturii": "încărcătură",
    "încărcăturile": "încărcătură",
    "încărcăturilor": "încărcătură",
    "încarceră": "încarcera",
    "încarcerai": "încarcera",
    "încarceram": "încarcera",
    "încarcerăm": "încarcera",
    "încarcerând": "încarcera",
    "încarcerându": "încarcera",
    "încarcerară": "încarcera",
    "încarcerarăm": "încarcera",
    "încarcerarăți": "încarcera",
    "încarcerase": "încarcera",
    "încarcerasem": "încarcera",
    "încarceraseră": "încarcera",
    "încarceraserăm": "încarcera",
    "încarceraserăți": "încarcera",
    "încarceraseși": "încarcera",
    "încarcerași": "încarcera",
    "încarcerat": "încarcera",
    "încarcerați": "încarcera",
    "încarceratu": "încarcera",
    "încarcerau": "încarcera",
    "încarcerează": "încarcera",
    "încarcerez": "încarcera",
    "încarcereze": "încarcera",
    "încarcerezi": "încarcera",
    "neîncarcerând": "încarcera",
    "neîncarcerându": "încarcera",
    "nemaiîncarcerând": "încarcera",
    "nemaiîncarcerându": "încarcera",
    "încarcerarea": "încarcerare",
    "încarcerareo": "încarcerare",
    "încarcerări": "încarcerare",
    "încarcerării": "încarcerare",
    "încarcerările": "încarcerare",
    "încarcerărilor": "încarcerare",
    "încarcerată": "încarcerat",
    "încarcerate": "încarcerat",
    "încarcerați": "încarcerat",
    "încârdoșă": "încârdoșa",
    "încârdoșai": "încârdoșa",
    "încârdoșam": "încârdoșa",
    "încârdoșăm": "încârdoșa",
    "încârdoșând": "încârdoșa",
    "încârdoșându": "încârdoșa",
    "încârdoșară": "încârdoșa",
    "încârdoșarăm": "încârdoșa",
    "încârdoșarăți": "încârdoșa",
    "încârdoșase": "încârdoșa",
    "încârdoșasem": "încârdoșa",
    "încârdoșaseră": "încârdoșa",
    "încârdoșaserăm": "încârdoșa",
    "încârdoșaserăți": "încârdoșa",
    "încârdoșaseși": "încârdoșa",
    "încârdoșași": "încârdoșa",
    "încârdoșat": "încârdoșa",
    "încârdoșați": "încârdoșa",
    "încârdoșatu": "încârdoșa",
    "încârdoșau": "încârdoșa",
    "încârdoșează": "încârdoșa",
    "încârdoșez": "încârdoșa",
    "încârdoșeze": "încârdoșa",
    "încârdoșezi": "încârdoșa",
    "neîncârdoșând": "încârdoșa",
    "neîncârdoșându": "încârdoșa",
    "nemaiîncârdoșând": "încârdoșa",
    "nemaiîncârdoșându": "încârdoșa",
    "încârdoșată": "încârdoșat",
    "încârdoșate": "încârdoșat",
    "încârdoșați": "încârdoșat",
    "încârduia": "încârdui",
    "încârduiai": "încârdui",
    "încârduiam": "încârdui",
    "încârduiască": "încârdui",
    "încârduiați": "încârdui",
    "încârduiau": "încârdui",
    "încârduiesc": "încârdui",
    "încârduiește": "încârdui",
    "încârduiești": "încârdui",
    "încârduii": "încârdui",
    "încârduim": "încârdui",
    "încârduind": "încârdui",
    "încârduindu": "încârdui",
    "încârduiră": "încârdui",
    "încârduirăm": "încârdui",
    "încârduirăți": "încârdui",
    "încârduise": "încârdui",
    "încârduisem": "încârdui",
    "încârduiseră": "încârdui",
    "încârduiserăm": "încârdui",
    "încârduiserăți": "încârdui",
    "încârduiseși": "încârdui",
    "încârduiși": "încârdui",
    "încârduit": "încârdui",
    "încârduiți": "încârdui",
    "încârduitu": "încârdui",
    "neîncârduind": "încârdui",
    "neîncârduindu": "încârdui",
    "nemaiîncârduind": "încârdui",
    "nemaiîncârduindu": "încârdui",
    "încârduită": "încârduit",
    "încârduite": "încârduit",
    "încârduiți": "încârduit",
    "încârlig": "încârliga",
    "încârligă": "încârliga",
    "încârligai": "încârliga",
    "încârligam": "încârliga",
    "încârligăm": "încârliga",
    "încârligând": "încârliga",
    "încârligându": "încârliga",
    "încârligară": "încârliga",
    "încârligarăm": "încârliga",
    "încârligarăți": "încârliga",
    "încârligase": "încârliga",
    "încârligasem": "încârliga",
    "încârligaseră": "încârliga",
    "încârligaserăm": "încârliga",
    "încârligaserăți": "încârliga",
    "încârligaseși": "încârliga",
    "încârligași": "încârliga",
    "încârligat": "încârliga",
    "încârligați": "încârliga",
    "încârligatu": "încârliga",
    "încârligau": "încârliga",
    "încârlige": "încârliga",
    "încârligi": "încârliga",
    "neîncârligând": "încârliga",
    "neîncârligându": "încârliga",
    "nemaiîncârligând": "încârliga",
    "nemaiîncârligându": "încârliga",
    "încârligată": "încârligat",
    "încârligate": "încârligat",
    "încârligați": "încârligat",
    "încârlionță": "încârlionța",
    "încârlionțai": "încârlionța",
    "încârlionțam": "încârlionța",
    "încârlionțăm": "încârlionța",
    "încârlionțând": "încârlionța",
    "încârlionțându": "încârlionța",
    "încârlionțară": "încârlionța",
    "încârlionțarăm": "încârlionța",
    "încârlionțarăți": "încârlionța",
    "încârlionțase": "încârlionța",
    "încârlionțasem": "încârlionța",
    "încârlionțaseră": "încârlionța",
    "încârlionțaserăm": "încârlionța",
    "încârlionțaserăți": "încârlionța",
    "încârlionțaseși": "încârlionța",
    "încârlionțași": "încârlionța",
    "încârlionțat": "încârlionța",
    "încârlionțați": "încârlionța",
    "încârlionțatu": "încârlionța",
    "încârlionțau": "încârlionța",
    "încârlionțează": "încârlionța",
    "încârlionțez": "încârlionța",
    "încârlionțeze": "încârlionța",
    "încârlionțezi": "încârlionța",
    "neîncârlionțând": "încârlionța",
    "neîncârlionțându": "încârlionța",
    "nemaiîncârlionțând": "încârlionța",
    "nemaiîncârlionțându": "încârlionța",
    "încârlionțată": "încârlionțat",
    "încârlionțate": "încârlionțat",
    "încârlionțați": "încârlionțat",
    "incarnă": "incarna",
    "incarnai": "incarna",
    "incarnam": "incarna",
    "incarnăm": "incarna",
    "incarnând": "incarna",
    "incarnându": "incarna",
    "incarnară": "incarna",
    "incarnarăm": "incarna",
    "incarnarăți": "incarna",
    "incarnase": "incarna",
    "incarnasem": "incarna",
    "incarnaseră": "incarna",
    "incarnaserăm": "incarna",
    "incarnaserăți": "incarna",
    "incarnaseși": "incarna",
    "incarnași": "incarna",
    "incarnat": "incarna",
    "incarnați": "incarna",
    "incarnatu": "incarna",
    "incarnau": "incarna",
    "incarnează": "incarna",
    "incarnez": "incarna",
    "incarneze": "incarna",
    "incarnezi": "incarna",
    "neincarnând": "incarna",
    "neincarnându": "incarna",
    "nemaiincarnând": "incarna",
    "nemaiincarnându": "incarna",
    "încărnă": "încărna",
    "încărnai": "încărna",
    "încărnam": "încărna",
    "încărnăm": "încărna",
    "încărnând": "încărna",
    "încărnându": "încărna",
    "încărnară": "încărna",
    "încărnarăm": "încărna",
    "încărnarăți": "încărna",
    "încărnase": "încărna",
    "încărnasem": "încărna",
    "încărnaseră": "încărna",
    "încărnaserăm": "încărna",
    "încărnaserăți": "încărna",
    "încărnaseși": "încărna",
    "încărnași": "încărna",
    "încărnat": "încărna",
    "încărnați": "încărna",
    "încărnatu": "încărna",
    "încărnau": "încărna",
    "încărnează": "încărna",
    "încărnez": "încărna",
    "încărneze": "încărna",
    "încărnezi": "încărna",
    "neîncărnând": "încărna",
    "neîncărnându": "încărna",
    "nemaiîncărnând": "încărna",
    "nemaiîncărnându": "încărna",
    "incarnată": "incarnat",
    "incarnate": "incarnat",
    "incarnați": "incarnat",
    "încărnată": "încărnat",
    "încărnate": "încărnat",
    "încărnați": "încărnat",
    "încartiruia": "încartirui",
    "încartiruiai": "încartirui",
    "încartiruiam": "încartirui",
    "încartiruiască": "încartirui",
    "încartiruiați": "încartirui",
    "încartiruiau": "încartirui",
    "încartiruiesc": "încartirui",
    "încartiruiește": "încartirui",
    "încartiruiești": "încartirui",
    "încartiruii": "încartirui",
    "încartiruim": "încartirui",
    "încartiruind": "încartirui",
    "încartiruindu": "încartirui",
    "încartiruiră": "încartirui",
    "încartiruirăm": "încartirui",
    "încartiruirăți": "încartirui",
    "încartiruise": "încartirui",
    "încartiruisem": "încartirui",
    "încartiruiseră": "încartirui",
    "încartiruiserăm": "încartirui",
    "încartiruiserăți": "încartirui",
    "încartiruiseși": "încartirui",
    "încartiruiși": "încartirui",
    "încartiruit": "încartirui",
    "încartiruiți": "încartirui",
    "încartiruitu": "încartirui",
    "neîncartiruind": "încartirui",
    "neîncartiruindu": "încartirui",
    "nemaiîncartiruind": "încartirui",
    "nemaiîncartiruindu": "încartirui",
    "încartiruită": "încartiruit",
    "încartiruite": "încartiruit",
    "încartiruiți": "încartiruit",
    "încărunțea": "încărunți",
    "încărunțeai": "încărunți",
    "încărunțeam": "încărunți",
    "încărunțească": "încărunți",
    "încărunțeați": "încărunți",
    "încărunțeau": "încărunți",
    "încărunțesc": "încărunți",
    "încărunțește": "încărunți",
    "încărunțești": "încărunți",
    "încărunții": "încărunți",
    "încărunțim": "încărunți",
    "încărunțind": "încărunți",
    "încărunțindu": "încărunți",
    "încărunțiră": "încărunți",
    "încărunțirăm": "încărunți",
    "încărunțirăți": "încărunți",
    "încărunțise": "încărunți",
    "încărunțisem": "încărunți",
    "încărunțiseră": "încărunți",
    "încărunțiserăm": "încărunți",
    "încărunțiserăți": "încărunți",
    "încărunțiseși": "încărunți",
    "încărunțiși": "încărunți",
    "încărunțit": "încărunți",
    "încărunțiți": "încărunți",
    "încărunțitu": "încărunți",
    "neîncărunțind": "încărunți",
    "neîncărunțindu": "încărunți",
    "nemaiîncărunțind": "încărunți",
    "nemaiîncărunțindu": "încărunți",
    "încărunțita": "încărunțit",
    "încărunțită": "încărunțit",
    "încărunțite": "încărunțit",
    "încărunțitei": "încărunțit",
    "încărunțitele": "încărunțit",
    "încărunțitelor": "încărunțit",
    "încărunțiți": "încărunțit",
    "încărunțiții": "încărunțit",
    "încărunțiților": "încărunțit",
    "încărunțitul": "încărunțit",
    "încărunțitului": "încărunțit",
    "încasă": "încasa",
    "încasai": "încasa",
    "încasam": "încasa",
    "încasăm": "încasa",
    "încasând": "încasa",
    "încasându": "încasa",
    "încasară": "încasa",
    "încasarăm": "încasa",
    "încasarăți": "încasa",
    "încasase": "încasa",
    "încasasem": "încasa",
    "încasaseră": "încasa",
    "încasaserăm": "încasa",
    "încasaserăți": "încasa",
    "încasaseși": "încasa",
    "încasași": "încasa",
    "încasat": "încasa",
    "încasați": "încasa",
    "încasatu": "încasa",
    "încasau": "încasa",
    "încasează": "încasa",
    "încasez": "încasa",
    "încaseze": "încasa",
    "încasezi": "încasa",
    "neîncasând": "încasa",
    "neîncasându": "încasa",
    "nemaiîncasând": "încasa",
    "nemaiîncasându": "încasa",
    "încasarea": "încasare",
    "încasareo": "încasare",
    "încasări": "încasare",
    "încasării": "încasare",
    "încasările": "încasare",
    "încasărilor": "încasare",
    "încasată": "încasat",
    "încasate": "încasat",
    "încasați": "încasat",
    "încasatori": "încasator",
    "încasatorii": "încasator",
    "încasatorilor": "încasator",
    "încasatorul": "încasator",
    "încasatorului": "încasator",
    "încastră": "încastra",
    "încastrai": "încastra",
    "încastram": "încastra",
    "încastrăm": "încastra",
    "încastrând": "încastra",
    "încastrându": "încastra",
    "încastrară": "încastra",
    "încastrarăm": "încastra",
    "încastrarăți": "încastra",
    "încastrase": "încastra",
    "încastrasem": "încastra",
    "încastraseră": "încastra",
    "încastraserăm": "încastra",
    "încastraserăți": "încastra",
    "încastraseși": "încastra",
    "încastrași": "încastra",
    "încastrat": "încastra",
    "încastrați": "încastra",
    "încastratu": "încastra",
    "încastrau": "încastra",
    "încastrează": "încastra",
    "încastrez": "încastra",
    "încastreze": "încastra",
    "încastrezi": "încastra",
    "neîncastrând": "încastra",
    "neîncastrându": "încastra",
    "nemaiîncastrând": "încastra",
    "nemaiîncastrându": "încastra",
    "încastrată": "încastrat",
    "încastrate": "încastrat",
    "încastrați": "încastrat",
    "încătărămă": "încătărăma",
    "încătărămai": "încătărăma",
    "încătărămam": "încătărăma",
    "încătărămăm": "încătărăma",
    "încătărămând": "încătărăma",
    "încătărămându": "încătărăma",
    "încătărămară": "încătărăma",
    "încătărămarăm": "încătărăma",
    "încătărămarăți": "încătărăma",
    "încătărămase": "încătărăma",
    "încătărămasem": "încătărăma",
    "încătărămaseră": "încătărăma",
    "încătărămaserăm": "încătărăma",
    "încătărămaserăți": "încătărăma",
    "încătărămaseși": "încătărăma",
    "încătărămași": "încătărăma",
    "încătărămat": "încătărăma",
    "încătărămați": "încătărăma",
    "încătărămatu": "încătărăma",
    "încătărămau": "încătărăma",
    "încătărămează": "încătărăma",
    "încătărămez": "încătărăma",
    "încătărămeze": "încătărăma",
    "încătărămezi": "încătărăma",
    "neîncătărămând": "încătărăma",
    "neîncătărămându": "încătărăma",
    "nemaiîncătărămând": "încătărăma",
    "nemaiîncătărămându": "încătărăma",
    "încătărămată": "încătărămat",
    "încătărămate": "încătărămat",
    "încătărămați": "încătărămat",
    "încătușă": "încătușa",
    "încătușai": "încătușa",
    "încătușam": "încătușa",
    "încătușăm": "încătușa",
    "încătușând": "încătușa",
    "încătușându": "încătușa",
    "încătușară": "încătușa",
    "încătușarăm": "încătușa",
    "încătușarăți": "încătușa",
    "încătușase": "încătușa",
    "încătușasem": "încătușa",
    "încătușaseră": "încătușa",
    "încătușaserăm": "încătușa",
    "încătușaserăți": "încătușa",
    "încătușaseși": "încătușa",
    "încătușași": "încătușa",
    "încătușat": "încătușa",
    "încătușați": "încătușa",
    "încătușatu": "încătușa",
    "încătușau": "încătușa",
    "încătușează": "încătușa",
    "încătușez": "încătușa",
    "încătușeze": "încătușa",
    "încătușezi": "încătușa",
    "neîncătușând": "încătușa",
    "neîncătușându": "încătușa",
    "nemaiîncătușând": "încătușa",
    "nemaiîncătușându": "încătușa",
    "încătușată": "încătușat",
    "încătușate": "încătușat",
    "încătușați": "încătușat",
    "încazarmă": "încazarma",
    "încazarmai": "încazarma",
    "încazarmam": "încazarma",
    "încazarmăm": "încazarma",
    "încazarmând": "încazarma",
    "încazarmându": "încazarma",
    "încazarmară": "încazarma",
    "încazarmarăm": "încazarma",
    "încazarmarăți": "încazarma",
    "încazarmase": "încazarma",
    "încazarmasem": "încazarma",
    "încazarmaseră": "încazarma",
    "încazarmaserăm": "încazarma",
    "încazarmaserăți": "încazarma",
    "încazarmaseși": "încazarma",
    "încazarmași": "încazarma",
    "încazarmat": "încazarma",
    "încazarmați": "încazarma",
    "încazarmatu": "încazarma",
    "încazarmau": "încazarma",
    "încazarmează": "încazarma",
    "încazarmez": "încazarma",
    "încazarmeze": "încazarma",
    "încazarmezi": "încazarma",
    "neîncazarmând": "încazarma",
    "neîncazarmându": "încazarma",
    "nemaiîncazarmând": "încazarma",
    "nemaiîncazarmându": "încazarma",
    "încazarmată": "încazarmat",
    "încazarmate": "încazarmat",
    "încazarmați": "încazarmat",
    "incendiai": "incendia",
    "incendiam": "incendia",
    "incendiară": "incendia",
    "incendiarăm": "incendia",
    "incendiarăți": "incendia",
    "incendiase": "incendia",
    "incendiasem": "incendia",
    "incendiaseră": "incendia",
    "incendiaserăm": "incendia",
    "incendiaserăți": "incendia",
    "incendiaseși": "incendia",
    "incendiași": "incendia",
    "incendiat": "incendia",
    "incendiați": "incendia",
    "incendiatu": "incendia",
    "incendiau": "incendia",
    "incendiază": "incendia",
    "incendie": "incendia",
    "incendiem": "incendia",
    "incendiez": "incendia",
    "incendieze": "incendia",
    "incendiezi": "incendia",
    "incendiind": "incendia",
    "incendiindu": "incendia",
    "neincendiind": "incendia",
    "neincendiindu": "incendia",
    "nemaiincendiind": "incendia",
    "nemaiincendiindu": "incendia",
    "incendiara": "incendiar",
    "incendiară": "incendiar",
    "incendiare": "incendiar",
    "incendiarei": "incendiar",
    "incendiarele": "incendiar",
    "incendiarelor": "incendiar",
    "incendiari": "incendiar",
    "incendiarii": "incendiar",
    "incendiarilor": "incendiar",
    "incendiarul": "incendiar",
    "incendiarului": "incendiar",
    "incendiată": "incendiat",
    "incendiate": "incendiat",
    "incendiați": "incendiat",
    "incendii": "incendiu",
    "incendiile": "incendiu",
    "incendiilor": "incendiu",
    "incendiul": "incendiu",
    "incendiului": "incendiu",
    "începători": "începător",
    "începătorii": "începător",
    "începătorilor": "începător",
    "începătorul": "începător",
    "începătorului": "începător",
    "înceapă": "începe",
    "încep": "începe",
    "începând": "începe",
    "începându": "începe",
    "începea": "începe",
    "începeai": "începe",
    "începeam": "începe",
    "începeați": "începe",
    "începeau": "începe",
    "începem": "începe",
    "începeți": "începe",
    "începi": "începe",
    "începu": "începe",
    "începui": "începe",
    "începură": "începe",
    "începurăm": "începe",
    "începurăți": "începe",
    "începuse": "începe",
    "începusem": "începe",
    "începuseră": "începe",
    "începuserăm": "începe",
    "începuserăți": "începe",
    "începuseși": "începe",
    "începuși": "începe",
    "început": "începe",
    "începutu": "începe",
    "neîncepând": "începe",
    "neîncepându": "începe",
    "nemaiîncepând": "începe",
    "nemaiîncepându": "începe",
    "începerea": "începere",
    "începeri": "începere",
    "începerii": "începere",
    "începerile": "începere",
    "începerilor": "începere",
    "începută": "început",
    "începute": "început",
    "începuți": "început",
    "începutu'": "început",
    "începutul": "început",
    "începutului": "început",
    "începuturi": "început",
    "începuturile": "început",
    "începuturilor": "început",
    "încearcă": "încerca",
    "încerc": "încerca",
    "încercă": "încerca",
    "încercai": "încerca",
    "încercam": "încerca",
    "încercăm": "încerca",
    "încercând": "încerca",
    "încercându": "încerca",
    "încercară": "încerca",
    "încercarăm": "încerca",
    "încercarăți": "încerca",
    "încercase": "încerca",
    "încercasem": "încerca",
    "încercaseră": "încerca",
    "încercaserăm": "încerca",
    "încercaserăți": "încerca",
    "încercaseși": "încerca",
    "încercași": "încerca",
    "încercat": "încerca",
    "încercați": "încerca",
    "încercatu": "încerca",
    "încercau": "încerca",
    "încerce": "încerca",
    "încerci": "încerca",
    "neîncercând": "încerca",
    "neîncercându": "încerca",
    "nemaiîncercând": "încerca",
    "nemaiîncercându": "încerca",
    "încercănă": "încercăna",
    "încercănai": "încercăna",
    "încercănam": "încercăna",
    "încercănăm": "încercăna",
    "încercănând": "încercăna",
    "încercănându": "încercăna",
    "încercănară": "încercăna",
    "încercănarăm": "încercăna",
    "încercănarăți": "încercăna",
    "încercănase": "încercăna",
    "încercănasem": "încercăna",
    "încercănaseră": "încercăna",
    "încercănaserăm": "încercăna",
    "încercănaserăți": "încercăna",
    "încercănaseși": "încercăna",
    "încercănași": "încercăna",
    "încercănat": "încercăna",
    "încercănați": "încercăna",
    "încercănatu": "încercăna",
    "încercănau": "încercăna",
    "încercănează": "încercăna",
    "încercănez": "încercăna",
    "încercăneze": "încercăna",
    "încercănezi": "încercăna",
    "neîncercănând": "încercăna",
    "neîncercănându": "încercăna",
    "nemaiîncercănând": "încercăna",
    "nemaiîncercănându": "încercăna",
    "încercănată": "încercănat",
    "încercănate": "încercănat",
    "încercănați": "încercănat",
    "încercarea": "încercare",
    "încercări": "încercare",
    "încercării": "încercare",
    "încercările": "încercare",
    "încercărilor": "încercare",
    "încercată": "încercat",
    "încercate": "încercat",
    "încercați": "încercat",
    "încercuia": "încercui",
    "încercuiai": "încercui",
    "încercuiam": "încercui",
    "încercuiască": "încercui",
    "încercuiați": "încercui",
    "încercuiau": "încercui",
    "încercuiesc": "încercui",
    "încercuiește": "încercui",
    "încercuiești": "încercui",
    "încercuii": "încercui",
    "încercuim": "încercui",
    "încercuind": "încercui",
    "încercuindu": "încercui",
    "încercuiră": "încercui",
    "încercuirăm": "încercui",
    "încercuirăți": "încercui",
    "încercuise": "încercui",
    "încercuisem": "încercui",
    "încercuiseră": "încercui",
    "încercuiserăm": "încercui",
    "încercuiserăți": "încercui",
    "încercuiseși": "încercui",
    "încercuiși": "încercui",
    "încercuit": "încercui",
    "încercuiți": "încercui",
    "încercuitu": "încercui",
    "neîncercuind": "încercui",
    "neîncercuindu": "încercui",
    "nemaiîncercuind": "încercui",
    "nemaiîncercuindu": "încercui",
    "încercuirea": "încercuire",
    "încercuiri": "încercuire",
    "încercuirii": "încercuire",
    "încercuirile": "încercuire",
    "încercuirilor": "încercuire",
    "încercuită": "încercuit",
    "încercuite": "încercuit",
    "încercuiți": "încercuit",
    "incerta": "incert",
    "incertă": "incert",
    "incerte": "incert",
    "incertei": "incert",
    "incertele": "incert",
    "incertelor": "incert",
    "incerți": "incert",
    "incerții": "incert",
    "incerților": "incert",
    "incertul": "incert",
    "incertului": "incert",
    "incertitudinea": "incertitudine",
    "incertitudini": "incertitudine",
    "incertitudinii": "incertitudine",
    "incertitudinile": "incertitudine",
    "incertitudinilor": "incertitudine",
    "înceata": "încet",
    "înceată": "încet",
    "încete": "încet",
    "încetei": "încet",
    "încetele": "încet",
    "încetelor": "încet",
    "înceți": "încet",
    "înceții": "încet",
    "înceților": "încet",
    "încetul": "încet",
    "încetului": "încet",
    "încetă": "înceta",
    "încetai": "înceta",
    "încetam": "înceta",
    "încetăm": "înceta",
    "încetând": "înceta",
    "încetându": "înceta",
    "încetară": "înceta",
    "încetarăm": "înceta",
    "încetarăți": "înceta",
    "încetase": "înceta",
    "încetasem": "înceta",
    "încetaseră": "înceta",
    "încetaserăm": "înceta",
    "încetaserăți": "înceta",
    "încetaseși": "înceta",
    "încetași": "înceta",
    "încetat": "înceta",
    "încetați": "înceta",
    "încetatu": "înceta",
    "încetau": "înceta",
    "încetează": "înceta",
    "încetez": "înceta",
    "înceteze": "înceta",
    "încetezi": "înceta",
    "neîncetând": "înceta",
    "neîncetându": "înceta",
    "nemaiîncetând": "înceta",
    "nemaiîncetându": "înceta",
    "încetarea": "încetare",
    "încetări": "încetare",
    "încetării": "încetare",
    "încetată": "încetat",
    "încetate": "încetat",
    "încetați": "încetat",
    "încetățenea": "încetățeni",
    "încetățeneai": "încetățeni",
    "încetățeneam": "încetățeni",
    "încetățenească": "încetățeni",
    "încetățeneați": "încetățeni",
    "încetățeneau": "încetățeni",
    "încetățenesc": "încetățeni",
    "încetățenește": "încetățeni",
    "încetățenești": "încetățeni",
    "încetățenii": "încetățeni",
    "încetățenim": "încetățeni",
    "încetățenind": "încetățeni",
    "încetățenindu": "încetățeni",
    "încetățeniră": "încetățeni",
    "încetățenirăm": "încetățeni",
    "încetățenirăți": "încetățeni",
    "încetățenise": "încetățeni",
    "încetățenisem": "încetățeni",
    "încetățeniseră": "încetățeni",
    "încetățeniserăm": "încetățeni",
    "încetățeniserăți": "încetățeni",
    "încetățeniseși": "încetățeni",
    "încetățeniși": "încetățeni",
    "încetățenit": "încetățeni",
    "încetățeniți": "încetățeni",
    "încetățenitu": "încetățeni",
    "neîncetățenind": "încetățeni",
    "neîncetățenindu": "încetățeni",
    "nemaiîncetățenind": "încetățeni",
    "nemaiîncetățenindu": "încetățeni",
    "încetățenirea": "încetățenire",
    "încetățeniri": "încetățenire",
    "încetățenirii": "încetățenire",
    "încetățenirile": "încetățenire",
    "încetățenirilor": "încetățenire",
    "încetățenită": "încetățenit",
    "încetățenite": "încetățenit",
    "încetățeniți": "încetățenit",
    "încetineala": "încetineală",
    "încetineli": "încetineală",
    "încetinelii": "încetineală",
    "încetinea": "încetini",
    "încetineai": "încetini",
    "încetineam": "încetini",
    "încetinească": "încetini",
    "încetineați": "încetini",
    "încetineau": "încetini",
    "încetinesc": "încetini",
    "încetinește": "încetini",
    "încetinești": "încetini",
    "încetinii": "încetini",
    "încetinim": "încetini",
    "încetinind": "încetini",
    "încetinindu": "încetini",
    "încetiniră": "încetini",
    "încetinirăm": "încetini",
    "încetinirăți": "încetini",
    "încetinise": "încetini",
    "încetinisem": "încetini",
    "încetiniseră": "încetini",
    "încetiniserăm": "încetini",
    "încetiniserăți": "încetini",
    "încetiniseși": "încetini",
    "încetiniși": "încetini",
    "încetinit": "încetini",
    "încetiniți": "încetini",
    "încetinitu": "încetini",
    "neîncetinind": "încetini",
    "neîncetinindu": "încetini",
    "nemaiîncetinind": "încetini",
    "nemaiîncetinindu": "încetini",
    "încetinită": "încetinit",
    "încetinite": "încetinit",
    "încetiniți": "încetinit",
    "încetinitoare": "încetinitor",
    "încetinitoarele": "încetinitor",
    "încetinitoarelor": "încetinitor",
    "încetinitorul": "încetinitor",
    "încetinitorului": "încetinitor",
    "încețoșă": "încețoșa",
    "încețoșai": "încețoșa",
    "încețoșam": "încețoșa",
    "încețoșăm": "încețoșa",
    "încețoșând": "încețoșa",
    "încețoșându": "încețoșa",
    "încețoșară": "încețoșa",
    "încețoșarăm": "încețoșa",
    "încețoșarăți": "încețoșa",
    "încețoșase": "încețoșa",
    "încețoșasem": "încețoșa",
    "încețoșaseră": "încețoșa",
    "încețoșaserăm": "încețoșa",
    "încețoșaserăți": "încețoșa",
    "încețoșaseși": "încețoșa",
    "încețoșași": "încețoșa",
    "încețoșat": "încețoșa",
    "încețoșați": "încețoșa",
    "încețoșatu": "încețoșa",
    "încețoșau": "încețoșa",
    "încețoșează": "încețoșa",
    "încețoșez": "încețoșa",
    "încețoșeze": "încețoșa",
    "încețoșezi": "încețoșa",
    "neîncețoșând": "încețoșa",
    "neîncețoșându": "încețoșa",
    "nemaiîncețoșând": "încețoșa",
    "nemaiîncețoșându": "încețoșa",
    "încețoșata": "încețoșat",
    "încețoșată": "încețoșat",
    "încețoșate": "încețoșat",
    "încețoșatei": "încețoșat",
    "încețoșatele": "încețoșat",
    "încețoșatelor": "încețoșat",
    "încețoșați": "încețoșat",
    "încețoșații": "încețoșat",
    "încețoșaților": "încețoșat",
    "încețoșato": "încețoșat",
    "încețoșatul": "încețoșat",
    "încețoșatule": "încețoșat",
    "încețoșatului": "încețoșat",
    "încheagă": "închega",
    "încheg": "închega",
    "închegă": "închega",
    "închegai": "închega",
    "închegam": "închega",
    "închegăm": "închega",
    "închegând": "închega",
    "închegându": "închega",
    "închegară": "închega",
    "închegarăm": "închega",
    "închegarăți": "închega",
    "închegase": "închega",
    "închegasem": "închega",
    "închegaseră": "închega",
    "închegaserăm": "închega",
    "închegaserăți": "închega",
    "închegaseși": "închega",
    "închegași": "închega",
    "închegat": "închega",
    "închegați": "închega",
    "închegatu": "închega",
    "închegau": "închega",
    "închege": "închega",
    "închegi": "închega",
    "neînchegând": "închega",
    "neînchegându": "închega",
    "nemaiînchegând": "închega",
    "nemaiînchegându": "închega",
    "închegarea": "închegare",
    "închegareo": "închegare",
    "închegări": "închegare",
    "închegării": "închegare",
    "închegările": "închegare",
    "închegărilor": "închegare",
    "închegată": "închegat",
    "închegate": "închegat",
    "închegați": "închegat",
    "închei": "încheia",
    "încheiai": "încheia",
    "încheiam": "încheia",
    "încheiară": "încheia",
    "încheiarăm": "încheia",
    "încheiarăți": "încheia",
    "încheiase": "încheia",
    "încheiasem": "încheia",
    "încheiaseră": "încheia",
    "încheiaserăm": "încheia",
    "încheiaserăți": "încheia",
    "încheiaseși": "încheia",
    "încheiași": "încheia",
    "încheiat": "încheia",
    "încheiați": "încheia",
    "încheiatu": "încheia",
    "încheiau": "încheia",
    "încheie": "încheia",
    "încheiem": "încheia",
    "încheind": "încheia",
    "încheindu": "încheia",
    "neîncheiind": "încheia",
    "neîncheiindu": "încheia",
    "nemaiîncheiind": "încheia",
    "nemaiîncheiindu": "încheia",
    "încheiată": "încheiat",
    "încheiate": "încheiat",
    "încheiați": "încheiat",
    "încheierea": "încheiere",
    "încheieri": "încheiere",
    "încheierii": "încheiere",
    "încheierile": "încheiere",
    "încheierilor": "încheiere",
    "încheietura": "încheietură",
    "încheieturi": "încheietură",
    "încheieturii": "încheietură",
    "încheieturile": "încheietură",
    "încheieturilor": "încheietură",
    "închiaburea": "închiaburi",
    "închiabureai": "închiaburi",
    "închiabuream": "închiaburi",
    "închiaburească": "închiaburi",
    "închiabureați": "închiaburi",
    "închiabureau": "închiaburi",
    "închiaburesc": "închiaburi",
    "închiaburește": "închiaburi",
    "închiaburești": "închiaburi",
    "închiaburii": "închiaburi",
    "închiaburim": "închiaburi",
    "închiaburind": "închiaburi",
    "închiaburindu": "închiaburi",
    "închiaburiră": "închiaburi",
    "închiaburirăm": "închiaburi",
    "închiaburirăți": "închiaburi",
    "închiaburise": "închiaburi",
    "închiaburisem": "închiaburi",
    "închiaburiseră": "închiaburi",
    "închiaburiserăm": "închiaburi",
    "închiaburiserăți": "închiaburi",
    "închiaburiseși": "închiaburi",
    "închiaburiși": "închiaburi",
    "închiaburit": "închiaburi",
    "închiaburiți": "închiaburi",
    "închiaburitu": "închiaburi",
    "neînchiaburind": "închiaburi",
    "neînchiaburindu": "închiaburi",
    "nemaiînchiaburind": "închiaburi",
    "nemaiînchiaburindu": "închiaburi",
    "închiaburită": "închiaburit",
    "închiaburite": "închiaburit",
    "închiaburiți": "închiaburit",
    "închid": "închide",
    "închidă": "închide",
    "închidea": "închide",
    "închideai": "închide",
    "închideam": "închide",
    "închideați": "închide",
    "închideau": "închide",
    "închidem": "închide",
    "închideți": "închide",
    "închis": "închide",
    "închise": "închide",
    "închisei": "închide",
    "închiseră": "închide",
    "închiserăm": "închide",
    "închiserăți": "închide",
    "închisese": "închide",
    "închisesem": "închide",
    "închiseseră": "închide",
    "închiseserăm": "închide",
    "închiseserăți": "închide",
    "închiseseși": "închide",
    "închiseși": "închide",
    "închisu": "închide",
    "închizând": "închide",
    "închizându": "închide",
    "închizi": "închide",
    "neînchizând": "închide",
    "neînchizându": "închide",
    "nemaiînchizând": "închide",
    "nemaiînchizându": "închide",
    "închiderea": "închidere",
    "închideri": "închidere",
    "închiderii": "închidere",
    "închiderile": "închidere",
    "închiderilor": "închidere",
    "închin": "închina",
    "închină": "închina",
    "închinai": "închina",
    "închinam": "închina",
    "închinăm": "închina",
    "închinând": "închina",
    "închinându": "închina",
    "închinară": "închina",
    "închinarăm": "închina",
    "închinarăți": "închina",
    "închinase": "închina",
    "închinasem": "închina",
    "închinaseră": "închina",
    "închinaserăm": "închina",
    "închinaserăți": "închina",
    "închinaseși": "închina",
    "închinași": "închina",
    "închinat": "închina",
    "închinați": "închina",
    "închinatu": "închina",
    "închinau": "închina",
    "închine": "închina",
    "închini": "închina",
    "neînchinând": "închina",
    "neînchinându": "închina",
    "nemaiînchinând": "închina",
    "nemaiînchinându": "închina",
    "închinăciunea": "închinăciune",
    "închinăciuneo": "închinăciune",
    "închinăciuni": "închinăciune",
    "închinăciunii": "închinăciune",
    "închinăciunile": "închinăciune",
    "închinăciunilor": "închinăciune",
    "închinată": "închinat",
    "închinate": "închinat",
    "închinați": "închinat",
    "închipuia": "închipui",
    "închipuiai": "închipui",
    "închipuiam": "închipui",
    "închipuiați": "închipui",
    "închipuiau": "închipui",
    "închipuie": "închipui",
    "închipuii": "închipui",
    "închipuim": "închipui",
    "închipuind": "închipui",
    "închipuindu": "închipui",
    "închipuiră": "închipui",
    "închipuirăm": "închipui",
    "închipuirăți": "închipui",
    "închipuise": "închipui",
    "închipuisem": "închipui",
    "închipuiseră": "închipui",
    "închipuiserăm": "închipui",
    "închipuiserăți": "închipui",
    "închipuiseși": "închipui",
    "închipuiși": "închipui",
    "închipuit": "închipui",
    "închipuiți": "închipui",
    "închipuitu": "închipui",
    "neînchipuind": "închipui",
    "neînchipuindu": "închipui",
    "neînchipuit": "închipui",
    "nemaiînchipuind": "închipui",
    "nemaiînchipuindu": "închipui",
    "închipuirea": "închipuire",
    "închipuiri": "închipuire",
    "închipuirii": "închipuire",
    "închipuirile": "închipuire",
    "închipuirilor": "închipuire",
    "închipuita": "închipuit",
    "închipuită": "închipuit",
    "închipuite": "închipuit",
    "închipuitei": "închipuit",
    "închipuitele": "închipuit",
    "închipuitelor": "închipuit",
    "închipuiți": "închipuit",
    "închipuiții": "închipuit",
    "închipuiților": "închipuit",
    "închipuitul": "închipuit",
    "închipuitului": "închipuit",
    "închircea": "închirci",
    "închirceai": "închirci",
    "închirceam": "închirci",
    "închircească": "închirci",
    "închirceați": "închirci",
    "închirceau": "închirci",
    "închircesc": "închirci",
    "închircește": "închirci",
    "închircești": "închirci",
    "închircii": "închirci",
    "închircim": "închirci",
    "închircind": "închirci",
    "închircindu": "închirci",
    "închirciră": "închirci",
    "închircirăm": "închirci",
    "închircirăți": "închirci",
    "închircise": "închirci",
    "închircisem": "închirci",
    "închirciseră": "închirci",
    "închirciserăm": "închirci",
    "închirciserăți": "închirci",
    "închirciseși": "închirci",
    "închirciși": "închirci",
    "închircit": "închirci",
    "închirciți": "închirci",
    "închircitu": "închirci",
    "neînchircind": "închirci",
    "neînchircindu": "închirci",
    "nemaiînchircind": "închirci",
    "nemaiînchircindu": "închirci",
    "închircită": "închircit",
    "închircite": "închircit",
    "închirciți": "închircit",
    "închiriai": "închiria",
    "închiriam": "închiria",
    "închiriară": "închiria",
    "închiriarăm": "închiria",
    "închiriarăți": "închiria",
    "închiriase": "închiria",
    "închiriasem": "închiria",
    "închiriaseră": "închiria",
    "închiriaserăm": "închiria",
    "închiriaserăți": "închiria",
    "închiriaseși": "închiria",
    "închiriași": "închiria",
    "închiriat": "închiria",
    "închiriați": "închiria",
    "închiriatu": "închiria",
    "închiriau": "închiria",
    "închiriază": "închiria",
    "închirie": "închiria",
    "închiriem": "închiria",
    "închiriez": "închiria",
    "închirieze": "închiria",
    "închiriezi": "închiria",
    "închiriind": "închiria",
    "închiriindu": "închiria",
    "neînchiriând": "închiria",
    "neînchiriându": "închiria",
    "nemaiînchiriând": "închiria",
    "nemaiînchiriându": "închiria",
    "închiriată": "închiriat",
    "închiriate": "închiriat",
    "închiriați": "închiriat",
    "închiriatul": "închiriat",
    "închiriatului": "închiriat",
    "închirierea": "închiriere",
    "închiriereo": "închiriere",
    "închirieri": "închiriere",
    "închirierii": "închiriere",
    "închirierile": "închiriere",
    "închirierilor": "închiriere",
    "închisa": "închis",
    "închisă": "închis",
    "închise": "închis",
    "închisei": "închis",
    "închisele": "închis",
    "închiselor": "închis",
    "închiși": "închis",
    "închișii": "închis",
    "închișilor": "închis",
    "închisul": "închis",
    "închisului": "închis",
    "închisoarea": "închisoare",
    "închisori": "închisoare",
    "închisorii": "închisoare",
    "închisorile": "închisoare",
    "închisorilor": "închisoare",
    "închistă": "închista",
    "închistai": "închista",
    "închistam": "închista",
    "închistăm": "închista",
    "închistând": "închista",
    "închistându": "închista",
    "închistară": "închista",
    "închistarăm": "închista",
    "închistarăți": "închista",
    "închistase": "închista",
    "închistasem": "închista",
    "închistaseră": "închista",
    "închistaserăm": "închista",
    "închistaserăți": "închista",
    "închistaseși": "închista",
    "închistași": "închista",
    "închistat": "închista",
    "închistați": "închista",
    "închistatu": "închista",
    "închistau": "închista",
    "închistează": "închista",
    "închistez": "închista",
    "închisteze": "închista",
    "închistezi": "închista",
    "neînchistând": "închista",
    "neînchistându": "închista",
    "nemaiînchistând": "închista",
    "nemaiînchistându": "închista",
    "închistată": "închistat",
    "închistate": "închistat",
    "închistați": "închistat",
    "inchiziția": "inchiziție",
    "inchiziției": "inchiziție",
    "inchiziții": "inchiziție",
    "inchizițiile": "inchiziție",
    "inchizițiilor": "inchiziție",
    "inchizitori": "inchizitor",
    "inchizitorii": "inchizitor",
    "inchizitorilor": "inchizitor",
    "inchizitorul": "inchizitor",
    "inchizitorului": "inchizitor",
    "incidenta": "incident",
    "incidentă": "incident",
    "incidente": "incident",
    "incidentei": "incident",
    "incidentele": "incident",
    "incidentelor": "incident",
    "incidenți": "incident",
    "incidenții": "incident",
    "incidenților": "incident",
    "incidentul": "incident",
    "incidentului": "incident",
    "incidența": "incidență",
    "incidențe": "incidență",
    "incidenței": "incidență",
    "incidențele": "incidență",
    "incidențelor": "incidență",
    "incidentala": "incidental",
    "incidentală": "incidental",
    "incidentale": "incidental",
    "incidentalei": "incidental",
    "incidentalele": "incidental",
    "incidentalelor": "incidental",
    "incidentali": "incidental",
    "incidentalii": "incidental",
    "incidentalilor": "incidental",
    "incidentalul": "incidental",
    "incidentalului": "incidental",
    "încincita": "încincit",
    "încincită": "încincit",
    "încincite": "încincit",
    "încincitei": "încincit",
    "încincitele": "încincit",
    "încincitelor": "încincit",
    "încinciți": "încincit",
    "încinciții": "încincit",
    "încinciților": "încincit",
    "încincitul": "încincit",
    "încincitului": "încincit",
    "incineră": "incinera",
    "incinerai": "incinera",
    "incineram": "incinera",
    "incinerăm": "incinera",
    "incinerând": "incinera",
    "incinerându": "incinera",
    "incinerară": "incinera",
    "incinerarăm": "incinera",
    "incinerarăți": "incinera",
    "incinerase": "incinera",
    "incinerasem": "incinera",
    "incineraseră": "incinera",
    "incineraserăm": "incinera",
    "incineraserăți": "incinera",
    "incineraseși": "incinera",
    "incinerași": "incinera",
    "incinerat": "incinera",
    "incinerați": "incinera",
    "incineratu": "incinera",
    "incinerau": "incinera",
    "incinerează": "incinera",
    "incinerez": "incinera",
    "incinereze": "incinera",
    "incinerezi": "incinera",
    "neincinerând": "incinera",
    "neincinerându": "incinera",
    "nemaiincinerând": "incinera",
    "nemaiincinerându": "incinera",
    "incinerată": "incinerat",
    "incinerate": "incinerat",
    "incinerați": "incinerat",
    "încing": "încinge",
    "încingă": "încinge",
    "încingând": "încinge",
    "încingându": "încinge",
    "încingea": "încinge",
    "încingeai": "încinge",
    "încingeam": "încinge",
    "încingeați": "încinge",
    "încingeau": "încinge",
    "încingem": "încinge",
    "încingeți": "încinge",
    "încingi": "încinge",
    "încins": "încinge",
    "încinse": "încinge",
    "încinsei": "încinge",
    "încinseră": "încinge",
    "încinserăm": "încinge",
    "încinserăți": "încinge",
    "încinsese": "încinge",
    "încinsesem": "încinge",
    "încinseseră": "încinge",
    "încinseserăm": "încinge",
    "încinseserăți": "încinge",
    "încinseseși": "încinge",
    "încinseși": "încinge",
    "încinsu": "încinge",
    "neîncingând": "încinge",
    "neîncingându": "încinge",
    "nemaiîncingând": "încinge",
    "nemaiîncingându": "încinge",
    "încinsa": "încins",
    "încinsă": "încins",
    "încinse": "încins",
    "încinsei": "încins",
    "încinsele": "încins",
    "încinselor": "încins",
    "încinși": "încins",
    "încinșii": "încins",
    "încinșilor": "încins",
    "încinsul": "încins",
    "încinsului": "încins",
    "incinta": "incintă",
    "incinte": "incintă",
    "incintei": "incintă",
    "incintele": "incintă",
    "incintelor": "incintă",
    "incipienta": "incipient",
    "incipientă": "incipient",
    "incipiente": "incipient",
    "incipientei": "incipient",
    "incipientele": "incipient",
    "incipientelor": "incipient",
    "incipienți": "incipient",
    "incipienții": "incipient",
    "incipienților": "incipient",
    "incipientul": "incipient",
    "incipientului": "incipient",
    "incisiva": "incisiv",
    "incisivă": "incisiv",
    "incisive": "incisiv",
    "incisivei": "incisiv",
    "incisivele": "incisiv",
    "incisivelor": "incisiv",
    "incisivi": "incisiv",
    "incisivii": "incisiv",
    "incisivilor": "incisiv",
    "incisivul": "incisiv",
    "incisivului": "incisiv",
    "incit": "incita",
    "incită": "incita",
    "incitai": "incita",
    "incitam": "incita",
    "incităm": "incita",
    "incitând": "incita",
    "incitându": "incita",
    "incitară": "incita",
    "incitarăm": "incita",
    "incitarăți": "incita",
    "incitase": "incita",
    "incitasem": "incita",
    "incitaseră": "incita",
    "incitaserăm": "incita",
    "incitaserăți": "incita",
    "incitaseși": "incita",
    "incitași": "incita",
    "incitat": "incita",
    "incitați": "incita",
    "incitatu": "incita",
    "incitau": "incita",
    "incite": "incita",
    "inciți": "incita",
    "neincitând": "incita",
    "neincitându": "incita",
    "nemaiincitând": "incita",
    "nemaiincitându": "incita",
    "incitanta": "incitant",
    "incitantă": "incitant",
    "incitante": "incitant",
    "incitantei": "incitant",
    "incitantele": "incitant",
    "incitantelor": "incitant",
    "incitanți": "incitant",
    "incitanții": "incitant",
    "incitanților": "incitant",
    "incitantul": "incitant",
    "incitantului": "incitant",
    "incitată": "incitat",
    "incitate": "incitat",
    "incitați": "incitat",
    "incitatoarea": "incitatoare",
    "incitatoarei": "incitatoare",
    "incitatoarele": "incitatoare",
    "incitatoarelor": "incitatoare",
    "incitatoareo": "incitatoare",
    "înciudă": "înciuda",
    "înciudai": "înciuda",
    "înciudam": "înciuda",
    "înciudăm": "înciuda",
    "înciudând": "înciuda",
    "înciudându": "înciuda",
    "înciudară": "înciuda",
    "înciudarăm": "înciuda",
    "înciudarăți": "înciuda",
    "înciudase": "înciuda",
    "înciudasem": "înciuda",
    "înciudaseră": "înciuda",
    "înciudaserăm": "înciuda",
    "înciudaserăți": "înciuda",
    "înciudaseși": "înciuda",
    "înciudași": "înciuda",
    "înciudat": "înciuda",
    "înciudați": "înciuda",
    "înciudatu": "înciuda",
    "înciudau": "înciuda",
    "înciudează": "înciuda",
    "înciudez": "înciuda",
    "înciudeze": "înciuda",
    "înciudezi": "înciuda",
    "neînciudând": "înciuda",
    "neînciudându": "înciuda",
    "nemaiînciudând": "înciuda",
    "nemaiînciudându": "înciuda",
    "înciudata": "înciudat",
    "înciudată": "înciudat",
    "înciudate": "înciudat",
    "înciudatei": "înciudat",
    "înciudatele": "înciudat",
    "înciudatelor": "înciudat",
    "înciudați": "înciudat",
    "înciudații": "înciudat",
    "înciudaților": "înciudat",
    "înciudatul": "înciudat",
    "înciudatului": "înciudat",
    "inciză": "inciza",
    "incizai": "inciza",
    "incizam": "inciza",
    "incizăm": "inciza",
    "incizând": "inciza",
    "incizându": "inciza",
    "incizară": "inciza",
    "incizarăm": "inciza",
    "incizarăți": "inciza",
    "incizase": "inciza",
    "incizasem": "inciza",
    "incizaseră": "inciza",
    "incizaserăm": "inciza",
    "incizaserăți": "inciza",
    "incizaseși": "inciza",
    "incizași": "inciza",
    "incizat": "inciza",
    "incizați": "inciza",
    "incizatu": "inciza",
    "incizau": "inciza",
    "incizează": "inciza",
    "incizez": "inciza",
    "incizeze": "inciza",
    "incizezi": "inciza",
    "neincizând": "inciza",
    "neincizându": "inciza",
    "nemaiincizând": "inciza",
    "nemaiincizându": "inciza",
    "incizată": "incizat",
    "incizate": "incizat",
    "incizați": "incizat",
    "incizia": "incizie",
    "inciziei": "incizie",
    "incizii": "incizie",
    "inciziile": "incizie",
    "inciziilor": "incizie",
    "încleiai": "încleia",
    "încleiam": "încleia",
    "încleiară": "încleia",
    "încleiarăm": "încleia",
    "încleiarăți": "încleia",
    "încleiase": "încleia",
    "încleiasem": "încleia",
    "încleiaseră": "încleia",
    "încleiaserăm": "încleia",
    "încleiaserăți": "încleia",
    "încleiaseși": "încleia",
    "încleiași": "încleia",
    "încleiat": "încleia",
    "încleiați": "încleia",
    "încleiatu": "încleia",
    "încleiau": "încleia",
    "încleiază": "încleia",
    "încleie": "încleia",
    "încleiem": "încleia",
    "încleiez": "încleia",
    "încleieze": "încleia",
    "încleiezi": "încleia",
    "încleind": "încleia",
    "încleindu": "încleia",
    "neîncleiind": "încleia",
    "neîncleiindu": "încleia",
    "nemaiîncleiind": "încleia",
    "nemaiîncleiindu": "încleia",
    "încleiată": "încleiat",
    "încleiate": "încleiat",
    "încleiați": "încleiat",
    "încleștă": "încleșta",
    "încleștai": "încleșta",
    "încleștam": "încleșta",
    "încleștăm": "încleșta",
    "încleștând": "încleșta",
    "încleștându": "încleșta",
    "încleștară": "încleșta",
    "încleștarăm": "încleșta",
    "încleștarăți": "încleșta",
    "încleștase": "încleșta",
    "încleștasem": "încleșta",
    "încleștaseră": "încleșta",
    "încleștaserăm": "încleșta",
    "încleștaserăți": "încleșta",
    "încleștaseși": "încleșta",
    "încleștași": "încleșta",
    "încleștat": "încleșta",
    "încleștați": "încleșta",
    "încleștatu": "încleșta",
    "încleștau": "încleșta",
    "încleștează": "încleșta",
    "încleștez": "încleșta",
    "încleșteze": "încleșta",
    "încleștezi": "încleșta",
    "neîncleștând": "încleșta",
    "neîncleștându": "încleșta",
    "nemaiîncleștând": "încleșta",
    "nemaiîncleștându": "încleșta",
    "încleștarea": "încleștare",
    "încleștareo": "încleștare",
    "încleștări": "încleștare",
    "încleștării": "încleștare",
    "încleștările": "încleștare",
    "încleștărilor": "încleștare",
    "încleștată": "încleștat",
    "încleștate": "încleștat",
    "încleștați": "încleștat",
    "înclin": "înclina",
    "înclină": "înclina",
    "înclinai": "înclina",
    "înclinam": "înclina",
    "înclinăm": "înclina",
    "înclinând": "înclina",
    "înclinându": "înclina",
    "înclinară": "înclina",
    "înclinarăm": "înclina",
    "înclinarăți": "înclina",
    "înclinase": "înclina",
    "înclinasem": "înclina",
    "înclinaseră": "înclina",
    "înclinaserăm": "înclina",
    "înclinaserăți": "înclina",
    "înclinaseși": "înclina",
    "înclinași": "înclina",
    "înclinat": "înclina",
    "înclinați": "înclina",
    "înclinatu": "înclina",
    "înclinau": "înclina",
    "încline": "înclina",
    "înclini": "înclina",
    "neînclinând": "înclina",
    "neînclinându": "înclina",
    "nemaiînclinând": "înclina",
    "nemaiînclinându": "înclina",
    "înclinarea": "înclinare",
    "înclinări": "înclinare",
    "înclinării": "înclinare",
    "înclinările": "înclinare",
    "înclinărilor": "înclinare",
    "înclinata": "înclinat",
    "înclinată": "înclinat",
    "înclinate": "înclinat",
    "înclinatei": "înclinat",
    "înclinatele": "înclinat",
    "înclinatelor": "înclinat",
    "înclinați": "înclinat",
    "înclinații": "înclinat",
    "înclinaților": "înclinat",
    "înclinatul": "înclinat",
    "înclinatului": "înclinat",
    "înclinația": "înclinație",
    "înclinației": "înclinație",
    "înclinații": "înclinație",
    "înclinațiile": "înclinație",
    "înclinațiilor": "înclinație",
    "includ": "include",
    "includă": "include",
    "includea": "include",
    "includeai": "include",
    "includeam": "include",
    "includeați": "include",
    "includeau": "include",
    "includem": "include",
    "includeți": "include",
    "inclus": "include",
    "incluse": "include",
    "inclusei": "include",
    "incluseră": "include",
    "incluserăm": "include",
    "incluserăți": "include",
    "inclusese": "include",
    "inclusesem": "include",
    "incluseseră": "include",
    "incluseserăm": "include",
    "incluseserăți": "include",
    "incluseseși": "include",
    "incluseși": "include",
    "inclusu": "include",
    "incluzând": "include",
    "incluzându": "include",
    "incluzi": "include",
    "neincluzând": "include",
    "neincluzându": "include",
    "nemaiincluzând": "include",
    "nemaiincluzându": "include",
    "includerea": "includere",
    "includeri": "includere",
    "includerii": "includere",
    "includerile": "includere",
    "includerilor": "includere",
    "inclusă": "inclus",
    "incluse": "inclus",
    "incluși": "inclus",
    "incl.": "inclusiv",
    "incoerenta": "incoerent",
    "incoerentă": "incoerent",
    "incoerente": "incoerent",
    "incoerentei": "incoerent",
    "incoerentele": "incoerent",
    "incoerentelor": "incoerent",
    "incoerenți": "incoerent",
    "incoerenții": "incoerent",
    "incoerenților": "incoerent",
    "incoerentul": "incoerent",
    "incoerentului": "incoerent",
    "incoerența": "incoerență",
    "incoerențe": "incoerență",
    "incoerenței": "incoerență",
    "incoerențele": "incoerență",
    "incoerențelor": "incoerență",
    "încolăcea": "încolăci",
    "încolăceai": "încolăci",
    "încolăceam": "încolăci",
    "încolăcească": "încolăci",
    "încolăceați": "încolăci",
    "încolăceau": "încolăci",
    "încolăcesc": "încolăci",
    "încolăcește": "încolăci",
    "încolăcești": "încolăci",
    "încolăcii": "încolăci",
    "încolăcim": "încolăci",
    "încolăcind": "încolăci",
    "încolăcindu": "încolăci",
    "încolăciră": "încolăci",
    "încolăcirăm": "încolăci",
    "încolăcirăți": "încolăci",
    "încolăcise": "încolăci",
    "încolăcisem": "încolăci",
    "încolăciseră": "încolăci",
    "încolăciserăm": "încolăci",
    "încolăciserăți": "încolăci",
    "încolăciseși": "încolăci",
    "încolăciși": "încolăci",
    "încolăcit": "încolăci",
    "încolăciți": "încolăci",
    "încolăcitu": "încolăci",
    "neîncolăcind": "încolăci",
    "neîncolăcindu": "încolăci",
    "nemaiîncolăcind": "încolăci",
    "nemaiîncolăcindu": "încolăci",
    "încolăcită": "încolăcit",
    "încolăcite": "încolăcit",
    "încolăciți": "încolăcit",
    "încolonă": "încolona",
    "încolonai": "încolona",
    "încolonam": "încolona",
    "încolonăm": "încolona",
    "încolonând": "încolona",
    "încolonându": "încolona",
    "încolonară": "încolona",
    "încolonarăm": "încolona",
    "încolonarăți": "încolona",
    "încolonase": "încolona",
    "încolonasem": "încolona",
    "încolonaseră": "încolona",
    "încolonaserăm": "încolona",
    "încolonaserăți": "încolona",
    "încolonaseși": "încolona",
    "încolonași": "încolona",
    "încolonat": "încolona",
    "încolonați": "încolona",
    "încolonatu": "încolona",
    "încolonau": "încolona",
    "încolonează": "încolona",
    "încolonez": "încolona",
    "încoloneze": "încolona",
    "încolonezi": "încolona",
    "neîncolonând": "încolona",
    "neîncolonându": "încolona",
    "nemaiîncolonând": "încolona",
    "nemaiîncolonându": "încolona",
    "încolonată": "încolonat",
    "încolonate": "încolonat",
    "încolonați": "încolonat",
    "incolora": "incolor",
    "incoloră": "incolor",
    "incolore": "incolor",
    "incolorei": "incolor",
    "incolorele": "incolor",
    "incolorelor": "incolor",
    "incolori": "incolor",
    "incolorii": "incolor",
    "incolorilor": "incolor",
    "incolorul": "incolor",
    "incolorului": "incolor",
    "încolțea": "încolți",
    "încolțeai": "încolți",
    "încolțeam": "încolți",
    "încolțească": "încolți",
    "încolțeați": "încolți",
    "încolțeau": "încolți",
    "încolțesc": "încolți",
    "încolțește": "încolți",
    "încolțești": "încolți",
    "încolții": "încolți",
    "încolțim": "încolți",
    "încolțind": "încolți",
    "încolțindu": "încolți",
    "încolțiră": "încolți",
    "încolțirăm": "încolți",
    "încolțirăți": "încolți",
    "încolțise": "încolți",
    "încolțisem": "încolți",
    "încolțiseră": "încolți",
    "încolțiserăm": "încolți",
    "încolțiserăți": "încolți",
    "încolțiseși": "încolți",
    "încolțiși": "încolți",
    "încolțit": "încolți",
    "încolțiți": "încolți",
    "încolțitu": "încolți",
    "neîncolțind": "încolți",
    "neîncolțindu": "încolți",
    "nemaiîncolțind": "încolți",
    "nemaiîncolțindu": "încolți",
    "încolțită": "încolțit",
    "încolțite": "încolțit",
    "încolțiți": "încolțit",
    "incomoda": "incomod",
    "incomodă": "incomod",
    "incomode": "incomod",
    "incomodei": "incomod",
    "incomodele": "incomod",
    "incomodelor": "incomod",
    "incomodul": "incomod",
    "incomodului": "incomod",
    "incomozi": "incomod",
    "incomozii": "incomod",
    "incomozilor": "incomod",
    "incomodă": "incomoda",
    "incomodai": "incomoda",
    "incomodam": "incomoda",
    "incomodăm": "incomoda",
    "incomodând": "incomoda",
    "incomodându": "incomoda",
    "incomodară": "incomoda",
    "incomodarăm": "incomoda",
    "incomodarăți": "incomoda",
    "incomodase": "incomoda",
    "incomodasem": "incomoda",
    "incomodaseră": "incomoda",
    "incomodaserăm": "incomoda",
    "incomodaserăți": "incomoda",
    "incomodaseși": "incomoda",
    "incomodași": "incomoda",
    "incomodat": "incomoda",
    "incomodați": "incomoda",
    "incomodatu": "incomoda",
    "incomodau": "incomoda",
    "incomodează": "incomoda",
    "incomodez": "incomoda",
    "incomodeze": "incomoda",
    "incomodezi": "incomoda",
    "neincomodând": "incomoda",
    "neincomodându": "incomoda",
    "nemaiincomodând": "incomoda",
    "nemaiincomodându": "incomoda",
    "incomodată": "incomodat",
    "incomodate": "incomodat",
    "incomodați": "incomodat",
    "incomparabila": "incomparabil",
    "incomparabilă": "incomparabil",
    "incomparabile": "incomparabil",
    "incomparabilei": "incomparabil",
    "incomparabilele": "incomparabil",
    "incomparabilelor": "incomparabil",
    "incomparabili": "incomparabil",
    "incomparabilii": "incomparabil",
    "incomparabililor": "incomparabil",
    "incomparabilul": "incomparabil",
    "incomparabilului": "incomparabil",
    "incompatibila": "incompatibil",
    "incompatibilă": "incompatibil",
    "incompatibile": "incompatibil",
    "incompatibilei": "incompatibil",
    "incompatibilele": "incompatibil",
    "incompatibilelor": "incompatibil",
    "incompatibili": "incompatibil",
    "incompatibilii": "incompatibil",
    "incompatibililor": "incompatibil",
    "incompatibilul": "incompatibil",
    "incompatibilului": "incompatibil",
    "incompatibilitatea": "incompatibilitate",
    "incompatibilități": "incompatibilitate",
    "incompatibilității": "incompatibilitate",
    "incompatibilitățile": "incompatibilitate",
    "incompatibilităților": "incompatibilitate",
    "incompetenta": "incompetent",
    "incompetentă": "incompetent",
    "incompetente": "incompetent",
    "incompetentei": "incompetent",
    "incompetentele": "incompetent",
    "incompetentelor": "incompetent",
    "incompetenți": "incompetent",
    "incompetenții": "incompetent",
    "incompetenților": "incompetent",
    "incompetentul": "incompetent",
    "incompetentului": "incompetent",
    "incompetența": "incompetență",
    "incompetențe": "incompetență",
    "incompetenței": "incompetență",
    "incompetențele": "incompetență",
    "incompetențelor": "incompetență",
    "incompleta": "incomplet",
    "incompletă": "incomplet",
    "incomplete": "incomplet",
    "incompletei": "incomplet",
    "incompletele": "incomplet",
    "incompletelor": "incomplet",
    "incompleți": "incomplet",
    "incompleții": "incomplet",
    "incompleților": "incomplet",
    "incompletul": "incomplet",
    "incompletului": "incomplet",
    "încondeiai": "încondeia",
    "încondeiam": "încondeia",
    "încondeiară": "încondeia",
    "încondeiarăm": "încondeia",
    "încondeiarăți": "încondeia",
    "încondeiase": "încondeia",
    "încondeiasem": "încondeia",
    "încondeiaseră": "încondeia",
    "încondeiaserăm": "încondeia",
    "încondeiaserăți": "încondeia",
    "încondeiaseși": "încondeia",
    "încondeiași": "încondeia",
    "încondeiat": "încondeia",
    "încondeiați": "încondeia",
    "încondeiatu": "încondeia",
    "încondeiau": "încondeia",
    "încondeiază": "încondeia",
    "încondeie": "încondeia",
    "încondeiem": "încondeia",
    "încondeiez": "încondeia",
    "încondeieze": "încondeia",
    "încondeiezi": "încondeia",
    "încondeind": "încondeia",
    "încondeindu": "încondeia",
    "neîncondeiând": "încondeia",
    "neîncondeiându": "încondeia",
    "nemaiîncondeiând": "încondeia",
    "nemaiîncondeiându": "încondeia",
    "încondeiată": "încondeiat",
    "încondeiate": "încondeiat",
    "încondeiați": "încondeiat",
    "inconfundabila": "inconfundabil",
    "inconfundabilă": "inconfundabil",
    "inconfundabile": "inconfundabil",
    "inconfundabilei": "inconfundabil",
    "inconfundabilele": "inconfundabil",
    "inconfundabilelor": "inconfundabil",
    "inconfundabili": "inconfundabil",
    "inconfundabilii": "inconfundabil",
    "inconfundabililor": "inconfundabil",
    "inconfundabilul": "inconfundabil",
    "inconfundabilului": "inconfundabil",
    "înconjurul": "înconjur",
    "înconjurului": "înconjur",
    "înconjururi": "înconjur",
    "înconjururile": "înconjur",
    "înconjururilor": "înconjur",
    "înconjoară": "înconjura",
    "înconjoare": "înconjura",
    "înconjor": "înconjura",
    "înconjori": "înconjura",
    "înconjură": "înconjura",
    "înconjurai": "înconjura",
    "înconjuram": "înconjura",
    "înconjurăm": "înconjura",
    "înconjurând": "înconjura",
    "înconjurându": "înconjura",
    "înconjurară": "înconjura",
    "înconjurarăm": "înconjura",
    "înconjurarăți": "înconjura",
    "înconjurase": "înconjura",
    "înconjurasem": "înconjura",
    "înconjuraseră": "înconjura",
    "înconjuraserăm": "înconjura",
    "înconjuraserăți": "înconjura",
    "înconjuraseși": "înconjura",
    "înconjurași": "înconjura",
    "înconjurat": "înconjura",
    "înconjurați": "înconjura",
    "înconjuratu": "înconjura",
    "înconjurau": "înconjura",
    "neînconjurând": "înconjura",
    "neînconjurându": "înconjura",
    "nemaiînconjurând": "înconjura",
    "nemaiînconjurându": "înconjura",
    "înconjurată": "înconjurat",
    "înconjurate": "înconjurat",
    "înconjurați": "înconjurat",
    "înconjurătoare": "înconjurător",
    "înconjurătoarea": "înconjurător",
    "înconjurătoarei": "înconjurător",
    "înconjurătoarele": "înconjurător",
    "înconjurătoarelor": "înconjurător",
    "înconjurători": "înconjurător",
    "înconjurătorii": "înconjurător",
    "înconjurătorilor": "înconjurător",
    "înconjurătorul": "înconjurător",
    "înconjurătorului": "înconjurător",
    "inconsecventa": "inconsecvent",
    "inconsecventă": "inconsecvent",
    "inconsecvente": "inconsecvent",
    "inconsecventei": "inconsecvent",
    "inconsecventele": "inconsecvent",
    "inconsecventelor": "inconsecvent",
    "inconsecvenți": "inconsecvent",
    "inconsecvenții": "inconsecvent",
    "inconsecvenților": "inconsecvent",
    "inconsecventul": "inconsecvent",
    "inconsecventului": "inconsecvent",
    "inconsecvența": "inconsecvență",
    "inconsecvențe": "inconsecvență",
    "inconsecvenței": "inconsecvență",
    "inconsecvențele": "inconsecvență",
    "inconsecvențelor": "inconsecvență",
    "inconsistența": "inconsistență",
    "inconsistențe": "inconsistență",
    "inconsistenței": "inconsistență",
    "inconsistențele": "inconsistență",
    "inconsistențelor": "inconsistență",
    "inconsistențo": "inconsistență",
    "inconstanta": "inconstant",
    "inconstantă": "inconstant",
    "inconstante": "inconstant",
    "inconstantei": "inconstant",
    "inconstantele": "inconstant",
    "inconstantelor": "inconstant",
    "inconstanți": "inconstant",
    "inconstanții": "inconstant",
    "inconstanților": "inconstant",
    "inconstantul": "inconstant",
    "inconstantului": "inconstant",
    "inconștienta": "inconștient",
    "inconștientă": "inconștient",
    "inconștiente": "inconștient",
    "inconștientei": "inconștient",
    "inconștientele": "inconștient",
    "inconștientelor": "inconștient",
    "inconștienți": "inconștient",
    "inconștienții": "inconștient",
    "inconștienților": "inconștient",
    "inconștientul": "inconștient",
    "inconștientului": "inconștient",
    "inconștiența": "inconștiență",
    "inconștiențe": "inconștiență",
    "inconștienței": "inconștiență",
    "inconștiențele": "inconștiență",
    "inconștiențelor": "inconștiență",
    "inconștiențo": "inconștiență",
    "incontestabila": "incontestabil",
    "incontestabilă": "incontestabil",
    "incontestabile": "incontestabil",
    "incontestabilei": "incontestabil",
    "incontestabilele": "incontestabil",
    "incontestabilelor": "incontestabil",
    "incontestabili": "incontestabil",
    "incontestabilii": "incontestabil",
    "incontestabililor": "incontestabil",
    "incontestabilul": "incontestabil",
    "incontestabilului": "incontestabil",
    "încontră": "încontra",
    "încontrai": "încontra",
    "încontram": "încontra",
    "încontrăm": "încontra",
    "încontrând": "încontra",
    "încontrându": "încontra",
    "încontrară": "încontra",
    "încontrarăm": "încontra",
    "încontrarăți": "încontra",
    "încontrase": "încontra",
    "încontrasem": "încontra",
    "încontraseră": "încontra",
    "încontraserăm": "încontra",
    "încontraserăți": "încontra",
    "încontraseși": "încontra",
    "încontrași": "încontra",
    "încontrat": "încontra",
    "încontrați": "încontra",
    "încontratu": "încontra",
    "încontrau": "încontra",
    "încontrează": "încontra",
    "încontrez": "încontra",
    "încontreze": "încontra",
    "încontrezi": "încontra",
    "neîncontrând": "încontra",
    "neîncontrându": "încontra",
    "nemaiîncontrând": "încontra",
    "nemaiîncontrându": "încontra",
    "încontrată": "încontrat",
    "încontrate": "încontrat",
    "încontrați": "încontrat",
    "inconveniente": "inconvenient",
    "inconvenientele": "inconvenient",
    "inconvenientelor": "inconvenient",
    "inconvenientul": "inconvenient",
    "inconvenientului": "inconvenient",
    "încopciai": "încopcia",
    "încopciam": "încopcia",
    "încopciară": "încopcia",
    "încopciarăm": "încopcia",
    "încopciarăți": "încopcia",
    "încopciase": "încopcia",
    "încopciasem": "încopcia",
    "încopciaseră": "încopcia",
    "încopciaserăm": "încopcia",
    "încopciaserăți": "încopcia",
    "încopciaseși": "încopcia",
    "încopciași": "încopcia",
    "încopciat": "încopcia",
    "încopciați": "încopcia",
    "încopciatu": "încopcia",
    "încopciau": "încopcia",
    "încopciază": "încopcia",
    "încopcie": "încopcia",
    "încopciem": "încopcia",
    "încopciez": "încopcia",
    "încopcieze": "încopcia",
    "încopciezi": "încopcia",
    "încopciind": "încopcia",
    "încopciindu": "încopcia",
    "neîncopciind": "încopcia",
    "neîncopciindu": "încopcia",
    "nemaiîncopciind": "încopcia",
    "nemaiîncopciindu": "încopcia",
    "încopciată": "încopciat",
    "încopciate": "încopciat",
    "încopciați": "încopciat",
    "încordă": "încorda",
    "încordai": "încorda",
    "încordam": "încorda",
    "încordăm": "încorda",
    "încordând": "încorda",
    "încordându": "încorda",
    "încordară": "încorda",
    "încordarăm": "încorda",
    "încordarăți": "încorda",
    "încordase": "încorda",
    "încordasem": "încorda",
    "încordaseră": "încorda",
    "încordaserăm": "încorda",
    "încordaserăți": "încorda",
    "încordaseși": "încorda",
    "încordași": "încorda",
    "încordat": "încorda",
    "încordați": "încorda",
    "încordatu": "încorda",
    "încordau": "încorda",
    "încordează": "încorda",
    "încordez": "încorda",
    "încordeze": "încorda",
    "încordezi": "încorda",
    "neîncordând": "încorda",
    "neîncordându": "încorda",
    "nemaiîncordând": "încorda",
    "nemaiîncordându": "încorda",
    "încordarea": "încordare",
    "încordări": "încordare",
    "încordării": "încordare",
    "încordările": "încordare",
    "încordărilor": "încordare",
    "încordata": "încordat",
    "încordată": "încordat",
    "încordate": "încordat",
    "încordatei": "încordat",
    "încordatele": "încordat",
    "încordatelor": "încordat",
    "încordați": "încordat",
    "încordații": "încordat",
    "încordaților": "încordat",
    "încordatul": "încordat",
    "încordatului": "încordat",
    "incorecta": "incorect",
    "incorectă": "incorect",
    "incorecte": "incorect",
    "incorectei": "incorect",
    "incorectele": "incorect",
    "incorectelor": "incorect",
    "incorecți": "incorect",
    "incorecții": "incorect",
    "incorecților": "incorect",
    "incorectul": "incorect",
    "incorectului": "incorect",
    "incorectitudinea": "incorectitudine",
    "incorectitudineo": "incorectitudine",
    "incorectitudini": "incorectitudine",
    "incorectitudinii": "incorectitudine",
    "incorectitudinile": "incorectitudine",
    "incorectitudinilor": "incorectitudine",
    "încoronă": "încorona",
    "încoronai": "încorona",
    "încoronam": "încorona",
    "încoronăm": "încorona",
    "încoronând": "încorona",
    "încoronându": "încorona",
    "încoronară": "încorona",
    "încoronarăm": "încorona",
    "încoronarăți": "încorona",
    "încoronase": "încorona",
    "încoronasem": "încorona",
    "încoronaseră": "încorona",
    "încoronaserăm": "încorona",
    "încoronaserăți": "încorona",
    "încoronaseși": "încorona",
    "încoronași": "încorona",
    "încoronat": "încorona",
    "încoronați": "încorona",
    "încoronatu": "încorona",
    "încoronau": "încorona",
    "încoronează": "încorona",
    "încoronez": "încorona",
    "încoroneze": "încorona",
    "încoronezi": "încorona",
    "neîncoronând": "încorona",
    "neîncoronându": "încorona",
    "nemaiîncoronând": "încorona",
    "nemaiîncoronându": "încorona",
    "încoronarea": "încoronare",
    "încoronări": "încoronare",
    "încoronării": "încoronare",
    "încoronările": "încoronare",
    "încoronărilor": "încoronare",
    "încoronată": "încoronat",
    "încoronate": "încoronat",
    "încoronați": "încoronat",
    "încorporă": "încorpora",
    "încorporai": "încorpora",
    "încorporam": "încorpora",
    "încorporăm": "încorpora",
    "încorporând": "încorpora",
    "încorporându": "încorpora",
    "încorporară": "încorpora",
    "încorporarăm": "încorpora",
    "încorporarăți": "încorpora",
    "încorporase": "încorpora",
    "încorporasem": "încorpora",
    "încorporaseră": "încorpora",
    "încorporaserăm": "încorpora",
    "încorporaserăți": "încorpora",
    "încorporaseși": "încorpora",
    "încorporași": "încorpora",
    "încorporat": "încorpora",
    "încorporați": "încorpora",
    "încorporatu": "încorpora",
    "încorporau": "încorpora",
    "încorporează": "încorpora",
    "încorporez": "încorpora",
    "încorporeze": "încorpora",
    "încorporezi": "încorpora",
    "neîncorporând": "încorpora",
    "neîncorporându": "încorpora",
    "nemaiîncorporând": "încorpora",
    "nemaiîncorporându": "încorpora",
    "încorporată": "încorporat",
    "încorporate": "încorporat",
    "încorporați": "încorporat",
    "încorsetă": "încorseta",
    "încorsetai": "încorseta",
    "încorsetam": "încorseta",
    "încorsetăm": "încorseta",
    "încorsetând": "încorseta",
    "încorsetându": "încorseta",
    "încorsetară": "încorseta",
    "încorsetarăm": "încorseta",
    "încorsetarăți": "încorseta",
    "încorsetase": "încorseta",
    "încorsetasem": "încorseta",
    "încorsetaseră": "încorseta",
    "încorsetaserăm": "încorseta",
    "încorsetaserăți": "încorseta",
    "încorsetaseși": "încorseta",
    "încorsetași": "încorseta",
    "încorsetat": "încorseta",
    "încorsetați": "încorseta",
    "încorsetatu": "încorseta",
    "încorsetau": "încorseta",
    "încorsetează": "încorseta",
    "încorsetez": "încorseta",
    "încorseteze": "încorseta",
    "încorsetezi": "încorseta",
    "neîncorsetând": "încorseta",
    "neîncorsetându": "încorseta",
    "nemaiîncorsetând": "încorseta",
    "nemaiîncorsetându": "încorseta",
    "încorsetată": "încorsetat",
    "încorsetate": "încorsetat",
    "încorsetați": "încorsetat",
    "incoruptibila": "incoruptibil",
    "incoruptibilă": "incoruptibil",
    "incoruptibile": "incoruptibil",
    "incoruptibilei": "incoruptibil",
    "incoruptibilele": "incoruptibil",
    "incoruptibilelor": "incoruptibil",
    "incoruptibili": "incoruptibil",
    "incoruptibilii": "incoruptibil",
    "incoruptibililor": "incoruptibil",
    "incoruptibilul": "incoruptibil",
    "incoruptibilului": "incoruptibil",
    "încotoșmănă": "încotoșmăna",
    "încotoșmănai": "încotoșmăna",
    "încotoșmănam": "încotoșmăna",
    "încotoșmănăm": "încotoșmăna",
    "încotoșmănând": "încotoșmăna",
    "încotoșmănându": "încotoșmăna",
    "încotoșmănară": "încotoșmăna",
    "încotoșmănarăm": "încotoșmăna",
    "încotoșmănarăți": "încotoșmăna",
    "încotoșmănase": "încotoșmăna",
    "încotoșmănasem": "încotoșmăna",
    "încotoșmănaseră": "încotoșmăna",
    "încotoșmănaserăm": "încotoșmăna",
    "încotoșmănaserăți": "încotoșmăna",
    "încotoșmănaseși": "încotoșmăna",
    "încotoșmănași": "încotoșmăna",
    "încotoșmănat": "încotoșmăna",
    "încotoșmănați": "încotoșmăna",
    "încotoșmănatu": "încotoșmăna",
    "încotoșmănau": "încotoșmăna",
    "încotoșmănează": "încotoșmăna",
    "încotoșmănez": "încotoșmăna",
    "încotoșmăneze": "încotoșmăna",
    "încotoșmănezi": "încotoșmăna",
    "neîncotoșmănând": "încotoșmăna",
    "neîncotoșmănându": "încotoșmăna",
    "nemaiîncotoșmănând": "încotoșmăna",
    "nemaiîncotoșmănându": "încotoșmăna",
    "încotoșmănată": "încotoșmănat",
    "încotoșmănate": "încotoșmănat",
    "încotoșmănați": "încotoșmănat",
    "încovoiai": "încovoia",
    "încovoiam": "încovoia",
    "încovoiară": "încovoia",
    "încovoiarăm": "încovoia",
    "încovoiarăți": "încovoia",
    "încovoiase": "încovoia",
    "încovoiasem": "încovoia",
    "încovoiaseră": "încovoia",
    "încovoiaserăm": "încovoia",
    "încovoiaserăți": "încovoia",
    "încovoiaseși": "încovoia",
    "încovoiași": "încovoia",
    "încovoiat": "încovoia",
    "încovoiați": "încovoia",
    "încovoiatu": "încovoia",
    "încovoiau": "încovoia",
    "încovoiază": "încovoia",
    "încovoie": "încovoia",
    "încovoiem": "încovoia",
    "încovoiez": "încovoia",
    "încovoieze": "încovoia",
    "încovoiezi": "încovoia",
    "încovoind": "încovoia",
    "încovoindu": "încovoia",
    "neîncovoiaind": "încovoia",
    "neîncovoiaindu": "încovoia",
    "nemaiîncovoiaind": "încovoia",
    "nemaiîncovoiaindu": "încovoia",
    "încovoiata": "încovoiat",
    "încovoiată": "încovoiat",
    "încovoiate": "încovoiat",
    "încovoiatei": "încovoiat",
    "încovoiatele": "încovoiat",
    "încovoiatelor": "încovoiat",
    "încovoiați": "încovoiat",
    "încovoiații": "încovoiat",
    "încovoiaților": "încovoiat",
    "încovoiatul": "încovoiat",
    "încovoiatului": "încovoiat",
    "încovrig": "încovriga",
    "încovrigă": "încovriga",
    "încovrigai": "încovriga",
    "încovrigam": "încovriga",
    "încovrigăm": "încovriga",
    "încovrigând": "încovriga",
    "încovrigându": "încovriga",
    "încovrigară": "încovriga",
    "încovrigarăm": "încovriga",
    "încovrigarăți": "încovriga",
    "încovrigase": "încovriga",
    "încovrigasem": "încovriga",
    "încovrigaseră": "încovriga",
    "încovrigaserăm": "încovriga",
    "încovrigaserăți": "încovriga",
    "încovrigaseși": "încovriga",
    "încovrigași": "încovriga",
    "încovrigat": "încovriga",
    "încovrigați": "încovriga",
    "încovrigatu": "încovriga",
    "încovrigau": "încovriga",
    "încovrige": "încovriga",
    "încovrigi": "încovriga",
    "neîncovrigând": "încovriga",
    "neîncovrigându": "încovriga",
    "nemaiîncovrigând": "încovriga",
    "nemaiîncovrigându": "încovriga",
    "încovrigată": "încovrigat",
    "încovrigate": "încovrigat",
    "încovrigați": "încovrigat",
    "încrâncenă": "încrâncena",
    "încrâncenai": "încrâncena",
    "încrâncenam": "încrâncena",
    "încrâncenăm": "încrâncena",
    "încrâncenând": "încrâncena",
    "încrâncenându": "încrâncena",
    "încrâncenară": "încrâncena",
    "încrâncenarăm": "încrâncena",
    "încrâncenarăți": "încrâncena",
    "încrâncenase": "încrâncena",
    "încrâncenasem": "încrâncena",
    "încrâncenaseră": "încrâncena",
    "încrâncenaserăm": "încrâncena",
    "încrâncenaserăți": "încrâncena",
    "încrâncenaseși": "încrâncena",
    "încrâncenași": "încrâncena",
    "încrâncenat": "încrâncena",
    "încrâncenați": "încrâncena",
    "încrâncenatu": "încrâncena",
    "încrâncenau": "încrâncena",
    "încrâncenează": "încrâncena",
    "încrâncenez": "încrâncena",
    "încrânceneze": "încrâncena",
    "încrâncenezi": "încrâncena",
    "neîncrâncenând": "încrâncena",
    "neîncrâncenându": "încrâncena",
    "nemaiîncrâncenând": "încrâncena",
    "nemaiîncrâncenându": "încrâncena",
    "încrâncenarea": "încrâncenare",
    "încrâncenareo": "încrâncenare",
    "încrâncenări": "încrâncenare",
    "încrâncenării": "încrâncenare",
    "încrâncenările": "încrâncenare",
    "încrâncenărilor": "încrâncenare",
    "încrâncenată": "încrâncenat",
    "încrâncenate": "încrâncenat",
    "încrâncenați": "încrâncenat",
    "încreadă": "încrede",
    "încred": "încrede",
    "încredea": "încrede",
    "încredeai": "încrede",
    "încredeam": "încrede",
    "încredeați": "încrede",
    "încredeau": "încrede",
    "încredem": "încrede",
    "încredeți": "încrede",
    "încrezând": "încrede",
    "încrezându": "încrede",
    "încrezi": "încrede",
    "încrezu": "încrede",
    "încrezui": "încrede",
    "încrezură": "încrede",
    "încrezurăm": "încrede",
    "încrezurăți": "încrede",
    "încrezuse": "încrede",
    "încrezusem": "încrede",
    "încrezuseră": "încrede",
    "încrezuserăm": "încrede",
    "încrezuserăți": "încrede",
    "încrezuseși": "încrede",
    "încrezuși": "încrede",
    "încrezut": "încrede",
    "încrezutu": "încrede",
    "neîncrezând": "încrede",
    "neîncrezându": "încrede",
    "nemaiîncrezând": "încrede",
    "nemaiîncrezându": "încrede",
    "încrederea": "încredere",
    "încrederi": "încredere",
    "încrederii": "încredere",
    "încrederile": "încredere",
    "încrederilor": "încredere",
    "incredibila": "incredibil",
    "incredibilă": "incredibil",
    "incredibile": "incredibil",
    "incredibilei": "incredibil",
    "incredibilele": "incredibil",
    "incredibilelor": "incredibil",
    "incredibili": "incredibil",
    "incredibilii": "incredibil",
    "incredibililor": "incredibil",
    "incredibilul": "incredibil",
    "incredibilului": "incredibil",
    "încredință": "încredința",
    "încredințai": "încredința",
    "încredințam": "încredința",
    "încredințăm": "încredința",
    "încredințând": "încredința",
    "încredințându": "încredința",
    "încredințară": "încredința",
    "încredințarăm": "încredința",
    "încredințarăți": "încredința",
    "încredințase": "încredința",
    "încredințasem": "încredința",
    "încredințaseră": "încredința",
    "încredințaserăm": "încredința",
    "încredințaserăți": "încredința",
    "încredințaseși": "încredința",
    "încredințași": "încredința",
    "încredințat": "încredința",
    "încredințați": "încredința",
    "încredințatu": "încredința",
    "încredințau": "încredința",
    "încredințează": "încredința",
    "încredințez": "încredința",
    "încredințeze": "încredința",
    "încredințezi": "încredința",
    "neîncredințând": "încredința",
    "neîncredințându": "încredința",
    "nemaiîncredințând": "încredința",
    "nemaiîncredințându": "încredința",
    "încredințarea": "încredințare",
    "încredințări": "încredințare",
    "încredințării": "încredințare",
    "încredințările": "încredințare",
    "încredințărilor": "încredințare",
    "încredințată": "încredințat",
    "încredințate": "încredințat",
    "încredințați": "încredințat",
    "incredula": "incredul",
    "incredulă": "incredul",
    "incredule": "incredul",
    "incredulei": "incredul",
    "incredulele": "incredul",
    "incredulelor": "incredul",
    "increduli": "incredul",
    "incredulii": "incredul",
    "incredulilor": "incredul",
    "incredulul": "incredul",
    "incredulului": "incredul",
    "încremenea": "încremeni",
    "încremeneai": "încremeni",
    "încremeneam": "încremeni",
    "încremenească": "încremeni",
    "încremeneați": "încremeni",
    "încremeneau": "încremeni",
    "încremenesc": "încremeni",
    "încremenește": "încremeni",
    "încremenești": "încremeni",
    "încremenii": "încremeni",
    "încremenim": "încremeni",
    "încremenind": "încremeni",
    "încremenindu": "încremeni",
    "încremeniră": "încremeni",
    "încremenirăm": "încremeni",
    "încremenirăți": "încremeni",
    "încremenise": "încremeni",
    "încremenisem": "încremeni",
    "încremeniseră": "încremeni",
    "încremeniserăm": "încremeni",
    "încremeniserăți": "încremeni",
    "încremeniseși": "încremeni",
    "încremeniși": "încremeni",
    "încremenit": "încremeni",
    "încremeniți": "încremeni",
    "încremenitu": "încremeni",
    "neîncremenind": "încremeni",
    "neîncremenindu": "încremeni",
    "nemaiîncremenind": "încremeni",
    "nemaiîncremenindu": "încremeni",
    "încremenită": "încremenit",
    "încremenite": "încremenit",
    "încremeniți": "încremenit",
    "încrengătura": "încrengătură",
    "încrengătureo": "încrengătură",
    "încrengături": "încrengătură",
    "încrengăturii": "încrengătură",
    "încrengăturile": "încrengătură",
    "încrengăturilor": "încrengătură",
    "încrestă": "încresta",
    "încrestai": "încresta",
    "încrestam": "încresta",
    "încrestăm": "încresta",
    "încrestând": "încresta",
    "încrestându": "încresta",
    "încrestară": "încresta",
    "încrestarăm": "încresta",
    "încrestarăți": "încresta",
    "încrestase": "încresta",
    "încrestasem": "încresta",
    "încrestaseră": "încresta",
    "încrestaserăm": "încresta",
    "încrestaserăți": "încresta",
    "încrestaseși": "încresta",
    "încrestași": "încresta",
    "încrestat": "încresta",
    "încrestați": "încresta",
    "încrestatu": "încresta",
    "încrestau": "încresta",
    "încrestează": "încresta",
    "încrestez": "încresta",
    "încresteze": "încresta",
    "încrestezi": "încresta",
    "neîncrestând": "încresta",
    "neîncrestându": "încresta",
    "nemaiîncrestând": "încresta",
    "nemaiîncrestându": "încresta",
    "încrestată": "încrestat",
    "încrestate": "încrestat",
    "încrestați": "încrestat",
    "încrețea": "încreți",
    "încrețeai": "încreți",
    "încrețeam": "încreți",
    "încrețească": "încreți",
    "încrețeați": "încreți",
    "încrețeau": "încreți",
    "încrețesc": "încreți",
    "încrețește": "încreți",
    "încrețești": "încreți",
    "încreții": "încreți",
    "încrețim": "încreți",
    "încrețind": "încreți",
    "încrețindu": "încreți",
    "încrețiră": "încreți",
    "încrețirăm": "încreți",
    "încrețirăți": "încreți",
    "încrețise": "încreți",
    "încrețisem": "încreți",
    "încrețiseră": "încreți",
    "încrețiserăm": "încreți",
    "încrețiserăți": "încreți",
    "încrețiseși": "încreți",
    "încrețiși": "încreți",
    "încrețit": "încreți",
    "încrețiți": "încreți",
    "încrețitu": "încreți",
    "neîncrețind": "încreți",
    "neîncrețindu": "încreți",
    "nemaiîncrețind": "încreți",
    "nemaiîncrețindu": "încreți",
    "încrețita": "încrețit",
    "încrețită": "încrețit",
    "încrețite": "încrețit",
    "încrețitei": "încrețit",
    "încrețitele": "încrețit",
    "încrețitelor": "încrețit",
    "încrețiți": "încrețit",
    "încrețiții": "încrețit",
    "încrețiților": "încrețit",
    "încrețitul": "încrețit",
    "încrețitului": "încrețit",
    "încrezătoare": "încrezător",
    "încrezătoarea": "încrezător",
    "încrezătoarei": "încrezător",
    "încrezătoarele": "încrezător",
    "încrezătoarelor": "încrezător",
    "încrezători": "încrezător",
    "încrezătorii": "încrezător",
    "încrezătorilor": "încrezător",
    "încrezătorul": "încrezător",
    "încrezătorului": "încrezător",
    "încrezuta": "încrezut",
    "încrezută": "încrezut",
    "încrezute": "încrezut",
    "încrezutei": "încrezut",
    "încrezutele": "încrezut",
    "încrezutelor": "încrezut",
    "încrezuți": "încrezut",
    "încrezuții": "încrezut",
    "încrezuților": "încrezut",
    "încrezutul": "încrezut",
    "încrezutului": "încrezut",
    "incrimină": "incrimina",
    "incriminai": "incrimina",
    "incriminam": "incrimina",
    "incriminăm": "incrimina",
    "incriminând": "incrimina",
    "incriminându": "incrimina",
    "incriminară": "incrimina",
    "incriminarăm": "incrimina",
    "incriminarăți": "incrimina",
    "incriminase": "incrimina",
    "incriminasem": "incrimina",
    "incriminaseră": "incrimina",
    "incriminaserăm": "incrimina",
    "incriminaserăți": "incrimina",
    "incriminaseși": "incrimina",
    "incriminași": "incrimina",
    "incriminat": "incrimina",
    "incriminați": "incrimina",
    "incriminatu": "incrimina",
    "incriminau": "incrimina",
    "incriminează": "incrimina",
    "incriminez": "incrimina",
    "incrimineze": "incrimina",
    "incriminezi": "incrimina",
    "neincriminând": "incrimina",
    "neincriminându": "incrimina",
    "nemaiincriminând": "incrimina",
    "nemaiincriminându": "incrimina",
    "incriminarea": "incriminare",
    "incriminareo": "incriminare",
    "incriminări": "incriminare",
    "incriminării": "incriminare",
    "incriminările": "incriminare",
    "incriminărilor": "incriminare",
    "incriminată": "incriminat",
    "incriminate": "incriminat",
    "incriminați": "incriminat",
    "încropea": "încropi",
    "încropeai": "încropi",
    "încropeam": "încropi",
    "încropească": "încropi",
    "încropeați": "încropi",
    "încropeau": "încropi",
    "încropesc": "încropi",
    "încropește": "încropi",
    "încropești": "încropi",
    "încropii": "încropi",
    "încropim": "încropi",
    "încropind": "încropi",
    "încropindu": "încropi",
    "încropiră": "încropi",
    "încropirăm": "încropi",
    "încropirăți": "încropi",
    "încropise": "încropi",
    "încropisem": "încropi",
    "încropiseră": "încropi",
    "încropiserăm": "încropi",
    "încropiserăți": "încropi",
    "încropiseși": "încropi",
    "încropiși": "încropi",
    "încropit": "încropi",
    "încropiți": "încropi",
    "încropitu": "încropi",
    "neîncropind": "încropi",
    "neîncropindu": "încropi",
    "nemaiîncropind": "încropi",
    "nemaiîncropindu": "încropi",
    "încropită": "încropit",
    "încropite": "încropit",
    "încropiți": "încropit",
    "încrucea": "încruci",
    "încruceai": "încruci",
    "încruceam": "încruci",
    "încrucească": "încruci",
    "încruceați": "încruci",
    "încruceau": "încruci",
    "încrucesc": "încruci",
    "încrucește": "încruci",
    "încrucești": "încruci",
    "încrucii": "încruci",
    "încrucim": "încruci",
    "încrucind": "încruci",
    "încrucindu": "încruci",
    "încruciră": "încruci",
    "încrucirăm": "încruci",
    "încrucirăți": "încruci",
    "încrucise": "încruci",
    "încrucisem": "încruci",
    "încruciseră": "încruci",
    "încruciserăm": "încruci",
    "încruciserăți": "încruci",
    "încruciseși": "încruci",
    "încruciși": "încruci",
    "încrucit": "încruci",
    "încruciți": "încruci",
    "încrucitu": "încruci",
    "neîncrucind": "încruci",
    "neîncrucindu": "încruci",
    "nemaiîncrucind": "încruci",
    "nemaiîncrucindu": "încruci",
    "încrucișă": "încrucișa",
    "încrucișai": "încrucișa",
    "încrucișam": "încrucișa",
    "încrucișăm": "încrucișa",
    "încrucișând": "încrucișa",
    "încrucișându": "încrucișa",
    "încrucișară": "încrucișa",
    "încrucișarăm": "încrucișa",
    "încrucișarăți": "încrucișa",
    "încrucișase": "încrucișa",
    "încrucișasem": "încrucișa",
    "încrucișaseră": "încrucișa",
    "încrucișaserăm": "încrucișa",
    "încrucișaserăți": "încrucișa",
    "încrucișaseși": "încrucișa",
    "încrucișași": "încrucișa",
    "încrucișat": "încrucișa",
    "încrucișați": "încrucișa",
    "încrucișatu": "încrucișa",
    "încrucișau": "încrucișa",
    "încrucișează": "încrucișa",
    "încrucișez": "încrucișa",
    "încrucișeze": "încrucișa",
    "încrucișezi": "încrucișa",
    "neîncrucișând": "încrucișa",
    "neîncrucișându": "încrucișa",
    "nemaiîncrucișând": "încrucișa",
    "nemaiîncrucișându": "încrucișa",
    "încrucișarea": "încrucișare",
    "încrucișări": "încrucișare",
    "încrucișării": "încrucișare",
    "încrucișările": "încrucișare",
    "încrucișărilor": "încrucișare",
    "încrucișată": "încrucișat",
    "încrucișate": "încrucișat",
    "încrucișați": "încrucișat",
    "încrucită": "încrucit",
    "încrucite": "încrucit",
    "încruciți": "încrucit",
    "încrunt": "încrunta",
    "încruntă": "încrunta",
    "încruntai": "încrunta",
    "încruntam": "încrunta",
    "încruntăm": "încrunta",
    "încruntând": "încrunta",
    "încruntându": "încrunta",
    "încruntară": "încrunta",
    "încruntarăm": "încrunta",
    "încruntarăți": "încrunta",
    "încruntase": "încrunta",
    "încruntasem": "încrunta",
    "încruntaseră": "încrunta",
    "încruntaserăm": "încrunta",
    "încruntaserăți": "încrunta",
    "încruntaseși": "încrunta",
    "încruntași": "încrunta",
    "încruntat": "încrunta",
    "încruntați": "încrunta",
    "încruntatu": "încrunta",
    "încruntau": "încrunta",
    "încrunte": "încrunta",
    "încrunți": "încrunta",
    "neîncruntând": "încrunta",
    "neîncruntându": "încrunta",
    "nemaiîncruntând": "încrunta",
    "nemaiîncruntându": "încrunta",
    "încruntarea": "încruntare",
    "încruntareo": "încruntare",
    "încruntată": "încruntat",
    "încruntate": "încruntat",
    "încruntați": "încruntat",
    "incrustă": "incrusta",
    "incrustai": "incrusta",
    "incrustam": "incrusta",
    "incrustăm": "incrusta",
    "incrustând": "incrusta",
    "incrustându": "incrusta",
    "incrustară": "incrusta",
    "incrustarăm": "incrusta",
    "incrustarăți": "incrusta",
    "incrustase": "incrusta",
    "incrustasem": "incrusta",
    "incrustaseră": "incrusta",
    "incrustaserăm": "incrusta",
    "incrustaserăți": "incrusta",
    "incrustaseși": "incrusta",
    "incrustași": "incrusta",
    "incrustat": "incrusta",
    "incrustați": "incrusta",
    "incrustatu": "incrusta",
    "incrustau": "incrusta",
    "incrustează": "incrusta",
    "incrustez": "incrusta",
    "incrusteze": "incrusta",
    "incrustezi": "incrusta",
    "neincrustând": "incrusta",
    "neincrustându": "incrusta",
    "nemaiincrustând": "incrusta",
    "nemaiincrustându": "incrusta",
    "încrustă": "încrusta",
    "încrustai": "încrusta",
    "încrustam": "încrusta",
    "încrustăm": "încrusta",
    "încrustând": "încrusta",
    "încrustându": "încrusta",
    "încrustară": "încrusta",
    "încrustarăm": "încrusta",
    "încrustarăți": "încrusta",
    "încrustase": "încrusta",
    "încrustasem": "încrusta",
    "încrustaseră": "încrusta",
    "încrustaserăm": "încrusta",
    "încrustaserăți": "încrusta",
    "încrustaseși": "încrusta",
    "încrustași": "încrusta",
    "încrustat": "încrusta",
    "încrustați": "încrusta",
    "încrustatu": "încrusta",
    "încrustau": "încrusta",
    "încrustează": "încrusta",
    "încrustez": "încrusta",
    "încrusteze": "încrusta",
    "încrustezi": "încrusta",
    "incrustată": "incrustat",
    "incrustate": "incrustat",
    "incrustați": "incrustat",
    "încrustata": "încrustat",
    "încrustată": "încrustat",
    "încrustate": "încrustat",
    "încrustatei": "încrustat",
    "încrustatele": "încrustat",
    "încrustatelor": "încrustat",
    "încrustați": "încrustat",
    "încrustații": "încrustat",
    "încrustaților": "încrustat",
    "încrustato": "încrustat",
    "încrustatul": "încrustat",
    "încrustatule": "încrustat",
    "încrustatului": "încrustat",
    "incrustația": "incrustație",
    "incrustației": "incrustație",
    "incrustații": "incrustație",
    "incrustațiile": "incrustație",
    "incrustațiilor": "incrustație",
    "incubația": "incubație",
    "incubației": "incubație",
    "incubații": "incubație",
    "incubațiile": "incubație",
    "incubațiilor": "incubație",
    "încui": "încuia",
    "încuiai": "încuia",
    "încuiam": "încuia",
    "încuiară": "încuia",
    "încuiarăm": "încuia",
    "încuiarăți": "încuia",
    "încuiase": "încuia",
    "încuiasem": "încuia",
    "încuiaseră": "încuia",
    "încuiaserăm": "încuia",
    "încuiaserăți": "încuia",
    "încuiaseși": "încuia",
    "încuiași": "încuia",
    "încuiat": "încuia",
    "încuiați": "încuia",
    "încuiatu": "încuia",
    "încuiau": "încuia",
    "încuie": "încuia",
    "încuiem": "încuia",
    "încuind": "încuia",
    "încuindu": "încuia",
    "neîncuiind": "încuia",
    "neîncuiindu": "încuia",
    "nemaiîncuiind": "încuia",
    "nemaiîncuiindu": "încuia",
    "încuiată": "încuiat",
    "încuiate": "încuiat",
    "încuiați": "încuiat",
    "încuibă": "încuiba",
    "încuibai": "încuiba",
    "încuibam": "încuiba",
    "încuibăm": "încuiba",
    "încuibând": "încuiba",
    "încuibându": "încuiba",
    "încuibară": "încuiba",
    "încuibarăm": "încuiba",
    "încuibarăți": "încuiba",
    "încuibase": "încuiba",
    "încuibasem": "încuiba",
    "încuibaseră": "încuiba",
    "încuibaserăm": "încuiba",
    "încuibaserăți": "încuiba",
    "încuibaseși": "încuiba",
    "încuibași": "încuiba",
    "încuibat": "încuiba",
    "încuibați": "încuiba",
    "încuibatu": "încuiba",
    "încuibau": "încuiba",
    "încuibează": "încuiba",
    "încuibez": "încuiba",
    "încuibeze": "încuiba",
    "încuibezi": "încuiba",
    "neîncuibând": "încuiba",
    "neîncuibându": "încuiba",
    "nemaiîncuibând": "încuiba",
    "nemaiîncuibându": "încuiba",
    "încuibată": "încuibat",
    "încuibate": "încuibat",
    "încuibați": "încuibat",
    "inculc": "inculca",
    "inculcă": "inculca",
    "inculcai": "inculca",
    "inculcam": "inculca",
    "inculcăm": "inculca",
    "inculcând": "inculca",
    "inculcându": "inculca",
    "inculcară": "inculca",
    "inculcarăm": "inculca",
    "inculcarăți": "inculca",
    "inculcase": "inculca",
    "inculcasem": "inculca",
    "inculcaseră": "inculca",
    "inculcaserăm": "inculca",
    "inculcaserăți": "inculca",
    "inculcaseși": "inculca",
    "inculcași": "inculca",
    "inculcat": "inculca",
    "inculcați": "inculca",
    "inculcatu": "inculca",
    "inculcau": "inculca",
    "inculce": "inculca",
    "inculci": "inculca",
    "neinculcând": "inculca",
    "neinculcându": "inculca",
    "nemaiinculcând": "inculca",
    "nemaiinculcându": "inculca",
    "inculcarea": "inculcare",
    "inculcareo": "inculcare",
    "inculcări": "inculcare",
    "inculcării": "inculcare",
    "inculcările": "inculcare",
    "inculcărilor": "inculcare",
    "inculcată": "inculcat",
    "inculcate": "inculcat",
    "inculcați": "inculcat",
    "inculp": "inculpa",
    "inculpă": "inculpa",
    "inculpai": "inculpa",
    "inculpam": "inculpa",
    "inculpăm": "inculpa",
    "inculpând": "inculpa",
    "inculpându": "inculpa",
    "inculpară": "inculpa",
    "inculparăm": "inculpa",
    "inculparăți": "inculpa",
    "inculpase": "inculpa",
    "inculpasem": "inculpa",
    "inculpaseră": "inculpa",
    "inculpaserăm": "inculpa",
    "inculpaserăți": "inculpa",
    "inculpaseși": "inculpa",
    "inculpași": "inculpa",
    "inculpat": "inculpa",
    "inculpați": "inculpa",
    "inculpatu": "inculpa",
    "inculpau": "inculpa",
    "inculpe": "inculpa",
    "inculpi": "inculpa",
    "neinculpând": "inculpa",
    "neinculpându": "inculpa",
    "nemaiinculpând": "inculpa",
    "nemaiinculpându": "inculpa",
    "inculpată": "inculpat",
    "inculpate": "inculpat",
    "inculpați": "inculpat",
    "inculpații": "inculpat",
    "inculpaților": "inculpat",
    "inculpatul": "inculpat",
    "inculpatului": "inculpat",
    "inculta": "incult",
    "incultă": "incult",
    "inculte": "incult",
    "incultei": "incult",
    "incultele": "incult",
    "incultelor": "incult",
    "inculți": "incult",
    "inculții": "incult",
    "inculților": "incult",
    "incultul": "incult",
    "incultului": "incult",
    "incultura": "incultură",
    "incumb": "incumba",
    "incumbă": "incumba",
    "incumbai": "incumba",
    "incumbam": "incumba",
    "incumbăm": "incumba",
    "incumbând": "incumba",
    "incumbându": "incumba",
    "incumbară": "incumba",
    "incumbarăm": "incumba",
    "incumbarăți": "incumba",
    "incumbase": "incumba",
    "incumbasem": "incumba",
    "incumbaseră": "incumba",
    "incumbaserăm": "incumba",
    "incumbaserăți": "incumba",
    "incumbaseși": "incumba",
    "incumbași": "incumba",
    "incumbat": "incumba",
    "incumbați": "incumba",
    "incumbatu": "incumba",
    "incumbau": "incumba",
    "incumbe": "incumba",
    "incumbi": "incumba",
    "neincumbând": "incumba",
    "neincumbându": "incumba",
    "nemaiincumbând": "incumba",
    "nemaiincumbându": "incumba",
    "incumbată": "incumbat",
    "incumbate": "incumbat",
    "incumbați": "incumbat",
    "încumet": "încumeta",
    "încumetă": "încumeta",
    "încumetai": "încumeta",
    "încumetam": "încumeta",
    "încumetăm": "încumeta",
    "încumetând": "încumeta",
    "încumetându": "încumeta",
    "încumetară": "încumeta",
    "încumetarăm": "încumeta",
    "încumetarăți": "încumeta",
    "încumetase": "încumeta",
    "încumetasem": "încumeta",
    "încumetaseră": "încumeta",
    "încumetaserăm": "încumeta",
    "încumetaserăți": "încumeta",
    "încumetaseși": "încumeta",
    "încumetași": "încumeta",
    "încumetat": "încumeta",
    "încumetați": "încumeta",
    "încumetatu": "încumeta",
    "încumetau": "încumeta",
    "încumete": "încumeta",
    "încumeți": "încumeta",
    "neîncumetând": "încumeta",
    "neîncumetându": "încumeta",
    "nemaiîncumetând": "încumeta",
    "nemaiîncumetându": "încumeta",
    "încumetată": "încumetat",
    "încumetate": "încumetat",
    "încumetați": "încumetat",
    "încumetrea": "încumetri",
    "încumetreai": "încumetri",
    "încumetream": "încumetri",
    "încumetrească": "încumetri",
    "încumetreați": "încumetri",
    "încumetreau": "încumetri",
    "încumetresc": "încumetri",
    "încumetrește": "încumetri",
    "încumetrești": "încumetri",
    "încumetrii": "încumetri",
    "încumetrim": "încumetri",
    "încumetrind": "încumetri",
    "încumetrindu": "încumetri",
    "încumetriră": "încumetri",
    "încumetrirăm": "încumetri",
    "încumetrirăți": "încumetri",
    "încumetrise": "încumetri",
    "încumetrisem": "încumetri",
    "încumetriseră": "încumetri",
    "încumetriserăm": "încumetri",
    "încumetriserăți": "încumetri",
    "încumetriseși": "încumetri",
    "încumetriși": "încumetri",
    "încumetrit": "încumetri",
    "încumetriți": "încumetri",
    "încumetritu": "încumetri",
    "neîncumetrind": "încumetri",
    "neîncumetrindu": "încumetri",
    "nemaiîncumetrind": "încumetri",
    "nemaiîncumetrindu": "încumetri",
    "încumetrită": "încumetrit",
    "încumetrite": "încumetrit",
    "încumetriți": "încumetrit",
    "încunoștință": "încunoștința",
    "încunoștințai": "încunoștința",
    "încunoștințam": "încunoștința",
    "încunoștințăm": "încunoștința",
    "încunoștințând": "încunoștința",
    "încunoștințându": "încunoștința",
    "încunoștințară": "încunoștința",
    "încunoștințarăm": "încunoștința",
    "încunoștințarăți": "încunoștința",
    "încunoștințase": "încunoștința",
    "încunoștințasem": "încunoștința",
    "încunoștințaseră": "încunoștința",
    "încunoștințaserăm": "încunoștința",
    "încunoștințaserăți": "încunoștința",
    "încunoștințaseși": "încunoștința",
    "încunoștințași": "încunoștința",
    "încunoștințat": "încunoștința",
    "încunoștințați": "încunoștința",
    "încunoștințatu": "încunoștința",
    "încunoștințau": "încunoștința",
    "încunoștințează": "încunoștința",
    "încunoștințez": "încunoștința",
    "încunoștințeze": "încunoștința",
    "încunoștințezi": "încunoștința",
    "neîncunoștințând": "încunoștința",
    "neîncunoștințându": "încunoștința",
    "nemaiîncunoștințând": "încunoștința",
    "nemaiîncunoștințându": "încunoștința",
    "încunoștințată": "încunoștințat",
    "încunoștințate": "încunoștințat",
    "încunoștințați": "încunoștințat",
    "încunună": "încununa",
    "încununai": "încununa",
    "încununam": "încununa",
    "încununăm": "încununa",
    "încununând": "încununa",
    "încununându": "încununa",
    "încununară": "încununa",
    "încununarăm": "încununa",
    "încununarăți": "încununa",
    "încununase": "încununa",
    "încununasem": "încununa",
    "încununaseră": "încununa",
    "încununaserăm": "încununa",
    "încununaserăți": "încununa",
    "încununaseși": "încununa",
    "încununași": "încununa",
    "încununat": "încununa",
    "încununați": "încununa",
    "încununatu": "încununa",
    "încununau": "încununa",
    "încununează": "încununa",
    "încununez": "încununa",
    "încununeze": "încununa",
    "încununezi": "încununa",
    "neîncununând": "încununa",
    "neîncununându": "încununa",
    "nemaiîncununând": "încununa",
    "nemaiîncununându": "încununa",
    "încununată": "încununat",
    "încununate": "încununat",
    "încununați": "încununat",
    "încur": "încura",
    "încură": "încura",
    "încurai": "încura",
    "încuram": "încura",
    "încurăm": "încura",
    "încurând": "încura",
    "încurându": "încura",
    "încurară": "încura",
    "încurarăm": "încura",
    "încurarăți": "încura",
    "încurase": "încura",
    "încurasem": "încura",
    "încuraseră": "încura",
    "încuraserăm": "încura",
    "încuraserăți": "încura",
    "încuraseși": "încura",
    "încurași": "încura",
    "încurat": "încura",
    "încurați": "încura",
    "încuratu": "încura",
    "încurau": "încura",
    "încure": "încura",
    "încuri": "încura",
    "neîncurând": "încura",
    "neîncurându": "încura",
    "nemaiîncurând": "încura",
    "nemaiîncurându": "încura",
    "incurabila": "incurabil",
    "incurabilă": "incurabil",
    "incurabile": "incurabil",
    "incurabilei": "incurabil",
    "incurabilele": "incurabil",
    "incurabilelor": "incurabil",
    "incurabili": "incurabil",
    "incurabilii": "incurabil",
    "incurabililor": "incurabil",
    "incurabilul": "incurabil",
    "incurabilului": "incurabil",
    "încurajă": "încuraja",
    "încurajai": "încuraja",
    "încurajam": "încuraja",
    "încurajăm": "încuraja",
    "încurajând": "încuraja",
    "încurajându": "încuraja",
    "încurajară": "încuraja",
    "încurajarăm": "încuraja",
    "încurajarăți": "încuraja",
    "încurajase": "încuraja",
    "încurajasem": "încuraja",
    "încurajaseră": "încuraja",
    "încurajaserăm": "încuraja",
    "încurajaserăți": "încuraja",
    "încurajaseși": "încuraja",
    "încurajași": "încuraja",
    "încurajat": "încuraja",
    "încurajați": "încuraja",
    "încurajatu": "încuraja",
    "încurajau": "încuraja",
    "încurajează": "încuraja",
    "încurajez": "încuraja",
    "încurajeze": "încuraja",
    "încurajezi": "încuraja",
    "neîncurajând": "încuraja",
    "neîncurajându": "încuraja",
    "nemaiîncurajând": "încuraja",
    "nemaiîncurajându": "încuraja",
    "încurajarea": "încurajare",
    "încurajări": "încurajare",
    "încurajării": "încurajare",
    "încurajările": "încurajare",
    "încurajărilor": "încurajare",
    "încurajată": "încurajat",
    "încurajate": "încurajat",
    "încurajați": "încurajat",
    "încurajatoare": "încurajator",
    "încurajatoarea": "încurajator",
    "încurajatoarei": "încurajator",
    "încurajatoarele": "încurajator",
    "încurajatoarelor": "încurajator",
    "încurajatoareo": "încurajator",
    "încurajatori": "încurajator",
    "încurajatorii": "încurajator",
    "încurajatorilor": "încurajator",
    "încurajatorul": "încurajator",
    "încurajatorule": "încurajator",
    "încurajatorului": "încurajator",
    "încurată": "încurat",
    "încurate": "încurat",
    "încurați": "încurat",
    "încurc": "încurca",
    "încurcă": "încurca",
    "încurcai": "încurca",
    "încurcam": "încurca",
    "încurcăm": "încurca",
    "încurcând": "încurca",
    "încurcându": "încurca",
    "încurcară": "încurca",
    "încurcarăm": "încurca",
    "încurcarăți": "încurca",
    "încurcase": "încurca",
    "încurcasem": "încurca",
    "încurcaseră": "încurca",
    "încurcaserăm": "încurca",
    "încurcaserăți": "încurca",
    "încurcaseși": "încurca",
    "încurcași": "încurca",
    "încurcat": "încurca",
    "încurcați": "încurca",
    "încurcatu": "încurca",
    "încurcau": "încurca",
    "încurce": "încurca",
    "încurci": "încurca",
    "neîncurcând": "încurca",
    "neîncurcându": "încurca",
    "nemaiîncurcând": "încurca",
    "nemaiîncurcându": "încurca",
    "încurcarea": "încurcare",
    "încurcări": "încurcare",
    "încurcării": "încurcare",
    "încurcările": "încurcare",
    "încurcărilor": "încurcare",
    "încurcata": "încurcat",
    "încurcată": "încurcat",
    "încurcate": "încurcat",
    "încurcatei": "încurcat",
    "încurcatele": "încurcat",
    "încurcatelor": "încurcat",
    "încurcați": "încurcat",
    "încurcații": "încurcat",
    "încurcaților": "încurcat",
    "încurcatul": "încurcat",
    "încurcatului": "încurcat",
    "încurcătura": "încurcătură",
    "încurcături": "încurcătură",
    "încurcăturii": "încurcătură",
    "încurcăturile": "încurcătură",
    "încurcăturilor": "încurcătură",
    "încurelă": "încurela",
    "încurelai": "încurela",
    "încurelam": "încurela",
    "încurelăm": "încurela",
    "încurelând": "încurela",
    "încurelându": "încurela",
    "încurelară": "încurela",
    "încurelarăm": "încurela",
    "încurelarăți": "încurela",
    "încurelase": "încurela",
    "încurelasem": "încurela",
    "încurelaseră": "încurela",
    "încurelaserăm": "încurela",
    "încurelaserăți": "încurela",
    "încurelaseși": "încurela",
    "încurelași": "încurela",
    "încurelat": "încurela",
    "încurelați": "încurela",
    "încurelatu": "încurela",
    "încurelau": "încurela",
    "încurelează": "încurela",
    "încurelez": "încurela",
    "încureleze": "încurela",
    "încurelezi": "încurela",
    "neîncurelând": "încurela",
    "neîncurelându": "încurela",
    "nemaiîncurelând": "încurela",
    "nemaiîncurelându": "încurela",
    "încurelată": "încurelat",
    "încurelate": "încurelat",
    "încurelați": "încurelat",
    "incursiunea": "incursiune",
    "incursiuneo": "incursiune",
    "incursiuni": "incursiune",
    "incursiunii": "incursiune",
    "incursiunile": "incursiune",
    "incursiunilor": "incursiune",
    "încuscrea": "încuscri",
    "încuscreai": "încuscri",
    "încuscream": "încuscri",
    "încuscrească": "încuscri",
    "încuscreați": "încuscri",
    "încuscreau": "încuscri",
    "încuscresc": "încuscri",
    "încuscrește": "încuscri",
    "încuscrești": "încuscri",
    "încuscrii": "încuscri",
    "încuscrim": "încuscri",
    "încuscrind": "încuscri",
    "încuscrindu": "încuscri",
    "încuscriră": "încuscri",
    "încuscrirăm": "încuscri",
    "încuscrirăți": "încuscri",
    "încuscrise": "încuscri",
    "încuscrisem": "încuscri",
    "încuscriseră": "încuscri",
    "încuscriserăm": "încuscri",
    "încuscriserăți": "încuscri",
    "încuscriseși": "încuscri",
    "încuscriși": "încuscri",
    "încuscrit": "încuscri",
    "încuscriți": "încuscri",
    "încuscritu": "încuscri",
    "neîncuscrind": "încuscri",
    "neîncuscrindu": "încuscri",
    "nemaiîncuscrind": "încuscri",
    "nemaiîncuscrindu": "încuscri",
    "încuscrită": "încuscrit",
    "încuscrite": "încuscrit",
    "încuscriți": "încuscrit",
    "încuviință": "încuviința",
    "încuviințai": "încuviința",
    "încuviințam": "încuviința",
    "încuviințăm": "încuviința",
    "încuviințând": "încuviința",
    "încuviințându": "încuviința",
    "încuviințară": "încuviința",
    "încuviințarăm": "încuviința",
    "încuviințarăți": "încuviința",
    "încuviințase": "încuviința",
    "încuviințasem": "încuviința",
    "încuviințaseră": "încuviința",
    "încuviințaserăm": "încuviința",
    "încuviințaserăți": "încuviința",
    "încuviințaseși": "încuviința",
    "încuviințași": "încuviința",
    "încuviințat": "încuviința",
    "încuviințați": "încuviința",
    "încuviințatu": "încuviința",
    "încuviințau": "încuviința",
    "încuviințează": "încuviința",
    "încuviințez": "încuviința",
    "încuviințeze": "încuviința",
    "încuviințezi": "încuviința",
    "neîncuviințând": "încuviința",
    "neîncuviințându": "încuviința",
    "nemaiîncuviințând": "încuviința",
    "nemaiîncuviințându": "încuviința",
    "încuviințarea": "încuviințare",
    "încuviințări": "încuviințare",
    "încuviințării": "încuviințare",
    "încuviințările": "încuviințare",
    "încuviințărilor": "încuviințare",
    "încuviințată": "încuviințat",
    "încuviințate": "încuviințat",
    "încuviințați": "încuviințat",
    "îndărătnica": "îndărătnic",
    "îndărătnică": "îndărătnic",
    "îndărătnice": "îndărătnic",
    "îndărătnicei": "îndărătnic",
    "îndărătnicele": "îndărătnic",
    "îndărătnicelor": "îndărătnic",
    "îndărătnici": "îndărătnic",
    "îndărătnicii": "îndărătnic",
    "îndărătnicilor": "îndărătnic",
    "îndărătnicul": "îndărătnic",
    "îndărătnicului": "îndărătnic",
    "îndărătnicea": "îndărătnici",
    "îndărătniceai": "îndărătnici",
    "îndărătniceam": "îndărătnici",
    "îndărătnicească": "îndărătnici",
    "îndărătniceați": "îndărătnici",
    "îndărătniceau": "îndărătnici",
    "îndărătnicesc": "îndărătnici",
    "îndărătnicește": "îndărătnici",
    "îndărătnicești": "îndărătnici",
    "îndărătnicii": "îndărătnici",
    "îndărătnicim": "îndărătnici",
    "îndărătnicind": "îndărătnici",
    "îndărătnicindu": "îndărătnici",
    "îndărătniciră": "îndărătnici",
    "îndărătnicirăm": "îndărătnici",
    "îndărătnicirăți": "îndărătnici",
    "îndărătnicise": "îndărătnici",
    "îndărătnicisem": "îndărătnici",
    "îndărătniciseră": "îndărătnici",
    "îndărătniciserăm": "îndărătnici",
    "îndărătniciserăți": "îndărătnici",
    "îndărătniciseși": "îndărătnici",
    "îndărătniciși": "îndărătnici",
    "îndărătnicit": "îndărătnici",
    "îndărătniciți": "îndărătnici",
    "îndărătnicitu": "îndărătnici",
    "neîndărătnicind": "îndărătnici",
    "neîndărătnicindu": "îndărătnici",
    "nemaiîndărătnicind": "îndărătnici",
    "nemaiîndărătnicindu": "îndărătnici",
    "îndărătnicia": "îndărătnicie",
    "îndărătniciei": "îndărătnicie",
    "îndărătnicii": "îndărătnicie",
    "îndărătniciile": "îndărătnicie",
    "îndărătniciilor": "îndărătnicie",
    "îndărătnicită": "îndărătnicit",
    "îndărătnicite": "îndărătnicit",
    "îndărătniciți": "îndărătnicit",
    "îndârjea": "îndârji",
    "îndârjeai": "îndârji",
    "îndârjeam": "îndârji",
    "îndârjească": "îndârji",
    "îndârjeați": "îndârji",
    "îndârjeau": "îndârji",
    "îndârjesc": "îndârji",
    "îndârjește": "îndârji",
    "îndârjești": "îndârji",
    "îndârjii": "îndârji",
    "îndârjim": "îndârji",
    "îndârjind": "îndârji",
    "îndârjindu": "îndârji",
    "îndârjiră": "îndârji",
    "îndârjirăm": "îndârji",
    "îndârjirăți": "îndârji",
    "îndârjise": "îndârji",
    "îndârjisem": "îndârji",
    "îndârjiseră": "îndârji",
    "îndârjiserăm": "îndârji",
    "îndârjiserăți": "îndârji",
    "îndârjiseși": "îndârji",
    "îndârjiși": "îndârji",
    "îndârjit": "îndârji",
    "îndârjiți": "îndârji",
    "îndârjitu": "îndârji",
    "neîndârjind": "îndârji",
    "neîndârjindu": "îndârji",
    "nemaiîndârjind": "îndârji",
    "nemaiîndârjindu": "îndârji",
    "îndârjirea": "îndârjire",
    "îndârjiri": "îndârjire",
    "îndârjirii": "îndârjire",
    "îndârjirile": "îndârjire",
    "îndârjirilor": "îndârjire",
    "îndârjita": "îndârjit",
    "îndârjită": "îndârjit",
    "îndârjite": "îndârjit",
    "îndârjitei": "îndârjit",
    "îndârjitele": "îndârjit",
    "îndârjitelor": "îndârjit",
    "îndârjiți": "îndârjit",
    "îndârjiții": "îndârjit",
    "îndârjiților": "îndârjit",
    "îndârjitul": "îndârjit",
    "îndârjitului": "îndârjit",
    "îndătină": "îndătina",
    "îndătinai": "îndătina",
    "îndătinam": "îndătina",
    "îndătinăm": "îndătina",
    "îndătinând": "îndătina",
    "îndătinându": "îndătina",
    "îndătinară": "îndătina",
    "îndătinarăm": "îndătina",
    "îndătinarăți": "îndătina",
    "îndătinase": "îndătina",
    "îndătinasem": "îndătina",
    "îndătinaseră": "îndătina",
    "îndătinaserăm": "îndătina",
    "îndătinaserăți": "îndătina",
    "îndătinaseși": "îndătina",
    "îndătinași": "îndătina",
    "îndătinat": "îndătina",
    "îndătinați": "îndătina",
    "îndătinatu": "îndătina",
    "îndătinau": "îndătina",
    "îndătinează": "îndătina",
    "îndătinez": "îndătina",
    "îndătineze": "îndătina",
    "îndătinezi": "îndătina",
    "neîndătinând": "îndătina",
    "neîndătinându": "îndătina",
    "nemaiîndătinând": "îndătina",
    "nemaiîndătinându": "îndătina",
    "îndătinată": "îndătinat",
    "îndătinate": "îndătinat",
    "îndătinați": "îndătinat",
    "îndatoră": "îndatora",
    "îndatorai": "îndatora",
    "îndatoram": "îndatora",
    "îndatorăm": "îndatora",
    "îndatorând": "îndatora",
    "îndatorându": "îndatora",
    "îndatorară": "îndatora",
    "îndatorarăm": "îndatora",
    "îndatorarăți": "îndatora",
    "îndatorase": "îndatora",
    "îndatorasem": "îndatora",
    "îndatoraseră": "îndatora",
    "îndatoraserăm": "îndatora",
    "îndatoraserăți": "îndatora",
    "îndatoraseși": "îndatora",
    "îndatorași": "îndatora",
    "îndatorat": "îndatora",
    "îndatorați": "îndatora",
    "îndatoratu": "îndatora",
    "îndatorau": "îndatora",
    "îndatorează": "îndatora",
    "îndatorez": "îndatora",
    "îndatoreze": "îndatora",
    "îndatorezi": "îndatora",
    "neîndatorând": "îndatora",
    "neîndatorându": "îndatora",
    "nemaiîndatorând": "îndatora",
    "nemaiîndatorându": "îndatora",
    "îndatorată": "îndatorat",
    "îndatorate": "îndatorat",
    "îndatorați": "îndatorat",
    "îndatorirea": "îndatorire",
    "îndatoriri": "îndatorire",
    "îndatoririi": "îndatorire",
    "îndatoririle": "îndatorire",
    "îndatoririlor": "îndatorire",
    "îndatoritoare": "îndatoritor",
    "îndatoritoarea": "îndatoritor",
    "îndatoritoarei": "îndatoritor",
    "îndatoritoarele": "îndatoritor",
    "îndatoritoarelor": "îndatoritor",
    "îndatoritori": "îndatoritor",
    "îndatoritorii": "îndatoritor",
    "îndatoritorilor": "îndatoritor",
    "îndatoritorul": "îndatoritor",
    "îndatoritorului": "îndatoritor",
    "indecenta": "indecent",
    "indecentă": "indecent",
    "indecente": "indecent",
    "indecentei": "indecent",
    "indecentele": "indecent",
    "indecentelor": "indecent",
    "indecenți": "indecent",
    "indecenții": "indecent",
    "indecenților": "indecent",
    "indecentul": "indecent",
    "indecentului": "indecent",
    "indecizia": "indecizie",
    "indefinita": "indefinit",
    "indefinită": "indefinit",
    "indefinite": "indefinit",
    "indefinitei": "indefinit",
    "indefinitele": "indefinit",
    "indefinitelor": "indefinit",
    "indefiniți": "indefinit",
    "indefiniții": "indefinit",
    "indefiniților": "indefinit",
    "indefinitul": "indefinit",
    "indefinitului": "indefinit",
    "îndeletnicea": "îndeletnici",
    "îndeletniceai": "îndeletnici",
    "îndeletniceam": "îndeletnici",
    "îndeletnicească": "îndeletnici",
    "îndeletniceați": "îndeletnici",
    "îndeletniceau": "îndeletnici",
    "îndeletnicesc": "îndeletnici",
    "îndeletnicește": "îndeletnici",
    "îndeletnicești": "îndeletnici",
    "îndeletnicii": "îndeletnici",
    "îndeletnicim": "îndeletnici",
    "îndeletnicind": "îndeletnici",
    "îndeletnicindu": "îndeletnici",
    "îndeletniciră": "îndeletnici",
    "îndeletnicirăm": "îndeletnici",
    "îndeletnicirăți": "îndeletnici",
    "îndeletnicise": "îndeletnici",
    "îndeletnicisem": "îndeletnici",
    "îndeletniciseră": "îndeletnici",
    "îndeletniciserăm": "îndeletnici",
    "îndeletniciserăți": "îndeletnici",
    "îndeletniciseși": "îndeletnici",
    "îndeletniciși": "îndeletnici",
    "îndeletnicit": "îndeletnici",
    "îndeletniciți": "îndeletnici",
    "îndeletnicitu": "îndeletnici",
    "neîndeletnicind": "îndeletnici",
    "neîndeletnicindu": "îndeletnici",
    "nemaiîndeletnicind": "îndeletnici",
    "nemaiîndeletnicindu": "îndeletnici",
    "îndeletnicirea": "îndeletnicire",
    "îndeletniciri": "îndeletnicire",
    "îndeletnicirii": "îndeletnicire",
    "îndeletnicirile": "îndeletnicire",
    "îndeletnicirilor": "îndeletnicire",
    "îndeletnicită": "îndeletnicit",
    "îndeletnicite": "îndeletnicit",
    "îndeletniciți": "îndeletnicit",
    "îndelung": "îndelunga",
    "îndelungă": "îndelunga",
    "îndelungai": "îndelunga",
    "îndelungam": "îndelunga",
    "îndelungăm": "îndelunga",
    "îndelungând": "îndelunga",
    "îndelungându": "îndelunga",
    "îndelungară": "îndelunga",
    "îndelungarăm": "îndelunga",
    "îndelungarăți": "îndelunga",
    "îndelungase": "îndelunga",
    "îndelungasem": "îndelunga",
    "îndelungaseră": "îndelunga",
    "îndelungaserăm": "îndelunga",
    "îndelungaserăți": "îndelunga",
    "îndelungaseși": "îndelunga",
    "îndelungași": "îndelunga",
    "îndelungat": "îndelunga",
    "îndelungați": "îndelunga",
    "îndelungatu": "îndelunga",
    "îndelungau": "îndelunga",
    "îndelunge": "îndelunga",
    "îndelungi": "îndelunga",
    "neîndelungând": "îndelunga",
    "neîndelungându": "îndelunga",
    "nemaiîndelungând": "îndelunga",
    "nemaiîndelungându": "îndelunga",
    "îndelungata": "îndelungat",
    "îndelungată": "îndelungat",
    "îndelungate": "îndelungat",
    "îndelungatei": "îndelungat",
    "îndelungatele": "îndelungat",
    "îndelungatelor": "îndelungat",
    "îndelungați": "îndelungat",
    "îndelungații": "îndelungat",
    "îndelungaților": "îndelungat",
    "îndelungatul": "îndelungat",
    "îndelungatului": "îndelungat",
    "îndemână": "îndemâna",
    "îndemânai": "îndemâna",
    "îndemânam": "îndemâna",
    "îndemânăm": "îndemâna",
    "îndemânând": "îndemâna",
    "îndemânându": "îndemâna",
    "îndemânară": "îndemâna",
    "îndemânarăm": "îndemâna",
    "îndemânarăți": "îndemâna",
    "îndemânase": "îndemâna",
    "îndemânasem": "îndemâna",
    "îndemânaseră": "îndemâna",
    "îndemânaserăm": "îndemâna",
    "îndemânaserăți": "îndemâna",
    "îndemânaseși": "îndemâna",
    "îndemânași": "îndemâna",
    "îndemânat": "îndemâna",
    "îndemânați": "îndemâna",
    "îndemânatu": "îndemâna",
    "îndemânau": "îndemâna",
    "îndemânează": "îndemâna",
    "îndemânez": "îndemâna",
    "îndemâneze": "îndemâna",
    "îndemânezi": "îndemâna",
    "neîndemânând": "îndemâna",
    "neîndemânându": "îndemâna",
    "nemaiîndemânând": "îndemâna",
    "nemaiîndemânându": "îndemâna",
    "îndemânarea": "îndemânare",
    "îndemânări": "îndemânare",
    "îndemânării": "îndemânare",
    "îndemânările": "îndemânare",
    "îndemânărilor": "îndemânare",
    "îndemânată": "îndemânat",
    "îndemânate": "îndemânat",
    "îndemânați": "îndemânat",
    "îndemânatica": "îndemânatic",
    "îndemânatică": "îndemânatic",
    "îndemânatice": "îndemânatic",
    "îndemânaticei": "îndemânatic",
    "îndemânaticele": "îndemânatic",
    "îndemânaticelor": "îndemânatic",
    "îndemânatici": "îndemânatic",
    "îndemânaticii": "îndemânatic",
    "îndemânaticilor": "îndemânatic",
    "îndemânaticul": "îndemânatic",
    "îndemânaticului": "îndemânatic",
    "îndemnul": "îndemn",
    "îndemnului": "îndemn",
    "îndemnuri": "îndemn",
    "îndemnurile": "îndemn",
    "îndemnurilor": "îndemn",
    "îndeamnă": "îndemna",
    "îndemn": "îndemna",
    "îndemnă": "îndemna",
    "îndemnai": "îndemna",
    "îndemnam": "îndemna",
    "îndemnăm": "îndemna",
    "îndemnând": "îndemna",
    "îndemnându": "îndemna",
    "îndemnară": "îndemna",
    "îndemnarăm": "îndemna",
    "îndemnarăți": "îndemna",
    "îndemnase": "îndemna",
    "îndemnasem": "îndemna",
    "îndemnaseră": "îndemna",
    "îndemnaserăm": "îndemna",
    "îndemnaserăți": "îndemna",
    "îndemnaseși": "îndemna",
    "îndemnași": "îndemna",
    "îndemnat": "îndemna",
    "îndemnați": "îndemna",
    "îndemnatu": "îndemna",
    "îndemnau": "îndemna",
    "îndemne": "îndemna",
    "îndemni": "îndemna",
    "neîndemnând": "îndemna",
    "neîndemnându": "îndemna",
    "nemaiîndemnând": "îndemna",
    "nemaiîndemnându": "îndemna",
    "îndemnarea": "îndemnare",
    "îndemnareo": "îndemnare",
    "îndemnări": "îndemnare",
    "îndemnării": "îndemnare",
    "îndemnările": "îndemnare",
    "îndemnărilor": "îndemnare",
    "îndemnată": "îndemnat",
    "îndemnate": "îndemnat",
    "îndemnați": "îndemnat",
    "indemniză": "indemniza",
    "indemnizai": "indemniza",
    "indemnizam": "indemniza",
    "indemnizăm": "indemniza",
    "indemnizând": "indemniza",
    "indemnizându": "indemniza",
    "indemnizară": "indemniza",
    "indemnizarăm": "indemniza",
    "indemnizarăți": "indemniza",
    "indemnizase": "indemniza",
    "indemnizasem": "indemniza",
    "indemnizaseră": "indemniza",
    "indemnizaserăm": "indemniza",
    "indemnizaserăți": "indemniza",
    "indemnizaseși": "indemniza",
    "indemnizași": "indemniza",
    "indemnizat": "indemniza",
    "indemnizați": "indemniza",
    "indemnizatu": "indemniza",
    "indemnizau": "indemniza",
    "indemnizează": "indemniza",
    "indemnizez": "indemniza",
    "indemnizeze": "indemniza",
    "indemnizezi": "indemniza",
    "neindemnizând": "indemniza",
    "neindemnizându": "indemniza",
    "nemaiindemnizând": "indemniza",
    "nemaiindemnizându": "indemniza",
    "indemnizată": "indemnizat",
    "indemnizate": "indemnizat",
    "indemnizați": "indemnizat",
    "indemnizația": "indemnizație",
    "indemnizației": "indemnizație",
    "indemnizații": "indemnizație",
    "indemnizațiile": "indemnizație",
    "indemnizațiilor": "indemnizație",
    "îndepărtă": "îndepărta",
    "îndepărtai": "îndepărta",
    "îndepărtam": "îndepărta",
    "îndepărtăm": "îndepărta",
    "îndepărtând": "îndepărta",
    "îndepărtându": "îndepărta",
    "îndepărtară": "îndepărta",
    "îndepărtarăm": "îndepărta",
    "îndepărtarăți": "îndepărta",
    "îndepărtase": "îndepărta",
    "îndepărtasem": "îndepărta",
    "îndepărtaseră": "îndepărta",
    "îndepărtaserăm": "îndepărta",
    "îndepărtaserăți": "îndepărta",
    "îndepărtaseși": "îndepărta",
    "îndepărtași": "îndepărta",
    "îndepărtat": "îndepărta",
    "îndepărtați": "îndepărta",
    "îndepărtatu": "îndepărta",
    "îndepărtau": "îndepărta",
    "îndepărtează": "îndepărta",
    "îndepărtez": "îndepărta",
    "îndepărteze": "îndepărta",
    "îndepărtezi": "îndepărta",
    "neîndepărtând": "îndepărta",
    "neîndepărtându": "îndepărta",
    "nemaiîndepărtând": "îndepărta",
    "nemaiîndepărtându": "îndepărta",
    "îndepărtarea": "îndepărtare",
    "îndepărtări": "îndepărtare",
    "îndepărtării": "îndepărtare",
    "îndepărtările": "îndepărtare",
    "îndepărtărilor": "îndepărtare",
    "îndepărtata": "îndepărtat",
    "îndepărtată": "îndepărtat",
    "îndepărtate": "îndepărtat",
    "îndepărtatei": "îndepărtat",
    "îndepărtatele": "îndepărtat",
    "îndepărtatelor": "îndepărtat",
    "îndepărtați": "îndepărtat",
    "îndepărtații": "îndepărtat",
    "îndepărtaților": "îndepărtat",
    "îndepărtatul": "îndepărtat",
    "îndepărtatului": "îndepărtat",
    "independenta": "independent",
    "independentă": "independent",
    "independente": "independent",
    "independentei": "independent",
    "independentele": "independent",
    "independentelor": "independent",
    "independenți": "independent",
    "independenții": "independent",
    "independenților": "independent",
    "independentul": "independent",
    "independentului": "independent",
    "independența": "independență",
    "independențe": "independență",
    "independenței": "independență",
    "independențele": "independență",
    "independențelor": "independență",
    "independențo": "independență",
    "îndeplinea": "îndeplini",
    "îndeplineai": "îndeplini",
    "îndeplineam": "îndeplini",
    "îndeplinească": "îndeplini",
    "îndeplineați": "îndeplini",
    "îndeplineau": "îndeplini",
    "îndeplinesc": "îndeplini",
    "îndeplinește": "îndeplini",
    "îndeplinești": "îndeplini",
    "îndeplinii": "îndeplini",
    "îndeplinim": "îndeplini",
    "îndeplinind": "îndeplini",
    "îndeplinindu": "îndeplini",
    "îndepliniră": "îndeplini",
    "îndeplinirăm": "îndeplini",
    "îndeplinirăți": "îndeplini",
    "îndeplinise": "îndeplini",
    "îndeplinisem": "îndeplini",
    "îndepliniseră": "îndeplini",
    "îndepliniserăm": "îndeplini",
    "îndepliniserăți": "îndeplini",
    "îndepliniseși": "îndeplini",
    "îndepliniși": "îndeplini",
    "îndeplinit": "îndeplini",
    "îndepliniți": "îndeplini",
    "îndeplinitu": "îndeplini",
    "neîndeplinind": "îndeplini",
    "neîndeplinindu": "îndeplini",
    "nemaiîndeplinind": "îndeplini",
    "nemaiîndeplinindu": "îndeplini",
    "îndeplinirea": "îndeplinire",
    "îndepliniri": "îndeplinire",
    "îndeplinirii": "îndeplinire",
    "îndeplinirile": "îndeplinire",
    "îndeplinirilor": "îndeplinire",
    "îndeplinită": "îndeplinit",
    "îndeplinite": "îndeplinit",
    "îndepliniți": "îndeplinit",
    "îndes": "îndesa",
    "îndesă": "îndesa",
    "îndesai": "îndesa",
    "îndesam": "îndesa",
    "îndesăm": "îndesa",
    "îndesând": "îndesa",
    "îndesându": "îndesa",
    "îndesară": "îndesa",
    "îndesarăm": "îndesa",
    "îndesarăți": "îndesa",
    "îndesase": "îndesa",
    "îndesasem": "îndesa",
    "îndesaseră": "îndesa",
    "îndesaserăm": "îndesa",
    "îndesaserăți": "îndesa",
    "îndesaseși": "îndesa",
    "îndesași": "îndesa",
    "îndesat": "îndesa",
    "îndesați": "îndesa",
    "îndesatu": "îndesa",
    "îndesau": "îndesa",
    "îndese": "îndesa",
    "îndeși": "îndesa",
    "neîndesând": "îndesa",
    "neîndesându": "îndesa",
    "nemaiîndesând": "îndesa",
    "nemaiîndesându": "îndesa",
    "îndesata": "îndesat",
    "îndesată": "îndesat",
    "îndesate": "îndesat",
    "îndesatei": "îndesat",
    "îndesatele": "îndesat",
    "îndesatelor": "îndesat",
    "îndesați": "îndesat",
    "îndesații": "îndesat",
    "îndesaților": "îndesat",
    "îndesatul": "îndesat",
    "îndesatului": "îndesat",
    "indescifrabila": "indescifrabil",
    "indescifrabilă": "indescifrabil",
    "indescifrabile": "indescifrabil",
    "indescifrabilei": "indescifrabil",
    "indescifrabilele": "indescifrabil",
    "indescifrabilelor": "indescifrabil",
    "indescifrabili": "indescifrabil",
    "indescifrabilii": "indescifrabil",
    "indescifrabililor": "indescifrabil",
    "indescifrabilul": "indescifrabil",
    "indescifrabilului": "indescifrabil",
    "indescriptibila": "indescriptibil",
    "indescriptibilă": "indescriptibil",
    "indescriptibile": "indescriptibil",
    "indescriptibilei": "indescriptibil",
    "indescriptibilele": "indescriptibil",
    "indescriptibilelor": "indescriptibil",
    "indescriptibili": "indescriptibil",
    "indescriptibilii": "indescriptibil",
    "indescriptibililor": "indescriptibil",
    "indescriptibilo": "indescriptibil",
    "indescriptibilul": "indescriptibil",
    "indescriptibilule": "indescriptibil",
    "indescriptibilului": "indescriptibil",
    "îndesea": "îndesi",
    "îndeseai": "îndesi",
    "îndeseam": "îndesi",
    "îndesească": "îndesi",
    "îndeseați": "îndesi",
    "îndeseau": "îndesi",
    "îndesesc": "îndesi",
    "îndesește": "îndesi",
    "îndesești": "îndesi",
    "îndesii": "îndesi",
    "îndesim": "îndesi",
    "îndesind": "îndesi",
    "îndesindu": "îndesi",
    "îndesiră": "îndesi",
    "îndesirăm": "îndesi",
    "îndesirăți": "îndesi",
    "îndesise": "îndesi",
    "îndesisem": "îndesi",
    "îndesiseră": "îndesi",
    "îndesiserăm": "îndesi",
    "îndesiserăți": "îndesi",
    "îndesiseși": "îndesi",
    "îndesiși": "îndesi",
    "îndesit": "îndesi",
    "îndesiți": "îndesi",
    "îndesitu": "îndesi",
    "neîndesind": "îndesi",
    "neîndesindu": "îndesi",
    "nemaiîndesind": "îndesi",
    "nemaiîndesindu": "îndesi",
    "îndesită": "îndesit",
    "îndesite": "îndesit",
    "îndesiți": "îndesit",
    "indestructibila": "indestructibil",
    "indestructibilă": "indestructibil",
    "indestructibile": "indestructibil",
    "indestructibilei": "indestructibil",
    "indestructibilele": "indestructibil",
    "indestructibilelor": "indestructibil",
    "indestructibili": "indestructibil",
    "indestructibilii": "indestructibil",
    "indestructibililor": "indestructibil",
    "indestructibilul": "indestructibil",
    "indestructibilului": "indestructibil",
    "indestructibilitatea": "indestructibilitate",
    "indestructibilități": "indestructibilitate",
    "indestructibilității": "indestructibilitate",
    "îndestulă": "îndestula",
    "îndestulai": "îndestula",
    "îndestulam": "îndestula",
    "îndestulăm": "îndestula",
    "îndestulând": "îndestula",
    "îndestulându": "îndestula",
    "îndestulară": "îndestula",
    "îndestularăm": "îndestula",
    "îndestularăți": "îndestula",
    "îndestulase": "îndestula",
    "îndestulasem": "îndestula",
    "îndestulaseră": "îndestula",
    "îndestulaserăm": "îndestula",
    "îndestulaserăți": "îndestula",
    "îndestulaseși": "îndestula",
    "îndestulași": "îndestula",
    "îndestulat": "îndestula",
    "îndestulați": "îndestula",
    "îndestulatu": "îndestula",
    "îndestulau": "îndestula",
    "îndestulează": "îndestula",
    "îndestulez": "îndestula",
    "îndestuleze": "îndestula",
    "îndestulezi": "îndestula",
    "neîndestulând": "îndestula",
    "neîndestulându": "îndestula",
    "nemaiîndestulând": "îndestula",
    "nemaiîndestulându": "îndestula",
    "îndestularea": "îndestulare",
    "îndestulări": "îndestulare",
    "îndestulării": "îndestulare",
    "îndestulările": "îndestulare",
    "îndestulărilor": "îndestulare",
    "îndestulată": "îndestulat",
    "îndestulate": "îndestulat",
    "îndestulați": "îndestulat",
    "îndestulătoare": "îndestulător",
    "îndestulătoarea": "îndestulător",
    "îndestulătoarei": "îndestulător",
    "îndestulătoarele": "îndestulător",
    "îndestulătoarelor": "îndestulător",
    "îndestulători": "îndestulător",
    "îndestulătorii": "îndestulător",
    "îndestulătorilor": "îndestulător",
    "îndestulătorul": "îndestulător",
    "îndestulătorului": "îndestulător",
    "indexul": "index",
    "indexului": "index",
    "indexuri": "index",
    "indexurile": "index",
    "indexurilor": "index",
    "indexă": "indexa",
    "indexai": "indexa",
    "indexam": "indexa",
    "indexăm": "indexa",
    "indexând": "indexa",
    "indexându": "indexa",
    "indexară": "indexa",
    "indexarăm": "indexa",
    "indexarăți": "indexa",
    "indexase": "indexa",
    "indexasem": "indexa",
    "indexaseră": "indexa",
    "indexaserăm": "indexa",
    "indexaserăți": "indexa",
    "indexaseși": "indexa",
    "indexași": "indexa",
    "indexat": "indexa",
    "indexați": "indexa",
    "indexatu": "indexa",
    "indexau": "indexa",
    "indexează": "indexa",
    "indexez": "indexa",
    "indexeze": "indexa",
    "indexezi": "indexa",
    "indexarea": "indexare",
    "indexareo": "indexare",
    "indexări": "indexare",
    "indexării": "indexare",
    "indexările": "indexare",
    "indexărilor": "indexare",
    "indexată": "indexat",
    "indexate": "indexat",
    "indexați": "indexat",
    "indezirabila": "indezirabil",
    "indezirabilă": "indezirabil",
    "indezirabile": "indezirabil",
    "indezirabilei": "indezirabil",
    "indezirabilele": "indezirabil",
    "indezirabilelor": "indezirabil",
    "indezirabili": "indezirabil",
    "indezirabilii": "indezirabil",
    "indezirabililor": "indezirabil",
    "indezirabilul": "indezirabil",
    "indezirabilului": "indezirabil",
    "Indie": "India",
    "Indiei": "India",
    "Indii": "India",
    "indiana": "indian",
    "indiană": "indian",
    "indianul": "indian",
    "indianului": "indian",
    "indiene": "indian",
    "indienei": "indian",
    "indienele": "indian",
    "indienelor": "indian",
    "indieni": "indian",
    "indienii": "indian",
    "indienilor": "indian",
    "indic": "indica",
    "indică": "indica",
    "indicai": "indica",
    "indicam": "indica",
    "indicăm": "indica",
    "indicând": "indica",
    "indicându": "indica",
    "indicară": "indica",
    "indicarăm": "indica",
    "indicarăți": "indica",
    "indicase": "indica",
    "indicasem": "indica",
    "indicaseră": "indica",
    "indicaserăm": "indica",
    "indicaserăți": "indica",
    "indicaseși": "indica",
    "indicași": "indica",
    "indicat": "indica",
    "indicați": "indica",
    "indicatu": "indica",
    "indicau": "indica",
    "indice": "indica",
    "indici": "indica",
    "neindicând": "indica",
    "neindicându": "indica",
    "nemaiindicând": "indica",
    "nemaiindicându": "indica",
    "indicarea": "indicare",
    "indicări": "indicare",
    "indicării": "indicare",
    "indicările": "indicare",
    "indicărilor": "indicare",
    "indicata": "indicat",
    "indicată": "indicat",
    "indicate": "indicat",
    "indicatei": "indicat",
    "indicatele": "indicat",
    "indicatelor": "indicat",
    "indicați": "indicat",
    "indicații": "indicat",
    "indicaților": "indicat",
    "indicatul": "indicat",
    "indicatului": "indicat",
    "indicația": "indicație",
    "indicației": "indicație",
    "indicații": "indicație",
    "indicațiile": "indicație",
    "indicațiilor": "indicație",
    "indicațio": "indicație",
    "ind.": "indicativ",
    "indicativa": "indicativ",
    "indicativă": "indicativ",
    "indicative": "indicativ",
    "indicativei": "indicativ",
    "indicativele": "indicativ",
    "indicativelor": "indicativ",
    "indicativi": "indicativ",
    "indicativii": "indicativ",
    "indicativilor": "indicativ",
    "indicativul": "indicativ",
    "indicativului": "indicativ",
    "indicatoare": "indicator",
    "indicatoarea": "indicator",
    "indicatoarei": "indicator",
    "indicatoarele": "indicator",
    "indicatoarelor": "indicator",
    "indicatori": "indicator",
    "indicatorii": "indicator",
    "indicatorilor": "indicator",
    "indicatorul": "indicator",
    "indicatorului": "indicator",
    "indicele": "indice",
    "indicelui": "indice",
    "indici": "indice",
    "indicii": "indice",
    "indicilor": "indice",
    "indicii": "indiciu",
    "indiciile": "indiciu",
    "indiciilor": "indiciu",
    "indiciul": "indiciu",
    "indiciului": "indiciu",
    "indiferenta": "indiferent",
    "indiferentă": "indiferent",
    "indiferente": "indiferent",
    "indiferentei": "indiferent",
    "indiferentele": "indiferent",
    "indiferentelor": "indiferent",
    "indiferenți": "indiferent",
    "indiferenții": "indiferent",
    "indiferenților": "indiferent",
    "indiferentul": "indiferent",
    "indiferentului": "indiferent",
    "indiferența": "indiferență",
    "indiferențe": "indiferență",
    "indiferenței": "indiferență",
    "indigena": "indigen",
    "indigenă": "indigen",
    "indigene": "indigen",
    "indigenei": "indigen",
    "indigenele": "indigen",
    "indigenelor": "indigen",
    "indigeni": "indigen",
    "indigenii": "indigen",
    "indigenilor": "indigen",
    "indigenul": "indigen",
    "indigenului": "indigen",
    "indigenă": "indigena",
    "indigenai": "indigena",
    "indigenam": "indigena",
    "indigenăm": "indigena",
    "indigenând": "indigena",
    "indigenându": "indigena",
    "indigenară": "indigena",
    "indigenarăm": "indigena",
    "indigenarăți": "indigena",
    "indigenase": "indigena",
    "indigenasem": "indigena",
    "indigenaseră": "indigena",
    "indigenaserăm": "indigena",
    "indigenaserăți": "indigena",
    "indigenaseși": "indigena",
    "indigenași": "indigena",
    "indigenat": "indigena",
    "indigenați": "indigena",
    "indigenatu": "indigena",
    "indigenau": "indigena",
    "indigenează": "indigena",
    "indigenez": "indigena",
    "indigeneze": "indigena",
    "indigenezi": "indigena",
    "neindigenând": "indigena",
    "neindigenându": "indigena",
    "nemaiindigenând": "indigena",
    "nemaiindigenându": "indigena",
    "indigenată": "indigenat",
    "indigenate": "indigenat",
    "indigenați": "indigenat",
    "indigestia": "indigestie",
    "indigestiei": "indigestie",
    "indigestii": "indigestie",
    "indigestiile": "indigestie",
    "indigestiilor": "indigestie",
    "indignă": "indigna",
    "indignai": "indigna",
    "indignam": "indigna",
    "indignăm": "indigna",
    "indignând": "indigna",
    "indignându": "indigna",
    "indignară": "indigna",
    "indignarăm": "indigna",
    "indignarăți": "indigna",
    "indignase": "indigna",
    "indignasem": "indigna",
    "indignaseră": "indigna",
    "indignaserăm": "indigna",
    "indignaserăți": "indigna",
    "indignaseși": "indigna",
    "indignași": "indigna",
    "indignat": "indigna",
    "indignați": "indigna",
    "indignatu": "indigna",
    "indignau": "indigna",
    "indignează": "indigna",
    "indignez": "indigna",
    "indigneze": "indigna",
    "indignezi": "indigna",
    "neindignând": "indigna",
    "neindignându": "indigna",
    "nemaiindignând": "indigna",
    "nemaiindignându": "indigna",
    "indignarea": "indignare",
    "indignareo": "indignare",
    "indignări": "indignare",
    "indignării": "indignare",
    "indignările": "indignare",
    "indignărilor": "indignare",
    "indignata": "indignat",
    "indignată": "indignat",
    "indignate": "indignat",
    "indignatei": "indignat",
    "indignatele": "indignat",
    "indignatelor": "indignat",
    "indignați": "indignat",
    "indignații": "indignat",
    "indignaților": "indignat",
    "indignatul": "indignat",
    "indignatului": "indignat",
    "indigoul": "indigo",
    "indigoului": "indigo",
    "indigouri": "indigo",
    "indigourile": "indigo",
    "indigourilor": "indigo",
    "îndiguia": "îndigui",
    "îndiguiai": "îndigui",
    "îndiguiam": "îndigui",
    "îndiguiască": "îndigui",
    "îndiguiați": "îndigui",
    "îndiguiau": "îndigui",
    "îndiguiesc": "îndigui",
    "îndiguiește": "îndigui",
    "îndiguiești": "îndigui",
    "îndiguii": "îndigui",
    "îndiguim": "îndigui",
    "îndiguind": "îndigui",
    "îndiguindu": "îndigui",
    "îndiguiră": "îndigui",
    "îndiguirăm": "îndigui",
    "îndiguirăți": "îndigui",
    "îndiguise": "îndigui",
    "îndiguisem": "îndigui",
    "îndiguiseră": "îndigui",
    "îndiguiserăm": "îndigui",
    "îndiguiserăți": "îndigui",
    "îndiguiseși": "îndigui",
    "îndiguiși": "îndigui",
    "îndiguit": "îndigui",
    "îndiguiți": "îndigui",
    "îndiguitu": "îndigui",
    "neîndiguind": "îndigui",
    "neîndiguindu": "îndigui",
    "nemaiîndiguind": "îndigui",
    "nemaiîndiguindu": "îndigui",
    "îndiguită": "îndiguit",
    "îndiguite": "îndiguit",
    "îndiguiți": "îndiguit",
    "indirecta": "indirect",
    "indirectă": "indirect",
    "indirecte": "indirect",
    "indirectei": "indirect",
    "indirectele": "indirect",
    "indirectelor": "indirect",
    "indirecți": "indirect",
    "indirecții": "indirect",
    "indirecților": "indirect",
    "indirectul": "indirect",
    "indirectului": "indirect",
    "indisciplina": "indisciplină",
    "indiscipline": "indisciplină",
    "indisciplinei": "indisciplină",
    "indisciplinele": "indisciplină",
    "indisciplinelor": "indisciplină",
    "indisciplinata": "indisciplinat",
    "indisciplinată": "indisciplinat",
    "indisciplinate": "indisciplinat",
    "indisciplinatei": "indisciplinat",
    "indisciplinatele": "indisciplinat",
    "indisciplinatelor": "indisciplinat",
    "indisciplinați": "indisciplinat",
    "indisciplinații": "indisciplinat",
    "indisciplinaților": "indisciplinat",
    "indisciplinato": "indisciplinat",
    "indisciplinatul": "indisciplinat",
    "indisciplinatule": "indisciplinat",
    "indisciplinatului": "indisciplinat",
    "indiscreta": "indiscret",
    "indiscretă": "indiscret",
    "indiscrete": "indiscret",
    "indiscretei": "indiscret",
    "indiscretele": "indiscret",
    "indiscretelor": "indiscret",
    "indiscreți": "indiscret",
    "indiscreții": "indiscret",
    "indiscreților": "indiscret",
    "indiscretul": "indiscret",
    "indiscretului": "indiscret",
    "indiscreția": "indiscreție",
    "indiscreției": "indiscreție",
    "indiscreții": "indiscreție",
    "indiscrețiile": "indiscreție",
    "indiscrețiilor": "indiscreție",
    "indiscutabila": "indiscutabil",
    "indiscutabilă": "indiscutabil",
    "indiscutabile": "indiscutabil",
    "indiscutabilei": "indiscutabil",
    "indiscutabilele": "indiscutabil",
    "indiscutabilelor": "indiscutabil",
    "indiscutabili": "indiscutabil",
    "indiscutabilii": "indiscutabil",
    "indiscutabililor": "indiscutabil",
    "indiscutabilul": "indiscutabil",
    "indiscutabilului": "indiscutabil",
    "indisolubila": "indisolubil",
    "indisolubilă": "indisolubil",
    "indisolubile": "indisolubil",
    "indisolubilei": "indisolubil",
    "indisolubilele": "indisolubil",
    "indisolubilelor": "indisolubil",
    "indisolubili": "indisolubil",
    "indisolubilii": "indisolubil",
    "indisolubililor": "indisolubil",
    "indisolubilul": "indisolubil",
    "indisolubilului": "indisolubil",
    "indispensabila": "indispensabil",
    "indispensabilă": "indispensabil",
    "indispensabile": "indispensabil",
    "indispensabilei": "indispensabil",
    "indispensabilele": "indispensabil",
    "indispensabilelor": "indispensabil",
    "indispensabili": "indispensabil",
    "indispensabilii": "indispensabil",
    "indispensabililor": "indispensabil",
    "indispensabilul": "indispensabil",
    "indispensabilului": "indispensabil",
    "indispensabilii": "indispensabili",
    "indispensabililor": "indispensabili",
    "indisponibila": "indisponibil",
    "indisponibilă": "indisponibil",
    "indisponibile": "indisponibil",
    "indisponibilei": "indisponibil",
    "indisponibilele": "indisponibil",
    "indisponibilelor": "indisponibil",
    "indisponibili": "indisponibil",
    "indisponibilii": "indisponibil",
    "indisponibililor": "indisponibil",
    "indisponibilul": "indisponibil",
    "indisponibilului": "indisponibil",
    "indisponibilitatea": "indisponibilitate",
    "indisponibilitateo": "indisponibilitate",
    "indisponibilități": "indisponibilitate",
    "indisponibilității": "indisponibilitate",
    "indisponibilitățile": "indisponibilitate",
    "indisponibilităților": "indisponibilitate",
    "indispoziția": "indispoziție",
    "indispoziției": "indispoziție",
    "indispoziții": "indispoziție",
    "indispozițiile": "indispoziție",
    "indispozițiilor": "indispoziție",
    "indispui": "indispune",
    "indispun": "indispune",
    "indispună": "indispune",
    "indispunând": "indispune",
    "indispunându": "indispune",
    "indispunea": "indispune",
    "indispuneai": "indispune",
    "indispuneam": "indispune",
    "indispuneați": "indispune",
    "indispuneau": "indispune",
    "indispunem": "indispune",
    "indispuneți": "indispune",
    "indispus": "indispune",
    "indispuse": "indispune",
    "indispusei": "indispune",
    "indispuseră": "indispune",
    "indispuserăm": "indispune",
    "indispuserăți": "indispune",
    "indispusese": "indispune",
    "indispusesem": "indispune",
    "indispuseseră": "indispune",
    "indispuseserăm": "indispune",
    "indispuseserăți": "indispune",
    "indispuseseși": "indispune",
    "indispuseși": "indispune",
    "indispusu": "indispune",
    "neindispunând": "indispune",
    "neindispunându": "indispune",
    "nemaiindispunând": "indispune",
    "nemaiindispunându": "indispune",
    "indispusa": "indispus",
    "indispusă": "indispus",
    "indispuse": "indispus",
    "indispusei": "indispus",
    "indispusele": "indispus",
    "indispuselor": "indispus",
    "indispuși": "indispus",
    "indispușii": "indispus",
    "indispușilor": "indispus",
    "indispusul": "indispus",
    "indispusului": "indispus",
    "indistincta": "indistinct",
    "indistinctă": "indistinct",
    "indistincte": "indistinct",
    "indistinctei": "indistinct",
    "indistinctele": "indistinct",
    "indistinctelor": "indistinct",
    "indistincți": "indistinct",
    "indistincții": "indistinct",
    "indistincților": "indistinct",
    "indistinctul": "indistinct",
    "indistinctului": "indistinct",
    "In": "indiu",
    "indiul": "indiu",
    "indiului": "indiu",
    "individul": "individ",
    "individului": "individ",
    "indivizi": "individ",
    "indivizii": "individ",
    "indivizilor": "individ",
    "individuala": "individual",
    "individuală": "individual",
    "individuale": "individual",
    "individualei": "individual",
    "individualele": "individual",
    "individualelor": "individual",
    "individuali": "individual",
    "individualii": "individual",
    "individualilor": "individual",
    "individualul": "individual",
    "individualului": "individual",
    "individualismul": "individualism",
    "individualismului": "individualism",
    "individualista": "individualist",
    "individualiștă": "individualist",
    "individualiste": "individualist",
    "individualistei": "individualist",
    "individualistele": "individualist",
    "individualistelor": "individualist",
    "individualiști": "individualist",
    "individualiștii": "individualist",
    "individualiștilor": "individualist",
    "individualistul": "individualist",
    "individualistului": "individualist",
    "individualitatea": "individualitate",
    "individualități": "individualitate",
    "individualității": "individualitate",
    "individualitățile": "individualitate",
    "individualităților": "individualitate",
    "individualiză": "individualiza",
    "individualizai": "individualiza",
    "individualizam": "individualiza",
    "individualizăm": "individualiza",
    "individualizând": "individualiza",
    "individualizându": "individualiza",
    "individualizară": "individualiza",
    "individualizarăm": "individualiza",
    "individualizarăți": "individualiza",
    "individualizase": "individualiza",
    "individualizasem": "individualiza",
    "individualizaseră": "individualiza",
    "individualizaserăm": "individualiza",
    "individualizaserăți": "individualiza",
    "individualizaseși": "individualiza",
    "individualizași": "individualiza",
    "individualizat": "individualiza",
    "individualizați": "individualiza",
    "individualizatu": "individualiza",
    "individualizau": "individualiza",
    "individualizează": "individualiza",
    "individualizez": "individualiza",
    "individualizeze": "individualiza",
    "individualizezi": "individualiza",
    "neindividualizând": "individualiza",
    "neindividualizându": "individualiza",
    "nemaiindividualizând": "individualiza",
    "nemaiindividualizându": "individualiza",
    "individualizarea": "individualizare",
    "individualizări": "individualizare",
    "individualizării": "individualizare",
    "individualizările": "individualizare",
    "individualizărilor": "individualizare",
    "individualizată": "individualizat",
    "individualizate": "individualizat",
    "individualizați": "individualizat",
    "indivizibila": "indivizibil",
    "indivizibilă": "indivizibil",
    "indivizibile": "indivizibil",
    "indivizibilei": "indivizibil",
    "indivizibilele": "indivizibil",
    "indivizibilelor": "indivizibil",
    "indivizibili": "indivizibil",
    "indivizibilii": "indivizibil",
    "indivizibililor": "indivizibil",
    "indivizibilul": "indivizibil",
    "indivizibilului": "indivizibil",
    "îndobitocea": "îndobitoci",
    "îndobitoceai": "îndobitoci",
    "îndobitoceam": "îndobitoci",
    "îndobitocească": "îndobitoci",
    "îndobitoceați": "îndobitoci",
    "îndobitoceau": "îndobitoci",
    "îndobitocesc": "îndobitoci",
    "îndobitocește": "îndobitoci",
    "îndobitocești": "îndobitoci",
    "îndobitocii": "îndobitoci",
    "îndobitocim": "îndobitoci",
    "îndobitocind": "îndobitoci",
    "îndobitocindu": "îndobitoci",
    "îndobitociră": "îndobitoci",
    "îndobitocirăm": "îndobitoci",
    "îndobitocirăți": "îndobitoci",
    "îndobitocise": "îndobitoci",
    "îndobitocisem": "îndobitoci",
    "îndobitociseră": "îndobitoci",
    "îndobitociserăm": "îndobitoci",
    "îndobitociserăți": "îndobitoci",
    "îndobitociseși": "îndobitoci",
    "îndobitociși": "îndobitoci",
    "îndobitocit": "îndobitoci",
    "îndobitociți": "îndobitoci",
    "îndobitocitu": "îndobitoci",
    "neîndobitocind": "îndobitoci",
    "neîndobitocindu": "îndobitoci",
    "nemaiîndobitocind": "îndobitoci",
    "nemaiîndobitocindu": "îndobitoci",
    "îndobitocită": "îndobitocit",
    "îndobitocite": "îndobitocit",
    "îndobitociți": "îndobitocit",
    "îndobitocitoare": "îndobitocitor",
    "îndobitocitoarea": "îndobitocitor",
    "îndobitocitoarei": "îndobitocitor",
    "îndobitocitoarele": "îndobitocitor",
    "îndobitocitoarelor": "îndobitocitor",
    "îndobitocitoareo": "îndobitocitor",
    "îndobitocitori": "îndobitocitor",
    "îndobitocitorii": "îndobitocitor",
    "îndobitocitorilor": "îndobitocitor",
    "îndobitocitorul": "îndobitocitor",
    "îndobitocitorule": "îndobitocitor",
    "îndobitocitorului": "îndobitocitor",
    "îndoctrină": "îndoctrina",
    "îndoctrinai": "îndoctrina",
    "îndoctrinam": "îndoctrina",
    "îndoctrinăm": "îndoctrina",
    "îndoctrinând": "îndoctrina",
    "îndoctrinându": "îndoctrina",
    "îndoctrinară": "îndoctrina",
    "îndoctrinarăm": "îndoctrina",
    "îndoctrinarăți": "îndoctrina",
    "îndoctrinase": "îndoctrina",
    "îndoctrinasem": "îndoctrina",
    "îndoctrinaseră": "îndoctrina",
    "îndoctrinaserăm": "îndoctrina",
    "îndoctrinaserăți": "îndoctrina",
    "îndoctrinaseși": "îndoctrina",
    "îndoctrinași": "îndoctrina",
    "îndoctrinat": "îndoctrina",
    "îndoctrinați": "îndoctrina",
    "îndoctrinatu": "îndoctrina",
    "îndoctrinau": "îndoctrina",
    "îndoctrinează": "îndoctrina",
    "îndoctrinez": "îndoctrina",
    "îndoctrineze": "îndoctrina",
    "îndoctrinezi": "îndoctrina",
    "neîndoctrinând": "îndoctrina",
    "neîndoctrinându": "îndoctrina",
    "nemaiîndoctrinând": "îndoctrina",
    "nemaiîndoctrinându": "îndoctrina",
    "îndoctrinarea": "îndoctrinare",
    "îndoctrinareo": "îndoctrinare",
    "îndoctrinări": "îndoctrinare",
    "îndoctrinării": "îndoctrinare",
    "îndoctrinările": "îndoctrinare",
    "îndoctrinărilor": "îndoctrinare",
    "îndoctrinată": "îndoctrinat",
    "îndoctrinate": "îndoctrinat",
    "îndoctrinați": "îndoctrinat",
    "indo-europeană": "indo-european",
    "indo-europene": "indo-european",
    "indo-europeni": "indo-european",
    "indo-germanici": "indo-germanic",
    "îndoaie": "îndoi",
    "îndoia": "îndoi",
    "îndoiai": "îndoi",
    "îndoiam": "îndoi",
    "îndoiască": "îndoi",
    "îndoiați": "îndoi",
    "îndoiau": "îndoi",
    "îndoiesc": "îndoi",
    "îndoiește": "îndoi",
    "îndoiești": "îndoi",
    "îndoii": "îndoi",
    "îndoim": "îndoi",
    "îndoind": "îndoi",
    "îndoindu": "îndoi",
    "îndoiră": "îndoi",
    "îndoirăm": "îndoi",
    "îndoirăți": "îndoi",
    "îndoise": "îndoi",
    "îndoisem": "îndoi",
    "îndoiseră": "îndoi",
    "îndoiserăm": "îndoi",
    "îndoiserăți": "îndoi",
    "îndoiseși": "îndoi",
    "îndoiși": "îndoi",
    "îndoit": "îndoi",
    "îndoiți": "îndoi",
    "îndoitu": "îndoi",
    "neîndoindu": "îndoi",
    "nemaiîndoind": "îndoi",
    "îndoiala": "îndoială",
    "îndoieli": "îndoială",
    "îndoielii": "îndoială",
    "îndoielile": "îndoială",
    "îndoielilor": "îndoială",
    "îndoielnica": "îndoielnic",
    "îndoielnică": "îndoielnic",
    "îndoielnice": "îndoielnic",
    "îndoielnicei": "îndoielnic",
    "îndoielnicele": "îndoielnic",
    "îndoielnicelor": "îndoielnic",
    "îndoielnici": "îndoielnic",
    "îndoielnicii": "îndoielnic",
    "îndoielnicilor": "îndoielnic",
    "îndoielnicul": "îndoielnic",
    "îndoielnicului": "îndoielnic",
    "indo-iraniană": "indo-iranian",
    "indo-iraniene": "indo-iranian",
    "indo-iranieni": "indo-iranian",
    "îndoirea": "îndoire",
    "îndoiri": "îndoire",
    "îndoirii": "îndoire",
    "îndoirile": "îndoire",
    "îndoirilor": "îndoire",
    "îndoita": "îndoit",
    "îndoită": "îndoit",
    "îndoite": "îndoit",
    "îndoitei": "îndoit",
    "îndoitele": "îndoit",
    "îndoitelor": "îndoit",
    "îndoiți": "îndoit",
    "îndoiții": "îndoit",
    "îndoiților": "îndoit",
    "îndoitul": "îndoit",
    "îndoitului": "îndoit",
    "indolenta": "indolent",
    "indolentă": "indolent",
    "indolente": "indolent",
    "indolentei": "indolent",
    "indolentele": "indolent",
    "indolentelor": "indolent",
    "indolenți": "indolent",
    "indolenții": "indolent",
    "indolenților": "indolent",
    "indolentul": "indolent",
    "indolentului": "indolent",
    "indolența": "indolență",
    "indolențe": "indolență",
    "indolenței": "indolență",
    "indolențele": "indolență",
    "indolențelor": "indolență",
    "îndoliă": "îndolia",
    "îndoliai": "îndolia",
    "îndoliam": "îndolia",
    "îndoliăm": "îndolia",
    "îndoliând": "îndolia",
    "îndoliându": "îndolia",
    "îndoliară": "îndolia",
    "îndoliarăm": "îndolia",
    "îndoliarăți": "îndolia",
    "îndoliase": "îndolia",
    "îndoliasem": "îndolia",
    "îndoliaseră": "îndolia",
    "îndoliaserăm": "îndolia",
    "îndoliaserăți": "îndolia",
    "îndoliaseși": "îndolia",
    "îndoliași": "îndolia",
    "îndoliat": "îndolia",
    "îndoliați": "îndolia",
    "îndoliatu": "îndolia",
    "îndoliau": "îndolia",
    "îndoliază": "îndolia",
    "îndoliez": "îndolia",
    "îndolieze": "îndolia",
    "îndoliezi": "îndolia",
    "neîndoliând": "îndolia",
    "neîndoliându": "îndolia",
    "nemaiîndoliând": "îndolia",
    "nemaiîndoliându": "îndolia",
    "îndoliata": "îndoliat",
    "îndoliată": "îndoliat",
    "îndoliate": "îndoliat",
    "îndoliatei": "îndoliat",
    "îndoliatele": "îndoliat",
    "îndoliatelor": "îndoliat",
    "îndoliați": "îndoliat",
    "îndoliații": "îndoliat",
    "îndoliaților": "îndoliat",
    "îndoliatul": "îndoliat",
    "îndoliatului": "îndoliat",
    "indoneziana": "indonezian",
    "indoneziană": "indonezian",
    "indoneziano": "indonezian",
    "indonezianul": "indonezian",
    "indonezianule": "indonezian",
    "indonezianului": "indonezian",
    "indoneziene": "indonezian",
    "indonezienei": "indonezian",
    "indonezienele": "indonezian",
    "indonezienelor": "indonezian",
    "indonezieni": "indonezian",
    "indonezienii": "indonezian",
    "indonezienilor": "indonezian",
    "îndoape": "îndopa",
    "îndop": "îndopa",
    "îndopă": "îndopa",
    "îndopai": "îndopa",
    "îndopam": "îndopa",
    "îndopăm": "îndopa",
    "îndopând": "îndopa",
    "îndopându": "îndopa",
    "îndopară": "îndopa",
    "îndoparăm": "îndopa",
    "îndoparăți": "îndopa",
    "îndopase": "îndopa",
    "îndopasem": "îndopa",
    "îndopaseră": "îndopa",
    "îndopaserăm": "îndopa",
    "îndopaserăți": "îndopa",
    "îndopaseși": "îndopa",
    "îndopași": "îndopa",
    "îndopat": "îndopa",
    "îndopați": "îndopa",
    "îndopatu": "îndopa",
    "îndopau": "îndopa",
    "îndopi": "îndopa",
    "neîndopând": "îndopa",
    "neîndopându": "îndopa",
    "nemaiîndopând": "îndopa",
    "nemaiîndopându": "îndopa",
    "îndopată": "îndopat",
    "îndopate": "îndopat",
    "îndopați": "îndopat",
    "îndosea": "îndosi",
    "îndoseai": "îndosi",
    "îndoseam": "îndosi",
    "îndosească": "îndosi",
    "îndoseați": "îndosi",
    "îndoseau": "îndosi",
    "îndosesc": "îndosi",
    "îndosește": "îndosi",
    "îndosești": "îndosi",
    "îndosii": "îndosi",
    "îndosim": "îndosi",
    "îndosind": "îndosi",
    "îndosindu": "îndosi",
    "îndosiră": "îndosi",
    "îndosirăm": "îndosi",
    "îndosirăți": "îndosi",
    "îndosise": "îndosi",
    "îndosisem": "îndosi",
    "îndosiseră": "îndosi",
    "îndosiserăm": "îndosi",
    "îndosiserăți": "îndosi",
    "îndosiseși": "îndosi",
    "îndosiși": "îndosi",
    "îndosit": "îndosi",
    "îndosiți": "îndosi",
    "îndositu": "îndosi",
    "neîndosind": "îndosi",
    "neîndosindu": "îndosi",
    "nemaiîndosind": "îndosi",
    "nemaiîndosindu": "îndosi",
    "îndosită": "îndosit",
    "îndosite": "îndosit",
    "îndosiți": "îndosit",
    "îndrăcea": "îndrăci",
    "îndrăceai": "îndrăci",
    "îndrăceam": "îndrăci",
    "îndrăcească": "îndrăci",
    "îndrăceați": "îndrăci",
    "îndrăceau": "îndrăci",
    "îndrăcesc": "îndrăci",
    "îndrăcește": "îndrăci",
    "îndrăcești": "îndrăci",
    "îndrăcii": "îndrăci",
    "îndrăcim": "îndrăci",
    "îndrăcind": "îndrăci",
    "îndrăcindu": "îndrăci",
    "îndrăciră": "îndrăci",
    "îndrăcirăm": "îndrăci",
    "îndrăcirăți": "îndrăci",
    "îndrăcise": "îndrăci",
    "îndrăcisem": "îndrăci",
    "îndrăciseră": "îndrăci",
    "îndrăciserăm": "îndrăci",
    "îndrăciserăți": "îndrăci",
    "îndrăciseși": "îndrăci",
    "îndrăciși": "îndrăci",
    "îndrăcit": "îndrăci",
    "îndrăciți": "îndrăci",
    "îndrăcitu": "îndrăci",
    "neîndrăcind": "îndrăci",
    "neîndrăcindu": "îndrăci",
    "nemaiîndrăcind": "îndrăci",
    "nemaiîndrăcindu": "îndrăci",
    "îndrăcită": "îndrăcit",
    "îndrăcite": "îndrăcit",
    "îndrăciți": "îndrăcit",
    "îndrăgea": "îndrăgi",
    "îndrăgeai": "îndrăgi",
    "îndrăgeam": "îndrăgi",
    "îndrăgească": "îndrăgi",
    "îndrăgeați": "îndrăgi",
    "îndrăgeau": "îndrăgi",
    "îndrăgesc": "îndrăgi",
    "îndrăgește": "îndrăgi",
    "îndrăgești": "îndrăgi",
    "îndrăgii": "îndrăgi",
    "îndrăgim": "îndrăgi",
    "îndrăgind": "îndrăgi",
    "îndrăgindu": "îndrăgi",
    "îndrăgiră": "îndrăgi",
    "îndrăgirăm": "îndrăgi",
    "îndrăgirăți": "îndrăgi",
    "îndrăgise": "îndrăgi",
    "îndrăgisem": "îndrăgi",
    "îndrăgiseră": "îndrăgi",
    "îndrăgiserăm": "îndrăgi",
    "îndrăgiserăți": "îndrăgi",
    "îndrăgiseși": "îndrăgi",
    "îndrăgiși": "îndrăgi",
    "îndrăgit": "îndrăgi",
    "îndrăgiți": "îndrăgi",
    "îndrăgitu": "îndrăgi",
    "neîndrăgind": "îndrăgi",
    "neîndrăgindu": "îndrăgi",
    "nemaiîndrăgind": "îndrăgi",
    "nemaiîndrăgindu": "îndrăgi",
    "îndrăgită": "îndrăgit",
    "îndrăgite": "îndrăgit",
    "îndrăgiți": "îndrăgit",
    "îndrăgostea": "îndrăgosti",
    "îndrăgosteai": "îndrăgosti",
    "îndrăgosteam": "îndrăgosti",
    "îndrăgostească": "îndrăgosti",
    "îndrăgosteați": "îndrăgosti",
    "îndrăgosteau": "îndrăgosti",
    "îndrăgostesc": "îndrăgosti",
    "îndrăgostește": "îndrăgosti",
    "îndrăgostești": "îndrăgosti",
    "îndrăgostii": "îndrăgosti",
    "îndrăgostim": "îndrăgosti",
    "îndrăgostind": "îndrăgosti",
    "îndrăgostindu": "îndrăgosti",
    "îndrăgostiră": "îndrăgosti",
    "îndrăgostirăm": "îndrăgosti",
    "îndrăgostirăți": "îndrăgosti",
    "îndrăgostise": "îndrăgosti",
    "îndrăgostisem": "îndrăgosti",
    "îndrăgostiseră": "îndrăgosti",
    "îndrăgostiserăm": "îndrăgosti",
    "îndrăgostiserăți": "îndrăgosti",
    "îndrăgostiseși": "îndrăgosti",
    "îndrăgostiși": "îndrăgosti",
    "îndrăgostit": "îndrăgosti",
    "îndrăgostiți": "îndrăgosti",
    "îndrăgostitu": "îndrăgosti",
    "neîndrăgostind": "îndrăgosti",
    "neîndrăgostindu": "îndrăgosti",
    "nemaiîndrăgostind": "îndrăgosti",
    "nemaiîndrăgostindu": "îndrăgosti",
    "îndrăgostirea": "îndrăgostire",
    "îndrăgostireo": "îndrăgostire",
    "îndrăgostiri": "îndrăgostire",
    "îndrăgostirii": "îndrăgostire",
    "îndrăgostirile": "îndrăgostire",
    "îndrăgostirilor": "îndrăgostire",
    "îndrăgostita": "îndrăgostit",
    "îndrăgostită": "îndrăgostit",
    "îndrăgostite": "îndrăgostit",
    "îndrăgostitei": "îndrăgostit",
    "îndrăgostitele": "îndrăgostit",
    "îndrăgostitelor": "îndrăgostit",
    "îndrăgostiți": "îndrăgostit",
    "îndrăgostiții": "îndrăgostit",
    "îndrăgostiților": "îndrăgostit",
    "îndrăgostitul": "îndrăgostit",
    "îndrăgostitului": "îndrăgostit",
    "îndrăzneala": "îndrăzneală",
    "îndrăzneli": "îndrăzneală",
    "îndrăznelii": "îndrăzneală",
    "îndrăznelile": "îndrăzneală",
    "îndrăznelilor": "îndrăzneală",
    "îndrăzneața": "îndrăzneț",
    "îndrăzneață": "îndrăzneț",
    "îndrăznețe": "îndrăzneț",
    "îndrăzneței": "îndrăzneț",
    "îndrăznețele": "îndrăzneț",
    "îndrăznețelor": "îndrăzneț",
    "îndrăzneți": "îndrăzneț",
    "îndrăzneții": "îndrăzneț",
    "îndrăzneților": "îndrăzneț",
    "îndrăznețul": "îndrăzneț",
    "îndrăznețului": "îndrăzneț",
    "îndrăznea": "îndrăzni",
    "îndrăzneai": "îndrăzni",
    "îndrăzneam": "îndrăzni",
    "îndrăznească": "îndrăzni",
    "îndrăzneați": "îndrăzni",
    "îndrăzneau": "îndrăzni",
    "îndrăznesc": "îndrăzni",
    "îndrăznește": "îndrăzni",
    "îndrăznești": "îndrăzni",
    "îndrăznii": "îndrăzni",
    "îndrăznim": "îndrăzni",
    "îndrăznind": "îndrăzni",
    "îndrăznindu": "îndrăzni",
    "îndrăzniră": "îndrăzni",
    "îndrăznirăm": "îndrăzni",
    "îndrăznirăți": "îndrăzni",
    "îndrăznise": "îndrăzni",
    "îndrăznisem": "îndrăzni",
    "îndrăzniseră": "îndrăzni",
    "îndrăzniserăm": "îndrăzni",
    "îndrăzniserăți": "îndrăzni",
    "îndrăzniseși": "îndrăzni",
    "îndrăzniși": "îndrăzni",
    "îndrăznit": "îndrăzni",
    "îndrăzniți": "îndrăzni",
    "îndrăznitu": "îndrăzni",
    "neîndrăznind": "îndrăzni",
    "neîndrăznindu": "îndrăzni",
    "nemaiîndrăznind": "îndrăzni",
    "nemaiîndrăznindu": "îndrăzni",
    "îndrăznită": "îndrăznit",
    "îndrăznite": "îndrăznit",
    "îndrăzniți": "îndrăznit",
    "îndreaptă": "îndrepta",
    "îndrept": "îndrepta",
    "îndreptă": "îndrepta",
    "îndreptai": "îndrepta",
    "îndreptam": "îndrepta",
    "îndreptăm": "îndrepta",
    "îndreptând": "îndrepta",
    "îndreptându": "îndrepta",
    "îndreptară": "îndrepta",
    "îndreptarăm": "îndrepta",
    "îndreptarăți": "îndrepta",
    "îndreptase": "îndrepta",
    "îndreptasem": "îndrepta",
    "îndreptaseră": "îndrepta",
    "îndreptaserăm": "îndrepta",
    "îndreptaserăți": "îndrepta",
    "îndreptaseși": "îndrepta",
    "îndreptași": "îndrepta",
    "îndreptat": "îndrepta",
    "îndreptați": "îndrepta",
    "îndreptatu": "îndrepta",
    "îndreptau": "îndrepta",
    "îndrepte": "îndrepta",
    "îndrepți": "îndrepta",
    "neîndreptând": "îndrepta",
    "neîndreptându": "îndrepta",
    "nemaiîndreptând": "îndrepta",
    "nemaiîndreptându": "îndrepta",
    "îndreptare": "îndreptar",
    "îndreptarele": "îndreptar",
    "îndreptarelor": "îndreptar",
    "îndreptarul": "îndreptar",
    "îndreptarului": "îndreptar",
    "îndreptarea": "îndreptare",
    "îndreptări": "îndreptare",
    "îndreptării": "îndreptare",
    "îndreptările": "îndreptare",
    "îndreptărilor": "îndreptare",
    "îndreptată": "îndreptat",
    "îndreptate": "îndreptat",
    "îndreptați": "îndreptat",
    "îndreptățea": "îndreptăți",
    "îndreptățeai": "îndreptăți",
    "îndreptățeam": "îndreptăți",
    "îndreptățească": "îndreptăți",
    "îndreptățeați": "îndreptăți",
    "îndreptățeau": "îndreptăți",
    "îndreptățesc": "îndreptăți",
    "îndreptățește": "îndreptăți",
    "îndreptățești": "îndreptăți",
    "îndreptății": "îndreptăți",
    "îndreptățim": "îndreptăți",
    "îndreptățind": "îndreptăți",
    "îndreptățindu": "îndreptăți",
    "îndreptățiră": "îndreptăți",
    "îndreptățirăm": "îndreptăți",
    "îndreptățirăți": "îndreptăți",
    "îndreptățise": "îndreptăți",
    "îndreptățisem": "îndreptăți",
    "îndreptățiseră": "îndreptăți",
    "îndreptățiserăm": "îndreptăți",
    "îndreptățiserăți": "îndreptăți",
    "îndreptățiseși": "îndreptăți",
    "îndreptățiși": "îndreptăți",
    "îndreptățit": "îndreptăți",
    "îndreptățiți": "îndreptăți",
    "îndreptățitu": "îndreptăți",
    "neîndreptățind": "îndreptăți",
    "neîndreptățindu": "îndreptăți",
    "nemaiîndreptățind": "îndreptăți",
    "nemaiîndreptățindu": "îndreptăți",
    "îndreptățirea": "îndreptățire",
    "îndreptățiri": "îndreptățire",
    "îndreptățirii": "îndreptățire",
    "îndreptățirile": "îndreptățire",
    "îndreptățirilor": "îndreptățire",
    "îndreptățită": "îndreptățit",
    "îndreptățite": "îndreptățit",
    "îndreptățiți": "îndreptățit",
    "îndreptuia": "îndreptui",
    "îndreptuiai": "îndreptui",
    "îndreptuiam": "îndreptui",
    "îndreptuiască": "îndreptui",
    "îndreptuiați": "îndreptui",
    "îndreptuiau": "îndreptui",
    "îndreptuiesc": "îndreptui",
    "îndreptuiește": "îndreptui",
    "îndreptuiești": "îndreptui",
    "îndreptuii": "îndreptui",
    "îndreptuim": "îndreptui",
    "îndreptuind": "îndreptui",
    "îndreptuindu": "îndreptui",
    "îndreptuiră": "îndreptui",
    "îndreptuirăm": "îndreptui",
    "îndreptuirăți": "îndreptui",
    "îndreptuise": "îndreptui",
    "îndreptuisem": "îndreptui",
    "îndreptuiseră": "îndreptui",
    "îndreptuiserăm": "îndreptui",
    "îndreptuiserăți": "îndreptui",
    "îndreptuiseși": "îndreptui",
    "îndreptuiși": "îndreptui",
    "îndreptuit": "îndreptui",
    "îndreptuiți": "îndreptui",
    "îndreptuitu": "îndreptui",
    "neîndreptuind": "îndreptui",
    "neîndreptuindu": "îndreptui",
    "nemaiîndreptuind": "îndreptui",
    "nemaiîndreptuindu": "îndreptui",
    "îndreptuită": "îndreptuit",
    "îndreptuite": "îndreptuit",
    "îndreptuiți": "îndreptuit",
    "îndrituia": "îndritui",
    "îndrituiai": "îndritui",
    "îndrituiam": "îndritui",
    "îndrituiască": "îndritui",
    "îndrituiați": "îndritui",
    "îndrituiau": "îndritui",
    "îndrituiesc": "îndritui",
    "îndrituiește": "îndritui",
    "îndrituiești": "îndritui",
    "îndrituii": "îndritui",
    "îndrituim": "îndritui",
    "îndrituind": "îndritui",
    "îndrituindu": "îndritui",
    "îndrituiră": "îndritui",
    "îndrituirăm": "îndritui",
    "îndrituirăți": "îndritui",
    "îndrituise": "îndritui",
    "îndrituisem": "îndritui",
    "îndrituiseră": "îndritui",
    "îndrituiserăm": "îndritui",
    "îndrituiserăți": "îndritui",
    "îndrituiseși": "îndritui",
    "îndrituiși": "îndritui",
    "îndrituit": "îndritui",
    "îndrituiți": "îndritui",
    "îndrituitu": "îndritui",
    "neîndrituind": "îndritui",
    "neîndrituindu": "îndritui",
    "nemaiîndrituind": "îndritui",
    "nemaiîndrituindu": "îndritui",
    "îndrituită": "îndrituit",
    "îndrituite": "îndrituit",
    "îndrituiți": "îndrituit",
    "îndrug": "îndruga",
    "îndrugă": "îndruga",
    "îndrugai": "îndruga",
    "îndrugam": "îndruga",
    "îndrugăm": "îndruga",
    "îndrugând": "îndruga",
    "îndrugându": "îndruga",
    "îndrugară": "îndruga",
    "îndrugarăm": "îndruga",
    "îndrugarăți": "îndruga",
    "îndrugase": "îndruga",
    "îndrugasem": "îndruga",
    "îndrugaseră": "îndruga",
    "îndrugaserăm": "îndruga",
    "îndrugaserăți": "îndruga",
    "îndrugaseși": "îndruga",
    "îndrugași": "îndruga",
    "îndrugat": "îndruga",
    "îndrugați": "îndruga",
    "îndrugatu": "îndruga",
    "îndrugau": "îndruga",
    "îndruge": "îndruga",
    "îndrugi": "îndruga",
    "neîndrugând": "îndruga",
    "neîndrugându": "îndruga",
    "nemaiîndrugând": "îndruga",
    "nemaiîndrugându": "îndruga",
    "îndrugată": "îndrugat",
    "îndrugate": "îndrugat",
    "îndrugați": "îndrugat",
    "îndrum": "îndruma",
    "îndrumă": "îndruma",
    "îndrumai": "îndruma",
    "îndrumam": "îndruma",
    "îndrumăm": "îndruma",
    "îndrumând": "îndruma",
    "îndrumându": "îndruma",
    "îndrumară": "îndruma",
    "îndrumarăm": "îndruma",
    "îndrumarăți": "îndruma",
    "îndrumase": "îndruma",
    "îndrumasem": "îndruma",
    "îndrumaseră": "îndruma",
    "îndrumaserăm": "îndruma",
    "îndrumaserăți": "îndruma",
    "îndrumaseși": "îndruma",
    "îndrumași": "îndruma",
    "îndrumat": "îndruma",
    "îndrumați": "îndruma",
    "îndrumatu": "îndruma",
    "îndrumau": "îndruma",
    "îndrume": "îndruma",
    "îndrumi": "îndruma",
    "neîndrumând": "îndruma",
    "neîndrumându": "îndruma",
    "nemaiîndrumând": "îndruma",
    "nemaiîndrumându": "îndruma",
    "îndrumare": "îndrumar",
    "îndrumarele": "îndrumar",
    "îndrumarelor": "îndrumar",
    "îndrumarul": "îndrumar",
    "îndrumarule": "îndrumar",
    "îndrumarului": "îndrumar",
    "îndrumarea": "îndrumare",
    "îndrumareo": "îndrumare",
    "îndrumări": "îndrumare",
    "îndrumării": "îndrumare",
    "îndrumările": "îndrumare",
    "îndrumărilor": "îndrumare",
    "îndrumată": "îndrumat",
    "îndrumate": "îndrumat",
    "îndrumați": "îndrumat",
    "îndrumătoare": "îndrumător",
    "îndrumătoarea": "îndrumător",
    "îndrumătoarei": "îndrumător",
    "îndrumătoarele": "îndrumător",
    "îndrumătoarelor": "îndrumător",
    "îndrumători": "îndrumător",
    "îndrumătorii": "îndrumător",
    "îndrumătorilor": "îndrumător",
    "îndrumătorul": "îndrumător",
    "îndrumătorului": "îndrumător",
    "induc": "induce",
    "inducă": "induce",
    "inducând": "induce",
    "inducându": "induce",
    "inducea": "induce",
    "induceai": "induce",
    "induceam": "induce",
    "induceați": "induce",
    "induceau": "induce",
    "inducem": "induce",
    "induceți": "induce",
    "induci": "induce",
    "indus": "induce",
    "induse": "induce",
    "indusei": "induce",
    "induseră": "induce",
    "induserăm": "induce",
    "induserăți": "induce",
    "indusese": "induce",
    "indusesem": "induce",
    "induseseră": "induce",
    "induseserăm": "induce",
    "induseserăți": "induce",
    "induseseși": "induce",
    "induseși": "induce",
    "indusu": "induce",
    "neinducând": "induce",
    "neinducându": "induce",
    "nemaiinducând": "induce",
    "nemaiinducându": "induce",
    "inducerea": "inducere",
    "inducereo": "inducere",
    "induceri": "inducere",
    "inducerii": "inducere",
    "inducerile": "inducere",
    "inducerilor": "inducere",
    "inducția": "inducție",
    "inducției": "inducție",
    "inducții": "inducție",
    "inducțiile": "inducție",
    "inducțiilor": "inducție",
    "înduioșă": "înduioșa",
    "înduioșai": "înduioșa",
    "înduioșam": "înduioșa",
    "înduioșăm": "înduioșa",
    "înduioșând": "înduioșa",
    "înduioșându": "înduioșa",
    "înduioșară": "înduioșa",
    "înduioșarăm": "înduioșa",
    "înduioșarăți": "înduioșa",
    "înduioșase": "înduioșa",
    "înduioșasem": "înduioșa",
    "înduioșaseră": "înduioșa",
    "înduioșaserăm": "înduioșa",
    "înduioșaserăți": "înduioșa",
    "înduioșaseși": "înduioșa",
    "înduioșași": "înduioșa",
    "înduioșat": "înduioșa",
    "înduioșați": "înduioșa",
    "înduioșatu": "înduioșa",
    "înduioșau": "înduioșa",
    "înduioșează": "înduioșa",
    "înduioșez": "înduioșa",
    "înduioșeze": "înduioșa",
    "înduioșezi": "înduioșa",
    "neînduioșând": "înduioșa",
    "neînduioșându": "înduioșa",
    "nemaiînduioșând": "înduioșa",
    "nemaiînduioșându": "înduioșa",
    "înduioșarea": "înduioșare",
    "înduioșareo": "înduioșare",
    "înduioșări": "înduioșare",
    "înduioșării": "înduioșare",
    "înduioșările": "înduioșare",
    "înduioșărilor": "înduioșare",
    "înduioșată": "înduioșat",
    "înduioșate": "înduioșat",
    "înduioșați": "înduioșat",
    "înduioșătoare": "înduioșător",
    "înduioșătoarea": "înduioșător",
    "înduioșătoarei": "înduioșător",
    "înduioșătoarele": "înduioșător",
    "înduioșătoarelor": "înduioșător",
    "înduioșători": "înduioșător",
    "înduioșătorii": "înduioșător",
    "înduioșătorilor": "înduioșător",
    "înduioșătorul": "înduioșător",
    "înduioșătorului": "înduioșător",
    "îndulcea": "îndulci",
    "îndulceai": "îndulci",
    "îndulceam": "îndulci",
    "îndulcească": "îndulci",
    "îndulceați": "îndulci",
    "îndulceau": "îndulci",
    "îndulcesc": "îndulci",
    "îndulcește": "îndulci",
    "îndulcești": "îndulci",
    "îndulcii": "îndulci",
    "îndulcim": "îndulci",
    "îndulcind": "îndulci",
    "îndulcindu": "îndulci",
    "îndulciră": "îndulci",
    "îndulcirăm": "îndulci",
    "îndulcirăți": "îndulci",
    "îndulcise": "îndulci",
    "îndulcisem": "îndulci",
    "îndulciseră": "îndulci",
    "îndulciserăm": "îndulci",
    "îndulciserăți": "îndulci",
    "îndulciseși": "îndulci",
    "îndulciși": "îndulci",
    "îndulcit": "îndulci",
    "îndulciți": "îndulci",
    "îndulcitu": "îndulci",
    "neîndulcind": "îndulci",
    "neîndulcindu": "îndulci",
    "nemaiîndulcind": "îndulci",
    "nemaiîndulcindu": "îndulci",
    "îndulcită": "îndulcit",
    "îndulcite": "îndulcit",
    "îndulciți": "îndulcit",
    "indulgenta": "indulgent",
    "indulgentă": "indulgent",
    "indulgente": "indulgent",
    "indulgentei": "indulgent",
    "indulgentele": "indulgent",
    "indulgentelor": "indulgent",
    "indulgenți": "indulgent",
    "indulgenții": "indulgent",
    "indulgenților": "indulgent",
    "indulgentul": "indulgent",
    "indulgentului": "indulgent",
    "indulgența": "indulgență",
    "indulgențe": "indulgență",
    "indulgenței": "indulgență",
    "indulgențele": "indulgență",
    "indulgențelor": "indulgență",
    "îndumnezeia": "îndumnezei",
    "îndumnezeiai": "îndumnezei",
    "îndumnezeiam": "îndumnezei",
    "îndumnezeiască": "îndumnezei",
    "îndumnezeiați": "îndumnezei",
    "îndumnezeiau": "îndumnezei",
    "îndumnezeiesc": "îndumnezei",
    "îndumnezeiește": "îndumnezei",
    "îndumnezeiești": "îndumnezei",
    "îndumnezeii": "îndumnezei",
    "îndumnezeim": "îndumnezei",
    "îndumnezeind": "îndumnezei",
    "îndumnezeindu": "îndumnezei",
    "îndumnezeiră": "îndumnezei",
    "îndumnezeirăm": "îndumnezei",
    "îndumnezeirăți": "îndumnezei",
    "îndumnezeise": "îndumnezei",
    "îndumnezeisem": "îndumnezei",
    "îndumnezeiseră": "îndumnezei",
    "îndumnezeiserăm": "îndumnezei",
    "îndumnezeiserăți": "îndumnezei",
    "îndumnezeiseși": "îndumnezei",
    "îndumnezeiși": "îndumnezei",
    "îndumnezeit": "îndumnezei",
    "îndumnezeiți": "îndumnezei",
    "îndumnezeitu": "îndumnezei",
    "neîndumnezeind": "îndumnezei",
    "neîndumnezeindu": "îndumnezei",
    "nemaiîndumnezeind": "îndumnezei",
    "nemaiîndumnezeindu": "îndumnezei",
    "îndumnezeirea": "îndumnezeire",
    "îndumnezeireo": "îndumnezeire",
    "îndumnezeiri": "îndumnezeire",
    "îndumnezeirii": "îndumnezeire",
    "îndumnezeirile": "îndumnezeire",
    "îndumnezeirilor": "îndumnezeire",
    "îndumnezeită": "îndumnezeit",
    "îndumnezeite": "îndumnezeit",
    "îndumnezeiți": "îndumnezeit",
    "înduplec": "îndupleca",
    "înduplecă": "îndupleca",
    "înduplecai": "îndupleca",
    "înduplecam": "îndupleca",
    "înduplecăm": "îndupleca",
    "înduplecând": "îndupleca",
    "înduplecându": "îndupleca",
    "înduplecară": "îndupleca",
    "înduplecarăm": "îndupleca",
    "înduplecarăți": "îndupleca",
    "înduplecase": "îndupleca",
    "înduplecasem": "îndupleca",
    "înduplecaseră": "îndupleca",
    "înduplecaserăm": "îndupleca",
    "înduplecaserăți": "îndupleca",
    "înduplecaseși": "îndupleca",
    "înduplecași": "îndupleca",
    "înduplecat": "îndupleca",
    "înduplecați": "îndupleca",
    "înduplecatu": "îndupleca",
    "înduplecau": "îndupleca",
    "înduplece": "îndupleca",
    "îndupleci": "îndupleca",
    "neînduplecând": "îndupleca",
    "neînduplecându": "îndupleca",
    "nemaiînduplecând": "îndupleca",
    "nemaiînduplecându": "îndupleca",
    "înduplecată": "înduplecat",
    "înduplecate": "înduplecat",
    "înduplecați": "înduplecat",
    "indură": "indura",
    "indurai": "indura",
    "induram": "indura",
    "indurăm": "indura",
    "indurând": "indura",
    "indurându": "indura",
    "indurară": "indura",
    "indurarăm": "indura",
    "indurarăți": "indura",
    "indurase": "indura",
    "indurasem": "indura",
    "induraseră": "indura",
    "induraserăm": "indura",
    "induraserăți": "indura",
    "induraseși": "indura",
    "indurași": "indura",
    "indurat": "indura",
    "indurați": "indura",
    "induratu": "indura",
    "indurau": "indura",
    "indurează": "indura",
    "indurez": "indura",
    "indureze": "indura",
    "indurezi": "indura",
    "neindurând": "indura",
    "neindurându": "indura",
    "nemaiindurând": "indura",
    "nemaiindurându": "indura",
    "îndur": "îndura",
    "îndură": "îndura",
    "îndurai": "îndura",
    "înduram": "îndura",
    "îndurăm": "îndura",
    "îndurând": "îndura",
    "îndurându": "îndura",
    "îndurară": "îndura",
    "îndurarăm": "îndura",
    "îndurarăți": "îndura",
    "îndurase": "îndura",
    "îndurasem": "îndura",
    "înduraseră": "îndura",
    "înduraserăm": "îndura",
    "înduraserăți": "îndura",
    "înduraseși": "îndura",
    "îndurași": "îndura",
    "îndurat": "îndura",
    "îndurați": "îndura",
    "înduratu": "îndura",
    "îndurau": "îndura",
    "îndure": "îndura",
    "înduri": "îndura",
    "neîndurând": "îndura",
    "neîndurându": "îndura",
    "nemaiîndurând": "îndura",
    "nemaiîndurându": "îndura",
    "îndurarea": "îndurare",
    "îndurări": "îndurare",
    "îndurării": "îndurare",
    "îndurările": "îndurare",
    "îndurărilor": "îndurare",
    "indurată": "indurat",
    "indurate": "indurat",
    "indurați": "indurat",
    "îndurată": "îndurat",
    "îndurate": "îndurat",
    "îndurați": "îndurat",
    "îndureră": "îndurera",
    "îndurerai": "îndurera",
    "îndureram": "îndurera",
    "îndurerăm": "îndurera",
    "îndurerând": "îndurera",
    "îndurerându": "îndurera",
    "îndurerară": "îndurera",
    "îndurerarăm": "îndurera",
    "îndurerarăți": "îndurera",
    "îndurerase": "îndurera",
    "îndurerasem": "îndurera",
    "îndureraseră": "îndurera",
    "îndureraserăm": "îndurera",
    "îndureraserăți": "îndurera",
    "îndureraseși": "îndurera",
    "îndurerași": "îndurera",
    "îndurerat": "îndurera",
    "îndurerați": "îndurera",
    "îndureratu": "îndurera",
    "îndurerau": "îndurera",
    "îndurerează": "îndurera",
    "îndurerez": "îndurera",
    "îndurereze": "îndurera",
    "îndurerezi": "îndurera",
    "neîndurerând": "îndurera",
    "neîndurerându": "îndurera",
    "nemaiîndurerând": "îndurera",
    "nemaiîndurerându": "îndurera",
    "îndurerata": "îndurerat",
    "îndurerată": "îndurerat",
    "îndurerate": "îndurerat",
    "îndureratei": "îndurerat",
    "îndureratele": "îndurerat",
    "îndureratelor": "îndurerat",
    "îndurerați": "îndurerat",
    "îndurerații": "îndurerat",
    "îndureraților": "îndurerat",
    "îndureratul": "îndurerat",
    "îndureratului": "îndurerat",
    "indusă": "indus",
    "induse": "indus",
    "induși": "indus",
    "îndușmănea": "îndușmăni",
    "îndușmăneai": "îndușmăni",
    "îndușmăneam": "îndușmăni",
    "îndușmănească": "îndușmăni",
    "îndușmăneați": "îndușmăni",
    "îndușmăneau": "îndușmăni",
    "îndușmănesc": "îndușmăni",
    "îndușmănește": "îndușmăni",
    "îndușmănești": "îndușmăni",
    "îndușmănii": "îndușmăni",
    "îndușmănim": "îndușmăni",
    "îndușmănind": "îndușmăni",
    "îndușmănindu": "îndușmăni",
    "îndușmăniră": "îndușmăni",
    "îndușmănirăm": "îndușmăni",
    "îndușmănirăți": "îndușmăni",
    "îndușmănise": "îndușmăni",
    "îndușmănisem": "îndușmăni",
    "îndușmăniseră": "îndușmăni",
    "îndușmăniserăm": "îndușmăni",
    "îndușmăniserăți": "îndușmăni",
    "îndușmăniseși": "îndușmăni",
    "îndușmăniși": "îndușmăni",
    "îndușmănit": "îndușmăni",
    "îndușmăniți": "îndușmăni",
    "îndușmănitu": "îndușmăni",
    "neîndușmănind": "îndușmăni",
    "neîndușmănindu": "îndușmăni",
    "nemaiîndușmănind": "îndușmăni",
    "nemaiîndușmănindu": "îndușmăni",
    "îndușmănită": "îndușmănit",
    "îndușmănite": "îndușmănit",
    "îndușmăniți": "îndușmănit",
    "industriala": "industrial",
    "industrială": "industrial",
    "industriale": "industrial",
    "industrialei": "industrial",
    "industrialele": "industrial",
    "industrialelor": "industrial",
    "industriali": "industrial",
    "industrialii": "industrial",
    "industrialilor": "industrial",
    "industrialul": "industrial",
    "industrialului": "industrial",
    "industrializă": "industrializa",
    "industrializai": "industrializa",
    "industrializam": "industrializa",
    "industrializăm": "industrializa",
    "industrializând": "industrializa",
    "industrializându": "industrializa",
    "industrializară": "industrializa",
    "industrializarăm": "industrializa",
    "industrializarăți": "industrializa",
    "industrializase": "industrializa",
    "industrializasem": "industrializa",
    "industrializaseră": "industrializa",
    "industrializaserăm": "industrializa",
    "industrializaserăți": "industrializa",
    "industrializaseși": "industrializa",
    "industrializași": "industrializa",
    "industrializat": "industrializa",
    "industrializați": "industrializa",
    "industrializatu": "industrializa",
    "industrializau": "industrializa",
    "industrializează": "industrializa",
    "industrializez": "industrializa",
    "industrializeze": "industrializa",
    "industrializezi": "industrializa",
    "neindustrializând": "industrializa",
    "neindustrializându": "industrializa",
    "nemaiindustrializând": "industrializa",
    "nemaiindustrializându": "industrializa",
    "industrializarea": "industrializare",
    "industrializări": "industrializare",
    "industrializării": "industrializare",
    "industrializările": "industrializare",
    "industrializărilor": "industrializare",
    "industrializată": "industrializat",
    "industrializate": "industrializat",
    "industrializați": "industrializat",
    "ind.": "industrie",
    "industria": "industrie",
    "industriei": "industrie",
    "industrii": "industrie",
    "industriile": "industrie",
    "industriilor": "industrie",
    "înecul": "înec",
    "înecului": "înec",
    "înecuri": "înec",
    "înecurile": "înec",
    "înecurilor": "înec",
    "îneacă": "îneca",
    "înec": "îneca",
    "înecă": "îneca",
    "înecai": "îneca",
    "înecam": "îneca",
    "înecăm": "îneca",
    "înecând": "îneca",
    "înecându": "îneca",
    "înecară": "îneca",
    "înecarăm": "îneca",
    "înecarăți": "îneca",
    "înecase": "îneca",
    "înecasem": "îneca",
    "înecaseră": "îneca",
    "înecaserăm": "îneca",
    "înecaserăți": "îneca",
    "înecaseși": "îneca",
    "înecași": "îneca",
    "înecat": "îneca",
    "înecați": "îneca",
    "înecatu": "îneca",
    "înecau": "îneca",
    "înece": "îneca",
    "îneci": "îneca",
    "neînecând": "îneca",
    "neînecându": "îneca",
    "nemaiînecând": "îneca",
    "nemaiînecându": "îneca",
    "înecarea": "înecare",
    "înecări": "înecare",
    "înecării": "înecare",
    "înecările": "înecare",
    "înecărilor": "înecare",
    "înecată": "înecat",
    "înecate": "înecat",
    "înecați": "înecat",
    "înecații": "înecat",
    "înecaților": "înecat",
    "înecatul": "înecat",
    "înecatului": "înecat",
    "inedita": "inedit",
    "inedită": "inedit",
    "inedite": "inedit",
    "ineditei": "inedit",
    "ineditele": "inedit",
    "ineditelor": "inedit",
    "inediți": "inedit",
    "inediții": "inedit",
    "inediților": "inedit",
    "ineditul": "inedit",
    "ineditului": "inedit",
    "inefabila": "inefabil",
    "inefabilă": "inefabil",
    "inefabile": "inefabil",
    "inefabilei": "inefabil",
    "inefabilele": "inefabil",
    "inefabilelor": "inefabil",
    "inefabili": "inefabil",
    "inefabilii": "inefabil",
    "inefabililor": "inefabil",
    "inefabilo": "inefabil",
    "inefabilul": "inefabil",
    "inefabilule": "inefabil",
    "inefabilului": "inefabil",
    "ineficienta": "ineficient",
    "ineficientă": "ineficient",
    "ineficiente": "ineficient",
    "ineficientei": "ineficient",
    "ineficientele": "ineficient",
    "ineficientelor": "ineficient",
    "ineficienți": "ineficient",
    "ineficienții": "ineficient",
    "ineficienților": "ineficient",
    "ineficientul": "ineficient",
    "ineficientului": "ineficient",
    "ineficiența": "ineficiență",
    "ineficiențe": "ineficiență",
    "ineficienței": "ineficiență",
    "ineficiențele": "ineficiență",
    "ineficiențelor": "ineficiență",
    "inegala": "inegal",
    "inegală": "inegal",
    "inegale": "inegal",
    "inegalei": "inegal",
    "inegalele": "inegal",
    "inegalelor": "inegal",
    "inegali": "inegal",
    "inegalii": "inegal",
    "inegalilor": "inegal",
    "inegalul": "inegal",
    "inegalului": "inegal",
    "inegalitatea": "inegalitate",
    "inegalități": "inegalitate",
    "inegalității": "inegalitate",
    "inegalitățile": "inegalitate",
    "inegalităților": "inegalitate",
    "inele": "inel",
    "inelele": "inel",
    "inelelor": "inel",
    "inelul": "inel",
    "inelului": "inel",
    "inelara": "inelar",
    "inelară": "inelar",
    "inelare": "inelar",
    "inelarei": "inelar",
    "inelarele": "inelar",
    "inelarelor": "inelar",
    "inelari": "inelar",
    "inelarii": "inelar",
    "inelarilor": "inelar",
    "inelarul": "inelar",
    "inelarului": "inelar",
    "inepția": "inepție",
    "inepției": "inepție",
    "inepții": "inepție",
    "inepțiile": "inepție",
    "inepțiilor": "inepție",
    "inepuizabila": "inepuizabil",
    "inepuizabilă": "inepuizabil",
    "inepuizabile": "inepuizabil",
    "inepuizabilei": "inepuizabil",
    "inepuizabilele": "inepuizabil",
    "inepuizabilelor": "inepuizabil",
    "inepuizabili": "inepuizabil",
    "inepuizabilii": "inepuizabil",
    "inepuizabililor": "inepuizabil",
    "inepuizabilul": "inepuizabil",
    "inepuizabilului": "inepuizabil",
    "inerenta": "inerent",
    "inerentă": "inerent",
    "inerente": "inerent",
    "inerentei": "inerent",
    "inerentele": "inerent",
    "inerentelor": "inerent",
    "inerenți": "inerent",
    "inerenții": "inerent",
    "inerenților": "inerent",
    "inerentul": "inerent",
    "inerentului": "inerent",
    "inerta": "inert",
    "inertă": "inert",
    "inerte": "inert",
    "inertei": "inert",
    "inertele": "inert",
    "inertelor": "inert",
    "inerți": "inert",
    "inerții": "inert",
    "inerților": "inert",
    "inertul": "inert",
    "inertului": "inert",
    "inerția": "inerție",
    "inerției": "inerție",
    "inerții": "inerție",
    "inerțiile": "inerție",
    "inerțiilor": "inerție",
    "inervă": "inerva",
    "inervai": "inerva",
    "inervam": "inerva",
    "inervăm": "inerva",
    "inervând": "inerva",
    "inervându": "inerva",
    "inervară": "inerva",
    "inervarăm": "inerva",
    "inervarăți": "inerva",
    "inervase": "inerva",
    "inervasem": "inerva",
    "inervaseră": "inerva",
    "inervaserăm": "inerva",
    "inervaserăți": "inerva",
    "inervaseși": "inerva",
    "inervași": "inerva",
    "inervat": "inerva",
    "inervați": "inerva",
    "inervatu": "inerva",
    "inervau": "inerva",
    "inervează": "inerva",
    "inervez": "inerva",
    "inerveze": "inerva",
    "inervezi": "inerva",
    "neinervând": "inerva",
    "neinervându": "inerva",
    "nemaiinervând": "inerva",
    "nemaiinervându": "inerva",
    "inervată": "inervat",
    "inervate": "inervat",
    "inervați": "inervat",
    "inestimabila": "inestimabil",
    "inestimabilă": "inestimabil",
    "inestimabile": "inestimabil",
    "inestimabilei": "inestimabil",
    "inestimabilele": "inestimabil",
    "inestimabilelor": "inestimabil",
    "inestimabili": "inestimabil",
    "inestimabilii": "inestimabil",
    "inestimabililor": "inestimabil",
    "inestimabilul": "inestimabil",
    "inestimabilului": "inestimabil",
    "inevitabila": "inevitabil",
    "inevitabilă": "inevitabil",
    "inevitabile": "inevitabil",
    "inevitabilei": "inevitabil",
    "inevitabilele": "inevitabil",
    "inevitabilelor": "inevitabil",
    "inevitabili": "inevitabil",
    "inevitabilii": "inevitabil",
    "inevitabililor": "inevitabil",
    "inevitabilul": "inevitabil",
    "inevitabilului": "inevitabil",
    "inexacta": "inexact",
    "inexactă": "inexact",
    "inexacte": "inexact",
    "inexactei": "inexact",
    "inexactele": "inexact",
    "inexactelor": "inexact",
    "inexacți": "inexact",
    "inexacții": "inexact",
    "inexacților": "inexact",
    "inexactul": "inexact",
    "inexactului": "inexact",
    "inexactitatea": "inexactitate",
    "inexactități": "inexactitate",
    "inexactității": "inexactitate",
    "inexactitățile": "inexactitate",
    "inexactităților": "inexactitate",
    "inexistenta": "inexistent",
    "inexistentă": "inexistent",
    "inexistente": "inexistent",
    "inexistentei": "inexistent",
    "inexistentele": "inexistent",
    "inexistentelor": "inexistent",
    "inexistenți": "inexistent",
    "inexistenții": "inexistent",
    "inexistenților": "inexistent",
    "inexistentul": "inexistent",
    "inexistentului": "inexistent",
    "inexistența": "inexistență",
    "inexistențe": "inexistență",
    "inexistenței": "inexistență",
    "inexorabila": "inexorabil",
    "inexorabilă": "inexorabil",
    "inexorabile": "inexorabil",
    "inexorabilei": "inexorabil",
    "inexorabilele": "inexorabil",
    "inexorabilelor": "inexorabil",
    "inexorabili": "inexorabil",
    "inexorabilii": "inexorabil",
    "inexorabililor": "inexorabil",
    "inexorabilo": "inexorabil",
    "inexorabilul": "inexorabil",
    "inexorabilule": "inexorabil",
    "inexorabilului": "inexorabil",
    "inexplicabila": "inexplicabil",
    "inexplicabilă": "inexplicabil",
    "inexplicabile": "inexplicabil",
    "inexplicabilei": "inexplicabil",
    "inexplicabilele": "inexplicabil",
    "inexplicabilelor": "inexplicabil",
    "inexplicabili": "inexplicabil",
    "inexplicabilii": "inexplicabil",
    "inexplicabililor": "inexplicabil",
    "inexplicabilul": "inexplicabil",
    "inexplicabilului": "inexplicabil",
    "inexpresiva": "inexpresiv",
    "inexpresivă": "inexpresiv",
    "inexpresive": "inexpresiv",
    "inexpresivei": "inexpresiv",
    "inexpresivele": "inexpresiv",
    "inexpresivelor": "inexpresiv",
    "inexpresivi": "inexpresiv",
    "inexpresivii": "inexpresiv",
    "inexpresivilor": "inexpresiv",
    "inexpresivul": "inexpresiv",
    "inexpresivului": "inexpresiv",
    "infailibila": "infailibil",
    "infailibilă": "infailibil",
    "infailibile": "infailibil",
    "infailibilei": "infailibil",
    "infailibilele": "infailibil",
    "infailibilelor": "infailibil",
    "infailibili": "infailibil",
    "infailibilii": "infailibil",
    "infailibililor": "infailibil",
    "infailibilul": "infailibil",
    "infailibilului": "infailibil",
    "infailibilitatea": "infailibilitate",
    "infailibilități": "infailibilitate",
    "infailibilității": "infailibilitate",
    "infama": "infam",
    "infamă": "infam",
    "infame": "infam",
    "infamei": "infam",
    "infamele": "infam",
    "infamelor": "infam",
    "infami": "infam",
    "infamii": "infam",
    "infamilor": "infam",
    "infamul": "infam",
    "infamului": "infam",
    "infamia": "infamie",
    "infamiei": "infamie",
    "infamii": "infamie",
    "infamiile": "infamie",
    "infamiilor": "infamie",
    "infanteria": "infanterie",
    "infanteriei": "infanterie",
    "infanterii": "infanterie",
    "infanteriile": "infanterie",
    "infanteriilor": "infanterie",
    "infanteriști": "infanterist",
    "infanteriștii": "infanterist",
    "infanteriștilor": "infanterist",
    "infanteristul": "infanterist",
    "infanteristului": "infanterist",
    "infantila": "infantil",
    "infantilă": "infantil",
    "infantile": "infantil",
    "infantilei": "infantil",
    "infantilele": "infantil",
    "infantilelor": "infantil",
    "infantili": "infantil",
    "infantilii": "infantil",
    "infantililor": "infantil",
    "infantilul": "infantil",
    "infantilului": "infantil",
    "înfăptuia": "înfăptui",
    "înfăptuiai": "înfăptui",
    "înfăptuiam": "înfăptui",
    "înfăptuiască": "înfăptui",
    "înfăptuiați": "înfăptui",
    "înfăptuiau": "înfăptui",
    "înfăptuiesc": "înfăptui",
    "înfăptuiește": "înfăptui",
    "înfăptuiești": "înfăptui",
    "înfăptuii": "înfăptui",
    "înfăptuim": "înfăptui",
    "înfăptuind": "înfăptui",
    "înfăptuindu": "înfăptui",
    "înfăptuiră": "înfăptui",
    "înfăptuirăm": "înfăptui",
    "înfăptuirăți": "înfăptui",
    "înfăptuise": "înfăptui",
    "înfăptuisem": "înfăptui",
    "înfăptuiseră": "înfăptui",
    "înfăptuiserăm": "înfăptui",
    "înfăptuiserăți": "înfăptui",
    "înfăptuiseși": "înfăptui",
    "înfăptuiși": "înfăptui",
    "înfăptuit": "înfăptui",
    "înfăptuiți": "înfăptui",
    "înfăptuitu": "înfăptui",
    "neînfăptuind": "înfăptui",
    "neînfăptuindu": "înfăptui",
    "nemaiînfăptuind": "înfăptui",
    "nemaiînfăptuindu": "înfăptui",
    "înfăptuirea": "înfăptuire",
    "înfăptuireo": "înfăptuire",
    "înfăptuiri": "înfăptuire",
    "înfăptuirii": "înfăptuire",
    "înfăptuirile": "înfăptuire",
    "înfăptuirilor": "înfăptuire",
    "înfăptuită": "înfăptuit",
    "înfăptuite": "înfăptuit",
    "înfăptuiți": "înfăptuit",
    "infarcte": "infarct",
    "infarctele": "infarct",
    "infarctelor": "infarct",
    "infarctul": "infarct",
    "infarctului": "infarct",
    "înfăș": "înfășa",
    "înfașă": "înfășa",
    "înfășă": "înfășa",
    "înfășai": "înfășa",
    "înfășam": "înfășa",
    "înfășăm": "înfășa",
    "înfășând": "înfășa",
    "înfășându": "înfășa",
    "înfășară": "înfășa",
    "înfășarăm": "înfășa",
    "înfășarăți": "înfășa",
    "înfășase": "înfășa",
    "înfășasem": "înfășa",
    "înfășaseră": "înfășa",
    "înfășaserăm": "înfășa",
    "înfășaserăți": "înfășa",
    "înfășaseși": "înfășa",
    "înfășași": "înfășa",
    "înfășat": "înfășa",
    "înfășați": "înfășa",
    "înfășatu": "înfășa",
    "înfășau": "înfășa",
    "înfeșe": "înfășa",
    "înfeși": "înfășa",
    "neînfășând": "înfășa",
    "neînfășându": "înfășa",
    "nemaiînfășând": "înfășa",
    "nemaiînfășându": "înfășa",
    "înfășată": "înfășat",
    "înfășate": "înfășat",
    "înfășați": "înfășat",
    "înfășoară": "înfășura",
    "înfășoare": "înfășura",
    "înfășor": "înfășura",
    "înfășori": "înfășura",
    "înfășură": "înfășura",
    "înfășurai": "înfășura",
    "înfășuram": "înfășura",
    "înfășurăm": "înfășura",
    "înfășurând": "înfășura",
    "înfășurându": "înfășura",
    "înfășurară": "înfășura",
    "înfășurarăm": "înfășura",
    "înfășurarăți": "înfășura",
    "înfășurase": "înfășura",
    "înfășurasem": "înfășura",
    "înfășuraseră": "înfășura",
    "înfășuraserăm": "înfășura",
    "înfășuraserăți": "înfășura",
    "înfășuraseși": "înfășura",
    "înfășurași": "înfășura",
    "înfășurat": "înfășura",
    "înfășurați": "înfășura",
    "înfășuratu": "înfășura",
    "înfășurau": "înfășura",
    "neînfășurând": "înfășura",
    "neînfășurându": "înfășura",
    "nemaiînfășurând": "înfășura",
    "nemaiînfășurându": "înfășura",
    "înfășurată": "înfășurat",
    "înfășurate": "înfășurat",
    "înfășurați": "înfășurat",
    "înfăț": "înfăța",
    "înfață": "înfăța",
    "înfăță": "înfăța",
    "înfățai": "înfăța",
    "înfățam": "înfăța",
    "înfățăm": "înfăța",
    "înfățând": "înfăța",
    "înfățându": "înfăța",
    "înfățară": "înfăța",
    "înfățarăm": "înfăța",
    "înfățarăți": "înfăța",
    "înfățase": "înfăța",
    "înfățasem": "înfăța",
    "înfățaseră": "înfăța",
    "înfățaserăm": "înfăța",
    "înfățaserăți": "înfăța",
    "înfățaseși": "înfăța",
    "înfățași": "înfăța",
    "înfățat": "înfăța",
    "înfățați": "înfăța",
    "înfățatu": "înfăța",
    "înfățau": "înfăța",
    "înfețe": "înfăța",
    "înfeți": "înfăța",
    "neînfățând": "înfăța",
    "neînfățându": "înfăța",
    "nemaiînfățând": "înfăța",
    "nemaiînfățându": "înfăța",
    "înfățată": "înfățat",
    "înfățate": "înfățat",
    "înfățați": "înfățat",
    "înfățișă": "înfățișa",
    "înfățișai": "înfățișa",
    "înfățișam": "înfățișa",
    "înfățișăm": "înfățișa",
    "înfățișând": "înfățișa",
    "înfățișându": "înfățișa",
    "înfățișară": "înfățișa",
    "înfățișarăm": "înfățișa",
    "înfățișarăți": "înfățișa",
    "înfățișase": "înfățișa",
    "înfățișasem": "înfățișa",
    "înfățișaseră": "înfățișa",
    "înfățișaserăm": "înfățișa",
    "înfățișaserăți": "înfățișa",
    "înfățișaseși": "înfățișa",
    "înfățișași": "înfățișa",
    "înfățișat": "înfățișa",
    "înfățișați": "înfățișa",
    "înfățișatu": "înfățișa",
    "înfățișau": "înfățișa",
    "înfățișează": "înfățișa",
    "înfățișez": "înfățișa",
    "înfățișeze": "înfățișa",
    "înfățișezi": "înfățișa",
    "neînfățișând": "înfățișa",
    "neînfățișându": "înfățișa",
    "nemaiînfățișând": "înfățișa",
    "nemaiînfățișându": "înfățișa",
    "înfățișarea": "înfățișare",
    "înfățișări": "înfățișare",
    "înfățișării": "înfățișare",
    "înfățișările": "înfățișare",
    "înfățișărilor": "înfățișare",
    "înfățișată": "înfățișat",
    "înfățișate": "înfățișat",
    "înfățișați": "înfățișat",
    "infatuă": "infatua",
    "infatuai": "infatua",
    "infatuam": "infatua",
    "infatuăm": "infatua",
    "infatuând": "infatua",
    "infatuându": "infatua",
    "infatuară": "infatua",
    "infatuarăm": "infatua",
    "infatuarăți": "infatua",
    "infatuase": "infatua",
    "infatuasem": "infatua",
    "infatuaseră": "infatua",
    "infatuaserăm": "infatua",
    "infatuaserăți": "infatua",
    "infatuaseși": "infatua",
    "infatuași": "infatua",
    "infatuat": "infatua",
    "infatuați": "infatua",
    "infatuatu": "infatua",
    "infatuau": "infatua",
    "infatuează": "infatua",
    "infatuez": "infatua",
    "infatueze": "infatua",
    "infatuezi": "infatua",
    "neinfatuând": "infatua",
    "neinfatuându": "infatua",
    "nemaiinfatuând": "infatua",
    "nemaiinfatuându": "infatua",
    "infatuata": "infatuat",
    "infatuată": "infatuat",
    "infatuate": "infatuat",
    "infatuatei": "infatuat",
    "infatuatele": "infatuat",
    "infatuatelor": "infatuat",
    "infatuați": "infatuat",
    "infatuații": "infatuat",
    "infatuaților": "infatuat",
    "infatuatul": "infatuat",
    "infatuatului": "infatuat",
    "înfeciorirea": "înfeciorire",
    "înfeciorireo": "înfeciorire",
    "înfecioriri": "înfeciorire",
    "înfecioririi": "înfeciorire",
    "înfecioririle": "înfeciorire",
    "înfecioririlor": "înfeciorire",
    "infecta": "infect",
    "infectă": "infect",
    "infecte": "infect",
    "infectei": "infect",
    "infectele": "infect",
    "infectelor": "infect",
    "infecți": "infect",
    "infecții": "infect",
    "infecților": "infect",
    "infectul": "infect",
    "infectului": "infect",
    "infectă": "infecta",
    "infectai": "infecta",
    "infectam": "infecta",
    "infectăm": "infecta",
    "infectând": "infecta",
    "infectându": "infecta",
    "infectară": "infecta",
    "infectarăm": "infecta",
    "infectarăți": "infecta",
    "infectase": "infecta",
    "infectasem": "infecta",
    "infectaseră": "infecta",
    "infectaserăm": "infecta",
    "infectaserăți": "infecta",
    "infectaseși": "infecta",
    "infectași": "infecta",
    "infectat": "infecta",
    "infectați": "infecta",
    "infectatu": "infecta",
    "infectau": "infecta",
    "infectează": "infecta",
    "infectez": "infecta",
    "infecteze": "infecta",
    "infectezi": "infecta",
    "neinfectând": "infecta",
    "neinfectându": "infecta",
    "nemaiinfectând": "infecta",
    "nemaiinfectându": "infecta",
    "infectată": "infectat",
    "infectate": "infectat",
    "infectați": "infectat",
    "infecția": "infecție",
    "infecției": "infecție",
    "infecții": "infecție",
    "infecțiile": "infecție",
    "infecțiilor": "infecție",
    "infecțioasa": "infecțios",
    "infecțioasă": "infecțios",
    "infecțioase": "infecțios",
    "infecțioasei": "infecțios",
    "infecțioasele": "infecțios",
    "infecțioaselor": "infecțios",
    "infecțioși": "infecțios",
    "infecțioșii": "infecțios",
    "infecțioșilor": "infecțios",
    "infecțiosul": "infecțios",
    "infecțiosului": "infecțios",
    "inferă": "infera",
    "inferai": "infera",
    "inferam": "infera",
    "inferăm": "infera",
    "inferând": "infera",
    "inferându": "infera",
    "inferară": "infera",
    "inferarăm": "infera",
    "inferarăți": "infera",
    "inferase": "infera",
    "inferasem": "infera",
    "inferaseră": "infera",
    "inferaserăm": "infera",
    "inferaserăți": "infera",
    "inferaseși": "infera",
    "inferași": "infera",
    "inferat": "infera",
    "inferați": "infera",
    "inferatu": "infera",
    "inferau": "infera",
    "inferează": "infera",
    "inferez": "infera",
    "infereze": "infera",
    "inferezi": "infera",
    "neinferând": "infera",
    "neinferându": "infera",
    "nemaiinferând": "infera",
    "nemaiinferându": "infera",
    "inferată": "inferat",
    "inferate": "inferat",
    "inferați": "inferat",
    "inferioara": "inferioară",
    "inferioare": "inferioară",
    "inferioarei": "inferioară",
    "inferioarele": "inferioară",
    "inferioarelor": "inferioară",
    "inferioara": "inferior",
    "inferioară": "inferior",
    "inferioare": "inferior",
    "inferioarei": "inferior",
    "inferioarele": "inferior",
    "inferioarelor": "inferior",
    "inferiori": "inferior",
    "inferiorii": "inferior",
    "inferiorilor": "inferior",
    "inferiorul": "inferior",
    "inferiorului": "inferior",
    "inferioritatea": "inferioritate",
    "inferiorități": "inferioritate",
    "inferiorității": "inferioritate",
    "inferioritățile": "inferioritate",
    "inferiorităților": "inferioritate",
    "infernul": "infern",
    "infernului": "infern",
    "infernala": "infernal",
    "infernală": "infernal",
    "infernale": "infernal",
    "infernalei": "infernal",
    "infernalele": "infernal",
    "infernalelor": "infernal",
    "infernali": "infernal",
    "infernalii": "infernal",
    "infernalilor": "infernal",
    "infernalul": "infernal",
    "infernalului": "infernal",
    "infestă": "infesta",
    "infestai": "infesta",
    "infestam": "infesta",
    "infestăm": "infesta",
    "infestând": "infesta",
    "infestându": "infesta",
    "infestară": "infesta",
    "infestarăm": "infesta",
    "infestarăți": "infesta",
    "infestase": "infesta",
    "infestasem": "infesta",
    "infestaseră": "infesta",
    "infestaserăm": "infesta",
    "infestaserăți": "infesta",
    "infestaseși": "infesta",
    "infestași": "infesta",
    "infestat": "infesta",
    "infestați": "infesta",
    "infestatu": "infesta",
    "infestau": "infesta",
    "infestează": "infesta",
    "infestez": "infesta",
    "infesteze": "infesta",
    "infestezi": "infesta",
    "neinfestând": "infesta",
    "neinfestându": "infesta",
    "nemaiinfestând": "infesta",
    "nemaiinfestându": "infesta",
    "infestată": "infestat",
    "infestate": "infestat",
    "infestați": "infestat",
    "înfeudă": "înfeuda",
    "înfeudai": "înfeuda",
    "înfeudam": "înfeuda",
    "înfeudăm": "înfeuda",
    "înfeudând": "înfeuda",
    "înfeudându": "înfeuda",
    "înfeudară": "înfeuda",
    "înfeudarăm": "înfeuda",
    "înfeudarăți": "înfeuda",
    "înfeudase": "înfeuda",
    "înfeudasem": "înfeuda",
    "înfeudaseră": "înfeuda",
    "înfeudaserăm": "înfeuda",
    "înfeudaserăți": "înfeuda",
    "înfeudaseși": "înfeuda",
    "înfeudași": "înfeuda",
    "înfeudat": "înfeuda",
    "înfeudați": "înfeuda",
    "înfeudatu": "înfeuda",
    "înfeudau": "înfeuda",
    "înfeudează": "înfeuda",
    "înfeudez": "înfeuda",
    "înfeudeze": "înfeuda",
    "înfeudezi": "înfeuda",
    "neînfeudând": "înfeuda",
    "neînfeudându": "înfeuda",
    "nemaiînfeudând": "înfeuda",
    "nemaiînfeudându": "înfeuda",
    "înfeudată": "înfeudat",
    "înfeudate": "înfeudat",
    "înfeudați": "înfeudat",
    "înfiai": "înfia",
    "înfiam": "înfia",
    "înfiară": "înfia",
    "înfiarăm": "înfia",
    "înfiarăți": "înfia",
    "înfiase": "înfia",
    "înfiasem": "înfia",
    "înfiaseră": "înfia",
    "înfiaserăm": "înfia",
    "înfiaserăți": "înfia",
    "înfiaseși": "înfia",
    "înfiași": "înfia",
    "înfiat": "înfia",
    "înfiați": "înfia",
    "înfiatu": "înfia",
    "înfiau": "înfia",
    "înfiază": "înfia",
    "înfie": "înfia",
    "înfiem": "înfia",
    "înfiez": "înfia",
    "înfieze": "înfia",
    "înfiezi": "înfia",
    "înfiind": "înfia",
    "înfiindu": "înfia",
    "neînfiind": "înfia",
    "neînfiindu": "înfia",
    "nemaiînfiind": "înfia",
    "nemaiînfiindu": "înfia",
    "înfiată": "înfiat",
    "înfiate": "înfiat",
    "înfiați": "înfiat",
    "infidela": "infidel",
    "infidelă": "infidel",
    "infidele": "infidel",
    "infidelei": "infidel",
    "infidelele": "infidel",
    "infidelelor": "infidel",
    "infideli": "infidel",
    "infidelii": "infidel",
    "infidelilor": "infidel",
    "infidelul": "infidel",
    "infidelului": "infidel",
    "înfieră": "înfiera",
    "înfierai": "înfiera",
    "înfieram": "înfiera",
    "înfierăm": "înfiera",
    "înfierând": "înfiera",
    "înfierându": "înfiera",
    "înfierară": "înfiera",
    "înfierarăm": "înfiera",
    "înfierarăți": "înfiera",
    "înfierase": "înfiera",
    "înfierasem": "înfiera",
    "înfieraseră": "înfiera",
    "înfieraserăm": "înfiera",
    "înfieraserăți": "înfiera",
    "înfieraseși": "înfiera",
    "înfierași": "înfiera",
    "înfierat": "înfiera",
    "înfierați": "înfiera",
    "înfieratu": "înfiera",
    "înfierau": "înfiera",
    "înfierează": "înfiera",
    "înfierez": "înfiera",
    "înfiereze": "înfiera",
    "înfierezi": "înfiera",
    "neînfierând": "înfiera",
    "neînfierându": "înfiera",
    "nemaiînfierând": "înfiera",
    "nemaiînfierându": "înfiera",
    "înfierată": "înfierat",
    "înfierate": "înfierat",
    "înfierați": "înfierat",
    "înfierbânt": "înfierbânta",
    "înfierbântă": "înfierbânta",
    "înfierbântai": "înfierbânta",
    "înfierbântam": "înfierbânta",
    "înfierbântăm": "înfierbânta",
    "înfierbântând": "înfierbânta",
    "înfierbântându": "înfierbânta",
    "înfierbântară": "înfierbânta",
    "înfierbântarăm": "înfierbânta",
    "înfierbântarăți": "înfierbânta",
    "înfierbântase": "înfierbânta",
    "înfierbântasem": "înfierbânta",
    "înfierbântaseră": "înfierbânta",
    "înfierbântaserăm": "înfierbânta",
    "înfierbântaserăți": "înfierbânta",
    "înfierbântaseși": "înfierbânta",
    "înfierbântași": "înfierbânta",
    "înfierbântat": "înfierbânta",
    "înfierbântați": "înfierbânta",
    "înfierbântatu": "înfierbânta",
    "înfierbântau": "înfierbânta",
    "înfierbânte": "înfierbânta",
    "înfierbânți": "înfierbânta",
    "neînfierbântând": "înfierbânta",
    "neînfierbântându": "înfierbânta",
    "nemaiînfierbântând": "înfierbânta",
    "nemaiînfierbântându": "înfierbânta",
    "înfierbântată": "înfierbântat",
    "înfierbântate": "înfierbântat",
    "înfierbântați": "înfierbântat",
    "înfierea": "înfiere",
    "înfieri": "înfiere",
    "înfierii": "înfiere",
    "înfierile": "înfiere",
    "înfierilor": "înfiere",
    "înfig": "înfige",
    "înfigă": "înfige",
    "înfigând": "înfige",
    "înfigându": "înfige",
    "înfigea": "înfige",
    "înfigeai": "înfige",
    "înfigeam": "înfige",
    "înfigeați": "înfige",
    "înfigeau": "înfige",
    "înfigem": "înfige",
    "înfigeți": "înfige",
    "înfigi": "înfige",
    "înfipse": "înfige",
    "înfipsei": "înfige",
    "înfipseră": "înfige",
    "înfipserăm": "înfige",
    "înfipserăți": "înfige",
    "înfipsese": "înfige",
    "înfipsesem": "înfige",
    "înfipseseră": "înfige",
    "înfipseserăm": "înfige",
    "înfipseserăți": "înfige",
    "înfipseseși": "înfige",
    "înfipseși": "înfige",
    "înfipt": "înfige",
    "înfiptu": "înfige",
    "neînfigând": "înfige",
    "neînfigându": "înfige",
    "nemaiînfigând": "înfige",
    "nemaiînfigându": "înfige",
    "înființă": "înființa",
    "înființai": "înființa",
    "înființam": "înființa",
    "înființăm": "înființa",
    "înființând": "înființa",
    "înființându": "înființa",
    "înființară": "înființa",
    "înființarăm": "înființa",
    "înființarăți": "înființa",
    "înființase": "înființa",
    "înființasem": "înființa",
    "înființaseră": "înființa",
    "înființaserăm": "înființa",
    "înființaserăți": "înființa",
    "înființaseși": "înființa",
    "înființași": "înființa",
    "înființat": "înființa",
    "înființați": "înființa",
    "înființatu": "înființa",
    "înființau": "înființa",
    "înființează": "înființa",
    "înființez": "înființa",
    "înființeze": "înființa",
    "înființezi": "înființa",
    "neînființând": "înființa",
    "neînființându": "înființa",
    "nemaiînființând": "înființa",
    "nemaiînființându": "înființa",
    "înființarea": "înființare",
    "înființări": "înființare",
    "înființării": "înființare",
    "înființările": "înființare",
    "înființărilor": "înființare",
    "înființata": "înființat",
    "înființată": "înființat",
    "înființate": "înființat",
    "înființatei": "înființat",
    "înființatele": "înființat",
    "înființatelor": "înființat",
    "înființați": "înființat",
    "înființații": "înființat",
    "înființaților": "înființat",
    "înființato": "înființat",
    "înființatul": "înființat",
    "înființatule": "înființat",
    "înființatului": "înființat",
    "infiltră": "infiltra",
    "infiltrai": "infiltra",
    "infiltram": "infiltra",
    "infiltrăm": "infiltra",
    "infiltrând": "infiltra",
    "infiltrându": "infiltra",
    "infiltrară": "infiltra",
    "infiltrarăm": "infiltra",
    "infiltrarăți": "infiltra",
    "infiltrase": "infiltra",
    "infiltrasem": "infiltra",
    "infiltraseră": "infiltra",
    "infiltraserăm": "infiltra",
    "infiltraserăți": "infiltra",
    "infiltraseși": "infiltra",
    "infiltrași": "infiltra",
    "infiltrat": "infiltra",
    "infiltrați": "infiltra",
    "infiltratu": "infiltra",
    "infiltrau": "infiltra",
    "infiltrează": "infiltra",
    "infiltrez": "infiltra",
    "infiltreze": "infiltra",
    "infiltrezi": "infiltra",
    "neinfiltrând": "infiltra",
    "neinfiltrându": "infiltra",
    "nemaiinfiltrând": "infiltra",
    "nemaiinfiltrându": "infiltra",
    "infiltrată": "infiltrat",
    "infiltrate": "infiltrat",
    "infiltrați": "infiltrat",
    "infinita": "infinit",
    "infinită": "infinit",
    "infinite": "infinit",
    "infinitei": "infinit",
    "infinitele": "infinit",
    "infinitelor": "infinit",
    "infiniți": "infinit",
    "infiniții": "infinit",
    "infiniților": "infinit",
    "infinitul": "infinit",
    "infinitului": "infinit",
    "infinituri": "infinit",
    "infiniturile": "infinit",
    "infiniturilor": "infinit",
    "infinitatea": "infinitate",
    "infinități": "infinitate",
    "infinității": "infinitate",
    "infinitezimala": "infinitezimal",
    "infinitezimală": "infinitezimal",
    "infinitezimale": "infinitezimal",
    "infinitezimalei": "infinitezimal",
    "infinitezimalele": "infinitezimal",
    "infinitezimalelor": "infinitezimal",
    "infinitezimali": "infinitezimal",
    "infinitezimalii": "infinitezimal",
    "infinitezimalilor": "infinitezimal",
    "infinitezimalo": "infinitezimal",
    "infinitezimalul": "infinitezimal",
    "infinitezimalule": "infinitezimal",
    "infinitezimalului": "infinitezimal",
    "inf.": "infinitiv",
    "infinitive": "infinitiv",
    "infinitivele": "infinitiv",
    "infinitivelor": "infinitiv",
    "infinitivul": "infinitiv",
    "infinitivului": "infinitiv",
    "înfioară": "înfiora",
    "înfioare": "înfiora",
    "înfior": "înfiora",
    "înfioră": "înfiora",
    "înfiorai": "înfiora",
    "înfioram": "înfiora",
    "înfiorăm": "înfiora",
    "înfiorând": "înfiora",
    "înfiorându": "înfiora",
    "înfiorară": "înfiora",
    "înfiorarăm": "înfiora",
    "înfiorarăți": "înfiora",
    "înfiorase": "înfiora",
    "înfiorasem": "înfiora",
    "înfioraseră": "înfiora",
    "înfioraserăm": "înfiora",
    "înfioraserăți": "înfiora",
    "înfioraseși": "înfiora",
    "înfiorași": "înfiora",
    "înfiorat": "înfiora",
    "înfiorați": "înfiora",
    "înfioratu": "înfiora",
    "înfiorau": "înfiora",
    "înfiorează": "înfiora",
    "înfiorez": "înfiora",
    "înfioreze": "înfiora",
    "înfiorezi": "înfiora",
    "înfiori": "înfiora",
    "neînfiorând": "înfiora",
    "neînfiorându": "înfiora",
    "nemaiînfiorând": "înfiora",
    "nemaiînfiorându": "înfiora",
    "înfiorarea": "înfiorare",
    "înfiorări": "înfiorare",
    "înfiorării": "înfiorare",
    "înfiorările": "înfiorare",
    "înfiorărilor": "înfiorare",
    "înfiorată": "înfiorat",
    "înfiorate": "înfiorat",
    "înfiorați": "înfiorat",
    "înfiorătoare": "înfiorător",
    "înfiorătoarea": "înfiorător",
    "înfiorătoarei": "înfiorător",
    "înfiorătoarele": "înfiorător",
    "înfiorătoarelor": "înfiorător",
    "înfiorători": "înfiorător",
    "înfiorătorii": "înfiorător",
    "înfiorătorilor": "înfiorător",
    "înfiorătorul": "înfiorător",
    "înfiorătorului": "înfiorător",
    "înfiptă": "înfipt",
    "înfipte": "înfipt",
    "înfipți": "înfipt",
    "înfirip": "înfiripa",
    "înfiripă": "înfiripa",
    "înfiripai": "înfiripa",
    "înfiripam": "înfiripa",
    "înfiripăm": "înfiripa",
    "înfiripând": "înfiripa",
    "înfiripându": "înfiripa",
    "înfiripară": "înfiripa",
    "înfiriparăm": "înfiripa",
    "înfiriparăți": "înfiripa",
    "înfiripase": "înfiripa",
    "înfiripasem": "înfiripa",
    "înfiripaseră": "înfiripa",
    "înfiripaserăm": "înfiripa",
    "înfiripaserăți": "înfiripa",
    "înfiripaseși": "înfiripa",
    "înfiripași": "înfiripa",
    "înfiripat": "înfiripa",
    "înfiripați": "înfiripa",
    "înfiripatu": "înfiripa",
    "înfiripau": "înfiripa",
    "înfiripe": "înfiripa",
    "înfiripează": "înfiripa",
    "înfiripez": "înfiripa",
    "înfiripeze": "înfiripa",
    "înfiripezi": "înfiripa",
    "înfiripi": "înfiripa",
    "neînfiripând": "înfiripa",
    "neînfiripându": "înfiripa",
    "nemaiînfiripând": "înfiripa",
    "nemaiînfiripându": "înfiripa",
    "înfiripată": "înfiripat",
    "înfiripate": "înfiripat",
    "înfiripați": "înfiripat",
    "infirma": "infirm",
    "infirmă": "infirm",
    "infirme": "infirm",
    "infirmei": "infirm",
    "infirmele": "infirm",
    "infirmelor": "infirm",
    "infirmi": "infirm",
    "infirmii": "infirm",
    "infirmilor": "infirm",
    "infirmul": "infirm",
    "infirmului": "infirm",
    "infirm": "infirma",
    "infirmă": "infirma",
    "infirmai": "infirma",
    "infirmam": "infirma",
    "infirmăm": "infirma",
    "infirmând": "infirma",
    "infirmându": "infirma",
    "infirmară": "infirma",
    "infirmarăm": "infirma",
    "infirmarăți": "infirma",
    "infirmase": "infirma",
    "infirmasem": "infirma",
    "infirmaseră": "infirma",
    "infirmaserăm": "infirma",
    "infirmaserăți": "infirma",
    "infirmaseși": "infirma",
    "infirmași": "infirma",
    "infirmat": "infirma",
    "infirmați": "infirma",
    "infirmatu": "infirma",
    "infirmau": "infirma",
    "infirme": "infirma",
    "infirmi": "infirma",
    "neinfirmând": "infirma",
    "neinfirmându": "infirma",
    "nemaiinfirmând": "infirma",
    "nemaiinfirmându": "infirma",
    "infirmată": "infirmat",
    "infirmate": "infirmat",
    "infirmați": "infirmat",
    "infirmeria": "infirmerie",
    "infirmeriei": "infirmerie",
    "infirmerii": "infirmerie",
    "infirmeriile": "infirmerie",
    "infirmeriilor": "infirmerie",
    "infirmieri": "infirmier",
    "infirmierii": "infirmier",
    "infirmierilor": "infirmier",
    "infirmierul": "infirmier",
    "infirmierule": "infirmier",
    "infirmierului": "infirmier",
    "infirmiera": "infirmieră",
    "infirmiere": "infirmieră",
    "infirmierei": "infirmieră",
    "infirmierele": "infirmieră",
    "infirmierelor": "infirmieră",
    "infirmitatea": "infirmitate",
    "infirmități": "infirmitate",
    "infirmității": "infirmitate",
    "infirmitățile": "infirmitate",
    "infirmităților": "infirmitate",
    "înflăcără": "înflăcăra",
    "înflăcărai": "înflăcăra",
    "înflăcăram": "înflăcăra",
    "înflăcărăm": "înflăcăra",
    "înflăcărând": "înflăcăra",
    "înflăcărându": "înflăcăra",
    "înflăcărară": "înflăcăra",
    "înflăcărarăm": "înflăcăra",
    "înflăcărarăți": "înflăcăra",
    "înflăcărase": "înflăcăra",
    "înflăcărasem": "înflăcăra",
    "înflăcăraseră": "înflăcăra",
    "înflăcăraserăm": "înflăcăra",
    "înflăcăraserăți": "înflăcăra",
    "înflăcăraseși": "înflăcăra",
    "înflăcărași": "înflăcăra",
    "înflăcărat": "înflăcăra",
    "înflăcărați": "înflăcăra",
    "înflăcăratu": "înflăcăra",
    "înflăcărau": "înflăcăra",
    "înflăcărează": "înflăcăra",
    "înflăcărez": "înflăcăra",
    "înflăcăreze": "înflăcăra",
    "înflăcărezi": "înflăcăra",
    "neînflăcărând": "înflăcăra",
    "neînflăcărându": "înflăcăra",
    "nemaiînflăcărând": "înflăcăra",
    "nemaiînflăcărându": "înflăcăra",
    "înflăcărarea": "înflăcărare",
    "înflăcărări": "înflăcărare",
    "înflăcărării": "înflăcărare",
    "înflăcărările": "înflăcărare",
    "înflăcărărilor": "înflăcărare",
    "înflăcărata": "înflăcărat",
    "înflăcărată": "înflăcărat",
    "înflăcărate": "înflăcărat",
    "înflăcăratei": "înflăcărat",
    "înflăcăratele": "înflăcărat",
    "înflăcăratelor": "înflăcărat",
    "înflăcărați": "înflăcărat",
    "înflăcărații": "înflăcărat",
    "înflăcăraților": "înflăcărat",
    "înflăcăratul": "înflăcărat",
    "înflăcăratului": "înflăcărat",
    "inflamă": "inflama",
    "inflamai": "inflama",
    "inflamam": "inflama",
    "inflamăm": "inflama",
    "inflamând": "inflama",
    "inflamându": "inflama",
    "inflamară": "inflama",
    "inflamarăm": "inflama",
    "inflamarăți": "inflama",
    "inflamase": "inflama",
    "inflamasem": "inflama",
    "inflamaseră": "inflama",
    "inflamaserăm": "inflama",
    "inflamaserăți": "inflama",
    "inflamaseși": "inflama",
    "inflamași": "inflama",
    "inflamat": "inflama",
    "inflamați": "inflama",
    "inflamatu": "inflama",
    "inflamau": "inflama",
    "inflamează": "inflama",
    "inflamez": "inflama",
    "inflameze": "inflama",
    "inflamezi": "inflama",
    "neinflamând": "inflama",
    "neinflamându": "inflama",
    "nemaiinflamând": "inflama",
    "nemaiinflamându": "inflama",
    "inflamarea": "inflamare",
    "inflamări": "inflamare",
    "inflamării": "inflamare",
    "inflamările": "inflamare",
    "inflamărilor": "inflamare",
    "inflamată": "inflamat",
    "inflamate": "inflamat",
    "inflamați": "inflamat",
    "inflamația": "inflamație",
    "inflamației": "inflamație",
    "inflamații": "inflamație",
    "inflamațiile": "inflamație",
    "inflamațiilor": "inflamație",
    "inflația": "inflație",
    "inflației": "inflație",
    "inflații": "inflație",
    "inflațiile": "inflație",
    "inflațiilor": "inflație",
    "inflaționista": "inflaționist",
    "inflaționistă": "inflaționist",
    "inflaționiste": "inflaționist",
    "inflaționistei": "inflaționist",
    "inflaționistele": "inflaționist",
    "inflaționistelor": "inflaționist",
    "inflaționiști": "inflaționist",
    "inflaționiștii": "inflaționist",
    "inflaționiștilor": "inflaționist",
    "inflaționistul": "inflaționist",
    "inflaționistului": "inflaționist",
    "inflexibila": "inflexibil",
    "inflexibilă": "inflexibil",
    "inflexibile": "inflexibil",
    "inflexibilei": "inflexibil",
    "inflexibilele": "inflexibil",
    "inflexibilelor": "inflexibil",
    "inflexibili": "inflexibil",
    "inflexibilii": "inflexibil",
    "inflexibililor": "inflexibil",
    "inflexibilul": "inflexibil",
    "inflexibilului": "inflexibil",
    "inflexibilitatea": "inflexibilitate",
    "inflexibilitateo": "inflexibilitate",
    "inflexibilități": "inflexibilitate",
    "inflexibilității": "inflexibilitate",
    "inflexibilitățile": "inflexibilitate",
    "inflexibilităților": "inflexibilitate",
    "inflexiunea": "inflexiune",
    "inflexiuni": "inflexiune",
    "inflexiunii": "inflexiune",
    "inflexiunile": "inflexiune",
    "inflexiunilor": "inflexiune",
    "inflig": "inflige",
    "infligă": "inflige",
    "infligând": "inflige",
    "infligându": "inflige",
    "infligea": "inflige",
    "infligeai": "inflige",
    "infligeam": "inflige",
    "infligeați": "inflige",
    "infligeau": "inflige",
    "infligem": "inflige",
    "infligeți": "inflige",
    "infligi": "inflige",
    "neinfligând": "inflige",
    "neinfligându": "inflige",
    "nemaiinfligând": "inflige",
    "nemaiinfligându": "inflige",
    "înfloră": "înflora",
    "înflorai": "înflora",
    "înfloram": "înflora",
    "înflorăm": "înflora",
    "înflorând": "înflora",
    "înflorându": "înflora",
    "înflorară": "înflora",
    "înflorarăm": "înflora",
    "înflorarăți": "înflora",
    "înflorase": "înflora",
    "înflorasem": "înflora",
    "înfloraseră": "înflora",
    "înfloraserăm": "înflora",
    "înfloraserăți": "înflora",
    "înfloraseși": "înflora",
    "înflorași": "înflora",
    "înflorat": "înflora",
    "înflorați": "înflora",
    "înfloratu": "înflora",
    "înflorau": "înflora",
    "înflorează": "înflora",
    "înflorez": "înflora",
    "înfloreze": "înflora",
    "înflorezi": "înflora",
    "neînflorând": "înflora",
    "neînflorându": "înflora",
    "nemaiînflorând": "înflora",
    "nemaiînflorându": "înflora",
    "înflorata": "înflorat",
    "înflorată": "înflorat",
    "înflorate": "înflorat",
    "înfloratei": "înflorat",
    "înfloratele": "înflorat",
    "înfloratelor": "înflorat",
    "înflorați": "înflorat",
    "înflorații": "înflorat",
    "înfloraților": "înflorat",
    "înfloratul": "înflorat",
    "înfloratului": "înflorat",
    "înflorea": "înflori",
    "înfloreai": "înflori",
    "înfloream": "înflori",
    "înflorească": "înflori",
    "înfloreați": "înflori",
    "înfloreau": "înflori",
    "înfloresc": "înflori",
    "înflorește": "înflori",
    "înflorești": "înflori",
    "înflorii": "înflori",
    "înflorim": "înflori",
    "înflorind": "înflori",
    "înflorindu": "înflori",
    "înfloriră": "înflori",
    "înflorirăm": "înflori",
    "înflorirăți": "înflori",
    "înflorise": "înflori",
    "înflorisem": "înflori",
    "înfloriseră": "înflori",
    "înfloriserăm": "înflori",
    "înfloriserăți": "înflori",
    "înfloriseși": "înflori",
    "înfloriși": "înflori",
    "înflorit": "înflori",
    "înfloriți": "înflori",
    "înfloritu": "înflori",
    "neînflorind": "înflori",
    "neînflorindu": "înflori",
    "nemaiînflorind": "înflori",
    "nemaiînflorindu": "înflori",
    "înflorirea": "înflorire",
    "înfloriri": "înflorire",
    "înfloririi": "înflorire",
    "înfloririle": "înflorire",
    "înfloririlor": "înflorire",
    "înflorita": "înflorit",
    "înflorită": "înflorit",
    "înflorite": "înflorit",
    "înfloritei": "înflorit",
    "înfloritele": "înflorit",
    "înfloritelor": "înflorit",
    "înfloriți": "înflorit",
    "înfloriții": "înflorit",
    "înfloriților": "înflorit",
    "înfloritul": "înflorit",
    "înfloritului": "înflorit",
    "înfloritoare": "înfloritor",
    "înfloritoarea": "înfloritor",
    "înfloritoarei": "înfloritor",
    "înfloritoarele": "înfloritor",
    "înfloritoarelor": "înfloritor",
    "înfloritori": "înfloritor",
    "înfloritorii": "înfloritor",
    "înfloritorilor": "înfloritor",
    "înfloritorul": "înfloritor",
    "înfloritorului": "înfloritor",
    "influenta": "influent",
    "influentă": "influent",
    "influente": "influent",
    "influentei": "influent",
    "influentele": "influent",
    "influentelor": "influent",
    "influenți": "influent",
    "influenții": "influent",
    "influenților": "influent",
    "influentul": "influent",
    "influentului": "influent",
    "influență": "influența",
    "influențai": "influența",
    "influențam": "influența",
    "influențăm": "influența",
    "influențând": "influența",
    "influențându": "influența",
    "influențară": "influența",
    "influențarăm": "influența",
    "influențarăți": "influența",
    "influențase": "influența",
    "influențasem": "influența",
    "influențaseră": "influența",
    "influențaserăm": "influența",
    "influențaserăți": "influența",
    "influențaseși": "influența",
    "influențași": "influența",
    "influențat": "influența",
    "influențați": "influența",
    "influențatu": "influența",
    "influențau": "influența",
    "influențează": "influența",
    "influențez": "influența",
    "influențeze": "influența",
    "influențezi": "influența",
    "neinfluențând": "influența",
    "neinfluențându": "influența",
    "nemaiinfluențând": "influența",
    "nemaiinfluențându": "influența",
    "influența": "influență",
    "influențe": "influență",
    "influenței": "influență",
    "influențele": "influență",
    "influențelor": "influență",
    "influențarea": "influențare",
    "influențări": "influențare",
    "influențării": "influențare",
    "influențările": "influențare",
    "influențărilor": "influențare",
    "influențată": "influențat",
    "influențate": "influențat",
    "influențați": "influențat",
    "înfoacă": "înfoca",
    "înfoace": "înfoca",
    "înfoc": "înfoca",
    "înfocă": "înfoca",
    "înfocai": "înfoca",
    "înfocam": "înfoca",
    "înfocăm": "înfoca",
    "înfocând": "înfoca",
    "înfocându": "înfoca",
    "înfocară": "înfoca",
    "înfocarăm": "înfoca",
    "înfocarăți": "înfoca",
    "înfocase": "înfoca",
    "înfocasem": "înfoca",
    "înfocaseră": "înfoca",
    "înfocaserăm": "înfoca",
    "înfocaserăți": "înfoca",
    "înfocaseși": "înfoca",
    "înfocași": "înfoca",
    "înfocat": "înfoca",
    "înfocați": "înfoca",
    "înfocatu": "înfoca",
    "înfocau": "înfoca",
    "înfoci": "înfoca",
    "neînfocând": "înfoca",
    "neînfocându": "înfoca",
    "nemaiînfocând": "înfoca",
    "nemaiînfocându": "înfoca",
    "înfocarea": "înfocare",
    "înfocări": "înfocare",
    "înfocării": "înfocare",
    "înfocările": "înfocare",
    "înfocărilor": "înfocare",
    "înfocata": "înfocat",
    "înfocată": "înfocat",
    "înfocate": "înfocat",
    "înfocatei": "înfocat",
    "înfocatele": "înfocat",
    "înfocatelor": "înfocat",
    "înfocați": "înfocat",
    "înfocații": "înfocat",
    "înfocaților": "înfocat",
    "înfocatul": "înfocat",
    "înfocatului": "înfocat",
    "înfofolea": "înfofoli",
    "înfofoleai": "înfofoli",
    "înfofoleam": "înfofoli",
    "înfofolească": "înfofoli",
    "înfofoleați": "înfofoli",
    "înfofoleau": "înfofoli",
    "înfofolesc": "înfofoli",
    "înfofolește": "înfofoli",
    "înfofolești": "înfofoli",
    "înfofolii": "înfofoli",
    "înfofolim": "înfofoli",
    "înfofolind": "înfofoli",
    "înfofolindu": "înfofoli",
    "înfofoliră": "înfofoli",
    "înfofolirăm": "înfofoli",
    "înfofolirăți": "înfofoli",
    "înfofolise": "înfofoli",
    "înfofolisem": "înfofoli",
    "înfofoliseră": "înfofoli",
    "înfofoliserăm": "înfofoli",
    "înfofoliserăți": "înfofoli",
    "înfofoliseși": "înfofoli",
    "înfofoliși": "înfofoli",
    "înfofolit": "înfofoli",
    "înfofoliți": "înfofoli",
    "înfofolitu": "înfofoli",
    "neînfofolind": "înfofoli",
    "neînfofolindu": "înfofoli",
    "nemaiînfofolind": "înfofoli",
    "nemaiînfofolindu": "înfofoli",
    "înfofolită": "înfofolit",
    "înfofolite": "înfofolit",
    "înfofoliți": "înfofolit",
    "înfoaie": "înfoia",
    "înfoi": "înfoia",
    "înfoiai": "înfoia",
    "înfoiam": "înfoia",
    "înfoiară": "înfoia",
    "înfoiarăm": "înfoia",
    "înfoiarăți": "înfoia",
    "înfoiase": "înfoia",
    "înfoiasem": "înfoia",
    "înfoiaseră": "înfoia",
    "înfoiaserăm": "înfoia",
    "înfoiaserăți": "înfoia",
    "înfoiaseși": "înfoia",
    "înfoiași": "înfoia",
    "înfoiat": "înfoia",
    "înfoiați": "înfoia",
    "înfoiatu": "înfoia",
    "înfoiau": "înfoia",
    "înfoie": "înfoia",
    "înfoiem": "înfoia",
    "înfoind": "înfoia",
    "înfoindu": "înfoia",
    "neînfoiind": "înfoia",
    "neînfoiindu": "înfoia",
    "nemaiînfoiind": "înfoia",
    "nemaiînfoiindu": "înfoia",
    "înfoiată": "înfoiat",
    "înfoiate": "înfoiat",
    "înfoiați": "înfoiat",
    "înfometă": "înfometa",
    "înfometai": "înfometa",
    "înfometam": "înfometa",
    "înfometăm": "înfometa",
    "înfometând": "înfometa",
    "înfometându": "înfometa",
    "înfometară": "înfometa",
    "înfometarăm": "înfometa",
    "înfometarăți": "înfometa",
    "înfometase": "înfometa",
    "înfometasem": "înfometa",
    "înfometaseră": "înfometa",
    "înfometaserăm": "înfometa",
    "înfometaserăți": "înfometa",
    "înfometaseși": "înfometa",
    "înfometași": "înfometa",
    "înfometat": "înfometa",
    "înfometați": "înfometa",
    "înfometatu": "înfometa",
    "înfometau": "înfometa",
    "înfometează": "înfometa",
    "înfometez": "înfometa",
    "înfometeze": "înfometa",
    "înfometezi": "înfometa",
    "neînfometând": "înfometa",
    "neînfometându": "înfometa",
    "nemaiînfometând": "înfometa",
    "nemaiînfometându": "înfometa",
    "înfometarea": "înfometare",
    "înfometareo": "înfometare",
    "înfometări": "înfometare",
    "înfometării": "înfometare",
    "înfometările": "înfometare",
    "înfometărilor": "înfometare",
    "înfometată": "înfometat",
    "înfometate": "înfometat",
    "înfometați": "înfometat",
    "informa": "inform",
    "informă": "inform",
    "informe": "inform",
    "informei": "inform",
    "informele": "inform",
    "informelor": "inform",
    "informi": "inform",
    "informii": "inform",
    "informilor": "inform",
    "informul": "inform",
    "informului": "inform",
    "informă": "informa",
    "informai": "informa",
    "informam": "informa",
    "informăm": "informa",
    "informând": "informa",
    "informându": "informa",
    "informară": "informa",
    "informarăm": "informa",
    "informarăți": "informa",
    "informase": "informa",
    "informasem": "informa",
    "informaseră": "informa",
    "informaserăm": "informa",
    "informaserăți": "informa",
    "informaseși": "informa",
    "informași": "informa",
    "informat": "informa",
    "informați": "informa",
    "informatu": "informa",
    "informau": "informa",
    "informează": "informa",
    "informez": "informa",
    "informeze": "informa",
    "informezi": "informa",
    "neinformând": "informa",
    "neinformându": "informa",
    "nemaiinformând": "informa",
    "nemaiinformându": "informa",
    "informarea": "informare",
    "informări": "informare",
    "informării": "informare",
    "informările": "informare",
    "informărilor": "informare",
    "informata": "informat",
    "informată": "informat",
    "informate": "informat",
    "informatei": "informat",
    "informatele": "informat",
    "informatelor": "informat",
    "informați": "informat",
    "informații": "informat",
    "informaților": "informat",
    "informatul": "informat",
    "informatului": "informat",
    "informatica": "informatic",
    "informatică": "informatic",
    "informatice": "informatic",
    "informaticei": "informatic",
    "informaticele": "informatic",
    "informaticelor": "informatic",
    "informatici": "informatic",
    "informaticii": "informatic",
    "informaticilor": "informatic",
    "informatico": "informatic",
    "informaticul": "informatic",
    "informaticule": "informatic",
    "informaticului": "informatic",
    "informatica": "informatică",
    "informaticele": "informatică",
    "informatici": "informatică",
    "informaticii": "informatică",
    "informaticilor": "informatică",
    "informatico": "informatică",
    "informația": "informație",
    "informației": "informație",
    "informații": "informație",
    "informațiile": "informație",
    "informațiilor": "informație",
    "informativa": "informativ",
    "informativă": "informativ",
    "informative": "informativ",
    "informativei": "informativ",
    "informativele": "informativ",
    "informativelor": "informativ",
    "informativi": "informativ",
    "informativii": "informativ",
    "informativilor": "informativ",
    "informativo": "informativ",
    "informativul": "informativ",
    "informativule": "informativ",
    "informativului": "informativ",
    "informatori": "informator",
    "informatorii": "informator",
    "informatorilor": "informator",
    "informatorul": "informator",
    "informatorule": "informator",
    "informatorului": "informator",
    "infracțională": "infracțional",
    "infracționale": "infracțional",
    "infracționali": "infracțional",
    "infracționalitatea": "infracționalitate",
    "infracționalități": "infracționalitate",
    "infracționalității": "infracționalitate",
    "infracționalitățile": "infracționalitate",
    "infracționalităților": "infracționalitate",
    "infracțiunea": "infracțiune",
    "infracțiuni": "infracțiune",
    "infracțiunii": "infracțiune",
    "infracțiunile": "infracțiune",
    "infracțiunilor": "infracțiune",
    "infractori": "infractor",
    "infractorii": "infractor",
    "infractorilor": "infractor",
    "infractorul": "infractor",
    "infractorului": "infractor",
    "înfrână": "înfrâna",
    "înfrânai": "înfrâna",
    "înfrânam": "înfrâna",
    "înfrânăm": "înfrâna",
    "înfrânând": "înfrâna",
    "înfrânându": "înfrâna",
    "înfrânară": "înfrâna",
    "înfrânarăm": "înfrâna",
    "înfrânarăți": "înfrâna",
    "înfrânase": "înfrâna",
    "înfrânasem": "înfrâna",
    "înfrânaseră": "înfrâna",
    "înfrânaserăm": "înfrâna",
    "înfrânaserăți": "înfrâna",
    "înfrânaseși": "înfrâna",
    "înfrânași": "înfrâna",
    "înfrânat": "înfrâna",
    "înfrânați": "înfrâna",
    "înfrânatu": "înfrâna",
    "înfrânau": "înfrâna",
    "înfrânează": "înfrâna",
    "înfrânez": "înfrâna",
    "înfrâneze": "înfrâna",
    "înfrânezi": "înfrâna",
    "neînfrânând": "înfrâna",
    "neînfrânându": "înfrâna",
    "nemaiînfrânând": "înfrâna",
    "nemaiînfrânându": "înfrâna",
    "înfrânarea": "înfrânare",
    "înfrânareo": "înfrânare",
    "înfrânări": "înfrânare",
    "înfrânării": "înfrânare",
    "înfrânările": "înfrânare",
    "înfrânărilor": "înfrânare",
    "înfrânată": "înfrânat",
    "înfrânate": "înfrânat",
    "înfrânați": "înfrânat",
    "înfrâng": "înfrânge",
    "înfrângă": "înfrânge",
    "înfrângând": "înfrânge",
    "înfrângându": "înfrânge",
    "înfrângea": "înfrânge",
    "înfrângeai": "înfrânge",
    "înfrângeam": "înfrânge",
    "înfrângeați": "înfrânge",
    "înfrângeau": "înfrânge",
    "înfrângem": "înfrânge",
    "înfrângeți": "înfrânge",
    "înfrângi": "înfrânge",
    "înfrânse": "înfrânge",
    "înfrânsei": "înfrânge",
    "înfrânseră": "înfrânge",
    "înfrânserăm": "înfrânge",
    "înfrânserăți": "înfrânge",
    "înfrânsese": "înfrânge",
    "înfrânsesem": "înfrânge",
    "înfrânseseră": "înfrânge",
    "înfrânseserăm": "înfrânge",
    "înfrânseserăți": "înfrânge",
    "înfrânseseși": "înfrânge",
    "înfrânseși": "înfrânge",
    "înfrânt": "înfrânge",
    "înfrântu": "înfrânge",
    "neînfrângând": "înfrânge",
    "neînfrângându": "înfrânge",
    "nemaiînfrângând": "înfrânge",
    "nemaiînfrângându": "înfrânge",
    "înfrângerea": "înfrângere",
    "înfrângeri": "înfrângere",
    "înfrângerii": "înfrângere",
    "înfrângerile": "înfrângere",
    "înfrângerilor": "înfrângere",
    "înfrântă": "înfrânt",
    "înfrânte": "înfrânt",
    "înfrânți": "înfrânt",
    "infraroșie": "infraroșu",
    "infraroșii": "infraroșu",
    "infraroșiile": "infraroșu",
    "infraroșiilor": "infraroșu",
    "infraroșul": "infraroșu",
    "infraroșului": "infraroșu",
    "ir.": "infraroșu",
    "infrastructura": "infrastructură",
    "infrastructuri": "infrastructură",
    "infrastructurii": "infrastructură",
    "infrastructurile": "infrastructură",
    "infrastructurilor": "infrastructură",
    "înfrățea": "înfrăți",
    "înfrățeai": "înfrăți",
    "înfrățeam": "înfrăți",
    "înfrățească": "înfrăți",
    "înfrățeați": "înfrăți",
    "înfrățeau": "înfrăți",
    "înfrățesc": "înfrăți",
    "înfrățește": "înfrăți",
    "înfrățești": "înfrăți",
    "înfrății": "înfrăți",
    "înfrățim": "înfrăți",
    "înfrățind": "înfrăți",
    "înfrățindu": "înfrăți",
    "înfrățiră": "înfrăți",
    "înfrățirăm": "înfrăți",
    "înfrățirăți": "înfrăți",
    "înfrățise": "înfrăți",
    "înfrățisem": "înfrăți",
    "înfrățiseră": "înfrăți",
    "înfrățiserăm": "înfrăți",
    "înfrățiserăți": "înfrăți",
    "înfrățiseși": "înfrăți",
    "înfrățiși": "înfrăți",
    "înfrățit": "înfrăți",
    "înfrățiți": "înfrăți",
    "înfrățitu": "înfrăți",
    "neînfrățind": "înfrăți",
    "neînfrățindu": "înfrăți",
    "nemaiînfrățind": "înfrăți",
    "nemaiînfrățindu": "înfrăți",
    "înfrățirea": "înfrățire",
    "înfrățiri": "înfrățire",
    "înfrățirii": "înfrățire",
    "înfrățirile": "înfrățire",
    "înfrățirilor": "înfrățire",
    "înfrățită": "înfrățit",
    "înfrățite": "înfrățit",
    "înfrățiți": "înfrățit",
    "înfric": "înfrica",
    "înfrică": "înfrica",
    "înfricai": "înfrica",
    "înfricam": "înfrica",
    "înfricăm": "înfrica",
    "înfricând": "înfrica",
    "înfricându": "înfrica",
    "înfricară": "înfrica",
    "înfricarăm": "înfrica",
    "înfricarăți": "înfrica",
    "înfricase": "înfrica",
    "înfricasem": "înfrica",
    "înfricaseră": "înfrica",
    "înfricaserăm": "înfrica",
    "înfricaserăți": "înfrica",
    "înfricaseși": "înfrica",
    "înfricași": "înfrica",
    "înfricat": "înfrica",
    "înfricați": "înfrica",
    "înfricatu": "înfrica",
    "înfricau": "înfrica",
    "înfrice": "înfrica",
    "înfrici": "înfrica",
    "neînfricând": "înfrica",
    "neînfricându": "înfrica",
    "nemaiînfricând": "înfrica",
    "nemaiînfricându": "înfrica",
    "înfricată": "înfricat",
    "înfricate": "înfricat",
    "înfricați": "înfricat",
    "înfricoșă": "înfricoșa",
    "înfricoșai": "înfricoșa",
    "înfricoșam": "înfricoșa",
    "înfricoșăm": "înfricoșa",
    "înfricoșând": "înfricoșa",
    "înfricoșându": "înfricoșa",
    "înfricoșară": "înfricoșa",
    "înfricoșarăm": "înfricoșa",
    "înfricoșarăți": "înfricoșa",
    "înfricoșase": "înfricoșa",
    "înfricoșasem": "înfricoșa",
    "înfricoșaseră": "înfricoșa",
    "înfricoșaserăm": "înfricoșa",
    "înfricoșaserăți": "înfricoșa",
    "înfricoșaseși": "înfricoșa",
    "înfricoșași": "înfricoșa",
    "înfricoșat": "înfricoșa",
    "înfricoșați": "înfricoșa",
    "înfricoșatu": "înfricoșa",
    "înfricoșau": "înfricoșa",
    "înfricoșează": "înfricoșa",
    "înfricoșez": "înfricoșa",
    "înfricoșeze": "înfricoșa",
    "înfricoșezi": "înfricoșa",
    "neînfricoșând": "înfricoșa",
    "neînfricoșându": "înfricoșa",
    "nemaiînfricoșând": "înfricoșa",
    "nemaiînfricoșându": "înfricoșa",
    "înfricoșata": "înfricoșat",
    "înfricoșată": "înfricoșat",
    "înfricoșate": "înfricoșat",
    "înfricoșatei": "înfricoșat",
    "înfricoșatele": "înfricoșat",
    "înfricoșatelor": "înfricoșat",
    "înfricoșați": "înfricoșat",
    "înfricoșații": "înfricoșat",
    "înfricoșaților": "înfricoșat",
    "înfricoșatul": "înfricoșat",
    "înfricoșatului": "înfricoșat",
    "înfricoșătoare": "înfricoșător",
    "înfricoșătoarea": "înfricoșător",
    "înfricoșătoarei": "înfricoșător",
    "înfricoșătoarele": "înfricoșător",
    "înfricoșătoarelor": "înfricoșător",
    "înfricoșători": "înfricoșător",
    "înfricoșătorii": "înfricoșător",
    "înfricoșătorilor": "înfricoșător",
    "înfricoșătorul": "înfricoșător",
    "înfricoșătorului": "înfricoșător",
    "înfrigurarea": "înfrigurare",
    "înfrigurări": "înfrigurare",
    "înfrigurării": "înfrigurare",
    "înfrigurările": "înfrigurare",
    "înfrigurărilor": "înfrigurare",
    "înfrigurata": "înfrigurat",
    "înfrigurată": "înfrigurat",
    "înfrigurate": "înfrigurat",
    "înfriguratei": "înfrigurat",
    "înfriguratele": "înfrigurat",
    "înfriguratelor": "înfrigurat",
    "înfriguratul": "înfrigurat",
    "înfriguratului": "înfrigurat",
    "înfrumoșă": "înfrumoșa",
    "înfrumoșai": "înfrumoșa",
    "înfrumoșam": "înfrumoșa",
    "înfrumoșăm": "înfrumoșa",
    "înfrumoșând": "înfrumoșa",
    "înfrumoșându": "înfrumoșa",
    "înfrumoșară": "înfrumoșa",
    "înfrumoșarăm": "înfrumoșa",
    "înfrumoșarăți": "înfrumoșa",
    "înfrumoșase": "înfrumoșa",
    "înfrumoșasem": "înfrumoșa",
    "înfrumoșaseră": "înfrumoșa",
    "înfrumoșaserăm": "înfrumoșa",
    "înfrumoșaserăți": "înfrumoșa",
    "înfrumoșaseși": "înfrumoșa",
    "înfrumoșași": "înfrumoșa",
    "înfrumoșat": "înfrumoșa",
    "înfrumoșați": "înfrumoșa",
    "înfrumoșatu": "înfrumoșa",
    "înfrumoșau": "înfrumoșa",
    "înfrumoșează": "înfrumoșa",
    "înfrumoșez": "înfrumoșa",
    "înfrumoșeze": "înfrumoșa",
    "înfrumoșezi": "înfrumoșa",
    "neînfrumoșând": "înfrumoșa",
    "neînfrumoșându": "înfrumoșa",
    "nemaiînfrumoșând": "înfrumoșa",
    "nemaiînfrumoșându": "înfrumoșa",
    "înfrumoșată": "înfrumoșat",
    "înfrumoșate": "înfrumoșat",
    "înfrumoșați": "înfrumoșat",
    "înfrumuseță": "înfrumuseța",
    "înfrumusețai": "înfrumuseța",
    "înfrumusețam": "înfrumuseța",
    "înfrumusețăm": "înfrumuseța",
    "înfrumusețând": "înfrumuseța",
    "înfrumusețându": "înfrumuseța",
    "înfrumusețară": "înfrumuseța",
    "înfrumusețarăm": "înfrumuseța",
    "înfrumusețarăți": "înfrumuseța",
    "înfrumusețase": "înfrumuseța",
    "înfrumusețasem": "înfrumuseța",
    "înfrumusețaseră": "înfrumuseța",
    "înfrumusețaserăm": "înfrumuseța",
    "înfrumusețaserăți": "înfrumuseța",
    "înfrumusețaseși": "înfrumuseța",
    "înfrumusețași": "înfrumuseța",
    "înfrumusețat": "înfrumuseța",
    "înfrumusețați": "înfrumuseța",
    "înfrumusețatu": "înfrumuseța",
    "înfrumusețau": "înfrumuseța",
    "înfrumusețează": "înfrumuseța",
    "înfrumusețez": "înfrumuseța",
    "înfrumusețeze": "înfrumuseța",
    "înfrumusețezi": "înfrumuseța",
    "neînfrumusețând": "înfrumuseța",
    "neînfrumusețându": "înfrumuseța",
    "nemaiînfrumusețând": "înfrumuseța",
    "nemaiînfrumusețându": "înfrumuseța",
    "înfrumusețarea": "înfrumusețare",
    "înfrumusețări": "înfrumusețare",
    "înfrumusețării": "înfrumusețare",
    "înfrumusețările": "înfrumusețare",
    "înfrumusețărilor": "înfrumusețare",
    "înfrumusețată": "înfrumusețat",
    "înfrumusețate": "înfrumusețat",
    "înfrumusețați": "înfrumusețat",
    "înfrunt": "înfrunta",
    "înfruntă": "înfrunta",
    "înfruntai": "înfrunta",
    "înfruntam": "înfrunta",
    "înfruntăm": "înfrunta",
    "înfruntând": "înfrunta",
    "înfruntându": "înfrunta",
    "înfruntară": "înfrunta",
    "înfruntarăm": "înfrunta",
    "înfruntarăți": "înfrunta",
    "înfruntase": "înfrunta",
    "înfruntasem": "înfrunta",
    "înfruntaseră": "înfrunta",
    "înfruntaserăm": "înfrunta",
    "înfruntaserăți": "înfrunta",
    "înfruntaseși": "înfrunta",
    "înfruntași": "înfrunta",
    "înfruntat": "înfrunta",
    "înfruntați": "înfrunta",
    "înfruntatu": "înfrunta",
    "înfruntau": "înfrunta",
    "înfrunte": "înfrunta",
    "înfrunți": "înfrunta",
    "neînfruntând": "înfrunta",
    "neînfruntându": "înfrunta",
    "nemaiînfruntând": "înfrunta",
    "nemaiînfruntându": "înfrunta",
    "înfruntarea": "înfruntare",
    "înfruntări": "înfruntare",
    "înfruntării": "înfruntare",
    "înfruntările": "înfruntare",
    "înfruntărilor": "înfruntare",
    "înfruntată": "înfruntat",
    "înfruntate": "înfruntat",
    "înfruntați": "înfruntat",
    "înfrunzea": "înfrunzi",
    "înfrunzeai": "înfrunzi",
    "înfrunzeam": "înfrunzi",
    "înfrunzească": "înfrunzi",
    "înfrunzeați": "înfrunzi",
    "înfrunzeau": "înfrunzi",
    "înfrunzesc": "înfrunzi",
    "înfrunzește": "înfrunzi",
    "înfrunzești": "înfrunzi",
    "înfrunzii": "înfrunzi",
    "înfrunzim": "înfrunzi",
    "înfrunzind": "înfrunzi",
    "înfrunzindu": "înfrunzi",
    "înfrunziră": "înfrunzi",
    "înfrunzirăm": "înfrunzi",
    "înfrunzirăți": "înfrunzi",
    "înfrunzise": "înfrunzi",
    "înfrunzisem": "înfrunzi",
    "înfrunziseră": "înfrunzi",
    "înfrunziserăm": "înfrunzi",
    "înfrunziserăți": "înfrunzi",
    "înfrunziseși": "înfrunzi",
    "înfrunziși": "înfrunzi",
    "înfrunzit": "înfrunzi",
    "înfrunziți": "înfrunzi",
    "înfrunzitu": "înfrunzi",
    "neînfrunzind": "înfrunzi",
    "neînfrunzindu": "înfrunzi",
    "nemaiînfrunzind": "înfrunzi",
    "nemaiînfrunzindu": "înfrunzi",
    "înfrunzita": "înfrunzit",
    "înfrunzită": "înfrunzit",
    "înfrunzite": "înfrunzit",
    "înfrunzitei": "înfrunzit",
    "înfrunzitele": "înfrunzit",
    "înfrunzitelor": "înfrunzit",
    "înfrunziți": "înfrunzit",
    "înfrunziții": "înfrunzit",
    "înfrunziților": "înfrunzit",
    "înfrunzitul": "înfrunzit",
    "înfrunzitului": "înfrunzit",
    "înfrupt": "înfrupta",
    "înfruptă": "înfrupta",
    "înfruptai": "înfrupta",
    "înfruptam": "înfrupta",
    "înfruptăm": "înfrupta",
    "înfruptând": "înfrupta",
    "înfruptându": "înfrupta",
    "înfruptară": "înfrupta",
    "înfruptarăm": "înfrupta",
    "înfruptarăți": "înfrupta",
    "înfruptase": "înfrupta",
    "înfruptasem": "înfrupta",
    "înfruptaseră": "înfrupta",
    "înfruptaserăm": "înfrupta",
    "înfruptaserăți": "înfrupta",
    "înfruptaseși": "înfrupta",
    "înfruptași": "înfrupta",
    "înfruptat": "înfrupta",
    "înfruptați": "înfrupta",
    "înfruptatu": "înfrupta",
    "înfruptau": "înfrupta",
    "înfrupte": "înfrupta",
    "înfrupți": "înfrupta",
    "neînfruptând": "înfrupta",
    "neînfruptându": "înfrupta",
    "nemaiînfruptând": "înfrupta",
    "nemaiînfruptându": "înfrupta",
    "înfruptată": "înfruptat",
    "înfruptate": "înfruptat",
    "înfruptați": "înfruptat",
    "înfulec": "înfuleca",
    "înfulecă": "înfuleca",
    "înfulecai": "înfuleca",
    "înfulecam": "înfuleca",
    "înfulecăm": "înfuleca",
    "înfulecând": "înfuleca",
    "înfulecându": "înfuleca",
    "înfulecară": "înfuleca",
    "înfulecarăm": "înfuleca",
    "înfulecarăți": "înfuleca",
    "înfulecase": "înfuleca",
    "înfulecasem": "înfuleca",
    "înfulecaseră": "înfuleca",
    "înfulecaserăm": "înfuleca",
    "înfulecaserăți": "înfuleca",
    "înfulecaseși": "înfuleca",
    "înfulecași": "înfuleca",
    "înfulecat": "înfuleca",
    "înfulecați": "înfuleca",
    "înfulecatu": "înfuleca",
    "înfulecau": "înfuleca",
    "înfulece": "înfuleca",
    "înfuleci": "înfuleca",
    "neînfulecând": "înfuleca",
    "neînfulecându": "înfuleca",
    "nemaiînfulecând": "înfuleca",
    "nemaiînfulecându": "înfuleca",
    "înfulecată": "înfulecat",
    "înfulecate": "înfulecat",
    "înfulecați": "înfulecat",
    "înfumură": "înfumura",
    "înfumurai": "înfumura",
    "înfumuram": "înfumura",
    "înfumurăm": "înfumura",
    "înfumurând": "înfumura",
    "înfumurându": "înfumura",
    "înfumurară": "înfumura",
    "înfumurarăm": "înfumura",
    "înfumurarăți": "înfumura",
    "înfumurase": "înfumura",
    "înfumurasem": "înfumura",
    "înfumuraseră": "înfumura",
    "înfumuraserăm": "înfumura",
    "înfumuraserăți": "înfumura",
    "înfumuraseși": "înfumura",
    "înfumurași": "înfumura",
    "înfumurat": "înfumura",
    "înfumurați": "înfumura",
    "înfumuratu": "înfumura",
    "înfumurau": "înfumura",
    "înfumurează": "înfumura",
    "înfumurez": "înfumura",
    "înfumureze": "înfumura",
    "înfumurezi": "înfumura",
    "neînfumurând": "înfumura",
    "neînfumurându": "înfumura",
    "nemaiînfumurând": "înfumura",
    "nemaiînfumurându": "înfumura",
    "înfumurarea": "înfumurare",
    "înfumurări": "înfumurare",
    "înfumurării": "înfumurare",
    "înfumurările": "înfumurare",
    "înfumurărilor": "înfumurare",
    "înfumurata": "înfumurat",
    "înfumurată": "înfumurat",
    "înfumurate": "înfumurat",
    "înfumuratei": "înfumurat",
    "înfumuratele": "înfumurat",
    "înfumuratelor": "înfumurat",
    "înfumurați": "înfumurat",
    "înfumurații": "înfumurat",
    "înfumuraților": "înfumurat",
    "înfumuratul": "înfumurat",
    "înfumuratului": "înfumurat",
    "înfund": "înfunda",
    "înfundă": "înfunda",
    "înfundai": "înfunda",
    "înfundam": "înfunda",
    "înfundăm": "înfunda",
    "înfundând": "înfunda",
    "înfundându": "înfunda",
    "înfundară": "înfunda",
    "înfundarăm": "înfunda",
    "înfundarăți": "înfunda",
    "înfundase": "înfunda",
    "înfundasem": "înfunda",
    "înfundaseră": "înfunda",
    "înfundaserăm": "înfunda",
    "înfundaserăți": "înfunda",
    "înfundaseși": "înfunda",
    "înfundași": "înfunda",
    "înfundat": "înfunda",
    "înfundați": "înfunda",
    "înfundatu": "înfunda",
    "înfundau": "înfunda",
    "înfunde": "înfunda",
    "înfunzi": "înfunda",
    "neînfundând": "înfunda",
    "neînfundându": "înfunda",
    "nemaiînfundând": "înfunda",
    "nemaiînfundându": "înfunda",
    "înfundata": "înfundat",
    "înfundată": "înfundat",
    "înfundate": "înfundat",
    "înfundatei": "înfundat",
    "înfundatele": "înfundat",
    "înfundatelor": "înfundat",
    "înfundați": "înfundat",
    "înfundații": "înfundat",
    "înfundaților": "înfundat",
    "înfundatul": "înfundat",
    "înfundatului": "înfundat",
    "înfuriai": "înfuria",
    "înfuriam": "înfuria",
    "înfuriară": "înfuria",
    "înfuriarăm": "înfuria",
    "înfuriarăți": "înfuria",
    "înfuriase": "înfuria",
    "înfuriasem": "înfuria",
    "înfuriaseră": "înfuria",
    "înfuriaserăm": "înfuria",
    "înfuriaserăți": "înfuria",
    "înfuriaseși": "înfuria",
    "înfuriași": "înfuria",
    "înfuriat": "înfuria",
    "înfuriați": "înfuria",
    "înfuriatu": "înfuria",
    "înfuriau": "înfuria",
    "înfurie": "înfuria",
    "înfuriem": "înfuria",
    "înfurii": "înfuria",
    "înfuriind": "înfuria",
    "înfuriindu": "înfuria",
    "neînfuriind": "înfuria",
    "neînfuriindu": "înfuria",
    "nemaiînfuriind": "înfuria",
    "nemaiînfuriindu": "înfuria",
    "înfuriata": "înfuriat",
    "înfuriată": "înfuriat",
    "înfuriate": "înfuriat",
    "înfuriatei": "înfuriat",
    "înfuriatele": "înfuriat",
    "înfuriatelor": "înfuriat",
    "înfuriați": "înfuriat",
    "înfuriații": "înfuriat",
    "înfuriaților": "înfuriat",
    "înfuriatul": "înfuriat",
    "înfuriatului": "înfuriat",
    "infuză": "infuza",
    "infuzai": "infuza",
    "infuzam": "infuza",
    "infuzăm": "infuza",
    "infuzând": "infuza",
    "infuzându": "infuza",
    "infuzară": "infuza",
    "infuzarăm": "infuza",
    "infuzarăți": "infuza",
    "infuzase": "infuza",
    "infuzasem": "infuza",
    "infuzaseră": "infuza",
    "infuzaserăm": "infuza",
    "infuzaserăți": "infuza",
    "infuzaseși": "infuza",
    "infuzași": "infuza",
    "infuzat": "infuza",
    "infuzați": "infuza",
    "infuzatu": "infuza",
    "infuzau": "infuza",
    "infuzează": "infuza",
    "infuzez": "infuza",
    "infuzeze": "infuza",
    "infuzezi": "infuza",
    "neinfuzând": "infuza",
    "neinfuzându": "infuza",
    "nemaiinfuzând": "infuza",
    "nemaiinfuzându": "infuza",
    "infuzată": "infuzat",
    "infuzate": "infuzat",
    "infuzați": "infuzat",
    "îngăduia": "îngădui",
    "îngăduiai": "îngădui",
    "îngăduiam": "îngădui",
    "îngăduiați": "îngădui",
    "îngăduiau": "îngădui",
    "îngăduie": "îngădui",
    "îngăduii": "îngădui",
    "îngăduim": "îngădui",
    "îngăduind": "îngădui",
    "îngăduindu": "îngădui",
    "îngăduiră": "îngădui",
    "îngăduirăm": "îngădui",
    "îngăduirăți": "îngădui",
    "îngăduise": "îngădui",
    "îngăduisem": "îngădui",
    "îngăduiseră": "îngădui",
    "îngăduiserăm": "îngădui",
    "îngăduiserăți": "îngădui",
    "îngăduiseși": "îngădui",
    "îngăduiși": "îngădui",
    "îngăduit": "îngădui",
    "îngăduiți": "îngădui",
    "îngăduitu": "îngădui",
    "neîngăduind": "îngădui",
    "neîngăduindu": "îngădui",
    "nemaiîngăduind": "îngădui",
    "nemaiîngăduindu": "îngădui",
    "îngăduința": "îngăduință",
    "îngăduințe": "îngăduință",
    "îngăduinței": "îngăduință",
    "îngăduințele": "îngăduință",
    "îngăduințelor": "îngăduință",
    "îngăduită": "îngăduit",
    "îngăduite": "îngăduit",
    "îngăduiți": "îngăduit",
    "îngăduitoare": "îngăduitor",
    "îngăduitoarea": "îngăduitor",
    "îngăduitoarei": "îngăduitor",
    "îngăduitoarele": "îngăduitor",
    "îngăduitoarelor": "îngăduitor",
    "îngăduitori": "îngăduitor",
    "îngăduitorii": "îngăduitor",
    "îngăduitorilor": "îngăduitor",
    "îngăduitorul": "îngăduitor",
    "îngăduitorului": "îngăduitor",
    "îngăim": "îngăima",
    "îngaimă": "îngăima",
    "îngăimă": "îngăima",
    "îngăimai": "îngăima",
    "îngăimam": "îngăima",
    "îngăimăm": "îngăima",
    "îngăimând": "îngăima",
    "îngăimându": "îngăima",
    "îngăimară": "îngăima",
    "îngăimarăm": "îngăima",
    "îngăimarăți": "îngăima",
    "îngăimase": "îngăima",
    "îngăimasem": "îngăima",
    "îngăimaseră": "îngăima",
    "îngăimaserăm": "îngăima",
    "îngăimaserăți": "îngăima",
    "îngăimaseși": "îngăima",
    "îngăimași": "îngăima",
    "îngăimat": "îngăima",
    "îngăimați": "îngăima",
    "îngăimatu": "îngăima",
    "îngăimau": "îngăima",
    "îngaime": "îngăima",
    "îngăimi": "îngăima",
    "neîngăimând": "îngăima",
    "neîngăimându": "îngăima",
    "nemaiîngăimând": "îngăima",
    "nemaiîngăimându": "îngăima",
    "îngăimată": "îngăimat",
    "îngăimate": "îngăimat",
    "îngăimați": "îngăimat",
    "îngălă": "îngăla",
    "îngălai": "îngăla",
    "îngălam": "îngăla",
    "îngălăm": "îngăla",
    "îngălând": "îngăla",
    "îngălându": "îngăla",
    "îngălară": "îngăla",
    "îngălarăm": "îngăla",
    "îngălarăți": "îngăla",
    "îngălase": "îngăla",
    "îngălasem": "îngăla",
    "îngălaseră": "îngăla",
    "îngălaserăm": "îngăla",
    "îngălaserăți": "îngăla",
    "îngălaseși": "îngăla",
    "îngălași": "îngăla",
    "îngălat": "îngăla",
    "îngălați": "îngăla",
    "îngălatu": "îngăla",
    "îngălau": "îngăla",
    "îngălează": "îngăla",
    "îngălez": "îngăla",
    "îngăleze": "îngăla",
    "îngălezi": "îngăla",
    "neîngălând": "îngăla",
    "neîngălându": "îngăla",
    "nemaiîngălând": "îngăla",
    "nemaiîngălându": "îngăla",
    "îngălată": "îngălat",
    "îngălate": "îngălat",
    "îngălați": "îngălat",
    "îngălbenea": "îngălbeni",
    "îngălbeneai": "îngălbeni",
    "îngălbeneam": "îngălbeni",
    "îngălbenească": "îngălbeni",
    "îngălbeneați": "îngălbeni",
    "îngălbeneau": "îngălbeni",
    "îngălbenesc": "îngălbeni",
    "îngălbenește": "îngălbeni",
    "îngălbenești": "îngălbeni",
    "îngălbenii": "îngălbeni",
    "îngălbenim": "îngălbeni",
    "îngălbenind": "îngălbeni",
    "îngălbenindu": "îngălbeni",
    "îngălbeniră": "îngălbeni",
    "îngălbenirăm": "îngălbeni",
    "îngălbenirăți": "îngălbeni",
    "îngălbenise": "îngălbeni",
    "îngălbenisem": "îngălbeni",
    "îngălbeniseră": "îngălbeni",
    "îngălbeniserăm": "îngălbeni",
    "îngălbeniserăți": "îngălbeni",
    "îngălbeniseși": "îngălbeni",
    "îngălbeniși": "îngălbeni",
    "îngălbenit": "îngălbeni",
    "îngălbeniți": "îngălbeni",
    "îngălbenitu": "îngălbeni",
    "neîngălbenind": "îngălbeni",
    "neîngălbenindu": "îngălbeni",
    "nemaiîngălbenind": "îngălbeni",
    "nemaiîngălbenindu": "îngălbeni",
    "îngălbenită": "îngălbenit",
    "îngălbenite": "îngălbenit",
    "îngălbeniți": "îngălbenit",
    "îngâmf": "îngâmfa",
    "îngâmfă": "îngâmfa",
    "îngâmfai": "îngâmfa",
    "îngâmfam": "îngâmfa",
    "îngâmfăm": "îngâmfa",
    "îngâmfând": "îngâmfa",
    "îngâmfându": "îngâmfa",
    "îngâmfară": "îngâmfa",
    "îngâmfarăm": "îngâmfa",
    "îngâmfarăți": "îngâmfa",
    "îngâmfase": "îngâmfa",
    "îngâmfasem": "îngâmfa",
    "îngâmfaseră": "îngâmfa",
    "îngâmfaserăm": "îngâmfa",
    "îngâmfaserăți": "îngâmfa",
    "îngâmfaseși": "îngâmfa",
    "îngâmfași": "îngâmfa",
    "îngâmfat": "îngâmfa",
    "îngâmfați": "îngâmfa",
    "îngâmfatu": "îngâmfa",
    "îngâmfau": "îngâmfa",
    "îngâmfe": "îngâmfa",
    "îngâmfi": "îngâmfa",
    "neîngâmfând": "îngâmfa",
    "neîngâmfându": "îngâmfa",
    "nemaiîngâmfând": "îngâmfa",
    "nemaiîngâmfându": "îngâmfa",
    "îngâmfarea": "îngâmfare",
    "îngâmfări": "îngâmfare",
    "îngâmfării": "îngâmfare",
    "îngâmfările": "îngâmfare",
    "îngâmfărilor": "îngâmfare",
    "îngâmfata": "îngâmfat",
    "îngâmfată": "îngâmfat",
    "îngâmfate": "îngâmfat",
    "îngâmfatei": "îngâmfat",
    "îngâmfatele": "îngâmfat",
    "îngâmfatelor": "îngâmfat",
    "îngâmfați": "îngâmfat",
    "îngâmfații": "îngâmfat",
    "îngâmfaților": "îngâmfat",
    "îngâmfatul": "îngâmfat",
    "îngâmfatului": "îngâmfat",
    "îngân": "îngâna",
    "îngână": "îngâna",
    "îngânai": "îngâna",
    "îngânam": "îngâna",
    "îngânăm": "îngâna",
    "îngânând": "îngâna",
    "îngânându": "îngâna",
    "îngânară": "îngâna",
    "îngânarăm": "îngâna",
    "îngânarăți": "îngâna",
    "îngânase": "îngâna",
    "îngânasem": "îngâna",
    "îngânaseră": "îngâna",
    "îngânaserăm": "îngâna",
    "îngânaserăți": "îngâna",
    "îngânaseși": "îngâna",
    "îngânași": "îngâna",
    "îngânat": "îngâna",
    "îngânați": "îngâna",
    "îngânatu": "îngâna",
    "îngânau": "îngâna",
    "îngâne": "îngâna",
    "îngâni": "îngâna",
    "neîngânând": "îngâna",
    "neîngânându": "îngâna",
    "nemaiîngânând": "îngâna",
    "nemaiîngânându": "îngâna",
    "îngânarea": "îngânare",
    "îngânareo": "îngânare",
    "îngânări": "îngânare",
    "îngânării": "îngânare",
    "îngânările": "îngânare",
    "îngânărilor": "îngânare",
    "îngânată": "îngânat",
    "îngânate": "îngânat",
    "îngânați": "îngânat",
    "îngândură": "îngândura",
    "îngândurai": "îngândura",
    "îngânduram": "îngândura",
    "îngândurăm": "îngândura",
    "îngândurând": "îngândura",
    "îngândurându": "îngândura",
    "îngândurară": "îngândura",
    "îngândurarăm": "îngândura",
    "îngândurarăți": "îngândura",
    "îngândurase": "îngândura",
    "îngândurasem": "îngândura",
    "îngânduraseră": "îngândura",
    "îngânduraserăm": "îngândura",
    "îngânduraserăți": "îngândura",
    "îngânduraseși": "îngândura",
    "îngândurași": "îngândura",
    "îngândurat": "îngândura",
    "îngândurați": "îngândura",
    "îngânduratu": "îngândura",
    "îngândurau": "îngândura",
    "îngândurează": "îngândura",
    "îngândurez": "îngândura",
    "îngândureze": "îngândura",
    "îngândurezi": "îngândura",
    "neîngândurând": "îngândura",
    "neîngândurându": "îngândura",
    "nemaiîngândurând": "îngândura",
    "nemaiîngândurându": "îngândura",
    "îngândurata": "îngândurat",
    "îngândurată": "îngândurat",
    "îngândurate": "îngândurat",
    "îngânduratei": "îngândurat",
    "îngânduratele": "îngândurat",
    "îngânduratelor": "îngândurat",
    "îngândurați": "îngândurat",
    "îngândurații": "îngândurat",
    "îngânduraților": "îngândurat",
    "îngânduratul": "îngândurat",
    "îngânduratului": "îngândurat",
    "îngemănă": "îngemăna",
    "îngemănai": "îngemăna",
    "îngemănam": "îngemăna",
    "îngemănăm": "îngemăna",
    "îngemănând": "îngemăna",
    "îngemănându": "îngemăna",
    "îngemănară": "îngemăna",
    "îngemănarăm": "îngemăna",
    "îngemănarăți": "îngemăna",
    "îngemănase": "îngemăna",
    "îngemănasem": "îngemăna",
    "îngemănaseră": "îngemăna",
    "îngemănaserăm": "îngemăna",
    "îngemănaserăți": "îngemăna",
    "îngemănaseși": "îngemăna",
    "îngemănași": "îngemăna",
    "îngemănat": "îngemăna",
    "îngemănați": "îngemăna",
    "îngemănatu": "îngemăna",
    "îngemănau": "îngemăna",
    "îngemănează": "îngemăna",
    "îngemănez": "îngemăna",
    "îngemăneze": "îngemăna",
    "îngemănezi": "îngemăna",
    "neîngemănând": "îngemăna",
    "neîngemănându": "îngemăna",
    "nemaiîngemănând": "îngemăna",
    "nemaiîngemănându": "îngemăna",
    "îngemănată": "îngemănat",
    "îngemănate": "îngemănat",
    "îngemănați": "îngemănat",
    "ingenioasa": "ingenios",
    "ingenioasă": "ingenios",
    "ingenioase": "ingenios",
    "ingenioasei": "ingenios",
    "ingenioasele": "ingenios",
    "ingenioaselor": "ingenios",
    "ingenioși": "ingenios",
    "ingenioșii": "ingenios",
    "ingenioșilor": "ingenios",
    "ingeniosul": "ingenios",
    "ingeniosului": "ingenios",
    "ingeniozitatea": "ingeniozitate",
    "ingeniozități": "ingeniozitate",
    "ingeniozității": "ingeniozitate",
    "îngenunche": "îngenunchea",
    "îngenuncheai": "îngenunchea",
    "îngenuncheam": "îngenunchea",
    "îngenuncheară": "îngenunchea",
    "îngenunchearăm": "îngenunchea",
    "îngenunchearăți": "îngenunchea",
    "îngenunchease": "îngenunchea",
    "îngenuncheasem": "îngenunchea",
    "îngenuncheaseră": "îngenunchea",
    "îngenuncheaserăm": "îngenunchea",
    "îngenuncheaserăți": "îngenunchea",
    "îngenuncheaseși": "îngenunchea",
    "îngenuncheași": "îngenunchea",
    "îngenuncheat": "îngenunchea",
    "îngenuncheați": "îngenunchea",
    "îngenuncheatu": "îngenunchea",
    "îngenuncheau": "îngenunchea",
    "îngenunchează": "îngenunchea",
    "îngenunchem": "îngenunchea",
    "îngenunchez": "îngenunchea",
    "îngenuncheze": "îngenunchea",
    "îngenunchezi": "îngenunchea",
    "îngenunchind": "îngenunchea",
    "îngenunchindu": "îngenunchea",
    "neîngenunchind": "îngenunchea",
    "neîngenunchindu": "îngenunchea",
    "nemaiîngenunchind": "îngenunchea",
    "nemaiîngenunchindu": "îngenunchea",
    "îngenuncheată": "îngenuncheat",
    "îngenuncheate": "îngenuncheat",
    "îngenuncheați": "îngenuncheat",
    "îngenuncherea": "îngenunchere",
    "îngenunchereo": "îngenunchere",
    "îngenuncheri": "îngenunchere",
    "îngenuncherii": "îngenunchere",
    "îngenuncherile": "îngenunchere",
    "îngenuncherilor": "îngenunchere",
    "ingenua": "ingenuu",
    "ingenuă": "ingenuu",
    "ingenue": "ingenuu",
    "ingenuei": "ingenuu",
    "ingenuele": "ingenuu",
    "ingenuelor": "ingenuu",
    "ingenui": "ingenuu",
    "ingenuii": "ingenuu",
    "ingenuilor": "ingenuu",
    "ingenuo": "ingenuu",
    "ingenuul": "ingenuu",
    "ingenuule": "ingenuu",
    "ingenuului": "ingenuu",
    "îngeri": "înger",
    "îngerii": "înger",
    "îngerilor": "înger",
    "îngerul": "înger",
    "îngerului": "înger",
    "ingeră": "ingera",
    "ingerai": "ingera",
    "ingeram": "ingera",
    "ingerăm": "ingera",
    "ingerând": "ingera",
    "ingerându": "ingera",
    "ingerară": "ingera",
    "ingerarăm": "ingera",
    "ingerarăți": "ingera",
    "ingerase": "ingera",
    "ingerasem": "ingera",
    "ingeraseră": "ingera",
    "ingeraserăm": "ingera",
    "ingeraserăți": "ingera",
    "ingeraseși": "ingera",
    "ingerași": "ingera",
    "ingerat": "ingera",
    "ingerați": "ingera",
    "ingeratu": "ingera",
    "ingerau": "ingera",
    "ingerează": "ingera",
    "ingerez": "ingera",
    "ingereze": "ingera",
    "ingerezi": "ingera",
    "neingerând": "ingera",
    "neingerându": "ingera",
    "nemaiingerând": "ingera",
    "nemaiingerându": "ingera",
    "ingerată": "ingerat",
    "ingerate": "ingerat",
    "ingerați": "ingerat",
    "îngereasca": "îngeresc",
    "îngerească": "îngeresc",
    "îngereasco": "îngeresc",
    "îngerescul": "îngeresc",
    "îngerescule": "îngeresc",
    "îngerescului": "îngeresc",
    "îngerești": "îngeresc",
    "îngereștii": "îngeresc",
    "îngereștile": "îngeresc",
    "îngereștilor": "îngeresc",
    "ingerința": "ingerință",
    "ingerințe": "ingerință",
    "ingerinței": "ingerință",
    "ingerințele": "ingerință",
    "ingerințelor": "ingerință",
    "înghemuia": "înghemui",
    "înghemuiai": "înghemui",
    "înghemuiam": "înghemui",
    "înghemuiască": "înghemui",
    "înghemuiați": "înghemui",
    "înghemuiau": "înghemui",
    "înghemuiesc": "înghemui",
    "înghemuiește": "înghemui",
    "înghemuiești": "înghemui",
    "înghemuii": "înghemui",
    "înghemuim": "înghemui",
    "înghemuind": "înghemui",
    "înghemuindu": "înghemui",
    "înghemuiră": "înghemui",
    "înghemuirăm": "înghemui",
    "înghemuirăți": "înghemui",
    "înghemuise": "înghemui",
    "înghemuisem": "înghemui",
    "înghemuiseră": "înghemui",
    "înghemuiserăm": "înghemui",
    "înghemuiserăți": "înghemui",
    "înghemuiseși": "înghemui",
    "înghemuiși": "înghemui",
    "înghemuit": "înghemui",
    "înghemuiți": "înghemui",
    "înghemuitu": "înghemui",
    "neînghemuind": "înghemui",
    "neînghemuindu": "înghemui",
    "nemaiînghemuind": "înghemui",
    "nemaiînghemuindu": "înghemui",
    "înghemuită": "înghemuit",
    "înghemuite": "înghemuit",
    "înghemuiți": "înghemuit",
    "înghesuia": "înghesui",
    "înghesuiai": "înghesui",
    "înghesuiam": "înghesui",
    "înghesuiați": "înghesui",
    "înghesuiau": "înghesui",
    "înghesuie": "înghesui",
    "înghesuii": "înghesui",
    "înghesuim": "înghesui",
    "înghesuind": "înghesui",
    "înghesuindu": "înghesui",
    "înghesuiră": "înghesui",
    "înghesuirăm": "înghesui",
    "înghesuirăți": "înghesui",
    "înghesuise": "înghesui",
    "înghesuisem": "înghesui",
    "înghesuiseră": "înghesui",
    "înghesuiserăm": "înghesui",
    "înghesuiserăți": "înghesui",
    "înghesuiseși": "înghesui",
    "înghesuiși": "înghesui",
    "înghesuit": "înghesui",
    "înghesuiți": "înghesui",
    "înghesuitu": "înghesui",
    "neînghesuind": "înghesui",
    "neînghesuindu": "înghesui",
    "nemaiînghesuind": "înghesui",
    "nemaiînghesuindu": "înghesui",
    "înghesuiala": "înghesuială",
    "înghesuieli": "înghesuială",
    "înghesuielii": "înghesuială",
    "înghesuielile": "înghesuială",
    "înghesuielilor": "înghesuială",
    "înghesuită": "înghesuit",
    "înghesuite": "înghesuit",
    "înghesuiți": "înghesuit",
    "înghețul": "îngheț",
    "înghețului": "îngheț",
    "înghețuri": "îngheț",
    "înghețurile": "îngheț",
    "înghețurilor": "îngheț",
    "îngheață": "îngheța",
    "îngheț": "îngheța",
    "îngheță": "îngheța",
    "înghețai": "îngheța",
    "înghețam": "îngheța",
    "înghețăm": "îngheța",
    "înghețând": "îngheța",
    "înghețându": "îngheța",
    "înghețară": "îngheța",
    "înghețarăm": "îngheța",
    "înghețarăți": "îngheța",
    "înghețase": "îngheța",
    "înghețasem": "îngheța",
    "înghețaseră": "îngheța",
    "înghețaserăm": "îngheța",
    "înghețaserăți": "îngheța",
    "înghețaseși": "îngheța",
    "înghețași": "îngheța",
    "înghețat": "îngheța",
    "înghețați": "îngheța",
    "înghețatu": "îngheța",
    "înghețau": "îngheța",
    "înghețe": "îngheța",
    "îngheți": "îngheța",
    "neînghețând": "îngheța",
    "neînghețându": "îngheța",
    "nemaiînghețând": "îngheța",
    "nemaiînghețându": "îngheța",
    "înghețarea": "înghețare",
    "înghețareo": "înghețare",
    "înghețări": "înghețare",
    "înghețării": "înghețare",
    "înghețările": "înghețare",
    "înghețărilor": "înghețare",
    "înghețată": "înghețat",
    "înghețate": "înghețat",
    "înghețați": "înghețat",
    "înghețata": "înghețată",
    "înghețate": "înghețată",
    "înghețatei": "înghețată",
    "înghețatele": "înghețată",
    "înghețatelor": "înghețată",
    "înghimpă": "înghimpa",
    "înghimpai": "înghimpa",
    "înghimpam": "înghimpa",
    "înghimpăm": "înghimpa",
    "înghimpând": "înghimpa",
    "înghimpându": "înghimpa",
    "înghimpară": "înghimpa",
    "înghimparăm": "înghimpa",
    "înghimparăți": "înghimpa",
    "înghimpase": "înghimpa",
    "înghimpasem": "înghimpa",
    "înghimpaseră": "înghimpa",
    "înghimpaserăm": "înghimpa",
    "înghimpaserăți": "înghimpa",
    "înghimpaseși": "înghimpa",
    "înghimpași": "înghimpa",
    "înghimpat": "înghimpa",
    "înghimpați": "înghimpa",
    "înghimpatu": "înghimpa",
    "înghimpau": "înghimpa",
    "înghimpează": "înghimpa",
    "înghimpez": "înghimpa",
    "înghimpeze": "înghimpa",
    "înghimpezi": "înghimpa",
    "neînghimpând": "înghimpa",
    "neînghimpându": "înghimpa",
    "nemaiînghimpând": "înghimpa",
    "nemaiînghimpându": "înghimpa",
    "înghimpată": "înghimpat",
    "înghimpate": "înghimpat",
    "înghimpați": "înghimpat",
    "înghioldea": "înghioldi",
    "înghioldeai": "înghioldi",
    "înghioldeam": "înghioldi",
    "înghioldească": "înghioldi",
    "înghioldeați": "înghioldi",
    "înghioldeau": "înghioldi",
    "înghioldesc": "înghioldi",
    "înghioldește": "înghioldi",
    "înghioldești": "înghioldi",
    "înghioldii": "înghioldi",
    "înghioldim": "înghioldi",
    "înghioldind": "înghioldi",
    "înghioldindu": "înghioldi",
    "înghioldiră": "înghioldi",
    "înghioldirăm": "înghioldi",
    "înghioldirăți": "înghioldi",
    "înghioldise": "înghioldi",
    "înghioldisem": "înghioldi",
    "înghioldiseră": "înghioldi",
    "înghioldiserăm": "înghioldi",
    "înghioldiserăți": "înghioldi",
    "înghioldiseși": "înghioldi",
    "înghioldiși": "înghioldi",
    "înghioldit": "înghioldi",
    "înghioldiți": "înghioldi",
    "înghiolditu": "înghioldi",
    "neînghioldind": "înghioldi",
    "neînghioldindu": "înghioldi",
    "nemaiînghioldind": "înghioldi",
    "nemaiînghioldindu": "înghioldi",
    "înghioldită": "înghioldit",
    "înghioldite": "înghioldit",
    "înghioldiți": "înghioldit",
    "înghiontea": "înghionti",
    "înghionteai": "înghionti",
    "înghionteam": "înghionti",
    "înghiontească": "înghionti",
    "înghionteați": "înghionti",
    "înghionteau": "înghionti",
    "înghiontesc": "înghionti",
    "înghiontește": "înghionti",
    "înghiontești": "înghionti",
    "înghiontii": "înghionti",
    "înghiontim": "înghionti",
    "înghiontind": "înghionti",
    "înghiontindu": "înghionti",
    "înghiontiră": "înghionti",
    "înghiontirăm": "înghionti",
    "înghiontirăți": "înghionti",
    "înghiontise": "înghionti",
    "înghiontisem": "înghionti",
    "înghiontiseră": "înghionti",
    "înghiontiserăm": "înghionti",
    "înghiontiserăți": "înghionti",
    "înghiontiseși": "înghionti",
    "înghiontiși": "înghionti",
    "înghiontit": "înghionti",
    "înghiontiți": "înghionti",
    "înghiontitu": "înghionti",
    "neînghiontind": "înghionti",
    "neînghiontindu": "înghionti",
    "nemaiînghiontind": "înghionti",
    "nemaiînghiontindu": "înghionti",
    "înghiontită": "înghiontit",
    "înghiontite": "înghiontit",
    "înghiontiți": "înghiontit",
    "înghit": "înghiți",
    "înghită": "înghiți",
    "înghite": "înghiți",
    "înghițea": "înghiți",
    "înghițeai": "înghiți",
    "înghițeam": "înghiți",
    "înghițeați": "înghiți",
    "înghițeau": "înghiți",
    "înghiții": "înghiți",
    "înghițim": "înghiți",
    "înghițind": "înghiți",
    "înghițindu": "înghiți",
    "înghițiră": "înghiți",
    "înghițirăm": "înghiți",
    "înghițirăți": "înghiți",
    "înghițise": "înghiți",
    "înghițisem": "înghiți",
    "înghițiseră": "înghiți",
    "înghițiserăm": "înghiți",
    "înghițiserăți": "înghiți",
    "înghițiseși": "înghiți",
    "înghițiși": "înghiți",
    "înghițit": "înghiți",
    "înghițiți": "înghiți",
    "înghițitu": "înghiți",
    "neînghițind": "înghiți",
    "neînghițindu": "înghiți",
    "nemaiînghițind": "înghiți",
    "nemaiînghițindu": "înghiți",
    "înghițirea": "înghițire",
    "înghițiri": "înghițire",
    "înghițirii": "înghițire",
    "înghițirile": "înghițire",
    "înghițirilor": "înghițire",
    "înghițită": "înghițit",
    "înghițite": "înghițit",
    "înghițiți": "înghițit",
    "înghițitura": "înghițitură",
    "înghițituri": "înghițitură",
    "înghițiturii": "înghițitură",
    "înghițiturile": "înghițitură",
    "înghițiturilor": "înghițitură",
    "ing": "inginer",
    "ing.": "inginer",
    "ingineri": "inginer",
    "inginerii": "inginer",
    "inginerilor": "inginer",
    "inginerul": "inginer",
    "inginerului": "inginer",
    "ingineria": "inginerie",
    "ingineriei": "inginerie",
    "inginerii": "inginerie",
    "ingineriile": "inginerie",
    "ingineriilor": "inginerie",
    "inginerio": "inginerie",
    "înglobă": "îngloba",
    "înglobai": "îngloba",
    "înglobam": "îngloba",
    "înglobăm": "îngloba",
    "înglobând": "îngloba",
    "înglobându": "îngloba",
    "înglobară": "îngloba",
    "înglobarăm": "îngloba",
    "înglobarăți": "îngloba",
    "înglobase": "îngloba",
    "înglobasem": "îngloba",
    "înglobaseră": "îngloba",
    "înglobaserăm": "îngloba",
    "înglobaserăți": "îngloba",
    "înglobaseși": "îngloba",
    "înglobași": "îngloba",
    "înglobat": "îngloba",
    "înglobați": "îngloba",
    "înglobatu": "îngloba",
    "înglobau": "îngloba",
    "înglobează": "îngloba",
    "înglobez": "îngloba",
    "înglobeze": "îngloba",
    "înglobezi": "îngloba",
    "neînglobând": "îngloba",
    "neînglobându": "îngloba",
    "nemaiînglobând": "îngloba",
    "nemaiînglobându": "îngloba",
    "înglobarea": "înglobare",
    "înglobareo": "înglobare",
    "înglobări": "înglobare",
    "înglobării": "înglobare",
    "înglobările": "înglobare",
    "înglobărilor": "înglobare",
    "înglobată": "înglobat",
    "înglobate": "înglobat",
    "înglobați": "înglobat",
    "înglodă": "îngloda",
    "înglodai": "îngloda",
    "înglodam": "îngloda",
    "înglodăm": "îngloda",
    "înglodând": "îngloda",
    "înglodându": "îngloda",
    "înglodară": "îngloda",
    "înglodarăm": "îngloda",
    "înglodarăți": "îngloda",
    "înglodase": "îngloda",
    "înglodasem": "îngloda",
    "înglodaseră": "îngloda",
    "înglodaserăm": "îngloda",
    "înglodaserăți": "îngloda",
    "înglodaseși": "îngloda",
    "înglodași": "îngloda",
    "înglodat": "îngloda",
    "înglodați": "îngloda",
    "înglodatu": "îngloda",
    "înglodau": "îngloda",
    "înglodează": "îngloda",
    "înglodez": "îngloda",
    "înglodeze": "îngloda",
    "înglodezi": "îngloda",
    "neînglodând": "îngloda",
    "neînglodându": "îngloda",
    "nemaiînglodând": "îngloda",
    "nemaiînglodându": "îngloda",
    "înglodată": "înglodat",
    "înglodate": "înglodat",
    "înglodați": "înglodat",
    "înglotea": "îngloti",
    "îngloteai": "îngloti",
    "îngloteam": "îngloti",
    "înglotească": "îngloti",
    "îngloteați": "îngloti",
    "îngloteau": "îngloti",
    "înglotesc": "îngloti",
    "înglotește": "îngloti",
    "înglotești": "îngloti",
    "înglotii": "îngloti",
    "înglotim": "îngloti",
    "înglotind": "îngloti",
    "înglotindu": "îngloti",
    "înglotiră": "îngloti",
    "înglotirăm": "îngloti",
    "înglotirăți": "îngloti",
    "înglotise": "îngloti",
    "înglotisem": "îngloti",
    "înglotiseră": "îngloti",
    "înglotiserăm": "îngloti",
    "înglotiserăți": "îngloti",
    "înglotiseși": "îngloti",
    "înglotiși": "îngloti",
    "înglotit": "îngloti",
    "înglotiți": "îngloti",
    "înglotitu": "îngloti",
    "neînglotind": "îngloti",
    "neînglotindu": "îngloti",
    "nemaiînglotind": "îngloti",
    "nemaiînglotindu": "îngloti",
    "înglotită": "înglotit",
    "înglotite": "înglotit",
    "înglotiți": "înglotit",
    "îngrădea": "îngrădi",
    "îngrădeai": "îngrădi",
    "îngrădeam": "îngrădi",
    "îngrădească": "îngrădi",
    "îngrădeați": "îngrădi",
    "îngrădeau": "îngrădi",
    "îngrădesc": "îngrădi",
    "îngrădește": "îngrădi",
    "îngrădești": "îngrădi",
    "îngrădii": "îngrădi",
    "îngrădim": "îngrădi",
    "îngrădind": "îngrădi",
    "îngrădindu": "îngrădi",
    "îngrădiră": "îngrădi",
    "îngrădirăm": "îngrădi",
    "îngrădirăți": "îngrădi",
    "îngrădise": "îngrădi",
    "îngrădisem": "îngrădi",
    "îngrădiseră": "îngrădi",
    "îngrădiserăm": "îngrădi",
    "îngrădiserăți": "îngrădi",
    "îngrădiseși": "îngrădi",
    "îngrădiși": "îngrădi",
    "îngrădit": "îngrădi",
    "îngrădiți": "îngrădi",
    "îngrăditu": "îngrădi",
    "neîngrădind": "îngrădi",
    "neîngrădindu": "îngrădi",
    "nemaiîngrădind": "îngrădi",
    "nemaiîngrădindu": "îngrădi",
    "îngrădirea": "îngrădire",
    "îngrădireo": "îngrădire",
    "îngrădiri": "îngrădire",
    "îngrădirii": "îngrădire",
    "îngrădirile": "îngrădire",
    "îngrădirilor": "îngrădire",
    "îngrădită": "îngrădit",
    "îngrădite": "îngrădit",
    "îngrădiți": "îngrădit",
    "îngrăditura": "îngrăditură",
    "îngrădituri": "îngrăditură",
    "îngrăditurii": "îngrăditură",
    "îngrăditurile": "îngrăditură",
    "îngrăditurilor": "îngrăditură",
    "îngrămădea": "îngrămădi",
    "îngrămădeai": "îngrămădi",
    "îngrămădeam": "îngrămădi",
    "îngrămădească": "îngrămădi",
    "îngrămădeați": "îngrămădi",
    "îngrămădeau": "îngrămădi",
    "îngrămădesc": "îngrămădi",
    "îngrămădește": "îngrămădi",
    "îngrămădești": "îngrămădi",
    "îngrămădii": "îngrămădi",
    "îngrămădim": "îngrămădi",
    "îngrămădind": "îngrămădi",
    "îngrămădindu": "îngrămădi",
    "îngrămădiră": "îngrămădi",
    "îngrămădirăm": "îngrămădi",
    "îngrămădirăți": "îngrămădi",
    "îngrămădise": "îngrămădi",
    "îngrămădisem": "îngrămădi",
    "îngrămădiseră": "îngrămădi",
    "îngrămădiserăm": "îngrămădi",
    "îngrămădiserăți": "îngrămădi",
    "îngrămădiseși": "îngrămădi",
    "îngrămădiși": "îngrămădi",
    "îngrămădit": "îngrămădi",
    "îngrămădiți": "îngrămădi",
    "îngrămăditu": "îngrămădi",
    "neîngrămădind": "îngrămădi",
    "neîngrămădindu": "îngrămădi",
    "nemaiîngrămădind": "îngrămădi",
    "nemaiîngrămădindu": "îngrămădi",
    "îngrămădirea": "îngrămădire",
    "îngrămădiri": "îngrămădire",
    "îngrămădirii": "îngrămădire",
    "îngrămădirile": "îngrămădire",
    "îngrămădirilor": "îngrămădire",
    "îngrămădită": "îngrămădit",
    "îngrămădite": "îngrămădit",
    "îngrămădiți": "îngrămădit",
    "îngraș": "îngrășa",
    "îngrașă": "îngrășa",
    "îngrășă": "îngrășa",
    "îngrășai": "îngrășa",
    "îngrășam": "îngrășa",
    "îngrășăm": "îngrășa",
    "îngrășând": "îngrășa",
    "îngrășându": "îngrășa",
    "îngrășară": "îngrășa",
    "îngrășarăm": "îngrășa",
    "îngrășarăți": "îngrășa",
    "îngrășase": "îngrășa",
    "îngrășasem": "îngrășa",
    "îngrășaseră": "îngrășa",
    "îngrășaserăm": "îngrășa",
    "îngrășaserăți": "îngrășa",
    "îngrășaseși": "îngrășa",
    "îngrășași": "îngrășa",
    "îngrășat": "îngrășa",
    "îngrășați": "îngrășa",
    "îngrășatu": "îngrășa",
    "îngrășau": "îngrășa",
    "îngrașe": "îngrășa",
    "îngrași": "îngrășa",
    "neîngrășând": "îngrășa",
    "neîngrășându": "îngrășa",
    "nemaiîngrășând": "îngrășa",
    "nemaiîngrășându": "îngrășa",
    "îngrășământul": "îngrășământ",
    "îngrășământului": "îngrășământ",
    "îngrășăminte": "îngrășământ",
    "îngrășămintele": "îngrășământ",
    "îngrășămintelor": "îngrășământ",
    "îngrășată": "îngrășat",
    "îngrășate": "îngrășat",
    "îngrășați": "îngrășat",
    "ingrata": "ingrat",
    "ingrată": "ingrat",
    "ingrate": "ingrat",
    "ingratei": "ingrat",
    "ingratele": "ingrat",
    "ingratelor": "ingrat",
    "ingrați": "ingrat",
    "ingrații": "ingrat",
    "ingraților": "ingrat",
    "ingratul": "ingrat",
    "ingratului": "ingrat",
    "ingratitudinea": "ingratitudine",
    "ingratitudini": "ingratitudine",
    "ingratitudinii": "ingratitudine",
    "ingratitudinile": "ingratitudine",
    "ingratitudinilor": "ingratitudine",
    "îngrețoșă": "îngrețoșa",
    "îngrețoșai": "îngrețoșa",
    "îngrețoșam": "îngrețoșa",
    "îngrețoșăm": "îngrețoșa",
    "îngrețoșând": "îngrețoșa",
    "îngrețoșându": "îngrețoșa",
    "îngrețoșară": "îngrețoșa",
    "îngrețoșarăm": "îngrețoșa",
    "îngrețoșarăți": "îngrețoșa",
    "îngrețoșase": "îngrețoșa",
    "îngrețoșasem": "îngrețoșa",
    "îngrețoșaseră": "îngrețoșa",
    "îngrețoșaserăm": "îngrețoșa",
    "îngrețoșaserăți": "îngrețoșa",
    "îngrețoșaseși": "îngrețoșa",
    "îngrețoșași": "îngrețoșa",
    "îngrețoșat": "îngrețoșa",
    "îngrețoșați": "îngrețoșa",
    "îngrețoșatu": "îngrețoșa",
    "îngrețoșau": "îngrețoșa",
    "îngrețoșează": "îngrețoșa",
    "îngrețoșez": "îngrețoșa",
    "îngrețoșeze": "îngrețoșa",
    "îngrețoșezi": "îngrețoșa",
    "neîngrețoșând": "îngrețoșa",
    "neîngrețoșându": "îngrețoșa",
    "nemaiîngrețoșând": "îngrețoșa",
    "nemaiîngrețoșându": "îngrețoșa",
    "îngrețoșată": "îngrețoșat",
    "îngrețoșate": "îngrețoșat",
    "îngrețoșați": "îngrețoșat",
    "îngreuiai": "îngreuia",
    "îngreuiam": "îngreuia",
    "îngreuiară": "îngreuia",
    "îngreuiarăm": "îngreuia",
    "îngreuiarăți": "îngreuia",
    "îngreuiase": "îngreuia",
    "îngreuiasem": "îngreuia",
    "îngreuiaseră": "îngreuia",
    "îngreuiaserăm": "îngreuia",
    "îngreuiaserăți": "îngreuia",
    "îngreuiaseși": "îngreuia",
    "îngreuiași": "îngreuia",
    "îngreuiat": "îngreuia",
    "îngreuiați": "îngreuia",
    "îngreuiatu": "îngreuia",
    "îngreuiau": "îngreuia",
    "îngreuiază": "îngreuia",
    "îngreuie": "îngreuia",
    "îngreuiem": "îngreuia",
    "îngreuiez": "îngreuia",
    "îngreuieze": "îngreuia",
    "îngreuiezi": "îngreuia",
    "îngreuind": "îngreuia",
    "îngreuindu": "îngreuia",
    "neîngreuiind": "îngreuia",
    "neîngreuiindu": "îngreuia",
    "nemaiîngreuiind": "îngreuia",
    "nemaiîngreuiindu": "îngreuia",
    "îngreuiată": "îngreuiat",
    "îngreuiate": "îngreuiat",
    "îngreuiați": "îngreuiat",
    "îngreună": "îngreuna",
    "îngreunai": "îngreuna",
    "îngreunam": "îngreuna",
    "îngreunăm": "îngreuna",
    "îngreunând": "îngreuna",
    "îngreunându": "îngreuna",
    "îngreunară": "îngreuna",
    "îngreunarăm": "îngreuna",
    "îngreunarăți": "îngreuna",
    "îngreunase": "îngreuna",
    "îngreunasem": "îngreuna",
    "îngreunaseră": "îngreuna",
    "îngreunaserăm": "îngreuna",
    "îngreunaserăți": "îngreuna",
    "îngreunaseși": "îngreuna",
    "îngreunași": "îngreuna",
    "îngreunat": "îngreuna",
    "îngreunați": "îngreuna",
    "îngreunatu": "îngreuna",
    "îngreunau": "îngreuna",
    "îngreunează": "îngreuna",
    "îngreunez": "îngreuna",
    "îngreuneze": "îngreuna",
    "îngreunezi": "îngreuna",
    "neîngreunând": "îngreuna",
    "neîngreunându": "îngreuna",
    "nemaiîngreunând": "îngreuna",
    "nemaiîngreunându": "îngreuna",
    "îngreunată": "îngreunat",
    "îngreunate": "îngreunat",
    "îngreunați": "îngreunat",
    "îngrijarea": "îngrijare",
    "îngrijea": "îngriji",
    "îngrijeai": "îngriji",
    "îngrijeam": "îngriji",
    "îngrijească": "îngriji",
    "îngrijeați": "îngriji",
    "îngrijeau": "îngriji",
    "îngrijesc": "îngriji",
    "îngrijește": "îngriji",
    "îngrijești": "îngriji",
    "îngrijii": "îngriji",
    "îngrijim": "îngriji",
    "îngrijind": "îngriji",
    "îngrijindu": "îngriji",
    "îngrijiră": "îngriji",
    "îngrijirăm": "îngriji",
    "îngrijirăți": "îngriji",
    "îngrijise": "îngriji",
    "îngrijisem": "îngriji",
    "îngrijiseră": "îngriji",
    "îngrijiserăm": "îngriji",
    "îngrijiserăți": "îngriji",
    "îngrijiseși": "îngriji",
    "îngrijiși": "îngriji",
    "îngrijit": "îngriji",
    "îngrijiți": "îngriji",
    "îngrijitu": "îngriji",
    "neîngrijind": "îngriji",
    "neîngrijindu": "îngriji",
    "nemaiîngrijind": "îngriji",
    "nemaiîngrijindu": "îngriji",
    "îngrijirea": "îngrijire",
    "îngrijiri": "îngrijire",
    "îngrijirii": "îngrijire",
    "îngrijirile": "îngrijire",
    "îngrijirilor": "îngrijire",
    "îngrijita": "îngrijit",
    "îngrijită": "îngrijit",
    "îngrijite": "îngrijit",
    "îngrijitei": "îngrijit",
    "îngrijitele": "îngrijit",
    "îngrijitelor": "îngrijit",
    "îngrijiți": "îngrijit",
    "îngrijiții": "îngrijit",
    "îngrijiților": "îngrijit",
    "îngrijitul": "îngrijit",
    "îngrijitului": "îngrijit",
    "îngrijitoarea": "îngrijitoare",
    "îngrijitoarei": "îngrijitoare",
    "îngrijitoarele": "îngrijitoare",
    "îngrijitoarelor": "îngrijitoare",
    "îngrijitori": "îngrijitor",
    "îngrijitorii": "îngrijitor",
    "îngrijitorilor": "îngrijitor",
    "îngrijitorul": "îngrijitor",
    "îngrijitorului": "îngrijitor",
    "îngrijoră": "îngrijora",
    "îngrijorai": "îngrijora",
    "îngrijoram": "îngrijora",
    "îngrijorăm": "îngrijora",
    "îngrijorând": "îngrijora",
    "îngrijorându": "îngrijora",
    "îngrijorară": "îngrijora",
    "îngrijorarăm": "îngrijora",
    "îngrijorarăți": "îngrijora",
    "îngrijorase": "îngrijora",
    "îngrijorasem": "îngrijora",
    "îngrijoraseră": "îngrijora",
    "îngrijoraserăm": "îngrijora",
    "îngrijoraserăți": "îngrijora",
    "îngrijoraseși": "îngrijora",
    "îngrijorași": "îngrijora",
    "îngrijorat": "îngrijora",
    "îngrijorați": "îngrijora",
    "îngrijoratu": "îngrijora",
    "îngrijorau": "îngrijora",
    "îngrijorează": "îngrijora",
    "îngrijorez": "îngrijora",
    "îngrijoreze": "îngrijora",
    "îngrijorezi": "îngrijora",
    "neîngrijorând": "îngrijora",
    "neîngrijorându": "îngrijora",
    "nemaiîngrijorând": "îngrijora",
    "nemaiîngrijorându": "îngrijora",
    "îngrijorarea": "îngrijorare",
    "îngrijorări": "îngrijorare",
    "îngrijorării": "îngrijorare",
    "îngrijorările": "îngrijorare",
    "îngrijorărilor": "îngrijorare",
    "îngrijorata": "îngrijorat",
    "îngrijorată": "îngrijorat",
    "îngrijorate": "îngrijorat",
    "îngrijoratei": "îngrijorat",
    "îngrijoratele": "îngrijorat",
    "îngrijoratelor": "îngrijorat",
    "îngrijorați": "îngrijorat",
    "îngrijorații": "îngrijorat",
    "îngrijoraților": "îngrijorat",
    "îngrijoratul": "îngrijorat",
    "îngrijoratului": "îngrijorat",
    "îngrijorătoare": "îngrijorător",
    "îngrijorătoarea": "îngrijorător",
    "îngrijorătoarei": "îngrijorător",
    "îngrijorătoarele": "îngrijorător",
    "îngrijorătoarelor": "îngrijorător",
    "îngrijorători": "îngrijorător",
    "îngrijorătorii": "îngrijorător",
    "îngrijorătorilor": "îngrijorător",
    "îngrijorătorul": "îngrijorător",
    "îngrijorătorului": "îngrijorător",
    "îngroapă": "îngropa",
    "îngroape": "îngropa",
    "îngrop": "îngropa",
    "îngropă": "îngropa",
    "îngropai": "îngropa",
    "îngropam": "îngropa",
    "îngropăm": "îngropa",
    "îngropând": "îngropa",
    "îngropându": "îngropa",
    "îngropară": "îngropa",
    "îngroparăm": "îngropa",
    "îngroparăți": "îngropa",
    "îngropase": "îngropa",
    "îngropasem": "îngropa",
    "îngropaseră": "îngropa",
    "îngropaserăm": "îngropa",
    "îngropaserăți": "îngropa",
    "îngropaseși": "îngropa",
    "îngropași": "îngropa",
    "îngropat": "îngropa",
    "îngropați": "îngropa",
    "îngropatu": "îngropa",
    "îngropau": "îngropa",
    "îngropi": "îngropa",
    "neîngropând": "îngropa",
    "neîngropându": "îngropa",
    "nemaiîngropând": "îngropa",
    "nemaiîngropându": "îngropa",
    "îngropăciunea": "îngropăciune",
    "îngropăciuneo": "îngropăciune",
    "îngropăciuni": "îngropăciune",
    "îngropăciunii": "îngropăciune",
    "îngropăciunile": "îngropăciune",
    "îngropăciunilor": "îngropăciune",
    "îngroparea": "îngropare",
    "îngropări": "îngropare",
    "îngropării": "îngropare",
    "îngropările": "îngropare",
    "îngropărilor": "îngropare",
    "îngropată": "îngropat",
    "îngropate": "îngropat",
    "îngropați": "îngropat",
    "îngropatul": "îngropat",
    "îngropatului": "îngropat",
    "îngroașă": "îngroșa",
    "îngroașe": "îngroșa",
    "îngroș": "îngroșa",
    "îngroșă": "îngroșa",
    "îngroșai": "îngroșa",
    "îngroșam": "îngroșa",
    "îngroșăm": "îngroșa",
    "îngroșând": "îngroșa",
    "îngroșându": "îngroșa",
    "îngroșară": "îngroșa",
    "îngroșarăm": "îngroșa",
    "îngroșarăți": "îngroșa",
    "îngroșase": "îngroșa",
    "îngroșasem": "îngroșa",
    "îngroșaseră": "îngroșa",
    "îngroșaserăm": "îngroșa",
    "îngroșaserăți": "îngroșa",
    "îngroșaseși": "îngroșa",
    "îngroșași": "îngroșa",
    "îngroșat": "îngroșa",
    "îngroșați": "îngroșa",
    "îngroșatu": "îngroșa",
    "îngroșau": "îngroșa",
    "îngroși": "îngroșa",
    "neîngroșând": "îngroșa",
    "neîngroșându": "îngroșa",
    "nemaiîngroșând": "îngroșa",
    "nemaiîngroșându": "îngroșa",
    "îngroșată": "îngroșat",
    "îngroșate": "îngroșat",
    "îngroșați": "îngroșat",
    "îngrozea": "îngrozi",
    "îngrozeai": "îngrozi",
    "îngrozeam": "îngrozi",
    "îngrozească": "îngrozi",
    "îngrozeați": "îngrozi",
    "îngrozeau": "îngrozi",
    "îngrozesc": "îngrozi",
    "îngrozește": "îngrozi",
    "îngrozești": "îngrozi",
    "îngrozii": "îngrozi",
    "îngrozim": "îngrozi",
    "îngrozind": "îngrozi",
    "îngrozindu": "îngrozi",
    "îngroziră": "îngrozi",
    "îngrozirăm": "îngrozi",
    "îngrozirăți": "îngrozi",
    "îngrozise": "îngrozi",
    "îngrozisem": "îngrozi",
    "îngroziseră": "îngrozi",
    "îngroziserăm": "îngrozi",
    "îngroziserăți": "îngrozi",
    "îngroziseși": "îngrozi",
    "îngroziși": "îngrozi",
    "îngrozit": "îngrozi",
    "îngroziți": "îngrozi",
    "îngrozitu": "îngrozi",
    "neîngrozind": "îngrozi",
    "neîngrozindu": "îngrozi",
    "nemaiîngrozind": "îngrozi",
    "nemaiîngrozindu": "îngrozi",
    "îngrozita": "îngrozit",
    "îngrozită": "îngrozit",
    "îngrozite": "îngrozit",
    "îngrozitei": "îngrozit",
    "îngrozitele": "îngrozit",
    "îngrozitelor": "îngrozit",
    "îngroziți": "îngrozit",
    "îngroziții": "îngrozit",
    "îngroziților": "îngrozit",
    "îngrozitul": "îngrozit",
    "îngrozitului": "îngrozit",
    "îngrozitoare": "îngrozitor",
    "îngrozitoarea": "îngrozitor",
    "îngrozitoarei": "îngrozitor",
    "îngrozitoarele": "îngrozitor",
    "îngrozitoarelor": "îngrozitor",
    "îngrozitori": "îngrozitor",
    "îngrozitorii": "îngrozitor",
    "îngrozitorilor": "îngrozitor",
    "îngrozitorul": "îngrozitor",
    "îngrozitorului": "îngrozitor",
    "ingurgită": "ingurgita",
    "ingurgitai": "ingurgita",
    "ingurgitam": "ingurgita",
    "ingurgităm": "ingurgita",
    "ingurgitând": "ingurgita",
    "ingurgitându": "ingurgita",
    "ingurgitară": "ingurgita",
    "ingurgitarăm": "ingurgita",
    "ingurgitarăți": "ingurgita",
    "ingurgitase": "ingurgita",
    "ingurgitasem": "ingurgita",
    "ingurgitaseră": "ingurgita",
    "ingurgitaserăm": "ingurgita",
    "ingurgitaserăți": "ingurgita",
    "ingurgitaseși": "ingurgita",
    "ingurgitași": "ingurgita",
    "ingurgitat": "ingurgita",
    "ingurgitați": "ingurgita",
    "ingurgitatu": "ingurgita",
    "ingurgitau": "ingurgita",
    "ingurgitează": "ingurgita",
    "ingurgitez": "ingurgita",
    "ingurgiteze": "ingurgita",
    "ingurgitezi": "ingurgita",
    "neingurgitând": "ingurgita",
    "neingurgitându": "ingurgita",
    "nemaiingurgitând": "ingurgita",
    "nemaiingurgitându": "ingurgita",
    "ingurgitată": "ingurgitat",
    "ingurgitate": "ingurgitat",
    "ingurgitați": "ingurgitat",
    "îngusta": "îngust",
    "îngustă": "îngust",
    "înguste": "îngust",
    "îngustei": "îngust",
    "îngustele": "îngust",
    "îngustelor": "îngust",
    "înguști": "îngust",
    "înguștii": "îngust",
    "înguștilor": "îngust",
    "îngustul": "îngust",
    "îngustului": "îngust",
    "îngustă": "îngusta",
    "îngustai": "îngusta",
    "îngustam": "îngusta",
    "îngustăm": "îngusta",
    "îngustând": "îngusta",
    "îngustându": "îngusta",
    "îngustară": "îngusta",
    "îngustarăm": "îngusta",
    "îngustarăți": "îngusta",
    "îngustase": "îngusta",
    "îngustasem": "îngusta",
    "îngustaseră": "îngusta",
    "îngustaserăm": "îngusta",
    "îngustaserăți": "îngusta",
    "îngustaseși": "îngusta",
    "îngustași": "îngusta",
    "îngustat": "îngusta",
    "îngustați": "îngusta",
    "îngustatu": "îngusta",
    "îngustau": "îngusta",
    "îngustează": "îngusta",
    "îngustez": "îngusta",
    "îngusteze": "îngusta",
    "îngustezi": "îngusta",
    "neîngustând": "îngusta",
    "neîngustându": "îngusta",
    "nemaiîngustând": "îngusta",
    "nemaiîngustându": "îngusta",
    "îngustată": "îngustat",
    "îngustate": "îngustat",
    "îngustați": "îngustat",
    "îngustimea": "îngustime",
    "îngustimi": "îngustime",
    "îngustimii": "îngustime",
    "îngustimile": "îngustime",
    "îngustimilor": "îngustime",
    "înhăită": "înhăita",
    "înhăitai": "înhăita",
    "înhăitam": "înhăita",
    "înhăităm": "înhăita",
    "înhăitând": "înhăita",
    "înhăitându": "înhăita",
    "înhăitară": "înhăita",
    "înhăitarăm": "înhăita",
    "înhăitarăți": "înhăita",
    "înhăitase": "înhăita",
    "înhăitasem": "înhăita",
    "înhăitaseră": "înhăita",
    "înhăitaserăm": "înhăita",
    "înhăitaserăți": "înhăita",
    "înhăitaseși": "înhăita",
    "înhăitași": "înhăita",
    "înhăitat": "înhăita",
    "înhăitați": "înhăita",
    "înhăitatu": "înhăita",
    "înhăitau": "înhăita",
    "înhăitează": "înhăita",
    "înhăitez": "înhăita",
    "înhăiteze": "înhăita",
    "înhăitezi": "înhăita",
    "neînhăitând": "înhăita",
    "neînhăitându": "înhăita",
    "nemaiînhăitând": "înhăita",
    "nemaiînhăitându": "înhăita",
    "înhăitată": "înhăitat",
    "înhăitate": "înhăitat",
    "înhăitați": "înhăitat",
    "inhală": "inhala",
    "inhalai": "inhala",
    "inhalam": "inhala",
    "inhalăm": "inhala",
    "inhalând": "inhala",
    "inhalându": "inhala",
    "inhalară": "inhala",
    "inhalarăm": "inhala",
    "inhalarăți": "inhala",
    "inhalase": "inhala",
    "inhalasem": "inhala",
    "inhalaseră": "inhala",
    "inhalaserăm": "inhala",
    "inhalaserăți": "inhala",
    "inhalaseși": "inhala",
    "inhalași": "inhala",
    "inhalat": "inhala",
    "inhalați": "inhala",
    "inhalatu": "inhala",
    "inhalau": "inhala",
    "inhalează": "inhala",
    "inhalez": "inhala",
    "inhaleze": "inhala",
    "inhalezi": "inhala",
    "neinhalând": "inhala",
    "neinhalându": "inhala",
    "nemaiinhalând": "inhala",
    "nemaiinhalându": "inhala",
    "inhalată": "inhalat",
    "inhalate": "inhalat",
    "inhalați": "inhalat",
    "înham": "înhăma",
    "înhamă": "înhăma",
    "înhămă": "înhăma",
    "înhămai": "înhăma",
    "înhămam": "înhăma",
    "înhămăm": "înhăma",
    "înhămând": "înhăma",
    "înhămându": "înhăma",
    "înhămară": "înhăma",
    "înhămarăm": "înhăma",
    "înhămarăți": "înhăma",
    "înhămase": "înhăma",
    "înhămasem": "înhăma",
    "înhămaseră": "înhăma",
    "înhămaserăm": "înhăma",
    "înhămaserăți": "înhăma",
    "înhămaseși": "înhăma",
    "înhămași": "înhăma",
    "înhămat": "înhăma",
    "înhămați": "înhăma",
    "înhămatu": "înhăma",
    "înhămau": "înhăma",
    "înhame": "înhăma",
    "înhami": "înhăma",
    "neînhămând": "înhăma",
    "neînhămându": "înhăma",
    "nemaiînhămând": "înhăma",
    "nemaiînhămându": "înhăma",
    "înhămată": "înhămat",
    "înhămate": "înhămat",
    "înhămați": "înhămat",
    "înhaț": "înhăța",
    "înhață": "înhăța",
    "înhăță": "înhăța",
    "înhățai": "înhăța",
    "înhățam": "înhăța",
    "înhățăm": "înhăța",
    "înhățând": "înhăța",
    "înhățându": "înhăța",
    "înhățară": "înhăța",
    "înhățarăm": "înhăța",
    "înhățarăți": "înhăța",
    "înhățase": "înhăța",
    "înhățasem": "înhăța",
    "înhățaseră": "înhăța",
    "înhățaserăm": "înhăța",
    "înhățaserăți": "înhăța",
    "înhățaseși": "înhăța",
    "înhățași": "înhăța",
    "înhățat": "înhăța",
    "înhățați": "înhăța",
    "înhățatu": "înhăța",
    "înhățau": "înhăța",
    "înhațe": "înhăța",
    "înhați": "înhăța",
    "neînhățând": "înhăța",
    "neînhățându": "înhăța",
    "nemaiînhățând": "înhăța",
    "nemaiînhățându": "înhăța",
    "înhățată": "înhățat",
    "înhățate": "înhățat",
    "înhățați": "înhățat",
    "inhib": "inhiba",
    "inhibă": "inhiba",
    "inhibai": "inhiba",
    "inhibam": "inhiba",
    "inhibăm": "inhiba",
    "inhibând": "inhiba",
    "inhibându": "inhiba",
    "inhibară": "inhiba",
    "inhibarăm": "inhiba",
    "inhibarăți": "inhiba",
    "inhibase": "inhiba",
    "inhibasem": "inhiba",
    "inhibaseră": "inhiba",
    "inhibaserăm": "inhiba",
    "inhibaserăți": "inhiba",
    "inhibaseși": "inhiba",
    "inhibași": "inhiba",
    "inhibat": "inhiba",
    "inhibați": "inhiba",
    "inhibatu": "inhiba",
    "inhibau": "inhiba",
    "inhibe": "inhiba",
    "inhibi": "inhiba",
    "neinhibând": "inhiba",
    "neinhibându": "inhiba",
    "nemaiinhibând": "inhiba",
    "nemaiinhibându": "inhiba",
    "inhibată": "inhibat",
    "inhibate": "inhibat",
    "inhibați": "inhibat",
    "inhibiția": "inhibiție",
    "inhibiției": "inhibiție",
    "inhibiții": "inhibiție",
    "inhibițiile": "inhibiție",
    "inhibițiilor": "inhibiție",
    "înhumă": "înhuma",
    "înhumai": "înhuma",
    "înhumam": "înhuma",
    "înhumăm": "înhuma",
    "înhumând": "înhuma",
    "înhumându": "înhuma",
    "înhumară": "înhuma",
    "înhumarăm": "înhuma",
    "înhumarăți": "înhuma",
    "înhumase": "înhuma",
    "înhumasem": "înhuma",
    "înhumaseră": "înhuma",
    "înhumaserăm": "înhuma",
    "înhumaserăți": "înhuma",
    "înhumaseși": "înhuma",
    "înhumași": "înhuma",
    "înhumat": "înhuma",
    "înhumați": "înhuma",
    "înhumatu": "înhuma",
    "înhumau": "înhuma",
    "înhumează": "înhuma",
    "înhumez": "înhuma",
    "înhumeze": "înhuma",
    "înhumezi": "înhuma",
    "neînhumând": "înhuma",
    "neînhumându": "înhuma",
    "nemaiînhumând": "înhuma",
    "nemaiînhumându": "înhuma",
    "înhumată": "înhumat",
    "înhumate": "înhumat",
    "înhumați": "înhumat",
    "înierbă": "înierba",
    "înierbai": "înierba",
    "înierbam": "înierba",
    "înierbăm": "înierba",
    "înierbând": "înierba",
    "înierbându": "înierba",
    "înierbară": "înierba",
    "înierbarăm": "înierba",
    "înierbarăți": "înierba",
    "înierbase": "înierba",
    "înierbasem": "înierba",
    "înierbaseră": "înierba",
    "înierbaserăm": "înierba",
    "înierbaserăți": "înierba",
    "înierbaseși": "înierba",
    "înierbași": "înierba",
    "înierbat": "înierba",
    "înierbați": "înierba",
    "înierbatu": "înierba",
    "înierbau": "înierba",
    "înierbează": "înierba",
    "înierbez": "înierba",
    "înierbeze": "înierba",
    "înierbezi": "înierba",
    "neînierbând": "înierba",
    "neînierbându": "înierba",
    "nemaiînierbând": "înierba",
    "nemaiînierbându": "înierba",
    "înierbată": "înierbat",
    "înierbate": "înierbat",
    "înierbați": "înierbat",
    "inima": "inimă",
    "inimi": "inimă",
    "inimii": "inimă",
    "inimile": "inimă",
    "inimilor": "inimă",
    "inimaginabila": "inimaginabil",
    "inimaginabilă": "inimaginabil",
    "inimaginabile": "inimaginabil",
    "inimaginabilei": "inimaginabil",
    "inimaginabilele": "inimaginabil",
    "inimaginabilelor": "inimaginabil",
    "inimaginabili": "inimaginabil",
    "inimaginabilii": "inimaginabil",
    "inimaginabililor": "inimaginabil",
    "inimaginabilul": "inimaginabil",
    "inimaginabilului": "inimaginabil",
    "inimiciția": "inimiciție",
    "inimiciției": "inimiciție",
    "inimiciții": "inimiciție",
    "inimicițiile": "inimiciție",
    "inimicițiilor": "inimiciție",
    "inimicițio": "inimiciție",
    "inimioara": "inimioară",
    "inimioare": "inimioară",
    "inimioarei": "inimioară",
    "inimioarele": "inimioară",
    "inimioarelor": "inimioară",
    "inimioaro": "inimioară",
    "inimitabila": "inimitabil",
    "inimitabilă": "inimitabil",
    "inimitabile": "inimitabil",
    "inimitabilei": "inimitabil",
    "inimitabilele": "inimitabil",
    "inimitabilelor": "inimitabil",
    "inimitabili": "inimitabil",
    "inimitabilii": "inimitabil",
    "inimitabililor": "inimitabil",
    "inimitabilo": "inimitabil",
    "inimitabilul": "inimitabil",
    "inimitabilule": "inimitabil",
    "inimitabilului": "inimitabil",
    "inimoasa": "inimos",
    "inimoasă": "inimos",
    "inimoase": "inimos",
    "inimoasei": "inimos",
    "inimoasele": "inimos",
    "inimoaselor": "inimos",
    "inimoși": "inimos",
    "inimoșii": "inimos",
    "inimoșilor": "inimos",
    "inimosul": "inimos",
    "inimosului": "inimos",
    "inițiai": "iniția",
    "inițiam": "iniția",
    "inițiară": "iniția",
    "inițiarăm": "iniția",
    "inițiarăți": "iniția",
    "inițiase": "iniția",
    "inițiasem": "iniția",
    "inițiaseră": "iniția",
    "inițiaserăm": "iniția",
    "inițiaserăți": "iniția",
    "inițiaseși": "iniția",
    "inițiași": "iniția",
    "inițiat": "iniția",
    "inițiați": "iniția",
    "inițiatu": "iniția",
    "inițiau": "iniția",
    "inițiază": "iniția",
    "iniție": "iniția",
    "inițiem": "iniția",
    "inițiez": "iniția",
    "inițieze": "iniția",
    "inițiezi": "iniția",
    "inițiind": "iniția",
    "inițiindu": "iniția",
    "neinițiind": "iniția",
    "neinițiindu": "iniția",
    "nemaiinițiind": "iniția",
    "nemaiinițiindu": "iniția",
    "inițiala": "inițial",
    "inițială": "inițial",
    "inițiale": "inițial",
    "inițialei": "inițial",
    "inițialele": "inițial",
    "inițialelor": "inițial",
    "inițiali": "inițial",
    "inițialii": "inițial",
    "inițialilor": "inițial",
    "inițialul": "inițial",
    "inițialului": "inițial",
    "inițiala": "inițială",
    "inițiale": "inițială",
    "inițialei": "inițială",
    "inițialele": "inițială",
    "inițialelor": "inițială",
    "inițiată": "inițiat",
    "inițiate": "inițiat",
    "inițiați": "inițiat",
    "inițiativa": "inițiativă",
    "inițiative": "inițiativă",
    "inițiativei": "inițiativă",
    "inițiativele": "inițiativă",
    "inițiativelor": "inițiativă",
    "inițiatori": "inițiator",
    "inițiatorii": "inițiator",
    "inițiatorilor": "inițiator",
    "inițiatorul": "inițiator",
    "inițiatorului": "inițiator",
    "inițierea": "inițiere",
    "inițiereo": "inițiere",
    "inițieri": "inițiere",
    "inițierii": "inițiere",
    "inițierile": "inițiere",
    "inițierilor": "inițiere",
    "injectă": "injecta",
    "injectai": "injecta",
    "injectam": "injecta",
    "injectăm": "injecta",
    "injectând": "injecta",
    "injectându": "injecta",
    "injectară": "injecta",
    "injectarăm": "injecta",
    "injectarăți": "injecta",
    "injectase": "injecta",
    "injectasem": "injecta",
    "injectaseră": "injecta",
    "injectaserăm": "injecta",
    "injectaserăți": "injecta",
    "injectaseși": "injecta",
    "injectași": "injecta",
    "injectat": "injecta",
    "injectați": "injecta",
    "injectatu": "injecta",
    "injectau": "injecta",
    "injectează": "injecta",
    "injectez": "injecta",
    "injecteze": "injecta",
    "injectezi": "injecta",
    "neinjectând": "injecta",
    "neinjectându": "injecta",
    "nemaiinjectând": "injecta",
    "nemaiinjectându": "injecta",
    "injectarea": "injectare",
    "injectareo": "injectare",
    "injectări": "injectare",
    "injectării": "injectare",
    "injectările": "injectare",
    "injectărilor": "injectare",
    "injectata": "injectat",
    "injectată": "injectat",
    "injectate": "injectat",
    "injectatei": "injectat",
    "injectatele": "injectat",
    "injectatelor": "injectat",
    "injectați": "injectat",
    "injectații": "injectat",
    "injectaților": "injectat",
    "injectatul": "injectat",
    "injectatului": "injectat",
    "injecția": "injecție",
    "injecției": "injecție",
    "injecții": "injecție",
    "injecțiile": "injecție",
    "injecțiilor": "injecție",
    "înjghebă": "înjgheba",
    "înjghebai": "înjgheba",
    "înjghebam": "înjgheba",
    "înjghebăm": "înjgheba",
    "înjghebând": "înjgheba",
    "înjghebându": "înjgheba",
    "înjghebară": "înjgheba",
    "înjghebarăm": "înjgheba",
    "înjghebarăți": "înjgheba",
    "înjghebase": "înjgheba",
    "înjghebasem": "înjgheba",
    "înjghebaseră": "înjgheba",
    "înjghebaserăm": "înjgheba",
    "înjghebaserăți": "înjgheba",
    "înjghebaseși": "înjgheba",
    "înjghebași": "înjgheba",
    "înjghebat": "înjgheba",
    "înjghebați": "înjgheba",
    "înjghebatu": "înjgheba",
    "înjghebau": "înjgheba",
    "înjghebează": "înjgheba",
    "înjghebez": "înjgheba",
    "înjghebeze": "înjgheba",
    "înjghebezi": "înjgheba",
    "neînjghebând": "înjgheba",
    "neînjghebându": "înjgheba",
    "nemaiînjghebând": "înjgheba",
    "nemaiînjghebându": "înjgheba",
    "înjghebarea": "înjghebare",
    "înjghebări": "înjghebare",
    "înjghebării": "înjghebare",
    "înjghebările": "înjghebare",
    "înjghebărilor": "înjghebare",
    "înjghebată": "înjghebat",
    "înjghebate": "înjghebat",
    "înjghebați": "înjghebat",
    "înjosea": "înjosi",
    "înjoseai": "înjosi",
    "înjoseam": "înjosi",
    "înjosească": "înjosi",
    "înjoseați": "înjosi",
    "înjoseau": "înjosi",
    "înjosesc": "înjosi",
    "înjosește": "înjosi",
    "înjosești": "înjosi",
    "înjosii": "înjosi",
    "înjosim": "înjosi",
    "înjosind": "înjosi",
    "înjosindu": "înjosi",
    "înjosiră": "înjosi",
    "înjosirăm": "înjosi",
    "înjosirăți": "înjosi",
    "înjosise": "înjosi",
    "înjosisem": "înjosi",
    "înjosiseră": "înjosi",
    "înjosiserăm": "înjosi",
    "înjosiserăți": "înjosi",
    "înjosiseși": "înjosi",
    "înjosiși": "înjosi",
    "înjosit": "înjosi",
    "înjosiți": "înjosi",
    "înjositu": "înjosi",
    "neînjosind": "înjosi",
    "neînjosindu": "înjosi",
    "nemaiînjosind": "înjosi",
    "nemaiînjosindu": "înjosi",
    "înjosirea": "înjosire",
    "înjosiri": "înjosire",
    "înjosirii": "înjosire",
    "înjosirile": "înjosire",
    "înjosirilor": "înjosire",
    "înjosită": "înjosit",
    "înjosite": "înjosit",
    "înjosiți": "înjosit",
    "înjositoare": "înjositor",
    "înjositoarea": "înjositor",
    "înjositoarei": "înjositor",
    "înjositoarele": "înjositor",
    "înjositoarelor": "înjositor",
    "înjositori": "înjositor",
    "înjositorii": "înjositor",
    "înjositorilor": "înjositor",
    "înjositorul": "înjositor",
    "înjositorului": "înjositor",
    "înjug": "înjuga",
    "înjugă": "înjuga",
    "înjugai": "înjuga",
    "înjugam": "înjuga",
    "înjugăm": "înjuga",
    "înjugând": "înjuga",
    "înjugându": "înjuga",
    "înjugară": "înjuga",
    "înjugarăm": "înjuga",
    "înjugarăți": "înjuga",
    "înjugase": "înjuga",
    "înjugasem": "înjuga",
    "înjugaseră": "înjuga",
    "înjugaserăm": "înjuga",
    "înjugaserăți": "înjuga",
    "înjugaseși": "înjuga",
    "înjugași": "înjuga",
    "înjugat": "înjuga",
    "înjugați": "înjuga",
    "înjugatu": "înjuga",
    "înjugau": "înjuga",
    "înjuge": "înjuga",
    "înjugi": "înjuga",
    "neînjugând": "înjuga",
    "neînjugându": "înjuga",
    "nemaiînjugând": "înjuga",
    "nemaiînjugându": "înjuga",
    "înjugată": "înjugat",
    "înjugate": "înjugat",
    "înjugați": "înjugat",
    "înjumătățea": "înjumătăți",
    "înjumătățeai": "înjumătăți",
    "înjumătățeam": "înjumătăți",
    "înjumătățească": "înjumătăți",
    "înjumătățeați": "înjumătăți",
    "înjumătățeau": "înjumătăți",
    "înjumătățesc": "înjumătăți",
    "înjumătățește": "înjumătăți",
    "înjumătățești": "înjumătăți",
    "înjumătății": "înjumătăți",
    "înjumătățim": "înjumătăți",
    "înjumătățind": "înjumătăți",
    "înjumătățindu": "înjumătăți",
    "înjumătățiră": "înjumătăți",
    "înjumătățirăm": "înjumătăți",
    "înjumătățirăți": "înjumătăți",
    "înjumătățise": "înjumătăți",
    "înjumătățisem": "înjumătăți",
    "înjumătățiseră": "înjumătăți",
    "înjumătățiserăm": "înjumătăți",
    "înjumătățiserăți": "înjumătăți",
    "înjumătățiseși": "înjumătăți",
    "înjumătățiși": "înjumătăți",
    "înjumătățit": "înjumătăți",
    "înjumătățiți": "înjumătăți",
    "înjumătățitu": "înjumătăți",
    "neînjumătățind": "înjumătăți",
    "neînjumătățindu": "înjumătăți",
    "nemaiînjumătățind": "înjumătăți",
    "nemaiînjumătățindu": "înjumătăți",
    "înjumătățirea": "înjumătățire",
    "înjumătățiri": "înjumătățire",
    "înjumătățirii": "înjumătățire",
    "înjumătățirile": "înjumătățire",
    "înjumătățirilor": "înjumătățire",
    "înjumătățită": "înjumătățit",
    "înjumătățite": "înjumătățit",
    "înjumătățiți": "înjumătățit",
    "înjunghiai": "înjunghia",
    "înjunghiam": "înjunghia",
    "înjunghiară": "înjunghia",
    "înjunghiarăm": "înjunghia",
    "înjunghiarăți": "înjunghia",
    "înjunghiase": "înjunghia",
    "înjunghiasem": "înjunghia",
    "înjunghiaseră": "înjunghia",
    "înjunghiaserăm": "înjunghia",
    "înjunghiaserăți": "înjunghia",
    "înjunghiaseși": "înjunghia",
    "înjunghiași": "înjunghia",
    "înjunghiat": "înjunghia",
    "înjunghiați": "înjunghia",
    "înjunghiatu": "înjunghia",
    "înjunghiau": "înjunghia",
    "înjunghie": "înjunghia",
    "înjunghiem": "înjunghia",
    "înjunghii": "înjunghia",
    "înjunghiind": "înjunghia",
    "înjunghiindu": "înjunghia",
    "neînjunghiind": "înjunghia",
    "neînjunghiindu": "înjunghia",
    "nemaiînjunghiind": "înjunghia",
    "nemaiînjunghiindu": "înjunghia",
    "înjunghiată": "înjunghiat",
    "înjunghiate": "înjunghiat",
    "înjunghiați": "înjunghiat",
    "înjur": "înjura",
    "înjură": "înjura",
    "înjurai": "înjura",
    "înjuram": "înjura",
    "înjurăm": "înjura",
    "înjurând": "înjura",
    "înjurându": "înjura",
    "înjurară": "înjura",
    "înjurarăm": "înjura",
    "înjurarăți": "înjura",
    "înjurase": "înjura",
    "înjurasem": "înjura",
    "înjuraseră": "înjura",
    "înjuraserăm": "înjura",
    "înjuraserăți": "înjura",
    "înjuraseși": "înjura",
    "înjurași": "înjura",
    "înjurat": "înjura",
    "înjurați": "înjura",
    "înjuratu": "înjura",
    "înjurau": "înjura",
    "înjure": "înjura",
    "înjuri": "înjura",
    "neînjurând": "înjura",
    "neînjurându": "înjura",
    "nemaiînjurând": "înjura",
    "nemaiînjurându": "înjura",
    "înjurată": "înjurat",
    "înjurate": "înjurat",
    "înjurați": "înjurat",
    "înjurătura": "înjurătură",
    "înjurături": "înjurătură",
    "înjurăturii": "înjurătură",
    "înjurăturile": "înjurătură",
    "înjurăturilor": "înjurătură",
    "injuria": "injurie",
    "injuriei": "injurie",
    "injurii": "injurie",
    "injuriile": "injurie",
    "injuriilor": "injurie",
    "injusta": "injust",
    "injustă": "injust",
    "injuste": "injust",
    "injustei": "injust",
    "injustele": "injust",
    "injustelor": "injust",
    "injuști": "injust",
    "injuștii": "injust",
    "injuștilor": "injust",
    "injustul": "injust",
    "injustului": "injust",
    "înlăcrimă": "înlăcrima",
    "înlăcrimai": "înlăcrima",
    "înlăcrimam": "înlăcrima",
    "înlăcrimăm": "înlăcrima",
    "înlăcrimând": "înlăcrima",
    "înlăcrimându": "înlăcrima",
    "înlăcrimară": "înlăcrima",
    "înlăcrimarăm": "înlăcrima",
    "înlăcrimarăți": "înlăcrima",
    "înlăcrimase": "înlăcrima",
    "înlăcrimasem": "înlăcrima",
    "înlăcrimaseră": "înlăcrima",
    "înlăcrimaserăm": "înlăcrima",
    "înlăcrimaserăți": "înlăcrima",
    "înlăcrimaseși": "înlăcrima",
    "înlăcrimași": "înlăcrima",
    "înlăcrimat": "înlăcrima",
    "înlăcrimați": "înlăcrima",
    "înlăcrimatu": "înlăcrima",
    "înlăcrimau": "înlăcrima",
    "înlăcrimează": "înlăcrima",
    "înlăcrimez": "înlăcrima",
    "înlăcrimeze": "înlăcrima",
    "înlăcrimezi": "înlăcrima",
    "neînlăcrimând": "înlăcrima",
    "neînlăcrimându": "înlăcrima",
    "nemaiînlăcrimând": "înlăcrima",
    "nemaiînlăcrimându": "înlăcrima",
    "înlăcrimată": "înlăcrimat",
    "înlăcrimate": "înlăcrimat",
    "înlăcrimați": "înlăcrimat",
    "înlănțuia": "înlănțui",
    "înlănțuiai": "înlănțui",
    "înlănțuiam": "înlănțui",
    "înlănțuiați": "înlănțui",
    "înlănțuiau": "înlănțui",
    "înlănțuie": "înlănțui",
    "înlănțuii": "înlănțui",
    "înlănțuim": "înlănțui",
    "înlănțuind": "înlănțui",
    "înlănțuindu": "înlănțui",
    "înlănțuiră": "înlănțui",
    "înlănțuirăm": "înlănțui",
    "înlănțuirăți": "înlănțui",
    "înlănțuise": "înlănțui",
    "înlănțuisem": "înlănțui",
    "înlănțuiseră": "înlănțui",
    "înlănțuiserăm": "înlănțui",
    "înlănțuiserăți": "înlănțui",
    "înlănțuiseși": "înlănțui",
    "înlănțuiși": "înlănțui",
    "înlănțuit": "înlănțui",
    "înlănțuiți": "înlănțui",
    "înlănțuitu": "înlănțui",
    "neînlănțuind": "înlănțui",
    "neînlănțuindu": "înlănțui",
    "nemaiînlănțuind": "înlănțui",
    "nemaiînlănțuindu": "înlănțui",
    "înlănțuirea": "înlănțuire",
    "înlănțuireo": "înlănțuire",
    "înlănțuiri": "înlănțuire",
    "înlănțuirii": "înlănțuire",
    "înlănțuirile": "înlănțuire",
    "înlănțuirilor": "înlănțuire",
    "înlănțuită": "înlănțuit",
    "înlănțuite": "înlănțuit",
    "înlănțuiți": "înlănțuit",
    "înlătur": "înlătura",
    "înlătură": "înlătura",
    "înlăturai": "înlătura",
    "înlăturam": "înlătura",
    "înlăturăm": "înlătura",
    "înlăturând": "înlătura",
    "înlăturându": "înlătura",
    "înlăturară": "înlătura",
    "înlăturarăm": "înlătura",
    "înlăturarăți": "înlătura",
    "înlăturase": "înlătura",
    "înlăturasem": "înlătura",
    "înlăturaseră": "înlătura",
    "înlăturaserăm": "înlătura",
    "înlăturaserăți": "înlătura",
    "înlăturaseși": "înlătura",
    "înlăturași": "înlătura",
    "înlăturat": "înlătura",
    "înlăturați": "înlătura",
    "înlăturatu": "înlătura",
    "înlăturau": "înlătura",
    "înlăture": "înlătura",
    "înlături": "înlătura",
    "neînlăturând": "înlătura",
    "neînlăturându": "înlătura",
    "nemaiînlăturând": "înlătura",
    "nemaiînlăturându": "înlătura",
    "înlăturarea": "înlăturare",
    "înlăturareo": "înlăturare",
    "înlăturări": "înlăturare",
    "înlăturării": "înlăturare",
    "înlăturările": "înlăturare",
    "înlăturărilor": "înlăturare",
    "înlăturată": "înlăturat",
    "înlăturate": "înlăturat",
    "înlăturați": "înlăturat",
    "înlemnea": "înlemni",
    "înlemneai": "înlemni",
    "înlemneam": "înlemni",
    "înlemnească": "înlemni",
    "înlemneați": "înlemni",
    "înlemneau": "înlemni",
    "înlemnesc": "înlemni",
    "înlemnește": "înlemni",
    "înlemnești": "înlemni",
    "înlemnii": "înlemni",
    "înlemnim": "înlemni",
    "înlemnind": "înlemni",
    "înlemnindu": "înlemni",
    "înlemniră": "înlemni",
    "înlemnirăm": "înlemni",
    "înlemnirăți": "înlemni",
    "înlemnise": "înlemni",
    "înlemnisem": "înlemni",
    "înlemniseră": "înlemni",
    "înlemniserăm": "înlemni",
    "înlemniserăți": "înlemni",
    "înlemniseși": "înlemni",
    "înlemniși": "înlemni",
    "înlemnit": "înlemni",
    "înlemniți": "înlemni",
    "înlemnitu": "înlemni",
    "neînlemnind": "înlemni",
    "neînlemnindu": "înlemni",
    "nemaiînlemnind": "înlemni",
    "nemaiînlemnindu": "înlemni",
    "înlemnirea": "înlemnire",
    "înlemnireo": "înlemnire",
    "înlemniri": "înlemnire",
    "înlemnirii": "înlemnire",
    "înlemnirile": "înlemnire",
    "înlemnirilor": "înlemnire",
    "înlemnită": "înlemnit",
    "înlemnite": "înlemnit",
    "înlemniți": "înlemnit",
    "înlesnea": "înlesni",
    "înlesneai": "înlesni",
    "înlesneam": "înlesni",
    "înlesnească": "înlesni",
    "înlesneați": "înlesni",
    "înlesneau": "înlesni",
    "înlesnesc": "înlesni",
    "înlesnește": "înlesni",
    "înlesnești": "înlesni",
    "înlesnii": "înlesni",
    "înlesnim": "înlesni",
    "înlesnind": "înlesni",
    "înlesnindu": "înlesni",
    "înlesniră": "înlesni",
    "înlesnirăm": "înlesni",
    "înlesnirăți": "înlesni",
    "înlesnise": "înlesni",
    "înlesnisem": "înlesni",
    "înlesniseră": "înlesni",
    "înlesniserăm": "înlesni",
    "înlesniserăți": "înlesni",
    "înlesniseși": "înlesni",
    "înlesniși": "înlesni",
    "înlesnit": "înlesni",
    "înlesniți": "înlesni",
    "înlesnitu": "înlesni",
    "neînlesnind": "înlesni",
    "neînlesnindu": "înlesni",
    "nemaiînlesnind": "înlesni",
    "nemaiînlesnindu": "înlesni",
    "înlesnirea": "înlesnire",
    "înlesniri": "înlesnire",
    "înlesnirii": "înlesnire",
    "înlesnirile": "înlesnire",
    "înlesnirilor": "înlesnire",
    "înlesnită": "înlesnit",
    "înlesnite": "înlesnit",
    "înlesniți": "înlesnit",
    "înlocuia": "înlocui",
    "înlocuiai": "înlocui",
    "înlocuiam": "înlocui",
    "înlocuiască": "înlocui",
    "înlocuiați": "înlocui",
    "înlocuiau": "înlocui",
    "înlocuiesc": "înlocui",
    "înlocuiește": "înlocui",
    "înlocuiești": "înlocui",
    "înlocuii": "înlocui",
    "înlocuim": "înlocui",
    "înlocuind": "înlocui",
    "înlocuindu": "înlocui",
    "înlocuiră": "înlocui",
    "înlocuirăm": "înlocui",
    "înlocuirăți": "înlocui",
    "înlocuise": "înlocui",
    "înlocuisem": "înlocui",
    "înlocuiseră": "înlocui",
    "înlocuiserăm": "înlocui",
    "înlocuiserăți": "înlocui",
    "înlocuiseși": "înlocui",
    "înlocuiși": "înlocui",
    "înlocuit": "înlocui",
    "înlocuiți": "înlocui",
    "înlocuitu": "înlocui",
    "neînlocuind": "înlocui",
    "neînlocuindu": "înlocui",
    "nemaiînlocuind": "înlocui",
    "nemaiînlocuindu": "înlocui",
    "înlocuirea": "înlocuire",
    "înlocuiri": "înlocuire",
    "înlocuirii": "înlocuire",
    "înlocuirile": "înlocuire",
    "înlocuirilor": "înlocuire",
    "înlocuită": "înlocuit",
    "înlocuite": "înlocuit",
    "înlocuiți": "înlocuit",
    "înlocuitoare": "înlocuitor",
    "înlocuitoarea": "înlocuitor",
    "înlocuitoarei": "înlocuitor",
    "înlocuitoarele": "înlocuitor",
    "înlocuitoarelor": "înlocuitor",
    "înlocuitori": "înlocuitor",
    "înlocuitorii": "înlocuitor",
    "înlocuitorilor": "înlocuitor",
    "înlocuitorul": "înlocuitor",
    "înlocuitorului": "înlocuitor",
    "înlumină": "înlumina",
    "înluminai": "înlumina",
    "înluminam": "înlumina",
    "înluminăm": "înlumina",
    "înluminând": "înlumina",
    "înluminându": "înlumina",
    "înluminară": "înlumina",
    "înluminarăm": "înlumina",
    "înluminarăți": "înlumina",
    "înluminase": "înlumina",
    "înluminasem": "înlumina",
    "înluminaseră": "înlumina",
    "înluminaserăm": "înlumina",
    "înluminaserăți": "înlumina",
    "înluminaseși": "înlumina",
    "înluminași": "înlumina",
    "înluminat": "înlumina",
    "înluminați": "înlumina",
    "înluminatu": "înlumina",
    "înluminau": "înlumina",
    "înluminează": "înlumina",
    "înluminez": "înlumina",
    "înlumineze": "înlumina",
    "înluminezi": "înlumina",
    "neînluminând": "înlumina",
    "neînluminându": "înlumina",
    "nemaiînluminând": "înlumina",
    "nemaiînluminându": "înlumina",
    "înluminată": "înluminat",
    "înluminate": "înluminat",
    "înluminați": "înluminat",
    "înmagazină": "înmagazina",
    "înmagazinai": "înmagazina",
    "înmagazinam": "înmagazina",
    "înmagazinăm": "înmagazina",
    "înmagazinând": "înmagazina",
    "înmagazinându": "înmagazina",
    "înmagazinară": "înmagazina",
    "înmagazinarăm": "înmagazina",
    "înmagazinarăți": "înmagazina",
    "înmagazinase": "înmagazina",
    "înmagazinasem": "înmagazina",
    "înmagazinaseră": "înmagazina",
    "înmagazinaserăm": "înmagazina",
    "înmagazinaserăți": "înmagazina",
    "înmagazinaseși": "înmagazina",
    "înmagazinași": "înmagazina",
    "înmagazinat": "înmagazina",
    "înmagazinați": "înmagazina",
    "înmagazinatu": "înmagazina",
    "înmagazinau": "înmagazina",
    "înmagazinează": "înmagazina",
    "înmagazinez": "înmagazina",
    "înmagazineze": "înmagazina",
    "înmagazinezi": "înmagazina",
    "neînmagazinând": "înmagazina",
    "neînmagazinându": "înmagazina",
    "nemaiînmagazinând": "înmagazina",
    "nemaiînmagazinându": "înmagazina",
    "înmagazinată": "înmagazinat",
    "înmagazinate": "înmagazinat",
    "înmagazinați": "înmagazinat",
    "înmână": "înmâna",
    "înmânai": "înmâna",
    "înmânam": "înmâna",
    "înmânăm": "înmâna",
    "înmânând": "înmâna",
    "înmânându": "înmâna",
    "înmânară": "înmâna",
    "înmânarăm": "înmâna",
    "înmânarăți": "înmâna",
    "înmânase": "înmâna",
    "înmânasem": "înmâna",
    "înmânaseră": "înmâna",
    "înmânaserăm": "înmâna",
    "înmânaserăți": "înmâna",
    "înmânaseși": "înmâna",
    "înmânași": "înmâna",
    "înmânat": "înmâna",
    "înmânați": "înmâna",
    "înmânatu": "înmâna",
    "înmânau": "înmâna",
    "înmânează": "înmâna",
    "înmânez": "înmâna",
    "înmâneze": "înmâna",
    "înmânezi": "înmâna",
    "neînmânând": "înmâna",
    "neînmânându": "înmâna",
    "nemaiînmânând": "înmâna",
    "nemaiînmânându": "înmâna",
    "înmânată": "înmânat",
    "înmânate": "înmânat",
    "înmânați": "înmânat",
    "înmănunche": "înmănunchea",
    "înmănuncheai": "înmănunchea",
    "înmănuncheam": "înmănunchea",
    "înmănuncheară": "înmănunchea",
    "înmănunchearăm": "înmănunchea",
    "înmănunchearăți": "înmănunchea",
    "înmănunchease": "înmănunchea",
    "înmănuncheasem": "înmănunchea",
    "înmănuncheaseră": "înmănunchea",
    "înmănuncheaserăm": "înmănunchea",
    "înmănuncheaserăți": "înmănunchea",
    "înmănuncheaseși": "înmănunchea",
    "înmănuncheași": "înmănunchea",
    "înmănuncheat": "înmănunchea",
    "înmănuncheați": "înmănunchea",
    "înmănuncheatu": "înmănunchea",
    "înmănuncheau": "înmănunchea",
    "înmănunchează": "înmănunchea",
    "înmănunchem": "înmănunchea",
    "înmănunchez": "înmănunchea",
    "înmănuncheze": "înmănunchea",
    "înmănunchezi": "înmănunchea",
    "înmănunchind": "înmănunchea",
    "înmănunchindu": "înmănunchea",
    "neînmănunchind": "înmănunchea",
    "neînmănunchindu": "înmănunchea",
    "nemaiînmănunchind": "înmănunchea",
    "nemaiînmănunchindu": "înmănunchea",
    "înmănuncheată": "înmănuncheat",
    "înmănuncheate": "înmănuncheat",
    "înmănuncheați": "înmănuncheat",
    "înmărmurea": "înmărmuri",
    "înmărmureai": "înmărmuri",
    "înmărmuream": "înmărmuri",
    "înmărmurească": "înmărmuri",
    "înmărmureați": "înmărmuri",
    "înmărmureau": "înmărmuri",
    "înmărmuresc": "înmărmuri",
    "înmărmurește": "înmărmuri",
    "înmărmurești": "înmărmuri",
    "înmărmurii": "înmărmuri",
    "înmărmurim": "înmărmuri",
    "înmărmurind": "înmărmuri",
    "înmărmurindu": "înmărmuri",
    "înmărmuriră": "înmărmuri",
    "înmărmurirăm": "înmărmuri",
    "înmărmurirăți": "înmărmuri",
    "înmărmurise": "înmărmuri",
    "înmărmurisem": "înmărmuri",
    "înmărmuriseră": "înmărmuri",
    "înmărmuriserăm": "înmărmuri",
    "înmărmuriserăți": "înmărmuri",
    "înmărmuriseși": "înmărmuri",
    "înmărmuriși": "înmărmuri",
    "înmărmurit": "înmărmuri",
    "înmărmuriți": "înmărmuri",
    "înmărmuritu": "înmărmuri",
    "neînmărmurind": "înmărmuri",
    "neînmărmurindu": "înmărmuri",
    "nemaiînmărmurind": "înmărmuri",
    "nemaiînmărmurindu": "înmărmuri",
    "înmărmurita": "înmărmurit",
    "înmărmurită": "înmărmurit",
    "înmărmurite": "înmărmurit",
    "înmărmuritei": "înmărmurit",
    "înmărmuritele": "înmărmurit",
    "înmărmuritelor": "înmărmurit",
    "înmărmuriți": "înmărmurit",
    "înmărmuriții": "înmărmurit",
    "înmărmuriților": "înmărmurit",
    "înmărmuritul": "înmărmurit",
    "înmărmuritului": "înmărmurit",
    "înmatriculă": "înmatricula",
    "înmatriculai": "înmatricula",
    "înmatriculam": "înmatricula",
    "înmatriculăm": "înmatricula",
    "înmatriculând": "înmatricula",
    "înmatriculându": "înmatricula",
    "înmatriculară": "înmatricula",
    "înmatricularăm": "înmatricula",
    "înmatricularăți": "înmatricula",
    "înmatriculase": "înmatricula",
    "înmatriculasem": "înmatricula",
    "înmatriculaseră": "înmatricula",
    "înmatriculaserăm": "înmatricula",
    "înmatriculaserăți": "înmatricula",
    "înmatriculaseși": "înmatricula",
    "înmatriculași": "înmatricula",
    "înmatriculat": "înmatricula",
    "înmatriculați": "înmatricula",
    "înmatriculatu": "înmatricula",
    "înmatriculau": "înmatricula",
    "înmatriculează": "înmatricula",
    "înmatriculez": "înmatricula",
    "înmatriculeze": "înmatricula",
    "înmatriculezi": "înmatricula",
    "neînmatriculând": "înmatricula",
    "neînmatriculându": "înmatricula",
    "nemaiînmatriculând": "înmatricula",
    "nemaiînmatriculându": "înmatricula",
    "înmatriculată": "înmatriculat",
    "înmatriculate": "înmatriculat",
    "înmatriculați": "înmatriculat",
    "înmiia": "înmii",
    "înmiiai": "înmii",
    "înmiiam": "înmii",
    "înmiiască": "înmii",
    "înmiiați": "înmii",
    "înmiiau": "înmii",
    "înmiiesc": "înmii",
    "înmiiește": "înmii",
    "înmiiești": "înmii",
    "înmiii": "înmii",
    "înmiim": "înmii",
    "înmiind": "înmii",
    "înmiindu": "înmii",
    "înmiiră": "înmii",
    "înmiirăm": "înmii",
    "înmiirăți": "înmii",
    "înmiise": "înmii",
    "înmiisem": "înmii",
    "înmiiseră": "înmii",
    "înmiiserăm": "înmii",
    "înmiiserăți": "înmii",
    "înmiiseși": "înmii",
    "înmiiși": "înmii",
    "înmiit": "înmii",
    "înmiiți": "înmii",
    "înmiitu": "înmii",
    "neînmiind": "înmii",
    "neînmiindu": "înmii",
    "nemaiînmiind": "înmii",
    "nemaiînmiindu": "înmii",
    "înmiita": "înmiit",
    "înmiită": "înmiit",
    "înmiite": "înmiit",
    "înmiitei": "înmiit",
    "înmiitele": "înmiit",
    "înmiitelor": "înmiit",
    "înmiiți": "înmiit",
    "înmiiții": "înmiit",
    "înmiiților": "înmiit",
    "înmiitul": "înmiit",
    "înmiitului": "înmiit",
    "înmiresmă": "înmiresma",
    "înmiresmai": "înmiresma",
    "înmiresmam": "înmiresma",
    "înmiresmăm": "înmiresma",
    "înmiresmând": "înmiresma",
    "înmiresmându": "înmiresma",
    "înmiresmară": "înmiresma",
    "înmiresmarăm": "înmiresma",
    "înmiresmarăți": "înmiresma",
    "înmiresmase": "înmiresma",
    "înmiresmasem": "înmiresma",
    "înmiresmaseră": "înmiresma",
    "înmiresmaserăm": "înmiresma",
    "înmiresmaserăți": "înmiresma",
    "înmiresmaseși": "înmiresma",
    "înmiresmași": "înmiresma",
    "înmiresmat": "înmiresma",
    "înmiresmați": "înmiresma",
    "înmiresmatu": "înmiresma",
    "înmiresmau": "înmiresma",
    "înmiresmează": "înmiresma",
    "înmiresmez": "înmiresma",
    "înmiresmeze": "înmiresma",
    "înmiresmezi": "înmiresma",
    "neînmiresmând": "înmiresma",
    "neînmiresmându": "înmiresma",
    "nemaiînmiresmând": "înmiresma",
    "nemaiînmiresmându": "înmiresma",
    "înmiresmata": "înmiresmat",
    "înmiresmată": "înmiresmat",
    "înmiresmate": "înmiresmat",
    "înmiresmatei": "înmiresmat",
    "înmiresmatele": "înmiresmat",
    "înmiresmatelor": "înmiresmat",
    "înmiresmați": "înmiresmat",
    "înmiresmații": "înmiresmat",
    "înmiresmaților": "înmiresmat",
    "înmiresmatul": "înmiresmat",
    "înmiresmatului": "înmiresmat",
    "înmlădiai": "înmlădia",
    "înmlădiam": "înmlădia",
    "înmlădiară": "înmlădia",
    "înmlădiarăm": "înmlădia",
    "înmlădiarăți": "înmlădia",
    "înmlădiase": "înmlădia",
    "înmlădiasem": "înmlădia",
    "înmlădiaseră": "înmlădia",
    "înmlădiaserăm": "înmlădia",
    "înmlădiaserăți": "înmlădia",
    "înmlădiaseși": "înmlădia",
    "înmlădiași": "înmlădia",
    "înmlădiat": "înmlădia",
    "înmlădiați": "înmlădia",
    "înmlădiatu": "înmlădia",
    "înmlădiau": "înmlădia",
    "înmlădiază": "înmlădia",
    "înmlădie": "înmlădia",
    "înmlădiem": "înmlădia",
    "înmlădiez": "înmlădia",
    "înmlădieze": "înmlădia",
    "înmlădiezi": "înmlădia",
    "înmlădiind": "înmlădia",
    "înmlădiindu": "înmlădia",
    "neînmlădiind": "înmlădia",
    "neînmlădiindu": "înmlădia",
    "nemaiînmlădiind": "înmlădia",
    "nemaiînmlădiindu": "înmlădia",
    "înmlădiată": "înmlădiat",
    "înmlădiate": "înmlădiat",
    "înmlădiați": "înmlădiat",
    "înmoină": "înmoina",
    "înmoinase": "înmoina",
    "înmoinat": "înmoina",
    "înmoinatu": "înmoina",
    "înmoinează": "înmoina",
    "înmoineze": "înmoina",
    "înmoinată": "înmoinat",
    "înmormântă": "înmormânta",
    "înmormântai": "înmormânta",
    "înmormântam": "înmormânta",
    "înmormântăm": "înmormânta",
    "înmormântând": "înmormânta",
    "înmormântându": "înmormânta",
    "înmormântară": "înmormânta",
    "înmormântarăm": "înmormânta",
    "înmormântarăți": "înmormânta",
    "înmormântase": "înmormânta",
    "înmormântasem": "înmormânta",
    "înmormântaseră": "înmormânta",
    "înmormântaserăm": "înmormânta",
    "înmormântaserăți": "înmormânta",
    "înmormântaseși": "înmormânta",
    "înmormântași": "înmormânta",
    "înmormântat": "înmormânta",
    "înmormântați": "înmormânta",
    "înmormântatu": "înmormânta",
    "înmormântau": "înmormânta",
    "înmormântează": "înmormânta",
    "înmormântez": "înmormânta",
    "înmormânteze": "înmormânta",
    "înmormântezi": "înmormânta",
    "neînmormântând": "înmormânta",
    "neînmormântându": "înmormânta",
    "nemaiînmormântând": "înmormânta",
    "nemaiînmormântându": "înmormânta",
    "îmmormântarea": "înmormântare",
    "înmormântarea": "înmormântare",
    "înmormântări": "înmormântare",
    "înmormântării": "înmormântare",
    "înmormântările": "înmormântare",
    "înmormântărilor": "înmormântare",
    "înmormântată": "înmormântat",
    "înmormântate": "înmormântat",
    "înmormântați": "înmormântat",
    "înmugurea": "înmuguri",
    "înmugureai": "înmuguri",
    "înmuguream": "înmuguri",
    "înmugurească": "înmuguri",
    "înmugureați": "înmuguri",
    "înmugureau": "înmuguri",
    "înmuguresc": "înmuguri",
    "înmugurește": "înmuguri",
    "înmugurești": "înmuguri",
    "înmugurii": "înmuguri",
    "înmugurim": "înmuguri",
    "înmugurind": "înmuguri",
    "înmugurindu": "înmuguri",
    "înmuguriră": "înmuguri",
    "înmugurirăm": "înmuguri",
    "înmugurirăți": "înmuguri",
    "înmugurise": "înmuguri",
    "înmugurisem": "înmuguri",
    "înmuguriseră": "înmuguri",
    "înmuguriserăm": "înmuguri",
    "înmuguriserăți": "înmuguri",
    "înmuguriseși": "înmuguri",
    "înmuguriși": "înmuguri",
    "înmugurit": "înmuguri",
    "înmuguriți": "înmuguri",
    "înmuguritu": "înmuguri",
    "neînmugurind": "înmuguri",
    "neînmugurindu": "înmuguri",
    "nemaiînmugurind": "înmuguri",
    "nemaiînmugurindu": "înmuguri",
    "înmugurită": "înmugurit",
    "înmugurite": "înmugurit",
    "înmuguriți": "înmugurit",
    "înmoaie": "înmuia",
    "înmoi": "înmuia",
    "înmuiai": "înmuia",
    "înmuiam": "înmuia",
    "înmuiară": "înmuia",
    "înmuiarăm": "înmuia",
    "înmuiarăți": "înmuia",
    "înmuiase": "înmuia",
    "înmuiasem": "înmuia",
    "înmuiaseră": "înmuia",
    "înmuiaserăm": "înmuia",
    "înmuiaserăți": "înmuia",
    "înmuiaseși": "înmuia",
    "înmuiași": "înmuia",
    "înmuiat": "înmuia",
    "înmuiați": "înmuia",
    "înmuiatu": "înmuia",
    "înmuiau": "înmuia",
    "înmuie": "înmuia",
    "înmuiem": "înmuia",
    "înmuind": "înmuia",
    "înmuindu": "înmuia",
    "neînmuiind": "înmuia",
    "neînmuiindu": "înmuia",
    "nemaiînmuiind": "înmuia",
    "nemaiînmuiindu": "înmuia",
    "înmuiată": "înmuiat",
    "înmuiate": "înmuiat",
    "înmuiați": "înmuiat",
    "înmuierea": "înmuiere",
    "înmuiereo": "înmuiere",
    "înmuieri": "înmuiere",
    "înmuierii": "înmuiere",
    "înmuierile": "înmuiere",
    "înmuierilor": "înmuiere",
    "înmulțea": "înmulți",
    "înmulțeai": "înmulți",
    "înmulțeam": "înmulți",
    "înmulțească": "înmulți",
    "înmulțeați": "înmulți",
    "înmulțeau": "înmulți",
    "înmulțesc": "înmulți",
    "înmulțește": "înmulți",
    "înmulțești": "înmulți",
    "înmulții": "înmulți",
    "înmulțim": "înmulți",
    "înmulțind": "înmulți",
    "înmulțindu": "înmulți",
    "înmulțiră": "înmulți",
    "înmulțirăm": "înmulți",
    "înmulțirăți": "înmulți",
    "înmulțise": "înmulți",
    "înmulțisem": "înmulți",
    "înmulțiseră": "înmulți",
    "înmulțiserăm": "înmulți",
    "înmulțiserăți": "înmulți",
    "înmulțiseși": "înmulți",
    "înmulțiși": "înmulți",
    "înmulțit": "înmulți",
    "înmulțiți": "înmulți",
    "înmulțitu": "înmulți",
    "neînmulțind": "înmulți",
    "neînmulțindu": "înmulți",
    "nemaiînmulțind": "înmulți",
    "nemaiînmulțindu": "înmulți",
    "înmulțirea": "înmulțire",
    "înmulțiri": "înmulțire",
    "înmulțirii": "înmulțire",
    "înmulțirile": "înmulțire",
    "înmulțirilor": "înmulțire",
    "înmulțită": "înmulțit",
    "înmulțite": "înmulțit",
    "înmulțiți": "înmulțit",
    "înmulțitori": "înmulțitor",
    "înmulțitorii": "înmulțitor",
    "înmulțitorilor": "înmulțitor",
    "înmulțitorul": "înmulțitor",
    "înmulțitorului": "înmulțitor",
    "înmurgea": "înmurgi",
    "înmurgeai": "înmurgi",
    "înmurgeam": "înmurgi",
    "înmurgească": "înmurgi",
    "înmurgeați": "înmurgi",
    "înmurgeau": "înmurgi",
    "înmurgesc": "înmurgi",
    "înmurgește": "înmurgi",
    "înmurgești": "înmurgi",
    "înmurgii": "înmurgi",
    "înmurgim": "înmurgi",
    "înmurgind": "înmurgi",
    "înmurgindu": "înmurgi",
    "înmurgiră": "înmurgi",
    "înmurgirăm": "înmurgi",
    "înmurgirăți": "înmurgi",
    "înmurgise": "înmurgi",
    "înmurgisem": "înmurgi",
    "înmurgiseră": "înmurgi",
    "înmurgiserăm": "înmurgi",
    "înmurgiserăți": "înmurgi",
    "înmurgiseși": "înmurgi",
    "înmurgiși": "înmurgi",
    "înmurgit": "înmurgi",
    "înmurgiți": "înmurgi",
    "înmurgitu": "înmurgi",
    "neînmurgind": "înmurgi",
    "neînmurgindu": "înmurgi",
    "nemaiînmurgind": "înmurgi",
    "nemaiînmurgindu": "înmurgi",
    "înmurgită": "înmurgit",
    "înmurgite": "înmurgit",
    "înmurgiți": "înmurgit",
    "înnădea": "înnădi",
    "înnădeai": "înnădi",
    "înnădeam": "înnădi",
    "înnădească": "înnădi",
    "înnădeați": "înnădi",
    "înnădeau": "înnădi",
    "înnădesc": "înnădi",
    "înnădește": "înnădi",
    "înnădești": "înnădi",
    "înnădii": "înnădi",
    "înnădim": "înnădi",
    "înnădind": "înnădi",
    "înnădindu": "înnădi",
    "înnădiră": "înnădi",
    "înnădirăm": "înnădi",
    "înnădirăți": "înnădi",
    "înnădise": "înnădi",
    "înnădisem": "înnădi",
    "înnădiseră": "înnădi",
    "înnădiserăm": "înnădi",
    "înnădiserăți": "înnădi",
    "înnădiseși": "înnădi",
    "înnădiși": "înnădi",
    "înnădit": "înnădi",
    "înnădiți": "înnădi",
    "înnăditu": "înnădi",
    "neînnădind": "înnădi",
    "neînnădindu": "înnădi",
    "nemaiînnădind": "înnădi",
    "nemaiînnădindu": "înnădi",
    "înnădită": "înnădit",
    "înnădite": "înnădit",
    "înnădiți": "înnădit",
    "înnămolea": "înnămoli",
    "înnămoleai": "înnămoli",
    "înnămoleam": "înnămoli",
    "înnămolească": "înnămoli",
    "înnămoleați": "înnămoli",
    "înnămoleau": "înnămoli",
    "înnămolesc": "înnămoli",
    "înnămolește": "înnămoli",
    "înnămolești": "înnămoli",
    "înnămolii": "înnămoli",
    "înnămolim": "înnămoli",
    "înnămolind": "înnămoli",
    "înnămolindu": "înnămoli",
    "înnămoliră": "înnămoli",
    "înnămolirăm": "înnămoli",
    "înnămolirăți": "înnămoli",
    "înnămolise": "înnămoli",
    "înnămolisem": "înnămoli",
    "înnămoliseră": "înnămoli",
    "înnămoliserăm": "înnămoli",
    "înnămoliserăți": "înnămoli",
    "înnămoliseși": "înnămoli",
    "înnămoliși": "înnămoli",
    "înnămolit": "înnămoli",
    "înnămoliți": "înnămoli",
    "înnămolitu": "înnămoli",
    "neînnămolind": "înnămoli",
    "neînnămolindu": "înnămoli",
    "nemaiînnămolind": "înnămoli",
    "nemaiînnămolindu": "înnămoli",
    "înnămolită": "înnămolit",
    "înnămolite": "înnămolit",
    "înnămoliți": "înnămolit",
    "înnărăvea": "înnărăvi",
    "înnărăveai": "înnărăvi",
    "înnărăveam": "înnărăvi",
    "înnărăvească": "înnărăvi",
    "înnărăveați": "înnărăvi",
    "înnărăveau": "înnărăvi",
    "înnărăvesc": "înnărăvi",
    "înnărăvește": "înnărăvi",
    "înnărăvești": "înnărăvi",
    "înnărăvii": "înnărăvi",
    "înnărăvim": "înnărăvi",
    "înnărăvind": "înnărăvi",
    "înnărăvindu": "înnărăvi",
    "înnărăviră": "înnărăvi",
    "înnărăvirăm": "înnărăvi",
    "înnărăvirăți": "înnărăvi",
    "înnărăvise": "înnărăvi",
    "înnărăvisem": "înnărăvi",
    "înnărăviseră": "înnărăvi",
    "înnărăviserăm": "înnărăvi",
    "înnărăviserăți": "înnărăvi",
    "înnărăviseși": "înnărăvi",
    "înnărăviși": "înnărăvi",
    "înnărăvit": "înnărăvi",
    "înnărăviți": "înnărăvi",
    "înnărăvitu": "înnărăvi",
    "neînnărăvind": "înnărăvi",
    "neînnărăvindu": "înnărăvi",
    "nemaiînnărăvind": "înnărăvi",
    "nemaiînnărăvindu": "înnărăvi",
    "înnărăvită": "înnărăvit",
    "înnărăvite": "înnărăvit",
    "înnărăviți": "înnărăvit",
    "înnăscuta": "înnăscut",
    "înnăscută": "înnăscut",
    "înnăscute": "înnăscut",
    "înnăscutei": "înnăscut",
    "înnăscutele": "înnăscut",
    "înnăscutelor": "înnăscut",
    "înnăscuți": "înnăscut",
    "înnăscuții": "înnăscut",
    "înnăscuților": "înnăscut",
    "înnăscutul": "înnăscut",
    "înnăscutului": "înnăscut",
    "înnebunea": "înnebuni",
    "înnebuneai": "înnebuni",
    "înnebuneam": "înnebuni",
    "înnebunească": "înnebuni",
    "înnebuneați": "înnebuni",
    "înnebuneau": "înnebuni",
    "înnebunesc": "înnebuni",
    "înnebunește": "înnebuni",
    "înnebunești": "înnebuni",
    "înnebunii": "înnebuni",
    "înnebunim": "înnebuni",
    "înnebunind": "înnebuni",
    "înnebunindu": "înnebuni",
    "înnebuniră": "înnebuni",
    "înnebunirăm": "înnebuni",
    "înnebunirăți": "înnebuni",
    "înnebunise": "înnebuni",
    "înnebunisem": "înnebuni",
    "înnebuniseră": "înnebuni",
    "înnebuniserăm": "înnebuni",
    "înnebuniserăți": "înnebuni",
    "înnebuniseși": "înnebuni",
    "înnebuniși": "înnebuni",
    "înnebunit": "înnebuni",
    "înnebuniți": "înnebuni",
    "înnebunitu": "înnebuni",
    "neînnebunind": "înnebuni",
    "neînnebunindu": "înnebuni",
    "nemaiînnebunind": "înnebuni",
    "nemaiînnebunindu": "înnebuni",
    "înnebunita": "înnebunit",
    "înnebunită": "înnebunit",
    "înnebunite": "înnebunit",
    "înnebunitei": "înnebunit",
    "înnebunitele": "înnebunit",
    "înnebunitelor": "înnebunit",
    "înnebuniți": "înnebunit",
    "înnebuniții": "înnebunit",
    "înnebuniților": "înnebunit",
    "înnebunitul": "înnebunit",
    "înnebunitului": "înnebunit",
    "înnebunitoare": "înnebunitor",
    "înnebunitoarea": "înnebunitor",
    "înnebunitoarei": "înnebunitor",
    "înnebunitoarele": "înnebunitor",
    "înnebunitoarelor": "înnebunitor",
    "înnebunitori": "înnebunitor",
    "înnebunitorii": "înnebunitor",
    "înnebunitorilor": "înnebunitor",
    "înnebunitorul": "înnebunitor",
    "înnebunitorului": "înnebunitor",
    "înnegrea": "înnegri",
    "înnegreai": "înnegri",
    "înnegream": "înnegri",
    "înnegrească": "înnegri",
    "înnegreați": "înnegri",
    "înnegreau": "înnegri",
    "înnegresc": "înnegri",
    "înnegrește": "înnegri",
    "înnegrești": "înnegri",
    "înnegrii": "înnegri",
    "înnegrim": "înnegri",
    "înnegrind": "înnegri",
    "înnegrindu": "înnegri",
    "înnegriră": "înnegri",
    "înnegrirăm": "înnegri",
    "înnegrirăți": "înnegri",
    "înnegrise": "înnegri",
    "înnegrisem": "înnegri",
    "înnegriseră": "înnegri",
    "înnegriserăm": "înnegri",
    "înnegriserăți": "înnegri",
    "înnegriseși": "înnegri",
    "înnegriși": "înnegri",
    "înnegrit": "înnegri",
    "înnegriți": "înnegri",
    "înnegritu": "înnegri",
    "neînnegrind": "înnegri",
    "neînnegrindu": "înnegri",
    "nemaiînnegrind": "înnegri",
    "nemaiînnegrindu": "înnegri",
    "înnegrită": "înnegrit",
    "înnegrite": "înnegrit",
    "înnegriți": "înnegrit",
    "înnegură": "înnegura",
    "înnegurase": "înnegura",
    "înnegurat": "înnegura",
    "înneguratu": "înnegura",
    "înnegurează": "înnegura",
    "înnegureze": "înnegura",
    "înnegurată": "înnegurat",
    "înnemurea": "înnemuri",
    "înnemureai": "înnemuri",
    "înnemuream": "înnemuri",
    "înnemurească": "înnemuri",
    "înnemureați": "înnemuri",
    "înnemureau": "înnemuri",
    "înnemuresc": "înnemuri",
    "înnemurește": "înnemuri",
    "înnemurești": "înnemuri",
    "înnemurii": "înnemuri",
    "înnemurim": "înnemuri",
    "înnemurind": "înnemuri",
    "înnemurindu": "înnemuri",
    "înnemuriră": "înnemuri",
    "înnemurirăm": "înnemuri",
    "înnemurirăți": "înnemuri",
    "înnemurise": "înnemuri",
    "înnemurisem": "înnemuri",
    "înnemuriseră": "înnemuri",
    "înnemuriserăm": "înnemuri",
    "înnemuriserăți": "înnemuri",
    "înnemuriseși": "înnemuri",
    "înnemuriși": "înnemuri",
    "înnemurit": "înnemuri",
    "înnemuriți": "înnemuri",
    "înnemuritu": "înnemuri",
    "neînnemurind": "înnemuri",
    "neînnemurindu": "înnemuri",
    "nemaiînnemurind": "înnemuri",
    "nemaiînnemurindu": "înnemuri",
    "înnemurită": "înnemurit",
    "înnemurite": "înnemurit",
    "înnemuriți": "înnemurit",
    "înnisipă": "înnisipa",
    "înnisipai": "înnisipa",
    "înnisipam": "înnisipa",
    "înnisipăm": "înnisipa",
    "înnisipând": "înnisipa",
    "înnisipându": "înnisipa",
    "înnisipară": "înnisipa",
    "înnisiparăm": "înnisipa",
    "înnisiparăți": "înnisipa",
    "înnisipase": "înnisipa",
    "înnisipasem": "înnisipa",
    "înnisipaseră": "înnisipa",
    "înnisipaserăm": "înnisipa",
    "înnisipaserăți": "înnisipa",
    "înnisipaseși": "înnisipa",
    "înnisipași": "înnisipa",
    "înnisipat": "înnisipa",
    "înnisipați": "înnisipa",
    "înnisipatu": "înnisipa",
    "înnisipau": "înnisipa",
    "înnisipează": "înnisipa",
    "înnisipez": "înnisipa",
    "înnisipeze": "înnisipa",
    "înnisipezi": "înnisipa",
    "neînnisipând": "înnisipa",
    "neînnisipându": "înnisipa",
    "nemaiînnisipând": "înnisipa",
    "nemaiînnisipându": "înnisipa",
    "înnisipată": "înnisipat",
    "înnisipate": "înnisipat",
    "înnisipați": "înnisipat",
    "înnobilă": "înnobila",
    "înnobilai": "înnobila",
    "înnobilam": "înnobila",
    "înnobilăm": "înnobila",
    "înnobilând": "înnobila",
    "înnobilându": "înnobila",
    "înnobilară": "înnobila",
    "înnobilarăm": "înnobila",
    "înnobilarăți": "înnobila",
    "înnobilase": "înnobila",
    "înnobilasem": "înnobila",
    "înnobilaseră": "înnobila",
    "înnobilaserăm": "înnobila",
    "înnobilaserăți": "înnobila",
    "înnobilaseși": "înnobila",
    "înnobilași": "înnobila",
    "înnobilat": "înnobila",
    "înnobilați": "înnobila",
    "înnobilatu": "înnobila",
    "înnobilau": "înnobila",
    "înnobilează": "înnobila",
    "înnobilez": "înnobila",
    "înnobileze": "înnobila",
    "înnobilezi": "înnobila",
    "neînnobilând": "înnobila",
    "neînnobilându": "înnobila",
    "nemaiînnobilând": "înnobila",
    "nemaiînnobilându": "înnobila",
    "înnobilată": "înnobilat",
    "înnobilate": "înnobilat",
    "înnobilați": "înnobilat",
    "înnoadă": "înnoda",
    "înnoade": "înnoda",
    "înnod": "înnoda",
    "înnodă": "înnoda",
    "înnodai": "înnoda",
    "înnodam": "înnoda",
    "înnodăm": "înnoda",
    "înnodând": "înnoda",
    "înnodându": "înnoda",
    "înnodară": "înnoda",
    "înnodarăm": "înnoda",
    "înnodarăți": "înnoda",
    "înnodase": "înnoda",
    "înnodasem": "înnoda",
    "înnodaseră": "înnoda",
    "înnodaserăm": "înnoda",
    "înnodaserăți": "înnoda",
    "înnodaseși": "înnoda",
    "înnodași": "înnoda",
    "înnodat": "înnoda",
    "înnodați": "înnoda",
    "înnodatu": "înnoda",
    "înnodau": "înnoda",
    "înnozi": "înnoda",
    "neînnodând": "înnoda",
    "neînnodându": "înnoda",
    "nemaiînnodând": "înnoda",
    "nemaiînnodându": "înnoda",
    "înnodată": "înnodat",
    "înnodate": "înnodat",
    "înnodați": "înnodat",
    "înnoia": "înnoi",
    "înnoiai": "înnoi",
    "înnoiam": "înnoi",
    "înnoiască": "înnoi",
    "înnoiați": "înnoi",
    "înnoiau": "înnoi",
    "înnoiesc": "înnoi",
    "înnoiește": "înnoi",
    "înnoiești": "înnoi",
    "înnoii": "înnoi",
    "înnoim": "înnoi",
    "înnoind": "înnoi",
    "înnoindu": "înnoi",
    "înnoiră": "înnoi",
    "înnoirăm": "înnoi",
    "înnoirăți": "înnoi",
    "înnoise": "înnoi",
    "înnoisem": "înnoi",
    "înnoiseră": "înnoi",
    "înnoiserăm": "înnoi",
    "înnoiserăți": "înnoi",
    "înnoiseși": "înnoi",
    "înnoiși": "înnoi",
    "înnoit": "înnoi",
    "înnoiți": "înnoi",
    "înnoitu": "înnoi",
    "neînnoind": "înnoi",
    "neînnoindu": "înnoi",
    "nemaiînnoind": "înnoi",
    "nemaiînnoindu": "înnoi",
    "înnoirea": "înnoire",
    "înnoireo": "înnoire",
    "înnoiri": "înnoire",
    "înnoirii": "înnoire",
    "înnoirile": "înnoire",
    "înnoirilor": "înnoire",
    "înnoită": "înnoit",
    "înnoite": "înnoit",
    "înnoiți": "înnoit",
    "înnoitoare": "înnoitor",
    "înnoitoarea": "înnoitor",
    "înnoitoarei": "înnoitor",
    "înnoitoarele": "înnoitor",
    "înnoitoarelor": "înnoitor",
    "înnoitori": "înnoitor",
    "înnoitorii": "înnoitor",
    "înnoitorilor": "înnoitor",
    "înnoitorul": "înnoitor",
    "înnoitorului": "înnoitor",
    "înnoptă": "înnopta",
    "înnoptai": "înnopta",
    "înnoptam": "înnopta",
    "înnoptăm": "înnopta",
    "înnoptând": "înnopta",
    "înnoptându": "înnopta",
    "înnoptară": "înnopta",
    "înnoptarăm": "înnopta",
    "înnoptarăți": "înnopta",
    "înnoptase": "înnopta",
    "înnoptasem": "înnopta",
    "înnoptaseră": "înnopta",
    "înnoptaserăm": "înnopta",
    "înnoptaserăți": "înnopta",
    "înnoptaseși": "înnopta",
    "înnoptași": "înnopta",
    "înnoptat": "înnopta",
    "înnoptați": "înnopta",
    "înnoptatu": "înnopta",
    "înnoptau": "înnopta",
    "înnoptează": "înnopta",
    "înnoptez": "înnopta",
    "înnopteze": "înnopta",
    "înnoptezi": "înnopta",
    "neînnoptând": "înnopta",
    "neînnoptându": "înnopta",
    "nemaiînnoptând": "înnopta",
    "nemaiînnoptându": "înnopta",
    "înnoptată": "înnoptat",
    "înnoptate": "înnoptat",
    "înnoptați": "înnoptat",
    "înnoră": "înnora",
    "înnorând": "înnora",
    "înnorându": "înnora",
    "înnorase": "înnora",
    "înnorat": "înnora",
    "înnoratu": "înnora",
    "înnorează": "înnora",
    "înnoreze": "înnora",
    "neînnorând": "înnora",
    "neînnorându": "înnora",
    "nemaiînnorând": "înnora",
    "nemaiînnorându": "înnora",
    "înnorarea": "înnorare",
    "înnorareo": "înnorare",
    "înnorări": "înnorare",
    "înnorării": "înnorare",
    "înnorările": "înnorare",
    "înnorărilor": "înnorare",
    "înnorata": "înnorat",
    "înnorată": "înnorat",
    "înnorate": "înnorat",
    "înnoratei": "înnorat",
    "înnoratele": "înnorat",
    "înnoratelor": "înnorat",
    "înnorați": "înnorat",
    "înnorații": "înnorat",
    "înnoraților": "înnorat",
    "înnoratul": "înnorat",
    "înnoratului": "înnorat",
    "înnoroia": "înnoroi",
    "înnoroiai": "înnoroi",
    "înnoroiam": "înnoroi",
    "înnoroiască": "înnoroi",
    "înnoroiați": "înnoroi",
    "înnoroiau": "înnoroi",
    "înnoroiesc": "înnoroi",
    "înnoroiește": "înnoroi",
    "înnoroiești": "înnoroi",
    "înnoroii": "înnoroi",
    "înnoroim": "înnoroi",
    "înnoroind": "înnoroi",
    "înnoroindu": "înnoroi",
    "înnoroiră": "înnoroi",
    "înnoroirăm": "înnoroi",
    "înnoroirăți": "înnoroi",
    "înnoroise": "înnoroi",
    "înnoroisem": "înnoroi",
    "înnoroiseră": "înnoroi",
    "înnoroiserăm": "înnoroi",
    "înnoroiserăți": "înnoroi",
    "înnoroiseși": "înnoroi",
    "înnoroiși": "înnoroi",
    "înnoroit": "înnoroi",
    "înnoroiți": "înnoroi",
    "înnoroitu": "înnoroi",
    "neînnoroind": "înnoroi",
    "neînnoroindu": "înnoroi",
    "nemaiînnoroind": "înnoroi",
    "nemaiînnoroindu": "înnoroi",
    "înnoroită": "înnoroit",
    "înnoroite": "înnoroit",
    "înnoroiți": "înnoroit",
    "inocenta": "inocent",
    "inocentă": "inocent",
    "inocente": "inocent",
    "inocentei": "inocent",
    "inocentele": "inocent",
    "inocentelor": "inocent",
    "inocenți": "inocent",
    "inocenții": "inocent",
    "inocenților": "inocent",
    "inocentul": "inocent",
    "inocentului": "inocent",
    "inocența": "inocență",
    "inoculă": "inocula",
    "inoculai": "inocula",
    "inoculam": "inocula",
    "inoculăm": "inocula",
    "inoculând": "inocula",
    "inoculându": "inocula",
    "inoculară": "inocula",
    "inocularăm": "inocula",
    "inocularăți": "inocula",
    "inoculase": "inocula",
    "inoculasem": "inocula",
    "inoculaseră": "inocula",
    "inoculaserăm": "inocula",
    "inoculaserăți": "inocula",
    "inoculaseși": "inocula",
    "inoculași": "inocula",
    "inoculat": "inocula",
    "inoculați": "inocula",
    "inoculatu": "inocula",
    "inoculau": "inocula",
    "inoculează": "inocula",
    "inoculez": "inocula",
    "inoculeze": "inocula",
    "inoculezi": "inocula",
    "neinoculând": "inocula",
    "neinoculându": "inocula",
    "nemaiinoculând": "inocula",
    "nemaiinoculându": "inocula",
    "inoculată": "inoculat",
    "inoculate": "inoculat",
    "inoculați": "inoculat",
    "inodora": "inodor",
    "inodoră": "inodor",
    "inodore": "inodor",
    "inodorei": "inodor",
    "inodorele": "inodor",
    "inodorelor": "inodor",
    "inodori": "inodor",
    "inodorii": "inodor",
    "inodorilor": "inodor",
    "inodorul": "inodor",
    "inodorului": "inodor",
    "inofensiva": "inofensiv",
    "inofensivă": "inofensiv",
    "inofensive": "inofensiv",
    "inofensivei": "inofensiv",
    "inofensivele": "inofensiv",
    "inofensivelor": "inofensiv",
    "inofensivi": "inofensiv",
    "inofensivii": "inofensiv",
    "inofensivilor": "inofensiv",
    "inofensivul": "inofensiv",
    "inofensivului": "inofensiv",
    "inopinata": "inopinat",
    "inopinată": "inopinat",
    "inopinate": "inopinat",
    "inopinatei": "inopinat",
    "inopinatele": "inopinat",
    "inopinatelor": "inopinat",
    "inopinați": "inopinat",
    "inopinații": "inopinat",
    "inopinaților": "inopinat",
    "inopinato": "inopinat",
    "inopinatul": "inopinat",
    "inopinatule": "inopinat",
    "inopinatului": "inopinat",
    "inoportuna": "inoportun",
    "inoportună": "inoportun",
    "inoportune": "inoportun",
    "inoportunei": "inoportun",
    "inoportunele": "inoportun",
    "inoportunelor": "inoportun",
    "inoportuni": "inoportun",
    "inoportunii": "inoportun",
    "inoportunilor": "inoportun",
    "inoportunul": "inoportun",
    "inoportunului": "inoportun",
    "înotul": "înot",
    "înotului": "înot",
    "înoturi": "înot",
    "înoturile": "înot",
    "înoturilor": "înot",
    "înoată": "înota",
    "înoate": "înota",
    "înot": "înota",
    "înotă": "înota",
    "înotai": "înota",
    "înotam": "înota",
    "înotăm": "înota",
    "înotând": "înota",
    "înotându": "înota",
    "înotară": "înota",
    "înotarăm": "înota",
    "înotarăți": "înota",
    "înotase": "înota",
    "înotasem": "înota",
    "înotaseră": "înota",
    "înotaserăm": "înota",
    "înotaserăți": "înota",
    "înotaseși": "înota",
    "înotași": "înota",
    "înotat": "înota",
    "înotați": "înota",
    "înotatu": "înota",
    "înotau": "înota",
    "înoți": "înota",
    "neînotând": "înota",
    "neînotându": "înota",
    "nemaiînotând": "înota",
    "nemaiînotându": "înota",
    "înotată": "înotat",
    "înotate": "înotat",
    "înotați": "înotat",
    "inovă": "inova",
    "inovai": "inova",
    "inovam": "inova",
    "inovăm": "inova",
    "inovând": "inova",
    "inovându": "inova",
    "inovară": "inova",
    "inovarăm": "inova",
    "inovarăți": "inova",
    "inovase": "inova",
    "inovasem": "inova",
    "inovaseră": "inova",
    "inovaserăm": "inova",
    "inovaserăți": "inova",
    "inovaseși": "inova",
    "inovași": "inova",
    "inovat": "inova",
    "inovați": "inova",
    "inovatu": "inova",
    "inovau": "inova",
    "inovează": "inova",
    "inovez": "inova",
    "inoveze": "inova",
    "inovezi": "inova",
    "neinovând": "inova",
    "neinovându": "inova",
    "nemaiinovând": "inova",
    "nemaiinovându": "inova",
    "inovată": "inovat",
    "inovate": "inovat",
    "inovați": "inovat",
    "inovația": "inovație",
    "inovației": "inovație",
    "inovații": "inovație",
    "inovațiile": "inovație",
    "inovațiilor": "inovație",
    "inovatoare": "inovator",
    "inovatoarea": "inovator",
    "inovatoarei": "inovator",
    "inovatoarele": "inovator",
    "inovatoarelor": "inovator",
    "inovatori": "inovator",
    "inovatorii": "inovator",
    "inovatorilor": "inovator",
    "inovatorul": "inovator",
    "inovatorului": "inovator",
    "inoxidabila": "inoxidabil",
    "inoxidabilă": "inoxidabil",
    "inoxidabile": "inoxidabil",
    "inoxidabilei": "inoxidabil",
    "inoxidabilele": "inoxidabil",
    "inoxidabilelor": "inoxidabil",
    "inoxidabili": "inoxidabil",
    "inoxidabilii": "inoxidabil",
    "inoxidabililor": "inoxidabil",
    "inoxidabilul": "inoxidabil",
    "inoxidabilului": "inoxidabil",
    "înrădăcină": "înrădăcina",
    "înrădăcinai": "înrădăcina",
    "înrădăcinam": "înrădăcina",
    "înrădăcinăm": "înrădăcina",
    "înrădăcinând": "înrădăcina",
    "înrădăcinându": "înrădăcina",
    "înrădăcinară": "înrădăcina",
    "înrădăcinarăm": "înrădăcina",
    "înrădăcinarăți": "înrădăcina",
    "înrădăcinase": "înrădăcina",
    "înrădăcinasem": "înrădăcina",
    "înrădăcinaseră": "înrădăcina",
    "înrădăcinaserăm": "înrădăcina",
    "înrădăcinaserăți": "înrădăcina",
    "înrădăcinaseși": "înrădăcina",
    "înrădăcinași": "înrădăcina",
    "înrădăcinat": "înrădăcina",
    "înrădăcinați": "înrădăcina",
    "înrădăcinatu": "înrădăcina",
    "înrădăcinau": "înrădăcina",
    "înrădăcinează": "înrădăcina",
    "înrădăcinez": "înrădăcina",
    "înrădăcineze": "înrădăcina",
    "înrădăcinezi": "înrădăcina",
    "neînrădăcinând": "înrădăcina",
    "neînrădăcinându": "înrădăcina",
    "nemaiînrădăcinând": "înrădăcina",
    "nemaiînrădăcinându": "înrădăcina",
    "înrădăcinarea": "înrădăcinare",
    "înrădăcinareo": "înrădăcinare",
    "înrădăcinări": "înrădăcinare",
    "înrădăcinării": "înrădăcinare",
    "înrădăcinările": "înrădăcinare",
    "înrădăcinărilor": "înrădăcinare",
    "înrădăcinata": "înrădăcinat",
    "înrădăcinată": "înrădăcinat",
    "înrădăcinate": "înrădăcinat",
    "înrădăcinatei": "înrădăcinat",
    "înrădăcinatele": "înrădăcinat",
    "înrădăcinatelor": "înrădăcinat",
    "înrădăcinați": "înrădăcinat",
    "înrădăcinații": "înrădăcinat",
    "înrădăcinaților": "înrădăcinat",
    "înrădăcinatul": "înrădăcinat",
    "înrădăcinatului": "înrădăcinat",
    "înrăia": "înrăi",
    "înrăiai": "înrăi",
    "înrăiam": "înrăi",
    "înrăiască": "înrăi",
    "înrăiați": "înrăi",
    "înrăiau": "înrăi",
    "înrăiesc": "înrăi",
    "înrăiește": "înrăi",
    "înrăiești": "înrăi",
    "înrăii": "înrăi",
    "înrăim": "înrăi",
    "înrăind": "înrăi",
    "înrăindu": "înrăi",
    "înrăiră": "înrăi",
    "înrăirăm": "înrăi",
    "înrăirăți": "înrăi",
    "înrăise": "înrăi",
    "înrăisem": "înrăi",
    "înrăiseră": "înrăi",
    "înrăiserăm": "înrăi",
    "înrăiserăți": "înrăi",
    "înrăiseși": "înrăi",
    "înrăiși": "înrăi",
    "înrăit": "înrăi",
    "înrăiți": "înrăi",
    "înrăitu": "înrăi",
    "neînrăind": "înrăi",
    "neînrăindu": "înrăi",
    "nemaiînrăind": "înrăi",
    "nemaiînrăindu": "înrăi",
    "înrăita": "înrăit",
    "înrăită": "înrăit",
    "înrăite": "înrăit",
    "înrăitei": "înrăit",
    "înrăitele": "înrăit",
    "înrăitelor": "înrăit",
    "înrăiți": "înrăit",
    "înrăiții": "înrăit",
    "înrăiților": "înrăit",
    "înrăitul": "înrăit",
    "înrăitului": "înrăit",
    "înrămă": "înrăma",
    "înrămai": "înrăma",
    "înrămam": "înrăma",
    "înrămăm": "înrăma",
    "înrămând": "înrăma",
    "înrămându": "înrăma",
    "înrămară": "înrăma",
    "înrămarăm": "înrăma",
    "înrămarăți": "înrăma",
    "înrămase": "înrăma",
    "înrămasem": "înrăma",
    "înrămaseră": "înrăma",
    "înrămaserăm": "înrăma",
    "înrămaserăți": "înrăma",
    "înrămaseși": "înrăma",
    "înrămași": "înrăma",
    "înrămat": "înrăma",
    "înrămați": "înrăma",
    "înrămatu": "înrăma",
    "înrămau": "înrăma",
    "înrămează": "înrăma",
    "înrămez": "înrăma",
    "înrămeze": "înrăma",
    "înrămezi": "înrăma",
    "neînrămând": "înrăma",
    "neînrămându": "înrăma",
    "nemaiînrămând": "înrăma",
    "nemaiînrămându": "înrăma",
    "înrămată": "înrămat",
    "înrămate": "înrămat",
    "înrămați": "înrămat",
    "înrâurea": "înrâuri",
    "înrâureai": "înrâuri",
    "înrâuream": "înrâuri",
    "înrâurească": "înrâuri",
    "înrâureați": "înrâuri",
    "înrâureau": "înrâuri",
    "înrâuresc": "înrâuri",
    "înrâurește": "înrâuri",
    "înrâurești": "înrâuri",
    "înrâurii": "înrâuri",
    "înrâurim": "înrâuri",
    "înrâurind": "înrâuri",
    "înrâurindu": "înrâuri",
    "înrâuriră": "înrâuri",
    "înrâurirăm": "înrâuri",
    "înrâurirăți": "înrâuri",
    "înrâurise": "înrâuri",
    "înrâurisem": "înrâuri",
    "înrâuriseră": "înrâuri",
    "înrâuriserăm": "înrâuri",
    "înrâuriserăți": "înrâuri",
    "înrâuriseși": "înrâuri",
    "înrâuriși": "înrâuri",
    "înrâurit": "înrâuri",
    "înrâuriți": "înrâuri",
    "înrâuritu": "înrâuri",
    "neînrâurind": "înrâuri",
    "neînrâurindu": "înrâuri",
    "nemaiînrâurind": "înrâuri",
    "nemaiînrâurindu": "înrâuri",
    "înrâurirea": "înrâurire",
    "înrâuriri": "înrâurire",
    "înrâuririi": "înrâurire",
    "înrâuririle": "înrâurire",
    "înrâuririlor": "înrâurire",
    "înrâurită": "înrâurit",
    "înrâurite": "înrâurit",
    "înrâuriți": "înrâurit",
    "înrăutățea": "înrăutăți",
    "înrăutățeai": "înrăutăți",
    "înrăutățeam": "înrăutăți",
    "înrăutățească": "înrăutăți",
    "înrăutățeați": "înrăutăți",
    "înrăutățeau": "înrăutăți",
    "înrăutățesc": "înrăutăți",
    "înrăutățește": "înrăutăți",
    "înrăutățești": "înrăutăți",
    "înrăutății": "înrăutăți",
    "înrăutățim": "înrăutăți",
    "înrăutățind": "înrăutăți",
    "înrăutățindu": "înrăutăți",
    "înrăutățiră": "înrăutăți",
    "înrăutățirăm": "înrăutăți",
    "înrăutățirăți": "înrăutăți",
    "înrăutățise": "înrăutăți",
    "înrăutățisem": "înrăutăți",
    "înrăutățiseră": "înrăutăți",
    "înrăutățiserăm": "înrăutăți",
    "înrăutățiserăți": "înrăutăți",
    "înrăutățiseși": "înrăutăți",
    "înrăutățiși": "înrăutăți",
    "înrăutățit": "înrăutăți",
    "înrăutățiți": "înrăutăți",
    "înrăutățitu": "înrăutăți",
    "neînrăutățind": "înrăutăți",
    "neînrăutățindu": "înrăutăți",
    "nemaiînrăutățind": "înrăutăți",
    "nemaiînrăutățindu": "înrăutăți",
    "înrăutățită": "înrăutățit",
    "înrăutățite": "înrăutățit",
    "înrăutățiți": "înrăutățit",
    "înregimentă": "înregimenta",
    "înregimentai": "înregimenta",
    "înregimentam": "înregimenta",
    "înregimentăm": "înregimenta",
    "înregimentând": "înregimenta",
    "înregimentându": "înregimenta",
    "înregimentară": "înregimenta",
    "înregimentarăm": "înregimenta",
    "înregimentarăți": "înregimenta",
    "înregimentase": "înregimenta",
    "înregimentasem": "înregimenta",
    "înregimentaseră": "înregimenta",
    "înregimentaserăm": "înregimenta",
    "înregimentaserăți": "înregimenta",
    "înregimentaseși": "înregimenta",
    "înregimentași": "înregimenta",
    "înregimentat": "înregimenta",
    "înregimentați": "înregimenta",
    "înregimentatu": "înregimenta",
    "înregimentau": "înregimenta",
    "înregimentează": "înregimenta",
    "înregimentez": "înregimenta",
    "înregimenteze": "înregimenta",
    "înregimentezi": "înregimenta",
    "neînregimentând": "înregimenta",
    "neînregimentându": "înregimenta",
    "nemaiînregimentând": "înregimenta",
    "nemaiînregimentându": "înregimenta",
    "înregimentarea": "înregimentare",
    "înregimentareo": "înregimentare",
    "înregimentări": "înregimentare",
    "înregimentării": "înregimentare",
    "înregimentările": "înregimentare",
    "înregimentărilor": "înregimentare",
    "înregimentată": "înregimentat",
    "înregimentate": "înregimentat",
    "înregimentați": "înregimentat",
    "înregistră": "înregistra",
    "înregistrai": "înregistra",
    "înregistram": "înregistra",
    "înregistrăm": "înregistra",
    "înregistrând": "înregistra",
    "înregistrându": "înregistra",
    "înregistrară": "înregistra",
    "înregistrarăm": "înregistra",
    "înregistrarăți": "înregistra",
    "înregistrase": "înregistra",
    "înregistrasem": "înregistra",
    "înregistraseră": "înregistra",
    "înregistraserăm": "înregistra",
    "înregistraserăți": "înregistra",
    "înregistraseși": "înregistra",
    "înregistrași": "înregistra",
    "înregistrat": "înregistra",
    "înregistrați": "înregistra",
    "înregistratu": "înregistra",
    "înregistrau": "înregistra",
    "înregistrează": "înregistra",
    "înregistrez": "înregistra",
    "înregistreze": "înregistra",
    "înregistrezi": "înregistra",
    "neînregistrând": "înregistra",
    "neînregistrându": "înregistra",
    "nemaiînregistrând": "înregistra",
    "nemaiînregistrându": "înregistra",
    "înregistrarea": "înregistrare",
    "înregistrări": "înregistrare",
    "înregistrării": "înregistrare",
    "înregistrările": "înregistrare",
    "înregistrărilor": "înregistrare",
    "înregistrată": "înregistrat",
    "înregistrate": "înregistrat",
    "înregistrați": "înregistrat",
    "înrobea": "înrobi",
    "înrobeai": "înrobi",
    "înrobeam": "înrobi",
    "înrobească": "înrobi",
    "înrobeați": "înrobi",
    "înrobeau": "înrobi",
    "înrobesc": "înrobi",
    "înrobește": "înrobi",
    "înrobești": "înrobi",
    "înrobii": "înrobi",
    "înrobim": "înrobi",
    "înrobind": "înrobi",
    "înrobindu": "înrobi",
    "înrobiră": "înrobi",
    "înrobirăm": "înrobi",
    "înrobirăți": "înrobi",
    "înrobise": "înrobi",
    "înrobisem": "înrobi",
    "înrobiseră": "înrobi",
    "înrobiserăm": "înrobi",
    "înrobiserăți": "înrobi",
    "înrobiseși": "înrobi",
    "înrobiși": "înrobi",
    "înrobit": "înrobi",
    "înrobiți": "înrobi",
    "înrobitu": "înrobi",
    "neînrobind": "înrobi",
    "neînrobindu": "înrobi",
    "nemaiînrobind": "înrobi",
    "nemaiînrobindu": "înrobi",
    "înrobită": "înrobit",
    "înrobite": "înrobit",
    "înrobiți": "înrobit",
    "înrolă": "înrola",
    "înrolai": "înrola",
    "înrolam": "înrola",
    "înrolăm": "înrola",
    "înrolând": "înrola",
    "înrolându": "înrola",
    "înrolară": "înrola",
    "înrolarăm": "înrola",
    "înrolarăți": "înrola",
    "înrolase": "înrola",
    "înrolasem": "înrola",
    "înrolaseră": "înrola",
    "înrolaserăm": "înrola",
    "înrolaserăți": "înrola",
    "înrolaseși": "înrola",
    "înrolași": "înrola",
    "înrolat": "înrola",
    "înrolați": "înrola",
    "înrolatu": "înrola",
    "înrolau": "înrola",
    "înrolează": "înrola",
    "înrolez": "înrola",
    "înroleze": "înrola",
    "înrolezi": "înrola",
    "neînrolând": "înrola",
    "neînrolându": "înrola",
    "nemaiînrolând": "înrola",
    "nemaiînrolându": "înrola",
    "înrolată": "înrolat",
    "înrolate": "înrolat",
    "înrolați": "înrolat",
    "înroșea": "înroși",
    "înroșeai": "înroși",
    "înroșeam": "înroși",
    "înroșească": "înroși",
    "înroșeați": "înroși",
    "înroșeau": "înroși",
    "înroșesc": "înroși",
    "înroșește": "înroși",
    "înroșești": "înroși",
    "înroșii": "înroși",
    "înroșim": "înroși",
    "înroșind": "înroși",
    "înroșindu": "înroși",
    "înroșiră": "înroși",
    "înroșirăm": "înroși",
    "înroșirăți": "înroși",
    "înroșise": "înroși",
    "înroșisem": "înroși",
    "înroșiseră": "înroși",
    "înroșiserăm": "înroși",
    "înroșiserăți": "înroși",
    "înroșiseși": "înroși",
    "înroșiși": "înroși",
    "înroșit": "înroși",
    "înroșiți": "înroși",
    "înroșitu": "înroși",
    "neînroșind": "înroși",
    "neînroșindu": "înroși",
    "nemaiînroșind": "înroși",
    "nemaiînroșindu": "înroși",
    "înroșită": "înroșit",
    "înroșite": "înroșit",
    "înroșiți": "înroșit",
    "înroură": "înroura",
    "înrourând": "înroura",
    "înrourându": "înroura",
    "înrourase": "înroura",
    "înrourat": "înroura",
    "înrouratu": "înroura",
    "înrourează": "înroura",
    "înroureze": "înroura",
    "neînrourând": "înroura",
    "neînrourându": "înroura",
    "nemaiînrourând": "înroura",
    "nemaiînrourându": "înroura",
    "înrourata": "înrourat",
    "înrourată": "înrourat",
    "înrourate": "înrourat",
    "înrouratei": "înrourat",
    "înrouratele": "înrourat",
    "înrouratelor": "înrourat",
    "înrourați": "înrourat",
    "înrourații": "înrourat",
    "înrouraților": "înrourat",
    "înrouratul": "înrourat",
    "înrouratului": "înrourat",
    "înrudea": "înrudi",
    "înrudeai": "înrudi",
    "înrudeam": "înrudi",
    "înrudească": "înrudi",
    "înrudeați": "înrudi",
    "înrudeau": "înrudi",
    "înrudesc": "înrudi",
    "înrudește": "înrudi",
    "înrudești": "înrudi",
    "înrudii": "înrudi",
    "înrudim": "înrudi",
    "înrudind": "înrudi",
    "înrudindu": "înrudi",
    "înrudiră": "înrudi",
    "înrudirăm": "înrudi",
    "înrudirăți": "înrudi",
    "înrudise": "înrudi",
    "înrudisem": "înrudi",
    "înrudiseră": "înrudi",
    "înrudiserăm": "înrudi",
    "înrudiserăți": "înrudi",
    "înrudiseși": "înrudi",
    "înrudiși": "înrudi",
    "înrudit": "înrudi",
    "înrudiți": "înrudi",
    "înruditu": "înrudi",
    "neînrudind": "înrudi",
    "neînrudindu": "înrudi",
    "nemaiînrudind": "înrudi",
    "nemaiînrudindu": "înrudi",
    "înrudirea": "înrudire",
    "înrudiri": "înrudire",
    "înrudirii": "înrudire",
    "înrudirile": "înrudire",
    "înrudirilor": "înrudire",
    "înrudita": "înrudit",
    "înrudită": "înrudit",
    "înrudite": "înrudit",
    "înruditei": "înrudit",
    "înruditele": "înrudit",
    "înruditelor": "înrudit",
    "înrudiți": "înrudit",
    "înrudiții": "înrudit",
    "înrudiților": "înrudit",
    "înruditul": "înrudit",
    "înruditului": "înrudit",
    "inși": "ins",
    "inșii": "ins",
    "inșilor": "ins",
    "insul": "ins",
    "insului": "ins",
    "însăilă": "însăila",
    "însăilai": "însăila",
    "însăilam": "însăila",
    "însăilăm": "însăila",
    "însăilând": "însăila",
    "însăilându": "însăila",
    "însăilară": "însăila",
    "însăilarăm": "însăila",
    "însăilarăți": "însăila",
    "însăilase": "însăila",
    "însăilasem": "însăila",
    "însăilaseră": "însăila",
    "însăilaserăm": "însăila",
    "însăilaserăți": "însăila",
    "însăilaseși": "însăila",
    "însăilași": "însăila",
    "însăilat": "însăila",
    "însăilați": "însăila",
    "însăilatu": "însăila",
    "însăilau": "însăila",
    "însăilează": "însăila",
    "însăilez": "însăila",
    "însăileze": "însăila",
    "însăilezi": "însăila",
    "neînsăilând": "însăila",
    "neînsăilându": "însăila",
    "nemaiînsăilând": "însăila",
    "nemaiînsăilându": "însăila",
    "însăilată": "însăilat",
    "însăilate": "însăilat",
    "însăilați": "însăilat",
    "insalubra": "insalubru",
    "insalubră": "insalubru",
    "insalubre": "insalubru",
    "insalubrei": "insalubru",
    "insalubrele": "insalubru",
    "insalubrelor": "insalubru",
    "insalubri": "insalubru",
    "insalubrii": "insalubru",
    "insalubrilor": "insalubru",
    "insalubrul": "insalubru",
    "insalubrului": "insalubru",
    "însămânță": "însămânța",
    "însămânțai": "însămânța",
    "însămânțam": "însămânța",
    "însămânțăm": "însămânța",
    "însămânțând": "însămânța",
    "însămânțându": "însămânța",
    "însămânțară": "însămânța",
    "însămânțarăm": "însămânța",
    "însămânțarăți": "însămânța",
    "însămânțase": "însămânța",
    "însămânțasem": "însămânța",
    "însămânțaseră": "însămânța",
    "însămânțaserăm": "însămânța",
    "însămânțaserăți": "însămânța",
    "însămânțaseși": "însămânța",
    "însămânțași": "însămânța",
    "însămânțat": "însămânța",
    "însămânțați": "însămânța",
    "însămânțatu": "însămânța",
    "însămânțau": "însămânța",
    "însămânțează": "însămânța",
    "însămânțez": "însămânța",
    "însămânțeze": "însămânța",
    "însămânțezi": "însămânța",
    "neînsămânțând": "însămânța",
    "neînsămânțându": "însămânța",
    "nemaiînsămânțând": "însămânța",
    "nemaiînsămânțându": "însămânța",
    "însămânțarea": "însămânțare",
    "însămânțări": "însămânțare",
    "însămânțării": "însămânțare",
    "însămânțările": "însămânțare",
    "însămânțărilor": "însămânțare",
    "însămânțată": "însămânțat",
    "însămânțate": "însămânțat",
    "însămânțați": "însămânțat",
    "însănătoșea": "însănătoși",
    "însănătoșeai": "însănătoși",
    "însănătoșeam": "însănătoși",
    "însănătoșească": "însănătoși",
    "însănătoșeați": "însănătoși",
    "însănătoșeau": "însănătoși",
    "însănătoșesc": "însănătoși",
    "însănătoșește": "însănătoși",
    "însănătoșești": "însănătoși",
    "însănătoșii": "însănătoși",
    "însănătoșim": "însănătoși",
    "însănătoșind": "însănătoși",
    "însănătoșindu": "însănătoși",
    "însănătoșiră": "însănătoși",
    "însănătoșirăm": "însănătoși",
    "însănătoșirăți": "însănătoși",
    "însănătoșise": "însănătoși",
    "însănătoșisem": "însănătoși",
    "însănătoșiseră": "însănătoși",
    "însănătoșiserăm": "însănătoși",
    "însănătoșiserăți": "însănătoși",
    "însănătoșiseși": "însănătoși",
    "însănătoșiși": "însănătoși",
    "însănătoșit": "însănătoși",
    "însănătoșiți": "însănătoși",
    "însănătoșitu": "însănătoși",
    "neînsănătoșind": "însănătoși",
    "neînsănătoșindu": "însănătoși",
    "nemaiînsănătoșind": "însănătoși",
    "nemaiînsănătoșindu": "însănătoși",
    "însănătoșirea": "însănătoșire",
    "însănătoșiri": "însănătoșire",
    "însănătoșirii": "însănătoșire",
    "însănătoșirile": "însănătoșire",
    "însănătoșirilor": "însănătoșire",
    "însănătoșită": "însănătoșit",
    "însănătoșite": "însănătoșit",
    "însănătoșiți": "însănătoșit",
    "însângerata": "însângerat",
    "însângerată": "însângerat",
    "însângerate": "însângerat",
    "însângeratei": "însângerat",
    "însângeratele": "însângerat",
    "însângeratelor": "însângerat",
    "însângerați": "însângerat",
    "însângerații": "însângerat",
    "însângeraților": "însângerat",
    "însângeratul": "însângerat",
    "însângeratului": "însângerat",
    "însărcină": "însărcina",
    "însărcinai": "însărcina",
    "însărcinam": "însărcina",
    "însărcinăm": "însărcina",
    "însărcinând": "însărcina",
    "însărcinându": "însărcina",
    "însărcinară": "însărcina",
    "însărcinarăm": "însărcina",
    "însărcinarăți": "însărcina",
    "însărcinase": "însărcina",
    "însărcinasem": "însărcina",
    "însărcinaseră": "însărcina",
    "însărcinaserăm": "însărcina",
    "însărcinaserăți": "însărcina",
    "însărcinaseși": "însărcina",
    "însărcinași": "însărcina",
    "însărcinat": "însărcina",
    "însărcinați": "însărcina",
    "însărcinatu": "însărcina",
    "însărcinau": "însărcina",
    "însărcinează": "însărcina",
    "însărcinez": "însărcina",
    "însărcineze": "însărcina",
    "însărcinezi": "însărcina",
    "neînsărcinând": "însărcina",
    "neînsărcinându": "însărcina",
    "nemaiînsărcinând": "însărcina",
    "nemaiînsărcinându": "însărcina",
    "însărcinată": "însărcinat",
    "însărcinate": "însărcinat",
    "însărcinați": "însărcinat",
    "însărcinata": "însărcinată",
    "însărcinate": "însărcinată",
    "însărcinatei": "însărcinată",
    "însărcinatele": "însărcinată",
    "însărcinatelor": "însărcinată",
    "insatisfacția": "insatisfacție",
    "insatisfacției": "insatisfacție",
    "insatisfacții": "insatisfacție",
    "insatisfacțiile": "insatisfacție",
    "insatisfacțiilor": "insatisfacție",
    "înscăună": "înscăuna",
    "înscăunai": "înscăuna",
    "înscăunam": "înscăuna",
    "înscăunăm": "înscăuna",
    "înscăunând": "înscăuna",
    "înscăunându": "înscăuna",
    "înscăunară": "înscăuna",
    "înscăunarăm": "înscăuna",
    "înscăunarăți": "înscăuna",
    "înscăunase": "înscăuna",
    "înscăunasem": "înscăuna",
    "înscăunaseră": "înscăuna",
    "înscăunaserăm": "înscăuna",
    "înscăunaserăți": "înscăuna",
    "înscăunaseși": "înscăuna",
    "înscăunași": "înscăuna",
    "înscăunat": "înscăuna",
    "înscăunați": "înscăuna",
    "înscăunatu": "înscăuna",
    "înscăunau": "înscăuna",
    "înscăunează": "înscăuna",
    "înscăunez": "înscăuna",
    "înscăuneze": "înscăuna",
    "înscăunezi": "înscăuna",
    "neînscăunând": "înscăuna",
    "neînscăunându": "înscăuna",
    "nemaiînscăunând": "înscăuna",
    "nemaiînscăunându": "înscăuna",
    "înscăunată": "înscăunat",
    "înscăunate": "înscăunat",
    "înscăunați": "înscăunat",
    "înscenarea": "înscenare",
    "înscenareo": "înscenare",
    "înscenări": "înscenare",
    "înscenării": "înscenare",
    "înscenările": "înscenare",
    "înscenărilor": "înscenare",
    "înscria": "înscrie",
    "înscriai": "înscrie",
    "înscriam": "înscrie",
    "înscriați": "înscrie",
    "înscriau": "înscrie",
    "înscriem": "înscrie",
    "înscrieți": "înscrie",
    "înscrii": "înscrie",
    "înscriind": "înscrie",
    "înscriindu": "înscrie",
    "înscris": "înscrie",
    "înscrise": "înscrie",
    "înscrisei": "înscrie",
    "înscriseră": "înscrie",
    "înscriserăm": "înscrie",
    "înscriserăți": "înscrie",
    "înscrisese": "înscrie",
    "înscrisesem": "înscrie",
    "înscriseseră": "înscrie",
    "înscriseserăm": "înscrie",
    "înscriseserăți": "înscrie",
    "înscriseseși": "înscrie",
    "înscriseși": "înscrie",
    "înscrisu": "înscrie",
    "înscriu": "înscrie",
    "înscrierea": "înscriere",
    "înscrieri": "înscriere",
    "înscrierii": "înscriere",
    "înscrierile": "înscriere",
    "înscrierilor": "înscriere",
    "inscripția": "inscripție",
    "inscripției": "inscripție",
    "inscripții": "inscripție",
    "inscripțiile": "inscripție",
    "inscripțiilor": "inscripție",
    "inscripționata": "inscripționat",
    "inscripționată": "inscripționat",
    "inscripționate": "inscripționat",
    "inscripționatei": "inscripționat",
    "inscripționatele": "inscripționat",
    "inscripționatelor": "inscripționat",
    "inscripționați": "inscripționat",
    "inscripționații": "inscripționat",
    "inscripționaților": "inscripționat",
    "inscripționato": "inscripționat",
    "inscripționatul": "inscripționat",
    "inscripționatule": "inscripționat",
    "inscripționatului": "inscripționat",
    "înscrisa": "înscris",
    "înscrisă": "înscris",
    "înscrise": "înscris",
    "înscrisei": "înscris",
    "înscrisele": "înscris",
    "înscriselor": "înscris",
    "înscriși": "înscris",
    "înscrișii": "înscris",
    "înscrișilor": "înscris",
    "înscriso": "înscris",
    "înscrisul": "înscris",
    "înscrisule": "înscris",
    "înscrisului": "înscris",
    "înscrisuri": "înscris",
    "înscrisurile": "înscris",
    "înscrisurilor": "înscris",
    "insculpă": "insculpa",
    "insculpai": "insculpa",
    "insculpam": "insculpa",
    "insculpăm": "insculpa",
    "insculpând": "insculpa",
    "insculpându": "insculpa",
    "insculpară": "insculpa",
    "insculparăm": "insculpa",
    "insculparăți": "insculpa",
    "insculpase": "insculpa",
    "insculpasem": "insculpa",
    "insculpaseră": "insculpa",
    "insculpaserăm": "insculpa",
    "insculpaserăți": "insculpa",
    "insculpaseși": "insculpa",
    "insculpași": "insculpa",
    "insculpat": "insculpa",
    "insculpați": "insculpa",
    "insculpatu": "insculpa",
    "insculpau": "insculpa",
    "insculpează": "insculpa",
    "insculpez": "insculpa",
    "insculpeze": "insculpa",
    "insculpezi": "insculpa",
    "neinsculpând": "insculpa",
    "neinsculpându": "insculpa",
    "nemaiinsculpând": "insculpa",
    "nemaiinsculpându": "insculpa",
    "insculpată": "insculpat",
    "insculpate": "insculpat",
    "insculpați": "insculpat",
    "insecta": "insectă",
    "insecte": "insectă",
    "insectei": "insectă",
    "insectele": "insectă",
    "insectelor": "insectă",
    "insecto": "insectă",
    "insecticide": "insecticid",
    "insecticidele": "insecticid",
    "insecticidelor": "insecticid",
    "insecticidul": "insecticid",
    "insecticidului": "insecticid",
    "înșală": "înșela",
    "înșeală": "înșela",
    "înșel": "înșela",
    "înșelă": "înșela",
    "înșelai": "înșela",
    "înșelam": "înșela",
    "înșelăm": "înșela",
    "înșelând": "înșela",
    "înșelându": "înșela",
    "înșelară": "înșela",
    "înșelarăm": "înșela",
    "înșelarăți": "înșela",
    "înșelase": "înșela",
    "înșelasem": "înșela",
    "înșelaseră": "înșela",
    "înșelaserăm": "înșela",
    "înșelaserăți": "înșela",
    "înșelaseși": "înșela",
    "înșelași": "înșela",
    "înșelat": "înșela",
    "înșelați": "înșela",
    "înșelatu": "înșela",
    "înșelau": "înșela",
    "înșele": "înșela",
    "înșeli": "înșela",
    "neînșelând": "înșela",
    "neînșelându": "înșela",
    "nemaiînșelând": "înșela",
    "nemaiînșelându": "înșela",
    "înșelăciunea": "înșelăciune",
    "înșelăciuni": "înșelăciune",
    "înșelăciunii": "înșelăciune",
    "înșelăciunile": "înșelăciune",
    "înșelăciunilor": "înșelăciune",
    "înșelarea": "înșelare",
    "înșelări": "înșelare",
    "înșelării": "înșelare",
    "înșelările": "înșelare",
    "înșelărilor": "înșelare",
    "înșelată": "înșelat",
    "înșelate": "înșelat",
    "înșelați": "înșelat",
    "înșelătoare": "înșelător",
    "înșelătoarea": "înșelător",
    "înșelătoarei": "înșelător",
    "înșelătoarele": "înșelător",
    "înșelătoarelor": "înșelător",
    "înșelători": "înșelător",
    "înșelătorii": "înșelător",
    "înșelătorilor": "înșelător",
    "înșelătorul": "înșelător",
    "înșelătorului": "înșelător",
    "înșelătoria": "înșelătorie",
    "înșelătoriei": "înșelătorie",
    "înșelătorii": "înșelătorie",
    "înșelătoriile": "înșelătorie",
    "înșelătoriilor": "înșelătorie",
    "însemne": "însemn",
    "însemnele": "însemn",
    "însemnelor": "însemn",
    "însemnul": "însemn",
    "însemnule": "însemn",
    "însemnului": "însemn",
    "înseamnă": "însemna",
    "însemn": "însemna",
    "însemnă": "însemna",
    "însemnai": "însemna",
    "însemnam": "însemna",
    "însemnăm": "însemna",
    "însemnând": "însemna",
    "însemnându": "însemna",
    "însemnară": "însemna",
    "însemnarăm": "însemna",
    "însemnarăți": "însemna",
    "însemnase": "însemna",
    "însemnasem": "însemna",
    "însemnaseră": "însemna",
    "însemnaserăm": "însemna",
    "însemnaserăți": "însemna",
    "însemnaseși": "însemna",
    "însemnași": "însemna",
    "însemnat": "însemna",
    "însemnați": "însemna",
    "însemnatu": "însemna",
    "însemnau": "însemna",
    "însemne": "însemna",
    "însemnează": "însemna",
    "însemnez": "însemna",
    "însemneze": "însemna",
    "însemnezi": "însemna",
    "însemni": "însemna",
    "însemnarea": "însemnare",
    "însemnări": "însemnare",
    "însemnării": "însemnare",
    "însemnările": "însemnare",
    "însemnărilor": "însemnare",
    "însemnata": "însemnat",
    "însemnată": "însemnat",
    "însemnate": "însemnat",
    "însemnatei": "însemnat",
    "însemnatele": "însemnat",
    "însemnatelor": "însemnat",
    "însemnați": "însemnat",
    "însemnații": "însemnat",
    "însemnaților": "însemnat",
    "însemnatul": "însemnat",
    "însemnatului": "însemnat",
    "însemnătatea": "însemnătate",
    "însemnătăți": "însemnătate",
    "însemnătății": "însemnătate",
    "insensibila": "insensibil",
    "insensibilă": "insensibil",
    "insensibile": "insensibil",
    "insensibilei": "insensibil",
    "insensibilele": "insensibil",
    "insensibilelor": "insensibil",
    "insensibili": "insensibil",
    "insensibilii": "insensibil",
    "insensibililor": "insensibil",
    "insensibilul": "insensibil",
    "insensibilului": "insensibil",
    "insensibilitatea": "insensibilitate",
    "insensibilitateo": "insensibilitate",
    "insensibilități": "insensibilitate",
    "insensibilității": "insensibilitate",
    "insensibilitățile": "insensibilitate",
    "insensibilităților": "insensibilitate",
    "insensibiliză": "insensibiliza",
    "insensibilizai": "insensibiliza",
    "insensibilizam": "insensibiliza",
    "insensibilizăm": "insensibiliza",
    "insensibilizând": "insensibiliza",
    "insensibilizându": "insensibiliza",
    "insensibilizară": "insensibiliza",
    "insensibilizarăm": "insensibiliza",
    "insensibilizarăți": "insensibiliza",
    "insensibilizase": "insensibiliza",
    "insensibilizasem": "insensibiliza",
    "insensibilizaseră": "insensibiliza",
    "insensibilizaserăm": "insensibiliza",
    "insensibilizaserăți": "insensibiliza",
    "insensibilizaseși": "insensibiliza",
    "insensibilizași": "insensibiliza",
    "insensibilizat": "insensibiliza",
    "insensibilizați": "insensibiliza",
    "insensibilizatu": "insensibiliza",
    "insensibilizau": "insensibiliza",
    "insensibilizează": "insensibiliza",
    "insensibilizez": "insensibiliza",
    "insensibilizeze": "insensibiliza",
    "insensibilizezi": "insensibiliza",
    "neinsensibilizând": "insensibiliza",
    "neinsensibilizându": "insensibiliza",
    "nemaiinsensibilizând": "insensibiliza",
    "nemaiinsensibilizându": "insensibiliza",
    "insensibilizată": "insensibilizat",
    "insensibilizate": "insensibilizat",
    "insensibilizați": "insensibilizat",
    "inseparabila": "inseparabil",
    "inseparabilă": "inseparabil",
    "inseparabile": "inseparabil",
    "inseparabilei": "inseparabil",
    "inseparabilele": "inseparabil",
    "inseparabilelor": "inseparabil",
    "inseparabili": "inseparabil",
    "inseparabilii": "inseparabil",
    "inseparabililor": "inseparabil",
    "inseparabilul": "inseparabil",
    "inseparabilului": "inseparabil",
    "înșeptita": "înșeptit",
    "înșeptită": "înșeptit",
    "înșeptite": "înșeptit",
    "înșeptitei": "înșeptit",
    "înșeptitele": "înșeptit",
    "înșeptitelor": "înșeptit",
    "înșeptiți": "înșeptit",
    "înșeptiții": "înșeptit",
    "înșeptiților": "înșeptit",
    "înșeptitul": "înșeptit",
    "înșeptitului": "înșeptit",
    "inseră": "insera",
    "inserai": "insera",
    "inseram": "insera",
    "inserăm": "insera",
    "inserând": "insera",
    "inserându": "insera",
    "inserară": "insera",
    "inserarăm": "insera",
    "inserarăți": "insera",
    "inserase": "insera",
    "inserasem": "insera",
    "inseraseră": "insera",
    "inseraserăm": "insera",
    "inseraserăți": "insera",
    "inseraseși": "insera",
    "inserași": "insera",
    "inserat": "insera",
    "inserați": "insera",
    "inseratu": "insera",
    "inserau": "insera",
    "inserează": "insera",
    "inserez": "insera",
    "insereze": "insera",
    "inserezi": "insera",
    "neinserând": "insera",
    "neinserându": "insera",
    "nemaiinserând": "insera",
    "nemaiinserându": "insera",
    "înserând": "însera",
    "înserându": "însera",
    "înserat": "însera",
    "înseratu": "însera",
    "înserează": "însera",
    "înserarea": "înserare",
    "înserări": "înserare",
    "înserării": "înserare",
    "înserările": "înserare",
    "înserărilor": "înserare",
    "inserată": "inserat",
    "inserate": "inserat",
    "inserați": "inserat",
    "înserată": "înserat",
    "înserate": "înserat",
    "înserați": "înserat",
    "înșesita": "înșesit",
    "înșesită": "înșesit",
    "înșesite": "înșesit",
    "înșesitei": "înșesit",
    "înșesitele": "înșesit",
    "înșesitelor": "înșesit",
    "înșesiți": "înșesit",
    "înșesiții": "înșesit",
    "înșesiților": "înșesit",
    "înșesitul": "înșesit",
    "înșesitului": "înșesit",
    "insesizabila": "insesizabil",
    "insesizabilă": "insesizabil",
    "insesizabile": "insesizabil",
    "insesizabilei": "insesizabil",
    "insesizabilele": "insesizabil",
    "insesizabilelor": "insesizabil",
    "insesizabili": "insesizabil",
    "insesizabilii": "insesizabil",
    "insesizabililor": "insesizabil",
    "insesizabilul": "insesizabil",
    "insesizabilului": "insesizabil",
    "însetata": "însetat",
    "însetată": "însetat",
    "însetate": "însetat",
    "însetatei": "însetat",
    "însetatele": "însetat",
    "însetatelor": "însetat",
    "însetați": "însetat",
    "însetații": "însetat",
    "însetaților": "însetat",
    "însetatul": "însetat",
    "însetatului": "însetat",
    "înșeuă": "înșeua",
    "înșeuai": "înșeua",
    "înșeuam": "înșeua",
    "înșeuăm": "înșeua",
    "înșeuând": "înșeua",
    "înșeuându": "înșeua",
    "înșeuară": "înșeua",
    "înșeuarăm": "înșeua",
    "înșeuarăți": "înșeua",
    "înșeuase": "înșeua",
    "înșeuasem": "înșeua",
    "înșeuaseră": "înșeua",
    "înșeuaserăm": "înșeua",
    "înșeuaserăți": "înșeua",
    "înșeuaseși": "înșeua",
    "înșeuași": "înșeua",
    "înșeuat": "înșeua",
    "înșeuați": "înșeua",
    "înșeuatu": "înșeua",
    "înșeuau": "înșeua",
    "înșeuează": "înșeua",
    "înșeuez": "înșeua",
    "înșeueze": "înșeua",
    "înșeuezi": "înșeua",
    "neînșeuând": "înșeua",
    "neînșeuându": "înșeua",
    "nemaiînșeuând": "înșeua",
    "nemaiînșeuându": "înșeua",
    "înșeuată": "înșeuat",
    "înșeuate": "înșeuat",
    "înșeuați": "înșeuat",
    "înșfac": "înșfăca",
    "înșfacă": "înșfăca",
    "înșfăcă": "înșfăca",
    "înșfăcai": "înșfăca",
    "înșfăcam": "înșfăca",
    "înșfăcăm": "înșfăca",
    "înșfăcând": "înșfăca",
    "înșfăcându": "înșfăca",
    "înșfăcară": "înșfăca",
    "înșfăcarăm": "înșfăca",
    "înșfăcarăți": "înșfăca",
    "înșfăcase": "înșfăca",
    "înșfăcasem": "înșfăca",
    "înșfăcaseră": "înșfăca",
    "înșfăcaserăm": "înșfăca",
    "înșfăcaserăți": "înșfăca",
    "înșfăcaseși": "înșfăca",
    "înșfăcași": "înșfăca",
    "înșfăcat": "înșfăca",
    "înșfăcați": "înșfăca",
    "înșfăcatu": "înșfăca",
    "înșfăcau": "înșfăca",
    "înșface": "înșfăca",
    "înșfaci": "înșfăca",
    "neînșfăcând": "înșfăca",
    "neînșfăcându": "înșfăca",
    "nemaiînșfăcând": "înșfăca",
    "nemaiînșfăcându": "înșfăca",
    "înșfăcată": "înșfăcat",
    "înșfăcate": "înșfăcat",
    "înșfăcați": "înșfăcat",
    "insigna": "insignă",
    "insigne": "insignă",
    "insignei": "insignă",
    "insignele": "insignă",
    "insignelor": "insignă",
    "insigno": "insignă",
    "insignifianta": "insignifiant",
    "insignifiantă": "insignifiant",
    "insignifiante": "insignifiant",
    "insignifiantei": "insignifiant",
    "insignifiantele": "insignifiant",
    "insignifiantelor": "insignifiant",
    "insignifianți": "insignifiant",
    "insignifianții": "insignifiant",
    "insignifianților": "insignifiant",
    "insignifiantul": "insignifiant",
    "insignifiantului": "insignifiant",
    "însingurarea": "însingurare",
    "însingurareo": "însingurare",
    "însingurări": "însingurare",
    "însingurării": "însingurare",
    "însingurările": "însingurare",
    "însingurărilor": "însingurare",
    "însingurata": "însingurat",
    "însingurată": "însingurat",
    "însingurate": "însingurat",
    "însinguratei": "însingurat",
    "însinguratele": "însingurat",
    "însinguratelor": "însingurat",
    "însingurați": "însingurat",
    "însingurații": "însingurat",
    "însinguraților": "însingurat",
    "însingurato": "însingurat",
    "însinguratul": "însingurat",
    "însinguratule": "însingurat",
    "însinguratului": "însingurat",
    "insinuă": "insinua",
    "insinuai": "insinua",
    "insinuam": "insinua",
    "insinuăm": "insinua",
    "insinuând": "insinua",
    "insinuându": "insinua",
    "insinuară": "insinua",
    "insinuarăm": "insinua",
    "insinuarăți": "insinua",
    "insinuase": "insinua",
    "insinuasem": "insinua",
    "insinuaseră": "insinua",
    "insinuaserăm": "insinua",
    "insinuaserăți": "insinua",
    "insinuaseși": "insinua",
    "insinuași": "insinua",
    "insinuat": "insinua",
    "insinuați": "insinua",
    "insinuatu": "insinua",
    "insinuau": "insinua",
    "insinuează": "insinua",
    "insinuez": "insinua",
    "insinueze": "insinua",
    "insinuezi": "insinua",
    "neinsinuând": "insinua",
    "neinsinuându": "insinua",
    "nemaiinsinuând": "insinua",
    "nemaiinsinuându": "insinua",
    "insinuanta": "insinuant",
    "insinuantă": "insinuant",
    "insinuante": "insinuant",
    "insinuantei": "insinuant",
    "insinuantele": "insinuant",
    "insinuantelor": "insinuant",
    "insinuanți": "insinuant",
    "insinuanții": "insinuant",
    "insinuanților": "insinuant",
    "insinuantul": "insinuant",
    "insinuantului": "insinuant",
    "insinuată": "insinuat",
    "insinuate": "insinuat",
    "insinuați": "insinuat",
    "insipida": "insipid",
    "insipidă": "insipid",
    "insipide": "insipid",
    "insipidei": "insipid",
    "insipidele": "insipid",
    "insipidelor": "insipid",
    "insipidul": "insipid",
    "insipidului": "insipid",
    "insipizi": "insipid",
    "insipizii": "insipid",
    "insipizilor": "insipid",
    "înșir": "înșira",
    "înșiră": "înșira",
    "înșirai": "înșira",
    "înșiram": "înșira",
    "înșirăm": "înșira",
    "înșirând": "înșira",
    "înșirându": "înșira",
    "înșirară": "înșira",
    "înșirarăm": "înșira",
    "înșirarăți": "înșira",
    "înșirase": "înșira",
    "înșirasem": "înșira",
    "înșiraseră": "înșira",
    "înșiraserăm": "înșira",
    "înșiraserăți": "înșira",
    "înșiraseși": "înșira",
    "înșirași": "înșira",
    "înșirat": "înșira",
    "înșirați": "înșira",
    "înșiratu": "înșira",
    "înșirau": "înșira",
    "înșire": "înșira",
    "înșiri": "înșira",
    "neînșirând": "înșira",
    "neînșirându": "înșira",
    "nemaiînșirând": "înșira",
    "nemaiînșirându": "înșira",
    "înșirată": "înșirat",
    "înșirate": "înșirat",
    "înșirați": "înșirat",
    "înșiruia": "înșirui",
    "înșiruiai": "înșirui",
    "înșiruiam": "înșirui",
    "înșiruiați": "înșirui",
    "înșiruiau": "înșirui",
    "înșiruie": "înșirui",
    "înșiruii": "înșirui",
    "înșiruim": "înșirui",
    "înșiruind": "înșirui",
    "înșiruindu": "înșirui",
    "înșiruiră": "înșirui",
    "înșiruirăm": "înșirui",
    "înșiruirăți": "înșirui",
    "înșiruise": "înșirui",
    "înșiruisem": "înșirui",
    "înșiruiseră": "înșirui",
    "înșiruiserăm": "înșirui",
    "înșiruiserăți": "înșirui",
    "înșiruiseși": "înșirui",
    "înșiruiși": "înșirui",
    "înșiruit": "înșirui",
    "înșiruiți": "înșirui",
    "înșiruitu": "înșirui",
    "neînșiruind": "înșirui",
    "neînșiruindu": "înșirui",
    "nemaiînșiruind": "înșirui",
    "nemaiînșiruindu": "înșirui",
    "înșiruită": "înșiruit",
    "înșiruite": "înșiruit",
    "înșiruiți": "înșiruit",
    "insist": "insista",
    "insistă": "insista",
    "insistai": "insista",
    "insistam": "insista",
    "insistăm": "insista",
    "insistând": "insista",
    "insistându": "insista",
    "insistară": "insista",
    "insistarăm": "insista",
    "insistarăți": "insista",
    "insistase": "insista",
    "insistasem": "insista",
    "insistaseră": "insista",
    "insistaserăm": "insista",
    "insistaserăți": "insista",
    "insistaseși": "insista",
    "insistași": "insista",
    "insistat": "insista",
    "insistați": "insista",
    "insistatu": "insista",
    "insistau": "insista",
    "insiste": "insista",
    "insiști": "insista",
    "neinsistând": "insista",
    "neinsistându": "insista",
    "nemaiinsistând": "insista",
    "nemaiinsistându": "insista",
    "insistată": "insistat",
    "insistate": "insistat",
    "insistați": "insistat",
    "insistenta": "insistent",
    "insistentă": "insistent",
    "insistente": "insistent",
    "insistentei": "insistent",
    "insistentele": "insistent",
    "insistentelor": "insistent",
    "insistenți": "insistent",
    "insistenții": "insistent",
    "insistenților": "insistent",
    "insistentul": "insistent",
    "insistentului": "insistent",
    "insistența": "insistență",
    "insistențe": "insistență",
    "insistenței": "insistență",
    "insistențele": "insistență",
    "insistențelor": "insistență",
    "insistențo": "insistență",
    "insolenta": "insolent",
    "insolentă": "insolent",
    "insolente": "insolent",
    "insolentei": "insolent",
    "insolentele": "insolent",
    "insolentelor": "insolent",
    "insolenți": "insolent",
    "insolenții": "insolent",
    "insolenților": "insolent",
    "insolentul": "insolent",
    "insolentului": "insolent",
    "insolita": "insolit",
    "insolită": "insolit",
    "insolite": "insolit",
    "insolitei": "insolit",
    "insolitele": "insolit",
    "insolitelor": "insolit",
    "insoliți": "insolit",
    "insoliții": "insolit",
    "insoliților": "insolit",
    "insolito": "insolit",
    "insolitul": "insolit",
    "insolitule": "insolit",
    "insolitului": "insolit",
    "insolubila": "insolubil",
    "insolubilă": "insolubil",
    "insolubile": "insolubil",
    "insolubilei": "insolubil",
    "insolubilele": "insolubil",
    "insolubilelor": "insolubil",
    "insolubili": "insolubil",
    "insolubilii": "insolubil",
    "insolubililor": "insolubil",
    "insolubilul": "insolubil",
    "insolubilului": "insolubil",
    "insolubiliză": "insolubiliza",
    "insolubilizai": "insolubiliza",
    "insolubilizam": "insolubiliza",
    "insolubilizăm": "insolubiliza",
    "insolubilizând": "insolubiliza",
    "insolubilizându": "insolubiliza",
    "insolubilizară": "insolubiliza",
    "insolubilizarăm": "insolubiliza",
    "insolubilizarăți": "insolubiliza",
    "insolubilizase": "insolubiliza",
    "insolubilizasem": "insolubiliza",
    "insolubilizaseră": "insolubiliza",
    "insolubilizaserăm": "insolubiliza",
    "insolubilizaserăți": "insolubiliza",
    "insolubilizaseși": "insolubiliza",
    "insolubilizași": "insolubiliza",
    "insolubilizat": "insolubiliza",
    "insolubilizați": "insolubiliza",
    "insolubilizatu": "insolubiliza",
    "insolubilizau": "insolubiliza",
    "insolubilizează": "insolubiliza",
    "insolubilizez": "insolubiliza",
    "insolubilizeze": "insolubiliza",
    "insolubilizezi": "insolubiliza",
    "neinsolubilizând": "insolubiliza",
    "neinsolubilizându": "insolubiliza",
    "nemaiinsolubilizând": "insolubiliza",
    "nemaiinsolubilizându": "insolubiliza",
    "insolubilizată": "insolubilizat",
    "insolubilizate": "insolubilizat",
    "insolubilizați": "insolubilizat",
    "insomnia": "insomnie",
    "insomniei": "insomnie",
    "insomnii": "insomnie",
    "insomniile": "insomnie",
    "insomniilor": "insomnie",
    "insomnio": "insomnie",
    "înșomoltocea": "înșomoltoci",
    "înșomoltoceai": "înșomoltoci",
    "înșomoltoceam": "înșomoltoci",
    "înșomoltocească": "înșomoltoci",
    "înșomoltoceați": "înșomoltoci",
    "înșomoltoceau": "înșomoltoci",
    "înșomoltocesc": "înșomoltoci",
    "înșomoltocește": "înșomoltoci",
    "înșomoltocești": "înșomoltoci",
    "înșomoltocii": "înșomoltoci",
    "înșomoltocim": "înșomoltoci",
    "înșomoltocind": "înșomoltoci",
    "înșomoltocindu": "înșomoltoci",
    "înșomoltociră": "înșomoltoci",
    "înșomoltocirăm": "înșomoltoci",
    "înșomoltocirăți": "înșomoltoci",
    "înșomoltocise": "înșomoltoci",
    "înșomoltocisem": "înșomoltoci",
    "înșomoltociseră": "înșomoltoci",
    "înșomoltociserăm": "înșomoltoci",
    "înșomoltociserăți": "înșomoltoci",
    "înșomoltociseși": "înșomoltoci",
    "înșomoltociși": "înșomoltoci",
    "înșomoltocit": "înșomoltoci",
    "înșomoltociți": "înșomoltoci",
    "înșomoltocitu": "înșomoltoci",
    "neînșomoltocind": "înșomoltoci",
    "neînșomoltocindu": "înșomoltoci",
    "nemaiînșomoltocind": "înșomoltoci",
    "nemaiînșomoltocindu": "înșomoltoci",
    "înșomoltocită": "înșomoltocit",
    "înșomoltocite": "înșomoltocit",
    "înșomoltociți": "înșomoltocit",
    "însorita": "însorit",
    "însorită": "însorit",
    "însorite": "însorit",
    "însoritei": "însorit",
    "însoritele": "însorit",
    "însoritelor": "însorit",
    "însoriți": "însorit",
    "însoriții": "însorit",
    "însoriților": "însorit",
    "însoritul": "însorit",
    "însoritului": "însorit",
    "însoțea": "însoți",
    "însoțeai": "însoți",
    "însoțeam": "însoți",
    "însoțească": "însoți",
    "însoțeați": "însoți",
    "însoțeau": "însoți",
    "însoțesc": "însoți",
    "însoțește": "însoți",
    "însoțești": "însoți",
    "însoții": "însoți",
    "însoțim": "însoți",
    "însoțind": "însoți",
    "însoțindu": "însoți",
    "însoțiră": "însoți",
    "însoțirăm": "însoți",
    "însoțirăți": "însoți",
    "însoțise": "însoți",
    "însoțisem": "însoți",
    "însoțiseră": "însoți",
    "însoțiserăm": "însoți",
    "însoțiserăți": "însoți",
    "însoțiseși": "însoți",
    "însoțiși": "însoți",
    "însoțit": "însoți",
    "însoțiți": "însoți",
    "însoțitu": "însoți",
    "însoțirea": "însoțire",
    "însoțiri": "însoțire",
    "însoțirii": "însoțire",
    "însoțirile": "însoțire",
    "însoțirilor": "însoțire",
    "însoțită": "însoțit",
    "însoțite": "însoțit",
    "însoțiți": "însoțit",
    "însoțitoarea": "însoțitoare",
    "însoțitoarei": "însoțitoare",
    "însoțitoarele": "însoțitoare",
    "însoțitoarelor": "însoțitoare",
    "însoțitoare": "însoțitor",
    "însoțitoarea": "însoțitor",
    "însoțitoarei": "însoțitor",
    "însoțitoarele": "însoțitor",
    "însoțitoarelor": "însoțitor",
    "însoțitori": "însoțitor",
    "însoțitorii": "însoțitor",
    "însoțitorilor": "însoțitor",
    "însoțitorul": "însoțitor",
    "însoțitorului": "însoțitor",
    "înspăimânt": "înspăimânta",
    "înspăimântă": "înspăimânta",
    "înspăimântai": "înspăimânta",
    "înspăimântam": "înspăimânta",
    "înspăimântăm": "înspăimânta",
    "înspăimântând": "înspăimânta",
    "înspăimântându": "înspăimânta",
    "înspăimântară": "înspăimânta",
    "înspăimântarăm": "înspăimânta",
    "înspăimântarăți": "înspăimânta",
    "înspăimântase": "înspăimânta",
    "înspăimântasem": "înspăimânta",
    "înspăimântaseră": "înspăimânta",
    "înspăimântaserăm": "înspăimânta",
    "înspăimântaserăți": "înspăimânta",
    "înspăimântaseși": "înspăimânta",
    "înspăimânțaseși": "înspăimânta",
    "înspăimântași": "înspăimânta",
    "înspăimânțași": "înspăimânta",
    "înspăimântat": "înspăimânta",
    "înspăimântați": "înspăimânta",
    "înspăimântatu": "înspăimânta",
    "înspăimântau": "înspăimânta",
    "înspăimânte": "înspăimânta",
    "înspăimânți": "înspăimânta",
    "înspăimântarea": "înspăimântare",
    "înspăimântareo": "înspăimântare",
    "înspăimântări": "înspăimântare",
    "înspăimântării": "înspăimântare",
    "înspăimântările": "înspăimântare",
    "înspăimântărilor": "înspăimântare",
    "înspăimântata": "înspăimântat",
    "înspăimântată": "înspăimântat",
    "înspăimântate": "înspăimântat",
    "înspăimântatei": "înspăimântat",
    "înspăimântatele": "înspăimântat",
    "înspăimântatelor": "înspăimântat",
    "înspăimântați": "înspăimântat",
    "înspăimântații": "înspăimântat",
    "înspăimântaților": "înspăimântat",
    "înspăimântatul": "înspăimântat",
    "înspăimântatului": "înspăimântat",
    "înspăimântătoare": "înspăimântător",
    "înspăimântătoarea": "înspăimântător",
    "înspăimântătoarei": "înspăimântător",
    "înspăimântătoarele": "înspăimântător",
    "înspăimântătoarelor": "înspăimântător",
    "înspăimântători": "înspăimântător",
    "înspăimântătorii": "înspăimântător",
    "înspăimântătorilor": "înspăimântător",
    "înspăimântătorul": "înspăimântător",
    "înspăimântătorului": "înspăimântător",
    "inspectă": "inspecta",
    "inspectai": "inspecta",
    "inspectam": "inspecta",
    "inspectăm": "inspecta",
    "inspectând": "inspecta",
    "inspectându": "inspecta",
    "inspectară": "inspecta",
    "inspectarăm": "inspecta",
    "inspectarăți": "inspecta",
    "inspectase": "inspecta",
    "inspectasem": "inspecta",
    "inspectaseră": "inspecta",
    "inspectaserăm": "inspecta",
    "inspectaserăți": "inspecta",
    "inspectaseși": "inspecta",
    "inspectași": "inspecta",
    "inspectat": "inspecta",
    "inspectați": "inspecta",
    "inspectatu": "inspecta",
    "inspectau": "inspecta",
    "inspectează": "inspecta",
    "inspectez": "inspecta",
    "inspecteze": "inspecta",
    "inspectezi": "inspecta",
    "neinspectând": "inspecta",
    "neinspectându": "inspecta",
    "nemaiinspectând": "inspecta",
    "nemaiinspectându": "inspecta",
    "inspectarea": "inspectare",
    "inspectareo": "inspectare",
    "inspectări": "inspectare",
    "inspectării": "inspectare",
    "inspectările": "inspectare",
    "inspectărilor": "inspectare",
    "inspectată": "inspectat",
    "inspectate": "inspectat",
    "inspectați": "inspectat",
    "inspecția": "inspecție",
    "inspecției": "inspecție",
    "inspecții": "inspecție",
    "inspecțiile": "inspecție",
    "inspecțiilor": "inspecție",
    "inspecțio": "inspecție",
    "inspectori": "inspector",
    "inspectorii": "inspector",
    "inspectorilor": "inspector",
    "inspectorul": "inspector",
    "inspectorule": "inspector",
    "inspectorului": "inspector",
    "inspectorate": "inspectorat",
    "inspectoratele": "inspectorat",
    "inspectoratelor": "inspectorat",
    "inspectoratul": "inspectorat",
    "inspectoratule": "inspectorat",
    "inspectoratului": "inspectorat",
    "IGP": "Inspectoratul_General_al_Poliției",
    "înspicata": "înspicat",
    "înspicată": "înspicat",
    "înspicate": "înspicat",
    "înspicatei": "înspicat",
    "înspicatele": "înspicat",
    "înspicatelor": "înspicat",
    "înspicați": "înspicat",
    "înspicații": "înspicat",
    "înspicaților": "înspicat",
    "înspicato": "înspicat",
    "înspicatul": "înspicat",
    "înspicatule": "înspicat",
    "înspicatului": "înspicat",
    "inspir": "inspira",
    "inspiră": "inspira",
    "inspirai": "inspira",
    "inspiram": "inspira",
    "inspirăm": "inspira",
    "inspirând": "inspira",
    "inspirându": "inspira",
    "inspirară": "inspira",
    "inspirarăm": "inspira",
    "inspirarăți": "inspira",
    "inspirase": "inspira",
    "inspirasem": "inspira",
    "inspiraseră": "inspira",
    "inspiraserăm": "inspira",
    "inspiraserăți": "inspira",
    "inspiraseși": "inspira",
    "inspirași": "inspira",
    "inspirat": "inspira",
    "inspirați": "inspira",
    "inspiratu": "inspira",
    "inspirau": "inspira",
    "inspire": "inspira",
    "inspiri": "inspira",
    "neinspirând": "inspira",
    "neinspirându": "inspira",
    "nemaiinspirând": "inspira",
    "nemaiinspirându": "inspira",
    "inspirarea": "inspirare",
    "inspirareo": "inspirare",
    "inspirări": "inspirare",
    "inspirării": "inspirare",
    "inspirările": "inspirare",
    "inspirărilor": "inspirare",
    "inspirata": "inspirat",
    "inspirată": "inspirat",
    "inspirate": "inspirat",
    "inspiratei": "inspirat",
    "inspiratele": "inspirat",
    "inspiratelor": "inspirat",
    "inspirați": "inspirat",
    "inspirații": "inspirat",
    "inspiraților": "inspirat",
    "inspiratul": "inspirat",
    "inspiratului": "inspirat",
    "inspirația": "inspirație",
    "inspirației": "inspirație",
    "inspirații": "inspirație",
    "inspirațiile": "inspirație",
    "inspirațiilor": "inspirație",
    "înspumă": "înspuma",
    "înspumai": "înspuma",
    "înspumam": "înspuma",
    "înspumăm": "înspuma",
    "înspumând": "înspuma",
    "înspumându": "înspuma",
    "înspumară": "înspuma",
    "înspumarăm": "înspuma",
    "înspumarăți": "înspuma",
    "înspumase": "înspuma",
    "înspumasem": "înspuma",
    "înspumaseră": "înspuma",
    "înspumaserăm": "înspuma",
    "înspumaserăți": "înspuma",
    "înspumaseși": "înspuma",
    "înspumași": "înspuma",
    "înspumat": "înspuma",
    "înspumați": "înspuma",
    "înspumatu": "înspuma",
    "înspumau": "înspuma",
    "înspumează": "înspuma",
    "înspumez": "înspuma",
    "înspumeze": "înspuma",
    "înspumezi": "înspuma",
    "neînspumând": "înspuma",
    "neînspumându": "înspuma",
    "nemaiînspumând": "înspuma",
    "nemaiînspumându": "înspuma",
    "înspumata": "înspumat",
    "înspumată": "înspumat",
    "înspumate": "înspumat",
    "înspumatei": "înspumat",
    "înspumatele": "înspumat",
    "înspumatelor": "înspumat",
    "înspumați": "înspumat",
    "înspumații": "înspumat",
    "înspumaților": "înspumat",
    "înspumatul": "înspumat",
    "înspumatului": "înspumat",
    "înspumeg": "înspumega",
    "înspumegă": "înspumega",
    "înspumegai": "înspumega",
    "înspumegam": "înspumega",
    "înspumegăm": "înspumega",
    "înspumegând": "înspumega",
    "înspumegându": "înspumega",
    "înspumegară": "înspumega",
    "înspumegarăm": "înspumega",
    "înspumegarăți": "înspumega",
    "înspumegase": "înspumega",
    "înspumegasem": "înspumega",
    "înspumegaseră": "înspumega",
    "înspumegaserăm": "înspumega",
    "înspumegaserăți": "înspumega",
    "înspumegaseși": "înspumega",
    "înspumegași": "înspumega",
    "înspumegat": "înspumega",
    "înspumegați": "înspumega",
    "înspumegatu": "înspumega",
    "înspumegau": "înspumega",
    "înspumege": "înspumega",
    "înspumegi": "înspumega",
    "neînspumegând": "înspumega",
    "neînspumegându": "înspumega",
    "nemaiînspumegând": "înspumega",
    "nemaiînspumegându": "înspumega",
    "înspumegată": "înspumegat",
    "înspumegate": "înspumegat",
    "înspumegați": "înspumegat",
    "instabila": "instabil",
    "instabilă": "instabil",
    "instabile": "instabil",
    "instabilei": "instabil",
    "instabilele": "instabil",
    "instabilelor": "instabil",
    "instabili": "instabil",
    "instabilii": "instabil",
    "instabililor": "instabil",
    "instabilul": "instabil",
    "instabilului": "instabil",
    "instabilitatea": "instabilitate",
    "instabilități": "instabilitate",
    "instabilității": "instabilitate",
    "instabilitățile": "instabilitate",
    "instabilităților": "instabilitate",
    "instală": "instala",
    "instalai": "instala",
    "instalam": "instala",
    "instalăm": "instala",
    "instalând": "instala",
    "instalându": "instala",
    "instalară": "instala",
    "instalarăm": "instala",
    "instalarăți": "instala",
    "instalase": "instala",
    "instalasem": "instala",
    "instalaseră": "instala",
    "instalaserăm": "instala",
    "instalaserăți": "instala",
    "instalaseși": "instala",
    "instalași": "instala",
    "instalat": "instala",
    "instalați": "instala",
    "instalatu": "instala",
    "instalau": "instala",
    "instalează": "instala",
    "instalez": "instala",
    "instaleze": "instala",
    "instalezi": "instala",
    "neinstalând": "instala",
    "neinstalându": "instala",
    "nemaiinstalând": "instala",
    "nemaiinstalându": "instala",
    "instalarea": "instalare",
    "instalareo": "instalare",
    "instalări": "instalare",
    "instalării": "instalare",
    "instalările": "instalare",
    "instalărilor": "instalare",
    "instalată": "instalat",
    "instalate": "instalat",
    "instalați": "instalat",
    "instalația": "instalație",
    "instalației": "instalație",
    "instalații": "instalație",
    "instalațiile": "instalație",
    "instalațiilor": "instalație",
    "instalatori": "instalator",
    "instalatorii": "instalator",
    "instalatorilor": "instalator",
    "instalatorul": "instalator",
    "instalatorului": "instalator",
    "Instanbulul": "Instanbul",
    "Instanbulului": "Instanbul",
    "instanța": "instanță",
    "instanțe": "instanță",
    "instanței": "instanță",
    "instanțele": "instanță",
    "instanțelor": "instanță",
    "instantanee": "instantaneu",
    "instantaneea": "instantaneu",
    "instantaneele": "instantaneu",
    "instantaneelor": "instantaneu",
    "instantanei": "instantaneu",
    "instantaneii": "instantaneu",
    "instantaneilor": "instantaneu",
    "instantaneul": "instantaneu",
    "instantaneului": "instantaneu",
    "înstăpânea": "înstăpâni",
    "înstăpâneai": "înstăpâni",
    "înstăpâneam": "înstăpâni",
    "înstăpânească": "înstăpâni",
    "înstăpâneați": "înstăpâni",
    "înstăpâneau": "înstăpâni",
    "înstăpânesc": "înstăpâni",
    "înstăpânește": "înstăpâni",
    "înstăpânești": "înstăpâni",
    "înstăpânii": "înstăpâni",
    "înstăpânim": "înstăpâni",
    "înstăpânind": "înstăpâni",
    "înstăpânindu": "înstăpâni",
    "înstăpâniră": "înstăpâni",
    "înstăpânirăm": "înstăpâni",
    "înstăpânirăți": "înstăpâni",
    "înstăpânise": "înstăpâni",
    "înstăpânisem": "înstăpâni",
    "înstăpâniseră": "înstăpâni",
    "înstăpâniserăm": "înstăpâni",
    "înstăpâniserăți": "înstăpâni",
    "înstăpâniseși": "înstăpâni",
    "înstăpâniși": "înstăpâni",
    "înstăpânit": "înstăpâni",
    "înstăpâniți": "înstăpâni",
    "înstăpânitu": "înstăpâni",
    "neînstăpânind": "înstăpâni",
    "neînstăpânindu": "înstăpâni",
    "nemaiînstăpânind": "înstăpâni",
    "nemaiînstăpânindu": "înstăpâni",
    "înstăpânirea": "înstăpânire",
    "înstăpâniri": "înstăpânire",
    "înstăpânirii": "înstăpânire",
    "înstăpânirile": "înstăpânire",
    "înstăpânirilor": "înstăpânire",
    "înstăpânită": "înstăpânit",
    "înstăpânite": "înstăpânit",
    "înstăpâniți": "înstăpânit",
    "înstărea": "înstări",
    "înstăreai": "înstări",
    "înstăream": "înstări",
    "înstărească": "înstări",
    "înstăreați": "înstări",
    "înstăreau": "înstări",
    "înstăresc": "înstări",
    "înstărește": "înstări",
    "înstărești": "înstări",
    "înstării": "înstări",
    "înstărim": "înstări",
    "înstărind": "înstări",
    "înstărindu": "înstări",
    "înstăriră": "înstări",
    "înstărirăm": "înstări",
    "înstărirăți": "înstări",
    "înstărise": "înstări",
    "înstărisem": "înstări",
    "înstăriseră": "înstări",
    "înstăriserăm": "înstări",
    "înstăriserăți": "înstări",
    "înstăriseși": "înstări",
    "înstăriși": "înstări",
    "înstărit": "înstări",
    "înstăriți": "înstări",
    "înstăritu": "înstări",
    "neînstărind": "înstări",
    "neînstărindu": "înstări",
    "nemaiînstărind": "înstări",
    "nemaiînstărindu": "înstări",
    "înstărita": "înstărit",
    "înstărită": "înstărit",
    "înstărite": "înstărit",
    "înstăritei": "înstărit",
    "înstăritele": "înstărit",
    "înstăritelor": "înstărit",
    "înstăriți": "înstărit",
    "înstăriții": "înstărit",
    "înstăriților": "înstărit",
    "înstăritul": "înstărit",
    "înstăritului": "înstărit",
    "instaură": "instaura",
    "instaurai": "instaura",
    "instauram": "instaura",
    "instaurăm": "instaura",
    "instaurând": "instaura",
    "instaurându": "instaura",
    "instaurară": "instaura",
    "instaurarăm": "instaura",
    "instaurarăți": "instaura",
    "instaurase": "instaura",
    "instaurasem": "instaura",
    "instauraseră": "instaura",
    "instauraserăm": "instaura",
    "instauraserăți": "instaura",
    "instauraseși": "instaura",
    "instaurași": "instaura",
    "instaurat": "instaura",
    "instaurați": "instaura",
    "instauratu": "instaura",
    "instaurau": "instaura",
    "instaurează": "instaura",
    "instaurez": "instaura",
    "instaureze": "instaura",
    "instaurezi": "instaura",
    "neinstaurând": "instaura",
    "neinstaurându": "instaura",
    "nemaiinstaurând": "instaura",
    "nemaiinstaurându": "instaura",
    "instaurarea": "instaurare",
    "instaurări": "instaurare",
    "instaurării": "instaurare",
    "instaurările": "instaurare",
    "instaurărilor": "instaurare",
    "instaurată": "instaurat",
    "instaurate": "instaurat",
    "instaurați": "instaurat",
    "înstelă": "înstela",
    "înstelai": "înstela",
    "înstelam": "înstela",
    "înstelăm": "înstela",
    "înstelând": "înstela",
    "înstelându": "înstela",
    "înstelară": "înstela",
    "înstelarăm": "înstela",
    "înstelarăți": "înstela",
    "înstelase": "înstela",
    "înstelasem": "înstela",
    "înstelaseră": "înstela",
    "înstelaserăm": "înstela",
    "înstelaserăți": "înstela",
    "înstelaseși": "înstela",
    "înstelași": "înstela",
    "înstelat": "înstela",
    "înstelați": "înstela",
    "înstelatu": "înstela",
    "înstelau": "înstela",
    "înstelează": "înstela",
    "înstelez": "înstela",
    "însteleze": "înstela",
    "înstelezi": "înstela",
    "neînstelând": "înstela",
    "neînstelându": "înstela",
    "nemaiînstelând": "înstela",
    "nemaiînstelându": "înstela",
    "înstelata": "înstelat",
    "înstelată": "înstelat",
    "înstelate": "înstelat",
    "înstelatei": "înstelat",
    "înstelatele": "înstelat",
    "înstelatelor": "înstelat",
    "înstelați": "înstelat",
    "înstelații": "înstelat",
    "înstelaților": "înstelat",
    "înstelatul": "înstelat",
    "înstelatului": "înstelat",
    "instig": "instiga",
    "instigă": "instiga",
    "instigai": "instiga",
    "instigam": "instiga",
    "instigăm": "instiga",
    "instigând": "instiga",
    "instigându": "instiga",
    "instigară": "instiga",
    "instigarăm": "instiga",
    "instigarăți": "instiga",
    "instigase": "instiga",
    "instigasem": "instiga",
    "instigaseră": "instiga",
    "instigaserăm": "instiga",
    "instigaserăți": "instiga",
    "instigaseși": "instiga",
    "instigași": "instiga",
    "instigat": "instiga",
    "instigați": "instiga",
    "instigatu": "instiga",
    "instigau": "instiga",
    "instige": "instiga",
    "instigi": "instiga",
    "neinstigând": "instiga",
    "neinstigându": "instiga",
    "nemaiinstigând": "instiga",
    "nemaiinstigându": "instiga",
    "instigarea": "instigare",
    "instigări": "instigare",
    "instigării": "instigare",
    "instigările": "instigare",
    "instigărilor": "instigare",
    "instigată": "instigat",
    "instigate": "instigat",
    "instigați": "instigat",
    "instigatori": "instigator",
    "instigatorii": "instigator",
    "instigatorilor": "instigator",
    "instigatorul": "instigator",
    "instigatorului": "instigator",
    "înștiință": "înștiința",
    "înștiințai": "înștiința",
    "înștiințam": "înștiința",
    "înștiințăm": "înștiința",
    "înștiințând": "înștiința",
    "înștiințându": "înștiința",
    "înștiințară": "înștiința",
    "înștiințarăm": "înștiința",
    "înștiințarăți": "înștiința",
    "înștiințase": "înștiința",
    "înștiințasem": "înștiința",
    "înștiințaseră": "înștiința",
    "înștiințaserăm": "înștiința",
    "înștiințaserăți": "înștiința",
    "înștiințaseși": "înștiința",
    "înștiințași": "înștiința",
    "înștiințat": "înștiința",
    "înștiințați": "înștiința",
    "înștiințatu": "înștiința",
    "înștiințau": "înștiința",
    "înștiințează": "înștiința",
    "înștiințez": "înștiința",
    "înștiințeze": "înștiința",
    "înștiințezi": "înștiința",
    "neînștiințând": "înștiința",
    "neînștiințându": "înștiința",
    "nemaiînștiințând": "înștiința",
    "nemaiînștiințându": "înștiința",
    "înștiințarea": "înștiințare",
    "înștiințări": "înștiințare",
    "înștiințării": "înștiințare",
    "înștiințările": "înștiințare",
    "înștiințărilor": "înștiințare",
    "înștiințată": "înștiințat",
    "înștiințate": "înștiințat",
    "înștiințați": "înștiințat",
    "instilă": "instila",
    "instilai": "instila",
    "instilam": "instila",
    "instilăm": "instila",
    "instilând": "instila",
    "instilându": "instila",
    "instilară": "instila",
    "instilarăm": "instila",
    "instilarăți": "instila",
    "instilase": "instila",
    "instilasem": "instila",
    "instilaseră": "instila",
    "instilaserăm": "instila",
    "instilaserăți": "instila",
    "instilaseși": "instila",
    "instilași": "instila",
    "instilat": "instila",
    "instilați": "instila",
    "instilatu": "instila",
    "instilau": "instila",
    "instilează": "instila",
    "instilez": "instila",
    "instileze": "instila",
    "instilezi": "instila",
    "neinstilând": "instila",
    "neinstilându": "instila",
    "nemaiinstilând": "instila",
    "nemaiinstilându": "instila",
    "instilată": "instilat",
    "instilate": "instilat",
    "instilați": "instilat",
    "instincte": "instinct",
    "instinctele": "instinct",
    "instinctelor": "instinct",
    "instinctul": "instinct",
    "instinctului": "instinct",
    "instinctiva": "instinctiv",
    "instinctivă": "instinctiv",
    "instinctive": "instinctiv",
    "instinctivei": "instinctiv",
    "instinctivele": "instinctiv",
    "instinctivelor": "instinctiv",
    "instinctivi": "instinctiv",
    "instinctivii": "instinctiv",
    "instinctivilor": "instinctiv",
    "instinctivul": "instinctiv",
    "instinctivului": "instinctiv",
    "instinctuala": "instinctual",
    "instinctuală": "instinctual",
    "instinctuale": "instinctual",
    "instinctualei": "instinctual",
    "instinctualele": "instinctual",
    "instinctualelor": "instinctual",
    "instinctuali": "instinctual",
    "instinctualii": "instinctual",
    "instinctualilor": "instinctual",
    "instinctualul": "instinctual",
    "instinctualului": "instinctual",
    "instituia": "institui",
    "instituiai": "institui",
    "instituiam": "institui",
    "instituiați": "institui",
    "instituiau": "institui",
    "instituie": "institui",
    "instituii": "institui",
    "instituim": "institui",
    "instituind": "institui",
    "instituindu": "institui",
    "instituiră": "institui",
    "instituirăm": "institui",
    "instituirăți": "institui",
    "instituise": "institui",
    "instituisem": "institui",
    "instituiseră": "institui",
    "instituiserăm": "institui",
    "instituiserăți": "institui",
    "instituiseși": "institui",
    "instituiși": "institui",
    "instituit": "institui",
    "instituiți": "institui",
    "instituitu": "institui",
    "neinstituind": "institui",
    "neinstituindu": "institui",
    "nemaiinstituind": "institui",
    "nemaiinstituindu": "institui",
    "instituirea": "instituire",
    "instituiri": "instituire",
    "instituirii": "instituire",
    "instituirile": "instituire",
    "instituirilor": "instituire",
    "instituită": "instituit",
    "instituite": "instituit",
    "instituiți": "instituit",
    "inst.": "institut",
    "institute": "institut",
    "institutele": "institut",
    "institutelor": "institut",
    "institutul": "institut",
    "institutului": "institut",
    "instituția": "instituție",
    "instituției": "instituție",
    "instituții": "instituție",
    "instituțiile": "instituție",
    "instituțiilor": "instituție",
    "instituționala": "instituțional",
    "instituțională": "instituțional",
    "instituționale": "instituțional",
    "instituționalei": "instituțional",
    "instituționalele": "instituțional",
    "instituționalelor": "instituțional",
    "instituționali": "instituțional",
    "instituționalii": "instituțional",
    "instituționalilor": "instituțional",
    "instituționalul": "instituțional",
    "instituționalului": "instituțional",
    "instituționalizata": "instituționalizat",
    "instituționalizată": "instituționalizat",
    "instituționalizate": "instituționalizat",
    "instituționalizatei": "instituționalizat",
    "instituționalizatele": "instituționalizat",
    "instituționalizatelor": "instituționalizat",
    "instituționalizați": "instituționalizat",
    "instituționalizații": "instituționalizat",
    "instituționalizaților": "instituționalizat",
    "instituționalizatul": "instituționalizat",
    "instituționalizatului": "instituționalizat",
    "institutori": "institutor",
    "institutorii": "institutor",
    "institutorilor": "institutor",
    "institutorul": "institutor",
    "institutorului": "institutor",
    "înstrăină": "înstrăina",
    "înstrăinai": "înstrăina",
    "înstrăinam": "înstrăina",
    "înstrăinăm": "înstrăina",
    "înstrăinând": "înstrăina",
    "înstrăinându": "înstrăina",
    "înstrăinară": "înstrăina",
    "înstrăinarăm": "înstrăina",
    "înstrăinarăți": "înstrăina",
    "înstrăinase": "înstrăina",
    "înstrăinasem": "înstrăina",
    "înstrăinaseră": "înstrăina",
    "înstrăinaserăm": "înstrăina",
    "înstrăinaserăți": "înstrăina",
    "înstrăinaseși": "înstrăina",
    "înstrăinași": "înstrăina",
    "înstrăinat": "înstrăina",
    "înstrăinați": "înstrăina",
    "înstrăinatu": "înstrăina",
    "înstrăinau": "înstrăina",
    "înstrăinează": "înstrăina",
    "înstrăinez": "înstrăina",
    "înstrăineze": "înstrăina",
    "înstrăinezi": "înstrăina",
    "neînstrăinând": "înstrăina",
    "neînstrăinându": "înstrăina",
    "nemaiînstrăinând": "înstrăina",
    "nemaiînstrăinându": "înstrăina",
    "înstrăinată": "înstrăinat",
    "înstrăinate": "înstrăinat",
    "înstrăinați": "înstrăinat",
    "instructaje": "instructaj",
    "instructajele": "instructaj",
    "instructajelor": "instructaj",
    "instructajul": "instructaj",
    "instructajului": "instructaj",
    "instrucția": "instrucție",
    "instrucției": "instrucție",
    "instrucții": "instrucție",
    "instrucțiile": "instrucție",
    "instrucțiilor": "instrucție",
    "instrucțiunea": "instrucțiune",
    "instrucțiuni": "instrucțiune",
    "instrucțiunii": "instrucțiune",
    "instrucțiunile": "instrucțiune",
    "instrucțiunilor": "instrucțiune",
    "instructiva": "instructiv",
    "instructivă": "instructiv",
    "instructive": "instructiv",
    "instructivei": "instructiv",
    "instructivele": "instructiv",
    "instructivelor": "instructiv",
    "instructivi": "instructiv",
    "instructivii": "instructiv",
    "instructivilor": "instructiv",
    "instructivul": "instructiv",
    "instructivului": "instructiv",
    "instructoarea": "instructoare",
    "instructoarei": "instructoare",
    "instructoarele": "instructoare",
    "instructoarelor": "instructoare",
    "instructori": "instructor",
    "instructorii": "instructor",
    "instructorilor": "instructor",
    "instructorul": "instructor",
    "instructorului": "instructor",
    "instruia": "instrui",
    "instruiai": "instrui",
    "instruiam": "instrui",
    "instruiască": "instrui",
    "instruiați": "instrui",
    "instruiau": "instrui",
    "instruiesc": "instrui",
    "instruiește": "instrui",
    "instruiești": "instrui",
    "instruii": "instrui",
    "instruim": "instrui",
    "instruind": "instrui",
    "instruindu": "instrui",
    "instruiră": "instrui",
    "instruirăm": "instrui",
    "instruirăți": "instrui",
    "instruise": "instrui",
    "instruisem": "instrui",
    "instruiseră": "instrui",
    "instruiserăm": "instrui",
    "instruiserăți": "instrui",
    "instruiseși": "instrui",
    "instruiși": "instrui",
    "instruit": "instrui",
    "instruiți": "instrui",
    "instruitu": "instrui",
    "neinstruind": "instrui",
    "neinstruindu": "instrui",
    "nemaiinstruind": "instrui",
    "nemaiinstruindu": "instrui",
    "instruirea": "instruire",
    "instruireo": "instruire",
    "instruiri": "instruire",
    "instruirii": "instruire",
    "instruirile": "instruire",
    "instruirilor": "instruire",
    "instruita": "instruit",
    "instruită": "instruit",
    "instruite": "instruit",
    "instruitei": "instruit",
    "instruitele": "instruit",
    "instruitelor": "instruit",
    "instruiți": "instruit",
    "instruiții": "instruit",
    "instruiților": "instruit",
    "instruitul": "instruit",
    "instruitului": "instruit",
    "instrumente": "instrument",
    "instrumentele": "instrument",
    "instrumentelor": "instrument",
    "instrumentul": "instrument",
    "instrumentului": "instrument",
    "instrumentă": "instrumenta",
    "instrumentai": "instrumenta",
    "instrumentam": "instrumenta",
    "instrumentăm": "instrumenta",
    "instrumentând": "instrumenta",
    "instrumentându": "instrumenta",
    "instrumentară": "instrumenta",
    "instrumentarăm": "instrumenta",
    "instrumentarăți": "instrumenta",
    "instrumentase": "instrumenta",
    "instrumentasem": "instrumenta",
    "instrumentaseră": "instrumenta",
    "instrumentaserăm": "instrumenta",
    "instrumentaserăți": "instrumenta",
    "instrumentaseși": "instrumenta",
    "instrumentași": "instrumenta",
    "instrumentat": "instrumenta",
    "instrumentați": "instrumenta",
    "instrumentatu": "instrumenta",
    "instrumentau": "instrumenta",
    "instrumentează": "instrumenta",
    "instrumentez": "instrumenta",
    "instrumenteze": "instrumenta",
    "instrumentezi": "instrumenta",
    "neinstrumentând": "instrumenta",
    "neinstrumentându": "instrumenta",
    "nemaiinstrumentând": "instrumenta",
    "nemaiinstrumentându": "instrumenta",
    "instrumentată": "instrumentat",
    "instrumentate": "instrumentat",
    "instrumentați": "instrumentat",
    "instrumentiști": "instrumentist",
    "instrumentiștii": "instrumentist",
    "instrumentiștilor": "instrumentist",
    "instrumentistul": "instrumentist",
    "instrumentistului": "instrumentist",
    "înstrună": "înstruna",
    "înstrunai": "înstruna",
    "înstrunam": "înstruna",
    "înstrunăm": "înstruna",
    "înstrunând": "înstruna",
    "înstrunându": "înstruna",
    "înstrunară": "înstruna",
    "înstrunarăm": "înstruna",
    "înstrunarăți": "înstruna",
    "înstrunase": "înstruna",
    "înstrunasem": "înstruna",
    "înstrunaseră": "înstruna",
    "înstrunaserăm": "înstruna",
    "înstrunaserăți": "înstruna",
    "înstrunaseși": "înstruna",
    "înstrunași": "înstruna",
    "înstrunat": "înstruna",
    "înstrunați": "înstruna",
    "înstrunatu": "înstruna",
    "înstrunau": "înstruna",
    "înstrunează": "înstruna",
    "înstrunez": "înstruna",
    "înstruneze": "înstruna",
    "înstrunezi": "înstruna",
    "neînstrunând": "înstruna",
    "neînstrunându": "înstruna",
    "nemaiînstrunând": "înstruna",
    "nemaiînstrunându": "înstruna",
    "înstrunată": "înstrunat",
    "înstrunate": "înstrunat",
    "înstrunați": "înstrunat",
    "insubordonarea": "insubordonare",
    "insubordonareo": "insubordonare",
    "insubordonări": "insubordonare",
    "insubordonării": "insubordonare",
    "insubordonările": "insubordonare",
    "insubordonărilor": "insubordonare",
    "insubordonata": "insubordonat",
    "insubordonată": "insubordonat",
    "insubordonate": "insubordonat",
    "insubordonatei": "insubordonat",
    "insubordonatele": "insubordonat",
    "insubordonatelor": "insubordonat",
    "insubordonați": "insubordonat",
    "insubordonații": "insubordonat",
    "insubordonaților": "insubordonat",
    "insubordonato": "insubordonat",
    "insubordonatul": "insubordonat",
    "insubordonatule": "insubordonat",
    "insubordonatului": "insubordonat",
    "insuccese": "insucces",
    "insuccesele": "insucces",
    "insucceselor": "insucces",
    "insuccesul": "insucces",
    "insuccesului": "insucces",
    "insuficienta": "insuficient",
    "insuficientă": "insuficient",
    "insuficiente": "insuficient",
    "insuficientei": "insuficient",
    "insuficientele": "insuficient",
    "insuficientelor": "insuficient",
    "insuficienți": "insuficient",
    "insuficienții": "insuficient",
    "insuficienților": "insuficient",
    "insuficientul": "insuficient",
    "insuficientului": "insuficient",
    "insuficiența": "insuficiență",
    "insuficiențe": "insuficiență",
    "insuficienței": "insuficiență",
    "insuficiențele": "insuficiență",
    "insuficiențelor": "insuficiență",
    "insuflă": "insufla",
    "insuflai": "insufla",
    "insuflam": "insufla",
    "insuflăm": "insufla",
    "insuflând": "insufla",
    "insuflându": "insufla",
    "insuflară": "insufla",
    "insuflarăm": "insufla",
    "insuflarăți": "insufla",
    "insuflase": "insufla",
    "insuflasem": "insufla",
    "insuflaseră": "insufla",
    "insuflaserăm": "insufla",
    "insuflaserăți": "insufla",
    "insuflaseși": "insufla",
    "insuflași": "insufla",
    "insuflat": "insufla",
    "insuflați": "insufla",
    "insuflatu": "insufla",
    "insuflau": "insufla",
    "insufle": "insufla",
    "insufli": "insufla",
    "insuflu": "insufla",
    "neinsuflând": "insufla",
    "neinsuflându": "insufla",
    "nemaiinsuflând": "insufla",
    "nemaiinsuflându": "insufla",
    "insuflarea": "insuflare",
    "insuflări": "insuflare",
    "insuflării": "insuflare",
    "insuflările": "insuflare",
    "insuflărilor": "insuflare",
    "insuflată": "insuflat",
    "insuflate": "insuflat",
    "insuflați": "insuflat",
    "însuflețea": "însufleți",
    "însuflețeai": "însufleți",
    "însuflețeam": "însufleți",
    "însuflețească": "însufleți",
    "însuflețeați": "însufleți",
    "însuflețeau": "însufleți",
    "însuflețesc": "însufleți",
    "însuflețește": "însufleți",
    "însuflețești": "însufleți",
    "însufleții": "însufleți",
    "însuflețim": "însufleți",
    "însuflețind": "însufleți",
    "însuflețindu": "însufleți",
    "însuflețiră": "însufleți",
    "însuflețirăm": "însufleți",
    "însuflețirăți": "însufleți",
    "însuflețise": "însufleți",
    "însuflețisem": "însufleți",
    "însuflețiseră": "însufleți",
    "însuflețiserăm": "însufleți",
    "însuflețiserăți": "însufleți",
    "însuflețiseși": "însufleți",
    "însuflețiși": "însufleți",
    "însuflețit": "însufleți",
    "însuflețiți": "însufleți",
    "însuflețitu": "însufleți",
    "neînsuflețind": "însufleți",
    "neînsuflețindu": "însufleți",
    "nemaiînsuflețind": "însufleți",
    "nemaiînsuflețindu": "însufleți",
    "însuflețirea": "însuflețire",
    "însuflețiri": "însuflețire",
    "însuflețirii": "însuflețire",
    "însuflețirile": "însuflețire",
    "însuflețirilor": "însuflețire",
    "însuflețita": "însuflețit",
    "însuflețită": "însuflețit",
    "însuflețite": "însuflețit",
    "însuflețitei": "însuflețit",
    "însuflețitele": "însuflețit",
    "însuflețitelor": "însuflețit",
    "însuflețiți": "însuflețit",
    "însuflețiții": "însuflețit",
    "însuflețiților": "însuflețit",
    "însuflețitul": "însuflețit",
    "însuflețitului": "însuflețit",
    "însa": "însul",
    "însele": "însul",
    "înșii": "însul",
    "insula": "insulă",
    "insule": "insulă",
    "insulei": "insulă",
    "insulele": "insulă",
    "insulelor": "insulă",
    "insulara": "insular",
    "insulară": "insular",
    "insulare": "insular",
    "insularei": "insular",
    "insularele": "insular",
    "insularelor": "insular",
    "insulari": "insular",
    "insularii": "insular",
    "insularilor": "insular",
    "insularo": "insular",
    "insularul": "insular",
    "insularule": "insular",
    "insularului": "insular",
    "ile": "insulele",
    "insult": "insulta",
    "insultă": "insulta",
    "insultai": "insulta",
    "insultam": "insulta",
    "insultăm": "insulta",
    "insultând": "insulta",
    "insultându": "insulta",
    "insultară": "insulta",
    "insultarăm": "insulta",
    "insultarăți": "insulta",
    "insultase": "insulta",
    "insultasem": "insulta",
    "insultaseră": "insulta",
    "insultaserăm": "insulta",
    "insultaserăți": "insulta",
    "insultaseși": "insulta",
    "insultași": "insulta",
    "insultat": "insulta",
    "insultați": "insulta",
    "insultatu": "insulta",
    "insultau": "insulta",
    "insulte": "insulta",
    "insulți": "insulta",
    "neinsultând": "insulta",
    "neinsultându": "insulta",
    "nemaiinsultând": "insulta",
    "nemaiinsultându": "insulta",
    "insulta": "insultă",
    "insulte": "insultă",
    "insultei": "insultă",
    "insultele": "insultă",
    "insultelor": "insultă",
    "insultată": "insultat",
    "insultate": "insultat",
    "insultați": "insultat",
    "insultătoare": "insultător",
    "insultătoarea": "insultător",
    "insultătoarei": "insultător",
    "insultătoarele": "insultător",
    "insultătoarelor": "insultător",
    "insultători": "insultător",
    "insultătorii": "insultător",
    "insultătorilor": "insultător",
    "insultătorul": "insultător",
    "insultătorului": "insultător",
    "însumă": "însuma",
    "însumai": "însuma",
    "însumam": "însuma",
    "însumăm": "însuma",
    "însumând": "însuma",
    "însumându": "însuma",
    "însumară": "însuma",
    "însumarăm": "însuma",
    "însumarăți": "însuma",
    "însumase": "însuma",
    "însumasem": "însuma",
    "însumaseră": "însuma",
    "însumaserăm": "însuma",
    "însumaserăți": "însuma",
    "însumaseși": "însuma",
    "însumași": "însuma",
    "însumat": "însuma",
    "însumați": "însuma",
    "însumatu": "însuma",
    "însumau": "însuma",
    "însumează": "însuma",
    "însumez": "însuma",
    "însumeze": "însuma",
    "însumezi": "însuma",
    "neînsumând": "însuma",
    "neînsumându": "însuma",
    "nemaiînsumând": "însuma",
    "nemaiînsumându": "însuma",
    "însumabila": "însumabil",
    "însumabilă": "însumabil",
    "însumabile": "însumabil",
    "însumabilei": "însumabil",
    "însumabilele": "însumabil",
    "însumabilelor": "însumabil",
    "însumabili": "însumabil",
    "însumabilii": "însumabil",
    "însumabililor": "însumabil",
    "însumabilo": "însumabil",
    "însumabilul": "însumabil",
    "însumabilule": "însumabil",
    "însumabilului": "însumabil",
    "însumată": "însumat",
    "însumate": "însumat",
    "însumați": "însumat",
    "însămi": "însumi",
    "însăși": "însumi",
    "însăți": "însumi",
    "însele": "însumi",
    "însemi": "însumi",
    "însene": "însumi",
    "înseși": "însumi",
    "înseți": "însumi",
    "însevă": "însumi",
    "înșine": "însumi",
    "înșiși": "însumi",
    "înșivă": "însumi",
    "însuși": "însumi",
    "însuți": "însumi",
    "insuportabila": "insuportabil",
    "insuportabilă": "insuportabil",
    "insuportabile": "insuportabil",
    "insuportabilei": "insuportabil",
    "insuportabilele": "insuportabil",
    "insuportabilelor": "insuportabil",
    "insuportabili": "insuportabil",
    "insuportabilii": "insuportabil",
    "insuportabililor": "insuportabil",
    "insuportabilul": "insuportabil",
    "insuportabilului": "insuportabil",
    "însoară": "însura",
    "însoare": "însura",
    "însor": "însura",
    "însori": "însura",
    "însurând": "însura",
    "însurându": "însura",
    "însurat": "însura",
    "însuratu": "însura",
    "neînsurând": "însura",
    "neînsurându": "însura",
    "nemaiînsurând": "însura",
    "nemaiînsurându": "însura",
    "însurați": "însurat",
    "însurătoarea": "însurătoare",
    "însurători": "însurătoare",
    "însurătorii": "însurătoare",
    "însurătorile": "însurătoare",
    "însurătorilor": "însurătoare",
    "insurecția": "insurecție",
    "insurecției": "insurecție",
    "insurecții": "insurecție",
    "insurecțiile": "insurecție",
    "insurecțiilor": "insurecție",
    "înșurubă": "înșuruba",
    "înșurubai": "înșuruba",
    "înșurubam": "înșuruba",
    "înșurubăm": "înșuruba",
    "înșurubând": "înșuruba",
    "înșurubându": "înșuruba",
    "înșurubară": "înșuruba",
    "înșurubarăm": "înșuruba",
    "înșurubarăți": "înșuruba",
    "înșurubase": "înșuruba",
    "înșurubasem": "înșuruba",
    "înșurubaseră": "înșuruba",
    "înșurubaserăm": "înșuruba",
    "înșurubaserăți": "înșuruba",
    "înșurubaseși": "înșuruba",
    "înșurubași": "înșuruba",
    "înșurubat": "înșuruba",
    "înșurubați": "înșuruba",
    "înșurubatu": "înșuruba",
    "înșurubau": "înșuruba",
    "înșurubează": "înșuruba",
    "înșurubez": "înșuruba",
    "înșurubeze": "înșuruba",
    "înșurubezi": "înșuruba",
    "neînșurubând": "înșuruba",
    "neînșurubându": "înșuruba",
    "nemaiînșurubând": "înșuruba",
    "nemaiînșurubându": "înșuruba",
    "înșurubată": "înșurubat",
    "înșurubate": "înșurubat",
    "înșurubați": "înșurubat",
    "însușea": "însuși",
    "însușeai": "însuși",
    "însușeam": "însuși",
    "însușească": "însuși",
    "însușeați": "însuși",
    "însușeau": "însuși",
    "însușesc": "însuși",
    "însușește": "însuși",
    "însușești": "însuși",
    "însușii": "însuși",
    "însușim": "însuși",
    "însușind": "însuși",
    "însușindu": "însuși",
    "însușiră": "însuși",
    "însușirăm": "însuși",
    "însușirăți": "însuși",
    "însușise": "însuși",
    "însușisem": "însuși",
    "însușiseră": "însuși",
    "însușiserăm": "însuși",
    "însușiserăți": "însuși",
    "însușiseși": "însuși",
    "însușiși": "însuși",
    "însușit": "însuși",
    "însușiți": "însuși",
    "însușitu": "însuși",
    "neînsușind": "însuși",
    "neînsușindu": "însuși",
    "nemaiînsușind": "însuși",
    "nemaiînsușindu": "însuși",
    "însușirea": "însușire",
    "însușiri": "însușire",
    "însușirii": "însușire",
    "însușirile": "însușire",
    "însușirilor": "însușire",
    "însușită": "însușit",
    "însușite": "însușit",
    "însușiți": "însușit",
    "însutea": "însuti",
    "însuteai": "însuti",
    "însuteam": "însuti",
    "însutească": "însuti",
    "însuteați": "însuti",
    "însuteau": "însuti",
    "însutesc": "însuti",
    "însutește": "însuti",
    "însutești": "însuti",
    "însutii": "însuti",
    "însutim": "însuti",
    "însutind": "însuti",
    "însutindu": "însuti",
    "însutiră": "însuti",
    "însutirăm": "însuti",
    "însutirăți": "însuti",
    "însutise": "însuti",
    "însutisem": "însuti",
    "însutiseră": "însuti",
    "însutiserăm": "însuti",
    "însutiserăți": "însuti",
    "însutiseși": "însuti",
    "însutiși": "însuti",
    "însutit": "însuti",
    "însutiți": "însuti",
    "însutitu": "însuti",
    "neînsutind": "însuti",
    "neînsutindu": "însuti",
    "nemaiînsutind": "însuti",
    "nemaiînsutindu": "însuti",
    "însutita": "însutit",
    "însutită": "însutit",
    "însutite": "însutit",
    "însutitei": "însutit",
    "însutitele": "însutit",
    "însutitelor": "însutit",
    "însutiți": "însutit",
    "însutiții": "însutit",
    "însutiților": "însutit",
    "însutitul": "însutit",
    "însutitului": "însutit",
    "intabulă": "intabula",
    "intabulai": "intabula",
    "intabulam": "intabula",
    "intabulăm": "intabula",
    "intabulând": "intabula",
    "intabulându": "intabula",
    "intabulară": "intabula",
    "intabularăm": "intabula",
    "intabularăți": "intabula",
    "intabulase": "intabula",
    "intabulasem": "intabula",
    "intabulaseră": "intabula",
    "intabulaserăm": "intabula",
    "intabulaserăți": "intabula",
    "intabulaseși": "intabula",
    "intabulași": "intabula",
    "intabulat": "intabula",
    "intabulați": "intabula",
    "intabulatu": "intabula",
    "intabulau": "intabula",
    "intabulează": "intabula",
    "intabulez": "intabula",
    "intabuleze": "intabula",
    "intabulezi": "intabula",
    "neintabulând": "intabula",
    "neintabulându": "intabula",
    "nemaiintabulând": "intabula",
    "nemaiintabulându": "intabula",
    "intabulată": "intabulat",
    "intabulate": "intabulat",
    "intabulați": "intabulat",
    "intacta": "intact",
    "intactă": "intact",
    "intacte": "intact",
    "intactei": "intact",
    "intactele": "intact",
    "intactelor": "intact",
    "intacți": "intact",
    "intacții": "intact",
    "intacților": "intact",
    "intactul": "intact",
    "intactului": "intact",
    "întâia": "întâi",
    "întâiași": "întâi",
    "întâii": "întâi",
    "întâile": "întâi",
    "întâilor": "întâi",
    "întâiul": "întâi",
    "întâiului": "întâi",
    "întâietatea": "întâietate",
    "întâietăți": "întâietate",
    "întâietății": "întâietate",
    "întâi-stătători": "întâi-stătător",
    "întâi-stătătorii": "întâi-stătător",
    "întâi-stătătorilor": "întâi-stătător",
    "întâi-stătătorul": "întâi-stătător",
    "întâi-stătătorului": "întâi-stătător",
    "întâlnea": "întâlni",
    "întâlneai": "întâlni",
    "întâlneam": "întâlni",
    "întâlnească": "întâlni",
    "întâlneați": "întâlni",
    "întâlneau": "întâlni",
    "întâlnesc": "întâlni",
    "întâlnește": "întâlni",
    "întâlnești": "întâlni",
    "întâlnii": "întâlni",
    "întâlnim": "întâlni",
    "întâlnind": "întâlni",
    "întâlnindu": "întâlni",
    "întâlniră": "întâlni",
    "întâlnirăm": "întâlni",
    "întâlnirăți": "întâlni",
    "întâlnise": "întâlni",
    "întâlnisem": "întâlni",
    "întâlniseră": "întâlni",
    "întâlniserăm": "întâlni",
    "întâlniserăți": "întâlni",
    "întâlniseși": "întâlni",
    "întâlniși": "întâlni",
    "întâlnit": "întâlni",
    "întâlniți": "întâlni",
    "întâlnitu": "întâlni",
    "neîntâlnind": "întâlni",
    "neîntâlnindu": "întâlni",
    "nemaiîntâlnind": "întâlni",
    "nemaiîntâlnindu": "întâlni",
    "întâlnirea": "întâlnire",
    "întâlniri": "întâlnire",
    "întâlnirii": "întâlnire",
    "întâlnirile": "întâlnire",
    "întâlnirilor": "întâlnire",
    "întâlnită": "întâlnit",
    "întâlnite": "întâlnit",
    "întâlniți": "întâlnit",
    "întâmpin": "întâmpina",
    "întâmpină": "întâmpina",
    "întâmpinai": "întâmpina",
    "întâmpinam": "întâmpina",
    "întâmpinăm": "întâmpina",
    "întâmpinând": "întâmpina",
    "întâmpinându": "întâmpina",
    "întâmpinară": "întâmpina",
    "întâmpinarăm": "întâmpina",
    "întâmpinarăți": "întâmpina",
    "întâmpinase": "întâmpina",
    "întâmpinasem": "întâmpina",
    "întâmpinaseră": "întâmpina",
    "întâmpinaserăm": "întâmpina",
    "întâmpinaserăți": "întâmpina",
    "întâmpinaseși": "întâmpina",
    "întâmpinași": "întâmpina",
    "întâmpinat": "întâmpina",
    "întâmpinați": "întâmpina",
    "întâmpinatu": "întâmpina",
    "întâmpinau": "întâmpina",
    "întâmpine": "întâmpina",
    "întâmpini": "întâmpina",
    "neîntâmpinând": "întâmpina",
    "neîntâmpinându": "întâmpina",
    "nemaiîntâmpinând": "întâmpina",
    "nemaiîntâmpinându": "întâmpina",
    "întâmpinarea": "întâmpinare",
    "întâmpinări": "întâmpinare",
    "întâmpinării": "întâmpinare",
    "întâmpinările": "întâmpinare",
    "întâmpinărilor": "întâmpinare",
    "întâmpinată": "întâmpinat",
    "întâmpinate": "întâmpinat",
    "întâmpinați": "întâmpinat",
    "întâmplă": "întâmpla",
    "întâmplând": "întâmpla",
    "întâmplându": "întâmpla",
    "întâmplară": "întâmpla",
    "întâmplase": "întâmpla",
    "întâmplaseră": "întâmpla",
    "întâmplat": "întâmpla",
    "întâmplatu": "întâmpla",
    "întâmplau": "întâmpla",
    "întâmple": "întâmpla",
    "neîntâmplând": "întâmpla",
    "neîntâmplându": "întâmpla",
    "nemaiîntâmplând": "întâmpla",
    "nemaiîntâmplându": "întâmpla",
    "întâmplarea": "întâmplare",
    "întâmplări": "întâmplare",
    "întâmplării": "întâmplare",
    "întâmplările": "întâmplare",
    "întâmplărilor": "întâmplare",
    "întâmplata": "întâmplat",
    "întâmplată": "întâmplat",
    "întâmplate": "întâmplat",
    "întâmplatei": "întâmplat",
    "întâmplatele": "întâmplat",
    "întâmplatelor": "întâmplat",
    "întâmplați": "întâmplat",
    "întâmplații": "întâmplat",
    "întâmplaților": "întâmplat",
    "întâmplato": "întâmplat",
    "întâmplatul": "întâmplat",
    "întâmplatule": "întâmplat",
    "întâmplatului": "întâmplat",
    "întâmplătoare": "întâmplător",
    "întâmplătoarea": "întâmplător",
    "întâmplătoarei": "întâmplător",
    "întâmplătoarele": "întâmplător",
    "întâmplătoarelor": "întâmplător",
    "întâmplători": "întâmplător",
    "întâmplătorii": "întâmplător",
    "întâmplătorilor": "întâmplător",
    "întâmplătorul": "întâmplător",
    "întâmplătorului": "întâmplător",
    "intangibila": "intangibil",
    "intangibilă": "intangibil",
    "intangibile": "intangibil",
    "intangibilei": "intangibil",
    "intangibilele": "intangibil",
    "intangibilelor": "intangibil",
    "intangibili": "intangibil",
    "intangibilii": "intangibil",
    "intangibililor": "intangibil",
    "intangibilul": "intangibil",
    "intangibilului": "intangibil",
    "întărât": "întărâta",
    "întărâtă": "întărâta",
    "întărâtai": "întărâta",
    "întărâtam": "întărâta",
    "întărâtăm": "întărâta",
    "întărâtând": "întărâta",
    "întărâtându": "întărâta",
    "întărâtară": "întărâta",
    "întărâtarăm": "întărâta",
    "întărâtarăți": "întărâta",
    "întărâtase": "întărâta",
    "întărâtasem": "întărâta",
    "întărâtaseră": "întărâta",
    "întărâtaserăm": "întărâta",
    "întărâtaserăți": "întărâta",
    "întărâtaseși": "întărâta",
    "întărâtași": "întărâta",
    "întărâtat": "întărâta",
    "întărâtați": "întărâta",
    "întărâtatu": "întărâta",
    "întărâtau": "întărâta",
    "întărâte": "întărâta",
    "întărâți": "întărâta",
    "neîntărâtând": "întărâta",
    "neîntărâtându": "întărâta",
    "nemaiîntărâtând": "întărâta",
    "nemaiîntărâtându": "întărâta",
    "întărâtată": "întărâtat",
    "întărâtate": "întărâtat",
    "întărâtați": "întărâtat",
    "înțarc": "înțărca",
    "înțarcă": "înțărca",
    "înțărcă": "înțărca",
    "înțărcai": "înțărca",
    "înțărcam": "înțărca",
    "înțărcăm": "înțărca",
    "înțărcând": "înțărca",
    "înțărcându": "înțărca",
    "înțărcară": "înțărca",
    "înțărcarăm": "înțărca",
    "înțărcarăți": "înțărca",
    "înțărcase": "înțărca",
    "înțărcasem": "înțărca",
    "înțărcaseră": "înțărca",
    "înțărcaserăm": "înțărca",
    "înțărcaserăți": "înțărca",
    "înțărcaseși": "înțărca",
    "înțărcași": "înțărca",
    "înțărcat": "înțărca",
    "înțărcați": "înțărca",
    "înțărcatu": "înțărca",
    "înțărcau": "înțărca",
    "înțarce": "înțărca",
    "înțarci": "înțărca",
    "neînțărcând": "înțărca",
    "neînțărcându": "înțărca",
    "nemaiînțărcând": "înțărca",
    "nemaiînțărcându": "înțărca",
    "înțărcată": "înțărcat",
    "înțărcate": "înțărcat",
    "înțărcați": "înțărcat",
    "înțărcuia": "înțărcui",
    "înțărcuiai": "înțărcui",
    "înțărcuiam": "înțărcui",
    "înțărcuiască": "înțărcui",
    "înțărcuiați": "înțărcui",
    "înțărcuiau": "înțărcui",
    "înțărcuiesc": "înțărcui",
    "înțărcuiește": "înțărcui",
    "înțărcuiești": "înțărcui",
    "înțărcuii": "înțărcui",
    "înțărcuim": "înțărcui",
    "înțărcuind": "înțărcui",
    "înțărcuindu": "înțărcui",
    "înțărcuiră": "înțărcui",
    "înțărcuirăm": "înțărcui",
    "înțărcuirăți": "înțărcui",
    "înțărcuise": "înțărcui",
    "înțărcuisem": "înțărcui",
    "înțărcuiseră": "înțărcui",
    "înțărcuiserăm": "înțărcui",
    "înțărcuiserăți": "înțărcui",
    "înțărcuiseși": "înțărcui",
    "înțărcuiși": "înțărcui",
    "înțărcuit": "înțărcui",
    "înțărcuiți": "înțărcui",
    "înțărcuitu": "înțărcui",
    "neînțărcuind": "înțărcui",
    "neînțărcuindu": "înțărcui",
    "nemaiînțărcuind": "înțărcui",
    "nemaiînțărcuindu": "înțărcui",
    "înțărcuită": "înțărcuit",
    "înțărcuite": "înțărcuit",
    "înțărcuiți": "înțărcuit",
    "întărea": "întări",
    "întăreai": "întări",
    "întăream": "întări",
    "întărească": "întări",
    "întăreați": "întări",
    "întăreau": "întări",
    "întăresc": "întări",
    "întărește": "întări",
    "întărești": "întări",
    "întării": "întări",
    "întărim": "întări",
    "întărind": "întări",
    "întărindu": "întări",
    "întăriră": "întări",
    "întărirăm": "întări",
    "întărirăți": "întări",
    "întărise": "întări",
    "întărisem": "întări",
    "întăriseră": "întări",
    "întăriserăm": "întări",
    "întăriserăți": "întări",
    "întăriseși": "întări",
    "întăriși": "întări",
    "întărit": "întări",
    "întăriți": "întări",
    "întăritu": "întări",
    "neîntărind": "întări",
    "neîntărindu": "întări",
    "nemaiîntărind": "întări",
    "nemaiîntărindu": "întări",
    "întărirea": "întărire",
    "întărireo": "întărire",
    "întăriri": "întărire",
    "întăririi": "întărire",
    "întăririle": "întărire",
    "întăririlor": "întărire",
    "întărită": "întărit",
    "întărite": "întărit",
    "întăriți": "întărit",
    "întăritoare": "întăritor",
    "întăritoarea": "întăritor",
    "întăritoarei": "întăritor",
    "întăritoarele": "întăritor",
    "întăritoarelor": "întăritor",
    "întăritori": "întăritor",
    "întăritorii": "întăritor",
    "întăritorilor": "întăritor",
    "întăritorul": "întăritor",
    "întăritorului": "întăritor",
    "întârziai": "întârzia",
    "întârziam": "întârzia",
    "întârziară": "întârzia",
    "întârziarăm": "întârzia",
    "întârziarăți": "întârzia",
    "întârziase": "întârzia",
    "întârziasem": "întârzia",
    "întârziaseră": "întârzia",
    "întârziaserăm": "întârzia",
    "întârziaserăți": "întârzia",
    "întârziaseși": "întârzia",
    "întârziași": "întârzia",
    "întârziat": "întârzia",
    "întârziați": "întârzia",
    "întârziatu": "întârzia",
    "întârziau": "întârzia",
    "întârzie": "întârzia",
    "întârziem": "întârzia",
    "întârzii": "întârzia",
    "întârziind": "întârzia",
    "întârziindu": "întârzia",
    "neîntârziind": "întârzia",
    "neîntârziindu": "întârzia",
    "nemaiîntârziind": "întârzia",
    "nemaiîntârziindu": "întârzia",
    "întârziata": "întârziat",
    "întârziată": "întârziat",
    "întârziate": "întârziat",
    "întârziatei": "întârziat",
    "întârziatele": "întârziat",
    "întârziatelor": "întârziat",
    "întârziați": "întârziat",
    "întârziații": "întârziat",
    "întârziaților": "întârziat",
    "întârziato": "întârziat",
    "întârziatul": "întârziat",
    "întârziatule": "întârziat",
    "întârziatului": "întârziat",
    "întârzierea": "întârziere",
    "întârzieri": "întârziere",
    "întârzierii": "întârziere",
    "întârzierile": "întârziere",
    "întârzierilor": "întârziere",
    "integră": "integra",
    "integrai": "integra",
    "integram": "integra",
    "integrăm": "integra",
    "integrând": "integra",
    "integrându": "integra",
    "integrară": "integra",
    "integrarăm": "integra",
    "integrarăți": "integra",
    "integrase": "integra",
    "integrasem": "integra",
    "integraseră": "integra",
    "integraserăm": "integra",
    "integraserăți": "integra",
    "integraseși": "integra",
    "integrași": "integra",
    "integrat": "integra",
    "integrați": "integra",
    "integratu": "integra",
    "integrau": "integra",
    "integrează": "integra",
    "integrez": "integra",
    "integreze": "integra",
    "integrezi": "integra",
    "neintegrând": "integra",
    "neintegrându": "integra",
    "nemaiintegrând": "integra",
    "nemaiintegrându": "integra",
    "integrala": "integral",
    "integrală": "integral",
    "integrale": "integral",
    "integralei": "integral",
    "integralele": "integral",
    "integralelor": "integral",
    "integrali": "integral",
    "integralii": "integral",
    "integralilor": "integral",
    "integralul": "integral",
    "integralului": "integral",
    "integrala": "integrală",
    "integrale": "integrală",
    "integralei": "integrală",
    "integralele": "integrală",
    "integralelor": "integrală",
    "integralitatea": "integralitate",
    "integralitateo": "integralitate",
    "integralități": "integralitate",
    "integralității": "integralitate",
    "integralitățile": "integralitate",
    "integralităților": "integralitate",
    "integrante": "integrantă",
    "integrarea": "integrare",
    "integrări": "integrare",
    "integrării": "integrare",
    "integrările": "integrare",
    "integrărilor": "integrare",
    "integrată": "integrat",
    "integrate": "integrat",
    "integrați": "integrat",
    "integritatea": "integritate",
    "integrități": "integritate",
    "integrității": "integritate",
    "integra": "integru",
    "integră": "integru",
    "integre": "integru",
    "integrei": "integru",
    "integrele": "integru",
    "integrelor": "integru",
    "integri": "integru",
    "integrii": "integru",
    "integrilor": "integru",
    "integrul": "integru",
    "integrului": "integru",
    "intelecte": "intelect",
    "intelectele": "intelect",
    "intelectelor": "intelect",
    "intelectul": "intelect",
    "intelectului": "intelect",
    "intelectuala": "intelectual",
    "intelectuală": "intelectual",
    "intelectuale": "intelectual",
    "intelectualei": "intelectual",
    "intelectualele": "intelectual",
    "intelectualelor": "intelectual",
    "intelectuali": "intelectual",
    "intelectualii": "intelectual",
    "intelectualilor": "intelectual",
    "intelectualul": "intelectual",
    "intelectualului": "intelectual",
    "intelectualitatea": "intelectualitate",
    "intelectualități": "intelectualitate",
    "intelectualității": "intelectualitate",
    "intelectualitățile": "intelectualitate",
    "intelectualităților": "intelectualitate",
    "înțelegătoare": "înțelegător",
    "înțelegătoarea": "înțelegător",
    "înțelegătoarei": "înțelegător",
    "înțelegătoarele": "înțelegător",
    "înțelegătoarelor": "înțelegător",
    "înțelegători": "înțelegător",
    "înțelegătorii": "înțelegător",
    "înțelegătorilor": "înțelegător",
    "înțelegătorul": "înțelegător",
    "înțelegătorului": "înțelegător",
    "înțeleagă": "înțelege",
    "înțeleg": "înțelege",
    "înțelegând": "înțelege",
    "înțelegându": "înțelege",
    "înțelegea": "înțelege",
    "înțelegeai": "înțelege",
    "înțelegeam": "înțelege",
    "înțelegeați": "înțelege",
    "înțelegeau": "înțelege",
    "înțelegem": "înțelege",
    "înțelegeți": "înțelege",
    "înțelegi": "înțelege",
    "înțeles": "înțelege",
    "înțelese": "înțelege",
    "înțelesei": "înțelege",
    "înțeleseră": "înțelege",
    "înțeleserăm": "înțelege",
    "înțeleserăți": "înțelege",
    "înțelesese": "înțelege",
    "înțelesesem": "înțelege",
    "înțeleseseră": "înțelege",
    "înțeleseserăm": "înțelege",
    "înțeleseserăți": "înțelege",
    "înțeleseseși": "înțelege",
    "înțeleseși": "înțelege",
    "înțelesu": "înțelege",
    "neînțelegând": "înțelege",
    "neînțelegându": "înțelege",
    "neînțeles": "înțelege",
    "neînțelesu": "înțelege",
    "nemaiînțelegând": "înțelege",
    "nemaiînțelegându": "înțelege",
    "înțelegerea": "înțelegere",
    "înțelegeri": "înțelegere",
    "înțelegerii": "înțelegere",
    "înțelegerile": "înțelegere",
    "înțelegerilor": "înțelegere",
    "înțelenea": "înțeleni",
    "înțeleneai": "înțeleni",
    "înțeleneam": "înțeleni",
    "înțelenească": "înțeleni",
    "înțeleneați": "înțeleni",
    "înțeleneau": "înțeleni",
    "înțelenesc": "înțeleni",
    "înțelenește": "înțeleni",
    "înțelenești": "înțeleni",
    "înțelenii": "înțeleni",
    "înțelenim": "înțeleni",
    "înțelenind": "înțeleni",
    "înțelenindu": "înțeleni",
    "înțeleniră": "înțeleni",
    "înțelenirăm": "înțeleni",
    "înțelenirăți": "înțeleni",
    "înțelenise": "înțeleni",
    "înțelenisem": "înțeleni",
    "înțeleniseră": "înțeleni",
    "înțeleniserăm": "înțeleni",
    "înțeleniserăți": "înțeleni",
    "înțeleniseși": "înțeleni",
    "înțeleniși": "înțeleni",
    "înțelenit": "înțeleni",
    "înțeleniți": "înțeleni",
    "înțelenitu": "înțeleni",
    "neînțelenind": "înțeleni",
    "neînțelenindu": "înțeleni",
    "nemaiînțelenind": "înțeleni",
    "nemaiînțelenindu": "înțeleni",
    "înțelenită": "înțelenit",
    "înțelenite": "înțelenit",
    "înțeleniți": "înțelenit",
    "înțelepciunea": "înțelepciune",
    "înțelepciuni": "înțelepciune",
    "înțelepciunii": "înțelepciune",
    "înțelepciunile": "înțelepciune",
    "înțelepciunilor": "înțelepciune",
    "înțeleapta": "înțelept",
    "înțeleaptă": "înțelept",
    "înțelepte": "înțelept",
    "înțeleptei": "înțelept",
    "înțeleptele": "înțelept",
    "înțeleptelor": "înțelept",
    "înțelepți": "înțelept",
    "înțelepții": "înțelept",
    "înțelepților": "înțelept",
    "înțeleptul": "înțelept",
    "înțeleptului": "înțelept",
    "înțeleasă": "înțeles",
    "înțelese": "înțeles",
    "înțeleși": "înțeles",
    "înțelesul": "înțeles",
    "înțelesului": "înțeles",
    "înțelesuri": "înțeles",
    "înțelesurile": "înțeles",
    "înțelesurilor": "înțeles",
    "inteligenta": "inteligent",
    "inteligentă": "inteligent",
    "inteligente": "inteligent",
    "inteligentei": "inteligent",
    "inteligentele": "inteligent",
    "inteligentelor": "inteligent",
    "inteligenți": "inteligent",
    "inteligenții": "inteligent",
    "inteligenților": "inteligent",
    "inteligentul": "inteligent",
    "inteligentului": "inteligent",
    "inteligența": "inteligență",
    "inteligențe": "inteligență",
    "inteligenței": "inteligență",
    "inteligențele": "inteligență",
    "inteligențelor": "inteligență",
    "intelighenților": "intelighent",
    "inteligibila": "inteligibil",
    "inteligibilă": "inteligibil",
    "inteligibile": "inteligibil",
    "inteligibilei": "inteligibil",
    "inteligibilele": "inteligibil",
    "inteligibilelor": "inteligibil",
    "inteligibili": "inteligibil",
    "inteligibilii": "inteligibil",
    "inteligibililor": "inteligibil",
    "inteligibilul": "inteligibil",
    "inteligibilului": "inteligibil",
    "întemeiai": "întemeia",
    "întemeiam": "întemeia",
    "întemeiară": "întemeia",
    "întemeiarăm": "întemeia",
    "întemeiarăți": "întemeia",
    "întemeiase": "întemeia",
    "întemeiasem": "întemeia",
    "întemeiaseră": "întemeia",
    "întemeiaserăm": "întemeia",
    "întemeiaserăți": "întemeia",
    "întemeiaseși": "întemeia",
    "întemeiași": "întemeia",
    "întemeiat": "întemeia",
    "întemeiați": "întemeia",
    "întemeiatu": "întemeia",
    "întemeiau": "întemeia",
    "întemeiază": "întemeia",
    "întemeie": "întemeia",
    "întemeiem": "întemeia",
    "întemeiez": "întemeia",
    "întemeieze": "întemeia",
    "întemeiezi": "întemeia",
    "întemeind": "întemeia",
    "întemeindu": "întemeia",
    "neîntemeiind": "întemeia",
    "neîntemeiindu": "întemeia",
    "nemaiîntemeiind": "întemeia",
    "nemaiîntemeiindu": "întemeia",
    "întemeiata": "întemeiat",
    "întemeiată": "întemeiat",
    "întemeiate": "întemeiat",
    "întemeiatei": "întemeiat",
    "întemeiatele": "întemeiat",
    "întemeiatelor": "întemeiat",
    "întemeiați": "întemeiat",
    "întemeiații": "întemeiat",
    "întemeiaților": "întemeiat",
    "întemeiatul": "întemeiat",
    "întemeiatului": "întemeiat",
    "întemeierea": "întemeiere",
    "întemeieri": "întemeiere",
    "întemeierii": "întemeiere",
    "întemeierile": "întemeiere",
    "întemeierilor": "întemeiere",
    "întemeietori": "întemeietor",
    "întemeietorii": "întemeietor",
    "întemeietorilor": "întemeietor",
    "întemeietorul": "întemeietor",
    "întemeietorului": "întemeietor",
    "întemniță": "întemnița",
    "întemnițai": "întemnița",
    "întemnițam": "întemnița",
    "întemnițăm": "întemnița",
    "întemnițând": "întemnița",
    "întemnițându": "întemnița",
    "întemnițară": "întemnița",
    "întemnițarăm": "întemnița",
    "întemnițarăți": "întemnița",
    "întemnițase": "întemnița",
    "întemnițasem": "întemnița",
    "întemnițaseră": "întemnița",
    "întemnițaserăm": "întemnița",
    "întemnițaserăți": "întemnița",
    "întemnițaseși": "întemnița",
    "întemnițași": "întemnița",
    "întemnițat": "întemnița",
    "întemnițați": "întemnița",
    "întemnițatu": "întemnița",
    "întemnițau": "întemnița",
    "întemnițează": "întemnița",
    "întemnițez": "întemnița",
    "întemnițeze": "întemnița",
    "întemnițezi": "întemnița",
    "neîntemnițând": "întemnița",
    "neîntemnițându": "întemnița",
    "nemaiîntemnițând": "întemnița",
    "nemaiîntemnițându": "întemnița",
    "întemnițată": "întemnițat",
    "întemnițate": "întemnițat",
    "întemnițați": "întemnițat",
    "intemperia": "intemperie",
    "intemperiei": "intemperie",
    "intemperii": "intemperie",
    "intemperiile": "intemperie",
    "intemperiilor": "intemperie",
    "intensa": "intens",
    "intensă": "intens",
    "intense": "intens",
    "intensei": "intens",
    "intensele": "intens",
    "intenselor": "intens",
    "intenși": "intens",
    "intenșii": "intens",
    "intenșilor": "intens",
    "intensul": "intens",
    "intensului": "intens",
    "intensific": "intensifica",
    "intensifică": "intensifica",
    "intensificai": "intensifica",
    "intensificam": "intensifica",
    "intensificăm": "intensifica",
    "intensificând": "intensifica",
    "intensificându": "intensifica",
    "intensificară": "intensifica",
    "intensificarăm": "intensifica",
    "intensificarăți": "intensifica",
    "intensificase": "intensifica",
    "intensificasem": "intensifica",
    "intensificaseră": "intensifica",
    "intensificaserăm": "intensifica",
    "intensificaserăți": "intensifica",
    "intensificaseși": "intensifica",
    "intensificași": "intensifica",
    "intensificat": "intensifica",
    "intensificați": "intensifica",
    "intensificatu": "intensifica",
    "intensificau": "intensifica",
    "intensifice": "intensifica",
    "intensifici": "intensifica",
    "neintensificând": "intensifica",
    "neintensificându": "intensifica",
    "nemaiintensificând": "intensifica",
    "nemaiintensificându": "intensifica",
    "intensificarea": "intensificare",
    "intensificări": "intensificare",
    "intensificării": "intensificare",
    "intensificările": "intensificare",
    "intensificărilor": "intensificare",
    "intensificată": "intensificat",
    "intensificate": "intensificat",
    "intensificați": "intensificat",
    "intensitatea": "intensitate",
    "intensități": "intensitate",
    "intensității": "intensitate",
    "intensitățile": "intensitate",
    "intensităților": "intensitate",
    "intensiva": "intensiv",
    "intensivă": "intensiv",
    "intensive": "intensiv",
    "intensivei": "intensiv",
    "intensivele": "intensiv",
    "intensivelor": "intensiv",
    "intensivi": "intensiv",
    "intensivii": "intensiv",
    "intensivilor": "intensiv",
    "intensivul": "intensiv",
    "intensivului": "intensiv",
    "intentă": "intenta",
    "intentai": "intenta",
    "intentam": "intenta",
    "intentăm": "intenta",
    "intentând": "intenta",
    "intentându": "intenta",
    "intentară": "intenta",
    "intentarăm": "intenta",
    "intentarăți": "intenta",
    "intentase": "intenta",
    "intentasem": "intenta",
    "intentaseră": "intenta",
    "intentaserăm": "intenta",
    "intentaserăți": "intenta",
    "intentaseși": "intenta",
    "intentași": "intenta",
    "intentat": "intenta",
    "intentați": "intenta",
    "intentatu": "intenta",
    "intentau": "intenta",
    "intentează": "intenta",
    "intentez": "intenta",
    "intenteze": "intenta",
    "intentezi": "intenta",
    "neintentând": "intenta",
    "neintentându": "intenta",
    "nemaiintentând": "intenta",
    "nemaiintentându": "intenta",
    "intentată": "intentat",
    "intentate": "intentat",
    "intentați": "intentat",
    "intenția": "intenție",
    "intenției": "intenție",
    "intenții": "intenție",
    "intențiile": "intenție",
    "intențiilor": "intenție",
    "intenționă": "intenționa",
    "intenționai": "intenționa",
    "intenționam": "intenționa",
    "intenționăm": "intenționa",
    "intenționând": "intenționa",
    "intenționându": "intenționa",
    "intenționară": "intenționa",
    "intenționarăm": "intenționa",
    "intenționarăți": "intenționa",
    "intenționase": "intenționa",
    "intenționasem": "intenționa",
    "intenționaseră": "intenționa",
    "intenționaserăm": "intenționa",
    "intenționaserăți": "intenționa",
    "intenționaseși": "intenționa",
    "intenționași": "intenționa",
    "intenționat": "intenționa",
    "intenționați": "intenționa",
    "intenționatu": "intenționa",
    "intenționau": "intenționa",
    "intenționează": "intenționa",
    "intenționez": "intenționa",
    "intenționeze": "intenționa",
    "intenționezi": "intenționa",
    "neintenționând": "intenționa",
    "neintenționându": "intenționa",
    "nemaiintenționând": "intenționa",
    "nemaiintenționându": "intenționa",
    "intenționata": "intenționat",
    "intenționată": "intenționat",
    "intenționate": "intenționat",
    "intenționatei": "intenționat",
    "intenționatele": "intenționat",
    "intenționatelor": "intenționat",
    "intenționați": "intenționat",
    "intenționații": "intenționat",
    "intenționaților": "intenționat",
    "intenționatul": "intenționat",
    "intenționatului": "intenționat",
    "înțeapă": "înțepa",
    "înțep": "înțepa",
    "înțepă": "înțepa",
    "înțepai": "înțepa",
    "înțepam": "înțepa",
    "înțepăm": "înțepa",
    "înțepând": "înțepa",
    "înțepându": "înțepa",
    "înțepară": "înțepa",
    "înțeparăm": "înțepa",
    "înțeparăți": "înțepa",
    "înțepase": "înțepa",
    "înțepasem": "înțepa",
    "înțepaseră": "înțepa",
    "înțepaserăm": "înțepa",
    "înțepaserăți": "înțepa",
    "înțepaseși": "înțepa",
    "înțepași": "înțepa",
    "înțepat": "înțepa",
    "înțepați": "înțepa",
    "înțepatu": "înțepa",
    "înțepau": "înțepa",
    "înțepe": "înțepa",
    "înțepi": "înțepa",
    "neînțepând": "înțepa",
    "neînțepându": "înțepa",
    "nemaiînțepând": "înțepa",
    "nemaiînțepându": "înțepa",
    "înțeparea": "înțepare",
    "înțepareo": "înțepare",
    "înțepări": "înțepare",
    "înțepării": "înțepare",
    "înțepările": "înțepare",
    "înțepărilor": "înțepare",
    "înțepată": "înțepat",
    "înțepate": "înțepat",
    "înțepați": "înțepat",
    "înțepătoare": "înțepător",
    "înțepătoarea": "înțepător",
    "înțepătoarei": "înțepător",
    "înțepătoarele": "înțepător",
    "înțepătoarelor": "înțepător",
    "înțepători": "înțepător",
    "înțepătorii": "înțepător",
    "înțepătorilor": "înțepător",
    "înțepătorul": "înțepător",
    "înțepătorului": "înțepător",
    "înțepătura": "înțepătură",
    "înțepături": "înțepătură",
    "înțepăturii": "înțepătură",
    "înțepăturile": "înțepătură",
    "înțepăturilor": "înțepătură",
    "înțepenea": "înțepeni",
    "înțepeneai": "înțepeni",
    "înțepeneam": "înțepeni",
    "înțepenească": "înțepeni",
    "înțepeneați": "înțepeni",
    "înțepeneau": "înțepeni",
    "înțepenesc": "înțepeni",
    "înțepenește": "înțepeni",
    "înțepenești": "înțepeni",
    "înțepenii": "înțepeni",
    "înțepenim": "înțepeni",
    "înțepenind": "înțepeni",
    "înțepenindu": "înțepeni",
    "înțepeniră": "înțepeni",
    "înțepenirăm": "înțepeni",
    "înțepenirăți": "înțepeni",
    "înțepenise": "înțepeni",
    "înțepenisem": "înțepeni",
    "înțepeniseră": "înțepeni",
    "înțepeniserăm": "înțepeni",
    "înțepeniserăți": "înțepeni",
    "înțepeniseși": "înțepeni",
    "înțepeniși": "înțepeni",
    "înțepenit": "înțepeni",
    "înțepeniți": "înțepeni",
    "înțepenitu": "înțepeni",
    "neînțepenind": "înțepeni",
    "neînțepenindu": "înțepeni",
    "nemaiînțepenind": "înțepeni",
    "nemaiînțepenindu": "înțepeni",
    "înțepenită": "înțepenit",
    "înțepenite": "înțepenit",
    "înțepeniți": "înțepenit",
    "înțepușă": "înțepușa",
    "înțepușai": "înțepușa",
    "înțepușam": "înțepușa",
    "înțepușăm": "înțepușa",
    "înțepușând": "înțepușa",
    "înțepușându": "înțepușa",
    "înțepușară": "înțepușa",
    "înțepușarăm": "înțepușa",
    "înțepușarăți": "înțepușa",
    "înțepușase": "înțepușa",
    "înțepușasem": "înțepușa",
    "înțepușaseră": "înțepușa",
    "înțepușaserăm": "înțepușa",
    "înțepușaserăți": "înțepușa",
    "înțepușaseși": "înțepușa",
    "înțepușași": "înțepușa",
    "înțepușat": "înțepușa",
    "înțepușați": "înțepușa",
    "înțepușatu": "înțepușa",
    "înțepușau": "înțepușa",
    "înțepușează": "înțepușa",
    "înțepușez": "înțepușa",
    "înțepușeze": "înțepușa",
    "înțepușezi": "înțepușa",
    "neînțepușând": "înțepușa",
    "neînțepușându": "înțepușa",
    "nemaiînțepușând": "înțepușa",
    "nemaiînțepușându": "înțepușa",
    "înțepușată": "înțepușat",
    "înțepușate": "înțepușat",
    "înțepușați": "înțepușat",
    "interacțiunea": "interacțiune",
    "interacțiuni": "interacțiune",
    "interacțiunii": "interacțiune",
    "interacțiunile": "interacțiune",
    "interacțiunilor": "interacțiune",
    "interbancara": "interbancar",
    "interbancară": "interbancar",
    "interbancare": "interbancar",
    "interbancarei": "interbancar",
    "interbancarele": "interbancar",
    "interbancarelor": "interbancar",
    "interbancari": "interbancar",
    "interbancarii": "interbancar",
    "interbancarilor": "interbancar",
    "interbancarul": "interbancar",
    "interbancarului": "interbancar",
    "interbelica": "interbelic",
    "interbelică": "interbelic",
    "interbelice": "interbelic",
    "interbelicei": "interbelic",
    "interbelicele": "interbelic",
    "interbelicelor": "interbelic",
    "interbelici": "interbelic",
    "interbelicii": "interbelic",
    "interbelicilor": "interbelic",
    "interbelicul": "interbelic",
    "interbelicului": "interbelic",
    "intercală": "intercala",
    "intercalai": "intercala",
    "intercalam": "intercala",
    "intercalăm": "intercala",
    "intercalând": "intercala",
    "intercalându": "intercala",
    "intercalară": "intercala",
    "intercalarăm": "intercala",
    "intercalarăți": "intercala",
    "intercalase": "intercala",
    "intercalasem": "intercala",
    "intercalaseră": "intercala",
    "intercalaserăm": "intercala",
    "intercalaserăți": "intercala",
    "intercalaseși": "intercala",
    "intercalași": "intercala",
    "intercalat": "intercala",
    "intercalați": "intercala",
    "intercalatu": "intercala",
    "intercalau": "intercala",
    "intercalează": "intercala",
    "intercalez": "intercala",
    "intercaleze": "intercala",
    "intercalezi": "intercala",
    "neintercalând": "intercala",
    "neintercalându": "intercala",
    "nemaiintercalând": "intercala",
    "nemaiintercalându": "intercala",
    "intercalarea": "intercalare",
    "intercalareo": "intercalare",
    "intercalări": "intercalare",
    "intercalării": "intercalare",
    "intercalările": "intercalare",
    "intercalărilor": "intercalare",
    "intercalată": "intercalat",
    "intercalate": "intercalat",
    "intercalați": "intercalat",
    "interceptă": "intercepta",
    "interceptai": "intercepta",
    "interceptam": "intercepta",
    "interceptăm": "intercepta",
    "interceptând": "intercepta",
    "interceptându": "intercepta",
    "interceptară": "intercepta",
    "interceptarăm": "intercepta",
    "interceptarăți": "intercepta",
    "interceptase": "intercepta",
    "interceptasem": "intercepta",
    "interceptaseră": "intercepta",
    "interceptaserăm": "intercepta",
    "interceptaserăți": "intercepta",
    "interceptaseși": "intercepta",
    "interceptași": "intercepta",
    "interceptat": "intercepta",
    "interceptați": "intercepta",
    "interceptatu": "intercepta",
    "interceptau": "intercepta",
    "interceptează": "intercepta",
    "interceptez": "intercepta",
    "intercepteze": "intercepta",
    "interceptezi": "intercepta",
    "neinterceptând": "intercepta",
    "neinterceptându": "intercepta",
    "nemaiinterceptând": "intercepta",
    "nemaiinterceptându": "intercepta",
    "interceptarea": "interceptare",
    "interceptări": "interceptare",
    "interceptării": "interceptare",
    "interceptările": "interceptare",
    "interceptărilor": "interceptare",
    "interceptată": "interceptat",
    "interceptate": "interceptat",
    "interceptați": "interceptat",
    "interconectă": "interconecta",
    "interconectai": "interconecta",
    "interconectam": "interconecta",
    "interconectăm": "interconecta",
    "interconectând": "interconecta",
    "interconectându": "interconecta",
    "interconectară": "interconecta",
    "interconectarăm": "interconecta",
    "interconectarăți": "interconecta",
    "interconectase": "interconecta",
    "interconectasem": "interconecta",
    "interconectaseră": "interconecta",
    "interconectaserăm": "interconecta",
    "interconectaserăți": "interconecta",
    "interconectaseși": "interconecta",
    "interconectași": "interconecta",
    "interconectat": "interconecta",
    "interconectați": "interconecta",
    "interconectatu": "interconecta",
    "interconectau": "interconecta",
    "interconectează": "interconecta",
    "interconectez": "interconecta",
    "interconecteze": "interconecta",
    "interconectezi": "interconecta",
    "neinterconectând": "interconecta",
    "neinterconectându": "interconecta",
    "nemaiinterconectând": "interconecta",
    "nemaiinterconectându": "interconecta",
    "interconectată": "interconectat",
    "interconectate": "interconectat",
    "interconectați": "interconectat",
    "interconexiunea": "interconexiune",
    "interconexiuni": "interconexiune",
    "interconexiunii": "interconexiune",
    "interconexiunile": "interconexiune",
    "interconexiunilor": "interconexiune",
    "interdependenta": "interdependent",
    "interdependentă": "interdependent",
    "interdependente": "interdependent",
    "interdependentei": "interdependent",
    "interdependentele": "interdependent",
    "interdependentelor": "interdependent",
    "interdependenți": "interdependent",
    "interdependenții": "interdependent",
    "interdependenților": "interdependent",
    "interdependentul": "interdependent",
    "interdependentului": "interdependent",
    "interdependența": "interdependență",
    "interdependențe": "interdependență",
    "interdependenței": "interdependență",
    "interdependențele": "interdependență",
    "interdependențelor": "interdependență",
    "interdicția": "interdicție",
    "interdicției": "interdicție",
    "interdicții": "interdicție",
    "interdicțiile": "interdicție",
    "interdicțiilor": "interdicție",
    "interese": "interes",
    "interesele": "interes",
    "intereselor": "interes",
    "interesul": "interes",
    "interesului": "interes",
    "interesă": "interesa",
    "interesai": "interesa",
    "interesam": "interesa",
    "interesăm": "interesa",
    "interesând": "interesa",
    "interesându": "interesa",
    "interesară": "interesa",
    "interesarăm": "interesa",
    "interesarăți": "interesa",
    "interesase": "interesa",
    "interesasem": "interesa",
    "interesaseră": "interesa",
    "interesaserăm": "interesa",
    "interesaserăți": "interesa",
    "interesaseși": "interesa",
    "interesași": "interesa",
    "interesat": "interesa",
    "interesați": "interesa",
    "interesatu": "interesa",
    "interesau": "interesa",
    "interesează": "interesa",
    "interesez": "interesa",
    "intereseze": "interesa",
    "interesezi": "interesa",
    "neinteresând": "interesa",
    "neinteresându": "interesa",
    "nemaiinteresând": "interesa",
    "nemaiinteresându": "interesa",
    "interesanta": "interesant",
    "interesantă": "interesant",
    "interesante": "interesant",
    "interesantei": "interesant",
    "interesantele": "interesant",
    "interesantelor": "interesant",
    "interesanți": "interesant",
    "interesanții": "interesant",
    "interesanților": "interesant",
    "interesantul": "interesant",
    "interesantului": "interesant",
    "interesată": "interesat",
    "interesate": "interesat",
    "interesați": "interesat",
    "interferă": "interfera",
    "interferai": "interfera",
    "interferam": "interfera",
    "interferăm": "interfera",
    "interferând": "interfera",
    "interferându": "interfera",
    "interferară": "interfera",
    "interferarăm": "interfera",
    "interferarăți": "interfera",
    "interferase": "interfera",
    "interferasem": "interfera",
    "interferaseră": "interfera",
    "interferaserăm": "interfera",
    "interferaserăți": "interfera",
    "interferaseși": "interfera",
    "interferași": "interfera",
    "interferat": "interfera",
    "interferați": "interfera",
    "interferatu": "interfera",
    "interferau": "interfera",
    "interferează": "interfera",
    "interferez": "interfera",
    "interfereze": "interfera",
    "interferezi": "interfera",
    "neinterferând": "interfera",
    "neinterferându": "interfera",
    "nemaiinterferând": "interfera",
    "nemaiinterferându": "interfera",
    "interferată": "interferat",
    "interferate": "interferat",
    "interferați": "interferat",
    "interferența": "interferență",
    "interferențe": "interferență",
    "interferenței": "interferență",
    "interferențele": "interferență",
    "interferențelor": "interferență",
    "interfoliai": "interfolia",
    "interfoliam": "interfolia",
    "interfoliară": "interfolia",
    "interfoliarăm": "interfolia",
    "interfoliarăți": "interfolia",
    "interfoliase": "interfolia",
    "interfoliasem": "interfolia",
    "interfoliaseră": "interfolia",
    "interfoliaserăm": "interfolia",
    "interfoliaserăți": "interfolia",
    "interfoliaseși": "interfolia",
    "interfoliași": "interfolia",
    "interfoliat": "interfolia",
    "interfoliați": "interfolia",
    "interfoliatu": "interfolia",
    "interfoliau": "interfolia",
    "interfoliază": "interfolia",
    "interfolie": "interfolia",
    "interfoliem": "interfolia",
    "interfoliez": "interfolia",
    "interfolieze": "interfolia",
    "interfoliezi": "interfolia",
    "interfoliind": "interfolia",
    "interfoliindu": "interfolia",
    "neinterfoliind": "interfolia",
    "neinterfoliindu": "interfolia",
    "nemaiinterfoliind": "interfolia",
    "nemaiinterfoliindu": "interfolia",
    "interfoliată": "interfoliat",
    "interfoliate": "interfoliat",
    "interfoliați": "interfoliat",
    "interguvernamentală": "interguvernamental",
    "interguvernamentale": "interguvernamental",
    "interguvernamentali": "interguvernamental",
    "interimara": "interimar",
    "interimară": "interimar",
    "interimare": "interimar",
    "interimarei": "interimar",
    "interimarele": "interimar",
    "interimarelor": "interimar",
    "interimari": "interimar",
    "interimarii": "interimar",
    "interimarilor": "interimar",
    "interimarul": "interimar",
    "interimarului": "interimar",
    "interimate": "interimat",
    "interimatele": "interimat",
    "interimatelor": "interimat",
    "interimatul": "interimat",
    "interimatului": "interimat",
    "int.": "interior",
    "interioara": "interior",
    "interioară": "interior",
    "interioare": "interior",
    "interioarei": "interior",
    "interioarele": "interior",
    "interioarelor": "interior",
    "interiori": "interior",
    "interiorii": "interior",
    "interiorilor": "interior",
    "interiorul": "interior",
    "interiorului": "interior",
    "interiorizata": "interiorizat",
    "interiorizată": "interiorizat",
    "interiorizate": "interiorizat",
    "interiorizatei": "interiorizat",
    "interiorizatele": "interiorizat",
    "interiorizatelor": "interiorizat",
    "interiorizați": "interiorizat",
    "interiorizații": "interiorizat",
    "interiorizaților": "interiorizat",
    "interiorizato": "interiorizat",
    "interiorizatul": "interiorizat",
    "interiorizatule": "interiorizat",
    "interiorizatului": "interiorizat",
    "interj.": "interjecție",
    "interjecția": "interjecție",
    "interjecției": "interjecție",
    "interjecții": "interjecție",
    "interjecțiile": "interjecție",
    "interjecțiilor": "interjecție",
    "interjudețeana": "interjudețean",
    "interjudețeană": "interjudețean",
    "interjudețeanul": "interjudețean",
    "interjudețeanului": "interjudețean",
    "interjudețene": "interjudețean",
    "interjudețenei": "interjudețean",
    "interjudețenele": "interjudețean",
    "interjudețenelor": "interjudețean",
    "interjudețeni": "interjudețean",
    "interjudețenii": "interjudețean",
    "interjudețenilor": "interjudețean",
    "interliniai": "interlinia",
    "interliniam": "interlinia",
    "interliniară": "interlinia",
    "interliniarăm": "interlinia",
    "interliniarăți": "interlinia",
    "interliniase": "interlinia",
    "interliniasem": "interlinia",
    "interliniaseră": "interlinia",
    "interliniaserăm": "interlinia",
    "interliniaserăți": "interlinia",
    "interliniaseși": "interlinia",
    "interliniași": "interlinia",
    "interliniat": "interlinia",
    "interliniați": "interlinia",
    "interliniatu": "interlinia",
    "interliniau": "interlinia",
    "interliniază": "interlinia",
    "interlinie": "interlinia",
    "interliniem": "interlinia",
    "interliniez": "interlinia",
    "interlinieze": "interlinia",
    "interliniezi": "interlinia",
    "interliniind": "interlinia",
    "interliniindu": "interlinia",
    "neinterliniind": "interlinia",
    "neinterliniindu": "interlinia",
    "nemaiinterliniind": "interlinia",
    "nemaiinterliniindu": "interlinia",
    "interliniată": "interliniat",
    "interliniate": "interliniat",
    "interliniați": "interliniat",
    "interlocutori": "interlocutor",
    "interlocutorii": "interlocutor",
    "interlocutorilor": "interlocutor",
    "interlocutorul": "interlocutor",
    "interlocutorului": "interlocutor",
    "interlopa": "interlop",
    "interlopă": "interlop",
    "interlope": "interlop",
    "interlopei": "interlop",
    "interlopele": "interlop",
    "interlopelor": "interlop",
    "interlopi": "interlop",
    "interlopii": "interlop",
    "interlopilor": "interlop",
    "interlopul": "interlop",
    "interlopului": "interlop",
    "intermediai": "intermedia",
    "intermediam": "intermedia",
    "intermediară": "intermedia",
    "intermediarăm": "intermedia",
    "intermediarăți": "intermedia",
    "intermediase": "intermedia",
    "intermediasem": "intermedia",
    "intermediaseră": "intermedia",
    "intermediaserăm": "intermedia",
    "intermediaserăți": "intermedia",
    "intermediaseși": "intermedia",
    "intermediași": "intermedia",
    "intermediat": "intermedia",
    "intermediați": "intermedia",
    "intermediatu": "intermedia",
    "intermediau": "intermedia",
    "intermediază": "intermedia",
    "intermedie": "intermedia",
    "intermediem": "intermedia",
    "intermediez": "intermedia",
    "intermedieze": "intermedia",
    "intermediezi": "intermedia",
    "intermediind": "intermedia",
    "intermediindu": "intermedia",
    "neintermediind": "intermedia",
    "neintermediindu": "intermedia",
    "nemaiintermediind": "intermedia",
    "nemaiintermediindu": "intermedia",
    "intermediara": "intermediar",
    "intermediară": "intermediar",
    "intermediare": "intermediar",
    "intermediarei": "intermediar",
    "intermediarele": "intermediar",
    "intermediarelor": "intermediar",
    "intermediari": "intermediar",
    "intermediarii": "intermediar",
    "intermediarilor": "intermediar",
    "intermediarul": "intermediar",
    "intermediarului": "intermediar",
    "intermediată": "intermediat",
    "intermediate": "intermediat",
    "intermediați": "intermediat",
    "intermedii": "intermediu",
    "intermediile": "intermediu",
    "intermediilor": "intermediu",
    "intermediul": "intermediu",
    "intermediului": "intermediu",
    "intermezzoul": "intermezzo",
    "intermezzoului": "intermezzo",
    "interminabila": "interminabil",
    "interminabilă": "interminabil",
    "interminabile": "interminabil",
    "interminabilei": "interminabil",
    "interminabilele": "interminabil",
    "interminabilelor": "interminabil",
    "interminabili": "interminabil",
    "interminabilii": "interminabil",
    "interminabililor": "interminabil",
    "interminabilul": "interminabil",
    "interminabilului": "interminabil",
    "intermitenta": "intermitent",
    "intermitentă": "intermitent",
    "intermitente": "intermitent",
    "intermitentei": "intermitent",
    "intermitentele": "intermitent",
    "intermitentelor": "intermitent",
    "intermitenți": "intermitent",
    "intermitenții": "intermitent",
    "intermitenților": "intermitent",
    "intermitentul": "intermitent",
    "intermitentului": "intermitent",
    "interna": "intern",
    "internă": "intern",
    "interne": "intern",
    "internei": "intern",
    "internele": "intern",
    "internelor": "intern",
    "interni": "intern",
    "internii": "intern",
    "internilor": "intern",
    "internul": "intern",
    "internului": "intern",
    "internă": "interna",
    "internai": "interna",
    "internam": "interna",
    "internăm": "interna",
    "internând": "interna",
    "internându": "interna",
    "internară": "interna",
    "internarăm": "interna",
    "internarăți": "interna",
    "internase": "interna",
    "internasem": "interna",
    "internaseră": "interna",
    "internaserăm": "interna",
    "internaserăți": "interna",
    "internaseși": "interna",
    "internași": "interna",
    "internat": "interna",
    "internați": "interna",
    "internatu": "interna",
    "internau": "interna",
    "internează": "interna",
    "internez": "interna",
    "interneze": "interna",
    "internezi": "interna",
    "neinternând": "interna",
    "neinternându": "interna",
    "nemaiinternând": "interna",
    "nemaiinternându": "interna",
    "internarea": "internare",
    "internări": "internare",
    "internării": "internare",
    "internările": "internare",
    "internărilor": "internare",
    "internată": "internat",
    "internate": "internat",
    "internatele": "internat",
    "internatelor": "internat",
    "internați": "internat",
    "internatul": "internat",
    "internatului": "internat",
    "internaționala": "internațional",
    "internațională": "internațional",
    "internaționale": "internațional",
    "internaționalei": "internațional",
    "internaționalele": "internațional",
    "internaționalelor": "internațional",
    "internaționali": "internațional",
    "internaționalii": "internațional",
    "internaționalilor": "internațional",
    "internaționalul": "internațional",
    "internaționalului": "internațional",
    "internaționalismul": "internaționalism",
    "internaționalismului": "internaționalism",
    "interniști": "internist",
    "interniștii": "internist",
    "interniștilor": "internist",
    "internistul": "internist",
    "internistului": "internist",
    "interogă": "interoga",
    "interogai": "interoga",
    "interogam": "interoga",
    "interogăm": "interoga",
    "interogând": "interoga",
    "interogându": "interoga",
    "interogară": "interoga",
    "interogarăm": "interoga",
    "interogarăți": "interoga",
    "interogase": "interoga",
    "interogasem": "interoga",
    "interogaseră": "interoga",
    "interogaserăm": "interoga",
    "interogaserăți": "interoga",
    "interogaseși": "interoga",
    "interogași": "interoga",
    "interogat": "interoga",
    "interogați": "interoga",
    "interogatu": "interoga",
    "interogau": "interoga",
    "interoghează": "interoga",
    "interoghez": "interoga",
    "interogheze": "interoga",
    "interoghezi": "interoga",
    "neinterogând": "interoga",
    "neinterogându": "interoga",
    "nemaiinterogând": "interoga",
    "nemaiinterogându": "interoga",
    "interogată": "interogat",
    "interogate": "interogat",
    "interogați": "interogat",
    "interogația": "interogație",
    "interogației": "interogație",
    "interogații": "interogație",
    "interogațiile": "interogație",
    "interogațiilor": "interogație",
    "interogativa": "interogativ",
    "interogativă": "interogativ",
    "interogative": "interogativ",
    "interogativei": "interogativ",
    "interogativele": "interogativ",
    "interogativelor": "interogativ",
    "interogativi": "interogativ",
    "interogativii": "interogativ",
    "interogativilor": "interogativ",
    "interogativul": "interogativ",
    "interogativului": "interogativ",
    "interogatori": "interogator",
    "interogatorii": "interogator",
    "interogatorilor": "interogator",
    "interogatorul": "interogator",
    "interogatorului": "interogator",
    "interogatorii": "interogatoriu",
    "interogatoriile": "interogatoriu",
    "interogatoriilor": "interogatoriu",
    "interogatoriul": "interogatoriu",
    "interogatoriului": "interogatoriu",
    "interpelă": "interpela",
    "interpelai": "interpela",
    "interpelam": "interpela",
    "interpelăm": "interpela",
    "interpelând": "interpela",
    "interpelându": "interpela",
    "interpelară": "interpela",
    "interpelarăm": "interpela",
    "interpelarăți": "interpela",
    "interpelase": "interpela",
    "interpelasem": "interpela",
    "interpelaseră": "interpela",
    "interpelaserăm": "interpela",
    "interpelaserăți": "interpela",
    "interpelaseși": "interpela",
    "interpelași": "interpela",
    "interpelat": "interpela",
    "interpelați": "interpela",
    "interpelatu": "interpela",
    "interpelau": "interpela",
    "interpelează": "interpela",
    "interpelez": "interpela",
    "interpeleze": "interpela",
    "interpelezi": "interpela",
    "neinterpelând": "interpela",
    "neinterpelându": "interpela",
    "nemaiinterpelând": "interpela",
    "nemaiinterpelându": "interpela",
    "interpelată": "interpelat",
    "interpelate": "interpelat",
    "interpelați": "interpelat",
    "interplanetara": "interplanetar",
    "interplanetară": "interplanetar",
    "interplanetare": "interplanetar",
    "interplanetarei": "interplanetar",
    "interplanetarele": "interplanetar",
    "interplanetarelor": "interplanetar",
    "interplanetari": "interplanetar",
    "interplanetarii": "interplanetar",
    "interplanetarilor": "interplanetar",
    "interplanetarul": "interplanetar",
    "interplanetarului": "interplanetar",
    "interpolă": "interpola",
    "interpolai": "interpola",
    "interpolam": "interpola",
    "interpolăm": "interpola",
    "interpolând": "interpola",
    "interpolându": "interpola",
    "interpolară": "interpola",
    "interpolarăm": "interpola",
    "interpolarăți": "interpola",
    "interpolase": "interpola",
    "interpolasem": "interpola",
    "interpolaseră": "interpola",
    "interpolaserăm": "interpola",
    "interpolaserăți": "interpola",
    "interpolaseși": "interpola",
    "interpolași": "interpola",
    "interpolat": "interpola",
    "interpolați": "interpola",
    "interpolatu": "interpola",
    "interpolau": "interpola",
    "interpolează": "interpola",
    "interpolez": "interpola",
    "interpoleze": "interpola",
    "interpolezi": "interpola",
    "neinterpolând": "interpola",
    "neinterpolându": "interpola",
    "nemaiinterpolând": "interpola",
    "nemaiinterpolându": "interpola",
    "interpolată": "interpolat",
    "interpolate": "interpolat",
    "interpolați": "interpolat",
    "interpreți": "interpret",
    "interpreții": "interpret",
    "interpreților": "interpret",
    "interpretul": "interpret",
    "interpretului": "interpret",
    "interpretă": "interpreta",
    "interpretai": "interpreta",
    "interpretam": "interpreta",
    "interpretăm": "interpreta",
    "interpretând": "interpreta",
    "interpretându": "interpreta",
    "interpretară": "interpreta",
    "interpretarăm": "interpreta",
    "interpretarăți": "interpreta",
    "interpretase": "interpreta",
    "interpretasem": "interpreta",
    "interpretaseră": "interpreta",
    "interpretaserăm": "interpreta",
    "interpretaserăți": "interpreta",
    "interpretaseși": "interpreta",
    "interpretași": "interpreta",
    "interpretat": "interpreta",
    "interpretați": "interpreta",
    "interpretatu": "interpreta",
    "interpretau": "interpreta",
    "interpretează": "interpreta",
    "interpretez": "interpreta",
    "interpreteze": "interpreta",
    "interpretezi": "interpreta",
    "neinterpretând": "interpreta",
    "neinterpretându": "interpreta",
    "nemaiinterpretând": "interpreta",
    "nemaiinterpretându": "interpreta",
    "interpretarea": "interpretare",
    "interpretări": "interpretare",
    "interpretării": "interpretare",
    "interpretările": "interpretare",
    "interpretărilor": "interpretare",
    "interpretată": "interpretat",
    "interpretate": "interpretat",
    "interpretați": "interpretat",
    "interpui": "interpune",
    "interpun": "interpune",
    "interpună": "interpune",
    "interpunând": "interpune",
    "interpunându": "interpune",
    "interpunea": "interpune",
    "interpuneai": "interpune",
    "interpuneam": "interpune",
    "interpuneați": "interpune",
    "interpuneau": "interpune",
    "interpunem": "interpune",
    "interpuneți": "interpune",
    "interpus": "interpune",
    "interpuse": "interpune",
    "interpusei": "interpune",
    "interpuseră": "interpune",
    "interpuserăm": "interpune",
    "interpuserăți": "interpune",
    "interpusese": "interpune",
    "interpusesem": "interpune",
    "interpuseseră": "interpune",
    "interpuseserăm": "interpune",
    "interpuseserăți": "interpune",
    "interpuseseși": "interpune",
    "interpuseși": "interpune",
    "interpusu": "interpune",
    "neinterpunând": "interpune",
    "neinterpunându": "interpune",
    "nemaiinterpunând": "interpune",
    "nemaiinterpunându": "interpune",
    "interpusă": "interpus",
    "interpuse": "interpus",
    "interpuși": "interpus",
    "intersectă": "intersecta",
    "intersectai": "intersecta",
    "intersectam": "intersecta",
    "intersectăm": "intersecta",
    "intersectând": "intersecta",
    "intersectându": "intersecta",
    "intersectară": "intersecta",
    "intersectarăm": "intersecta",
    "intersectarăți": "intersecta",
    "intersectase": "intersecta",
    "intersectasem": "intersecta",
    "intersectaseră": "intersecta",
    "intersectaserăm": "intersecta",
    "intersectaserăți": "intersecta",
    "intersectaseși": "intersecta",
    "intersectași": "intersecta",
    "intersectat": "intersecta",
    "intersectați": "intersecta",
    "intersectatu": "intersecta",
    "intersectau": "intersecta",
    "intersectează": "intersecta",
    "intersectez": "intersecta",
    "intersecteze": "intersecta",
    "intersectezi": "intersecta",
    "neintersectând": "intersecta",
    "neintersectându": "intersecta",
    "nemaiintersectând": "intersecta",
    "nemaiintersectându": "intersecta",
    "intersectată": "intersectat",
    "intersectate": "intersectat",
    "intersectați": "intersectat",
    "intersecția": "intersecție",
    "intersecției": "intersecție",
    "intersecții": "intersecție",
    "intersecțiile": "intersecție",
    "intersecțiilor": "intersecție",
    "interstelara": "interstelar",
    "interstelară": "interstelar",
    "interstelare": "interstelar",
    "interstelarei": "interstelar",
    "interstelarele": "interstelar",
    "interstelarelor": "interstelar",
    "interstelari": "interstelar",
    "interstelarii": "interstelar",
    "interstelarilor": "interstelar",
    "interstelarul": "interstelar",
    "interstelarului": "interstelar",
    "interurbana": "interurban",
    "interurbană": "interurban",
    "interurbane": "interurban",
    "interurbanei": "interurban",
    "interurbanele": "interurban",
    "interurbanelor": "interurban",
    "interurbani": "interurban",
    "interurbanii": "interurban",
    "interurbanilor": "interurban",
    "interurbanul": "interurban",
    "interurbanului": "interurban",
    "intervale": "interval",
    "intervalele": "interval",
    "intervalelor": "interval",
    "intervalul": "interval",
    "intervalului": "interval",
    "intervenea": "interveni",
    "interveneai": "interveni",
    "interveneam": "interveni",
    "interveneați": "interveni",
    "interveneau": "interveni",
    "intervenii": "interveni",
    "intervenim": "interveni",
    "intervenind": "interveni",
    "intervenindu": "interveni",
    "interveniră": "interveni",
    "intervenirăm": "interveni",
    "intervenirăți": "interveni",
    "intervenise": "interveni",
    "intervenisem": "interveni",
    "interveniseră": "interveni",
    "interveniserăm": "interveni",
    "interveniserăți": "interveni",
    "interveniseși": "interveni",
    "interveniși": "interveni",
    "intervenit": "interveni",
    "interveniți": "interveni",
    "intervenitu": "interveni",
    "intervii": "interveni",
    "intervin": "interveni",
    "intervină": "interveni",
    "intervine": "interveni",
    "intervino": "interveni",
    "neintervenind": "interveni",
    "neintervenindu": "interveni",
    "nemaiintervenind": "interveni",
    "nemaiintervenindu": "interveni",
    "intervenită": "intervenit",
    "intervenite": "intervenit",
    "interveniți": "intervenit",
    "intervenția": "intervenție",
    "intervenției": "intervenție",
    "intervenții": "intervenție",
    "intervențiile": "intervenție",
    "intervențiilor": "intervenție",
    "intervertea": "interverti",
    "interverteai": "interverti",
    "interverteam": "interverti",
    "intervertească": "interverti",
    "interverteați": "interverti",
    "interverteau": "interverti",
    "intervertesc": "interverti",
    "intervertește": "interverti",
    "intervertești": "interverti",
    "intervertii": "interverti",
    "intervertim": "interverti",
    "intervertind": "interverti",
    "intervertindu": "interverti",
    "intervertiră": "interverti",
    "intervertirăm": "interverti",
    "intervertirăți": "interverti",
    "intervertise": "interverti",
    "intervertisem": "interverti",
    "intervertiseră": "interverti",
    "intervertiserăm": "interverti",
    "intervertiserăți": "interverti",
    "intervertiseși": "interverti",
    "intervertiși": "interverti",
    "intervertit": "interverti",
    "intervertiți": "interverti",
    "intervertitu": "interverti",
    "neintervertind": "interverti",
    "neintervertindu": "interverti",
    "nemaiintervertind": "interverti",
    "nemaiintervertindu": "interverti",
    "intervertită": "intervertit",
    "intervertite": "intervertit",
    "intervertiți": "intervertit",
    "intervievă": "intervieva",
    "intervievai": "intervieva",
    "intervievam": "intervieva",
    "intervievăm": "intervieva",
    "intervievând": "intervieva",
    "intervievându": "intervieva",
    "intervievară": "intervieva",
    "intervievarăm": "intervieva",
    "intervievarăți": "intervieva",
    "intervievase": "intervieva",
    "intervievasem": "intervieva",
    "intervievaseră": "intervieva",
    "intervievaserăm": "intervieva",
    "intervievaserăți": "intervieva",
    "intervievaseși": "intervieva",
    "intervievași": "intervieva",
    "intervievat": "intervieva",
    "intervievați": "intervieva",
    "intervievatu": "intervieva",
    "intervievau": "intervieva",
    "intervievează": "intervieva",
    "intervievez": "intervieva",
    "intervieveze": "intervieva",
    "intervievezi": "intervieva",
    "neintervievând": "intervieva",
    "neintervievându": "intervieva",
    "nemaiintervievând": "intervieva",
    "nemaiintervievându": "intervieva",
    "intervievată": "intervievat",
    "intervievate": "intervievat",
    "intervievați": "intervievat",
    "interviul": "interviu",
    "interviului": "interviu",
    "interviuri": "interviu",
    "interviurile": "interviu",
    "interviurilor": "interviu",
    "interzic": "interzice",
    "interzică": "interzice",
    "interzicând": "interzice",
    "interzicându": "interzice",
    "interzicea": "interzice",
    "interziceai": "interzice",
    "interziceam": "interzice",
    "interziceați": "interzice",
    "interziceau": "interzice",
    "interzicem": "interzice",
    "interziceți": "interzice",
    "interzici": "interzice",
    "interzis": "interzice",
    "interzise": "interzice",
    "interzisei": "interzice",
    "interziseră": "interzice",
    "interziserăm": "interzice",
    "interziserăți": "interzice",
    "interzisese": "interzice",
    "interzisesem": "interzice",
    "interziseseră": "interzice",
    "interziseserăm": "interzice",
    "interziseserăți": "interzice",
    "interziseseși": "interzice",
    "interziseși": "interzice",
    "interzisu": "interzice",
    "neinterzicând": "interzice",
    "neinterzicându": "interzice",
    "nemaiinterzicând": "interzice",
    "nemaiinterzicându": "interzice",
    "interzicerea": "interzicere",
    "interziceri": "interzicere",
    "interzicerii": "interzicere",
    "interzicerile": "interzicere",
    "interzicerilor": "interzicere",
    "interzisa": "interzis",
    "interzisă": "interzis",
    "interzise": "interzis",
    "interzisei": "interzis",
    "interzisele": "interzis",
    "interziselor": "interzis",
    "interziși": "interzis",
    "interzișii": "interzis",
    "interzișilor": "interzis",
    "interzisul": "interzis",
    "interzisului": "interzis",
    "înțeasă": "înțesa",
    "înțes": "înțesa",
    "înțesă": "înțesa",
    "înțesai": "înțesa",
    "înțesam": "înțesa",
    "înțesăm": "înțesa",
    "înțesând": "înțesa",
    "înțesându": "înțesa",
    "înțesară": "înțesa",
    "înțesarăm": "înțesa",
    "înțesarăți": "înțesa",
    "înțesase": "înțesa",
    "înțesasem": "înțesa",
    "înțesaseră": "înțesa",
    "înțesaserăm": "înțesa",
    "înțesaserăți": "înțesa",
    "înțesaseși": "înțesa",
    "înțesași": "înțesa",
    "înțesat": "înțesa",
    "înțesați": "înțesa",
    "înțesatu": "înțesa",
    "înțesau": "înțesa",
    "înțese": "înțesa",
    "înțeși": "înțesa",
    "neînțesând": "înțesa",
    "neînțesându": "înțesa",
    "nemaiînțesând": "înțesa",
    "nemaiînțesându": "înțesa",
    "înțesată": "înțesat",
    "înțesate": "înțesat",
    "înțesați": "înțesat",
    "intestine": "intestin",
    "intestinele": "intestin",
    "intestinelor": "intestin",
    "intestinul": "intestin",
    "intestinului": "intestin",
    "intestinala": "intestinal",
    "intestinală": "intestinal",
    "intestinale": "intestinal",
    "intestinalei": "intestinal",
    "intestinalele": "intestinal",
    "intestinalelor": "intestinal",
    "intestinali": "intestinal",
    "intestinalii": "intestinal",
    "intestinalilor": "intestinal",
    "intestinalul": "intestinal",
    "intestinalului": "intestinal",
    "întețea": "înteți",
    "întețeai": "înteți",
    "întețeam": "înteți",
    "întețească": "înteți",
    "întețeați": "înteți",
    "întețeau": "înteți",
    "întețesc": "înteți",
    "întețește": "înteți",
    "întețești": "înteți",
    "înteții": "înteți",
    "întețim": "înteți",
    "întețind": "înteți",
    "întețindu": "înteți",
    "întețiră": "înteți",
    "întețirăm": "înteți",
    "întețirăți": "înteți",
    "întețise": "înteți",
    "întețisem": "înteți",
    "întețiseră": "înteți",
    "întețiserăm": "înteți",
    "întețiserăți": "înteți",
    "întețiseși": "înteți",
    "întețiși": "înteți",
    "întețit": "înteți",
    "întețiți": "înteți",
    "întețitu": "înteți",
    "neîntețind": "înteți",
    "neîntețindu": "înteți",
    "nemaiîntețind": "înteți",
    "nemaiîntețindu": "înteți",
    "întețirea": "întețire",
    "întețiri": "întețire",
    "întețirii": "întețire",
    "întețirile": "întețire",
    "întețirilor": "întețire",
    "întețită": "întețit",
    "întețite": "întețit",
    "întețiți": "întețit",
    "intima": "intim",
    "intimă": "intim",
    "intime": "intim",
    "intimei": "intim",
    "intimele": "intim",
    "intimelor": "intim",
    "intimi": "intim",
    "intimii": "intim",
    "intimilor": "intim",
    "intimul": "intim",
    "intimului": "intim",
    "intimă": "intima",
    "intimai": "intima",
    "intimam": "intima",
    "intimăm": "intima",
    "intimând": "intima",
    "intimându": "intima",
    "intimară": "intima",
    "intimarăm": "intima",
    "intimarăți": "intima",
    "intimase": "intima",
    "intimasem": "intima",
    "intimaseră": "intima",
    "intimaserăm": "intima",
    "intimaserăți": "intima",
    "intimaseși": "intima",
    "intimași": "intima",
    "intimat": "intima",
    "intimați": "intima",
    "intimatu": "intima",
    "intimau": "intima",
    "intimează": "intima",
    "intimez": "intima",
    "intimeze": "intima",
    "intimezi": "intima",
    "neintimând": "intima",
    "neintimându": "intima",
    "nemaiintimând": "intima",
    "nemaiintimându": "intima",
    "intimată": "intimat",
    "intimate": "intimat",
    "intimați": "intimat",
    "intimidă": "intimida",
    "intimidai": "intimida",
    "intimidam": "intimida",
    "intimidăm": "intimida",
    "intimidând": "intimida",
    "intimidându": "intimida",
    "intimidară": "intimida",
    "intimidarăm": "intimida",
    "intimidarăți": "intimida",
    "intimidase": "intimida",
    "intimidasem": "intimida",
    "intimidaseră": "intimida",
    "intimidaserăm": "intimida",
    "intimidaserăți": "intimida",
    "intimidaseși": "intimida",
    "intimidași": "intimida",
    "intimidat": "intimida",
    "intimidați": "intimida",
    "intimidatu": "intimida",
    "intimidau": "intimida",
    "intimidează": "intimida",
    "intimidez": "intimida",
    "intimideze": "intimida",
    "intimidezi": "intimida",
    "neintimidând": "intimida",
    "neintimidându": "intimida",
    "nemaiintimidând": "intimida",
    "nemaiintimidându": "intimida",
    "intimidarea": "intimidare",
    "intimidareo": "intimidare",
    "intimidări": "intimidare",
    "intimidării": "intimidare",
    "intimidările": "intimidare",
    "intimidărilor": "intimidare",
    "intimidata": "intimidat",
    "intimidată": "intimidat",
    "intimidate": "intimidat",
    "intimidatei": "intimidat",
    "intimidatele": "intimidat",
    "intimidatelor": "intimidat",
    "intimidați": "intimidat",
    "intimidații": "intimidat",
    "intimidaților": "intimidat",
    "intimidato": "intimidat",
    "intimidatul": "intimidat",
    "intimidatule": "intimidat",
    "intimidatului": "intimidat",
    "intimitatea": "intimitate",
    "intimități": "intimitate",
    "intimității": "intimitate",
    "intimitățile": "intimitate",
    "intimităților": "intimitate",
    "întină": "întina",
    "întinai": "întina",
    "întinam": "întina",
    "întinăm": "întina",
    "întinând": "întina",
    "întinându": "întina",
    "întinară": "întina",
    "întinarăm": "întina",
    "întinarăți": "întina",
    "întinase": "întina",
    "întinasem": "întina",
    "întinaseră": "întina",
    "întinaserăm": "întina",
    "întinaserăți": "întina",
    "întinaseși": "întina",
    "întinași": "întina",
    "întinat": "întina",
    "întinați": "întina",
    "întinatu": "întina",
    "întinau": "întina",
    "întinează": "întina",
    "întinez": "întina",
    "întineze": "întina",
    "întinezi": "întina",
    "neîntinând": "întina",
    "neîntinându": "întina",
    "nemaiîntinând": "întina",
    "nemaiîntinându": "întina",
    "întinată": "întinat",
    "întinate": "întinat",
    "întinați": "întinat",
    "întind": "întinde",
    "întindă": "întinde",
    "întindea": "întinde",
    "întindeai": "întinde",
    "întindeam": "întinde",
    "întindeați": "întinde",
    "întindeau": "întinde",
    "întindem": "întinde",
    "întindeți": "întinde",
    "întins": "întinde",
    "întinse": "întinde",
    "întinsei": "întinde",
    "întinseră": "întinde",
    "întinserăm": "întinde",
    "întinserăți": "întinde",
    "întinsese": "întinde",
    "întinsesem": "întinde",
    "întinseseră": "întinde",
    "întinseserăm": "întinde",
    "întinseserăți": "întinde",
    "întinseseși": "întinde",
    "întinseși": "întinde",
    "întinsu": "întinde",
    "întinzând": "întinde",
    "întinzându": "întinde",
    "întinzi": "întinde",
    "neîntinzând": "întinde",
    "neîntinzându": "întinde",
    "nemaiîntinzând": "întinde",
    "nemaiîntinzându": "întinde",
    "întinderea": "întindere",
    "întinderi": "întindere",
    "întinderii": "întindere",
    "întinderile": "întindere",
    "întinderilor": "întindere",
    "întinerea": "întineri",
    "întinereai": "întineri",
    "întineream": "întineri",
    "întinerească": "întineri",
    "întinereați": "întineri",
    "întinereau": "întineri",
    "întineresc": "întineri",
    "întinerește": "întineri",
    "întinerești": "întineri",
    "întinerii": "întineri",
    "întinerim": "întineri",
    "întinerind": "întineri",
    "întinerindu": "întineri",
    "întineriră": "întineri",
    "întinerirăm": "întineri",
    "întinerirăți": "întineri",
    "întinerise": "întineri",
    "întinerisem": "întineri",
    "întineriseră": "întineri",
    "întineriserăm": "întineri",
    "întineriserăți": "întineri",
    "întineriseși": "întineri",
    "întineriși": "întineri",
    "întinerit": "întineri",
    "întineriți": "întineri",
    "întineritu": "întineri",
    "neîntinerind": "întineri",
    "neîntinerindu": "întineri",
    "nemaiîntinerind": "întineri",
    "nemaiîntinerindu": "întineri",
    "întinerită": "întinerit",
    "întinerite": "întinerit",
    "întineriți": "întinerit",
    "înting": "întinge",
    "întingă": "întinge",
    "întingând": "întinge",
    "întingându": "întinge",
    "întingea": "întinge",
    "întingeai": "întinge",
    "întingeam": "întinge",
    "întingeați": "întinge",
    "întingeau": "întinge",
    "întingem": "întinge",
    "întingeți": "întinge",
    "întingi": "întinge",
    "întins": "întinge",
    "întinse": "întinge",
    "întinsei": "întinge",
    "întinseră": "întinge",
    "întinserăm": "întinge",
    "întinserăți": "întinge",
    "întinsese": "întinge",
    "întinsesem": "întinge",
    "întinseseră": "întinge",
    "întinseserăm": "întinge",
    "întinseserăți": "întinge",
    "întinseseși": "întinge",
    "întinseși": "întinge",
    "neîntingând": "întinge",
    "neîntingându": "întinge",
    "nemaiîntingând": "întinge",
    "nemaiîntingându": "întinge",
    "întinsa": "întins",
    "întinsă": "întins",
    "întinse": "întins",
    "întinsei": "întins",
    "întinsele": "întins",
    "întinselor": "întins",
    "întinși": "întins",
    "întinșii": "întins",
    "întinșilor": "întins",
    "întinsul": "întins",
    "întinsului": "întins",
    "întinsoarea": "întinsoare",
    "întinsori": "întinsoare",
    "întinsorii": "întinsoare",
    "întinsorile": "întinsoare",
    "întinsorilor": "întinsoare",
    "întipărea": "întipări",
    "întipăreai": "întipări",
    "întipăream": "întipări",
    "întipărească": "întipări",
    "întipăreați": "întipări",
    "întipăreau": "întipări",
    "întipăresc": "întipări",
    "întipărește": "întipări",
    "întipărești": "întipări",
    "întipării": "întipări",
    "întipărim": "întipări",
    "întipărind": "întipări",
    "întipărindu": "întipări",
    "întipăriră": "întipări",
    "întipărirăm": "întipări",
    "întipărirăți": "întipări",
    "întipărise": "întipări",
    "întipărisem": "întipări",
    "întipăriseră": "întipări",
    "întipăriserăm": "întipări",
    "întipăriserăți": "întipări",
    "întipăriseși": "întipări",
    "întipăriși": "întipări",
    "întipărit": "întipări",
    "întipăriți": "întipări",
    "întipăritu": "întipări",
    "neîntipărind": "întipări",
    "neîntipărindu": "întipări",
    "nemaiîntipărind": "întipări",
    "nemaiîntipărindu": "întipări",
    "întipărită": "întipărit",
    "întipărite": "întipărit",
    "întipăriți": "întipărit",
    "intitulă": "intitula",
    "intitulai": "intitula",
    "intitulam": "intitula",
    "intitulăm": "intitula",
    "intitulând": "intitula",
    "intitulându": "intitula",
    "intitulară": "intitula",
    "intitularăm": "intitula",
    "intitularăți": "intitula",
    "intitulase": "intitula",
    "intitulasem": "intitula",
    "intitulaseră": "intitula",
    "intitulaserăm": "intitula",
    "intitulaserăți": "intitula",
    "intitulaseși": "intitula",
    "intitulași": "intitula",
    "intitulat": "intitula",
    "intitulați": "intitula",
    "intitulatu": "intitula",
    "intitulau": "intitula",
    "intitulează": "intitula",
    "intitulez": "intitula",
    "intituleze": "intitula",
    "intitulezi": "intitula",
    "neintitulând": "intitula",
    "neintitulându": "intitula",
    "nemaiintitulând": "intitula",
    "nemaiintitulându": "intitula",
    "intitulata": "intitulat",
    "intitulată": "intitulat",
    "intitulate": "intitulat",
    "intitulatei": "intitulat",
    "intitulatele": "intitulat",
    "intitulatelor": "intitulat",
    "intitulați": "intitulat",
    "intitulații": "intitulat",
    "intitulaților": "intitulat",
    "intitulatul": "intitulat",
    "intitulatului": "intitulat",
    "întoarcă": "întoarce",
    "întoarcem": "întoarce",
    "întoarceți": "întoarce",
    "întoarse": "întoarce",
    "întoarseră": "întoarce",
    "întoarserăm": "întoarce",
    "întoarserăți": "întoarce",
    "întorc": "întoarce",
    "întorcând": "întoarce",
    "întorcându": "întoarce",
    "întorcea": "întoarce",
    "întorceai": "întoarce",
    "întorceam": "întoarce",
    "întorceați": "întoarce",
    "întorceau": "întoarce",
    "întorci": "întoarce",
    "întors": "întoarce",
    "întorsei": "întoarce",
    "întorsese": "întoarce",
    "întorsesem": "întoarce",
    "întorseseră": "întoarce",
    "întorseserăm": "întoarce",
    "întorseserăți": "întoarce",
    "întorseseși": "întoarce",
    "întorseși": "întoarce",
    "întorsu": "întoarce",
    "neîntorcând": "întoarce",
    "neîntorcându": "întoarce",
    "nemaiîntorcând": "întoarce",
    "nemaiîntorcându": "întoarce",
    "întoarcerea": "întoarcere",
    "întoarceri": "întoarcere",
    "întoarcerii": "întoarcere",
    "întoarcerile": "întoarcere",
    "întoarcerilor": "întoarcere",
    "întocmea": "întocmi",
    "întocmeai": "întocmi",
    "întocmeam": "întocmi",
    "întocmească": "întocmi",
    "întocmeați": "întocmi",
    "întocmeau": "întocmi",
    "întocmesc": "întocmi",
    "întocmește": "întocmi",
    "întocmești": "întocmi",
    "întocmii": "întocmi",
    "întocmim": "întocmi",
    "întocmind": "întocmi",
    "întocmindu": "întocmi",
    "întocmiră": "întocmi",
    "întocmirăm": "întocmi",
    "întocmirăți": "întocmi",
    "întocmise": "întocmi",
    "întocmisem": "întocmi",
    "întocmiseră": "întocmi",
    "întocmiserăm": "întocmi",
    "întocmiserăți": "întocmi",
    "întocmiseși": "întocmi",
    "întocmiși": "întocmi",
    "întocmit": "întocmi",
    "întocmiți": "întocmi",
    "întocmitu": "întocmi",
    "neîntocmind": "întocmi",
    "neîntocmindu": "întocmi",
    "nemaiîntocmind": "întocmi",
    "nemaiîntocmindu": "întocmi",
    "întocmirea": "întocmire",
    "întocmireo": "întocmire",
    "întocmiri": "întocmire",
    "întocmirii": "întocmire",
    "întocmirile": "întocmire",
    "întocmirilor": "întocmire",
    "întocmită": "întocmit",
    "întocmite": "întocmit",
    "întocmiți": "întocmit",
    "intolerabila": "intolerabil",
    "intolerabilă": "intolerabil",
    "intolerabile": "intolerabil",
    "intolerabilei": "intolerabil",
    "intolerabilele": "intolerabil",
    "intolerabilelor": "intolerabil",
    "intolerabili": "intolerabil",
    "intolerabilii": "intolerabil",
    "intolerabililor": "intolerabil",
    "intolerabilul": "intolerabil",
    "intolerabilului": "intolerabil",
    "intoleranta": "intolerant",
    "intolerantă": "intolerant",
    "intolerante": "intolerant",
    "intolerantei": "intolerant",
    "intolerantele": "intolerant",
    "intolerantelor": "intolerant",
    "intoleranți": "intolerant",
    "intoleranții": "intolerant",
    "intoleranților": "intolerant",
    "intolerantul": "intolerant",
    "intolerantului": "intolerant",
    "intoleranța": "intoleranță",
    "intoleranțe": "intoleranță",
    "intoleranței": "intoleranță",
    "intoleranțele": "intoleranță",
    "intoleranțelor": "intoleranță",
    "înțolea": "înțoli",
    "înțoleai": "înțoli",
    "înțoleam": "înțoli",
    "înțolească": "înțoli",
    "înțoleați": "înțoli",
    "înțoleau": "înțoli",
    "înțolesc": "înțoli",
    "înțolește": "înțoli",
    "înțolești": "înțoli",
    "înțolii": "înțoli",
    "înțolim": "înțoli",
    "înțolind": "înțoli",
    "înțolindu": "înțoli",
    "înțoliră": "înțoli",
    "înțolirăm": "înțoli",
    "înțolirăți": "înțoli",
    "înțolise": "înțoli",
    "înțolisem": "înțoli",
    "înțoliseră": "înțoli",
    "înțoliserăm": "înțoli",
    "înțoliserăți": "înțoli",
    "înțoliseși": "înțoli",
    "înțoliși": "înțoli",
    "înțolit": "înțoli",
    "înțoliți": "înțoli",
    "înțolitu": "înțoli",
    "neînțolind": "înțoli",
    "neînțolindu": "înțoli",
    "nemaiînțolind": "înțoli",
    "nemaiînțolindu": "înțoli",
    "înțolită": "înțolit",
    "înțolite": "înțolit",
    "înțoliți": "înțolit",
    "întomnă": "întomna",
    "întomnase": "întomna",
    "întomnat": "întomna",
    "întomnatu": "întomna",
    "întomnează": "întomna",
    "întomneze": "întomna",
    "întomnată": "întomnat",
    "intonă": "intona",
    "intonai": "intona",
    "intonam": "intona",
    "intonăm": "intona",
    "intonând": "intona",
    "intonându": "intona",
    "intonară": "intona",
    "intonarăm": "intona",
    "intonarăți": "intona",
    "intonase": "intona",
    "intonasem": "intona",
    "intonaseră": "intona",
    "intonaserăm": "intona",
    "intonaserăți": "intona",
    "intonaseși": "intona",
    "intonași": "intona",
    "intonat": "intona",
    "intonați": "intona",
    "intonatu": "intona",
    "intonau": "intona",
    "intonează": "intona",
    "intonez": "intona",
    "intoneze": "intona",
    "intonezi": "intona",
    "neintonând": "intona",
    "neintonându": "intona",
    "nemaiintonând": "intona",
    "nemaiintonându": "intona",
    "intonată": "intonat",
    "intonate": "intonat",
    "intonați": "intonat",
    "intonația": "intonație",
    "intonației": "intonație",
    "intonații": "intonație",
    "intonațiile": "intonație",
    "intonațiilor": "intonație",
    "întoarsă": "întors",
    "întoarse": "întors",
    "întorși": "întors",
    "întortoche": "întortochea",
    "întortocheai": "întortochea",
    "întortocheam": "întortochea",
    "întortocheară": "întortochea",
    "întortochearăm": "întortochea",
    "întortochearăți": "întortochea",
    "întortochease": "întortochea",
    "întortocheasem": "întortochea",
    "întortocheaseră": "întortochea",
    "întortocheaserăm": "întortochea",
    "întortocheaserăți": "întortochea",
    "întortocheaseși": "întortochea",
    "întortocheași": "întortochea",
    "întortocheat": "întortochea",
    "întortocheați": "întortochea",
    "întortocheatu": "întortochea",
    "întortocheau": "întortochea",
    "întortochează": "întortochea",
    "întortochem": "întortochea",
    "întortochez": "întortochea",
    "întortocheze": "întortochea",
    "întortochezi": "întortochea",
    "întortochind": "întortochea",
    "întortochindu": "întortochea",
    "neîntortochind": "întortochea",
    "neîntortochindu": "întortochea",
    "nemaiîntortochind": "întortochea",
    "nemaiîntortochindu": "întortochea",
    "întortocheata": "întortocheat",
    "întortocheată": "întortocheat",
    "întortocheate": "întortocheat",
    "întortocheatei": "întortocheat",
    "întortocheatele": "întortocheat",
    "întortocheatelor": "întortocheat",
    "întortocheați": "întortocheat",
    "întortocheații": "întortocheat",
    "întortocheaților": "întortocheat",
    "întortocheatul": "întortocheat",
    "întortocheatului": "întortocheat",
    "întovărășea": "întovărăși",
    "întovărășeai": "întovărăși",
    "întovărășeam": "întovărăși",
    "întovărășească": "întovărăși",
    "întovărășeați": "întovărăși",
    "întovărășeau": "întovărăși",
    "întovărășesc": "întovărăși",
    "întovărășește": "întovărăși",
    "întovărășești": "întovărăși",
    "întovărășii": "întovărăși",
    "întovărășim": "întovărăși",
    "întovărășind": "întovărăși",
    "întovărășindu": "întovărăși",
    "întovărășiră": "întovărăși",
    "întovărășirăm": "întovărăși",
    "întovărășirăți": "întovărăși",
    "întovărășise": "întovărăși",
    "întovărășisem": "întovărăși",
    "întovărășiseră": "întovărăși",
    "întovărășiserăm": "întovărăși",
    "întovărășiserăți": "întovărăși",
    "întovărășiseși": "întovărăși",
    "întovărășiși": "întovărăși",
    "întovărășit": "întovărăși",
    "întovărășiți": "întovărăși",
    "întovărășitu": "întovărăși",
    "neîntovărășind": "întovărăși",
    "neîntovărășindu": "întovărăși",
    "nemaiîntovărășind": "întovărăși",
    "nemaiîntovărășindu": "întovărăși",
    "întovărășirea": "întovărășire",
    "întovărășireo": "întovărășire",
    "întovărășiri": "întovărășire",
    "întovărășirii": "întovărășire",
    "întovărășirile": "întovărășire",
    "întovărășirilor": "întovărășire",
    "întovărășită": "întovărășit",
    "întovărășite": "întovărășit",
    "întovărășiți": "întovărășit",
    "intoxic": "intoxica",
    "intoxică": "intoxica",
    "intoxicai": "intoxica",
    "intoxicam": "intoxica",
    "intoxicăm": "intoxica",
    "intoxicând": "intoxica",
    "intoxicându": "intoxica",
    "intoxicară": "intoxica",
    "intoxicarăm": "intoxica",
    "intoxicarăți": "intoxica",
    "intoxicase": "intoxica",
    "intoxicasem": "intoxica",
    "intoxicaseră": "intoxica",
    "intoxicaserăm": "intoxica",
    "intoxicaserăți": "intoxica",
    "intoxicaseși": "intoxica",
    "intoxicași": "intoxica",
    "intoxicat": "intoxica",
    "intoxicați": "intoxica",
    "intoxicatu": "intoxica",
    "intoxicau": "intoxica",
    "intoxice": "intoxica",
    "intoxici": "intoxica",
    "neintoxicând": "intoxica",
    "neintoxicându": "intoxica",
    "nemaiintoxicând": "intoxica",
    "nemaiintoxicându": "intoxica",
    "intoxicarea": "intoxicare",
    "intoxicări": "intoxicare",
    "intoxicării": "intoxicare",
    "intoxicările": "intoxicare",
    "intoxicărilor": "intoxicare",
    "intoxicată": "intoxicat",
    "intoxicate": "intoxicat",
    "intoxicați": "intoxicat",
    "intră": "intra",
    "intrai": "intra",
    "intram": "intra",
    "intrăm": "intra",
    "intrând": "intra",
    "intrându": "intra",
    "intrară": "intra",
    "intrarăm": "intra",
    "intrarăți": "intra",
    "intrase": "intra",
    "intrasem": "intra",
    "intraseră": "intra",
    "intraserăm": "intra",
    "intraserăți": "intra",
    "intraseși": "intra",
    "intrași": "intra",
    "intrat": "intra",
    "intrați": "intra",
    "intratu": "intra",
    "intrau": "intra",
    "intre": "intra",
    "intri": "intra",
    "intru": "intra",
    "neintrând": "intra",
    "neintrându": "intra",
    "nemaiintrând": "intra",
    "nemaiintrându": "intra",
    "întrajutoră": "întrajutora",
    "întrajutorai": "întrajutora",
    "întrajutoram": "întrajutora",
    "întrajutorăm": "întrajutora",
    "întrajutorând": "întrajutora",
    "întrajutorându": "întrajutora",
    "întrajutorară": "întrajutora",
    "întrajutorarăm": "întrajutora",
    "întrajutorarăți": "întrajutora",
    "întrajutorase": "întrajutora",
    "întrajutorasem": "întrajutora",
    "întrajutoraseră": "întrajutora",
    "întrajutoraserăm": "întrajutora",
    "întrajutoraserăți": "întrajutora",
    "întrajutoraseși": "întrajutora",
    "întrajutorași": "întrajutora",
    "întrajutorat": "întrajutora",
    "întrajutorați": "întrajutora",
    "întrajutoratu": "întrajutora",
    "întrajutorau": "întrajutora",
    "întrajutorează": "întrajutora",
    "întrajutorez": "întrajutora",
    "întrajutoreze": "întrajutora",
    "întrajutorezi": "întrajutora",
    "neîntrajutorând": "întrajutora",
    "neîntrajutorându": "întrajutora",
    "nemaiîntrajutorând": "întrajutora",
    "nemaiîntrajutorându": "întrajutora",
    "întrajutorarea": "întrajutorare",
    "întrajutorări": "întrajutorare",
    "întrajutorării": "întrajutorare",
    "întrajutorările": "întrajutorare",
    "întrajutorărilor": "întrajutorare",
    "întrajutorată": "întrajutorat",
    "întrajutorate": "întrajutorat",
    "întrajutorați": "întrajutorat",
    "intrândul": "intrând",
    "intrândului": "intrând",
    "intrânduri": "intrând",
    "intrândurile": "intrând",
    "intrândurilor": "intrând",
    "intransigenta": "intransigent",
    "intransigentă": "intransigent",
    "intransigente": "intransigent",
    "intransigentei": "intransigent",
    "intransigentele": "intransigent",
    "intransigentelor": "intransigent",
    "intransigenți": "intransigent",
    "intransigenții": "intransigent",
    "intransigenților": "intransigent",
    "intransigentul": "intransigent",
    "intransigentului": "intransigent",
    "intransigența": "intransigență",
    "intranzitiva": "intranzitiv",
    "intranzitivă": "intranzitiv",
    "intranzitive": "intranzitiv",
    "intranzitivei": "intranzitiv",
    "intranzitivele": "intranzitiv",
    "intranzitivelor": "intranzitiv",
    "intranzitivi": "intranzitiv",
    "intranzitivii": "intranzitiv",
    "intranzitivilor": "intranzitiv",
    "intranzitivul": "intranzitiv",
    "intranzitivului": "intranzitiv",
    "intrarea": "intrare",
    "intrări": "intrare",
    "intrării": "intrare",
    "intrările": "intrare",
    "intrărilor": "intrare",
    "întraripă": "întraripa",
    "întraripai": "întraripa",
    "întraripam": "întraripa",
    "întraripăm": "întraripa",
    "întraripând": "întraripa",
    "întraripându": "întraripa",
    "întraripară": "întraripa",
    "întrariparăm": "întraripa",
    "întrariparăți": "întraripa",
    "întraripase": "întraripa",
    "întraripasem": "întraripa",
    "întraripaseră": "întraripa",
    "întraripaserăm": "întraripa",
    "întraripaserăți": "întraripa",
    "întraripaseși": "întraripa",
    "întraripași": "întraripa",
    "întraripat": "întraripa",
    "întraripați": "întraripa",
    "întraripatu": "întraripa",
    "întraripau": "întraripa",
    "întraripează": "întraripa",
    "întraripez": "întraripa",
    "întraripeze": "întraripa",
    "întraripezi": "întraripa",
    "neîntraripând": "întraripa",
    "neîntraripându": "întraripa",
    "nemaiîntraripând": "întraripa",
    "nemaiîntraripându": "întraripa",
    "întraripată": "întraripat",
    "întraripate": "întraripat",
    "întraripați": "întraripat",
    "întrarmă": "întrarma",
    "întrarmai": "întrarma",
    "întrarmam": "întrarma",
    "întrarmăm": "întrarma",
    "întrarmând": "întrarma",
    "întrarmându": "întrarma",
    "întrarmară": "întrarma",
    "întrarmarăm": "întrarma",
    "întrarmarăți": "întrarma",
    "întrarmase": "întrarma",
    "întrarmasem": "întrarma",
    "întrarmaseră": "întrarma",
    "întrarmaserăm": "întrarma",
    "întrarmaserăți": "întrarma",
    "întrarmaseși": "întrarma",
    "întrarmași": "întrarma",
    "întrarmat": "întrarma",
    "întrarmați": "întrarma",
    "întrarmatu": "întrarma",
    "întrarmau": "întrarma",
    "întrarmează": "întrarma",
    "întrarmez": "întrarma",
    "întrarmeze": "întrarma",
    "întrarmezi": "întrarma",
    "neîntrarmând": "întrarma",
    "neîntrarmându": "întrarma",
    "nemaiîntrarmând": "întrarma",
    "nemaiîntrarmându": "întrarma",
    "întrarmată": "întrarmat",
    "întrarmate": "întrarmat",
    "întrarmați": "întrarmat",
    "intrată": "intrat",
    "intrate": "intrat",
    "intrați": "intrat",
    "întraurea": "întrauri",
    "întraureai": "întrauri",
    "întrauream": "întrauri",
    "întraurească": "întrauri",
    "întraureați": "întrauri",
    "întraureau": "întrauri",
    "întrauresc": "întrauri",
    "întraurește": "întrauri",
    "întraurești": "întrauri",
    "întraurii": "întrauri",
    "întraurim": "întrauri",
    "întraurind": "întrauri",
    "întraurindu": "întrauri",
    "întrauriră": "întrauri",
    "întraurirăm": "întrauri",
    "întraurirăți": "întrauri",
    "întraurise": "întrauri",
    "întraurisem": "întrauri",
    "întrauriseră": "întrauri",
    "întrauriserăm": "întrauri",
    "întrauriserăți": "întrauri",
    "întrauriseși": "întrauri",
    "întrauriși": "întrauri",
    "întraurit": "întrauri",
    "întrauriți": "întrauri",
    "întrauritu": "întrauri",
    "neîntraurind": "întrauri",
    "neîntraurindu": "întrauri",
    "nemaiîntraurind": "întrauri",
    "nemaiîntraurindu": "întrauri",
    "întraurită": "întraurit",
    "întraurite": "întraurit",
    "întrauriți": "întraurit",
    "intravilane": "intravilan",
    "intravilanele": "intravilan",
    "intravilanelor": "intravilan",
    "intravilanul": "intravilan",
    "intravilanului": "intravilan",
    "întreabă": "întreba",
    "întreb": "întreba",
    "întrebă": "întreba",
    "întrebai": "întreba",
    "întrebam": "întreba",
    "întrebăm": "întreba",
    "întrebând": "întreba",
    "întrebându": "întreba",
    "întrebară": "întreba",
    "întrebarăm": "întreba",
    "întrebarăți": "întreba",
    "întrebase": "întreba",
    "întrebasem": "întreba",
    "întrebaseră": "întreba",
    "întrebaserăm": "întreba",
    "întrebaserăți": "întreba",
    "întrebaseși": "întreba",
    "întrebași": "întreba",
    "întrebat": "întreba",
    "întrebați": "întreba",
    "întrebatu": "întreba",
    "întrebau": "întreba",
    "întrebe": "întreba",
    "întrebi": "întreba",
    "neîntrebând": "întreba",
    "neîntrebându": "întreba",
    "nemaiîntrebând": "întreba",
    "nemaiîntrebându": "întreba",
    "întrebarea": "întrebare",
    "întrebări": "întrebare",
    "întrebării": "întrebare",
    "întrebările": "întrebare",
    "întrebărilor": "întrebare",
    "întrebată": "întrebat",
    "întrebate": "întrebat",
    "întrebați": "întrebat",
    "întrebătoare": "întrebător",
    "întrebătoarea": "întrebător",
    "întrebătoarei": "întrebător",
    "întrebătoarele": "întrebător",
    "întrebătoarelor": "întrebător",
    "întrebători": "întrebător",
    "întrebătorii": "întrebător",
    "întrebătorilor": "întrebător",
    "întrebătorul": "întrebător",
    "întrebătorului": "întrebător",
    "întrebuință": "întrebuința",
    "întrebuințai": "întrebuința",
    "întrebuințam": "întrebuința",
    "întrebuințăm": "întrebuința",
    "întrebuințând": "întrebuința",
    "întrebuințându": "întrebuința",
    "întrebuințară": "întrebuința",
    "întrebuințarăm": "întrebuința",
    "întrebuințarăți": "întrebuința",
    "întrebuințase": "întrebuința",
    "întrebuințasem": "întrebuința",
    "întrebuințaseră": "întrebuința",
    "întrebuințaserăm": "întrebuința",
    "întrebuințaserăți": "întrebuința",
    "întrebuințaseși": "întrebuința",
    "întrebuințași": "întrebuința",
    "întrebuințat": "întrebuința",
    "întrebuințați": "întrebuința",
    "întrebuințatu": "întrebuința",
    "întrebuințau": "întrebuința",
    "întrebuințează": "întrebuința",
    "întrebuințez": "întrebuința",
    "întrebuințeze": "întrebuința",
    "întrebuințezi": "întrebuința",
    "neîntrebuințând": "întrebuința",
    "neîntrebuințându": "întrebuința",
    "nemaiîntrebuințând": "întrebuința",
    "nemaiîntrebuințându": "întrebuința",
    "întrebuințarea": "întrebuințare",
    "întrebuințări": "întrebuințare",
    "întrebuințării": "întrebuințare",
    "întrebuințările": "întrebuințare",
    "întrebuințărilor": "întrebuințare",
    "întrebuințată": "întrebuințat",
    "întrebuințate": "întrebuințat",
    "întrebuințați": "întrebuințat",
    "întreacă": "întrece",
    "întrec": "întrece",
    "întrecând": "întrece",
    "întrecându": "întrece",
    "întrecea": "întrece",
    "întreceai": "întrece",
    "întreceam": "întrece",
    "întreceați": "întrece",
    "întreceau": "întrece",
    "întrecem": "întrece",
    "întreceți": "întrece",
    "întreci": "întrece",
    "întrecu": "întrece",
    "întrecui": "întrece",
    "întrecură": "întrece",
    "întrecurăm": "întrece",
    "întrecurăți": "întrece",
    "întrecuse": "întrece",
    "întrecusem": "întrece",
    "întrecuseră": "întrece",
    "întrecuserăm": "întrece",
    "întrecuserăți": "întrece",
    "întrecuseși": "întrece",
    "întrecuși": "întrece",
    "întrecut": "întrece",
    "întrecutu": "întrece",
    "neîntrecând": "întrece",
    "neîntrecându": "întrece",
    "nemaiîntrecând": "întrece",
    "nemaiîntrecându": "întrece",
    "întrecerea": "întrecere",
    "întreceri": "întrecere",
    "întrecerii": "întrecere",
    "întrecerile": "întrecere",
    "întrecerilor": "întrecere",
    "întrecută": "întrecut",
    "întrecute": "întrecut",
    "întrecuți": "întrecut",
    "întredeschid": "întredeschide",
    "întredeschidă": "întredeschide",
    "întredeschidea": "întredeschide",
    "întredeschideai": "întredeschide",
    "întredeschideam": "întredeschide",
    "întredeschideați": "întredeschide",
    "întredeschideau": "întredeschide",
    "întredeschidem": "întredeschide",
    "întredeschideți": "întredeschide",
    "întredeschis": "întredeschide",
    "întredeschisu": "întredeschide",
    "întredeschizând": "întredeschide",
    "întredeschizându": "întredeschide",
    "întredeschizi": "întredeschide",
    "neîntredeschizând": "întredeschide",
    "neîntredeschizându": "întredeschide",
    "nemaiîntredeschizând": "întredeschide",
    "nemaiîntredeschizându": "întredeschide",
    "întredeschiderea": "întredeschidere",
    "întredeschidereo": "întredeschidere",
    "întredeschideri": "întredeschidere",
    "întredeschiderii": "întredeschidere",
    "întredeschiderile": "întredeschidere",
    "întredeschiderilor": "întredeschidere",
    "întredeschisa": "întredeschis",
    "întredeschisă": "întredeschis",
    "întredeschise": "întredeschis",
    "întredeschisei": "întredeschis",
    "întredeschisele": "întredeschis",
    "întredeschiselor": "întredeschis",
    "întredeschiși": "întredeschis",
    "întredeschișii": "întredeschis",
    "întredeschișilor": "întredeschis",
    "întredeschisul": "întredeschis",
    "întredeschisului": "întredeschis",
    "întreaga": "întreg",
    "întreagă": "întreg",
    "întregi": "întreg",
    "întregii": "întreg",
    "întregile": "întreg",
    "întregilor": "întreg",
    "întregul": "întreg",
    "întregului": "întreg",
    "întregea": "întregi",
    "întregeai": "întregi",
    "întregeam": "întregi",
    "întregească": "întregi",
    "întregeați": "întregi",
    "întregeau": "întregi",
    "întregesc": "întregi",
    "întregește": "întregi",
    "întregești": "întregi",
    "întregii": "întregi",
    "întregim": "întregi",
    "întregind": "întregi",
    "întregindu": "întregi",
    "întregiră": "întregi",
    "întregirăm": "întregi",
    "întregirăți": "întregi",
    "întregise": "întregi",
    "întregisem": "întregi",
    "întregiseră": "întregi",
    "întregiserăm": "întregi",
    "întregiserăți": "întregi",
    "întregiseși": "întregi",
    "întregiși": "întregi",
    "întregit": "întregi",
    "întregiți": "întregi",
    "întregitu": "întregi",
    "neîntregind": "întregi",
    "neîntregindu": "întregi",
    "nemaiîntregind": "întregi",
    "nemaiîntregindu": "întregi",
    "întregimea": "întregime",
    "întregimi": "întregime",
    "întregimii": "întregime",
    "întregimile": "întregime",
    "întregimilor": "întregime",
    "întregirea": "întregire",
    "întregireo": "întregire",
    "întregiri": "întregire",
    "întregirii": "întregire",
    "întregirile": "întregire",
    "întregirilor": "întregire",
    "întregită": "întregit",
    "întregite": "întregit",
    "întregiți": "întregit",
    "întreia": "întrei",
    "întreiai": "întrei",
    "întreiam": "întrei",
    "întreiască": "întrei",
    "întreiați": "întrei",
    "întreiau": "întrei",
    "întreiesc": "întrei",
    "întreiește": "întrei",
    "întreiești": "întrei",
    "întreii": "întrei",
    "întreim": "întrei",
    "întreind": "întrei",
    "întreindu": "întrei",
    "întreiră": "întrei",
    "întreirăm": "întrei",
    "întreirăți": "întrei",
    "întreise": "întrei",
    "întreisem": "întrei",
    "întreiseră": "întrei",
    "întreiserăm": "întrei",
    "întreiserăți": "întrei",
    "întreiseși": "întrei",
    "întreiși": "întrei",
    "întreit": "întrei",
    "întreiți": "întrei",
    "întreitu": "întrei",
    "neîntreind": "întrei",
    "neîntreindu": "întrei",
    "nemaiîntreind": "întrei",
    "nemaiîntreindu": "întrei",
    "întreita": "întreit",
    "întreită": "întreit",
    "întreite": "întreit",
    "întreitei": "întreit",
    "întreitele": "întreit",
    "întreitelor": "întreit",
    "întreiți": "întreit",
    "întreiții": "întreit",
    "întreiților": "întreit",
    "întreitul": "întreit",
    "întreitului": "întreit",
    "întremă": "întrema",
    "întremai": "întrema",
    "întremam": "întrema",
    "întremăm": "întrema",
    "întremând": "întrema",
    "întremându": "întrema",
    "întremară": "întrema",
    "întremarăm": "întrema",
    "întremarăți": "întrema",
    "întremase": "întrema",
    "întremasem": "întrema",
    "întremaseră": "întrema",
    "întremaserăm": "întrema",
    "întremaserăți": "întrema",
    "întremaseși": "întrema",
    "întremași": "întrema",
    "întremat": "întrema",
    "întremați": "întrema",
    "întrematu": "întrema",
    "întremau": "întrema",
    "întremează": "întrema",
    "întremez": "întrema",
    "întremeze": "întrema",
    "întremezi": "întrema",
    "neîntremând": "întrema",
    "neîntremându": "întrema",
    "nemaiîntremând": "întrema",
    "nemaiîntremându": "întrema",
    "întremarea": "întremare",
    "întremări": "întremare",
    "întremării": "întremare",
    "întremările": "întremare",
    "întremărilor": "întremare",
    "întremată": "întremat",
    "întremate": "întremat",
    "întremați": "întremat",
    "întrepătrund": "întrepătrunde",
    "întrepătrundă": "întrepătrunde",
    "întrepătrundea": "întrepătrunde",
    "întrepătrundeai": "întrepătrunde",
    "întrepătrundeam": "întrepătrunde",
    "întrepătrundeați": "întrepătrunde",
    "întrepătrundeau": "întrepătrunde",
    "întrepătrundem": "întrepătrunde",
    "întrepătrundeți": "întrepătrunde",
    "întrepătruns": "întrepătrunde",
    "întrepătrunse": "întrepătrunde",
    "întrepătrunsei": "întrepătrunde",
    "întrepătrunseră": "întrepătrunde",
    "întrepătrunserăm": "întrepătrunde",
    "întrepătrunserăți": "întrepătrunde",
    "întrepătrunsese": "întrepătrunde",
    "întrepătrunsesem": "întrepătrunde",
    "întrepătrunseseră": "întrepătrunde",
    "întrepătrunseserăm": "întrepătrunde",
    "întrepătrunseserăți": "întrepătrunde",
    "întrepătrunseseși": "întrepătrunde",
    "întrepătrunseși": "întrepătrunde",
    "întrepătrunsu": "întrepătrunde",
    "întrepătrunzând": "întrepătrunde",
    "întrepătrunzându": "întrepătrunde",
    "întrepătrunzi": "întrepătrunde",
    "neîntrepătrunzând": "întrepătrunde",
    "neîntrepătrunzându": "întrepătrunde",
    "nemaiîntrepătrunzând": "întrepătrunde",
    "nemaiîntrepătrunzându": "întrepătrunde",
    "întrepătrunsă": "întrepătruns",
    "întrepătrunse": "întrepătruns",
    "întrepătrunși": "întrepătruns",
    "întreprind": "întreprinde",
    "întreprindă": "întreprinde",
    "întreprindea": "întreprinde",
    "întreprindeai": "întreprinde",
    "întreprindeam": "întreprinde",
    "întreprindeați": "întreprinde",
    "întreprindeau": "întreprinde",
    "întreprindem": "întreprinde",
    "întreprindeți": "întreprinde",
    "întreprins": "întreprinde",
    "întreprinse": "întreprinde",
    "întreprinsei": "întreprinde",
    "întreprinsem": "întreprinde",
    "întreprinseră": "întreprinde",
    "întreprinserăm": "întreprinde",
    "întreprinserăți": "întreprinde",
    "întreprinseși": "întreprinde",
    "întreprinși": "întreprinde",
    "întreprinsu": "întreprinde",
    "întreprinzând": "întreprinde",
    "întreprinzându": "întreprinde",
    "întreprinzi": "întreprinde",
    "neîntreprinzând": "întreprinde",
    "neîntreprinzându": "întreprinde",
    "nemaiîntreprinzând": "întreprinde",
    "nemaiîntreprinzându": "întreprinde",
    "întreprinderea": "întreprindere",
    "întreprinderi": "întreprindere",
    "întreprinderii": "întreprindere",
    "întreprinderile": "întreprindere",
    "întreprinderilor": "întreprindere",
    "I.A.S.": "întreprinderea_Agricolă_de_Stat",
    "IAS": "întreprinderea_Agricolă_de_Stat",
    "întreprinsă": "întreprins",
    "întreprinse": "întreprins",
    "întreprinși": "întreprins",
    "întreprinzătoarea": "întreprinzătoare",
    "întreprinzătoarei": "întreprinzătoare",
    "întreprinzătoarele": "întreprinzătoare",
    "întreprinzătoarelor": "întreprinzătoare",
    "întreprinzătoare": "întreprinzător",
    "întreprinzătoarea": "întreprinzător",
    "întreprinzătoarei": "întreprinzător",
    "întreprinzătoarele": "întreprinzător",
    "întreprinzătoarelor": "întreprinzător",
    "întreprinzători": "întreprinzător",
    "întreprinzătorii": "întreprinzător",
    "întreprinzătorilor": "întreprinzător",
    "întreprinzătorul": "întreprinzător",
    "întreprinzătorului": "întreprinzător",
    "întrerupătoare": "întrerupător",
    "întrerupătoarele": "întrerupător",
    "întrerupătoarelor": "întrerupător",
    "întrerupătorul": "întrerupător",
    "întrerupătorului": "întrerupător",
    "întrerup": "întrerupe",
    "întrerupă": "întrerupe",
    "întrerupând": "întrerupe",
    "întrerupându": "întrerupe",
    "întrerupea": "întrerupe",
    "întrerupeai": "întrerupe",
    "întrerupeam": "întrerupe",
    "întrerupeați": "întrerupe",
    "întrerupeau": "întrerupe",
    "întrerupem": "întrerupe",
    "întrerupeți": "întrerupe",
    "întrerupi": "întrerupe",
    "întrerupse": "întrerupe",
    "întrerupsei": "întrerupe",
    "întrerupseră": "întrerupe",
    "întrerupserăm": "întrerupe",
    "întrerupserăți": "întrerupe",
    "întrerupsese": "întrerupe",
    "întrerupsesem": "întrerupe",
    "întrerupseseră": "întrerupe",
    "întrerupseserăm": "întrerupe",
    "întrerupseserăți": "întrerupe",
    "întrerupseseși": "întrerupe",
    "întrerupseși": "întrerupe",
    "întrerupt": "întrerupe",
    "întreruptu": "întrerupe",
    "neîntrerupând": "întrerupe",
    "neîntrerupându": "întrerupe",
    "nemaiîntrerupând": "întrerupe",
    "nemaiîntrerupându": "întrerupe",
    "întreruperea": "întrerupere",
    "întreruperi": "întrerupere",
    "întreruperii": "întrerupere",
    "întreruperile": "întrerupere",
    "întreruperilor": "întrerupere",
    "întreruptă": "întrerupt",
    "întrerupte": "întrerupt",
    "întrerupți": "întrerupt",
    "întretai": "întretăia",
    "întretăiai": "întretăia",
    "întretăiam": "întretăia",
    "întretăiară": "întretăia",
    "întretăiarăm": "întretăia",
    "întretăiarăți": "întretăia",
    "întretăiase": "întretăia",
    "întretăiasem": "întretăia",
    "întretăiaseră": "întretăia",
    "întretăiaserăm": "întretăia",
    "întretăiaserăți": "întretăia",
    "întretăiaseși": "întretăia",
    "întretăiași": "întretăia",
    "întretăiat": "întretăia",
    "întretăiați": "întretăia",
    "întretăiatu": "întretăia",
    "întretăiau": "întretăia",
    "întretaie": "întretăia",
    "întretăie": "întretăia",
    "întretăiem": "întretăia",
    "întretăind": "întretăia",
    "întretăindu": "întretăia",
    "neîntretăiind": "întretăia",
    "neîntretăiindu": "întretăia",
    "nemaiîntretăiind": "întretăia",
    "nemaiîntretăiindu": "întretăia",
    "întretăiată": "întretăiat",
    "întretăiate": "întretăiat",
    "întretăiați": "întretăiat",
    "întretăierea": "întretăiere",
    "întretăieri": "întretăiere",
    "întretăierii": "întretăiere",
    "întretăierile": "întretăiere",
    "întretăierilor": "întretăiere",
    "întrețes": "întrețese",
    "întrețesă": "întrețese",
    "întrețesând": "întrețese",
    "întrețesându": "întrețese",
    "întrețesea": "întrețese",
    "întrețeseai": "întrețese",
    "întrețeseam": "întrețese",
    "întrețeseați": "întrețese",
    "întrețeseau": "întrețese",
    "întrețesem": "întrețese",
    "întrețeseți": "întrețese",
    "întrețeși": "întrețese",
    "întrețesu": "întrețese",
    "întrețesui": "întrețese",
    "întrețesură": "întrețese",
    "întrețesurăm": "întrețese",
    "întrețesurăți": "întrețese",
    "întrețesuse": "întrețese",
    "întrețesusem": "întrețese",
    "întrețesuseră": "întrețese",
    "întrețesuserăm": "întrețese",
    "întrețesuserăți": "întrețese",
    "întrețesuseși": "întrețese",
    "întrețesuși": "întrețese",
    "întrețesut": "întrețese",
    "întrețesutu": "întrețese",
    "neîntrețesând": "întrețese",
    "neîntrețesându": "întrețese",
    "nemaiîntrețesând": "întrețese",
    "nemaiîntrețesându": "întrețese",
    "întrețesută": "întrețesut",
    "întrețesute": "întrețesut",
    "întrețesuți": "întrețesut",
    "întreții": "întreține",
    "întrețin": "întreține",
    "întrețină": "întreține",
    "întreținând": "întreține",
    "întreținându": "întreține",
    "întreținea": "întreține",
    "întrețineai": "întreține",
    "întrețineam": "întreține",
    "întrețineați": "întreține",
    "întrețineau": "întreține",
    "întreținem": "întreține",
    "întrețineți": "întreține",
    "întreținu": "întreține",
    "întreținui": "întreține",
    "întreținură": "întreține",
    "întreținurăm": "întreține",
    "întreținurăți": "întreține",
    "întreținuse": "întreține",
    "întreținusem": "întreține",
    "întreținuseră": "întreține",
    "întreținuserăm": "întreține",
    "întreținuserăți": "întreține",
    "întreținuseși": "întreține",
    "întreținuși": "întreține",
    "întreținut": "întreține",
    "întreținutu": "întreține",
    "neîntreținând": "întreține",
    "neîntreținându": "întreține",
    "nemaiîntreținând": "întreține",
    "nemaiîntreținându": "întreține",
    "întreținerea": "întreținere",
    "întrețineri": "întreținere",
    "întreținerii": "întreținere",
    "întreținerile": "întreținere",
    "întreținerilor": "întreținere",
    "întreținută": "întreținut",
    "întreținute": "întreținut",
    "întreținuți": "întreținut",
    "întrevăzută": "întrevăzut",
    "întrevăzute": "întrevăzut",
    "întrevăzuți": "întrevăzut",
    "întrevăd": "întrevedea",
    "întrevadă": "întrevedea",
    "întrevăzând": "întrevedea",
    "întrevăzându": "întrevedea",
    "întrevăzu": "întrevedea",
    "întrevăzui": "întrevedea",
    "întrevăzură": "întrevedea",
    "întrevăzurăm": "întrevedea",
    "întrevăzurăți": "întrevedea",
    "întrevăzuse": "întrevedea",
    "întrevăzusem": "întrevedea",
    "întrevăzuseră": "întrevedea",
    "întrevăzuserăm": "întrevedea",
    "întrevăzuserăți": "întrevedea",
    "întrevăzuseși": "întrevedea",
    "întrevăzuși": "întrevedea",
    "întrevăzut": "întrevedea",
    "întrevăzutu": "întrevedea",
    "întrevede": "întrevedea",
    "întrevedeai": "întrevedea",
    "întrevedeam": "întrevedea",
    "întrevedeați": "întrevedea",
    "întrevedeau": "întrevedea",
    "întrevedem": "întrevedea",
    "întrevedeți": "întrevedea",
    "întrevezi": "întrevedea",
    "neîntrevăzând": "întrevedea",
    "neîntrevăzându": "întrevedea",
    "nemaiîntrevăzând": "întrevedea",
    "nemaiîntrevăzându": "întrevedea",
    "întrevederea": "întrevedere",
    "întrevederi": "întrevedere",
    "întrevederii": "întrevedere",
    "întrevederile": "întrevedere",
    "întrevederilor": "întrevedere",
    "întrezărea": "întrezări",
    "întrezăreai": "întrezări",
    "întrezăream": "întrezări",
    "întrezărească": "întrezări",
    "întrezăreați": "întrezări",
    "întrezăreau": "întrezări",
    "întrezăresc": "întrezări",
    "întrezărește": "întrezări",
    "întrezărești": "întrezări",
    "întrezării": "întrezări",
    "întrezărim": "întrezări",
    "întrezărind": "întrezări",
    "întrezărindu": "întrezări",
    "întrezăriră": "întrezări",
    "întrezărirăm": "întrezări",
    "întrezărirăți": "întrezări",
    "întrezărise": "întrezări",
    "întrezărisem": "întrezări",
    "întrezăriseră": "întrezări",
    "întrezăriserăm": "întrezări",
    "întrezăriserăți": "întrezări",
    "întrezăriseși": "întrezări",
    "întrezăriși": "întrezări",
    "întrezărit": "întrezări",
    "întrezăriți": "întrezări",
    "întrezăritu": "întrezări",
    "neîntrezărind": "întrezări",
    "neîntrezărindu": "întrezări",
    "nemaiîntrezărind": "întrezări",
    "nemaiîntrezărindu": "întrezări",
    "întrezărită": "întrezărit",
    "întrezărite": "întrezărit",
    "întrezăriți": "întrezărit",
    "intrig": "intriga",
    "intrigă": "intriga",
    "intrigai": "intriga",
    "intrigam": "intriga",
    "intrigăm": "intriga",
    "intrigând": "intriga",
    "intrigându": "intriga",
    "intrigară": "intriga",
    "intrigarăm": "intriga",
    "intrigarăți": "intriga",
    "intrigase": "intriga",
    "intrigasem": "intriga",
    "intrigaseră": "intriga",
    "intrigaserăm": "intriga",
    "intrigaserăți": "intriga",
    "intrigaseși": "intriga",
    "intrigași": "intriga",
    "intrigat": "intriga",
    "intrigați": "intriga",
    "intrigatu": "intriga",
    "intrigau": "intriga",
    "intrige": "intriga",
    "intrigi": "intriga",
    "neintrigând": "intriga",
    "neintrigându": "intriga",
    "nemaiintrigând": "intriga",
    "nemaiintrigându": "intriga",
    "intriga": "intrigă",
    "intrigi": "intrigă",
    "intrigii": "intrigă",
    "intrigile": "intrigă",
    "intrigilor": "intrigă",
    "intrigată": "intrigat",
    "intrigate": "intrigat",
    "intrigați": "intrigat",
    "întristă": "întrista",
    "întristai": "întrista",
    "întristam": "întrista",
    "întristăm": "întrista",
    "întristând": "întrista",
    "întristându": "întrista",
    "întristară": "întrista",
    "întristarăm": "întrista",
    "întristarăți": "întrista",
    "întristase": "întrista",
    "întristasem": "întrista",
    "întristaseră": "întrista",
    "întristaserăm": "întrista",
    "întristaserăți": "întrista",
    "întristaseși": "întrista",
    "întristași": "întrista",
    "întristat": "întrista",
    "întristați": "întrista",
    "întristatu": "întrista",
    "întristau": "întrista",
    "întristează": "întrista",
    "întristez": "întrista",
    "întristeze": "întrista",
    "întristezi": "întrista",
    "neîntristând": "întrista",
    "neîntristându": "întrista",
    "nemaiîntristând": "întrista",
    "nemaiîntristându": "întrista",
    "întristarea": "întristare",
    "întristări": "întristare",
    "întristării": "întristare",
    "întristările": "întristare",
    "întristărilor": "întristare",
    "întristata": "întristat",
    "întristată": "întristat",
    "întristate": "întristat",
    "întristatei": "întristat",
    "întristatele": "întristat",
    "întristatelor": "întristat",
    "întristați": "întristat",
    "întristații": "întristat",
    "întristaților": "întristat",
    "întristatul": "întristat",
    "întristatului": "întristat",
    "introdu": "introduce",
    "introduc": "introduce",
    "introducă": "introduce",
    "introducând": "introduce",
    "introducându": "introduce",
    "introducea": "introduce",
    "introduceai": "introduce",
    "introduceam": "introduce",
    "introduceați": "introduce",
    "introduceau": "introduce",
    "introducem": "introduce",
    "introduceți": "introduce",
    "introduci": "introduce",
    "introdus": "introduce",
    "introduse": "introduce",
    "introdusei": "introduce",
    "introduseră": "introduce",
    "introduserăm": "introduce",
    "introduserăți": "introduce",
    "introdusese": "introduce",
    "introdusesem": "introduce",
    "introduseseră": "introduce",
    "introduseserăm": "introduce",
    "introduseserăți": "introduce",
    "introduseseși": "introduce",
    "introduseși": "introduce",
    "introdusu": "introduce",
    "neintroducând": "introduce",
    "neintroducându": "introduce",
    "nemaiintroducând": "introduce",
    "nemaiintroducându": "introduce",
    "introducerea": "introducere",
    "introduceri": "introducere",
    "introducerii": "introducere",
    "introducerile": "introducere",
    "introducerilor": "introducere",
    "introductiva": "introductiv",
    "introductivă": "introductiv",
    "introductive": "introductiv",
    "introductivei": "introductiv",
    "introductivele": "introductiv",
    "introductivelor": "introductiv",
    "introductivi": "introductiv",
    "introductivii": "introductiv",
    "introductivilor": "introductiv",
    "introductivul": "introductiv",
    "introductivului": "introductiv",
    "introdusă": "introdus",
    "introduse": "introdus",
    "introduși": "introdus",
    "întroienea": "întroieni",
    "întroieneai": "întroieni",
    "întroieneam": "întroieni",
    "întroienească": "întroieni",
    "întroieneați": "întroieni",
    "întroieneau": "întroieni",
    "întroienesc": "întroieni",
    "întroienește": "întroieni",
    "întroienești": "întroieni",
    "întroienii": "întroieni",
    "întroienim": "întroieni",
    "întroienind": "întroieni",
    "întroienindu": "întroieni",
    "întroieniră": "întroieni",
    "întroienirăm": "întroieni",
    "întroienirăți": "întroieni",
    "întroienise": "întroieni",
    "întroienisem": "întroieni",
    "întroieniseră": "întroieni",
    "întroieniserăm": "întroieni",
    "întroieniserăți": "întroieni",
    "întroieniseși": "întroieni",
    "întroieniși": "întroieni",
    "întroienit": "întroieni",
    "întroieniți": "întroieni",
    "întroienitu": "întroieni",
    "neîntroienind": "întroieni",
    "neîntroienindu": "întroieni",
    "nemaiîntroienind": "întroieni",
    "nemaiîntroienindu": "întroieni",
    "întroienită": "întroienit",
    "întroienite": "întroienit",
    "întroieniți": "întroienit",
    "întronă": "întrona",
    "întronai": "întrona",
    "întronam": "întrona",
    "întronăm": "întrona",
    "întronând": "întrona",
    "întronându": "întrona",
    "întronară": "întrona",
    "întronarăm": "întrona",
    "întronarăți": "întrona",
    "întronase": "întrona",
    "întronasem": "întrona",
    "întronaseră": "întrona",
    "întronaserăm": "întrona",
    "întronaserăți": "întrona",
    "întronaseși": "întrona",
    "întronași": "întrona",
    "întronat": "întrona",
    "întronați": "întrona",
    "întronatu": "întrona",
    "întronau": "întrona",
    "întronează": "întrona",
    "întronez": "întrona",
    "întroneze": "întrona",
    "întronezi": "întrona",
    "neîntronând": "întrona",
    "neîntronându": "întrona",
    "nemaiîntronând": "întrona",
    "nemaiîntronându": "întrona",
    "întronată": "întronat",
    "întronate": "întronat",
    "întronați": "întronat",
    "introspecția": "introspecție",
    "introspecției": "introspecție",
    "introspecții": "introspecție",
    "introspecțiile": "introspecție",
    "introspecțiilor": "introspecție",
    "introspectiva": "introspectiv",
    "introspectivă": "introspectiv",
    "introspective": "introspectiv",
    "introspectivei": "introspectiv",
    "introspectivele": "introspectiv",
    "introspectivelor": "introspectiv",
    "introspectivi": "introspectiv",
    "introspectivii": "introspectiv",
    "introspectivilor": "introspectiv",
    "introspectivul": "introspectiv",
    "introspectivului": "introspectiv",
    "într": "întru",
    "într-": "întru",
    "întruchipă": "întruchipa",
    "întruchipai": "întruchipa",
    "întruchipam": "întruchipa",
    "întruchipăm": "întruchipa",
    "întruchipând": "întruchipa",
    "întruchipându": "întruchipa",
    "întruchipară": "întruchipa",
    "întruchiparăm": "întruchipa",
    "întruchiparăți": "întruchipa",
    "întruchipase": "întruchipa",
    "întruchipasem": "întruchipa",
    "întruchipaseră": "întruchipa",
    "întruchipaserăm": "întruchipa",
    "întruchipaserăți": "întruchipa",
    "întruchipaseși": "întruchipa",
    "întruchipași": "întruchipa",
    "întruchipat": "întruchipa",
    "întruchipați": "întruchipa",
    "întruchipatu": "întruchipa",
    "întruchipau": "întruchipa",
    "întruchipează": "întruchipa",
    "întruchipez": "întruchipa",
    "întruchipeze": "întruchipa",
    "întruchipezi": "întruchipa",
    "neîntruchipând": "întruchipa",
    "neîntruchipându": "întruchipa",
    "nemaiîntruchipând": "întruchipa",
    "nemaiîntruchipându": "întruchipa",
    "întruchiparea": "întruchipare",
    "întruchipări": "întruchipare",
    "întruchipării": "întruchipare",
    "întruchipările": "întruchipare",
    "întruchipărilor": "întruchipare",
    "întruchipată": "întruchipat",
    "întruchipate": "întruchipat",
    "întruchipați": "întruchipat",
    "întrunea": "întruni",
    "întruneai": "întruni",
    "întruneam": "întruni",
    "întrunească": "întruni",
    "întruneați": "întruni",
    "întruneau": "întruni",
    "întrunesc": "întruni",
    "întrunește": "întruni",
    "întrunești": "întruni",
    "întrunii": "întruni",
    "întrunim": "întruni",
    "întrunind": "întruni",
    "întrunindu": "întruni",
    "întruniră": "întruni",
    "întrunirăm": "întruni",
    "întrunirăți": "întruni",
    "întrunise": "întruni",
    "întrunisem": "întruni",
    "întruniseră": "întruni",
    "întruniserăm": "întruni",
    "întruniserăți": "întruni",
    "întruniseși": "întruni",
    "întruniși": "întruni",
    "întrunit": "întruni",
    "întruniți": "întruni",
    "întrunitu": "întruni",
    "neîntrunind": "întruni",
    "neîntrunindu": "întruni",
    "nemaiîntrunind": "întruni",
    "nemaiîntrunindu": "întruni",
    "întrunirea": "întrunire",
    "întruniri": "întrunire",
    "întrunirii": "întrunire",
    "întrunirile": "întrunire",
    "întrunirilor": "întrunire",
    "întrunită": "întrunit",
    "întrunite": "întrunit",
    "întruniți": "întrunit",
    "întrupă": "întrupa",
    "întrupai": "întrupa",
    "întrupam": "întrupa",
    "întrupăm": "întrupa",
    "întrupând": "întrupa",
    "întrupându": "întrupa",
    "întrupară": "întrupa",
    "întruparăm": "întrupa",
    "întruparăți": "întrupa",
    "întrupase": "întrupa",
    "întrupasem": "întrupa",
    "întrupaseră": "întrupa",
    "întrupaserăm": "întrupa",
    "întrupaserăți": "întrupa",
    "întrupaseși": "întrupa",
    "întrupași": "întrupa",
    "întrupat": "întrupa",
    "întrupați": "întrupa",
    "întrupatu": "întrupa",
    "întrupau": "întrupa",
    "întrupează": "întrupa",
    "întrupez": "întrupa",
    "întrupeze": "întrupa",
    "întrupezi": "întrupa",
    "neîntrupând": "întrupa",
    "neîntrupându": "întrupa",
    "nemaiîntrupând": "întrupa",
    "nemaiîntrupându": "întrupa",
    "întruparea": "întrupare",
    "întrupareo": "întrupare",
    "întrupări": "întrupare",
    "întrupării": "întrupare",
    "întrupările": "întrupare",
    "întrupărilor": "întrupare",
    "întrupată": "întrupat",
    "întrupate": "întrupat",
    "întrupați": "întrupat",
    "intruși": "intrus",
    "intrușii": "intrus",
    "intrușilor": "intrus",
    "intrusul": "intrus",
    "intrusului": "intrus",
    "intruziunea": "intruziune",
    "intruziuni": "intruziune",
    "intruziunii": "intruziune",
    "intruziunile": "intruziune",
    "intruziunilor": "intruziune",
    "intruziuno": "intruziune",
    "intuia": "intui",
    "intuiai": "intui",
    "intuiam": "intui",
    "intuiască": "intui",
    "intuiați": "intui",
    "intuiau": "intui",
    "intuiesc": "intui",
    "intuiește": "intui",
    "intuiești": "intui",
    "intuii": "intui",
    "intuim": "intui",
    "intuind": "intui",
    "intuindu": "intui",
    "intuiră": "intui",
    "intuirăm": "intui",
    "intuirăți": "intui",
    "intuise": "intui",
    "intuisem": "intui",
    "intuiseră": "intui",
    "intuiserăm": "intui",
    "intuiserăți": "intui",
    "intuiseși": "intui",
    "intuiși": "intui",
    "intuit": "intui",
    "intuiți": "intui",
    "intuitu": "intui",
    "neintuind": "intui",
    "neintuindu": "intui",
    "nemaiintuind": "intui",
    "nemaiintuindu": "intui",
    "intuirea": "intuire",
    "intuireo": "intuire",
    "intuiri": "intuire",
    "intuirii": "intuire",
    "intuirile": "intuire",
    "intuirilor": "intuire",
    "intuită": "intuit",
    "intuite": "intuit",
    "intuiți": "intuit",
    "intuiția": "intuiție",
    "intuiției": "intuiție",
    "intuiții": "intuiție",
    "intuițiile": "intuiție",
    "intuițiilor": "intuiție",
    "intuitiva": "intuitiv",
    "intuitivă": "intuitiv",
    "intuitive": "intuitiv",
    "intuitivei": "intuitiv",
    "intuitivele": "intuitiv",
    "intuitivelor": "intuitiv",
    "intuitivi": "intuitiv",
    "intuitivii": "intuitiv",
    "intuitivilor": "intuitiv",
    "intuitivul": "intuitiv",
    "intuitivului": "intuitiv",
    "întunec": "întuneca",
    "întunecă": "întuneca",
    "întunecai": "întuneca",
    "întunecam": "întuneca",
    "întunecăm": "întuneca",
    "întunecând": "întuneca",
    "întunecându": "întuneca",
    "întunecară": "întuneca",
    "întunecarăm": "întuneca",
    "întunecarăți": "întuneca",
    "întunecase": "întuneca",
    "întunecasem": "întuneca",
    "întunecaseră": "întuneca",
    "întunecaserăm": "întuneca",
    "întunecaserăți": "întuneca",
    "întunecaseși": "întuneca",
    "întunecași": "întuneca",
    "întunecat": "întuneca",
    "întunecați": "întuneca",
    "întunecatu": "întuneca",
    "întunecau": "întuneca",
    "întunece": "întuneca",
    "întuneci": "întuneca",
    "neîntunecând": "întuneca",
    "neîntunecându": "întuneca",
    "nemaiîntunecând": "întuneca",
    "nemaiîntunecându": "întuneca",
    "întunecarea": "întunecare",
    "întunecareo": "întunecare",
    "întunecări": "întunecare",
    "întunecării": "întunecare",
    "întunecările": "întunecare",
    "întunecărilor": "întunecare",
    "întunecata": "întunecat",
    "întunecată": "întunecat",
    "întunecate": "întunecat",
    "întunecatei": "întunecat",
    "întunecatele": "întunecat",
    "întunecatelor": "întunecat",
    "întunecați": "întunecat",
    "întunecații": "întunecat",
    "întunecaților": "întunecat",
    "întunecatul": "întunecat",
    "întunecatului": "întunecat",
    "întunecimea": "întunecime",
    "întunecimi": "întunecime",
    "întunecimii": "întunecime",
    "întunecimile": "întunecime",
    "întunecimilor": "întunecime",
    "întunecoasa": "întunecos",
    "întunecoasă": "întunecos",
    "întunecoase": "întunecos",
    "întunecoasei": "întunecos",
    "întunecoasele": "întunecos",
    "întunecoaselor": "întunecos",
    "întunecoși": "întunecos",
    "întunecoșii": "întunecos",
    "întunecoșilor": "întunecos",
    "întunecosul": "întunecos",
    "întunecosului": "întunecos",
    "întunericul": "întuneric",
    "întunericului": "întuneric",
    "inumana": "inuman",
    "inumană": "inuman",
    "inumane": "inuman",
    "inumanei": "inuman",
    "inumanele": "inuman",
    "inumanelor": "inuman",
    "inumani": "inuman",
    "inumanii": "inuman",
    "inumanilor": "inuman",
    "inumanul": "inuman",
    "inumanului": "inuman",
    "inund": "inunda",
    "inundă": "inunda",
    "inundai": "inunda",
    "inundam": "inunda",
    "inundăm": "inunda",
    "inundând": "inunda",
    "inundându": "inunda",
    "inundară": "inunda",
    "inundarăm": "inunda",
    "inundarăți": "inunda",
    "inundase": "inunda",
    "inundasem": "inunda",
    "inundaseră": "inunda",
    "inundaserăm": "inunda",
    "inundaserăți": "inunda",
    "inundaseși": "inunda",
    "inundași": "inunda",
    "inundat": "inunda",
    "inundați": "inunda",
    "inundatu": "inunda",
    "inundau": "inunda",
    "inunde": "inunda",
    "inunzi": "inunda",
    "neinundând": "inunda",
    "neinundându": "inunda",
    "nemaiinundând": "inunda",
    "nemaiinundându": "inunda",
    "inundată": "inundat",
    "inundate": "inundat",
    "inundați": "inundat",
    "inundația": "inundație",
    "inundației": "inundație",
    "inundații": "inundație",
    "inundațiile": "inundație",
    "inundațiilor": "inundație",
    "inutila": "inutil",
    "inutilă": "inutil",
    "inutile": "inutil",
    "inutilei": "inutil",
    "inutilele": "inutil",
    "inutilelor": "inutil",
    "inutili": "inutil",
    "inutilii": "inutil",
    "inutililor": "inutil",
    "inutilul": "inutil",
    "inutilului": "inutil",
    "inutilitatea": "inutilitate",
    "inutilități": "inutilitate",
    "inutilității": "inutilitate",
    "inutilitățile": "inutilitate",
    "inutilităților": "inutilitate",
    "invadă": "invada",
    "invadai": "invada",
    "invadam": "invada",
    "invadăm": "invada",
    "invadând": "invada",
    "invadându": "invada",
    "invadară": "invada",
    "invadarăm": "invada",
    "invadarăți": "invada",
    "invadase": "invada",
    "invadasem": "invada",
    "invadaseră": "invada",
    "invadaserăm": "invada",
    "invadaserăți": "invada",
    "invadaseși": "invada",
    "invadași": "invada",
    "invadat": "invada",
    "invadați": "invada",
    "invadatu": "invada",
    "invadau": "invada",
    "invadează": "invada",
    "invadez": "invada",
    "invadeze": "invada",
    "invadezi": "invada",
    "neinvadând": "invada",
    "neinvadându": "invada",
    "nemaiinvadând": "invada",
    "nemaiinvadându": "invada",
    "invadarea": "invadare",
    "invadări": "invadare",
    "invadării": "invadare",
    "invadările": "invadare",
    "invadărilor": "invadare",
    "invadată": "invadat",
    "invadate": "invadat",
    "invadați": "invadat",
    "invadatori": "invadator",
    "invadatorii": "invadator",
    "invadatorilor": "invadator",
    "invadatorul": "invadator",
    "invadatorului": "invadator",
    "învălătucea": "învălătuci",
    "învălătuceai": "învălătuci",
    "învălătuceam": "învălătuci",
    "învălătucească": "învălătuci",
    "învălătuceați": "învălătuci",
    "învălătuceau": "învălătuci",
    "învălătucesc": "învălătuci",
    "învălătucește": "învălătuci",
    "învălătucești": "învălătuci",
    "învălătucii": "învălătuci",
    "învălătucim": "învălătuci",
    "învălătucind": "învălătuci",
    "învălătucindu": "învălătuci",
    "învălătuciră": "învălătuci",
    "învălătucirăm": "învălătuci",
    "învălătucirăți": "învălătuci",
    "învălătucise": "învălătuci",
    "învălătucisem": "învălătuci",
    "învălătuciseră": "învălătuci",
    "învălătuciserăm": "învălătuci",
    "învălătuciserăți": "învălătuci",
    "învălătuciseși": "învălătuci",
    "învălătuciși": "învălătuci",
    "învălătucit": "învălătuci",
    "învălătuciți": "învălătuci",
    "învălătucitu": "învălătuci",
    "neînvălătucind": "învălătuci",
    "neînvălătucindu": "învălătuci",
    "nemaiînvălătucind": "învălătuci",
    "nemaiînvălătucindu": "învălătuci",
    "învălătucită": "învălătucit",
    "învălătucite": "învălătucit",
    "învălătuciți": "învălătucit",
    "invalida": "invalid",
    "invalidă": "invalid",
    "invalide": "invalid",
    "invalidei": "invalid",
    "invalidele": "invalid",
    "invalidelor": "invalid",
    "invalidul": "invalid",
    "invalidului": "invalid",
    "invalizi": "invalid",
    "invalizii": "invalid",
    "invalizilor": "invalid",
    "invalidă": "invalida",
    "invalidai": "invalida",
    "invalidam": "invalida",
    "invalidăm": "invalida",
    "invalidând": "invalida",
    "invalidându": "invalida",
    "invalidară": "invalida",
    "invalidarăm": "invalida",
    "invalidarăți": "invalida",
    "invalidase": "invalida",
    "invalidasem": "invalida",
    "invalidaseră": "invalida",
    "invalidaserăm": "invalida",
    "invalidaserăți": "invalida",
    "invalidaseși": "invalida",
    "invalidași": "invalida",
    "invalidat": "invalida",
    "invalidați": "invalida",
    "invalidatu": "invalida",
    "invalidau": "invalida",
    "invalidează": "invalida",
    "invalidez": "invalida",
    "invalideze": "invalida",
    "invalidezi": "invalida",
    "neinvalidând": "invalida",
    "neinvalidându": "invalida",
    "nemaiinvalidând": "invalida",
    "nemaiinvalidându": "invalida",
    "invalidată": "invalidat",
    "invalidate": "invalidat",
    "invalidați": "invalidat",
    "invaliditatea": "invaliditate",
    "invalidități": "invaliditate",
    "invalidității": "invaliditate",
    "invaliditățile": "invaliditate",
    "invalidităților": "invaliditate",
    "învălmășeala": "învălmășeală",
    "învălmășeli": "învălmășeală",
    "învălmășelii": "învălmășeală",
    "învălmășelile": "învălmășeală",
    "învălmășelilor": "învălmășeală",
    "învălmășea": "învălmăși",
    "învălmășeai": "învălmăși",
    "învălmășeam": "învălmăși",
    "învălmășească": "învălmăși",
    "învălmășeați": "învălmăși",
    "învălmășeau": "învălmăși",
    "învălmășesc": "învălmăși",
    "învălmășește": "învălmăși",
    "învălmășești": "învălmăși",
    "învălmășii": "învălmăși",
    "învălmășim": "învălmăși",
    "învălmășind": "învălmăși",
    "învălmășindu": "învălmăși",
    "învălmășiră": "învălmăși",
    "învălmășirăm": "învălmăși",
    "învălmășirăți": "învălmăși",
    "învălmășise": "învălmăși",
    "învălmășisem": "învălmăși",
    "învălmășiseră": "învălmăși",
    "învălmășiserăm": "învălmăși",
    "învălmășiserăți": "învălmăși",
    "învălmășiseși": "învălmăși",
    "învălmășiși": "învălmăși",
    "învălmășit": "învălmăși",
    "învălmășiți": "învălmăși",
    "învălmășitu": "învălmăși",
    "neînvălmășind": "învălmăși",
    "neînvălmășindu": "învălmăși",
    "nemaiînvălmășind": "învălmăși",
    "nemaiînvălmășindu": "învălmăși",
    "învălmășită": "învălmășit",
    "învălmășite": "învălmășit",
    "învălmășiți": "învălmășit",
    "învăluia": "învălui",
    "învăluiai": "învălui",
    "învăluiam": "învălui",
    "învăluiați": "învălui",
    "învăluiau": "învălui",
    "învăluie": "învălui",
    "învăluii": "învălui",
    "învăluim": "învălui",
    "învăluind": "învălui",
    "învăluindu": "învălui",
    "învăluiră": "învălui",
    "învăluirăm": "învălui",
    "învăluirăți": "învălui",
    "învăluise": "învălui",
    "învăluisem": "învălui",
    "învăluiseră": "învălui",
    "învăluiserăm": "învălui",
    "învăluiserăți": "învălui",
    "învăluiseși": "învălui",
    "învăluiși": "învălui",
    "învăluit": "învălui",
    "învăluiți": "învălui",
    "învăluitu": "învălui",
    "neînvăluind": "învălui",
    "neînvăluindu": "învălui",
    "nemaiînvăluind": "învălui",
    "nemaiînvăluindu": "învălui",
    "învăluită": "învăluit",
    "învăluite": "învăluit",
    "învăluiți": "învăluit",
    "învăluitoare": "învăluitor",
    "învăluitoarea": "învăluitor",
    "învăluitoarei": "învăluitor",
    "învăluitoarele": "învăluitor",
    "învăluitoarelor": "învăluitor",
    "învăluitori": "învăluitor",
    "învăluitorii": "învăluitor",
    "învăluitorilor": "învăluitor",
    "învăluitorul": "învăluitor",
    "învăluitorului": "învăluitor",
    "învăpăiai": "învăpăia",
    "învăpăiam": "învăpăia",
    "învăpăiară": "învăpăia",
    "învăpăiarăm": "învăpăia",
    "învăpăiarăți": "învăpăia",
    "învăpăiase": "învăpăia",
    "învăpăiasem": "învăpăia",
    "învăpăiaseră": "învăpăia",
    "învăpăiaserăm": "învăpăia",
    "învăpăiaserăți": "învăpăia",
    "învăpăiaseși": "învăpăia",
    "învăpăiași": "învăpăia",
    "învăpăiat": "învăpăia",
    "învăpăiați": "învăpăia",
    "învăpăiatu": "învăpăia",
    "învăpăiau": "învăpăia",
    "învăpăiază": "învăpăia",
    "învăpăie": "învăpăia",
    "învăpăiem": "învăpăia",
    "învăpăiez": "învăpăia",
    "învăpăieze": "învăpăia",
    "învăpăiezi": "învăpăia",
    "învăpăind": "învăpăia",
    "învăpăindu": "învăpăia",
    "neînvăpăiind": "învăpăia",
    "neînvăpăiindu": "învăpăia",
    "nemaiînvăpăiind": "învăpăia",
    "nemaiînvăpăiindu": "învăpăia",
    "învăpăiată": "învăpăiat",
    "învăpăiate": "învăpăiat",
    "învăpăiați": "învăpăiat",
    "invar.": "invariabil",
    "invariabila": "invariabil",
    "invariabilă": "invariabil",
    "invariabile": "invariabil",
    "invariabilei": "invariabil",
    "invariabilele": "invariabil",
    "invariabilelor": "invariabil",
    "invariabili": "invariabil",
    "invariabilii": "invariabil",
    "invariabililor": "invariabil",
    "invariabilul": "invariabil",
    "invariabilului": "invariabil",
    "învârteala": "învârteală",
    "învârteli": "învârteală",
    "învârtelii": "învârteală",
    "învârtelile": "învârteală",
    "învârtelilor": "învârteală",
    "învârtejea": "învârteji",
    "învârtejeai": "învârteji",
    "învârtejeam": "învârteji",
    "învârtejească": "învârteji",
    "învârtejeați": "învârteji",
    "învârtejeau": "învârteji",
    "învârtejesc": "învârteji",
    "învârtejește": "învârteji",
    "învârtejești": "învârteji",
    "învârtejii": "învârteji",
    "învârtejim": "învârteji",
    "învârtejind": "învârteji",
    "învârtejindu": "învârteji",
    "învârtejiră": "învârteji",
    "învârtejirăm": "învârteji",
    "învârtejirăți": "învârteji",
    "învârtejise": "învârteji",
    "învârtejisem": "învârteji",
    "învârtejiseră": "învârteji",
    "învârtejiserăm": "învârteji",
    "învârtejiserăți": "învârteji",
    "învârtejiseși": "învârteji",
    "învârtejiși": "învârteji",
    "învârtejit": "învârteji",
    "învârtejiți": "învârteji",
    "învârtejitu": "învârteji",
    "neînvârtejind": "învârteji",
    "neînvârtejindu": "învârteji",
    "nemaiînvârtejind": "învârteji",
    "nemaiînvârtejindu": "învârteji",
    "învârtejită": "învârtejit",
    "învârtejite": "învârtejit",
    "învârtejiți": "învârtejit",
    "învârt": "învârti",
    "învârtă": "învârti",
    "învârte": "învârti",
    "învârtea": "învârti",
    "învârteai": "învârti",
    "învârteam": "învârti",
    "învârtească": "învârti",
    "învârteați": "învârti",
    "învârteau": "învârti",
    "învârtesc": "învârti",
    "învârtește": "învârti",
    "învârtești": "învârti",
    "învârți": "învârti",
    "învârtii": "învârti",
    "învârtim": "învârti",
    "învârtind": "învârti",
    "învârtindu": "învârti",
    "învârtiră": "învârti",
    "învârtirăm": "învârti",
    "învârtirăți": "învârti",
    "învârtise": "învârti",
    "învârtisem": "învârti",
    "învârtiseră": "învârti",
    "învârtiserăm": "învârti",
    "învârtiserăți": "învârti",
    "învârtiseși": "învârti",
    "învârtiși": "învârti",
    "învârtit": "învârti",
    "învârtiți": "învârti",
    "învârtitu": "învârti",
    "neînvârtind": "învârti",
    "neînvârtindu": "învârti",
    "nemaiînvârtind": "învârti",
    "nemaiînvârtindu": "învârti",
    "învârtită": "învârtit",
    "învârtite": "învârtit",
    "învârtiți": "învârtit",
    "învârtoșă": "învârtoșa",
    "învârtoșai": "învârtoșa",
    "învârtoșam": "învârtoșa",
    "învârtoșăm": "învârtoșa",
    "învârtoșând": "învârtoșa",
    "învârtoșându": "învârtoșa",
    "învârtoșară": "învârtoșa",
    "învârtoșarăm": "învârtoșa",
    "învârtoșarăți": "învârtoșa",
    "învârtoșase": "învârtoșa",
    "învârtoșasem": "învârtoșa",
    "învârtoșaseră": "învârtoșa",
    "învârtoșaserăm": "învârtoșa",
    "învârtoșaserăți": "învârtoșa",
    "învârtoșaseși": "învârtoșa",
    "învârtoșași": "învârtoșa",
    "învârtoșat": "învârtoșa",
    "învârtoșați": "învârtoșa",
    "învârtoșatu": "învârtoșa",
    "învârtoșau": "învârtoșa",
    "învârtoșează": "învârtoșa",
    "învârtoșez": "învârtoșa",
    "învârtoșeze": "învârtoșa",
    "învârtoșezi": "învârtoșa",
    "neînvârtoșând": "învârtoșa",
    "neînvârtoșându": "învârtoșa",
    "nemaiînvârtoșând": "învârtoșa",
    "nemaiînvârtoșându": "învârtoșa",
    "învârtoșată": "învârtoșat",
    "învârtoșate": "învârtoșat",
    "învârtoșați": "învârtoșat",
    "învăț": "învăța",
    "învață": "învăța",
    "învăță": "învăța",
    "învățai": "învăța",
    "învățam": "învăța",
    "învățăm": "învăța",
    "învățând": "învăța",
    "învățându": "învăța",
    "învățară": "învăța",
    "învățarăm": "învăța",
    "învățarăți": "învăța",
    "învățase": "învăța",
    "învățasem": "învăța",
    "învățaseră": "învăța",
    "învățaserăm": "învăța",
    "învățaserăți": "învăța",
    "învățaseși": "învăța",
    "învățași": "învăța",
    "învățat": "învăța",
    "învățați": "învăța",
    "învățatu": "învăța",
    "învățau": "învăța",
    "învețe": "învăța",
    "înveți": "învăța",
    "neînvățând": "învăța",
    "neînvățându": "învăța",
    "nemaiînvățând": "învăța",
    "nemaiînvățându": "învăța",
    "învățăcei": "învățăcel",
    "învățăceii": "învățăcel",
    "învățăceilor": "învățăcel",
    "învățăcelul": "învățăcel",
    "învățăcelule": "învățăcel",
    "învățăcelului": "învățăcel",
    "învățământul": "învățământ",
    "învățământului": "învățământ",
    "învățăminte": "învățământ",
    "învățămintele": "învățământ",
    "învățămintelor": "învățământ",
    "învățarea": "învățare",
    "învățări": "învățare",
    "învățării": "învățare",
    "învățările": "învățare",
    "învățărilor": "învățare",
    "învățată": "învățat",
    "învățate": "învățat",
    "învățați": "învățat",
    "învățații": "învățat",
    "învățaților": "învățat",
    "învățatul": "învățat",
    "învățatului": "învățat",
    "învățătoarea": "învățătoare",
    "învățătoarei": "învățătoare",
    "învățătoarele": "învățătoare",
    "învățătoarelor": "învățătoare",
    "înv.": "învățător",
    "învățători": "învățător",
    "învățătorii": "învățător",
    "învățătorilor": "învățător",
    "învățătorul": "învățător",
    "învățătorului": "învățător",
    "învățătura": "învățătură",
    "învățături": "învățătură",
    "învățăturii": "învățătură",
    "învățăturile": "învățătură",
    "învățăturilor": "învățătură",
    "invazia": "invazie",
    "invaziei": "invazie",
    "invazii": "invazie",
    "invaziile": "invazie",
    "invaziilor": "invazie",
    "învechea": "învechi",
    "învecheai": "învechi",
    "învecheam": "învechi",
    "învechească": "învechi",
    "învecheați": "învechi",
    "învecheau": "învechi",
    "învechesc": "învechi",
    "învechește": "învechi",
    "învechești": "învechi",
    "învechii": "învechi",
    "învechim": "învechi",
    "învechind": "învechi",
    "învechindu": "învechi",
    "învechiră": "învechi",
    "învechirăm": "învechi",
    "învechirăți": "învechi",
    "învechise": "învechi",
    "învechisem": "învechi",
    "învechiseră": "învechi",
    "învechiserăm": "învechi",
    "învechiserăți": "învechi",
    "învechiseși": "învechi",
    "învechiși": "învechi",
    "învechit": "învechi",
    "învechiți": "învechi",
    "învechitu": "învechi",
    "neînvechind": "învechi",
    "neînvechindu": "învechi",
    "nemaiînvechind": "învechi",
    "nemaiînvechindu": "învechi",
    "învechita": "învechit",
    "învechită": "învechit",
    "învechite": "învechit",
    "învechitei": "învechit",
    "învechitele": "învechit",
    "învechitelor": "învechit",
    "învechiți": "învechit",
    "învechiții": "învechit",
    "învechiților": "învechit",
    "învechitul": "învechit",
    "învechitului": "învechit",
    "învecină": "învecina",
    "învecinai": "învecina",
    "învecinam": "învecina",
    "învecinăm": "învecina",
    "învecinând": "învecina",
    "învecinându": "învecina",
    "învecinară": "învecina",
    "învecinarăm": "învecina",
    "învecinarăți": "învecina",
    "învecinase": "învecina",
    "învecinasem": "învecina",
    "învecinaseră": "învecina",
    "învecinaserăm": "învecina",
    "învecinaserăți": "învecina",
    "învecinaseși": "învecina",
    "învecinași": "învecina",
    "învecinat": "învecina",
    "învecinați": "învecina",
    "învecinatu": "învecina",
    "învecinau": "învecina",
    "învecinează": "învecina",
    "învecinez": "învecina",
    "învecineze": "învecina",
    "învecinezi": "învecina",
    "neînvecinând": "învecina",
    "neînvecinându": "învecina",
    "nemaiînvecinând": "învecina",
    "nemaiînvecinându": "învecina",
    "învecinata": "învecinat",
    "învecinată": "învecinat",
    "învecinate": "învecinat",
    "învecinatei": "învecinat",
    "învecinatele": "învecinat",
    "învecinatelor": "învecinat",
    "învecinați": "învecinat",
    "învecinații": "învecinat",
    "învecinaților": "învecinat",
    "învecinatul": "învecinat",
    "învecinatului": "învecinat",
    "invectivă": "invectiva",
    "invectivai": "invectiva",
    "invectivam": "invectiva",
    "invectivăm": "invectiva",
    "invectivând": "invectiva",
    "invectivându": "invectiva",
    "invectivară": "invectiva",
    "invectivarăm": "invectiva",
    "invectivarăți": "invectiva",
    "invectivase": "invectiva",
    "invectivasem": "invectiva",
    "invectivaseră": "invectiva",
    "invectivaserăm": "invectiva",
    "invectivaserăți": "invectiva",
    "invectivaseși": "invectiva",
    "invectivași": "invectiva",
    "invectivat": "invectiva",
    "invectivați": "invectiva",
    "invectivatu": "invectiva",
    "invectivau": "invectiva",
    "invectivează": "invectiva",
    "invectivez": "invectiva",
    "invectiveze": "invectiva",
    "invectivezi": "invectiva",
    "neinvectivând": "invectiva",
    "neinvectivându": "invectiva",
    "nemaiinvectivând": "invectiva",
    "nemaiinvectivându": "invectiva",
    "invectiva": "invectivă",
    "invective": "invectivă",
    "invectivei": "invectivă",
    "invectivele": "invectivă",
    "invectivelor": "invectivă",
    "invectivată": "invectivat",
    "invectivate": "invectivat",
    "invectivați": "invectivat",
    "învederă": "învedera",
    "învederai": "învedera",
    "învederam": "învedera",
    "învederăm": "învedera",
    "învederând": "învedera",
    "învederându": "învedera",
    "învederară": "învedera",
    "învederarăm": "învedera",
    "învederarăți": "învedera",
    "învederase": "învedera",
    "învederasem": "învedera",
    "învederaseră": "învedera",
    "învederaserăm": "învedera",
    "învederaserăți": "învedera",
    "învederaseși": "învedera",
    "învederași": "învedera",
    "învederat": "învedera",
    "învederați": "învedera",
    "învederatu": "învedera",
    "învederau": "învedera",
    "învederează": "învedera",
    "învederez": "învedera",
    "învedereze": "învedera",
    "învederezi": "învedera",
    "neînvederând": "învedera",
    "neînvederându": "învedera",
    "nemaiînvederând": "învedera",
    "nemaiînvederându": "învedera",
    "învederată": "învederat",
    "învederate": "învederat",
    "învederați": "învederat",
    "învelea": "înveli",
    "înveleai": "înveli",
    "înveleam": "înveli",
    "învelească": "înveli",
    "înveleați": "înveli",
    "înveleau": "înveli",
    "învelesc": "înveli",
    "învelește": "înveli",
    "învelești": "înveli",
    "învelii": "înveli",
    "învelim": "înveli",
    "învelind": "înveli",
    "învelindu": "înveli",
    "înveliră": "înveli",
    "învelirăm": "înveli",
    "învelirăți": "înveli",
    "învelise": "înveli",
    "învelisem": "înveli",
    "înveliseră": "înveli",
    "înveliserăm": "înveli",
    "înveliserăți": "înveli",
    "înveliseși": "înveli",
    "înveliși": "înveli",
    "învelit": "înveli",
    "înveliți": "înveli",
    "învelitu": "înveli",
    "neînvelind": "înveli",
    "neînvelindu": "înveli",
    "nemaiînvelind": "înveli",
    "nemaiînvelindu": "înveli",
    "învelișul": "înveliș",
    "învelișului": "înveliș",
    "învelișuri": "înveliș",
    "învelișurile": "înveliș",
    "învelișurilor": "înveliș",
    "învelită": "învelit",
    "învelite": "învelit",
    "înveliți": "învelit",
    "învelitoarea": "învelitoare",
    "învelitori": "învelitoare",
    "învelitorii": "învelitoare",
    "învelitorile": "învelitoare",
    "învelitorilor": "învelitoare",
    "învenină": "învenina",
    "înveninai": "învenina",
    "înveninam": "învenina",
    "înveninăm": "învenina",
    "înveninând": "învenina",
    "înveninându": "învenina",
    "înveninară": "învenina",
    "înveninarăm": "învenina",
    "înveninarăți": "învenina",
    "înveninase": "învenina",
    "înveninasem": "învenina",
    "înveninaseră": "învenina",
    "înveninaserăm": "învenina",
    "înveninaserăți": "învenina",
    "înveninaseși": "învenina",
    "înveninași": "învenina",
    "înveninat": "învenina",
    "înveninați": "învenina",
    "înveninatu": "învenina",
    "înveninau": "învenina",
    "înveninează": "învenina",
    "înveninez": "învenina",
    "învenineze": "învenina",
    "înveninezi": "învenina",
    "neînveninând": "învenina",
    "neînveninându": "învenina",
    "nemaiînveninând": "învenina",
    "nemaiînveninându": "învenina",
    "înveninată": "înveninat",
    "înveninate": "înveninat",
    "înveninați": "înveninat",
    "inventă": "inventa",
    "inventai": "inventa",
    "inventam": "inventa",
    "inventăm": "inventa",
    "inventând": "inventa",
    "inventându": "inventa",
    "inventară": "inventa",
    "inventarăm": "inventa",
    "inventarăți": "inventa",
    "inventase": "inventa",
    "inventasem": "inventa",
    "inventaseră": "inventa",
    "inventaserăm": "inventa",
    "inventaserăți": "inventa",
    "inventaseși": "inventa",
    "inventași": "inventa",
    "inventat": "inventa",
    "inventați": "inventa",
    "inventatu": "inventa",
    "inventau": "inventa",
    "inventează": "inventa",
    "inventez": "inventa",
    "inventeze": "inventa",
    "inventezi": "inventa",
    "neinventând": "inventa",
    "neinventându": "inventa",
    "nemaiinventând": "inventa",
    "nemaiinventându": "inventa",
    "inventare": "inventar",
    "inventarele": "inventar",
    "inventarelor": "inventar",
    "inventarul": "inventar",
    "inventarului": "inventar",
    "inventarea": "inventare",
    "inventareo": "inventare",
    "inventări": "inventare",
    "inventării": "inventare",
    "inventările": "inventare",
    "inventărilor": "inventare",
    "inventariă": "inventaria",
    "inventariai": "inventaria",
    "inventariam": "inventaria",
    "inventariăm": "inventaria",
    "inventariând": "inventaria",
    "inventariându": "inventaria",
    "inventariară": "inventaria",
    "inventariarăm": "inventaria",
    "inventariarăți": "inventaria",
    "inventariase": "inventaria",
    "inventariasem": "inventaria",
    "inventariaseră": "inventaria",
    "inventariaserăm": "inventaria",
    "inventariaserăți": "inventaria",
    "inventariaseși": "inventaria",
    "inventariași": "inventaria",
    "inventariat": "inventaria",
    "inventariați": "inventaria",
    "inventariatu": "inventaria",
    "inventariau": "inventaria",
    "inventariează": "inventaria",
    "inventariez": "inventaria",
    "inventarieze": "inventaria",
    "inventariezi": "inventaria",
    "neinventariând": "inventaria",
    "neinventariându": "inventaria",
    "nemaiinventariând": "inventaria",
    "nemaiinventariându": "inventaria",
    "inventariată": "inventariat",
    "inventariate": "inventariat",
    "inventariați": "inventariat",
    "inventarierea": "inventariere",
    "inventată": "inventat",
    "inventate": "inventat",
    "inventați": "inventat",
    "inventatori": "inventator",
    "inventatorii": "inventator",
    "inventatorilor": "inventator",
    "inventatorul": "inventator",
    "inventatorului": "inventator",
    "invenția": "invenție",
    "invenției": "invenție",
    "invenții": "invenție",
    "invențiile": "invenție",
    "invențiilor": "invenție",
    "inventiva": "inventiv",
    "inventivă": "inventiv",
    "inventive": "inventiv",
    "inventivei": "inventiv",
    "inventivele": "inventiv",
    "inventivelor": "inventiv",
    "inventivi": "inventiv",
    "inventivii": "inventiv",
    "inventivilor": "inventiv",
    "inventivul": "inventiv",
    "inventivului": "inventiv",
    "inventivitatea": "inventivitate",
    "inventivitateo": "inventivitate",
    "inventivități": "inventivitate",
    "inventivității": "inventivitate",
    "inventivitățile": "inventivitate",
    "inventivităților": "inventivitate",
    "inversa": "invers",
    "inversă": "invers",
    "inverse": "invers",
    "inversei": "invers",
    "inversele": "invers",
    "inverselor": "invers",
    "inverși": "invers",
    "inverșii": "invers",
    "inverșilor": "invers",
    "inversul": "invers",
    "inversului": "invers",
    "inversă": "inversa",
    "inversai": "inversa",
    "inversam": "inversa",
    "inversăm": "inversa",
    "inversând": "inversa",
    "inversându": "inversa",
    "inversară": "inversa",
    "inversarăm": "inversa",
    "inversarăți": "inversa",
    "inversase": "inversa",
    "inversasem": "inversa",
    "inversaseră": "inversa",
    "inversaserăm": "inversa",
    "inversaserăți": "inversa",
    "inversaseși": "inversa",
    "inversași": "inversa",
    "inversat": "inversa",
    "inversați": "inversa",
    "inversatu": "inversa",
    "inversau": "inversa",
    "inversează": "inversa",
    "inversez": "inversa",
    "inverseze": "inversa",
    "inversezi": "inversa",
    "neinversând": "inversa",
    "neinversându": "inversa",
    "nemaiinversând": "inversa",
    "nemaiinversându": "inversa",
    "inversarea": "inversare",
    "inversări": "inversare",
    "inversării": "inversare",
    "inversările": "inversare",
    "inversărilor": "inversare",
    "inversată": "inversat",
    "inversate": "inversat",
    "inversați": "inversat",
    "inversiunea": "inversiune",
    "inversiuni": "inversiune",
    "inversiunii": "inversiune",
    "inversiunile": "inversiune",
    "inversiunilor": "inversiune",
    "înverșună": "înverșuna",
    "înverșunai": "înverșuna",
    "înverșunam": "înverșuna",
    "înverșunăm": "înverșuna",
    "înverșunând": "înverșuna",
    "înverșunându": "înverșuna",
    "înverșunară": "înverșuna",
    "înverșunarăm": "înverșuna",
    "înverșunarăți": "înverșuna",
    "înverșunase": "înverșuna",
    "înverșunasem": "înverșuna",
    "înverșunaseră": "înverșuna",
    "înverșunaserăm": "înverșuna",
    "înverșunaserăți": "înverșuna",
    "înverșunaseși": "înverșuna",
    "înverșunași": "înverșuna",
    "înverșunat": "înverșuna",
    "înverșunați": "înverșuna",
    "înverșunatu": "înverșuna",
    "înverșunau": "înverșuna",
    "înverșunează": "înverșuna",
    "înverșunez": "înverșuna",
    "înverșuneze": "înverșuna",
    "înverșunezi": "înverșuna",
    "neînverșunând": "înverșuna",
    "neînverșunându": "înverșuna",
    "nemaiînverșunând": "înverșuna",
    "nemaiînverșunându": "înverșuna",
    "înverșunarea": "înverșunare",
    "înverșunări": "înverșunare",
    "înverșunării": "înverșunare",
    "înverșunările": "înverșunare",
    "înverșunărilor": "înverșunare",
    "înverșunată": "înverșunat",
    "înverșunate": "înverșunat",
    "înverșunați": "înverșunat",
    "invertea": "inverti",
    "inverteai": "inverti",
    "inverteam": "inverti",
    "invertească": "inverti",
    "inverteați": "inverti",
    "inverteau": "inverti",
    "invertesc": "inverti",
    "invertește": "inverti",
    "invertești": "inverti",
    "invertii": "inverti",
    "invertim": "inverti",
    "invertind": "inverti",
    "invertindu": "inverti",
    "invertiră": "inverti",
    "invertirăm": "inverti",
    "invertirăți": "inverti",
    "invertise": "inverti",
    "invertisem": "inverti",
    "invertiseră": "inverti",
    "invertiserăm": "inverti",
    "invertiserăți": "inverti",
    "invertiseși": "inverti",
    "invertiși": "inverti",
    "invertit": "inverti",
    "invertiți": "inverti",
    "invertitu": "inverti",
    "neinvertind": "inverti",
    "neinvertindu": "inverti",
    "nemaiinvertind": "inverti",
    "nemaiinvertindu": "inverti",
    "invertită": "invertit",
    "invertite": "invertit",
    "invertiți": "invertit",
    "înverzea": "înverzi",
    "înverzeai": "înverzi",
    "înverzeam": "înverzi",
    "înverzească": "înverzi",
    "înverzeați": "înverzi",
    "înverzeau": "înverzi",
    "înverzesc": "înverzi",
    "înverzește": "înverzi",
    "înverzești": "înverzi",
    "înverzii": "înverzi",
    "înverzim": "înverzi",
    "înverzind": "înverzi",
    "înverzindu": "înverzi",
    "înverziră": "înverzi",
    "înverzirăm": "înverzi",
    "înverzirăți": "înverzi",
    "înverzise": "înverzi",
    "înverzisem": "înverzi",
    "înverziseră": "înverzi",
    "înverziserăm": "înverzi",
    "înverziserăți": "înverzi",
    "înverziseși": "înverzi",
    "înverziși": "înverzi",
    "înverzit": "înverzi",
    "înverziți": "înverzi",
    "înverzitu": "înverzi",
    "neînverzind": "înverzi",
    "neînverzindu": "înverzi",
    "nemaiînverzind": "înverzi",
    "nemaiînverzindu": "înverzi",
    "înverzita": "înverzit",
    "înverzită": "înverzit",
    "înverzite": "înverzit",
    "înverzitei": "înverzit",
    "înverzitele": "înverzit",
    "înverzitelor": "înverzit",
    "înverziți": "înverzit",
    "înverziții": "înverzit",
    "înverziților": "înverzit",
    "înverzitul": "înverzit",
    "înverzitului": "înverzit",
    "înveselea": "înveseli",
    "înveseleai": "înveseli",
    "înveseleam": "înveseli",
    "înveselească": "înveseli",
    "înveseleați": "înveseli",
    "înveseleau": "înveseli",
    "înveselesc": "înveseli",
    "înveselește": "înveseli",
    "înveselești": "înveseli",
    "înveselii": "înveseli",
    "înveselim": "înveseli",
    "înveselind": "înveseli",
    "înveselindu": "înveseli",
    "înveseliră": "înveseli",
    "înveselirăm": "înveseli",
    "înveselirăți": "înveseli",
    "înveselise": "înveseli",
    "înveselisem": "înveseli",
    "înveseliseră": "înveseli",
    "înveseliserăm": "înveseli",
    "înveseliserăți": "înveseli",
    "înveseliseși": "înveseli",
    "înveseliși": "înveseli",
    "înveselit": "înveseli",
    "înveseliți": "înveseli",
    "înveselitu": "înveseli",
    "neînveselind": "înveseli",
    "neînveselindu": "înveseli",
    "nemaiînveselind": "înveseli",
    "nemaiînveselindu": "înveseli",
    "înveselită": "înveselit",
    "înveselite": "înveselit",
    "înveseliți": "înveselit",
    "înveșmântă": "înveșmânta",
    "înveșmântai": "înveșmânta",
    "înveșmântam": "înveșmânta",
    "înveșmântăm": "înveșmânta",
    "înveșmântând": "înveșmânta",
    "înveșmântându": "înveșmânta",
    "înveșmântară": "înveșmânta",
    "înveșmântarăm": "înveșmânta",
    "înveșmântarăți": "înveșmânta",
    "înveșmântase": "înveșmânta",
    "înveșmântasem": "înveșmânta",
    "înveșmântaseră": "înveșmânta",
    "înveșmântaserăm": "înveșmânta",
    "înveșmântaserăți": "înveșmânta",
    "înveșmântaseși": "înveșmânta",
    "înveșmântași": "înveșmânta",
    "înveșmântat": "înveșmânta",
    "înveșmântați": "înveșmânta",
    "înveșmântatu": "înveșmânta",
    "înveșmântau": "înveșmânta",
    "înveșmântează": "înveșmânta",
    "înveșmântez": "înveșmânta",
    "înveșmânteze": "înveșmânta",
    "înveșmântezi": "înveșmânta",
    "neînveșmântând": "înveșmânta",
    "neînveșmântându": "înveșmânta",
    "nemaiînveșmântând": "înveșmânta",
    "nemaiînveșmântându": "înveșmânta",
    "înveșmântată": "înveșmântat",
    "înveșmântate": "înveșmântat",
    "înveșmântați": "înveșmântat",
    "înveșnicea": "înveșnici",
    "înveșniceai": "înveșnici",
    "înveșniceam": "înveșnici",
    "înveșnicească": "înveșnici",
    "înveșniceați": "înveșnici",
    "înveșniceau": "înveșnici",
    "înveșnicesc": "înveșnici",
    "înveșnicește": "înveșnici",
    "înveșnicești": "înveșnici",
    "înveșnicii": "înveșnici",
    "înveșnicim": "înveșnici",
    "înveșnicind": "înveșnici",
    "înveșnicindu": "înveșnici",
    "înveșniciră": "înveșnici",
    "înveșnicirăm": "înveșnici",
    "înveșnicirăți": "înveșnici",
    "înveșnicise": "înveșnici",
    "înveșnicisem": "înveșnici",
    "înveșniciseră": "înveșnici",
    "înveșniciserăm": "înveșnici",
    "înveșniciserăți": "înveșnici",
    "înveșniciseși": "înveșnici",
    "înveșniciși": "înveșnici",
    "înveșnicit": "înveșnici",
    "înveșniciți": "înveșnici",
    "înveșnicitu": "înveșnici",
    "neînveșnicind": "înveșnici",
    "neînveșnicindu": "înveșnici",
    "nemaiînveșnicind": "înveșnici",
    "nemaiînveșnicindu": "înveșnici",
    "înveșnicită": "înveșnicit",
    "înveșnicite": "înveșnicit",
    "înveșniciți": "înveșnicit",
    "investea": "investi",
    "investeai": "investi",
    "investeam": "investi",
    "investească": "investi",
    "investeați": "investi",
    "investeau": "investi",
    "investesc": "investi",
    "investește": "investi",
    "investești": "investi",
    "investii": "investi",
    "investim": "investi",
    "investind": "investi",
    "investindu": "investi",
    "investiră": "investi",
    "investirăm": "investi",
    "investirăți": "investi",
    "investise": "investi",
    "investisem": "investi",
    "investiseră": "investi",
    "investiserăm": "investi",
    "investiserăți": "investi",
    "investiseși": "investi",
    "investiși": "investi",
    "investit": "investi",
    "investiți": "investi",
    "investitu": "investi",
    "neinvestind": "investi",
    "neinvestindu": "investi",
    "nemaiinvestind": "investi",
    "nemaiinvestindu": "investi",
    "învestea": "învesti",
    "învesteai": "învesti",
    "învesteam": "învesti",
    "învestească": "învesti",
    "învesteați": "învesti",
    "învesteau": "învesti",
    "învestesc": "învesti",
    "învestește": "învesti",
    "învestești": "învesti",
    "învestii": "învesti",
    "învestim": "învesti",
    "învestind": "învesti",
    "învestindu": "învesti",
    "învestiră": "învesti",
    "învestirăm": "învesti",
    "învestirăți": "învesti",
    "învestise": "învesti",
    "învestisem": "învesti",
    "învestiseră": "învesti",
    "învestiserăm": "învesti",
    "învestiserăți": "învesti",
    "învestiseși": "învesti",
    "învestiși": "învesti",
    "învestit": "învesti",
    "învestiți": "învesti",
    "învestitu": "învesti",
    "neînvestind": "învesti",
    "neînvestindu": "învesti",
    "nemaiînvestind": "învesti",
    "nemaiînvestindu": "învesti",
    "investigă": "investiga",
    "investigai": "investiga",
    "investigam": "investiga",
    "investigăm": "investiga",
    "investigând": "investiga",
    "investigându": "investiga",
    "investigară": "investiga",
    "investigarăm": "investiga",
    "investigarăți": "investiga",
    "investigase": "investiga",
    "investigasem": "investiga",
    "investigaseră": "investiga",
    "investigaserăm": "investiga",
    "investigaserăți": "investiga",
    "investigaseși": "investiga",
    "investigași": "investiga",
    "investigat": "investiga",
    "investigați": "investiga",
    "investigatu": "investiga",
    "investigau": "investiga",
    "investighează": "investiga",
    "investighez": "investiga",
    "investigheze": "investiga",
    "investighezi": "investiga",
    "neinvestigând": "investiga",
    "neinvestigându": "investiga",
    "nemaiinvestigând": "investiga",
    "nemaiinvestigându": "investiga",
    "investigarea": "investigare",
    "investigareo": "investigare",
    "investigări": "investigare",
    "investigării": "investigare",
    "investigările": "investigare",
    "investigărilor": "investigare",
    "investigată": "investigat",
    "investigate": "investigat",
    "investigați": "investigat",
    "investigația": "investigație",
    "investigației": "investigație",
    "investigații": "investigație",
    "investigațiile": "investigație",
    "investigațiilor": "investigație",
    "investirea": "investire",
    "investireo": "investire",
    "investiri": "investire",
    "investirii": "investire",
    "investirile": "investire",
    "investirilor": "investire",
    "investită": "investit",
    "investite": "investit",
    "investiți": "investit",
    "învestită": "învestit",
    "învestite": "învestit",
    "învestiți": "învestit",
    "investiția": "investiție",
    "investiției": "investiție",
    "investiții": "investiție",
    "investițiile": "investiție",
    "investițiilor": "investiție",
    "investitori": "investitor",
    "investitorii": "investitor",
    "investitorilor": "investitor",
    "investitorul": "investitor",
    "investitorule": "investitor",
    "investitorului": "investitor",
    "înviai": "învia",
    "înviam": "învia",
    "înviară": "învia",
    "înviarăm": "învia",
    "înviarăți": "învia",
    "înviase": "învia",
    "înviasem": "învia",
    "înviaseră": "învia",
    "înviaserăm": "învia",
    "înviaserăți": "învia",
    "înviaseși": "învia",
    "înviași": "învia",
    "înviat": "învia",
    "înviați": "învia",
    "înviatu": "învia",
    "înviau": "învia",
    "înviază": "învia",
    "învie": "învia",
    "înviem": "învia",
    "înviez": "învia",
    "învieze": "învia",
    "înviezi": "învia",
    "înviind": "învia",
    "înviindu": "învia",
    "neînviind": "învia",
    "neînviindu": "învia",
    "nemaiînviind": "învia",
    "nemaiînviindu": "învia",
    "înviată": "înviat",
    "înviate": "înviat",
    "înviați": "înviat",
    "invidiai": "invidia",
    "invidiam": "invidia",
    "invidiară": "invidia",
    "invidiarăm": "invidia",
    "invidiarăți": "invidia",
    "invidiase": "invidia",
    "invidiasem": "invidia",
    "invidiaseră": "invidia",
    "invidiaserăm": "invidia",
    "invidiaserăți": "invidia",
    "invidiaseși": "invidia",
    "invidiași": "invidia",
    "invidiat": "invidia",
    "invidiați": "invidia",
    "invidiatu": "invidia",
    "invidiau": "invidia",
    "invidiază": "invidia",
    "invidie": "invidia",
    "invidiem": "invidia",
    "invidiez": "invidia",
    "invidieze": "invidia",
    "invidiezi": "invidia",
    "invidiind": "invidia",
    "invidiindu": "invidia",
    "neinvidiind": "invidia",
    "neinvidiindu": "invidia",
    "nemaiinvidiind": "invidia",
    "nemaiinvidiindu": "invidia",
    "invidiată": "invidiat",
    "invidiate": "invidiat",
    "invidiați": "invidiat",
    "invidia": "invidie",
    "invidiei": "invidie",
    "invidii": "invidie",
    "invidiii": "invidie",
    "invidiile": "invidie",
    "invidiilor": "invidie",
    "invidio": "invidie",
    "invidioasa": "invidios",
    "invidioasă": "invidios",
    "invidioase": "invidios",
    "invidioasei": "invidios",
    "invidioasele": "invidios",
    "invidioaselor": "invidios",
    "invidioși": "invidios",
    "invidioșii": "invidios",
    "invidioșilor": "invidios",
    "invidiosul": "invidios",
    "invidiosului": "invidios",
    "învierea": "înviere",
    "învieri": "înviere",
    "învierii": "înviere",
    "învierile": "înviere",
    "învierilor": "înviere",
    "înviforă": "învifora",
    "înviforase": "învifora",
    "înviforat": "învifora",
    "înviforatu": "învifora",
    "înviforează": "învifora",
    "înviforeze": "învifora",
    "înviforată": "înviforat",
    "invincibila": "invincibil",
    "invincibilă": "invincibil",
    "invincibile": "invincibil",
    "invincibilei": "invincibil",
    "invincibilele": "invincibil",
    "invincibilelor": "invincibil",
    "invincibili": "invincibil",
    "invincibilii": "invincibil",
    "invincibililor": "invincibil",
    "invincibilul": "invincibil",
    "invincibilului": "invincibil",
    "învinețea": "învineți",
    "învinețeai": "învineți",
    "învinețeam": "învineți",
    "învinețească": "învineți",
    "învinețeați": "învineți",
    "învinețeau": "învineți",
    "învinețesc": "învineți",
    "învinețește": "învineți",
    "învinețești": "învineți",
    "învineții": "învineți",
    "învinețim": "învineți",
    "învinețind": "învineți",
    "învinețindu": "învineți",
    "învinețiră": "învineți",
    "învinețirăm": "învineți",
    "învinețirăți": "învineți",
    "învinețise": "învineți",
    "învinețisem": "învineți",
    "învinețiseră": "învineți",
    "învinețiserăm": "învineți",
    "învinețiserăți": "învineți",
    "învinețiseși": "învineți",
    "învinețiși": "învineți",
    "învinețit": "învineți",
    "învinețiți": "învineți",
    "învinețitu": "învineți",
    "neînvinețind": "învineți",
    "neînvinețindu": "învineți",
    "nemaiînvinețind": "învineți",
    "nemaiînvinețindu": "învineți",
    "învinețită": "învinețit",
    "învinețite": "învinețit",
    "învinețiți": "învinețit",
    "învingătoare": "învingător",
    "învingători": "învingător",
    "învingătorii": "învingător",
    "învingătorilor": "învingător",
    "învingătorul": "învingător",
    "învingătorului": "învingător",
    "înving": "învinge",
    "învingă": "învinge",
    "învingând": "învinge",
    "învingându": "învinge",
    "învingea": "învinge",
    "învingeai": "învinge",
    "învingeam": "învinge",
    "învingeați": "învinge",
    "învingeau": "învinge",
    "învingem": "învinge",
    "învingeți": "învinge",
    "învingi": "învinge",
    "învins": "învinge",
    "învinse": "învinge",
    "învinsei": "învinge",
    "învinseră": "învinge",
    "învinserăm": "învinge",
    "învinserăți": "învinge",
    "învinsese": "învinge",
    "învinsesem": "învinge",
    "învinseseră": "învinge",
    "învinseserăm": "învinge",
    "învinseserăți": "învinge",
    "învinseseși": "învinge",
    "învinseși": "învinge",
    "învinsu": "învinge",
    "neînvingând": "învinge",
    "neînvingându": "învinge",
    "neînvins": "învinge",
    "nemaiînvingând": "învinge",
    "nemaiînvingându": "învinge",
    "învinovățea": "învinovăți",
    "învinovățeai": "învinovăți",
    "învinovățeam": "învinovăți",
    "învinovățească": "învinovăți",
    "învinovățeați": "învinovăți",
    "învinovățeau": "învinovăți",
    "învinovățesc": "învinovăți",
    "învinovățește": "învinovăți",
    "învinovățești": "învinovăți",
    "învinovății": "învinovăți",
    "învinovățim": "învinovăți",
    "învinovățind": "învinovăți",
    "învinovățindu": "învinovăți",
    "învinovățiră": "învinovăți",
    "învinovățirăm": "învinovăți",
    "învinovățirăți": "învinovăți",
    "învinovățise": "învinovăți",
    "învinovățisem": "învinovăți",
    "învinovățiseră": "învinovăți",
    "învinovățiserăm": "învinovăți",
    "învinovățiserăți": "învinovăți",
    "învinovățiseși": "învinovăți",
    "învinovățiși": "învinovăți",
    "învinovățit": "învinovăți",
    "învinovățiți": "învinovăți",
    "învinovățitu": "învinovăți",
    "neînvinovățind": "învinovăți",
    "neînvinovățindu": "învinovăți",
    "nemaiînvinovățind": "învinovăți",
    "nemaiînvinovățindu": "învinovăți",
    "învinovățită": "învinovățit",
    "învinovățite": "învinovățit",
    "învinovățiți": "învinovățit",
    "învinsă": "învins",
    "învinse": "învins",
    "învinși": "învins",
    "învinșii": "învins",
    "învinșilor": "învins",
    "învinsul": "învins",
    "învinsului": "învins",
    "învinuia": "învinui",
    "învinuiai": "învinui",
    "învinuiam": "învinui",
    "învinuiască": "învinui",
    "învinuiați": "învinui",
    "învinuiau": "învinui",
    "învinuiesc": "învinui",
    "învinuiește": "învinui",
    "învinuiești": "învinui",
    "învinuii": "învinui",
    "învinuim": "învinui",
    "învinuind": "învinui",
    "învinuindu": "învinui",
    "învinuiră": "învinui",
    "învinuirăm": "învinui",
    "învinuirăți": "învinui",
    "învinuise": "învinui",
    "învinuisem": "învinui",
    "învinuiseră": "învinui",
    "învinuiserăm": "învinui",
    "învinuiserăți": "învinui",
    "învinuiseși": "învinui",
    "învinuiși": "învinui",
    "învinuit": "învinui",
    "învinuiți": "învinui",
    "învinuitu": "învinui",
    "neînvinuind": "învinui",
    "neînvinuindu": "învinui",
    "nemaiînvinuind": "învinui",
    "nemaiînvinuindu": "învinui",
    "învinuirea": "învinuire",
    "învinuireo": "învinuire",
    "învinuiri": "învinuire",
    "învinuirii": "învinuire",
    "învinuirile": "învinuire",
    "învinuirilor": "învinuire",
    "învinuită": "învinuit",
    "învinuite": "învinuit",
    "învinuiți": "învinuit",
    "învioră": "înviora",
    "înviorai": "înviora",
    "învioram": "înviora",
    "înviorăm": "înviora",
    "înviorând": "înviora",
    "înviorându": "înviora",
    "înviorară": "înviora",
    "înviorarăm": "înviora",
    "înviorarăți": "înviora",
    "înviorase": "înviora",
    "înviorasem": "înviora",
    "învioraseră": "înviora",
    "învioraserăm": "înviora",
    "învioraserăți": "înviora",
    "învioraseși": "înviora",
    "înviorași": "înviora",
    "înviorat": "înviora",
    "înviorați": "înviora",
    "învioratu": "înviora",
    "înviorau": "înviora",
    "înviorează": "înviora",
    "înviorez": "înviora",
    "învioreze": "înviora",
    "înviorezi": "înviora",
    "neînviorând": "înviora",
    "neînviorându": "înviora",
    "nemaiînviorând": "înviora",
    "nemaiînviorându": "înviora",
    "înviorată": "înviorat",
    "înviorate": "înviorat",
    "înviorați": "înviorat",
    "înviorătoare": "înviorător",
    "înviorătoarea": "înviorător",
    "înviorătoarei": "înviorător",
    "înviorătoarele": "înviorător",
    "înviorătoarelor": "înviorător",
    "înviorătoareo": "înviorător",
    "înviorători": "înviorător",
    "înviorătorii": "înviorător",
    "înviorătorilor": "înviorător",
    "înviorătorul": "înviorător",
    "înviorătorule": "înviorător",
    "înviorătorului": "înviorător",
    "invit": "invita",
    "invită": "invita",
    "invitai": "invita",
    "invitam": "invita",
    "invităm": "invita",
    "invitând": "invita",
    "invitându": "invita",
    "invitară": "invita",
    "invitarăm": "invita",
    "invitarăți": "invita",
    "invitase": "invita",
    "invitasem": "invita",
    "invitaseră": "invita",
    "invitaserăm": "invita",
    "invitaserăți": "invita",
    "invitaseși": "invita",
    "invitași": "invita",
    "invitat": "invita",
    "invitați": "invita",
    "invitatu": "invita",
    "invitau": "invita",
    "invite": "invita",
    "inviți": "invita",
    "neinvitând": "invita",
    "neinvitându": "invita",
    "nemaiinvitând": "invita",
    "nemaiinvitându": "invita",
    "invitată": "invitat",
    "invitate": "invitat",
    "invitați": "invitat",
    "invitații": "invitat",
    "invitaților": "invitat",
    "invitatul": "invitat",
    "invitatului": "invitat",
    "invitația": "invitație",
    "invitației": "invitație",
    "invitații": "invitație",
    "invitațiile": "invitație",
    "invitațiilor": "invitație",
    "invizibila": "invizibil",
    "invizibilă": "invizibil",
    "invizibile": "invizibil",
    "invizibilei": "invizibil",
    "invizibilele": "invizibil",
    "invizibilelor": "invizibil",
    "invizibili": "invizibil",
    "invizibilii": "invizibil",
    "invizibililor": "invizibil",
    "invizibilul": "invizibil",
    "invizibilului": "invizibil",
    "invizibilitatea": "invizibilitate",
    "invizibilități": "invizibilitate",
    "invizibilității": "invizibilitate",
    "invizibilitățile": "invizibilitate",
    "invizibilităților": "invizibilitate",
    "invoc": "invoca",
    "invocă": "invoca",
    "invocai": "invoca",
    "invocam": "invoca",
    "invocăm": "invoca",
    "invocând": "invoca",
    "invocându": "invoca",
    "invocară": "invoca",
    "invocarăm": "invoca",
    "invocarăți": "invoca",
    "invocase": "invoca",
    "invocasem": "invoca",
    "invocaseră": "invoca",
    "invocaserăm": "invoca",
    "invocaserăți": "invoca",
    "invocaseși": "invoca",
    "invocași": "invoca",
    "invocat": "invoca",
    "invocați": "invoca",
    "invocatu": "invoca",
    "invocau": "invoca",
    "invoce": "invoca",
    "invoci": "invoca",
    "invocarea": "invocare",
    "invocări": "invocare",
    "invocării": "invocare",
    "invocările": "invocare",
    "invocărilor": "invocare",
    "invocata": "invocat",
    "invocată": "invocat",
    "invocate": "invocat",
    "invocatei": "invocat",
    "invocatele": "invocat",
    "invocatelor": "invocat",
    "invocați": "invocat",
    "invocații": "invocat",
    "invocaților": "invocat",
    "invocato": "invocat",
    "invocatul": "invocat",
    "invocatule": "invocat",
    "invocatului": "invocat",
    "învoia": "învoi",
    "învoiai": "învoi",
    "învoiam": "învoi",
    "învoiască": "învoi",
    "învoiați": "învoi",
    "învoiau": "învoi",
    "învoiesc": "învoi",
    "învoiește": "învoi",
    "învoiești": "învoi",
    "învoii": "învoi",
    "învoim": "învoi",
    "învoind": "învoi",
    "învoindu": "învoi",
    "învoiră": "învoi",
    "învoirăm": "învoi",
    "învoirăți": "învoi",
    "învoise": "învoi",
    "învoisem": "învoi",
    "învoiseră": "învoi",
    "învoiserăm": "învoi",
    "învoiserăți": "învoi",
    "învoiseși": "învoi",
    "învoiși": "învoi",
    "învoit": "învoi",
    "învoiți": "învoi",
    "învoitu": "învoi",
    "neînvoind": "învoi",
    "neînvoindu": "învoi",
    "nemaiînvoind": "învoi",
    "nemaiînvoindu": "învoi",
    "învoiala": "învoială",
    "învoieli": "învoială",
    "învoielii": "învoială",
    "învoielile": "învoială",
    "învoielilor": "învoială",
    "învoirea": "învoire",
    "învoiri": "învoire",
    "învoirii": "învoire",
    "învoirile": "învoire",
    "învoirilor": "învoire",
    "învoită": "învoit",
    "învoite": "învoit",
    "învoiți": "învoit",
    "învolbură": "învolbura",
    "învolburai": "învolbura",
    "învolburam": "învolbura",
    "învolburăm": "învolbura",
    "învolburând": "învolbura",
    "învolburându": "învolbura",
    "învolburară": "învolbura",
    "învolburarăm": "învolbura",
    "învolburarăți": "învolbura",
    "învolburase": "învolbura",
    "învolburasem": "învolbura",
    "învolburaseră": "învolbura",
    "învolburaserăm": "învolbura",
    "învolburaserăți": "învolbura",
    "învolburaseși": "învolbura",
    "învolburași": "învolbura",
    "învolburat": "învolbura",
    "învolburați": "învolbura",
    "învolburatu": "învolbura",
    "învolburau": "învolbura",
    "învolburează": "învolbura",
    "învolburez": "învolbura",
    "învolbureze": "învolbura",
    "învolburezi": "învolbura",
    "neînvolburând": "învolbura",
    "neînvolburându": "învolbura",
    "nemaiînvolburând": "învolbura",
    "nemaiînvolburându": "învolbura",
    "învolburata": "învolburat",
    "învolburată": "învolburat",
    "învolburate": "învolburat",
    "învolburatei": "învolburat",
    "învolburatele": "învolburat",
    "învolburatelor": "învolburat",
    "învolburați": "învolburat",
    "învolburații": "învolburat",
    "învolburaților": "învolburat",
    "învolburatul": "învolburat",
    "învolburatului": "învolburat",
    "involuntara": "involuntar",
    "involuntară": "involuntar",
    "involuntare": "involuntar",
    "involuntarei": "involuntar",
    "involuntarele": "involuntar",
    "involuntarelor": "involuntar",
    "involuntari": "involuntar",
    "involuntarii": "involuntar",
    "involuntarilor": "involuntar",
    "involuntarul": "involuntar",
    "involuntarului": "involuntar",
    "învrăjbea": "învrăjbi",
    "învrăjbeai": "învrăjbi",
    "învrăjbeam": "învrăjbi",
    "învrăjbească": "învrăjbi",
    "învrăjbeați": "învrăjbi",
    "învrăjbeau": "învrăjbi",
    "învrăjbesc": "învrăjbi",
    "învrăjbește": "învrăjbi",
    "învrăjbești": "învrăjbi",
    "învrăjbii": "învrăjbi",
    "învrăjbim": "învrăjbi",
    "învrăjbind": "învrăjbi",
    "învrăjbindu": "învrăjbi",
    "învrăjbiră": "învrăjbi",
    "învrăjbirăm": "învrăjbi",
    "învrăjbirăți": "învrăjbi",
    "învrăjbise": "învrăjbi",
    "învrăjbisem": "învrăjbi",
    "învrăjbiseră": "învrăjbi",
    "învrăjbiserăm": "învrăjbi",
    "învrăjbiserăți": "învrăjbi",
    "învrăjbiseși": "învrăjbi",
    "învrăjbiși": "învrăjbi",
    "învrăjbit": "învrăjbi",
    "învrăjbiți": "învrăjbi",
    "învrăjbitu": "învrăjbi",
    "neînvrăjbind": "învrăjbi",
    "neînvrăjbindu": "învrăjbi",
    "nemaiînvrăjbind": "învrăjbi",
    "nemaiînvrăjbindu": "învrăjbi",
    "învrăjbirea": "învrăjbire",
    "învrăjbiri": "învrăjbire",
    "învrăjbirii": "învrăjbire",
    "învrăjbirile": "învrăjbire",
    "învrăjbirilor": "învrăjbire",
    "învrăjbită": "învrăjbit",
    "învrăjbite": "învrăjbit",
    "învrăjbiți": "învrăjbit",
    "învrăjmășea": "învrăjmăși",
    "învrăjmășeai": "învrăjmăși",
    "învrăjmășeam": "învrăjmăși",
    "învrăjmășească": "învrăjmăși",
    "învrăjmășeați": "învrăjmăși",
    "învrăjmășeau": "învrăjmăși",
    "învrăjmășesc": "învrăjmăși",
    "învrăjmășește": "învrăjmăși",
    "învrăjmășești": "învrăjmăși",
    "învrăjmășii": "învrăjmăși",
    "învrăjmășim": "învrăjmăși",
    "învrăjmășind": "învrăjmăși",
    "învrăjmășindu": "învrăjmăși",
    "învrăjmășiră": "învrăjmăși",
    "învrăjmășirăm": "învrăjmăși",
    "învrăjmășirăți": "învrăjmăși",
    "învrăjmășise": "învrăjmăși",
    "învrăjmășisem": "învrăjmăși",
    "învrăjmășiseră": "învrăjmăși",
    "învrăjmășiserăm": "învrăjmăși",
    "învrăjmășiserăți": "învrăjmăși",
    "învrăjmășiseși": "învrăjmăși",
    "învrăjmășiși": "învrăjmăși",
    "învrăjmășit": "învrăjmăși",
    "învrăjmășiți": "învrăjmăși",
    "învrăjmășitu": "învrăjmăși",
    "neînvrăjmășind": "învrăjmăși",
    "neînvrăjmășindu": "învrăjmăși",
    "nemaiînvrăjmășind": "învrăjmăși",
    "nemaiînvrăjmășindu": "învrăjmăși",
    "învrăjmășită": "învrăjmășit",
    "învrăjmășite": "învrăjmășit",
    "învrăjmășiți": "învrăjmășit",
    "învrednicea": "învrednici",
    "învredniceai": "învrednici",
    "învredniceam": "învrednici",
    "învrednicească": "învrednici",
    "învredniceați": "învrednici",
    "învredniceau": "învrednici",
    "învrednicesc": "învrednici",
    "învrednicește": "învrednici",
    "învrednicești": "învrednici",
    "învrednicii": "învrednici",
    "învrednicim": "învrednici",
    "învrednicind": "învrednici",
    "învrednicindu": "învrednici",
    "învredniciră": "învrednici",
    "învrednicirăm": "învrednici",
    "învrednicirăți": "învrednici",
    "învrednicise": "învrednici",
    "învrednicisem": "învrednici",
    "învredniciseră": "învrednici",
    "învredniciserăm": "învrednici",
    "învredniciserăți": "învrednici",
    "învredniciseși": "învrednici",
    "învredniciși": "învrednici",
    "învrednicit": "învrednici",
    "învredniciți": "învrednici",
    "învrednicitu": "învrednici",
    "neînvrednicind": "învrednici",
    "neînvrednicindu": "învrednici",
    "nemaiînvrednicind": "învrednici",
    "nemaiînvrednicindu": "învrednici",
    "învrednicită": "învrednicit",
    "învrednicite": "învrednicit",
    "învredniciți": "învrednicit",
    "invulnerabila": "invulnerabil",
    "invulnerabilă": "invulnerabil",
    "invulnerabile": "invulnerabil",
    "invulnerabilei": "invulnerabil",
    "invulnerabilele": "invulnerabil",
    "invulnerabilelor": "invulnerabil",
    "invulnerabili": "invulnerabil",
    "invulnerabilii": "invulnerabil",
    "invulnerabililor": "invulnerabil",
    "invulnerabilul": "invulnerabil",
    "invulnerabilului": "invulnerabil",
    "invulnerabilitatea": "invulnerabilitate",
    "invulnerabilități": "invulnerabilitate",
    "invulnerabilității": "invulnerabilitate",
    "înzăpezea": "înzăpezi",
    "înzăpezeai": "înzăpezi",
    "înzăpezeam": "înzăpezi",
    "înzăpezească": "înzăpezi",
    "înzăpezeați": "înzăpezi",
    "înzăpezeau": "înzăpezi",
    "înzăpezesc": "înzăpezi",
    "înzăpezește": "înzăpezi",
    "înzăpezești": "înzăpezi",
    "înzăpezii": "înzăpezi",
    "înzăpezim": "înzăpezi",
    "înzăpezind": "înzăpezi",
    "înzăpezindu": "înzăpezi",
    "înzăpeziră": "înzăpezi",
    "înzăpezirăm": "înzăpezi",
    "înzăpezirăți": "înzăpezi",
    "înzăpezise": "înzăpezi",
    "înzăpezisem": "înzăpezi",
    "înzăpeziseră": "înzăpezi",
    "înzăpeziserăm": "înzăpezi",
    "înzăpeziserăți": "înzăpezi",
    "înzăpeziseși": "înzăpezi",
    "înzăpeziși": "înzăpezi",
    "înzăpezit": "înzăpezi",
    "înzăpeziți": "înzăpezi",
    "înzăpezitu": "înzăpezi",
    "neînzăpezind": "înzăpezi",
    "neînzăpezindu": "înzăpezi",
    "nemaiînzăpezind": "înzăpezi",
    "nemaiînzăpezindu": "înzăpezi",
    "înzăpezita": "înzăpezit",
    "înzăpezită": "înzăpezit",
    "înzăpezite": "înzăpezit",
    "înzăpezitei": "înzăpezit",
    "înzăpezitele": "înzăpezit",
    "înzăpezitelor": "înzăpezit",
    "înzăpeziți": "înzăpezit",
    "înzăpeziții": "înzăpezit",
    "înzăpeziților": "înzăpezit",
    "înzăpezitul": "înzăpezit",
    "înzăpezitului": "înzăpezit",
    "înzdrăvenea": "înzdrăveni",
    "înzdrăveneai": "înzdrăveni",
    "înzdrăveneam": "înzdrăveni",
    "înzdrăvenească": "înzdrăveni",
    "înzdrăveneați": "înzdrăveni",
    "înzdrăveneau": "înzdrăveni",
    "înzdrăvenesc": "înzdrăveni",
    "înzdrăvenește": "înzdrăveni",
    "înzdrăvenești": "înzdrăveni",
    "înzdrăvenii": "înzdrăveni",
    "înzdrăvenim": "înzdrăveni",
    "înzdrăvenind": "înzdrăveni",
    "înzdrăvenindu": "înzdrăveni",
    "înzdrăveniră": "înzdrăveni",
    "înzdrăvenirăm": "înzdrăveni",
    "înzdrăvenirăți": "înzdrăveni",
    "înzdrăvenise": "înzdrăveni",
    "înzdrăvenisem": "înzdrăveni",
    "înzdrăveniseră": "înzdrăveni",
    "înzdrăveniserăm": "înzdrăveni",
    "înzdrăveniserăți": "înzdrăveni",
    "înzdrăveniseși": "înzdrăveni",
    "înzdrăveniși": "înzdrăveni",
    "înzdrăvenit": "înzdrăveni",
    "înzdrăveniți": "înzdrăveni",
    "înzdrăvenitu": "înzdrăveni",
    "neînzdrăvenind": "înzdrăveni",
    "neînzdrăvenindu": "înzdrăveni",
    "nemaiînzdrăvenind": "înzdrăveni",
    "nemaiînzdrăvenindu": "înzdrăveni",
    "înzdrăvenirea": "înzdrăvenire",
    "înzdrăveniri": "înzdrăvenire",
    "înzdrăvenirii": "înzdrăvenire",
    "înzdrăvenirile": "înzdrăvenire",
    "înzdrăvenirilor": "înzdrăvenire",
    "înzdrăvenită": "înzdrăvenit",
    "înzdrăvenite": "înzdrăvenit",
    "înzdrăveniți": "înzdrăvenit",
    "înzecea": "înzeci",
    "înzeceai": "înzeci",
    "înzeceam": "înzeci",
    "înzecească": "înzeci",
    "înzeceați": "înzeci",
    "înzeceau": "înzeci",
    "înzecesc": "înzeci",
    "înzecește": "înzeci",
    "înzecești": "înzeci",
    "înzecii": "înzeci",
    "înzecim": "înzeci",
    "înzecind": "înzeci",
    "înzecindu": "înzeci",
    "înzeciră": "înzeci",
    "înzecirăm": "înzeci",
    "înzecirăți": "înzeci",
    "înzecise": "înzeci",
    "înzecisem": "înzeci",
    "înzeciseră": "înzeci",
    "înzeciserăm": "înzeci",
    "înzeciserăți": "înzeci",
    "înzeciseși": "înzeci",
    "înzeciși": "înzeci",
    "înzecit": "înzeci",
    "înzeciți": "înzeci",
    "înzecitu": "înzeci",
    "neînzecind": "înzeci",
    "neînzecindu": "înzeci",
    "nemaiînzecind": "înzeci",
    "nemaiînzecindu": "înzeci",
    "înzecita": "înzecit",
    "înzecită": "înzecit",
    "înzecite": "înzecit",
    "înzecitei": "înzecit",
    "înzecitele": "înzecit",
    "înzecitelor": "înzecit",
    "înzeciți": "înzecit",
    "înzeciții": "înzecit",
    "înzeciților": "înzecit",
    "înzecitul": "înzecit",
    "înzecitului": "înzecit",
    "înzestră": "înzestra",
    "înzestrai": "înzestra",
    "înzestram": "înzestra",
    "înzestrăm": "înzestra",
    "înzestrând": "înzestra",
    "înzestrându": "înzestra",
    "înzestrară": "înzestra",
    "înzestrarăm": "înzestra",
    "înzestrarăți": "înzestra",
    "înzestrase": "înzestra",
    "înzestrasem": "înzestra",
    "înzestraseră": "înzestra",
    "înzestraserăm": "înzestra",
    "înzestraserăți": "înzestra",
    "înzestraseși": "înzestra",
    "înzestrași": "înzestra",
    "înzestrat": "înzestra",
    "înzestrați": "înzestra",
    "înzestratu": "înzestra",
    "înzestrau": "înzestra",
    "înzestrează": "înzestra",
    "înzestrez": "înzestra",
    "înzestreze": "înzestra",
    "înzestrezi": "înzestra",
    "neînzestrând": "înzestra",
    "neînzestrându": "înzestra",
    "nemaiînzestrând": "înzestra",
    "nemaiînzestrându": "înzestra",
    "înzestrarea": "înzestrare",
    "înzestrareo": "înzestrare",
    "înzestrări": "înzestrare",
    "înzestrării": "înzestrare",
    "înzestrările": "înzestrare",
    "înzestrărilor": "înzestrare",
    "înzestrata": "înzestrat",
    "înzestrată": "înzestrat",
    "înzestrate": "înzestrat",
    "înzestratei": "înzestrat",
    "înzestratele": "înzestrat",
    "înzestratelor": "înzestrat",
    "înzestrați": "înzestrat",
    "înzestrații": "înzestrat",
    "înzestraților": "înzestrat",
    "înzestratul": "înzestrat",
    "înzestratului": "înzestrat",
    "înzidea": "înzidi",
    "înzideai": "înzidi",
    "înzideam": "înzidi",
    "înzidească": "înzidi",
    "înzideați": "înzidi",
    "înzideau": "înzidi",
    "înzidesc": "înzidi",
    "înzidește": "înzidi",
    "înzidești": "înzidi",
    "înzidii": "înzidi",
    "înzidim": "înzidi",
    "înzidind": "înzidi",
    "înzidindu": "înzidi",
    "înzidiră": "înzidi",
    "înzidirăm": "înzidi",
    "înzidirăți": "înzidi",
    "înzidise": "înzidi",
    "înzidisem": "înzidi",
    "înzidiseră": "înzidi",
    "înzidiserăm": "înzidi",
    "înzidiserăți": "înzidi",
    "înzidiseși": "înzidi",
    "înzidiși": "înzidi",
    "înzidit": "înzidi",
    "înzidiți": "înzidi",
    "înziditu": "înzidi",
    "neînzidind": "înzidi",
    "neînzidindu": "înzidi",
    "nemaiînzidind": "înzidi",
    "nemaiînzidindu": "înzidi",
    "înzidită": "înzidit",
    "înzidite": "înzidit",
    "înzidiți": "înzidit",
    "înzorzonă": "înzorzona",
    "înzorzonai": "înzorzona",
    "înzorzonam": "înzorzona",
    "înzorzonăm": "înzorzona",
    "înzorzonând": "înzorzona",
    "înzorzonându": "înzorzona",
    "înzorzonară": "înzorzona",
    "înzorzonarăm": "înzorzona",
    "înzorzonarăți": "înzorzona",
    "înzorzonase": "înzorzona",
    "înzorzonasem": "înzorzona",
    "înzorzonaseră": "înzorzona",
    "înzorzonaserăm": "înzorzona",
    "înzorzonaserăți": "înzorzona",
    "înzorzonaseși": "înzorzona",
    "înzorzonași": "înzorzona",
    "înzorzonat": "înzorzona",
    "înzorzonați": "înzorzona",
    "înzorzonatu": "înzorzona",
    "înzorzonau": "înzorzona",
    "înzorzonează": "înzorzona",
    "înzorzonez": "înzorzona",
    "înzorzoneze": "înzorzona",
    "înzorzonezi": "înzorzona",
    "neînzorzonând": "înzorzona",
    "neînzorzonându": "înzorzona",
    "nemaiînzorzonând": "înzorzona",
    "nemaiînzorzonându": "înzorzona",
    "înzorzonata": "înzorzonat",
    "înzorzonată": "înzorzonat",
    "înzorzonate": "înzorzonat",
    "înzorzonatei": "înzorzonat",
    "înzorzonatele": "înzorzonat",
    "înzorzonatelor": "înzorzonat",
    "înzorzonați": "înzorzonat",
    "înzorzonații": "înzorzonat",
    "înzorzonaților": "înzorzonat",
    "înzorzonatul": "înzorzonat",
    "înzorzonatului": "înzorzonat",
    "Ioane": "Ioan",
    "Ioanei": "Ioana",
    "iobagi": "iobag",
    "iobagii": "iobag",
    "iobagilor": "iobag",
    "iobagul": "iobag",
    "iobagului": "iobag",
    "iobăgea": "iobăgi",
    "iobăgeai": "iobăgi",
    "iobăgeam": "iobăgi",
    "iobăgească": "iobăgi",
    "iobăgeați": "iobăgi",
    "iobăgeau": "iobăgi",
    "iobăgesc": "iobăgi",
    "iobăgește": "iobăgi",
    "iobăgești": "iobăgi",
    "iobăgii": "iobăgi",
    "iobăgim": "iobăgi",
    "iobăgind": "iobăgi",
    "iobăgindu": "iobăgi",
    "iobăgiră": "iobăgi",
    "iobăgirăm": "iobăgi",
    "iobăgirăți": "iobăgi",
    "iobăgise": "iobăgi",
    "iobăgisem": "iobăgi",
    "iobăgiseră": "iobăgi",
    "iobăgiserăm": "iobăgi",
    "iobăgiserăți": "iobăgi",
    "iobăgiseși": "iobăgi",
    "iobăgiși": "iobăgi",
    "iobăgit": "iobăgi",
    "iobăgiți": "iobăgi",
    "iobăgitu": "iobăgi",
    "neiobăgind": "iobăgi",
    "neiobăgindu": "iobăgi",
    "nemaiiobăgind": "iobăgi",
    "nemaiiobăgindu": "iobăgi",
    "iobăgia": "iobăgie",
    "iobăgită": "iobăgit",
    "iobăgite": "iobăgit",
    "iobăgiți": "iobăgit",
    "iodul": "iod",
    "iodului": "iod",
    "iodura": "iodură",
    "ioduri": "iodură",
    "iodurii": "iodură",
    "iodurile": "iodură",
    "iodurilor": "iodură",
    "iola": "iolă",
    "iole": "iolă",
    "iolei": "iolă",
    "iolele": "iolă",
    "iolelor": "iolă",
    "I.": "Ion",
    "Ioane": "Ion",
    "ioni": "ion",
    "ionii": "ion",
    "ionilor": "ion",
    "ionul": "ion",
    "ionului": "ion",
    "I.D.": "Ion_Dumitru",
    "I.L.": "Ion_Luca",
    "Ionelei": "Ionela",
    "ioniză": "ioniza",
    "ionizai": "ioniza",
    "ionizam": "ioniza",
    "ionizăm": "ioniza",
    "ionizând": "ioniza",
    "ionizându": "ioniza",
    "ionizară": "ioniza",
    "ionizarăm": "ioniza",
    "ionizarăți": "ioniza",
    "ionizase": "ioniza",
    "ionizasem": "ioniza",
    "ionizaseră": "ioniza",
    "ionizaserăm": "ioniza",
    "ionizaserăți": "ioniza",
    "ionizaseși": "ioniza",
    "ionizași": "ioniza",
    "ionizat": "ioniza",
    "ionizați": "ioniza",
    "ionizatu": "ioniza",
    "ionizau": "ioniza",
    "ionizează": "ioniza",
    "ionizez": "ioniza",
    "ionizeze": "ioniza",
    "ionizezi": "ioniza",
    "neionizând": "ioniza",
    "neionizându": "ioniza",
    "nemaiionizând": "ioniza",
    "nemaiionizându": "ioniza",
    "ionizarea": "ionizare",
    "ionizări": "ionizare",
    "ionizării": "ionizare",
    "ionizările": "ionizare",
    "ionizărilor": "ionizare",
    "ionizată": "ionizat",
    "ionizate": "ionizat",
    "ionizați": "ionizat",
    "Iordaniei": "Iordania",
    "iordaniana": "iordanian",
    "iordaniană": "iordanian",
    "iordanianul": "iordanian",
    "iordanianului": "iordanian",
    "iordaniene": "iordanian",
    "iordanienei": "iordanian",
    "iordanienele": "iordanian",
    "iordanienelor": "iordanian",
    "iordanieni": "iordanian",
    "iordanienii": "iordanian",
    "iordanienilor": "iordanian",
    "iota": "iotă",
    "iote": "iotă",
    "iotei": "iotă",
    "iotele": "iotă",
    "iotelor": "iotă",
    "iotaciză": "iotaciza",
    "iotacizai": "iotaciza",
    "iotacizam": "iotaciza",
    "iotacizăm": "iotaciza",
    "iotacizând": "iotaciza",
    "iotacizându": "iotaciza",
    "iotacizară": "iotaciza",
    "iotacizarăm": "iotaciza",
    "iotacizarăți": "iotaciza",
    "iotacizase": "iotaciza",
    "iotacizasem": "iotaciza",
    "iotacizaseră": "iotaciza",
    "iotacizaserăm": "iotaciza",
    "iotacizaserăți": "iotaciza",
    "iotacizaseși": "iotaciza",
    "iotacizași": "iotaciza",
    "iotacizat": "iotaciza",
    "iotacizați": "iotaciza",
    "iotacizatu": "iotaciza",
    "iotacizau": "iotaciza",
    "iotacizează": "iotaciza",
    "iotacizez": "iotaciza",
    "iotacizeze": "iotaciza",
    "iotacizezi": "iotaciza",
    "neiotacizând": "iotaciza",
    "neiotacizându": "iotaciza",
    "nemaiiotacizând": "iotaciza",
    "nemaiiotacizându": "iotaciza",
    "iotacizată": "iotacizat",
    "iotacizate": "iotacizat",
    "iotacizați": "iotacizat",
    "ipocrita": "ipocrit",
    "ipocrită": "ipocrit",
    "ipocrite": "ipocrit",
    "ipocritei": "ipocrit",
    "ipocritele": "ipocrit",
    "ipocritelor": "ipocrit",
    "ipocriți": "ipocrit",
    "ipocriții": "ipocrit",
    "ipocriților": "ipocrit",
    "ipocritul": "ipocrit",
    "ipocritului": "ipocrit",
    "ipocrizia": "ipocrizie",
    "ipocriziei": "ipocrizie",
    "ipocrizii": "ipocrizie",
    "ipocriziile": "ipocrizie",
    "ipocriziilor": "ipocrizie",
    "ipohondra": "ipohondru",
    "ipohondră": "ipohondru",
    "ipohondre": "ipohondru",
    "ipohondrei": "ipohondru",
    "ipohondrele": "ipohondru",
    "ipohondrelor": "ipohondru",
    "ipohondri": "ipohondru",
    "ipohondrii": "ipohondru",
    "ipohondrilor": "ipohondru",
    "ipohondrul": "ipohondru",
    "ipohondrului": "ipohondru",
    "ipostaza": "ipostază",
    "ipostaze": "ipostază",
    "ipostazei": "ipostază",
    "ipostazele": "ipostază",
    "ipostazelor": "ipostază",
    "ipotecă": "ipoteca",
    "ipotecai": "ipoteca",
    "ipotecam": "ipoteca",
    "ipotecăm": "ipoteca",
    "ipotecând": "ipoteca",
    "ipotecându": "ipoteca",
    "ipotecară": "ipoteca",
    "ipotecarăm": "ipoteca",
    "ipotecarăți": "ipoteca",
    "ipotecase": "ipoteca",
    "ipotecasem": "ipoteca",
    "ipotecaseră": "ipoteca",
    "ipotecaserăm": "ipoteca",
    "ipotecaserăți": "ipoteca",
    "ipotecaseși": "ipoteca",
    "ipotecași": "ipoteca",
    "ipotecat": "ipoteca",
    "ipotecați": "ipoteca",
    "ipotecatu": "ipoteca",
    "ipotecau": "ipoteca",
    "ipotechează": "ipoteca",
    "ipotechez": "ipoteca",
    "ipotecheze": "ipoteca",
    "ipotechezi": "ipoteca",
    "neipotecând": "ipoteca",
    "neipotecându": "ipoteca",
    "nemaiipotecând": "ipoteca",
    "nemaiipotecându": "ipoteca",
    "ipoteca": "ipotecă",
    "ipoteci": "ipotecă",
    "ipotecii": "ipotecă",
    "ipotecile": "ipotecă",
    "ipotecilor": "ipotecă",
    "ipotecată": "ipotecat",
    "ipotecate": "ipotecat",
    "ipotecați": "ipotecat",
    "ipotenuza": "ipotenuză",
    "ipotenuze": "ipotenuză",
    "ipotenuzei": "ipotenuză",
    "ipotenuzele": "ipotenuză",
    "ipotenuzelor": "ipotenuză",
    "ipotetica": "ipotetic",
    "ipotetică": "ipotetic",
    "ipotetice": "ipotetic",
    "ipoteticei": "ipotetic",
    "ipoteticele": "ipotetic",
    "ipoteticelor": "ipotetic",
    "ipotetici": "ipotetic",
    "ipoteticii": "ipotetic",
    "ipoteticilor": "ipotetic",
    "ipoteticul": "ipotetic",
    "ipoteticului": "ipotetic",
    "ipoteza": "ipoteză",
    "ipoteze": "ipoteză",
    "ipotezei": "ipoteză",
    "ipotezele": "ipoteză",
    "ipotezelor": "ipoteză",
    "ipsosul": "ipsos",
    "ipsosului": "ipsos",
    "iradiai": "iradia",
    "iradiam": "iradia",
    "iradiară": "iradia",
    "iradiarăm": "iradia",
    "iradiarăți": "iradia",
    "iradiase": "iradia",
    "iradiasem": "iradia",
    "iradiaseră": "iradia",
    "iradiaserăm": "iradia",
    "iradiaserăți": "iradia",
    "iradiaseși": "iradia",
    "iradiași": "iradia",
    "iradiat": "iradia",
    "iradiați": "iradia",
    "iradiatu": "iradia",
    "iradiau": "iradia",
    "iradiază": "iradia",
    "iradie": "iradia",
    "iradiem": "iradia",
    "iradiez": "iradia",
    "iradieze": "iradia",
    "iradiezi": "iradia",
    "iradiind": "iradia",
    "iradiindu": "iradia",
    "neiradiind": "iradia",
    "neiradiindu": "iradia",
    "nemaiiradiind": "iradia",
    "nemaiiradiindu": "iradia",
    "iradiată": "iradiat",
    "iradiate": "iradiat",
    "iradiați": "iradiat",
    "iradiația": "iradiație",
    "iradiației": "iradiație",
    "iradiații": "iradiație",
    "iradiațiile": "iradiație",
    "iradiațiilor": "iradiație",
    "iradierea": "iradiere",
    "iradieri": "iradiere",
    "iradierii": "iradiere",
    "iradierile": "iradiere",
    "iradierilor": "iradiere",
    "Irakul": "Irak",
    "Irakului": "Irak",
    "iraniana": "iranian",
    "iraniană": "iranian",
    "iraniano": "iranian",
    "iranianul": "iranian",
    "iranianule": "iranian",
    "iranianului": "iranian",
    "iraniene": "iranian",
    "iranienei": "iranian",
    "iranienele": "iranian",
    "iranienelor": "iranian",
    "iranieni": "iranian",
    "iranienii": "iranian",
    "iranienilor": "iranian",
    "irascibila": "irascibil",
    "irascibilă": "irascibil",
    "irascibile": "irascibil",
    "irascibilei": "irascibil",
    "irascibilele": "irascibil",
    "irascibilelor": "irascibil",
    "irascibili": "irascibil",
    "irascibilii": "irascibil",
    "irascibililor": "irascibil",
    "irascibilul": "irascibil",
    "irascibilului": "irascibil",
    "iraționala": "irațional",
    "irațională": "irațional",
    "iraționale": "irațional",
    "iraționalei": "irațional",
    "iraționalele": "irațional",
    "iraționalelor": "irațional",
    "iraționali": "irațional",
    "iraționalii": "irațional",
    "iraționalilor": "irațional",
    "iraționalul": "irațional",
    "iraționalului": "irațional",
    "iraționalismul": "iraționalism",
    "iraționalismului": "iraționalism",
    "ireala": "ireal",
    "ireală": "ireal",
    "ireale": "ireal",
    "irealei": "ireal",
    "irealele": "ireal",
    "irealelor": "ireal",
    "ireali": "ireal",
    "irealii": "ireal",
    "irealilor": "ireal",
    "irealul": "ireal",
    "irealului": "ireal",
    "irealizabila": "irealizabil",
    "irealizabilă": "irealizabil",
    "irealizabile": "irealizabil",
    "irealizabilei": "irealizabil",
    "irealizabilele": "irealizabil",
    "irealizabilelor": "irealizabil",
    "irealizabili": "irealizabil",
    "irealizabilii": "irealizabil",
    "irealizabililor": "irealizabil",
    "irealizabilul": "irealizabil",
    "irealizabilului": "irealizabil",
    "ireconciliabila": "ireconciliabil",
    "ireconciliabilă": "ireconciliabil",
    "ireconciliabile": "ireconciliabil",
    "ireconciliabilei": "ireconciliabil",
    "ireconciliabilele": "ireconciliabil",
    "ireconciliabilelor": "ireconciliabil",
    "ireconciliabili": "ireconciliabil",
    "ireconciliabilii": "ireconciliabil",
    "ireconciliabililor": "ireconciliabil",
    "ireconciliabilul": "ireconciliabil",
    "ireconciliabilului": "ireconciliabil",
    "irecuperabila": "irecuperabil",
    "irecuperabilă": "irecuperabil",
    "irecuperabile": "irecuperabil",
    "irecuperabilei": "irecuperabil",
    "irecuperabilele": "irecuperabil",
    "irecuperabilelor": "irecuperabil",
    "irecuperabili": "irecuperabil",
    "irecuperabilii": "irecuperabil",
    "irecuperabililor": "irecuperabil",
    "irecuperabilul": "irecuperabil",
    "irecuperabilului": "irecuperabil",
    "ireductibila": "ireductibil",
    "ireductibilă": "ireductibil",
    "ireductibile": "ireductibil",
    "ireductibilei": "ireductibil",
    "ireductibilele": "ireductibil",
    "ireductibilelor": "ireductibil",
    "ireductibili": "ireductibil",
    "ireductibilii": "ireductibil",
    "ireductibililor": "ireductibil",
    "ireductibilul": "ireductibil",
    "ireductibilului": "ireductibil",
    "irefutabila": "irefutabil",
    "irefutabilă": "irefutabil",
    "irefutabile": "irefutabil",
    "irefutabilei": "irefutabil",
    "irefutabilele": "irefutabil",
    "irefutabilelor": "irefutabil",
    "irefutabili": "irefutabil",
    "irefutabilii": "irefutabil",
    "irefutabililor": "irefutabil",
    "irefutabilul": "irefutabil",
    "irefutabilului": "irefutabil",
    "iregularitatea": "iregularitate",
    "iregularități": "iregularitate",
    "iregularității": "iregularitate",
    "iregularitățile": "iregularitate",
    "iregularităților": "iregularitate",
    "iremediabila": "iremediabil",
    "iremediabilă": "iremediabil",
    "iremediabile": "iremediabil",
    "iremediabilei": "iremediabil",
    "iremediabilele": "iremediabil",
    "iremediabilelor": "iremediabil",
    "iremediabili": "iremediabil",
    "iremediabilii": "iremediabil",
    "iremediabililor": "iremediabil",
    "iremediabilul": "iremediabil",
    "iremediabilului": "iremediabil",
    "ireparabila": "ireparabil",
    "ireparabilă": "ireparabil",
    "ireparabile": "ireparabil",
    "ireparabilei": "ireparabil",
    "ireparabilele": "ireparabil",
    "ireparabilelor": "ireparabil",
    "ireparabili": "ireparabil",
    "ireparabilii": "ireparabil",
    "ireparabililor": "ireparabil",
    "ireparabilo": "ireparabil",
    "ireparabilul": "ireparabil",
    "ireparabilule": "ireparabil",
    "ireparabilului": "ireparabil",
    "irepetabila": "irepetabil",
    "irepetabilă": "irepetabil",
    "irepetabile": "irepetabil",
    "irepetabilei": "irepetabil",
    "irepetabilele": "irepetabil",
    "irepetabilelor": "irepetabil",
    "irepetabili": "irepetabil",
    "irepetabilii": "irepetabil",
    "irepetabililor": "irepetabil",
    "irepetabilo": "irepetabil",
    "irepetabilul": "irepetabil",
    "irepetabilule": "irepetabil",
    "irepetabilului": "irepetabil",
    "ireproșabila": "ireproșabil",
    "ireproșabilă": "ireproșabil",
    "ireproșabile": "ireproșabil",
    "ireproșabilei": "ireproșabil",
    "ireproșabilele": "ireproșabil",
    "ireproșabilelor": "ireproșabil",
    "ireproșabili": "ireproșabil",
    "ireproșabilii": "ireproșabil",
    "ireproșabililor": "ireproșabil",
    "ireproșabilul": "ireproșabil",
    "ireproșabilului": "ireproșabil",
    "irespirabila": "irespirabil",
    "irespirabilă": "irespirabil",
    "irespirabile": "irespirabil",
    "irespirabilei": "irespirabil",
    "irespirabilele": "irespirabil",
    "irespirabilelor": "irespirabil",
    "irespirabili": "irespirabil",
    "irespirabilii": "irespirabil",
    "irespirabililor": "irespirabil",
    "irespirabilo": "irespirabil",
    "irespirabilul": "irespirabil",
    "irespirabilule": "irespirabil",
    "irespirabilului": "irespirabil",
    "iresponsabila": "iresponsabil",
    "iresponsabilă": "iresponsabil",
    "iresponsabile": "iresponsabil",
    "iresponsabilei": "iresponsabil",
    "iresponsabilele": "iresponsabil",
    "iresponsabilelor": "iresponsabil",
    "iresponsabili": "iresponsabil",
    "iresponsabilii": "iresponsabil",
    "iresponsabililor": "iresponsabil",
    "iresponsabilul": "iresponsabil",
    "iresponsabilului": "iresponsabil",
    "iresponsabilitatea": "iresponsabilitate",
    "iresponsabilități": "iresponsabilitate",
    "iresponsabilității": "iresponsabilitate",
    "iresponsabilitățile": "iresponsabilitate",
    "iresponsabilităților": "iresponsabilitate",
    "ireverențioasa": "ireverențios",
    "ireverențioasă": "ireverențios",
    "ireverențioase": "ireverențios",
    "ireverențioasei": "ireverențios",
    "ireverențioasele": "ireverențios",
    "ireverențioaselor": "ireverențios",
    "ireverențioși": "ireverențios",
    "ireverențioșii": "ireverențios",
    "ireverențioșilor": "ireverențios",
    "ireverențiosul": "ireverențios",
    "ireverențiosului": "ireverențios",
    "ireversibila": "ireversibil",
    "ireversibilă": "ireversibil",
    "ireversibile": "ireversibil",
    "ireversibilei": "ireversibil",
    "ireversibilele": "ireversibil",
    "ireversibilelor": "ireversibil",
    "ireversibili": "ireversibil",
    "ireversibilii": "ireversibil",
    "ireversibililor": "ireversibil",
    "ireversibilul": "ireversibil",
    "ireversibilului": "ireversibil",
    "ireversibilitatea": "ireversibilitate",
    "ireversibilități": "ireversibilitate",
    "ireversibilității": "ireversibilitate",
    "irevocabila": "irevocabil",
    "irevocabilă": "irevocabil",
    "irevocabile": "irevocabil",
    "irevocabilei": "irevocabil",
    "irevocabilele": "irevocabil",
    "irevocabilelor": "irevocabil",
    "irevocabili": "irevocabil",
    "irevocabilii": "irevocabil",
    "irevocabililor": "irevocabil",
    "irevocabilul": "irevocabil",
    "irevocabilului": "irevocabil",
    "irezistibila": "irezistibil",
    "irezistibilă": "irezistibil",
    "irezistibile": "irezistibil",
    "irezistibilei": "irezistibil",
    "irezistibilele": "irezistibil",
    "irezistibilelor": "irezistibil",
    "irezistibili": "irezistibil",
    "irezistibilii": "irezistibil",
    "irezistibililor": "irezistibil",
    "irezistibilul": "irezistibil",
    "irezistibilului": "irezistibil",
    "Ir": "iridiu",
    "iridiul": "iridiu",
    "iridiului": "iridiu",
    "irigă": "iriga",
    "irigai": "iriga",
    "irigam": "iriga",
    "irigăm": "iriga",
    "irigând": "iriga",
    "irigându": "iriga",
    "irigară": "iriga",
    "irigarăm": "iriga",
    "irigarăți": "iriga",
    "irigase": "iriga",
    "irigasem": "iriga",
    "irigaseră": "iriga",
    "irigaserăm": "iriga",
    "irigaserăți": "iriga",
    "irigaseși": "iriga",
    "irigași": "iriga",
    "irigat": "iriga",
    "irigați": "iriga",
    "irigatu": "iriga",
    "irigau": "iriga",
    "irighează": "iriga",
    "irighez": "iriga",
    "irigheze": "iriga",
    "irighezi": "iriga",
    "neirigând": "iriga",
    "neirigându": "iriga",
    "nemaiirigând": "iriga",
    "nemaiirigându": "iriga",
    "irigată": "irigat",
    "irigate": "irigat",
    "irigați": "irigat",
    "irigația": "irigație",
    "irigației": "irigație",
    "irigații": "irigație",
    "irigațiile": "irigație",
    "irigațiilor": "irigație",
    "irisul": "iris",
    "irisului": "iris",
    "irisuri": "iris",
    "irisurile": "iris",
    "irisurilor": "iris",
    "irit": "irita",
    "irită": "irita",
    "iritai": "irita",
    "iritam": "irita",
    "irităm": "irita",
    "iritând": "irita",
    "iritându": "irita",
    "iritară": "irita",
    "iritarăm": "irita",
    "iritarăți": "irita",
    "iritase": "irita",
    "iritasem": "irita",
    "iritaseră": "irita",
    "iritaserăm": "irita",
    "iritaserăți": "irita",
    "iritaseși": "irita",
    "iritași": "irita",
    "iritat": "irita",
    "iritați": "irita",
    "iritatu": "irita",
    "iritau": "irita",
    "irite": "irita",
    "iriți": "irita",
    "neiritând": "irita",
    "neiritându": "irita",
    "nemaiiritând": "irita",
    "nemaiiritându": "irita",
    "iritabila": "iritabil",
    "iritabilă": "iritabil",
    "iritabile": "iritabil",
    "iritabilei": "iritabil",
    "iritabilele": "iritabil",
    "iritabilelor": "iritabil",
    "iritabili": "iritabil",
    "iritabilii": "iritabil",
    "iritabililor": "iritabil",
    "iritabilul": "iritabil",
    "iritabilului": "iritabil",
    "iritanta": "iritant",
    "iritantă": "iritant",
    "iritante": "iritant",
    "iritantei": "iritant",
    "iritantele": "iritant",
    "iritantelor": "iritant",
    "iritanți": "iritant",
    "iritanții": "iritant",
    "iritanților": "iritant",
    "iritantul": "iritant",
    "iritantului": "iritant",
    "iritarea": "iritare",
    "iritări": "iritare",
    "iritării": "iritare",
    "iritările": "iritare",
    "iritărilor": "iritare",
    "iritată": "iritat",
    "iritate": "iritat",
    "iritați": "iritat",
    "iritația": "iritație",
    "iritației": "iritație",
    "iritații": "iritație",
    "iritațiile": "iritație",
    "iritațiilor": "iritație",
    "iriză": "iriza",
    "irizai": "iriza",
    "irizam": "iriza",
    "irizăm": "iriza",
    "irizând": "iriza",
    "irizându": "iriza",
    "irizară": "iriza",
    "irizarăm": "iriza",
    "irizarăți": "iriza",
    "irizase": "iriza",
    "irizasem": "iriza",
    "irizaseră": "iriza",
    "irizaserăm": "iriza",
    "irizaserăți": "iriza",
    "irizaseși": "iriza",
    "irizași": "iriza",
    "irizat": "iriza",
    "irizați": "iriza",
    "irizatu": "iriza",
    "irizau": "iriza",
    "irizează": "iriza",
    "irizez": "iriza",
    "irizeze": "iriza",
    "irizezi": "iriza",
    "neirizând": "iriza",
    "neirizându": "iriza",
    "nemaiirizând": "iriza",
    "nemaiirizându": "iriza",
    "irizată": "irizat",
    "irizate": "irizat",
    "irizați": "irizat",
    "irlandeza": "irlandez",
    "irlandeză": "irlandez",
    "irlandeze": "irlandez",
    "irlandezei": "irlandez",
    "irlandezele": "irlandez",
    "irlandezelor": "irlandez",
    "irlandezi": "irlandez",
    "irlandezii": "irlandez",
    "irlandezilor": "irlandez",
    "irlandezul": "irlandez",
    "irlandezului": "irlandez",
    "ironica": "ironic",
    "ironică": "ironic",
    "ironice": "ironic",
    "ironicei": "ironic",
    "ironicele": "ironic",
    "ironicelor": "ironic",
    "ironici": "ironic",
    "ironicii": "ironic",
    "ironicilor": "ironic",
    "ironicul": "ironic",
    "ironicului": "ironic",
    "ironia": "ironie",
    "ironiei": "ironie",
    "ironii": "ironie",
    "ironiile": "ironie",
    "ironiilor": "ironie",
    "ironiză": "ironiza",
    "ironizai": "ironiza",
    "ironizam": "ironiza",
    "ironizăm": "ironiza",
    "ironizând": "ironiza",
    "ironizându": "ironiza",
    "ironizară": "ironiza",
    "ironizarăm": "ironiza",
    "ironizarăți": "ironiza",
    "ironizase": "ironiza",
    "ironizasem": "ironiza",
    "ironizaseră": "ironiza",
    "ironizaserăm": "ironiza",
    "ironizaserăți": "ironiza",
    "ironizaseși": "ironiza",
    "ironizași": "ironiza",
    "ironizat": "ironiza",
    "ironizați": "ironiza",
    "ironizatu": "ironiza",
    "ironizau": "ironiza",
    "ironizează": "ironiza",
    "ironizez": "ironiza",
    "ironizeze": "ironiza",
    "ironizezi": "ironiza",
    "neironizând": "ironiza",
    "neironizându": "ironiza",
    "nemaiironizând": "ironiza",
    "nemaiironizându": "ironiza",
    "ironizată": "ironizat",
    "ironizate": "ironizat",
    "ironizați": "ironizat",
    "irosea": "irosi",
    "iroseai": "irosi",
    "iroseam": "irosi",
    "irosească": "irosi",
    "iroseați": "irosi",
    "iroseau": "irosi",
    "irosesc": "irosi",
    "irosește": "irosi",
    "irosești": "irosi",
    "irosii": "irosi",
    "irosim": "irosi",
    "irosind": "irosi",
    "irosindu": "irosi",
    "irosiră": "irosi",
    "irosirăm": "irosi",
    "irosirăți": "irosi",
    "irosise": "irosi",
    "irosisem": "irosi",
    "irosiseră": "irosi",
    "irosiserăm": "irosi",
    "irosiserăți": "irosi",
    "irosiseși": "irosi",
    "irosiși": "irosi",
    "irosit": "irosi",
    "irosiți": "irosi",
    "irositu": "irosi",
    "neirosind": "irosi",
    "neirosindu": "irosi",
    "nemaiirosind": "irosi",
    "nemaiirosindu": "irosi",
    "irosirea": "irosire",
    "irosireo": "irosire",
    "irosiri": "irosire",
    "irosirii": "irosire",
    "irosirile": "irosire",
    "irosirilor": "irosire",
    "irosită": "irosit",
    "irosite": "irosit",
    "irosiți": "irosit",
    "Ișalniței": "Ișalnița",
    "isc": "isca",
    "iscă": "isca",
    "iscai": "isca",
    "iscam": "isca",
    "iscăm": "isca",
    "iscând": "isca",
    "iscându": "isca",
    "iscară": "isca",
    "iscarăm": "isca",
    "iscarăți": "isca",
    "iscase": "isca",
    "iscasem": "isca",
    "iscaseră": "isca",
    "iscaserăm": "isca",
    "iscaserăți": "isca",
    "iscaseși": "isca",
    "iscași": "isca",
    "iscat": "isca",
    "iscați": "isca",
    "iscatu": "isca",
    "iscau": "isca",
    "isce": "isca",
    "isci": "isca",
    "neiscând": "isca",
    "neiscându": "isca",
    "nemaiiscând": "isca",
    "nemaiiscându": "isca",
    "iscălea": "iscăli",
    "iscăleai": "iscăli",
    "iscăleam": "iscăli",
    "iscălească": "iscăli",
    "iscăleați": "iscăli",
    "iscăleau": "iscăli",
    "iscălesc": "iscăli",
    "iscălește": "iscăli",
    "iscălești": "iscăli",
    "iscălii": "iscăli",
    "iscălim": "iscăli",
    "iscălind": "iscăli",
    "iscălindu": "iscăli",
    "iscăliră": "iscăli",
    "iscălirăm": "iscăli",
    "iscălirăți": "iscăli",
    "iscălise": "iscăli",
    "iscălisem": "iscăli",
    "iscăliseră": "iscăli",
    "iscăliserăm": "iscăli",
    "iscăliserăți": "iscăli",
    "iscăliseși": "iscăli",
    "iscăliși": "iscăli",
    "iscălit": "iscăli",
    "iscăliți": "iscăli",
    "iscălitu": "iscăli",
    "neiscălind": "iscăli",
    "neiscălindu": "iscăli",
    "nemaiiscălind": "iscăli",
    "nemaiiscălindu": "iscăli",
    "iscălită": "iscălit",
    "iscălite": "iscălit",
    "iscăliți": "iscălit",
    "iscălitura": "iscălitură",
    "iscălituri": "iscălitură",
    "iscăliturii": "iscălitură",
    "iscăliturile": "iscălitură",
    "iscăliturilor": "iscălitură",
    "iscată": "iscat",
    "iscate": "iscat",
    "iscați": "iscat",
    "iscoada": "iscoadă",
    "iscoade": "iscoadă",
    "iscoadei": "iscoadă",
    "iscoadele": "iscoadă",
    "iscoadelor": "iscoadă",
    "iscodea": "iscodi",
    "iscodeai": "iscodi",
    "iscodeam": "iscodi",
    "iscodească": "iscodi",
    "iscodeați": "iscodi",
    "iscodeau": "iscodi",
    "iscodesc": "iscodi",
    "iscodește": "iscodi",
    "iscodești": "iscodi",
    "iscodii": "iscodi",
    "iscodim": "iscodi",
    "iscodind": "iscodi",
    "iscodindu": "iscodi",
    "iscodiră": "iscodi",
    "iscodirăm": "iscodi",
    "iscodirăți": "iscodi",
    "iscodise": "iscodi",
    "iscodisem": "iscodi",
    "iscodiseră": "iscodi",
    "iscodiserăm": "iscodi",
    "iscodiserăți": "iscodi",
    "iscodiseși": "iscodi",
    "iscodiși": "iscodi",
    "iscodit": "iscodi",
    "iscodiți": "iscodi",
    "iscoditu": "iscodi",
    "neiscodind": "iscodi",
    "neiscodindu": "iscodi",
    "nemaiiscodind": "iscodi",
    "nemaiiscodindu": "iscodi",
    "iscodirea": "iscodire",
    "iscodireo": "iscodire",
    "iscodiri": "iscodire",
    "iscodirii": "iscodire",
    "iscodirile": "iscodire",
    "iscodirilor": "iscodire",
    "iscodită": "iscodit",
    "iscodite": "iscodit",
    "iscodiți": "iscodit",
    "iscoditoare": "iscoditor",
    "iscoditoarea": "iscoditor",
    "iscoditoarei": "iscoditor",
    "iscoditoarele": "iscoditor",
    "iscoditoarelor": "iscoditor",
    "iscoditori": "iscoditor",
    "iscoditorii": "iscoditor",
    "iscoditorilor": "iscoditor",
    "iscoditorul": "iscoditor",
    "iscoditorului": "iscoditor",
    "iscusea": "iscusi",
    "iscuseai": "iscusi",
    "iscuseam": "iscusi",
    "iscusească": "iscusi",
    "iscuseați": "iscusi",
    "iscuseau": "iscusi",
    "iscusesc": "iscusi",
    "iscusește": "iscusi",
    "iscusești": "iscusi",
    "iscusii": "iscusi",
    "iscusim": "iscusi",
    "iscusind": "iscusi",
    "iscusindu": "iscusi",
    "iscusiră": "iscusi",
    "iscusirăm": "iscusi",
    "iscusirăți": "iscusi",
    "iscusise": "iscusi",
    "iscusisem": "iscusi",
    "iscusiseră": "iscusi",
    "iscusiserăm": "iscusi",
    "iscusiserăți": "iscusi",
    "iscusiseși": "iscusi",
    "iscusiși": "iscusi",
    "iscusit": "iscusi",
    "iscusiți": "iscusi",
    "iscusitu": "iscusi",
    "neiscusind": "iscusi",
    "neiscusindu": "iscusi",
    "nemaiiscusind": "iscusi",
    "nemaiiscusindu": "iscusi",
    "iscusința": "iscusință",
    "iscusințe": "iscusință",
    "iscusinței": "iscusință",
    "iscusințele": "iscusință",
    "iscusințelor": "iscusință",
    "iscusita": "iscusit",
    "iscusită": "iscusit",
    "iscusite": "iscusit",
    "iscusitei": "iscusit",
    "iscusitele": "iscusit",
    "iscusitelor": "iscusit",
    "iscusiți": "iscusit",
    "iscusiții": "iscusit",
    "iscusiților": "iscusit",
    "iscusitul": "iscusit",
    "iscusitului": "iscusit",
    "isihasmul": "isihasm",
    "isihasmule": "isihasm",
    "isihasmului": "isihasm",
    "isihasmuri": "isihasm",
    "isihasmurile": "isihasm",
    "isihasmurilor": "isihasm",
    "isihasta": "isihast",
    "isihastă": "isihast",
    "isihaste": "isihast",
    "isihastei": "isihast",
    "isihastele": "isihast",
    "isihastelor": "isihast",
    "isihaști": "isihast",
    "isihaștii": "isihast",
    "isihaștilor": "isihast",
    "isihastul": "isihast",
    "isihastule": "isihast",
    "isihastului": "isihast",
    "isihasta": "isihastă",
    "isihaste": "isihastă",
    "isihastei": "isihastă",
    "isihastele": "isihastă",
    "isihastelor": "isihastă",
    "Ice": "Islanda",
    "Islande": "Islanda",
    "Islandei": "Islanda",
    "islazul": "islaz",
    "islazului": "islaz",
    "islazuri": "islaz",
    "islazurile": "islaz",
    "islazurilor": "islaz",
    "isonul": "ison",
    "isonului": "ison",
    "isoscele": "isoscel",
    "isoscelele": "isoscel",
    "isoscelelor": "isoscel",
    "isoscelul": "isoscel",
    "isoscelului": "isoscel",
    "ispășea": "ispăși",
    "ispășeai": "ispăși",
    "ispășeam": "ispăși",
    "ispășească": "ispăși",
    "ispășeați": "ispăși",
    "ispășeau": "ispăși",
    "ispășesc": "ispăși",
    "ispășește": "ispăși",
    "ispășești": "ispăși",
    "ispășii": "ispăși",
    "ispășim": "ispăși",
    "ispășind": "ispăși",
    "ispășindu": "ispăși",
    "ispășiră": "ispăși",
    "ispășirăm": "ispăși",
    "ispășirăți": "ispăși",
    "ispășise": "ispăși",
    "ispășisem": "ispăși",
    "ispășiseră": "ispăși",
    "ispășiserăm": "ispăși",
    "ispășiserăți": "ispăși",
    "ispășiseși": "ispăși",
    "ispășiși": "ispăși",
    "ispășit": "ispăși",
    "ispășiți": "ispăși",
    "ispășitu": "ispăși",
    "neispășind": "ispăși",
    "neispășindu": "ispăși",
    "neispășit": "ispăși",
    "nemaiispășind": "ispăși",
    "nemaiispășindu": "ispăși",
    "ispășirea": "ispășire",
    "ispășiri": "ispășire",
    "ispășirii": "ispășire",
    "ispășirile": "ispășire",
    "ispășirilor": "ispășire",
    "ispășită": "ispășit",
    "ispășite": "ispășit",
    "ispășiți": "ispășit",
    "ispășitoare": "ispășitor",
    "ispășitoarea": "ispășitor",
    "ispășitoarei": "ispășitor",
    "ispășitoarele": "ispășitor",
    "ispășitoarelor": "ispășitor",
    "ispășitoareo": "ispășitor",
    "ispășitori": "ispășitor",
    "ispășitorii": "ispășitor",
    "ispășitorilor": "ispășitor",
    "ispășitorul": "ispășitor",
    "ispășitorule": "ispășitor",
    "ispășitorului": "ispășitor",
    "ispita": "ispită",
    "ispite": "ispită",
    "ispitei": "ispită",
    "ispitele": "ispită",
    "ispitelor": "ispită",
    "ispitea": "ispiti",
    "ispiteai": "ispiti",
    "ispiteam": "ispiti",
    "ispitească": "ispiti",
    "ispiteați": "ispiti",
    "ispiteau": "ispiti",
    "ispitesc": "ispiti",
    "ispitește": "ispiti",
    "ispitești": "ispiti",
    "ispitii": "ispiti",
    "ispitim": "ispiti",
    "ispitind": "ispiti",
    "ispitindu": "ispiti",
    "ispitiră": "ispiti",
    "ispitirăm": "ispiti",
    "ispitirăți": "ispiti",
    "ispitise": "ispiti",
    "ispitisem": "ispiti",
    "ispitiseră": "ispiti",
    "ispitiserăm": "ispiti",
    "ispitiserăți": "ispiti",
    "ispitiseși": "ispiti",
    "ispitiși": "ispiti",
    "ispitit": "ispiti",
    "ispitiți": "ispiti",
    "ispititu": "ispiti",
    "neispitind": "ispiti",
    "neispitindu": "ispiti",
    "nemaiispitind": "ispiti",
    "nemaiispitindu": "ispiti",
    "ispitirea": "ispitire",
    "ispitireo": "ispitire",
    "ispitiri": "ispitire",
    "ispitirii": "ispitire",
    "ispitirile": "ispitire",
    "ispitirilor": "ispitire",
    "ispitită": "ispitit",
    "ispitite": "ispitit",
    "ispitiți": "ispitit",
    "ispititoare": "ispititor",
    "ispititoarea": "ispititor",
    "ispititoarei": "ispititor",
    "ispititoarele": "ispititor",
    "ispititoarelor": "ispititor",
    "ispititori": "ispititor",
    "ispititorii": "ispititor",
    "ispititorilor": "ispititor",
    "ispititorul": "ispititor",
    "ispititorului": "ispititor",
    "isprava": "ispravă",
    "isprăvi": "ispravă",
    "isprăvii": "ispravă",
    "isprăvile": "ispravă",
    "isprăvilor": "ispravă",
    "isprăvea": "isprăvi",
    "isprăveai": "isprăvi",
    "isprăveam": "isprăvi",
    "isprăvească": "isprăvi",
    "isprăveați": "isprăvi",
    "isprăveau": "isprăvi",
    "isprăvesc": "isprăvi",
    "isprăvește": "isprăvi",
    "isprăvești": "isprăvi",
    "isprăvii": "isprăvi",
    "isprăvim": "isprăvi",
    "isprăvind": "isprăvi",
    "isprăvindu": "isprăvi",
    "isprăviră": "isprăvi",
    "isprăvirăm": "isprăvi",
    "isprăvirăți": "isprăvi",
    "isprăvise": "isprăvi",
    "isprăvisem": "isprăvi",
    "isprăviseră": "isprăvi",
    "isprăviserăm": "isprăvi",
    "isprăviserăți": "isprăvi",
    "isprăviseși": "isprăvi",
    "isprăviși": "isprăvi",
    "isprăvit": "isprăvi",
    "isprăviți": "isprăvi",
    "isprăvitu": "isprăvi",
    "neisprăvind": "isprăvi",
    "neisprăvindu": "isprăvi",
    "nemaiisprăvind": "isprăvi",
    "nemaiisprăvindu": "isprăvi",
    "isprăvită": "isprăvit",
    "isprăvite": "isprăvit",
    "isprăviți": "isprăvit",
    "Israelul": "Israel",
    "Israelului": "Israel",
    "israeliana": "israelian",
    "israeliană": "israelian",
    "israeliano": "israelian",
    "israelianul": "israelian",
    "israelianule": "israelian",
    "israelianului": "israelian",
    "israeliene": "israelian",
    "israelienei": "israelian",
    "israelienele": "israelian",
    "israelienelor": "israelian",
    "israelieni": "israelian",
    "israelienii": "israelian",
    "israelienilor": "israelian",
    "isterica": "isteric",
    "isterică": "isteric",
    "isterice": "isteric",
    "istericei": "isteric",
    "istericele": "isteric",
    "istericelor": "isteric",
    "isterici": "isteric",
    "istericii": "isteric",
    "istericilor": "isteric",
    "istericul": "isteric",
    "istericului": "isteric",
    "isterica": "isterică",
    "isterice": "isterică",
    "istericei": "isterică",
    "istericele": "isterică",
    "istericelor": "isterică",
    "isteria": "isterie",
    "isteriei": "isterie",
    "isterii": "isterie",
    "isteriile": "isterie",
    "isteriilor": "isterie",
    "isteața": "isteț",
    "isteață": "isteț",
    "istețe": "isteț",
    "isteței": "isteț",
    "istețele": "isteț",
    "istețelor": "isteț",
    "isteți": "isteț",
    "isteții": "isteț",
    "isteților": "isteț",
    "istețul": "isteț",
    "istețului": "isteț",
    "istețimea": "istețime",
    "istețimi": "istețime",
    "istețimii": "istețime",
    "istețimile": "istețime",
    "istețimilor": "istețime",
    "istmul": "istm",
    "istmului": "istm",
    "istmuri": "istm",
    "istmurile": "istm",
    "istmurilor": "istm",
    "istorica": "istoric",
    "istorică": "istoric",
    "istorice": "istoric",
    "istoricei": "istoric",
    "istoricele": "istoric",
    "istoricelor": "istoric",
    "istorici": "istoric",
    "istoricii": "istoric",
    "istoricilor": "istoric",
    "istoricul": "istoric",
    "istoricului": "istoric",
    "ist.": "istorie",
    "istoria": "istorie",
    "istoriei": "istorie",
    "istorii": "istorie",
    "istoriile": "istorie",
    "istoriilor": "istorie",
    "istorisea": "istorisi",
    "istoriseai": "istorisi",
    "istoriseam": "istorisi",
    "istorisească": "istorisi",
    "istoriseați": "istorisi",
    "istoriseau": "istorisi",
    "istorisesc": "istorisi",
    "istorisește": "istorisi",
    "istorisești": "istorisi",
    "istorisii": "istorisi",
    "istorisim": "istorisi",
    "istorisind": "istorisi",
    "istorisindu": "istorisi",
    "istorisiră": "istorisi",
    "istorisirăm": "istorisi",
    "istorisirăți": "istorisi",
    "istorisise": "istorisi",
    "istorisisem": "istorisi",
    "istorisiseră": "istorisi",
    "istorisiserăm": "istorisi",
    "istorisiserăți": "istorisi",
    "istorisiseși": "istorisi",
    "istorisiși": "istorisi",
    "istorisit": "istorisi",
    "istorisiți": "istorisi",
    "istorisitu": "istorisi",
    "neistorisind": "istorisi",
    "neistorisindu": "istorisi",
    "nemaiistorisind": "istorisi",
    "nemaiistorisindu": "istorisi",
    "istorisirea": "istorisire",
    "istorisiri": "istorisire",
    "istorisirii": "istorisire",
    "istorisirile": "istorisire",
    "istorisirilor": "istorisire",
    "istorisită": "istorisit",
    "istorisite": "istorisit",
    "istorisiți": "istorisit",
    "istovea": "istovi",
    "istoveai": "istovi",
    "istoveam": "istovi",
    "istovească": "istovi",
    "istoveați": "istovi",
    "istoveau": "istovi",
    "istovesc": "istovi",
    "istovește": "istovi",
    "istovești": "istovi",
    "istovii": "istovi",
    "istovim": "istovi",
    "istovind": "istovi",
    "istovindu": "istovi",
    "istoviră": "istovi",
    "istovirăm": "istovi",
    "istovirăți": "istovi",
    "istovise": "istovi",
    "istovisem": "istovi",
    "istoviseră": "istovi",
    "istoviserăm": "istovi",
    "istoviserăți": "istovi",
    "istoviseși": "istovi",
    "istoviși": "istovi",
    "istovit": "istovi",
    "istoviți": "istovi",
    "istovitu": "istovi",
    "neistovind": "istovi",
    "neistovindu": "istovi",
    "nemaiistovind": "istovi",
    "nemaiistovindu": "istovi",
    "istovirea": "istovire",
    "istovireo": "istovire",
    "istoviri": "istovire",
    "istovirii": "istovire",
    "istovirile": "istovire",
    "istovirilor": "istovire",
    "istovita": "istovit",
    "istovită": "istovit",
    "istovite": "istovit",
    "istovitei": "istovit",
    "istovitele": "istovit",
    "istovitelor": "istovit",
    "istoviți": "istovit",
    "istoviții": "istovit",
    "istoviților": "istovit",
    "istovitul": "istovit",
    "istovitului": "istovit",
    "istovitoare": "istovitor",
    "istovitoarea": "istovitor",
    "istovitoarei": "istovitor",
    "istovitoarele": "istovitor",
    "istovitoarelor": "istovitor",
    "istovitori": "istovitor",
    "istovitorii": "istovitor",
    "istovitorilor": "istovitor",
    "istovitorul": "istovitor",
    "istovitorului": "istovitor",
    "Italie": "Italia",
    "Italiei": "Italia",
    "Italii": "Italia",
    "italiana": "italian",
    "italiană": "italian",
    "italianul": "italian",
    "italianului": "italian",
    "italiene": "italian",
    "italienei": "italian",
    "italienele": "italian",
    "italienelor": "italian",
    "italieni": "italian",
    "italienii": "italian",
    "italienilor": "italian",
    "italianca": "italiancă",
    "italience": "italiancă",
    "italiencei": "italiancă",
    "italiencele": "italiancă",
    "italiencelor": "italiancă",
    "italieneasca": "italienesc",
    "italienească": "italienesc",
    "italienescul": "italienesc",
    "italienescului": "italienesc",
    "italienești": "italienesc",
    "italieneștii": "italienesc",
    "italieneștile": "italienesc",
    "italieneștilor": "italienesc",
    "italieniză": "italieniza",
    "italienizai": "italieniza",
    "italienizam": "italieniza",
    "italienizăm": "italieniza",
    "italienizând": "italieniza",
    "italienizându": "italieniza",
    "italienizară": "italieniza",
    "italienizarăm": "italieniza",
    "italienizarăți": "italieniza",
    "italienizase": "italieniza",
    "italienizasem": "italieniza",
    "italienizaseră": "italieniza",
    "italienizaserăm": "italieniza",
    "italienizaserăți": "italieniza",
    "italienizaseși": "italieniza",
    "italienizași": "italieniza",
    "italienizat": "italieniza",
    "italienizați": "italieniza",
    "italienizatu": "italieniza",
    "italienizau": "italieniza",
    "italienizează": "italieniza",
    "italienizez": "italieniza",
    "italienizeze": "italieniza",
    "italienizezi": "italieniza",
    "neitalienizând": "italieniza",
    "neitalienizându": "italieniza",
    "nemaiitalienizând": "italieniza",
    "nemaiitalienizându": "italieniza",
    "italienizată": "italienizat",
    "italienizate": "italienizat",
    "italienizați": "italienizat",
    "ițari": "ițar",
    "ițarii": "ițar",
    "ițarilor": "ițar",
    "ițarul": "ițar",
    "ițarule": "ițar",
    "ițarului": "ițar",
    "îț'": "îți",
    "ț'": "îți",
    "itinerare": "itinerar",
    "itinerarele": "itinerar",
    "itinerarelor": "itinerar",
    "itinerarul": "itinerar",
    "itinerarului": "itinerar",
    "itinerată": "itinerat",
    "itinerate": "itinerat",
    "itinerați": "itinerat",
    "iubăreți": "iubăreț",
    "iubăreții": "iubăreț",
    "iubăreților": "iubăreț",
    "iubărețul": "iubăreț",
    "iubărețului": "iubăreț",
    "iubea": "iubi",
    "iubeai": "iubi",
    "iubeam": "iubi",
    "iubească": "iubi",
    "iubeați": "iubi",
    "iubeau": "iubi",
    "iubesc": "iubi",
    "iubește": "iubi",
    "iubești": "iubi",
    "iubii": "iubi",
    "iubim": "iubi",
    "iubind": "iubi",
    "iubindu": "iubi",
    "iubiră": "iubi",
    "iubirăm": "iubi",
    "iubirăți": "iubi",
    "iubise": "iubi",
    "iubisem": "iubi",
    "iubiseră": "iubi",
    "iubiserăm": "iubi",
    "iubiserăți": "iubi",
    "iubiseși": "iubi",
    "iubiși": "iubi",
    "iubit": "iubi",
    "iubiți": "iubi",
    "iubitu": "iubi",
    "neiubind": "iubi",
    "neiubindu": "iubi",
    "nemaiiubind": "iubi",
    "nemaiiubindu": "iubi",
    "iubirea": "iubire",
    "iubiri": "iubire",
    "iubirii": "iubire",
    "iubirile": "iubire",
    "iubirilor": "iubire",
    "iubită": "iubit",
    "iubite": "iubit",
    "iubiți": "iubit",
    "iubiții": "iubit",
    "iubiților": "iubit",
    "iubitul": "iubit",
    "iubitule": "iubit",
    "iubitului": "iubit",
    "iubita": "iubită",
    "iubite": "iubită",
    "iubitei": "iubită",
    "iubitele": "iubită",
    "iubitelor": "iubită",
    "iubitoare": "iubitor",
    "iubitoarea": "iubitor",
    "iubitoarei": "iubitor",
    "iubitoarele": "iubitor",
    "iubitoarelor": "iubitor",
    "iubitori": "iubitor",
    "iubitorii": "iubitor",
    "iubitorilor": "iubitor",
    "iubitorul": "iubitor",
    "iubitorului": "iubitor",
    "Iudei": "Iuda",
    "iuda": "iudă",
    "iude": "iudă",
    "iudei": "iudă",
    "iudele": "iudă",
    "iudelor": "iudă",
    "iudo": "iudă",
    "iudei": "iudeu",
    "iudeii": "iudeu",
    "iudeilor": "iudeu",
    "iudeul": "iudeu",
    "iudeule": "iudeu",
    "iudeului": "iudeu",
    "iugoslava": "iugoslav",
    "iugoslavă": "iugoslav",
    "iugoslave": "iugoslav",
    "iugoslavei": "iugoslav",
    "iugoslavele": "iugoslav",
    "iugoslavelor": "iugoslav",
    "iugoslavi": "iugoslav",
    "iugoslavii": "iugoslav",
    "iugoslavilor": "iugoslav",
    "iugoslavo": "iugoslav",
    "iugoslavul": "iugoslav",
    "iugoslavule": "iugoslav",
    "iugoslavului": "iugoslav",
    "Iugoslavie": "Iugoslavia",
    "Iugoslaviei": "Iugoslavia",
    "Iugoslavii": "Iugoslavia",
    "Iulianei": "Iuliana",
    "iul.": "iulie",
    "iun.": "iunie",
    "iureșul": "iureș",
    "iureșului": "iureș",
    "iureșuri": "iureș",
    "iureșurile": "iureș",
    "iureșurilor": "iureș",
    "iuta": "iută",
    "iute": "iută",
    "iutei": "iută",
    "iutea": "iute",
    "iutele": "iute",
    "iutelui": "iute",
    "iuți": "iute",
    "iuții": "iute",
    "iuțile": "iute",
    "iuților": "iute",
    "iuțeala": "iuțeală",
    "iuțeli": "iuțeală",
    "iuțelii": "iuțeală",
    "iuțelile": "iuțeală",
    "iuțelilor": "iuțeală",
    "iuțea": "iuți",
    "iuțeai": "iuți",
    "iuțeam": "iuți",
    "iuțească": "iuți",
    "iuțeați": "iuți",
    "iuțeau": "iuți",
    "iuțesc": "iuți",
    "iuțește": "iuți",
    "iuțești": "iuți",
    "iuții": "iuți",
    "iuțim": "iuți",
    "iuțind": "iuți",
    "iuțindu": "iuți",
    "iuțiră": "iuți",
    "iuțirăm": "iuți",
    "iuțirăți": "iuți",
    "iuțise": "iuți",
    "iuțisem": "iuți",
    "iuțiseră": "iuți",
    "iuțiserăm": "iuți",
    "iuțiserăți": "iuți",
    "iuțiseși": "iuți",
    "iuțiși": "iuți",
    "iuțit": "iuți",
    "iuțiți": "iuți",
    "iuțitu": "iuți",
    "neiuțind": "iuți",
    "neiuțindu": "iuți",
    "nemaiiuțind": "iuți",
    "nemaiiuțindu": "iuți",
    "iuțită": "iuțit",
    "iuțite": "iuțit",
    "iuțiți": "iuțit",
    "ivăre": "ivăr",
    "ivărele": "ivăr",
    "ivărelor": "ivăr",
    "ivărul": "ivăr",
    "ivărului": "ivăr",
    "iveala": "iveală",
    "iveli": "iveală",
    "ivelii": "iveală",
    "ivelile": "iveală",
    "ivelilor": "iveală",
    "ivea": "ivi",
    "iveai": "ivi",
    "iveam": "ivi",
    "ivească": "ivi",
    "iveați": "ivi",
    "iveau": "ivi",
    "ivesc": "ivi",
    "ivește": "ivi",
    "ivești": "ivi",
    "ivii": "ivi",
    "ivim": "ivi",
    "ivind": "ivi",
    "ivindu": "ivi",
    "iviră": "ivi",
    "ivirăm": "ivi",
    "ivirăți": "ivi",
    "ivise": "ivi",
    "ivisem": "ivi",
    "iviseră": "ivi",
    "iviserăm": "ivi",
    "iviserăți": "ivi",
    "iviseși": "ivi",
    "iviși": "ivi",
    "ivit": "ivi",
    "iviți": "ivi",
    "ivitu": "ivi",
    "neivind": "ivi",
    "neivindu": "ivi",
    "nemaiivind": "ivi",
    "nemaiivindu": "ivi",
    "ivirea": "ivire",
    "iviri": "ivire",
    "ivirii": "ivire",
    "ivirile": "ivire",
    "ivirilor": "ivire",
    "ivită": "ivit",
    "ivite": "ivit",
    "iviți": "ivit",
    "ivoriul": "ivoriu",
    "ivoriului": "ivoriu",
    "izul": "iz",
    "izului": "iz",
    "izuri": "iz",
    "izurile": "iz",
    "izurilor": "iz",
    "izbânda": "izbândă",
    "izbânzi": "izbândă",
    "izbânzii": "izbândă",
    "izbânzile": "izbândă",
    "izbânzilor": "izbândă",
    "izbândea": "izbândi",
    "izbândeai": "izbândi",
    "izbândeam": "izbândi",
    "izbândească": "izbândi",
    "izbândeați": "izbândi",
    "izbândeau": "izbândi",
    "izbândesc": "izbândi",
    "izbândește": "izbândi",
    "izbândești": "izbândi",
    "izbândii": "izbândi",
    "izbândim": "izbândi",
    "izbândind": "izbândi",
    "izbândindu": "izbândi",
    "izbândiră": "izbândi",
    "izbândirăm": "izbândi",
    "izbândirăți": "izbândi",
    "izbândise": "izbândi",
    "izbândisem": "izbândi",
    "izbândiseră": "izbândi",
    "izbândiserăm": "izbândi",
    "izbândiserăți": "izbândi",
    "izbândiseși": "izbândi",
    "izbândiși": "izbândi",
    "izbândit": "izbândi",
    "izbândiți": "izbândi",
    "izbânditu": "izbândi",
    "neizbândind": "izbândi",
    "neizbândindu": "izbândi",
    "nemaiizbândind": "izbândi",
    "nemaiizbândindu": "izbândi",
    "izbândită": "izbândit",
    "izbândite": "izbândit",
    "izbândiți": "izbândit",
    "izbânditoare": "izbânditor",
    "izbânditoarea": "izbânditor",
    "izbânditoarei": "izbânditor",
    "izbânditoarele": "izbânditor",
    "izbânditoarelor": "izbânditor",
    "izbânditoareo": "izbânditor",
    "izbânditori": "izbânditor",
    "izbânditorii": "izbânditor",
    "izbânditorilor": "izbânditor",
    "izbânditorul": "izbânditor",
    "izbânditorule": "izbânditor",
    "izbânditorului": "izbânditor",
    "izbăvea": "izbăvi",
    "izbăveai": "izbăvi",
    "izbăveam": "izbăvi",
    "izbăvească": "izbăvi",
    "izbăveați": "izbăvi",
    "izbăveau": "izbăvi",
    "izbăvesc": "izbăvi",
    "izbăvește": "izbăvi",
    "izbăvești": "izbăvi",
    "izbăvii": "izbăvi",
    "izbăvim": "izbăvi",
    "izbăvind": "izbăvi",
    "izbăvindu": "izbăvi",
    "izbăviră": "izbăvi",
    "izbăvirăm": "izbăvi",
    "izbăvirăți": "izbăvi",
    "izbăvise": "izbăvi",
    "izbăvisem": "izbăvi",
    "izbăviseră": "izbăvi",
    "izbăviserăm": "izbăvi",
    "izbăviserăți": "izbăvi",
    "izbăviseși": "izbăvi",
    "izbăviși": "izbăvi",
    "izbăvit": "izbăvi",
    "izbăviți": "izbăvi",
    "izbăvitu": "izbăvi",
    "neizbăvind": "izbăvi",
    "neizbăvindu": "izbăvi",
    "nemaiizbăvind": "izbăvi",
    "nemaiizbăvindu": "izbăvi",
    "izbăvirea": "izbăvire",
    "izbăvireo": "izbăvire",
    "izbăviri": "izbăvire",
    "izbăvirii": "izbăvire",
    "izbăvirile": "izbăvire",
    "izbăvirilor": "izbăvire",
    "izbăvită": "izbăvit",
    "izbăvite": "izbăvit",
    "izbăviți": "izbăvit",
    "izbăvitoare": "izbăvitor",
    "izbăvitoarea": "izbăvitor",
    "izbăvitoarei": "izbăvitor",
    "izbăvitoarele": "izbăvitor",
    "izbăvitoarelor": "izbăvitor",
    "izbăvitoareo": "izbăvitor",
    "izbăvitori": "izbăvitor",
    "izbăvitorii": "izbăvitor",
    "izbăvitorilor": "izbăvitor",
    "izbăvitorul": "izbăvitor",
    "izbăvitorule": "izbăvitor",
    "izbăvitorului": "izbăvitor",
    "izbea": "izbi",
    "izbeai": "izbi",
    "izbeam": "izbi",
    "izbească": "izbi",
    "izbeați": "izbi",
    "izbeau": "izbi",
    "izbesc": "izbi",
    "izbește": "izbi",
    "izbești": "izbi",
    "izbii": "izbi",
    "izbim": "izbi",
    "izbind": "izbi",
    "izbindu": "izbi",
    "izbiră": "izbi",
    "izbirăm": "izbi",
    "izbirăți": "izbi",
    "izbise": "izbi",
    "izbisem": "izbi",
    "izbiseră": "izbi",
    "izbiserăm": "izbi",
    "izbiserăți": "izbi",
    "izbiseși": "izbi",
    "izbiși": "izbi",
    "izbit": "izbi",
    "izbiți": "izbi",
    "izbitu": "izbi",
    "neizbind": "izbi",
    "neizbindu": "izbi",
    "nemaiizbind": "izbi",
    "nemaiizbindu": "izbi",
    "izbită": "izbit",
    "izbite": "izbit",
    "izbiți": "izbit",
    "izbitoare": "izbitor",
    "izbitoarea": "izbitor",
    "izbitoarei": "izbitor",
    "izbitoarele": "izbitor",
    "izbitoarelor": "izbitor",
    "izbitori": "izbitor",
    "izbitorii": "izbitor",
    "izbitorilor": "izbitor",
    "izbitorul": "izbitor",
    "izbitorului": "izbitor",
    "izbitura": "izbitură",
    "izbituri": "izbitură",
    "izbiturii": "izbitură",
    "izbiturile": "izbitură",
    "izbiturilor": "izbitură",
    "izbucnea": "izbucni",
    "izbucneai": "izbucni",
    "izbucneam": "izbucni",
    "izbucnească": "izbucni",
    "izbucneați": "izbucni",
    "izbucneau": "izbucni",
    "izbucnesc": "izbucni",
    "izbucnește": "izbucni",
    "izbucnești": "izbucni",
    "izbucnii": "izbucni",
    "izbucnim": "izbucni",
    "izbucnind": "izbucni",
    "izbucnindu": "izbucni",
    "izbucniră": "izbucni",
    "izbucnirăm": "izbucni",
    "izbucnirăți": "izbucni",
    "izbucnise": "izbucni",
    "izbucnisem": "izbucni",
    "izbucniseră": "izbucni",
    "izbucniserăm": "izbucni",
    "izbucniserăți": "izbucni",
    "izbucniseși": "izbucni",
    "izbucniși": "izbucni",
    "izbucnit": "izbucni",
    "izbucniți": "izbucni",
    "izbucnitu": "izbucni",
    "neizbucnind": "izbucni",
    "neizbucnindu": "izbucni",
    "nemaiizbucnind": "izbucni",
    "nemaiizbucnindu": "izbucni",
    "izbucnirea": "izbucnire",
    "izbucniri": "izbucnire",
    "izbucnirii": "izbucnire",
    "izbucnirile": "izbucnire",
    "izbucnirilor": "izbucnire",
    "izbucnită": "izbucnit",
    "izbucnite": "izbucnit",
    "izbucniți": "izbucnit",
    "izbutea": "izbuti",
    "izbuteai": "izbuti",
    "izbuteam": "izbuti",
    "izbutească": "izbuti",
    "izbuteați": "izbuti",
    "izbuteau": "izbuti",
    "izbutesc": "izbuti",
    "izbutește": "izbuti",
    "izbutești": "izbuti",
    "izbutii": "izbuti",
    "izbutim": "izbuti",
    "izbutind": "izbuti",
    "izbutindu": "izbuti",
    "izbutiră": "izbuti",
    "izbutirăm": "izbuti",
    "izbutirăți": "izbuti",
    "izbutise": "izbuti",
    "izbutisem": "izbuti",
    "izbutiseră": "izbuti",
    "izbutiserăm": "izbuti",
    "izbutiserăți": "izbuti",
    "izbutiseși": "izbuti",
    "izbutiși": "izbuti",
    "izbutit": "izbuti",
    "izbutiți": "izbuti",
    "izbutitu": "izbuti",
    "neizbutind": "izbuti",
    "neizbutindu": "izbuti",
    "nemaiizbutind": "izbuti",
    "nemaiizbutindu": "izbuti",
    "izbutirea": "izbutire",
    "izbutireo": "izbutire",
    "izbutiri": "izbutire",
    "izbutirii": "izbutire",
    "izbutirile": "izbutire",
    "izbutirilor": "izbutire",
    "izbutită": "izbutit",
    "izbutite": "izbutit",
    "izbutiți": "izbutit",
    "izgonea": "izgoni",
    "izgoneai": "izgoni",
    "izgoneam": "izgoni",
    "izgonească": "izgoni",
    "izgoneați": "izgoni",
    "izgoneau": "izgoni",
    "izgonesc": "izgoni",
    "izgonește": "izgoni",
    "izgonești": "izgoni",
    "izgonii": "izgoni",
    "izgonim": "izgoni",
    "izgonind": "izgoni",
    "izgonindu": "izgoni",
    "izgoniră": "izgoni",
    "izgonirăm": "izgoni",
    "izgonirăți": "izgoni",
    "izgonise": "izgoni",
    "izgonisem": "izgoni",
    "izgoniseră": "izgoni",
    "izgoniserăm": "izgoni",
    "izgoniserăți": "izgoni",
    "izgoniseși": "izgoni",
    "izgoniși": "izgoni",
    "izgonit": "izgoni",
    "izgoniți": "izgoni",
    "izgonitu": "izgoni",
    "neizgonind": "izgoni",
    "neizgonindu": "izgoni",
    "nemaiizgonind": "izgoni",
    "nemaiizgonindu": "izgoni",
    "izgonită": "izgonit",
    "izgonite": "izgonit",
    "izgoniți": "izgonit",
    "izma": "izmă",
    "izme": "izmă",
    "izmei": "izmă",
    "izmana": "izmană",
    "izmene": "izmană",
    "izmenei": "izmană",
    "izmenele": "izmană",
    "izmenelor": "izmană",
    "izmenea": "izmeni",
    "izmeneai": "izmeni",
    "izmeneam": "izmeni",
    "izmenească": "izmeni",
    "izmeneați": "izmeni",
    "izmeneau": "izmeni",
    "izmenesc": "izmeni",
    "izmenește": "izmeni",
    "izmenești": "izmeni",
    "izmenii": "izmeni",
    "izmenim": "izmeni",
    "izmenind": "izmeni",
    "izmenindu": "izmeni",
    "izmeniră": "izmeni",
    "izmenirăm": "izmeni",
    "izmenirăți": "izmeni",
    "izmenise": "izmeni",
    "izmenisem": "izmeni",
    "izmeniseră": "izmeni",
    "izmeniserăm": "izmeni",
    "izmeniserăți": "izmeni",
    "izmeniseși": "izmeni",
    "izmeniși": "izmeni",
    "izmenit": "izmeni",
    "izmeniți": "izmeni",
    "izmenitu": "izmeni",
    "neizmenind": "izmeni",
    "neizmenindu": "izmeni",
    "nemaiizmenind": "izmeni",
    "nemaiizmenindu": "izmeni",
    "izmenită": "izmenit",
    "izmenite": "izmenit",
    "izmeniți": "izmenit",
    "izolă": "izola",
    "izolai": "izola",
    "izolam": "izola",
    "izolăm": "izola",
    "izolând": "izola",
    "izolându": "izola",
    "izolară": "izola",
    "izolarăm": "izola",
    "izolarăți": "izola",
    "izolase": "izola",
    "izolasem": "izola",
    "izolaseră": "izola",
    "izolaserăm": "izola",
    "izolaserăți": "izola",
    "izolaseși": "izola",
    "izolași": "izola",
    "izolat": "izola",
    "izolați": "izola",
    "izolatu": "izola",
    "izolau": "izola",
    "izolează": "izola",
    "izolez": "izola",
    "izoleze": "izola",
    "izolezi": "izola",
    "neizolând": "izola",
    "neizolându": "izola",
    "nemaiizolând": "izola",
    "nemaiizolându": "izola",
    "izolarea": "izolare",
    "izolări": "izolare",
    "izolării": "izolare",
    "izolările": "izolare",
    "izolărilor": "izolare",
    "izolata": "izolat",
    "izolată": "izolat",
    "izolate": "izolat",
    "izolatei": "izolat",
    "izolatele": "izolat",
    "izolatelor": "izolat",
    "izolați": "izolat",
    "izolații": "izolat",
    "izolaților": "izolat",
    "izolatul": "izolat",
    "izolatului": "izolat",
    "izolația": "izolație",
    "izolației": "izolație",
    "izolații": "izolație",
    "izolațiile": "izolație",
    "izolațiilor": "izolație",
    "izotopi": "izotop",
    "izotopii": "izotop",
    "izotopilor": "izotop",
    "izotopul": "izotop",
    "izotopului": "izotop",
    "izvodea": "izvodi",
    "izvodeai": "izvodi",
    "izvodeam": "izvodi",
    "izvodească": "izvodi",
    "izvodeați": "izvodi",
    "izvodeau": "izvodi",
    "izvodesc": "izvodi",
    "izvodește": "izvodi",
    "izvodești": "izvodi",
    "izvodii": "izvodi",
    "izvodim": "izvodi",
    "izvodind": "izvodi",
    "izvodindu": "izvodi",
    "izvodiră": "izvodi",
    "izvodirăm": "izvodi",
    "izvodirăți": "izvodi",
    "izvodise": "izvodi",
    "izvodisem": "izvodi",
    "izvodiseră": "izvodi",
    "izvodiserăm": "izvodi",
    "izvodiserăți": "izvodi",
    "izvodiseși": "izvodi",
    "izvodiși": "izvodi",
    "izvodit": "izvodi",
    "izvodiți": "izvodi",
    "izvoditu": "izvodi",
    "neizvodind": "izvodi",
    "neizvodindu": "izvodi",
    "nemaiizvodind": "izvodi",
    "nemaiizvodindu": "izvodi",
    "izvodită": "izvodit",
    "izvodite": "izvodit",
    "izvodiți": "izvodit",
    "izvoditoare": "izvoditor",
    "izvoditoarea": "izvoditor",
    "izvoditoarei": "izvoditor",
    "izvoditoarele": "izvoditor",
    "izvoditoarelor": "izvoditor",
    "izvoditoareo": "izvoditor",
    "izvoditori": "izvoditor",
    "izvoditorii": "izvoditor",
    "izvoditorilor": "izvoditor",
    "izvoditorul": "izvoditor",
    "izvoditorule": "izvoditor",
    "izvoditorului": "izvoditor",
    "izvoare": "izvor",
    "izvoarele": "izvor",
    "izvoarelor": "izvor",
    "izvorul": "izvor",
    "izvorului": "izvor",
    "izvorâtă": "izvorât",
    "izvorâte": "izvorât",
    "izvorâți": "izvorât",
    "izvorâtoare": "izvorâtor",
    "izvorâtoarea": "izvorâtor",
    "izvorâtoarei": "izvorâtor",
    "izvorâtoarele": "izvorâtor",
    "izvorâtoarelor": "izvorâtor",
    "izvorâtoareo": "izvorâtor",
    "izvorâtori": "izvorâtor",
    "izvorâtorii": "izvorâtor",
    "izvorâtorilor": "izvorâtor",
    "izvorâtorul": "izvorâtor",
    "izvorâtorule": "izvorâtor",
    "izvorâtorului": "izvorâtor",
    "izvora": "izvorî",
    "izvorai": "izvorî",
    "izvorâi": "izvorî",
    "izvoram": "izvorî",
    "izvorâm": "izvorî",
    "izvorând": "izvorî",
    "izvorându": "izvorî",
    "izvorâră": "izvorî",
    "izvorârăm": "izvorî",
    "izvorârăți": "izvorî",
    "izvorăsc": "izvorî",
    "izvorască": "izvorî",
    "izvorâse": "izvorî",
    "izvorâsem": "izvorî",
    "izvorâseră": "izvorî",
    "izvorâserăm": "izvorî",
    "izvorâserăți": "izvorî",
    "izvorâseși": "izvorî",
    "izvorâși": "izvorî",
    "izvorăște": "izvorî",
    "izvorăști": "izvorî",
    "izvorât": "izvorî",
    "izvorați": "izvorî",
    "izvorâți": "izvorî",
    "izvorâtu": "izvorî",
    "izvorau": "izvorî",
    "neizvorând": "izvorî",
    "neizvorându": "izvorî",
    "nemaiizvorând": "izvorî",
    "nemaiizvorându": "izvorî",
    "jaboul": "jabou",
    "jaboule": "jabou",
    "jaboului": "jabou",
    "jabouri": "jabou",
    "jabourile": "jabou",
    "jabourilor": "jabou",
    "jacheta": "jachetă",
    "jachete": "jachetă",
    "jachetei": "jachetă",
    "jachetele": "jachetă",
    "jachetelor": "jachetă",
    "jadul": "jad",
    "jadului": "jad",
    "jaduri": "jad",
    "jadurile": "jad",
    "jadurilor": "jad",
    "jaful": "jaf",
    "jafului": "jaf",
    "jafuri": "jaf",
    "jafurile": "jaf",
    "jafurilor": "jaf",
    "jaguari": "jaguar",
    "jaguarii": "jaguar",
    "jaguarilor": "jaguar",
    "jaguarul": "jaguar",
    "jaguarului": "jaguar",
    "jalba": "jalbă",
    "jalbe": "jalbă",
    "jalbei": "jalbă",
    "jalbele": "jalbă",
    "jalbelor": "jalbă",
    "jalea": "jale",
    "jalei": "jale",
    "jalnica": "jalnic",
    "jalnică": "jalnic",
    "jalnice": "jalnic",
    "jalnicei": "jalnic",
    "jalnicele": "jalnic",
    "jalnicelor": "jalnic",
    "jalnici": "jalnic",
    "jalnicii": "jalnic",
    "jalnicilor": "jalnic",
    "jalnicul": "jalnic",
    "jalnicului": "jalnic",
    "jaloane": "jalon",
    "jaloanele": "jalon",
    "jaloanelor": "jalon",
    "jalonul": "jalon",
    "jalonului": "jalon",
    "jalonă": "jalona",
    "jalonai": "jalona",
    "jalonam": "jalona",
    "jalonăm": "jalona",
    "jalonând": "jalona",
    "jalonându": "jalona",
    "jalonară": "jalona",
    "jalonarăm": "jalona",
    "jalonarăți": "jalona",
    "jalonase": "jalona",
    "jalonasem": "jalona",
    "jalonaseră": "jalona",
    "jalonaserăm": "jalona",
    "jalonaserăți": "jalona",
    "jalonaseși": "jalona",
    "jalonași": "jalona",
    "jalonat": "jalona",
    "jalonați": "jalona",
    "jalonatu": "jalona",
    "jalonau": "jalona",
    "jalonează": "jalona",
    "jalonez": "jalona",
    "jaloneze": "jalona",
    "jalonezi": "jalona",
    "nejalonând": "jalona",
    "nejalonându": "jalona",
    "nemaijalonând": "jalona",
    "nemaijalonându": "jalona",
    "jalonată": "jalonat",
    "jalonate": "jalonat",
    "jalonați": "jalonat",
    "jaluzeaua": "jaluzea",
    "jaluzele": "jaluzea",
    "jaluzelei": "jaluzea",
    "jaluzelele": "jaluzea",
    "jaluzelelor": "jaluzea",
    "jamboane": "jambon",
    "jamboanele": "jambon",
    "jamboanelor": "jambon",
    "jambonul": "jambon",
    "jambonului": "jambon",
    "Janei": "Jana",
    "jandarmi": "jandarm",
    "jandarmii": "jandarm",
    "jandarmilor": "jandarm",
    "jandarmul": "jandarm",
    "jandarmule": "jandarm",
    "jandarmului": "jandarm",
    "jandarmeria": "jandarmerie",
    "jandarmeriei": "jandarmerie",
    "jandarmerii": "jandarmerie",
    "jandarmeriile": "jandarmerie",
    "jandarmeriilor": "jandarmerie",
    "jandarmerio": "jandarmerie",
    "janta": "jantă",
    "jante": "jantă",
    "jantei": "jantă",
    "jantele": "jantă",
    "jantelor": "jantă",
    "japca": "japcă",
    "japoneza": "japonez",
    "japoneză": "japonez",
    "japoneze": "japonez",
    "japonezei": "japonez",
    "japonezele": "japonez",
    "japonezelor": "japonez",
    "japonezi": "japonez",
    "japonezii": "japonez",
    "japonezilor": "japonez",
    "japonezul": "japonez",
    "japonezului": "japonez",
    "japoneza": "japoneză",
    "japoneze": "japoneză",
    "japonezei": "japoneză",
    "japonezele": "japoneză",
    "japonezelor": "japoneză",
    "Japonie": "Japonia",
    "Japoniei": "Japonia",
    "Japonii": "Japonia",
    "jarul": "jar",
    "jarului": "jar",
    "jăraticul": "jăratic",
    "jăraticului": "jăratic",
    "jargoane": "jargon",
    "jargoanele": "jargon",
    "jargoanelor": "jargon",
    "jargonul": "jargon",
    "jargonului": "jargon",
    "jartiera": "jartieră",
    "jartiere": "jartieră",
    "jartierei": "jartieră",
    "jartierele": "jartieră",
    "jartierelor": "jartieră",
    "jăruia": "jărui",
    "jăruiai": "jărui",
    "jăruiam": "jărui",
    "jăruiască": "jărui",
    "jăruiați": "jărui",
    "jăruiau": "jărui",
    "jăruiesc": "jărui",
    "jăruiește": "jărui",
    "jăruiești": "jărui",
    "jăruii": "jărui",
    "jăruim": "jărui",
    "jăruind": "jărui",
    "jăruindu": "jărui",
    "jăruiră": "jărui",
    "jăruirăm": "jărui",
    "jăruirăți": "jărui",
    "jăruise": "jărui",
    "jăruisem": "jărui",
    "jăruiseră": "jărui",
    "jăruiserăm": "jărui",
    "jăruiserăți": "jărui",
    "jăruiseși": "jărui",
    "jăruiși": "jărui",
    "jăruit": "jărui",
    "jăruiți": "jărui",
    "jăruitu": "jărui",
    "nejăruind": "jărui",
    "nejăruindu": "jărui",
    "nemaijăruind": "jărui",
    "nemaijăruindu": "jărui",
    "jăruită": "jăruit",
    "jăruite": "jăruit",
    "jăruiți": "jăruit",
    "javra": "javră",
    "javre": "javră",
    "javrei": "javră",
    "javrele": "javră",
    "javrelor": "javră",
    "jazul": "jaz",
    "jazului": "jaz",
    "jazuri": "jaz",
    "jazurile": "jaz",
    "jazurilor": "jaz",
    "jderi": "jder",
    "jderii": "jder",
    "jderilor": "jder",
    "jderul": "jder",
    "jderului": "jder",
    "jecmănea": "jecmăni",
    "jecmăneai": "jecmăni",
    "jecmăneam": "jecmăni",
    "jecmănească": "jecmăni",
    "jecmăneați": "jecmăni",
    "jecmăneau": "jecmăni",
    "jecmănesc": "jecmăni",
    "jecmănește": "jecmăni",
    "jecmănești": "jecmăni",
    "jecmănii": "jecmăni",
    "jecmănim": "jecmăni",
    "jecmănind": "jecmăni",
    "jecmănindu": "jecmăni",
    "jecmăniră": "jecmăni",
    "jecmănirăm": "jecmăni",
    "jecmănirăți": "jecmăni",
    "jecmănise": "jecmăni",
    "jecmănisem": "jecmăni",
    "jecmăniseră": "jecmăni",
    "jecmăniserăm": "jecmăni",
    "jecmăniserăți": "jecmăni",
    "jecmăniseși": "jecmăni",
    "jecmăniși": "jecmăni",
    "jecmănit": "jecmăni",
    "jecmăniți": "jecmăni",
    "jecmănitu": "jecmăni",
    "nejecmănind": "jecmăni",
    "nejecmănindu": "jecmăni",
    "nemaijecmănind": "jecmăni",
    "nemaijecmănindu": "jecmăni",
    "jecmănită": "jecmănit",
    "jecmănite": "jecmănit",
    "jecmăniți": "jecmănit",
    "jecmănitoare": "jecmănitor",
    "jecmănitori": "jecmănitor",
    "jeepul": "jeep",
    "jeepule": "jeep",
    "jeepului": "jeep",
    "jeepuri": "jeep",
    "jeepurile": "jeep",
    "jeepurilor": "jeep",
    "jefuia": "jefui",
    "jefuiai": "jefui",
    "jefuiam": "jefui",
    "jefuiască": "jefui",
    "jefuiați": "jefui",
    "jefuiau": "jefui",
    "jefuiesc": "jefui",
    "jefuiește": "jefui",
    "jefuiești": "jefui",
    "jefuii": "jefui",
    "jefuim": "jefui",
    "jefuind": "jefui",
    "jefuindu": "jefui",
    "jefuiră": "jefui",
    "jefuirăm": "jefui",
    "jefuirăți": "jefui",
    "jefuise": "jefui",
    "jefuisem": "jefui",
    "jefuiseră": "jefui",
    "jefuiserăm": "jefui",
    "jefuiserăți": "jefui",
    "jefuiseși": "jefui",
    "jefuiși": "jefui",
    "jefuit": "jefui",
    "jefuiți": "jefui",
    "jefuitu": "jefui",
    "nejefuind": "jefui",
    "nejefuindu": "jefui",
    "nemaijefuind": "jefui",
    "nemaijefuindu": "jefui",
    "jefuită": "jefuit",
    "jefuite": "jefuit",
    "jefuiți": "jefuit",
    "jefuitoare": "jefuitor",
    "jefuitori": "jefuitor",
    "jegul": "jeg",
    "jegului": "jeg",
    "jeguri": "jeg",
    "jegurile": "jeg",
    "jegurilor": "jeg",
    "jegoasa": "jegos",
    "jegoasă": "jegos",
    "jegoase": "jegos",
    "jegoasei": "jegos",
    "jegoasele": "jegos",
    "jegoaselor": "jegos",
    "jegoși": "jegos",
    "jegoșii": "jegos",
    "jegoșilor": "jegos",
    "jegosul": "jegos",
    "jegosule": "jegos",
    "jegosului": "jegos",
    "jelania": "jelanie",
    "jelaniei": "jelanie",
    "jelanii": "jelanie",
    "jelaniile": "jelanie",
    "jelaniilor": "jelanie",
    "jelanio": "jelanie",
    "jeleul": "jeleu",
    "jeleului": "jeleu",
    "jeleuri": "jeleu",
    "jeleurile": "jeleu",
    "jeleurilor": "jeleu",
    "jelea": "jeli",
    "jeleai": "jeli",
    "jeleam": "jeli",
    "jelească": "jeli",
    "jeleați": "jeli",
    "jeleau": "jeli",
    "jelesc": "jeli",
    "jelește": "jeli",
    "jelești": "jeli",
    "jelii": "jeli",
    "jelim": "jeli",
    "jelind": "jeli",
    "jelindu": "jeli",
    "jeliră": "jeli",
    "jelirăm": "jeli",
    "jelirăți": "jeli",
    "jelise": "jeli",
    "jelisem": "jeli",
    "jeliseră": "jeli",
    "jeliserăm": "jeli",
    "jeliserăți": "jeli",
    "jeliseși": "jeli",
    "jeliși": "jeli",
    "jelit": "jeli",
    "jeliți": "jeli",
    "jelitu": "jeli",
    "nejelind": "jeli",
    "nejelindu": "jeli",
    "nemaijelind": "jeli",
    "nemaijelindu": "jeli",
    "jelită": "jelit",
    "jelite": "jelit",
    "jeliți": "jelit",
    "jeluia": "jelui",
    "jeluiai": "jelui",
    "jeluiam": "jelui",
    "jeluiască": "jelui",
    "jeluiați": "jelui",
    "jeluiau": "jelui",
    "jeluiesc": "jelui",
    "jeluiește": "jelui",
    "jeluiești": "jelui",
    "jeluii": "jelui",
    "jeluim": "jelui",
    "jeluind": "jelui",
    "jeluindu": "jelui",
    "jeluiră": "jelui",
    "jeluirăm": "jelui",
    "jeluirăți": "jelui",
    "jeluise": "jelui",
    "jeluisem": "jelui",
    "jeluiseră": "jelui",
    "jeluiserăm": "jelui",
    "jeluiserăți": "jelui",
    "jeluiseși": "jelui",
    "jeluiși": "jelui",
    "jeluit": "jelui",
    "jeluiți": "jelui",
    "jeluitu": "jelui",
    "nejeluind": "jelui",
    "nejeluindu": "jelui",
    "nemaijeluind": "jelui",
    "nemaijeluindu": "jelui",
    "jeluită": "jeluit",
    "jeluite": "jeluit",
    "jeluiți": "jeluit",
    "jeluitoare": "jeluitor",
    "jeluitoarea": "jeluitor",
    "jeluitoarei": "jeluitor",
    "jeluitoarele": "jeluitor",
    "jeluitoarelor": "jeluitor",
    "jeluitori": "jeluitor",
    "jeluitorii": "jeluitor",
    "jeluitorilor": "jeluitor",
    "jeluitorul": "jeluitor",
    "jeluitorului": "jeluitor",
    "jenă": "jena",
    "jenai": "jena",
    "jenam": "jena",
    "jenăm": "jena",
    "jenând": "jena",
    "jenându": "jena",
    "jenară": "jena",
    "jenarăm": "jena",
    "jenarăți": "jena",
    "jenase": "jena",
    "jenasem": "jena",
    "jenaseră": "jena",
    "jenaserăm": "jena",
    "jenaserăți": "jena",
    "jenaseși": "jena",
    "jenași": "jena",
    "jenat": "jena",
    "jenați": "jena",
    "jenatu": "jena",
    "jenau": "jena",
    "jenează": "jena",
    "jenez": "jena",
    "jeneze": "jena",
    "jenezi": "jena",
    "nejenând": "jena",
    "nejenându": "jena",
    "nemaijenând": "jena",
    "nemaijenându": "jena",
    "jena": "jenă",
    "jene": "jenă",
    "jenei": "jenă",
    "jenanta": "jenant",
    "jenantă": "jenant",
    "jenante": "jenant",
    "jenantei": "jenant",
    "jenantele": "jenant",
    "jenantelor": "jenant",
    "jenanți": "jenant",
    "jenanții": "jenant",
    "jenanților": "jenant",
    "jenantul": "jenant",
    "jenantului": "jenant",
    "jenata": "jenat",
    "jenată": "jenat",
    "jenate": "jenat",
    "jenatei": "jenat",
    "jenatele": "jenat",
    "jenatelor": "jenat",
    "jenați": "jenat",
    "jenații": "jenat",
    "jenaților": "jenat",
    "jenatul": "jenat",
    "jenatului": "jenat",
    "jepi": "jep",
    "jepii": "jep",
    "jepilor": "jep",
    "jepul": "jep",
    "jepului": "jep",
    "jerba": "jerbă",
    "jerbe": "jerbă",
    "jerbei": "jerbă",
    "jerbele": "jerbă",
    "jerbelor": "jerbă",
    "jerpelea": "jerpeli",
    "jerpeleai": "jerpeli",
    "jerpeleam": "jerpeli",
    "jerpelească": "jerpeli",
    "jerpeleați": "jerpeli",
    "jerpeleau": "jerpeli",
    "jerpelesc": "jerpeli",
    "jerpelește": "jerpeli",
    "jerpelești": "jerpeli",
    "jerpelii": "jerpeli",
    "jerpelim": "jerpeli",
    "jerpelind": "jerpeli",
    "jerpelindu": "jerpeli",
    "jerpeliră": "jerpeli",
    "jerpelirăm": "jerpeli",
    "jerpelirăți": "jerpeli",
    "jerpelise": "jerpeli",
    "jerpelisem": "jerpeli",
    "jerpeliseră": "jerpeli",
    "jerpeliserăm": "jerpeli",
    "jerpeliserăți": "jerpeli",
    "jerpeliseși": "jerpeli",
    "jerpeliși": "jerpeli",
    "jerpelit": "jerpeli",
    "jerpeliți": "jerpeli",
    "jerpelitu": "jerpeli",
    "nejerpelind": "jerpeli",
    "nejerpelindu": "jerpeli",
    "nemaijerpelind": "jerpeli",
    "nemaijerpelindu": "jerpeli",
    "jerpelita": "jerpelit",
    "jerpelită": "jerpelit",
    "jerpelite": "jerpelit",
    "jerpelitei": "jerpelit",
    "jerpelitele": "jerpelit",
    "jerpelitelor": "jerpelit",
    "jerpeliți": "jerpelit",
    "jerpeliții": "jerpelit",
    "jerpeliților": "jerpelit",
    "jerpelitul": "jerpelit",
    "jerpelitului": "jerpelit",
    "jersee": "jerseu",
    "jerseele": "jerseu",
    "jerseelor": "jerseu",
    "jerseul": "jerseu",
    "jerseului": "jerseu",
    "jertfa": "jertfă",
    "jertfe": "jertfă",
    "jertfei": "jertfă",
    "jertfele": "jertfă",
    "jertfelor": "jertfă",
    "jertfelnice": "jertfelnic",
    "jertfelnicele": "jertfelnic",
    "jertfelnicelor": "jertfelnic",
    "jertfelnicul": "jertfelnic",
    "jertfelnicule": "jertfelnic",
    "jertfelnicului": "jertfelnic",
    "jertfea": "jertfi",
    "jertfeai": "jertfi",
    "jertfeam": "jertfi",
    "jertfească": "jertfi",
    "jertfeați": "jertfi",
    "jertfeau": "jertfi",
    "jertfesc": "jertfi",
    "jertfește": "jertfi",
    "jertfești": "jertfi",
    "jertfii": "jertfi",
    "jertfim": "jertfi",
    "jertfind": "jertfi",
    "jertfindu": "jertfi",
    "jertfiră": "jertfi",
    "jertfirăm": "jertfi",
    "jertfirăți": "jertfi",
    "jertfise": "jertfi",
    "jertfisem": "jertfi",
    "jertfiseră": "jertfi",
    "jertfiserăm": "jertfi",
    "jertfiserăți": "jertfi",
    "jertfiseși": "jertfi",
    "jertfiși": "jertfi",
    "jertfit": "jertfi",
    "jertfiți": "jertfi",
    "jertfitu": "jertfi",
    "nejertfind": "jertfi",
    "nejertfindu": "jertfi",
    "nemaijertfind": "jertfi",
    "nemaijertfindu": "jertfi",
    "jertfirea": "jertfire",
    "jertfiri": "jertfire",
    "jertfirii": "jertfire",
    "jertfirile": "jertfire",
    "jertfirilor": "jertfire",
    "jertfită": "jertfit",
    "jertfite": "jertfit",
    "jertfiți": "jertfit",
    "jetul": "jet",
    "jetului": "jet",
    "jeturi": "jet",
    "jeturile": "jet",
    "jeturilor": "jet",
    "jetoane": "jeton",
    "jetoanele": "jeton",
    "jetoanelor": "jeton",
    "jetonul": "jeton",
    "jetonului": "jeton",
    "jgheabul": "jgheab",
    "jgheabului": "jgheab",
    "jgheaburi": "jgheab",
    "jgheaburile": "jgheab",
    "jgheaburilor": "jgheab",
    "jidani": "jidan",
    "jidanii": "jidan",
    "jidanilor": "jidan",
    "jidanul": "jidan",
    "jidanule": "jidan",
    "jidanului": "jidan",
    "jidovi": "jidov",
    "jidovii": "jidov",
    "jidovilor": "jidov",
    "jidovul": "jidov",
    "jidovule": "jidov",
    "jidovului": "jidov",
    "jigărea": "jigări",
    "jigăreai": "jigări",
    "jigăream": "jigări",
    "jigărească": "jigări",
    "jigăreați": "jigări",
    "jigăreau": "jigări",
    "jigăresc": "jigări",
    "jigărește": "jigări",
    "jigărești": "jigări",
    "jigării": "jigări",
    "jigărim": "jigări",
    "jigărind": "jigări",
    "jigărindu": "jigări",
    "jigăriră": "jigări",
    "jigărirăm": "jigări",
    "jigărirăți": "jigări",
    "jigărise": "jigări",
    "jigărisem": "jigări",
    "jigăriseră": "jigări",
    "jigăriserăm": "jigări",
    "jigăriserăți": "jigări",
    "jigăriseși": "jigări",
    "jigăriși": "jigări",
    "jigărit": "jigări",
    "jigăriți": "jigări",
    "jigăritu": "jigări",
    "nejigărind": "jigări",
    "nejigărindu": "jigări",
    "nemaijigărind": "jigări",
    "nemaijigărindu": "jigări",
    "jigărita": "jigărit",
    "jigărită": "jigărit",
    "jigărite": "jigărit",
    "jigăritei": "jigărit",
    "jigăritele": "jigărit",
    "jigăritelor": "jigărit",
    "jigăriți": "jigărit",
    "jigăriții": "jigărit",
    "jigăriților": "jigărit",
    "jigăritul": "jigărit",
    "jigăritului": "jigărit",
    "jignea": "jigni",
    "jigneai": "jigni",
    "jigneam": "jigni",
    "jignească": "jigni",
    "jigneați": "jigni",
    "jigneau": "jigni",
    "jignesc": "jigni",
    "jignește": "jigni",
    "jignești": "jigni",
    "jignii": "jigni",
    "jignim": "jigni",
    "jignind": "jigni",
    "jignindu": "jigni",
    "jigniră": "jigni",
    "jignirăm": "jigni",
    "jignirăți": "jigni",
    "jignise": "jigni",
    "jignisem": "jigni",
    "jigniseră": "jigni",
    "jigniserăm": "jigni",
    "jigniserăți": "jigni",
    "jigniseși": "jigni",
    "jigniși": "jigni",
    "jignit": "jigni",
    "jigniți": "jigni",
    "jignitu": "jigni",
    "nejignind": "jigni",
    "nejignindu": "jigni",
    "nemaijignind": "jigni",
    "nemaijignindu": "jigni",
    "jignirea": "jignire",
    "jigniri": "jignire",
    "jignirii": "jignire",
    "jignirile": "jignire",
    "jignirilor": "jignire",
    "jignită": "jignit",
    "jignite": "jignit",
    "jigniți": "jignit",
    "jignitoare": "jignitor",
    "jignitoarea": "jignitor",
    "jignitoarei": "jignitor",
    "jignitoarele": "jignitor",
    "jignitoarelor": "jignitor",
    "jignitori": "jignitor",
    "jignitorii": "jignitor",
    "jignitorilor": "jignitor",
    "jignitorul": "jignitor",
    "jignitorului": "jignitor",
    "Jilavei": "Jilava",
    "jilăvea": "jilăvi",
    "jilăveai": "jilăvi",
    "jilăveam": "jilăvi",
    "jilăvească": "jilăvi",
    "jilăveați": "jilăvi",
    "jilăveau": "jilăvi",
    "jilăvesc": "jilăvi",
    "jilăvește": "jilăvi",
    "jilăvești": "jilăvi",
    "jilăvii": "jilăvi",
    "jilăvim": "jilăvi",
    "jilăvind": "jilăvi",
    "jilăvindu": "jilăvi",
    "jilăviră": "jilăvi",
    "jilăvirăm": "jilăvi",
    "jilăvirăți": "jilăvi",
    "jilăvise": "jilăvi",
    "jilăvisem": "jilăvi",
    "jilăviseră": "jilăvi",
    "jilăviserăm": "jilăvi",
    "jilăviserăți": "jilăvi",
    "jilăviseși": "jilăvi",
    "jilăviși": "jilăvi",
    "jilăvit": "jilăvi",
    "jilăviți": "jilăvi",
    "jilăvitu": "jilăvi",
    "nejilăvind": "jilăvi",
    "nejilăvindu": "jilăvi",
    "nemaijilăvind": "jilăvi",
    "nemaijilăvindu": "jilăvi",
    "jilăvită": "jilăvit",
    "jilăvite": "jilăvit",
    "jilăviți": "jilăvit",
    "jilțul": "jilț",
    "jilțului": "jilț",
    "jilțuri": "jilț",
    "jilțurile": "jilț",
    "jilțurilor": "jilț",
    "jindul": "jind",
    "jindului": "jind",
    "jinduia": "jindui",
    "jinduiai": "jindui",
    "jinduiam": "jindui",
    "jinduiască": "jindui",
    "jinduiați": "jindui",
    "jinduiau": "jindui",
    "jinduiesc": "jindui",
    "jinduiește": "jindui",
    "jinduiești": "jindui",
    "jinduii": "jindui",
    "jinduim": "jindui",
    "jinduind": "jindui",
    "jinduindu": "jindui",
    "jinduiră": "jindui",
    "jinduirăm": "jindui",
    "jinduirăți": "jindui",
    "jinduise": "jindui",
    "jinduisem": "jindui",
    "jinduiseră": "jindui",
    "jinduiserăm": "jindui",
    "jinduiserăți": "jindui",
    "jinduiseși": "jindui",
    "jinduiși": "jindui",
    "jinduit": "jindui",
    "jinduiți": "jindui",
    "jinduitu": "jindui",
    "nejinduind": "jindui",
    "nejinduindu": "jindui",
    "nemaijinduind": "jindui",
    "nemaijinduindu": "jindui",
    "jinduită": "jinduit",
    "jinduite": "jinduit",
    "jinduiți": "jinduit",
    "jinduitoare": "jinduitor",
    "jinduitoarea": "jinduitor",
    "jinduitoarei": "jinduitor",
    "jinduitoarele": "jinduitor",
    "jinduitoarelor": "jinduitor",
    "jinduitoareo": "jinduitor",
    "jinduitori": "jinduitor",
    "jinduitorii": "jinduitor",
    "jinduitorilor": "jinduitor",
    "jinduitorul": "jinduitor",
    "jinduitorule": "jinduitor",
    "jinduitorului": "jinduitor",
    "jintuia": "jintui",
    "jintuiai": "jintui",
    "jintuiam": "jintui",
    "jintuiască": "jintui",
    "jintuiați": "jintui",
    "jintuiau": "jintui",
    "jintuiesc": "jintui",
    "jintuiește": "jintui",
    "jintuiești": "jintui",
    "jintuii": "jintui",
    "jintuim": "jintui",
    "jintuind": "jintui",
    "jintuindu": "jintui",
    "jintuiră": "jintui",
    "jintuirăm": "jintui",
    "jintuirăți": "jintui",
    "jintuise": "jintui",
    "jintuisem": "jintui",
    "jintuiseră": "jintui",
    "jintuiserăm": "jintui",
    "jintuiserăți": "jintui",
    "jintuiseși": "jintui",
    "jintuiși": "jintui",
    "jintuit": "jintui",
    "jintuiți": "jintui",
    "jintuitu": "jintui",
    "nejintuind": "jintui",
    "nejintuindu": "jintui",
    "nemaijintuind": "jintui",
    "nemaijintuindu": "jintui",
    "jintuită": "jintuit",
    "jintuite": "jintuit",
    "jintuiți": "jintuit",
    "jirul": "jir",
    "jirului": "jir",
    "Jiul": "Jiu",
    "Jiului": "Jiu",
    "jivina": "jivină",
    "jivine": "jivină",
    "jivinei": "jivină",
    "jivinele": "jivină",
    "jivinelor": "jivină",
    "jneapănul": "jneapăn",
    "jneapănului": "jneapăn",
    "jnepeni": "jneapăn",
    "jnepenii": "jneapăn",
    "jnepenilor": "jneapăn",
    "joaca": "joacă",
    "joagăre": "joagăr",
    "joagărele": "joagăr",
    "joagărelor": "joagăr",
    "joagărul": "joagăr",
    "joagărului": "joagăr",
    "jobene": "joben",
    "jobenele": "joben",
    "jobenelor": "joben",
    "jobenul": "joben",
    "jobenule": "joben",
    "jobenului": "joben",
    "jobenuri": "joben",
    "jobenurile": "joben",
    "jobenurilor": "joben",
    "jocul": "joc",
    "jocului": "joc",
    "jocuri": "joc",
    "jocurile": "joc",
    "jocurilor": "joc",
    "jochei": "jocheu",
    "jocheii": "jocheu",
    "jocheilor": "jocheu",
    "jocheul": "jocheu",
    "jocheului": "jocheu",
    "J.O.": "Jocurile_Olimpice",
    "Jocurilor_Olimpice": "Jocurile_Olimpice",
    "joia": "joi",
    "joii": "joi",
    "joile": "joi",
    "joilor": "joi",
    "joncțiunea": "joncțiune",
    "joncțiuni": "joncțiune",
    "joncțiunii": "joncțiune",
    "joncțiunile": "joncțiune",
    "joncțiunilor": "joncțiune",
    "jonglă": "jongla",
    "jonglai": "jongla",
    "jonglam": "jongla",
    "jonglăm": "jongla",
    "jonglând": "jongla",
    "jonglându": "jongla",
    "jonglară": "jongla",
    "jonglarăm": "jongla",
    "jonglarăți": "jongla",
    "jonglase": "jongla",
    "jonglasem": "jongla",
    "jonglaseră": "jongla",
    "jonglaserăm": "jongla",
    "jonglaserăți": "jongla",
    "jonglaseși": "jongla",
    "jonglași": "jongla",
    "jonglat": "jongla",
    "jonglați": "jongla",
    "jonglatu": "jongla",
    "jonglau": "jongla",
    "jonglează": "jongla",
    "jonglez": "jongla",
    "jongleze": "jongla",
    "jonglezi": "jongla",
    "nejonglând": "jongla",
    "nejonglându": "jongla",
    "nemaijonglând": "jongla",
    "nemaijonglându": "jongla",
    "jonglată": "jonglat",
    "jonglate": "jonglat",
    "jonglați": "jonglat",
    "jongleri": "jongler",
    "jonglerii": "jongler",
    "jonglerilor": "jongler",
    "jonglerul": "jongler",
    "jonglerului": "jongler",
    "jongleria": "jonglerie",
    "jongleriei": "jonglerie",
    "jonglerii": "jonglerie",
    "jongleriile": "jonglerie",
    "jongleriilor": "jonglerie",
    "joasa": "jos",
    "joasă": "jos",
    "joase": "jos",
    "joasei": "jos",
    "joasele": "jos",
    "joaselor": "jos",
    "joși": "jos",
    "joșii": "jos",
    "joșilor": "jos",
    "josul": "jos",
    "josului": "jos",
    "josnica": "josnic",
    "josnică": "josnic",
    "josnice": "josnic",
    "josnicei": "josnic",
    "josnicele": "josnic",
    "josnicelor": "josnic",
    "josnici": "josnic",
    "josnicii": "josnic",
    "josnicilor": "josnic",
    "josnicul": "josnic",
    "josnicului": "josnic",
    "josnicia": "josnicie",
    "josniciei": "josnicie",
    "josnicii": "josnicie",
    "josniciile": "josnicie",
    "josniciilor": "josnicie",
    "J": "joule",
    "jouli": "joule",
    "joviala": "jovial",
    "jovială": "jovial",
    "joviale": "jovial",
    "jovialei": "jovial",
    "jovialele": "jovial",
    "jovialelor": "jovial",
    "joviali": "jovial",
    "jovialii": "jovial",
    "jovialilor": "jovial",
    "jovialul": "jovial",
    "jovialului": "jovial",
    "jubilă": "jubila",
    "jubilai": "jubila",
    "jubilam": "jubila",
    "jubilăm": "jubila",
    "jubilând": "jubila",
    "jubilându": "jubila",
    "jubilară": "jubila",
    "jubilarăm": "jubila",
    "jubilarăți": "jubila",
    "jubilase": "jubila",
    "jubilasem": "jubila",
    "jubilaseră": "jubila",
    "jubilaserăm": "jubila",
    "jubilaserăți": "jubila",
    "jubilaseși": "jubila",
    "jubilași": "jubila",
    "jubilat": "jubila",
    "jubilați": "jubila",
    "jubilatu": "jubila",
    "jubilau": "jubila",
    "jubilează": "jubila",
    "jubilez": "jubila",
    "jubileze": "jubila",
    "jubilezi": "jubila",
    "nejubilând": "jubila",
    "nejubilându": "jubila",
    "nemaijubilând": "jubila",
    "nemaijubilându": "jubila",
    "jubilarea": "jubilare",
    "jubilareo": "jubilare",
    "jubilări": "jubilare",
    "jubilării": "jubilare",
    "jubilările": "jubilare",
    "jubilărilor": "jubilare",
    "jubilată": "jubilat",
    "jubilate": "jubilat",
    "jubilați": "jubilat",
    "jubilee": "jubileu",
    "jubileele": "jubileu",
    "jubileelor": "jubileu",
    "jubileul": "jubileu",
    "jubileului": "jubileu",
    "jubiliara": "jubiliar",
    "jubiliară": "jubiliar",
    "jubiliare": "jubiliar",
    "jubiliarei": "jubiliar",
    "jubiliarele": "jubiliar",
    "jubiliarelor": "jubiliar",
    "jubiliari": "jubiliar",
    "jubiliarii": "jubiliar",
    "jubiliarilor": "jubiliar",
    "jubiliarul": "jubiliar",
    "jubiliarului": "jubiliar",
    "joacă": "juca",
    "joace": "juca",
    "joc": "juca",
    "joci": "juca",
    "jucă": "juca",
    "jucai": "juca",
    "jucam": "juca",
    "jucăm": "juca",
    "jucând": "juca",
    "jucându": "juca",
    "jucară": "juca",
    "jucarăm": "juca",
    "jucarăți": "juca",
    "jucase": "juca",
    "jucasem": "juca",
    "jucaseră": "juca",
    "jucaserăm": "juca",
    "jucaserăți": "juca",
    "jucaseși": "juca",
    "jucași": "juca",
    "jucat": "juca",
    "jucați": "juca",
    "jucatu": "juca",
    "jucau": "juca",
    "nejucând": "juca",
    "nejucându": "juca",
    "nemaijucând": "juca",
    "nemaijucându": "juca",
    "jucăria": "jucărie",
    "jucăriei": "jucărie",
    "jucării": "jucărie",
    "jucăriile": "jucărie",
    "jucăriilor": "jucărie",
    "jucată": "jucat",
    "jucate": "jucat",
    "jucați": "jucat",
    "jucătoarea": "jucătoare",
    "jucătoarei": "jucătoare",
    "jucătoarele": "jucătoare",
    "jucătoarelor": "jucătoare",
    "jucători": "jucător",
    "jucătorii": "jucător",
    "jucătorilor": "jucător",
    "jucătorul": "jucător",
    "jucătorului": "jucător",
    "jucăușa": "jucăuș",
    "jucăușă": "jucăuș",
    "jucăușe": "jucăuș",
    "jucăușei": "jucăuș",
    "jucăușele": "jucăuș",
    "jucăușelor": "jucăuș",
    "jucăuși": "jucăuș",
    "jucăușii": "jucăuș",
    "jucăușilor": "jucăuș",
    "jucăușo": "jucăuș",
    "jucăușul": "jucăuș",
    "jucăușule": "jucăuș",
    "jucăușului": "jucăuș",
    "judec": "judeca",
    "judecă": "judeca",
    "judecai": "judeca",
    "judecam": "judeca",
    "judecăm": "judeca",
    "judecând": "judeca",
    "judecându": "judeca",
    "judecară": "judeca",
    "judecarăm": "judeca",
    "judecarăți": "judeca",
    "judecase": "judeca",
    "judecasem": "judeca",
    "judecaseră": "judeca",
    "judecaserăm": "judeca",
    "judecaserăți": "judeca",
    "judecaseși": "judeca",
    "judecași": "judeca",
    "judecat": "judeca",
    "judecați": "judeca",
    "judecatu": "judeca",
    "judecau": "judeca",
    "judece": "judeca",
    "judeci": "judeca",
    "nejudecând": "judeca",
    "nejudecându": "judeca",
    "nemaijudecând": "judeca",
    "nemaijudecându": "judeca",
    "judecată": "judecat",
    "judecate": "judecat",
    "judecați": "judecat",
    "judecata": "judecată",
    "judecăți": "judecată",
    "judecății": "judecată",
    "judecățile": "judecată",
    "judecăților": "judecată",
    "judecătoarea": "judecătoare",
    "judecătoarei": "judecătoare",
    "judecătoarele": "judecătoare",
    "judecătoarelor": "judecătoare",
    "judecători": "judecător",
    "judecătorii": "judecător",
    "judecătorilor": "judecător",
    "judecătorul": "judecător",
    "judecătorului": "judecător",
    "judecătoreasca": "judecătoresc",
    "judecătorească": "judecătoresc",
    "judecătorescul": "judecătoresc",
    "judecătorescului": "judecătoresc",
    "judecătorești": "judecătoresc",
    "judecătoreștii": "judecătoresc",
    "judecătoreștile": "judecătoresc",
    "judecătoreștilor": "judecătoresc",
    "judecătoria": "judecătorie",
    "judecătoriei": "judecătorie",
    "judecătorii": "judecătorie",
    "judecătoriile": "judecătorie",
    "judecătoriilor": "judecătorie",
    "jud.": "județ",
    "județe": "județ",
    "județele": "județ",
    "județelor": "județ",
    "județul": "județ",
    "județului": "județ",
    "județeana": "județean",
    "județeană": "județean",
    "județeanul": "județean",
    "județeanului": "județean",
    "județene": "județean",
    "județenei": "județean",
    "județenele": "județean",
    "județenelor": "județean",
    "județeni": "județean",
    "județenii": "județean",
    "județenilor": "județean",
    "judiciara": "judiciar",
    "judiciară": "judiciar",
    "judiciare": "judiciar",
    "judiciarei": "judiciar",
    "judiciarele": "judiciar",
    "judiciarelor": "judiciar",
    "judiciari": "judiciar",
    "judiciarii": "judiciar",
    "judiciarilor": "judiciar",
    "judiciarul": "judiciar",
    "judiciarului": "judiciar",
    "judicioasa": "judicios",
    "judicioasă": "judicios",
    "judicioase": "judicios",
    "judicioasei": "judicios",
    "judicioasele": "judicios",
    "judicioaselor": "judicios",
    "judicioși": "judicios",
    "judicioșii": "judicios",
    "judicioșilor": "judicios",
    "judiciosul": "judicios",
    "judiciosului": "judicios",
    "jugul": "jug",
    "jugului": "jug",
    "juguri": "jug",
    "jugurile": "jug",
    "jugurilor": "jug",
    "jugulă": "jugula",
    "jugulai": "jugula",
    "jugulam": "jugula",
    "jugulăm": "jugula",
    "jugulând": "jugula",
    "jugulându": "jugula",
    "jugulară": "jugula",
    "jugularăm": "jugula",
    "jugularăți": "jugula",
    "jugulase": "jugula",
    "jugulasem": "jugula",
    "jugulaseră": "jugula",
    "jugulaserăm": "jugula",
    "jugulaserăți": "jugula",
    "jugulaseși": "jugula",
    "jugulași": "jugula",
    "jugulat": "jugula",
    "jugulați": "jugula",
    "jugulatu": "jugula",
    "jugulau": "jugula",
    "jugulează": "jugula",
    "jugulez": "jugula",
    "juguleze": "jugula",
    "jugulezi": "jugula",
    "nejugulând": "jugula",
    "nejugulându": "jugula",
    "nemaijugulând": "jugula",
    "nemaijugulându": "jugula",
    "jugulată": "jugulat",
    "jugulate": "jugulat",
    "jugulați": "jugulat",
    "juisă": "juisa",
    "juisai": "juisa",
    "juisam": "juisa",
    "juisăm": "juisa",
    "juisând": "juisa",
    "juisându": "juisa",
    "juisară": "juisa",
    "juisarăm": "juisa",
    "juisarăți": "juisa",
    "juisase": "juisa",
    "juisasem": "juisa",
    "juisaseră": "juisa",
    "juisaserăm": "juisa",
    "juisaserăți": "juisa",
    "juisaseși": "juisa",
    "juisași": "juisa",
    "juisat": "juisa",
    "juisați": "juisa",
    "juisatu": "juisa",
    "juisau": "juisa",
    "juisează": "juisa",
    "juisez": "juisa",
    "juiseze": "juisa",
    "juisezi": "juisa",
    "nejuisând": "juisa",
    "nejuisându": "juisa",
    "nemaijuisând": "juisa",
    "nemaijuisându": "juisa",
    "juisată": "juisat",
    "juisate": "juisat",
    "juisați": "juisat",
    "julea": "juli",
    "juleai": "juli",
    "juleam": "juli",
    "julească": "juli",
    "juleați": "juli",
    "juleau": "juli",
    "julesc": "juli",
    "julește": "juli",
    "julești": "juli",
    "julii": "juli",
    "julim": "juli",
    "julind": "juli",
    "julindu": "juli",
    "juliră": "juli",
    "julirăm": "juli",
    "julirăți": "juli",
    "julise": "juli",
    "julisem": "juli",
    "juliseră": "juli",
    "juliserăm": "juli",
    "juliserăți": "juli",
    "juliseși": "juli",
    "juliși": "juli",
    "julit": "juli",
    "juliți": "juli",
    "julitu": "juli",
    "nejulind": "juli",
    "nejulindu": "juli",
    "nemaijulind": "juli",
    "nemaijulindu": "juli",
    "Juliei": "Julia",
    "julită": "julit",
    "julite": "julit",
    "juliți": "julit",
    "julitura": "julitură",
    "julituri": "julitură",
    "juliturii": "julitură",
    "juliturile": "julitură",
    "juliturilor": "julitură",
    "jumara": "jumară",
    "jumări": "jumară",
    "jumării": "jumară",
    "jumările": "jumară",
    "jumărilor": "jumară",
    "juma'": "jumătate",
    "jumătatea": "jumătate",
    "jumătăți": "jumătate",
    "jumătății": "jumătate",
    "jumătățile": "jumătate",
    "jumătăților": "jumătate",
    "jumătățea": "jumătăți",
    "jumătățeai": "jumătăți",
    "jumătățeam": "jumătăți",
    "jumătățească": "jumătăți",
    "jumătățeați": "jumătăți",
    "jumătățeau": "jumătăți",
    "jumătățesc": "jumătăți",
    "jumătățește": "jumătăți",
    "jumătățești": "jumătăți",
    "jumătății": "jumătăți",
    "jumătățim": "jumătăți",
    "jumătățind": "jumătăți",
    "jumătățindu": "jumătăți",
    "jumătățiră": "jumătăți",
    "jumătățirăm": "jumătăți",
    "jumătățirăți": "jumătăți",
    "jumătățise": "jumătăți",
    "jumătățisem": "jumătăți",
    "jumătățiseră": "jumătăți",
    "jumătățiserăm": "jumătăți",
    "jumătățiserăți": "jumătăți",
    "jumătățiseși": "jumătăți",
    "jumătățiși": "jumătăți",
    "jumătățit": "jumătăți",
    "jumătățiți": "jumătăți",
    "jumătățitu": "jumătăți",
    "nejumătățind": "jumătăți",
    "nejumătățindu": "jumătăți",
    "nemaijumătățind": "jumătăți",
    "nemaijumătățindu": "jumătăți",
    "jumătățită": "jumătățit",
    "jumătățite": "jumătățit",
    "jumătățiți": "jumătățit",
    "jumatea": "jumate",
    "jumateo": "jumate",
    "jumulea": "jumuli",
    "jumuleai": "jumuli",
    "jumuleam": "jumuli",
    "jumulească": "jumuli",
    "jumuleați": "jumuli",
    "jumuleau": "jumuli",
    "jumulesc": "jumuli",
    "jumulește": "jumuli",
    "jumulești": "jumuli",
    "jumulii": "jumuli",
    "jumulim": "jumuli",
    "jumulind": "jumuli",
    "jumulindu": "jumuli",
    "jumuliră": "jumuli",
    "jumulirăm": "jumuli",
    "jumulirăți": "jumuli",
    "jumulise": "jumuli",
    "jumulisem": "jumuli",
    "jumuliseră": "jumuli",
    "jumuliserăm": "jumuli",
    "jumuliserăți": "jumuli",
    "jumuliseși": "jumuli",
    "jumuliși": "jumuli",
    "jumulit": "jumuli",
    "jumuliți": "jumuli",
    "jumulitu": "jumuli",
    "nejumulind": "jumuli",
    "nejumulindu": "jumuli",
    "nemaijumulind": "jumuli",
    "nemaijumulindu": "jumuli",
    "jumulită": "jumulit",
    "jumulite": "jumulit",
    "jumuliți": "jumulit",
    "juna": "jună",
    "june": "jună",
    "junei": "jună",
    "junele": "jună",
    "junelor": "jună",
    "juno": "jună",
    "junca": "juncă",
    "junci": "juncă",
    "juncii": "juncă",
    "juncile": "juncă",
    "juncilor": "juncă",
    "juncani": "juncan",
    "juncanii": "juncan",
    "juncanilor": "juncan",
    "juncanul": "juncan",
    "juncanului": "juncan",
    "juna": "june",
    "jună": "june",
    "junei": "june",
    "junele": "june",
    "junelor": "june",
    "junelui": "june",
    "juni": "june",
    "junii": "june",
    "junilor": "june",
    "juno": "june",
    "junețea": "junețe",
    "junețeo": "junețe",
    "juneți": "junețe",
    "juneții": "junețe",
    "junețile": "junețe",
    "juneților": "junețe",
    "junghiul": "junghi",
    "junghiului": "junghi",
    "junghiuri": "junghi",
    "junghiurile": "junghi",
    "junghiurilor": "junghi",
    "junghiai": "junghia",
    "junghiam": "junghia",
    "junghiară": "junghia",
    "junghiarăm": "junghia",
    "junghiarăți": "junghia",
    "junghiase": "junghia",
    "junghiasem": "junghia",
    "junghiaseră": "junghia",
    "junghiaserăm": "junghia",
    "junghiaserăți": "junghia",
    "junghiaseși": "junghia",
    "junghiași": "junghia",
    "junghiat": "junghia",
    "junghiați": "junghia",
    "junghiatu": "junghia",
    "junghiau": "junghia",
    "junghie": "junghia",
    "junghiem": "junghia",
    "junghii": "junghia",
    "junghiind": "junghia",
    "junghiindu": "junghia",
    "nejunghiind": "junghia",
    "nejunghiindu": "junghia",
    "nemaijunghiind": "junghia",
    "nemaijunghiindu": "junghia",
    "junghiată": "junghiat",
    "junghiate": "junghiat",
    "junghiați": "junghiat",
    "jungla": "junglă",
    "jungle": "junglă",
    "junglei": "junglă",
    "junglele": "junglă",
    "junglelor": "junglă",
    "Junimii": "Junimea",
    "juninca": "junincă",
    "juninci": "junincă",
    "junincii": "junincă",
    "junincile": "junincă",
    "junincilor": "junincă",
    "junioara": "junioară",
    "junioare": "junioară",
    "junioarei": "junioară",
    "junioarele": "junioară",
    "junioarelor": "junioară",
    "junioaro": "junioară",
    "j.": "junior",
    "jr.": "junior",
    "junioara": "junior",
    "junioară": "junior",
    "junioare": "junior",
    "junioarei": "junior",
    "junioarele": "junior",
    "junioarelor": "junior",
    "junioaro": "junior",
    "juniori": "junior",
    "juniorii": "junior",
    "juniorilor": "junior",
    "juniorul": "junior",
    "juniorule": "junior",
    "juniorului": "junior",
    "Junonei": "Junona",
    "jupoaie": "jupui",
    "jupoi": "jupui",
    "jupuia": "jupui",
    "jupuiai": "jupui",
    "jupuiam": "jupui",
    "jupuiați": "jupui",
    "jupuiau": "jupui",
    "jupuii": "jupui",
    "jupuim": "jupui",
    "jupuind": "jupui",
    "jupuindu": "jupui",
    "jupuiră": "jupui",
    "jupuirăm": "jupui",
    "jupuirăți": "jupui",
    "jupuise": "jupui",
    "jupuisem": "jupui",
    "jupuiseră": "jupui",
    "jupuiserăm": "jupui",
    "jupuiserăți": "jupui",
    "jupuiseși": "jupui",
    "jupuiși": "jupui",
    "jupuit": "jupui",
    "jupuiți": "jupui",
    "jupuitu": "jupui",
    "nejupuind": "jupui",
    "nejupuindu": "jupui",
    "nemaijupuind": "jupui",
    "nemaijupuindu": "jupui",
    "jupuită": "jupuit",
    "jupuite": "jupuit",
    "jupuiți": "jupuit",
    "jur": "jura",
    "jură": "jura",
    "jurai": "jura",
    "juram": "jura",
    "jurăm": "jura",
    "jurând": "jura",
    "jurându": "jura",
    "jurară": "jura",
    "jurarăm": "jura",
    "jurarăți": "jura",
    "jurase": "jura",
    "jurasem": "jura",
    "juraseră": "jura",
    "juraserăm": "jura",
    "juraserăți": "jura",
    "juraseși": "jura",
    "jurași": "jura",
    "jurat": "jura",
    "jurați": "jura",
    "juratu": "jura",
    "jurau": "jura",
    "jure": "jura",
    "juri": "jura",
    "nejurând": "jura",
    "nejurându": "jura",
    "nemaijurând": "jura",
    "nemaijurându": "jura",
    "jurământul": "jurământ",
    "jurământului": "jurământ",
    "jurăminte": "jurământ",
    "jurămintele": "jurământ",
    "jurămintelor": "jurământ",
    "jurată": "jurat",
    "jurate": "jurat",
    "jurați": "jurat",
    "jurații": "jurat",
    "juraților": "jurat",
    "juratul": "jurat",
    "juratului": "jurat",
    "juridica": "juridic",
    "juridică": "juridic",
    "juridice": "juridic",
    "juridicei": "juridic",
    "juridicele": "juridic",
    "juridicelor": "juridic",
    "juridici": "juridic",
    "juridicii": "juridic",
    "juridicilor": "juridic",
    "juridicul": "juridic",
    "juridicului": "juridic",
    "jurisconsulți": "jurisconsult",
    "jurisconsulții": "jurisconsult",
    "jurisconsulților": "jurisconsult",
    "jurisconsultul": "jurisconsult",
    "jurisconsultului": "jurisconsult",
    "jurisdicția": "jurisdicție",
    "jurisdicției": "jurisdicție",
    "jurisdicții": "jurisdicție",
    "jurisdicțiile": "jurisdicție",
    "jurisdicțiilor": "jurisdicție",
    "jurisprudența": "jurisprudență",
    "jurisprudențe": "jurisprudență",
    "jurisprudenței": "jurisprudență",
    "jurisprudențele": "jurisprudență",
    "jurisprudențelor": "jurisprudență",
    "juriști": "jurist",
    "juriștii": "jurist",
    "juriștilor": "jurist",
    "juristul": "jurist",
    "juristului": "jurist",
    "jurii": "juriu",
    "juriile": "juriu",
    "juriilor": "juriu",
    "juriul": "juriu",
    "juriului": "juriu",
    "jurnale": "jurnal",
    "jurnalele": "jurnal",
    "jurnalelor": "jurnal",
    "jurnalul": "jurnal",
    "jurnalului": "jurnal",
    "jurnaliști": "jurnalist",
    "jurnaliștii": "jurnalist",
    "jurnaliștilor": "jurnalist",
    "jurnalistul": "jurnalist",
    "jurnalistului": "jurnalist",
    "jurnalistica": "jurnalistică",
    "jurnalistici": "jurnalistică",
    "jurnalisticii": "jurnalistică",
    "juruia": "jurui",
    "juruiai": "jurui",
    "juruiam": "jurui",
    "juruiască": "jurui",
    "juruiați": "jurui",
    "juruiau": "jurui",
    "juruiesc": "jurui",
    "juruiește": "jurui",
    "juruiești": "jurui",
    "juruii": "jurui",
    "juruim": "jurui",
    "juruiră": "jurui",
    "juruirăm": "jurui",
    "juruirăți": "jurui",
    "juruise": "jurui",
    "juruisem": "jurui",
    "juruiseră": "jurui",
    "juruiserăm": "jurui",
    "juruiserăți": "jurui",
    "juruiseși": "jurui",
    "juruiși": "jurui",
    "juruit": "jurui",
    "juruiți": "jurui",
    "juruitu": "jurui",
    "juruită": "juruit",
    "juruite": "juruit",
    "juruiți": "juruit",
    "justa": "just",
    "justă": "just",
    "juste": "just",
    "justei": "just",
    "justele": "just",
    "justelor": "just",
    "juști": "just",
    "juștii": "just",
    "juștilor": "just",
    "justul": "just",
    "justului": "just",
    "justețea": "justețe",
    "justeți": "justețe",
    "justeții": "justețe",
    "justific": "justifica",
    "justifică": "justifica",
    "justificai": "justifica",
    "justificam": "justifica",
    "justificăm": "justifica",
    "justificând": "justifica",
    "justificându": "justifica",
    "justificară": "justifica",
    "justificarăm": "justifica",
    "justificarăți": "justifica",
    "justificase": "justifica",
    "justificasem": "justifica",
    "justificaseră": "justifica",
    "justificaserăm": "justifica",
    "justificaserăți": "justifica",
    "justificaseși": "justifica",
    "justificași": "justifica",
    "justificat": "justifica",
    "justificați": "justifica",
    "justificatu": "justifica",
    "justificau": "justifica",
    "justifice": "justifica",
    "justifici": "justifica",
    "nejustificând": "justifica",
    "nejustificându": "justifica",
    "nemaijustificând": "justifica",
    "nemaijustificându": "justifica",
    "justificarea": "justificare",
    "justificări": "justificare",
    "justificării": "justificare",
    "justificările": "justificare",
    "justificărilor": "justificare",
    "justificată": "justificat",
    "justificate": "justificat",
    "justificați": "justificat",
    "justificativa": "justificativ",
    "justificativă": "justificativ",
    "justificative": "justificativ",
    "justificativei": "justificativ",
    "justificativele": "justificativ",
    "justificativelor": "justificativ",
    "justificativi": "justificativ",
    "justificativii": "justificativ",
    "justificativilor": "justificativ",
    "justificativul": "justificativ",
    "justificativului": "justificativ",
    "justițiara": "justițiar",
    "justițiară": "justițiar",
    "justițiare": "justițiar",
    "justițiarei": "justițiar",
    "justițiarele": "justițiar",
    "justițiarelor": "justițiar",
    "justițiari": "justițiar",
    "justițiarii": "justițiar",
    "justițiarilor": "justițiar",
    "justițiaro": "justițiar",
    "justițiarul": "justițiar",
    "justițiarule": "justițiar",
    "justițiarului": "justițiar",
    "justiția": "justiție",
    "justiției": "justiție",
    "justiții": "justiție",
    "juvenila": "juvenil",
    "juvenilă": "juvenil",
    "juvenile": "juvenil",
    "juvenilei": "juvenil",
    "juvenilele": "juvenil",
    "juvenilelor": "juvenil",
    "juvenili": "juvenil",
    "juvenilii": "juvenil",
    "juvenililor": "juvenil",
    "juvenilul": "juvenil",
    "juvenilului": "juvenil",
    "juxtapui": "juxtapune",
    "juxtapun": "juxtapune",
    "juxtapună": "juxtapune",
    "juxtapunând": "juxtapune",
    "juxtapunându": "juxtapune",
    "juxtapunea": "juxtapune",
    "juxtapuneai": "juxtapune",
    "juxtapuneam": "juxtapune",
    "juxtapuneați": "juxtapune",
    "juxtapuneau": "juxtapune",
    "juxtapunem": "juxtapune",
    "juxtapuneți": "juxtapune",
    "juxtapus": "juxtapune",
    "juxtapuse": "juxtapune",
    "juxtapusei": "juxtapune",
    "juxtapuseră": "juxtapune",
    "juxtapuserăm": "juxtapune",
    "juxtapuserăți": "juxtapune",
    "juxtapusese": "juxtapune",
    "juxtapusesem": "juxtapune",
    "juxtapuseseră": "juxtapune",
    "juxtapuseserăm": "juxtapune",
    "juxtapuseserăți": "juxtapune",
    "juxtapuseseși": "juxtapune",
    "juxtapuseși": "juxtapune",
    "juxtapusu": "juxtapune",
    "nejuxtapunând": "juxtapune",
    "nejuxtapunându": "juxtapune",
    "nemaijuxtapunând": "juxtapune",
    "nemaijuxtapunându": "juxtapune",
    "juxtapunerea": "juxtapunere",
    "juxtapuneri": "juxtapunere",
    "juxtapunerii": "juxtapunere",
    "juxtapunerile": "juxtapunere",
    "juxtapunerilor": "juxtapunere",
    "juxtapusă": "juxtapus",
    "juxtapuse": "juxtapus",
    "juxtapuși": "juxtapus",
    "Kabalei": "Kabala",
    "K": "kaliu",
    "kaliul": "kaliu",
    "kaliului": "kaliu",
    "Katherinei": "Katherine",
    "K": "kelvin",
    "kelvinul": "kelvin",
    "kelvinului": "kelvin",
    "kile": "kil",
    "kilele": "kil",
    "kilelor": "kil",
    "kilul": "kil",
    "kilule": "kil",
    "kilului": "kil",
    "k.": "kilo",
    "kg": "kilogram",
    "kilograme": "kilogram",
    "kilogramele": "kilogram",
    "kilogramelor": "kilogram",
    "kilogramul": "kilogram",
    "kilogramului": "kilogram",
    "kgf.": "kilogram_forță",
    "kl": "kilolitri",
    "kilolitri": "kilolitru",
    "kilolitrii": "kilolitru",
    "kilolitrilor": "kilolitru",
    "kilolitrul": "kilolitru",
    "kilolitrului": "kilolitru",
    "kilometră": "kilometra",
    "kilometrai": "kilometra",
    "kilometram": "kilometra",
    "kilometrăm": "kilometra",
    "kilometrând": "kilometra",
    "kilometrându": "kilometra",
    "kilometrară": "kilometra",
    "kilometrarăm": "kilometra",
    "kilometrarăți": "kilometra",
    "kilometrase": "kilometra",
    "kilometrasem": "kilometra",
    "kilometraseră": "kilometra",
    "kilometraserăm": "kilometra",
    "kilometraserăți": "kilometra",
    "kilometraseși": "kilometra",
    "kilometrași": "kilometra",
    "kilometrat": "kilometra",
    "kilometrați": "kilometra",
    "kilometratu": "kilometra",
    "kilometrau": "kilometra",
    "kilometrează": "kilometra",
    "kilometrez": "kilometra",
    "kilometreze": "kilometra",
    "kilometrezi": "kilometra",
    "nekilometrând": "kilometra",
    "nekilometrându": "kilometra",
    "nemaikilometrând": "kilometra",
    "nemaikilometrându": "kilometra",
    "kilometraje": "kilometraj",
    "kilometrajele": "kilometraj",
    "kilometrajelor": "kilometraj",
    "kilometrajul": "kilometraj",
    "kilometrajului": "kilometraj",
    "kilometrată": "kilometrat",
    "kilometrate": "kilometrat",
    "kilometrați": "kilometrat",
    "kilometri": "kilometru",
    "kilometrii": "kilometru",
    "kilometrilor": "kilometru",
    "kilometrul": "kilometru",
    "kilometrului": "kilometru",
    "km": "kilometru",
    "kt": "kilotone",
    "kWh": "kilowatt_oră",
    "kirghiza": "kirghiz",
    "kirghiză": "kirghiz",
    "kirghize": "kirghiz",
    "kirghizei": "kirghiz",
    "kirghizele": "kirghiz",
    "kirghizelor": "kirghiz",
    "kirghizi": "kirghiz",
    "kirghizii": "kirghiz",
    "kirghizilor": "kirghiz",
    "kirghizul": "kirghiz",
    "kirghizului": "kirghiz",
    "kithara": "kithară",
    "kitharistul": "kitharist",
    "K.O.": "Knock_Out",
    "Kr": "kripton",
    "kriptonul": "kripton",
    "kriptonului": "kripton",
    "kurda": "kurd",
    "kurdă": "kurd",
    "kurde": "kurd",
    "kurdei": "kurd",
    "kurdele": "kurd",
    "kurdelor": "kurd",
    "kurdo": "kurd",
    "kurdul": "kurd",
    "kurdule": "kurd",
    "kurdului": "kurd",
    "kurzi": "kurd",
    "kurzii": "kurd",
    "kurzilor": "kurd",
    "kurda": "kurdă",
    "kurde": "kurdă",
    "kurdei": "kurdă",
    "kurdele": "kurdă",
    "kurdelor": "kurdă",
    "kurdo": "kurdă",
    "laba": "labă",
    "labe": "labă",
    "labei": "labă",
    "labele": "labă",
    "labelor": "labă",
    "lăbărță": "lăbărța",
    "lăbărțai": "lăbărța",
    "lăbărțam": "lăbărța",
    "lăbărțăm": "lăbărța",
    "lăbărțând": "lăbărța",
    "lăbărțându": "lăbărța",
    "lăbărțară": "lăbărța",
    "lăbărțarăm": "lăbărța",
    "lăbărțarăți": "lăbărța",
    "lăbărțase": "lăbărța",
    "lăbărțasem": "lăbărța",
    "lăbărțaseră": "lăbărța",
    "lăbărțaserăm": "lăbărța",
    "lăbărțaserăți": "lăbărța",
    "lăbărțaseși": "lăbărța",
    "lăbărțași": "lăbărța",
    "lăbărțat": "lăbărța",
    "lăbărțați": "lăbărța",
    "lăbărțatu": "lăbărța",
    "lăbărțau": "lăbărța",
    "lăbărțează": "lăbărța",
    "lăbărțez": "lăbărța",
    "lăbărțeze": "lăbărța",
    "lăbărțezi": "lăbărța",
    "nelăbărțând": "lăbărța",
    "nelăbărțându": "lăbărța",
    "nemailăbărțând": "lăbărța",
    "nemailăbărțându": "lăbărța",
    "lăbărțată": "lăbărțat",
    "lăbărțate": "lăbărțat",
    "lăbărțați": "lăbărțat",
    "labializă": "labializa",
    "labializai": "labializa",
    "labializam": "labializa",
    "labializăm": "labializa",
    "labializând": "labializa",
    "labializându": "labializa",
    "labializară": "labializa",
    "labializarăm": "labializa",
    "labializarăți": "labializa",
    "labializase": "labializa",
    "labializasem": "labializa",
    "labializaseră": "labializa",
    "labializaserăm": "labializa",
    "labializaserăți": "labializa",
    "labializaseși": "labializa",
    "labializași": "labializa",
    "labializat": "labializa",
    "labializați": "labializa",
    "labializatu": "labializa",
    "labializau": "labializa",
    "labializează": "labializa",
    "labializez": "labializa",
    "labializeze": "labializa",
    "labializezi": "labializa",
    "nelabializând": "labializa",
    "nelabializându": "labializa",
    "nemailabializând": "labializa",
    "nemailabializându": "labializa",
    "labializată": "labializat",
    "labializate": "labializat",
    "labializați": "labializat",
    "labirintul": "labirint",
    "labirintului": "labirint",
    "labirinturi": "labirint",
    "labirinturile": "labirint",
    "labirinturilor": "labirint",
    "labirintica": "labirintic",
    "labirintică": "labirintic",
    "labirintice": "labirintic",
    "labirinticei": "labirintic",
    "labirinticele": "labirintic",
    "labirinticelor": "labirintic",
    "labirintici": "labirintic",
    "labirinticii": "labirintic",
    "labirinticilor": "labirintic",
    "labirintico": "labirintic",
    "labirinticul": "labirintic",
    "labirinticule": "labirintic",
    "labirinticului": "labirintic",
    "laboranți": "laborant",
    "laboranții": "laborant",
    "laboranților": "laborant",
    "laborantul": "laborant",
    "laborantului": "laborant",
    "laboratoare": "laborator",
    "laboratoarele": "laborator",
    "laboratoarelor": "laborator",
    "laboratorul": "laborator",
    "laboratorului": "laborator",
    "laborioasa": "laborios",
    "laborioasă": "laborios",
    "laborioase": "laborios",
    "laborioasei": "laborios",
    "laborioasele": "laborios",
    "laborioaselor": "laborios",
    "laborioși": "laborios",
    "laborioșii": "laborios",
    "laborioșilor": "laborios",
    "laboriosul": "laborios",
    "laboriosului": "laborios",
    "laburista": "laburist",
    "laburistă": "laburist",
    "laburiste": "laburist",
    "laburistei": "laburist",
    "laburistele": "laburist",
    "laburistelor": "laburist",
    "laburiști": "laburist",
    "laburiștii": "laburist",
    "laburiștilor": "laburist",
    "laburisto": "laburist",
    "laburistul": "laburist",
    "laburistule": "laburist",
    "laburistului": "laburist",
    "laburista": "laburistă",
    "laburiste": "laburistă",
    "laburistei": "laburistă",
    "laburistele": "laburistă",
    "laburistelor": "laburistă",
    "laburisto": "laburistă",
    "lacul": "lac",
    "lacului": "lac",
    "lacuri": "lac",
    "lacurile": "lac",
    "lacurilor": "lac",
    "lăcașul": "lăcaș",
    "lăcașule": "lăcaș",
    "lăcașului": "lăcaș",
    "lăcașuri": "lăcaș",
    "lăcașurile": "lăcaș",
    "lăcașurilor": "lăcaș",
    "lacăte": "lacăt",
    "lacătele": "lacăt",
    "lacătelor": "lacăt",
    "lacătul": "lacăt",
    "lacătului": "lacăt",
    "lăcătuși": "lăcătuș",
    "lăcătușii": "lăcătuș",
    "lăcătușilor": "lăcătuș",
    "lăcătușul": "lăcătuș",
    "lăcătușului": "lăcătuș",
    "lăcătușeria": "lăcătușerie",
    "lăcătușeriei": "lăcătușerie",
    "lăcătușerii": "lăcătușerie",
    "lăcătușeriile": "lăcătușerie",
    "lăcătușeriilor": "lăcătușerie",
    "lacedemonianul": "lacedemonian",
    "lacedemonianului": "lacedemonian",
    "lacedemonieni": "lacedemonian",
    "lacedemonienii": "lacedemonian",
    "lacedemonienilor": "lacedemonian",
    "lachei": "lacheu",
    "lacheii": "lacheu",
    "lacheilor": "lacheu",
    "lacheul": "lacheu",
    "lacheule": "lacheu",
    "lacheului": "lacheu",
    "lacoma": "lacom",
    "lacomă": "lacom",
    "lacome": "lacom",
    "lacomei": "lacom",
    "lacomele": "lacom",
    "lacomelor": "lacom",
    "lacomi": "lacom",
    "lacomii": "lacom",
    "lacomilor": "lacom",
    "lacomul": "lacom",
    "lacomului": "lacom",
    "lăcomea": "lăcomi",
    "lăcomeai": "lăcomi",
    "lăcomeam": "lăcomi",
    "lăcomească": "lăcomi",
    "lăcomeați": "lăcomi",
    "lăcomeau": "lăcomi",
    "lăcomesc": "lăcomi",
    "lăcomește": "lăcomi",
    "lăcomești": "lăcomi",
    "lăcomii": "lăcomi",
    "lăcomim": "lăcomi",
    "lăcomind": "lăcomi",
    "lăcomindu": "lăcomi",
    "lăcomiră": "lăcomi",
    "lăcomirăm": "lăcomi",
    "lăcomirăți": "lăcomi",
    "lăcomise": "lăcomi",
    "lăcomisem": "lăcomi",
    "lăcomiseră": "lăcomi",
    "lăcomiserăm": "lăcomi",
    "lăcomiserăți": "lăcomi",
    "lăcomiseși": "lăcomi",
    "lăcomiși": "lăcomi",
    "lăcomit": "lăcomi",
    "lăcomiți": "lăcomi",
    "lăcomitu": "lăcomi",
    "nelăcomind": "lăcomi",
    "nelăcomindu": "lăcomi",
    "nemailăcomind": "lăcomi",
    "nemailăcomindu": "lăcomi",
    "lăcomia": "lăcomie",
    "lăcomiei": "lăcomie",
    "lăcomii": "lăcomie",
    "lăcomiile": "lăcomie",
    "lăcomiilor": "lăcomie",
    "lăcomită": "lăcomit",
    "lăcomite": "lăcomit",
    "lăcomiți": "lăcomit",
    "laconica": "laconic",
    "laconică": "laconic",
    "laconice": "laconic",
    "laconicei": "laconic",
    "laconicele": "laconic",
    "laconicelor": "laconic",
    "laconici": "laconic",
    "laconicii": "laconic",
    "laconicilor": "laconic",
    "laconicul": "laconic",
    "laconicului": "laconic",
    "lacrima": "lacrimă",
    "lacrimi": "lacrimă",
    "lacrimii": "lacrimă",
    "lacrimile": "lacrimă",
    "lacrimilor": "lacrimă",
    "lăcrimă": "lăcrima",
    "lăcrimai": "lăcrima",
    "lăcrimam": "lăcrima",
    "lăcrimăm": "lăcrima",
    "lăcrimând": "lăcrima",
    "lăcrimându": "lăcrima",
    "lăcrimară": "lăcrima",
    "lăcrimarăm": "lăcrima",
    "lăcrimarăți": "lăcrima",
    "lăcrimase": "lăcrima",
    "lăcrimasem": "lăcrima",
    "lăcrimaseră": "lăcrima",
    "lăcrimaserăm": "lăcrima",
    "lăcrimaserăți": "lăcrima",
    "lăcrimaseși": "lăcrima",
    "lăcrimași": "lăcrima",
    "lăcrimat": "lăcrima",
    "lăcrimați": "lăcrima",
    "lăcrimatu": "lăcrima",
    "lăcrimau": "lăcrima",
    "lăcrimează": "lăcrima",
    "lăcrimez": "lăcrima",
    "lăcrimeze": "lăcrima",
    "lăcrimezi": "lăcrima",
    "nelăcrimând": "lăcrima",
    "nelăcrimându": "lăcrima",
    "nemailăcrimând": "lăcrima",
    "nemailăcrimându": "lăcrima",
    "lăcrimarea": "lăcrimare",
    "lăcrimareo": "lăcrimare",
    "lăcrimări": "lăcrimare",
    "lăcrimării": "lăcrimare",
    "lăcrimările": "lăcrimare",
    "lăcrimărilor": "lăcrimare",
    "lăcrimată": "lăcrimat",
    "lăcrimate": "lăcrimat",
    "lăcrimați": "lăcrimat",
    "lacrimogena": "lacrimogen",
    "lacrimogenă": "lacrimogen",
    "lacrimogene": "lacrimogen",
    "lacrimogenei": "lacrimogen",
    "lacrimogenele": "lacrimogen",
    "lacrimogenelor": "lacrimogen",
    "lacrimogeni": "lacrimogen",
    "lacrimogenii": "lacrimogen",
    "lacrimogenilor": "lacrimogen",
    "lacrimogenul": "lacrimogen",
    "lacrimogenului": "lacrimogen",
    "lactata": "lactat",
    "lactată": "lactat",
    "lactate": "lactat",
    "lactatei": "lactat",
    "lactatele": "lactat",
    "lactatelor": "lactat",
    "lactați": "lactat",
    "lactații": "lactat",
    "lactaților": "lactat",
    "lactatul": "lactat",
    "lactatului": "lactat",
    "lactobarul": "lactobar",
    "lactobarului": "lactobar",
    "lactobaruri": "lactobar",
    "lactobarurile": "lactobar",
    "lactobarurilor": "lactobar",
    "lacto-vegetariana": "lacto-vegetarian",
    "lacto-vegetariană": "lacto-vegetarian",
    "lacto-vegetarianul": "lacto-vegetarian",
    "lacto-vegetarianului": "lacto-vegetarian",
    "lacto-vegetariene": "lacto-vegetarian",
    "lacto-vegetarienei": "lacto-vegetarian",
    "lacto-vegetarienele": "lacto-vegetarian",
    "lacto-vegetarienelor": "lacto-vegetarian",
    "lacto-vegetarieni": "lacto-vegetarian",
    "lacto-vegetarienii": "lacto-vegetarian",
    "lacto-vegetarienilor": "lacto-vegetarian",
    "lăcuia": "lăcui",
    "lăcuiai": "lăcui",
    "lăcuiam": "lăcui",
    "lăcuiască": "lăcui",
    "lăcuiați": "lăcui",
    "lăcuiau": "lăcui",
    "lăcuiesc": "lăcui",
    "lăcuiește": "lăcui",
    "lăcuiești": "lăcui",
    "lăcuii": "lăcui",
    "lăcuim": "lăcui",
    "lăcuind": "lăcui",
    "lăcuindu": "lăcui",
    "lăcuiră": "lăcui",
    "lăcuirăm": "lăcui",
    "lăcuirăți": "lăcui",
    "lăcuise": "lăcui",
    "lăcuisem": "lăcui",
    "lăcuiseră": "lăcui",
    "lăcuiserăm": "lăcui",
    "lăcuiserăți": "lăcui",
    "lăcuiseși": "lăcui",
    "lăcuiși": "lăcui",
    "lăcuit": "lăcui",
    "lăcuiți": "lăcui",
    "lăcuitu": "lăcui",
    "nelăcuind": "lăcui",
    "nelăcuindu": "lăcui",
    "nemailăcuind": "lăcui",
    "nemailăcuindu": "lăcui",
    "lăcuită": "lăcuit",
    "lăcuite": "lăcuit",
    "lăcuiți": "lăcuit",
    "lacuna": "lacună",
    "lacune": "lacună",
    "lacunei": "lacună",
    "lacunele": "lacună",
    "lacunelor": "lacună",
    "lăcusta": "lăcustă",
    "lăcuste": "lăcustă",
    "lăcustei": "lăcustă",
    "lăcustele": "lăcustă",
    "lăcustelor": "lăcustă",
    "lăcusto": "lăcustă",
    "lada": "ladă",
    "lăzi": "ladă",
    "lăzii": "ladă",
    "lăzile": "ladă",
    "lăzilor": "ladă",
    "lădița": "lădiță",
    "lădițe": "lădiță",
    "lădiței": "lădiță",
    "lădițele": "lădiță",
    "lădițelor": "lădiță",
    "lădițo": "lădiță",
    "lăfăia": "lăfăi",
    "lăfăiai": "lăfăi",
    "lăfăiam": "lăfăi",
    "lăfăiască": "lăfăi",
    "lăfăiați": "lăfăi",
    "lăfăiau": "lăfăi",
    "lăfăie": "lăfăi",
    "lăfăiesc": "lăfăi",
    "lăfăiește": "lăfăi",
    "lăfăiești": "lăfăi",
    "lăfăii": "lăfăi",
    "lăfăim": "lăfăi",
    "lăfăind": "lăfăi",
    "lăfăindu": "lăfăi",
    "lăfăiră": "lăfăi",
    "lăfăirăm": "lăfăi",
    "lăfăirăți": "lăfăi",
    "lăfăise": "lăfăi",
    "lăfăisem": "lăfăi",
    "lăfăiseră": "lăfăi",
    "lăfăiserăm": "lăfăi",
    "lăfăiserăți": "lăfăi",
    "lăfăiseși": "lăfăi",
    "lăfăiși": "lăfăi",
    "lăfăit": "lăfăi",
    "lăfăiți": "lăfăi",
    "lăfăitu": "lăfăi",
    "nelăfăind": "lăfăi",
    "nelăfăindu": "lăfăi",
    "nemailăfăind": "lăfăi",
    "nemailăfăindu": "lăfăi",
    "lăfăită": "lăfăit",
    "lăfăite": "lăfăit",
    "lăfăiți": "lăfăit",
    "lagăre": "lagăr",
    "lagărele": "lagăr",
    "lagărelor": "lagăr",
    "lagărul": "lagăr",
    "lagărului": "lagăr",
    "lag.": "lagună",
    "laguna": "lagună",
    "lagune": "lagună",
    "lagunei": "lagună",
    "lagunele": "lagună",
    "lagunelor": "lagună",
    "laica": "laic",
    "laică": "laic",
    "laice": "laic",
    "laicei": "laic",
    "laicele": "laic",
    "laicelor": "laic",
    "laici": "laic",
    "laicii": "laic",
    "laicilor": "laic",
    "laicul": "laic",
    "laicului": "laic",
    "laiciză": "laiciza",
    "laicizai": "laiciza",
    "laicizam": "laiciza",
    "laicizăm": "laiciza",
    "laicizând": "laiciza",
    "laicizându": "laiciza",
    "laicizară": "laiciza",
    "laicizarăm": "laiciza",
    "laicizarăți": "laiciza",
    "laicizase": "laiciza",
    "laicizasem": "laiciza",
    "laicizaseră": "laiciza",
    "laicizaserăm": "laiciza",
    "laicizaserăți": "laiciza",
    "laicizaseși": "laiciza",
    "laicizași": "laiciza",
    "laicizat": "laiciza",
    "laicizați": "laiciza",
    "laicizatu": "laiciza",
    "laicizau": "laiciza",
    "laicizează": "laiciza",
    "laicizez": "laiciza",
    "laicizeze": "laiciza",
    "laicizezi": "laiciza",
    "nelaicizând": "laiciza",
    "nelaicizându": "laiciza",
    "nemailaicizând": "laiciza",
    "nemailaicizându": "laiciza",
    "laicizată": "laicizat",
    "laicizate": "laicizat",
    "laicizați": "laicizat",
    "laitmotivul": "laitmotiv",
    "laitmotivului": "laitmotiv",
    "laitmotivuri": "laitmotiv",
    "laitmotivurile": "laitmotiv",
    "laitmotivurilor": "laitmotiv",
    "lălăia": "lălăi",
    "lălăiai": "lălăi",
    "lălăiam": "lălăi",
    "lălăiască": "lălăi",
    "lălăiați": "lălăi",
    "lălăiau": "lălăi",
    "lălăiesc": "lălăi",
    "lălăiește": "lălăi",
    "lălăiești": "lălăi",
    "lălăii": "lălăi",
    "lălăim": "lălăi",
    "lălăind": "lălăi",
    "lălăindu": "lălăi",
    "lălăiră": "lălăi",
    "lălăirăm": "lălăi",
    "lălăirăți": "lălăi",
    "lălăise": "lălăi",
    "lălăisem": "lălăi",
    "lălăiseră": "lălăi",
    "lălăiserăm": "lălăi",
    "lălăiserăți": "lălăi",
    "lălăiseși": "lălăi",
    "lălăiși": "lălăi",
    "lălăit": "lălăi",
    "lălăiți": "lălăi",
    "lălăitu": "lălăi",
    "nelălăind": "lălăi",
    "nelălăindu": "lălăi",
    "nemailălăind": "lălăi",
    "nemailălăindu": "lălăi",
    "lălăită": "lălăit",
    "lălăite": "lălăit",
    "lălăiți": "lălăit",
    "laleaua": "lalea",
    "lalele": "lalea",
    "lalelei": "lalea",
    "lalelele": "lalea",
    "lalelelor": "lalea",
    "lama": "lamă",
    "lame": "lamă",
    "lamei": "lamă",
    "lamele": "lamă",
    "lamelor": "lamă",
    "lămâii": "lămâi",
    "lămâilor": "lămâi",
    "lămâiul": "lămâi",
    "lămâiului": "lămâi",
    "lămâi": "lămâie",
    "lămâia": "lămâie",
    "lămâii": "lămâie",
    "lămâile": "lămâie",
    "lămâilor": "lămâie",
    "lambrisă": "lambrisa",
    "lambrisai": "lambrisa",
    "lambrisam": "lambrisa",
    "lambrisăm": "lambrisa",
    "lambrisând": "lambrisa",
    "lambrisându": "lambrisa",
    "lambrisară": "lambrisa",
    "lambrisarăm": "lambrisa",
    "lambrisarăți": "lambrisa",
    "lambrisase": "lambrisa",
    "lambrisasem": "lambrisa",
    "lambrisaseră": "lambrisa",
    "lambrisaserăm": "lambrisa",
    "lambrisaserăți": "lambrisa",
    "lambrisaseși": "lambrisa",
    "lambrisași": "lambrisa",
    "lambrisat": "lambrisa",
    "lambrisați": "lambrisa",
    "lambrisatu": "lambrisa",
    "lambrisau": "lambrisa",
    "lambrisează": "lambrisa",
    "lambrisez": "lambrisa",
    "lambriseze": "lambrisa",
    "lambrisezi": "lambrisa",
    "nelambrisând": "lambrisa",
    "nelambrisându": "lambrisa",
    "nemailambrisând": "lambrisa",
    "nemailambrisându": "lambrisa",
    "lambrisată": "lambrisat",
    "lambrisate": "lambrisat",
    "lambrisați": "lambrisat",
    "lambriul": "lambriu",
    "lambriule": "lambriu",
    "lambriului": "lambriu",
    "lambriuri": "lambriu",
    "lambriurile": "lambriu",
    "lambriurilor": "lambriu",
    "lamela": "lamelă",
    "lamele": "lamelă",
    "lamelei": "lamelă",
    "lamelele": "lamelă",
    "lamelelor": "lamelă",
    "lamentă": "lamenta",
    "lamentai": "lamenta",
    "lamentam": "lamenta",
    "lamentăm": "lamenta",
    "lamentând": "lamenta",
    "lamentându": "lamenta",
    "lamentară": "lamenta",
    "lamentarăm": "lamenta",
    "lamentarăți": "lamenta",
    "lamentase": "lamenta",
    "lamentasem": "lamenta",
    "lamentaseră": "lamenta",
    "lamentaserăm": "lamenta",
    "lamentaserăți": "lamenta",
    "lamentaseși": "lamenta",
    "lamentași": "lamenta",
    "lamentat": "lamenta",
    "lamentați": "lamenta",
    "lamentatu": "lamenta",
    "lamentau": "lamenta",
    "lamentează": "lamenta",
    "lamentez": "lamenta",
    "lamenteze": "lamenta",
    "lamentezi": "lamenta",
    "nelamentând": "lamenta",
    "nelamentându": "lamenta",
    "nemailamentând": "lamenta",
    "nemailamentându": "lamenta",
    "lamentabila": "lamentabil",
    "lamentabilă": "lamentabil",
    "lamentabile": "lamentabil",
    "lamentabilei": "lamentabil",
    "lamentabilele": "lamentabil",
    "lamentabilelor": "lamentabil",
    "lamentabili": "lamentabil",
    "lamentabilii": "lamentabil",
    "lamentabililor": "lamentabil",
    "lamentabilul": "lamentabil",
    "lamentabilului": "lamentabil",
    "lamentarea": "lamentare",
    "lamentări": "lamentare",
    "lamentării": "lamentare",
    "lamentările": "lamentare",
    "lamentărilor": "lamentare",
    "lamentată": "lamentat",
    "lamentate": "lamentat",
    "lamentați": "lamentat",
    "lamină": "lamina",
    "laminai": "lamina",
    "laminam": "lamina",
    "laminăm": "lamina",
    "laminând": "lamina",
    "laminându": "lamina",
    "laminară": "lamina",
    "laminarăm": "lamina",
    "laminarăți": "lamina",
    "laminase": "lamina",
    "laminasem": "lamina",
    "laminaseră": "lamina",
    "laminaserăm": "lamina",
    "laminaserăți": "lamina",
    "laminaseși": "lamina",
    "laminași": "lamina",
    "laminat": "lamina",
    "laminați": "lamina",
    "laminatu": "lamina",
    "laminau": "lamina",
    "laminează": "lamina",
    "laminez": "lamina",
    "lamineze": "lamina",
    "laminezi": "lamina",
    "nelaminând": "lamina",
    "nelaminându": "lamina",
    "nemailaminând": "lamina",
    "nemailaminându": "lamina",
    "laminată": "laminat",
    "laminate": "laminat",
    "laminatele": "laminat",
    "laminatelor": "laminat",
    "laminați": "laminat",
    "laminatul": "laminat",
    "laminatului": "laminat",
    "laminoare": "laminor",
    "laminoarele": "laminor",
    "laminoarelor": "laminor",
    "laminorul": "laminor",
    "laminorului": "laminor",
    "lampa": "lampă",
    "lămpi": "lampă",
    "lămpii": "lampă",
    "lămpile": "lampă",
    "lămpilor": "lampă",
    "lampo": "lampă",
    "lampadare": "lampadar",
    "lampadarele": "lampadar",
    "lampadarelor": "lampadar",
    "lampadarul": "lampadar",
    "lampadarului": "lampadar",
    "lampanta": "lampant",
    "lampantă": "lampant",
    "lampante": "lampant",
    "lampantei": "lampant",
    "lampantele": "lampant",
    "lampantelor": "lampant",
    "lampanți": "lampant",
    "lampanții": "lampant",
    "lampanților": "lampant",
    "lampantul": "lampant",
    "lampantului": "lampant",
    "lampioane": "lampion",
    "lampioanele": "lampion",
    "lampioanelor": "lampion",
    "lampionul": "lampion",
    "lampionului": "lampion",
    "lamura": "lamură",
    "lamuri": "lamură",
    "lamurii": "lamură",
    "lămurea": "lămuri",
    "lămureai": "lămuri",
    "lămuream": "lămuri",
    "lămurească": "lămuri",
    "lămureați": "lămuri",
    "lămureau": "lămuri",
    "lămuresc": "lămuri",
    "lămurește": "lămuri",
    "lămurești": "lămuri",
    "lămurii": "lămuri",
    "lămurim": "lămuri",
    "lămurind": "lămuri",
    "lămurindu": "lămuri",
    "lămuriră": "lămuri",
    "lămurirăm": "lămuri",
    "lămurirăți": "lămuri",
    "lămurise": "lămuri",
    "lămurisem": "lămuri",
    "lămuriseră": "lămuri",
    "lămuriserăm": "lămuri",
    "lămuriserăți": "lămuri",
    "lămuriseși": "lămuri",
    "lămuriși": "lămuri",
    "lămurit": "lămuri",
    "lămuriți": "lămuri",
    "lămuritu": "lămuri",
    "nelămurind": "lămuri",
    "nelămurindu": "lămuri",
    "nemailămurind": "lămuri",
    "nemailămurindu": "lămuri",
    "lămurirea": "lămurire",
    "lămuriri": "lămurire",
    "lămuririi": "lămurire",
    "lămuririle": "lămurire",
    "lămuririlor": "lămurire",
    "lămurita": "lămurit",
    "lămurită": "lămurit",
    "lămurite": "lămurit",
    "lămuritei": "lămurit",
    "lămuritele": "lămurit",
    "lămuritelor": "lămurit",
    "lămuriți": "lămurit",
    "lămuriții": "lămurit",
    "lămuriților": "lămurit",
    "lămuritul": "lămurit",
    "lămuritului": "lămurit",
    "lanul": "lan",
    "lanului": "lan",
    "lanuri": "lan",
    "lanurile": "lan",
    "lanurilor": "lan",
    "lâna": "lână",
    "lâni": "lână",
    "lânii": "lână",
    "lânuri": "lână",
    "lânurile": "lână",
    "lânurilor": "lână",
    "lancea": "lance",
    "lănci": "lance",
    "lăncii": "lance",
    "lăncile": "lance",
    "lăncilor": "lance",
    "lânceda": "lânced",
    "lâncedă": "lânced",
    "lâncede": "lânced",
    "lâncedei": "lânced",
    "lâncedele": "lânced",
    "lâncedelor": "lânced",
    "lâncedo": "lânced",
    "lâncedul": "lânced",
    "lâncedule": "lânced",
    "lâncedului": "lânced",
    "lâncezi": "lânced",
    "lâncezii": "lânced",
    "lâncezilor": "lânced",
    "lâncezeala": "lâncezeală",
    "lâncezeli": "lâncezeală",
    "lâncezelii": "lâncezeală",
    "lâncezelile": "lâncezeală",
    "lâncezelilor": "lâncezeală",
    "lâncezea": "lâncezi",
    "lâncezeai": "lâncezi",
    "lâncezeam": "lâncezi",
    "lâncezească": "lâncezi",
    "lâncezeați": "lâncezi",
    "lâncezeau": "lâncezi",
    "lâncezesc": "lâncezi",
    "lâncezește": "lâncezi",
    "lâncezești": "lâncezi",
    "lâncezii": "lâncezi",
    "lâncezim": "lâncezi",
    "lâncezind": "lâncezi",
    "lâncezindu": "lâncezi",
    "lânceziră": "lâncezi",
    "lâncezirăm": "lâncezi",
    "lâncezirăți": "lâncezi",
    "lâncezise": "lâncezi",
    "lâncezisem": "lâncezi",
    "lânceziseră": "lâncezi",
    "lânceziserăm": "lâncezi",
    "lânceziserăți": "lâncezi",
    "lânceziseși": "lâncezi",
    "lânceziși": "lâncezi",
    "lâncezit": "lâncezi",
    "lânceziți": "lâncezi",
    "lâncezitu": "lâncezi",
    "nelâncezind": "lâncezi",
    "nelâncezindu": "lâncezi",
    "nemailâncezind": "lâncezi",
    "nemailâncezindu": "lâncezi",
    "lâncezită": "lâncezit",
    "lâncezite": "lâncezit",
    "lânceziți": "lâncezit",
    "landul": "land",
    "landule": "land",
    "landului": "land",
    "landuri": "land",
    "landurile": "land",
    "landurilor": "land",
    "languroasa": "languros",
    "languroasă": "languros",
    "languroase": "languros",
    "languroasei": "languros",
    "languroasele": "languros",
    "languroaselor": "languros",
    "languroși": "languros",
    "languroșii": "languros",
    "languroșilor": "languros",
    "langurosul": "languros",
    "langurosului": "languros",
    "lanolina": "lanolină",
    "lanoline": "lanolină",
    "lanolinei": "lanolină",
    "lanolinele": "lanolină",
    "lanolinelor": "lanolină",
    "lânoasa": "lânos",
    "lânoasă": "lânos",
    "lânoase": "lânos",
    "lânoasei": "lânos",
    "lânoasele": "lânos",
    "lânoaselor": "lânos",
    "lânoși": "lânos",
    "lânoșii": "lânos",
    "lânoșilor": "lânos",
    "lânosul": "lânos",
    "lânosului": "lânos",
    "lansă": "lansa",
    "lansai": "lansa",
    "lansam": "lansa",
    "lansăm": "lansa",
    "lansând": "lansa",
    "lansându": "lansa",
    "lansară": "lansa",
    "lansarăm": "lansa",
    "lansarăți": "lansa",
    "lansase": "lansa",
    "lansasem": "lansa",
    "lansaseră": "lansa",
    "lansaserăm": "lansa",
    "lansaserăți": "lansa",
    "lansaseși": "lansa",
    "lansași": "lansa",
    "lansat": "lansa",
    "lansați": "lansa",
    "lansatu": "lansa",
    "lansau": "lansa",
    "lansează": "lansa",
    "lansez": "lansa",
    "lanseze": "lansa",
    "lansezi": "lansa",
    "nelansând": "lansa",
    "nelansându": "lansa",
    "nemailansând": "lansa",
    "nemailansându": "lansa",
    "lansarea": "lansare",
    "lansări": "lansare",
    "lansării": "lansare",
    "lansările": "lansare",
    "lansărilor": "lansare",
    "lansată": "lansat",
    "lansate": "lansat",
    "lansați": "lansat",
    "lanțul": "lanț",
    "lanțului": "lanț",
    "lanțuri": "lanț",
    "lanțurile": "lanț",
    "lanțurilor": "lanț",
    "lanterna": "lanternă",
    "lanterne": "lanternă",
    "lanternei": "lanternă",
    "lanternele": "lanternă",
    "lanternelor": "lanternă",
    "lanțeta": "lanțetă",
    "lanțete": "lanțetă",
    "lanțetei": "lanțetă",
    "lanțetele": "lanțetă",
    "lanțetelor": "lanțetă",
    "lapidă": "lapida",
    "lapidai": "lapida",
    "lapidam": "lapida",
    "lapidăm": "lapida",
    "lapidând": "lapida",
    "lapidându": "lapida",
    "lapidară": "lapida",
    "lapidarăm": "lapida",
    "lapidarăți": "lapida",
    "lapidase": "lapida",
    "lapidasem": "lapida",
    "lapidaseră": "lapida",
    "lapidaserăm": "lapida",
    "lapidaserăți": "lapida",
    "lapidaseși": "lapida",
    "lapidași": "lapida",
    "lapidat": "lapida",
    "lapidați": "lapida",
    "lapidatu": "lapida",
    "lapidau": "lapida",
    "lapidează": "lapida",
    "lapidez": "lapida",
    "lapideze": "lapida",
    "lapidezi": "lapida",
    "nelapidând": "lapida",
    "nelapidându": "lapida",
    "nemailapidând": "lapida",
    "nemailapidându": "lapida",
    "lapidara": "lapidar",
    "lapidară": "lapidar",
    "lapidare": "lapidar",
    "lapidarei": "lapidar",
    "lapidarele": "lapidar",
    "lapidarelor": "lapidar",
    "lapidari": "lapidar",
    "lapidarii": "lapidar",
    "lapidarilor": "lapidar",
    "lapidarul": "lapidar",
    "lapidarului": "lapidar",
    "lapidată": "lapidat",
    "lapidate": "lapidat",
    "lapidați": "lapidat",
    "laponi": "lapon",
    "laponii": "lapon",
    "laponilor": "lapon",
    "laponul": "lapon",
    "laponului": "lapon",
    "lapovița": "lapoviță",
    "lapovițe": "lapoviță",
    "lapoviței": "lapoviță",
    "lapsusul": "lapsus",
    "lapsusului": "lapsus",
    "lapsusuri": "lapsus",
    "lapsusurile": "lapsus",
    "lapsusurilor": "lapsus",
    "lăptari": "lăptar",
    "lăptarii": "lăptar",
    "lăptarilor": "lăptar",
    "lăptarul": "lăptar",
    "lăptarului": "lăptar",
    "lăptăreasa": "lăptăreasă",
    "lăptărese": "lăptăreasă",
    "lăptăresei": "lăptăreasă",
    "lăptăresele": "lăptăreasă",
    "lăptăreselor": "lăptăreasă",
    "laptele": "lapte",
    "laptelui": "lapte",
    "lăpturi": "lapte",
    "lăpturile": "lapte",
    "lăpturilor": "lapte",
    "lăptoasa": "lăptos",
    "lăptoasă": "lăptos",
    "lăptoase": "lăptos",
    "lăptoasei": "lăptos",
    "lăptoasele": "lăptos",
    "lăptoaselor": "lăptos",
    "lăptoși": "lăptos",
    "lăptoșii": "lăptos",
    "lăptoșilor": "lăptos",
    "lăptosul": "lăptos",
    "lăptosului": "lăptos",
    "larga": "larg",
    "largă": "larg",
    "largi": "larg",
    "largii": "larg",
    "largile": "larg",
    "largilor": "larg",
    "largo": "larg",
    "largul": "larg",
    "largule": "larg",
    "largului": "larg",
    "larguri": "larg",
    "largurile": "larg",
    "largurilor": "larg",
    "lărgea": "lărgi",
    "lărgeai": "lărgi",
    "lărgeam": "lărgi",
    "lărgească": "lărgi",
    "lărgeați": "lărgi",
    "lărgeau": "lărgi",
    "lărgesc": "lărgi",
    "lărgește": "lărgi",
    "lărgești": "lărgi",
    "lărgii": "lărgi",
    "lărgim": "lărgi",
    "lărgind": "lărgi",
    "lărgindu": "lărgi",
    "lărgiră": "lărgi",
    "lărgirăm": "lărgi",
    "lărgirăți": "lărgi",
    "lărgise": "lărgi",
    "lărgisem": "lărgi",
    "lărgiseră": "lărgi",
    "lărgiserăm": "lărgi",
    "lărgiserăți": "lărgi",
    "lărgiseși": "lărgi",
    "lărgiși": "lărgi",
    "lărgit": "lărgi",
    "lărgiți": "lărgi",
    "lărgitu": "lărgi",
    "nelărgind": "lărgi",
    "nelărgindu": "lărgi",
    "nemailărgind": "lărgi",
    "nemailărgindu": "lărgi",
    "lărgimea": "lărgime",
    "lărgimi": "lărgime",
    "lărgimii": "lărgime",
    "lărgimile": "lărgime",
    "lărgimilor": "lărgime",
    "lărgirea": "lărgire",
    "lărgirii": "lărgire",
    "lărgită": "lărgit",
    "lărgite": "lărgit",
    "lărgiți": "lărgit",
    "laringele": "laringe",
    "laringelor": "laringe",
    "laringelui": "laringe",
    "laringita": "laringită",
    "laringite": "laringită",
    "laringitei": "laringită",
    "laringitele": "laringită",
    "laringitelor": "laringită",
    "larma": "larmă",
    "larme": "larmă",
    "larmei": "larmă",
    "larva": "larvă",
    "larve": "larvă",
    "larvei": "larvă",
    "larvele": "larvă",
    "larvelor": "larvă",
    "lașa": "laș",
    "lașă": "laș",
    "lașe": "laș",
    "lașei": "laș",
    "lașele": "laș",
    "lașelor": "laș",
    "lași": "laș",
    "lașii": "laș",
    "lașilor": "laș",
    "lașul": "laș",
    "lașului": "laș",
    "las": "lăsa",
    "las'": "lăsa",
    "lasă": "lăsa",
    "lăsă": "lăsa",
    "lăsai": "lăsa",
    "lăsam": "lăsa",
    "lăsăm": "lăsa",
    "lăsând": "lăsa",
    "lăsându": "lăsa",
    "lăsară": "lăsa",
    "lăsarăm": "lăsa",
    "lăsarăți": "lăsa",
    "lăsase": "lăsa",
    "lăsasem": "lăsa",
    "lăsaseră": "lăsa",
    "lăsaserăm": "lăsa",
    "lăsaserăți": "lăsa",
    "lăsaseși": "lăsa",
    "lăsași": "lăsa",
    "lăsat": "lăsa",
    "lăsați": "lăsa",
    "lăsatu": "lăsa",
    "lăsau": "lăsa",
    "lase": "lăsa",
    "lași": "lăsa",
    "nelăsând": "lăsa",
    "nelăsându": "lăsa",
    "nemailăsând": "lăsa",
    "nemailăsându": "lăsa",
    "lăsarea": "lăsare",
    "lăsareo": "lăsare",
    "lăsări": "lăsare",
    "lăsării": "lăsare",
    "lăsările": "lăsare",
    "lăsărilor": "lăsare",
    "lăsata": "lăsat",
    "lăsată": "lăsat",
    "lăsate": "lăsat",
    "lăsatei": "lăsat",
    "lăsatele": "lăsat",
    "lăsatelor": "lăsat",
    "lăsați": "lăsat",
    "lăsații": "lăsat",
    "lăsaților": "lăsat",
    "lăsatul": "lăsat",
    "lăsatului": "lăsat",
    "lasere": "laser",
    "laserele": "laser",
    "laserelor": "laser",
    "laserul": "laser",
    "laserule": "laser",
    "laserului": "laser",
    "lașitatea": "lașitate",
    "lașități": "lașitate",
    "lașității": "lașitate",
    "lașitățile": "lașitate",
    "lașităților": "lașitate",
    "lasoul": "lasou",
    "lasoului": "lasou",
    "lasouri": "lasou",
    "lasourile": "lasou",
    "lasourilor": "lasou",
    "lăstari": "lăstar",
    "lăstarii": "lăstar",
    "lăstarilor": "lăstar",
    "lăstarul": "lăstar",
    "lăstarului": "lăstar",
    "lăstărișul": "lăstăriș",
    "lăstărișule": "lăstăriș",
    "lăstărișului": "lăstăriș",
    "lăstărișuri": "lăstăriș",
    "lăstărișurile": "lăstăriș",
    "lăstărișurilor": "lăstăriș",
    "lata": "lat",
    "lată": "lat",
    "late": "lat",
    "latei": "lat",
    "latele": "lat",
    "latelor": "lat",
    "lați": "lat",
    "lații": "lat",
    "laților": "lat",
    "latul": "lat",
    "latului": "lat",
    "laturi": "lat",
    "laturile": "lat",
    "laturilor": "lat",
    "lațul": "laț",
    "lațului": "laț",
    "lațuri": "laț",
    "lațurile": "laț",
    "lațurilor": "laț",
    "latenta": "latent",
    "latentă": "latent",
    "latente": "latent",
    "latentei": "latent",
    "latentele": "latent",
    "latentelor": "latent",
    "latenți": "latent",
    "latenții": "latent",
    "latenților": "latent",
    "latentul": "latent",
    "latentului": "latent",
    "laterala": "lateral",
    "laterală": "lateral",
    "laterale": "lateral",
    "lateralei": "lateral",
    "lateralele": "lateral",
    "lateralelor": "lateral",
    "laterali": "lateral",
    "lateralii": "lateral",
    "lateralilor": "lateral",
    "lateralul": "lateral",
    "lateralului": "lateral",
    "lățea": "lăți",
    "lățeai": "lăți",
    "lățeam": "lăți",
    "lățească": "lăți",
    "lățeați": "lăți",
    "lățeau": "lăți",
    "lățesc": "lăți",
    "lățește": "lăți",
    "lățești": "lăți",
    "lății": "lăți",
    "lățim": "lăți",
    "lățind": "lăți",
    "lățindu": "lăți",
    "lățiră": "lăți",
    "lățirăm": "lăți",
    "lățirăți": "lăți",
    "lățise": "lăți",
    "lățisem": "lăți",
    "lățiseră": "lăți",
    "lățiserăm": "lăți",
    "lățiserăți": "lăți",
    "lățiseși": "lăți",
    "lățiși": "lăți",
    "lățit": "lăți",
    "lățiți": "lăți",
    "lățitu": "lăți",
    "nelățind": "lăți",
    "nelățindu": "lăți",
    "nemailățind": "lăți",
    "nemailățindu": "lăți",
    "latifundiari": "latifundiar",
    "latifundiarii": "latifundiar",
    "latifundiarilor": "latifundiar",
    "latifundiarul": "latifundiar",
    "latifundiarului": "latifundiar",
    "lățimea": "lățime",
    "lățimi": "lățime",
    "lățimii": "lățime",
    "lățimile": "lățime",
    "lățimilor": "lățime",
    "latina": "latin",
    "latină": "latin",
    "latine": "latin",
    "latinei": "latin",
    "latinele": "latin",
    "latinelor": "latin",
    "latini": "latin",
    "latinii": "latin",
    "latinilor": "latin",
    "latinul": "latin",
    "latinului": "latin",
    "lat.": "latină",
    "lat.med.": "latina_medievală",
    "lat.pop.": "latina_populară",
    "latinisme": "latinism",
    "latinismele": "latinism",
    "latinismelor": "latinism",
    "latinismul": "latinism",
    "latinismule": "latinism",
    "latinismului": "latinism",
    "latiniză": "latiniza",
    "latinizai": "latiniza",
    "latinizam": "latiniza",
    "latinizăm": "latiniza",
    "latinizând": "latiniza",
    "latinizându": "latiniza",
    "latinizară": "latiniza",
    "latinizarăm": "latiniza",
    "latinizarăți": "latiniza",
    "latinizase": "latiniza",
    "latinizasem": "latiniza",
    "latinizaseră": "latiniza",
    "latinizaserăm": "latiniza",
    "latinizaserăți": "latiniza",
    "latinizaseși": "latiniza",
    "latinizași": "latiniza",
    "latinizat": "latiniza",
    "latinizați": "latiniza",
    "latinizatu": "latiniza",
    "latinizau": "latiniza",
    "latinizează": "latiniza",
    "latinizez": "latiniza",
    "latinizeze": "latiniza",
    "latinizezi": "latiniza",
    "nelatinizând": "latiniza",
    "nelatinizându": "latiniza",
    "nemailatinizând": "latiniza",
    "nemailatinizându": "latiniza",
    "latinizată": "latinizat",
    "latinizate": "latinizat",
    "latinizați": "latinizat",
    "lățită": "lățit",
    "lățite": "lățit",
    "lățiți": "lățit",
    "latitudinea": "latitudine",
    "latitudini": "latitudine",
    "latitudinii": "latitudine",
    "latitudinile": "latitudine",
    "latitudinilor": "latitudine",
    "lățoasa": "lățos",
    "lățoasă": "lățos",
    "lățoase": "lățos",
    "lățoasei": "lățos",
    "lățoasele": "lățos",
    "lățoaselor": "lățos",
    "lățoși": "lățos",
    "lățoșii": "lățos",
    "lățoșilor": "lățos",
    "lățosul": "lățos",
    "lățosului": "lățos",
    "latră": "lătra",
    "lătră": "lătra",
    "lătrai": "lătra",
    "lătram": "lătra",
    "lătrăm": "lătra",
    "lătrând": "lătra",
    "lătrându": "lătra",
    "lătrară": "lătra",
    "lătrarăm": "lătra",
    "lătrarăți": "lătra",
    "lătrase": "lătra",
    "lătrasem": "lătra",
    "lătraseră": "lătra",
    "lătraserăm": "lătra",
    "lătraserăți": "lătra",
    "lătraseși": "lătra",
    "lătrași": "lătra",
    "lătrat": "lătra",
    "lătrați": "lătra",
    "lătratu": "lătra",
    "lătrau": "lătra",
    "latre": "lătra",
    "latri": "lătra",
    "latru": "lătra",
    "nelătrând": "lătra",
    "nelătrându": "lătra",
    "nemailătrând": "lătra",
    "nemailătrându": "lătra",
    "lătrarea": "lătrare",
    "lătrareo": "lătrare",
    "lătrări": "lătrare",
    "lătrării": "lătrare",
    "lătrările": "lătrare",
    "lătrărilor": "lătrare",
    "lătrată": "lătrat",
    "lătrate": "lătrat",
    "lătrați": "lătrat",
    "lătratul": "lătrat",
    "lătratului": "lătrat",
    "lătraturi": "lătrat",
    "lătraturile": "lătrat",
    "lătraturilor": "lătrat",
    "lătrătoare": "lătrător",
    "lătrătoarea": "lătrător",
    "lătrătoarei": "lătrător",
    "lătrătoarele": "lătrător",
    "lătrătoarelor": "lătrător",
    "lătrătoareo": "lătrător",
    "lătrători": "lătrător",
    "lătrătorii": "lătrător",
    "lătrătorilor": "lătrător",
    "lătrătorul": "lătrător",
    "lătrătorule": "lătrător",
    "lătrătorului": "lătrător",
    "lătrătura": "lătrătură",
    "lătrături": "lătrătură",
    "lătrăturii": "lătrătură",
    "lătrăturile": "lătrătură",
    "lătrăturilor": "lătrătură",
    "lătrăturo": "lătrătură",
    "latrina": "latrină",
    "latrine": "latrină",
    "latrinei": "latrină",
    "latrinele": "latrină",
    "latrinelor": "latrină",
    "latrino": "latrină",
    "latura": "latură",
    "laturi": "latură",
    "laturii": "latură",
    "laturile": "latură",
    "laturilor": "latură",
    "lăturalnica": "lăturalnic",
    "lăturalnică": "lăturalnic",
    "lăturalnice": "lăturalnic",
    "lăturalnicei": "lăturalnic",
    "lăturalnicele": "lăturalnic",
    "lăturalnicelor": "lăturalnic",
    "lăturalnici": "lăturalnic",
    "lăturalnicii": "lăturalnic",
    "lăturalnicilor": "lăturalnic",
    "lăturalnicul": "lăturalnic",
    "lăturalnicului": "lăturalnic",
    "lăturile": "lături",
    "lăturilor": "lături",
    "lauda": "laudă",
    "laude": "laudă",
    "laudei": "laudă",
    "laudele": "laudă",
    "laudelor": "laudă",
    "laud": "lăuda",
    "laudă": "lăuda",
    "lăudă": "lăuda",
    "lăudai": "lăuda",
    "lăudam": "lăuda",
    "lăudăm": "lăuda",
    "lăudând": "lăuda",
    "lăudându": "lăuda",
    "lăudară": "lăuda",
    "lăudarăm": "lăuda",
    "lăudarăți": "lăuda",
    "lăudase": "lăuda",
    "lăudasem": "lăuda",
    "lăudaseră": "lăuda",
    "lăudaserăm": "lăuda",
    "lăudaserăți": "lăuda",
    "lăudaseși": "lăuda",
    "lăudași": "lăuda",
    "lăudat": "lăuda",
    "lăudați": "lăuda",
    "lăudatu": "lăuda",
    "lăudau": "lăuda",
    "laude": "lăuda",
    "lauzi": "lăuda",
    "nelăudând": "lăuda",
    "nelăudându": "lăuda",
    "nemailăudând": "lăuda",
    "nemailăudându": "lăuda",
    "lăudabila": "lăudabil",
    "lăudabilă": "lăudabil",
    "lăudabile": "lăudabil",
    "lăudabilei": "lăudabil",
    "lăudabilele": "lăudabil",
    "lăudabilelor": "lăudabil",
    "lăudabili": "lăudabil",
    "lăudabilii": "lăudabil",
    "lăudabililor": "lăudabil",
    "lăudabilul": "lăudabil",
    "lăudabilului": "lăudabil",
    "lăudăroasa": "lăudăros",
    "lăudăroasă": "lăudăros",
    "lăudăroase": "lăudăros",
    "lăudăroasei": "lăudăros",
    "lăudăroasele": "lăudăros",
    "lăudăroaselor": "lăudăros",
    "lăudăroși": "lăudăros",
    "lăudăroșii": "lăudăros",
    "lăudăroșilor": "lăudăros",
    "lăudărosul": "lăudăros",
    "lăudărosului": "lăudăros",
    "lăudăroșenia": "lăudăroșenie",
    "lăudăroșeniei": "lăudăroșenie",
    "lăudăroșenii": "lăudăroșenie",
    "lăudăroșeniile": "lăudăroșenie",
    "lăudăroșeniilor": "lăudăroșenie",
    "lăudată": "lăudat",
    "lăudate": "lăudat",
    "lăudați": "lăudat",
    "lăudători": "lăudător",
    "lăudătorii": "lăudător",
    "lăudătorilor": "lăudător",
    "lăudătorul": "lăudător",
    "lăudătorului": "lăudător",
    "lăuntrica": "lăuntric",
    "lăuntrică": "lăuntric",
    "lăuntrice": "lăuntric",
    "lăuntricei": "lăuntric",
    "lăuntricele": "lăuntric",
    "lăuntricelor": "lăuntric",
    "lăuntrici": "lăuntric",
    "lăuntricii": "lăuntric",
    "lăuntricilor": "lăuntric",
    "lăuntricul": "lăuntric",
    "lăuntricului": "lăuntric",
    "lauri": "laur",
    "laurii": "laur",
    "laurilor": "laur",
    "laurul": "laur",
    "laurului": "laur",
    "laureați": "laureat",
    "laureații": "laureat",
    "laureaților": "laureat",
    "laureatul": "laureat",
    "laureatului": "laureat",
    "L.": "Laurențiu",
    "lăutari": "lăutar",
    "lăutarii": "lăutar",
    "lăutarilor": "lăutar",
    "lăutarul": "lăutar",
    "lăutarului": "lăutar",
    "lăuzea": "lăuzi",
    "lăuzeai": "lăuzi",
    "lăuzeam": "lăuzi",
    "lăuzească": "lăuzi",
    "lăuzeați": "lăuzi",
    "lăuzeau": "lăuzi",
    "lăuzesc": "lăuzi",
    "lăuzește": "lăuzi",
    "lăuzești": "lăuzi",
    "lăuzii": "lăuzi",
    "lăuzim": "lăuzi",
    "lăuzind": "lăuzi",
    "lăuzindu": "lăuzi",
    "lăuziră": "lăuzi",
    "lăuzirăm": "lăuzi",
    "lăuzirăți": "lăuzi",
    "lăuzise": "lăuzi",
    "lăuzisem": "lăuzi",
    "lăuziseră": "lăuzi",
    "lăuziserăm": "lăuzi",
    "lăuziserăți": "lăuzi",
    "lăuziseși": "lăuzi",
    "lăuziși": "lăuzi",
    "lăuzit": "lăuzi",
    "lăuziți": "lăuzi",
    "lăuzitu": "lăuzi",
    "nelăuzind": "lăuzi",
    "nelăuzindu": "lăuzi",
    "nemailăuzind": "lăuzi",
    "nemailăuzindu": "lăuzi",
    "lăuzită": "lăuzit",
    "lăuzite": "lăuzit",
    "lăuziți": "lăuzit",
    "lava": "lavă",
    "lave": "lavă",
    "lavei": "lavă",
    "lavele": "lavă",
    "lavelor": "lavă",
    "lavabila": "lavabil",
    "lavabilă": "lavabil",
    "lavabile": "lavabil",
    "lavabilei": "lavabil",
    "lavabilele": "lavabil",
    "lavabilelor": "lavabil",
    "lavabili": "lavabil",
    "lavabilii": "lavabil",
    "lavabililor": "lavabil",
    "lavabilul": "lavabil",
    "lavabilului": "lavabil",
    "lavaboul": "lavabou",
    "lavaboului": "lavabou",
    "lavabouri": "lavabou",
    "lavabourile": "lavabou",
    "lavabourilor": "lavabou",
    "lavița": "laviță",
    "lavițe": "laviță",
    "laviței": "laviță",
    "lavițele": "laviță",
    "lavițelor": "laviță",
    "lavoare": "lavoar",
    "lavoarele": "lavoar",
    "lavoarelor": "lavoar",
    "lavoarul": "lavoar",
    "lavoarului": "lavoar",
    "laxative": "laxativ",
    "laxativele": "laxativ",
    "laxativelor": "laxativ",
    "laxativul": "laxativ",
    "laxativului": "laxativ",
    "leacul": "leac",
    "leacului": "leac",
    "leacuri": "leac",
    "leacurile": "leac",
    "leacurilor": "leac",
    "leafa": "leafă",
    "lefi": "leafă",
    "lefii": "leafă",
    "lefuri": "leafă",
    "lefurile": "leafă",
    "lefurilor": "leafă",
    "leagăne": "leagăn",
    "leagănele": "leagăn",
    "leagănelor": "leagăn",
    "leagănul": "leagăn",
    "leagănului": "leagăn",
    "leala": "leal",
    "leală": "leal",
    "leale": "leal",
    "lealei": "leal",
    "lealele": "leal",
    "lealelor": "leal",
    "leali": "leal",
    "lealii": "leal",
    "lealilor": "leal",
    "lealul": "leal",
    "lealului": "leal",
    "lealitatea": "lealitate",
    "lealități": "lealitate",
    "lealității": "lealitate",
    "leatul": "leat",
    "leatului": "leat",
    "leaturi": "leat",
    "leaturile": "leat",
    "leaturilor": "leat",
    "leațul": "leaț",
    "leațului": "leaț",
    "leațuri": "leaț",
    "leațurile": "leaț",
    "leațurilor": "leaț",
    "lebăda": "lebădă",
    "lebede": "lebădă",
    "lebedei": "lebădă",
    "lebedele": "lebădă",
    "lebedelor": "lebădă",
    "lecția": "lecție",
    "lecției": "lecție",
    "lecții": "lecție",
    "lecțiile": "lecție",
    "lecțiilor": "lecție",
    "lectori": "lector",
    "lectorii": "lector",
    "lectorilor": "lector",
    "lectorul": "lector",
    "lectorului": "lector",
    "lectură": "lectura",
    "lecturai": "lectura",
    "lecturam": "lectura",
    "lecturăm": "lectura",
    "lecturând": "lectura",
    "lecturându": "lectura",
    "lecturară": "lectura",
    "lecturarăm": "lectura",
    "lecturarăți": "lectura",
    "lecturase": "lectura",
    "lecturasem": "lectura",
    "lecturaseră": "lectura",
    "lecturaserăm": "lectura",
    "lecturaserăți": "lectura",
    "lecturaseși": "lectura",
    "lecturași": "lectura",
    "lecturat": "lectura",
    "lecturați": "lectura",
    "lecturatu": "lectura",
    "lecturau": "lectura",
    "lecturează": "lectura",
    "lecturez": "lectura",
    "lectureze": "lectura",
    "lecturezi": "lectura",
    "nelecturând": "lectura",
    "nelecturându": "lectura",
    "nemailecturând": "lectura",
    "nemailecturându": "lectura",
    "lectura": "lectură",
    "lecturi": "lectură",
    "lecturii": "lectură",
    "lecturile": "lectură",
    "lecturilor": "lectură",
    "lecturată": "lecturat",
    "lecturate": "lecturat",
    "lecturați": "lecturat",
    "lecuia": "lecui",
    "lecuiai": "lecui",
    "lecuiam": "lecui",
    "lecuiască": "lecui",
    "lecuiați": "lecui",
    "lecuiau": "lecui",
    "lecuiesc": "lecui",
    "lecuiește": "lecui",
    "lecuiești": "lecui",
    "lecuii": "lecui",
    "lecuim": "lecui",
    "lecuind": "lecui",
    "lecuindu": "lecui",
    "lecuiră": "lecui",
    "lecuirăm": "lecui",
    "lecuirăți": "lecui",
    "lecuise": "lecui",
    "lecuisem": "lecui",
    "lecuiseră": "lecui",
    "lecuiserăm": "lecui",
    "lecuiserăți": "lecui",
    "lecuiseși": "lecui",
    "lecuiși": "lecui",
    "lecuit": "lecui",
    "lecuiți": "lecui",
    "lecuitu": "lecui",
    "nelecuind": "lecui",
    "nelecuindu": "lecui",
    "nemailecuind": "lecui",
    "nemailecuindu": "lecui",
    "lecuită": "lecuit",
    "lecuite": "lecuit",
    "lecuiți": "lecuit",
    "lefegii": "lefegiu",
    "lefegiii": "lefegiu",
    "lefegiilor": "lefegiu",
    "lefegiul": "lefegiu",
    "lefegiule": "lefegiu",
    "lefegiului": "lefegiu",
    "leftera": "lefter",
    "lefteră": "lefter",
    "leftere": "lefter",
    "lefterei": "lefter",
    "lefterele": "lefter",
    "lefterelor": "lefter",
    "lefteri": "lefter",
    "lefterii": "lefter",
    "lefterilor": "lefter",
    "lefterul": "lefter",
    "lefterului": "lefter",
    "lefterea": "lefteri",
    "leftereai": "lefteri",
    "lefteream": "lefteri",
    "lefterească": "lefteri",
    "leftereați": "lefteri",
    "leftereau": "lefteri",
    "lefteresc": "lefteri",
    "lefterește": "lefteri",
    "lefterești": "lefteri",
    "lefterii": "lefteri",
    "lefterim": "lefteri",
    "lefterind": "lefteri",
    "lefterindu": "lefteri",
    "lefteriră": "lefteri",
    "lefterirăm": "lefteri",
    "lefterirăți": "lefteri",
    "lefterise": "lefteri",
    "lefterisem": "lefteri",
    "lefteriseră": "lefteri",
    "lefteriserăm": "lefteri",
    "lefteriserăți": "lefteri",
    "lefteriseși": "lefteri",
    "lefteriși": "lefteri",
    "lefterit": "lefteri",
    "lefteriți": "lefteri",
    "lefteritu": "lefteri",
    "nelefterind": "lefteri",
    "nelefterindu": "lefteri",
    "nemailefterind": "lefteri",
    "nemailefterindu": "lefteri",
    "lefterită": "lefterit",
    "lefterite": "lefterit",
    "lefteriți": "lefterit",
    "leagă": "lega",
    "leg": "lega",
    "legă": "lega",
    "legai": "lega",
    "legam": "lega",
    "legăm": "lega",
    "legând": "lega",
    "legându": "lega",
    "legară": "lega",
    "legarăm": "lega",
    "legarăți": "lega",
    "legase": "lega",
    "legasem": "lega",
    "legaseră": "lega",
    "legaserăm": "lega",
    "legaserăți": "lega",
    "legaseși": "lega",
    "legași": "lega",
    "legat": "lega",
    "legați": "lega",
    "legatu": "lega",
    "legau": "lega",
    "lege": "lega",
    "legi": "lega",
    "nelegând": "lega",
    "nelegându": "lega",
    "nemailegând": "lega",
    "nemailegându": "lega",
    "legala": "legal",
    "legală": "legal",
    "legale": "legal",
    "legalei": "legal",
    "legalele": "legal",
    "legalelor": "legal",
    "legali": "legal",
    "legalii": "legal",
    "legalilor": "legal",
    "legalul": "legal",
    "legalului": "legal",
    "legalista": "legalist",
    "legalistă": "legalist",
    "legaliste": "legalist",
    "legalistei": "legalist",
    "legalistele": "legalist",
    "legalistelor": "legalist",
    "legaliști": "legalist",
    "legaliștii": "legalist",
    "legaliștilor": "legalist",
    "legalisto": "legalist",
    "legalistul": "legalist",
    "legalistule": "legalist",
    "legalistului": "legalist",
    "legalitatea": "legalitate",
    "legalități": "legalitate",
    "legalității": "legalitate",
    "legalitățile": "legalitate",
    "legalităților": "legalitate",
    "legaliză": "legaliza",
    "legalizai": "legaliza",
    "legalizam": "legaliza",
    "legalizăm": "legaliza",
    "legalizând": "legaliza",
    "legalizându": "legaliza",
    "legalizară": "legaliza",
    "legalizarăm": "legaliza",
    "legalizarăți": "legaliza",
    "legalizase": "legaliza",
    "legalizasem": "legaliza",
    "legalizaseră": "legaliza",
    "legalizaserăm": "legaliza",
    "legalizaserăți": "legaliza",
    "legalizaseși": "legaliza",
    "legalizași": "legaliza",
    "legalizat": "legaliza",
    "legalizați": "legaliza",
    "legalizatu": "legaliza",
    "legalizau": "legaliza",
    "legalizează": "legaliza",
    "legalizez": "legaliza",
    "legalizeze": "legaliza",
    "legalizezi": "legaliza",
    "nelegalizând": "legaliza",
    "nelegalizându": "legaliza",
    "nemailegalizând": "legaliza",
    "nemailegalizându": "legaliza",
    "legalizată": "legalizat",
    "legalizate": "legalizat",
    "legalizați": "legalizat",
    "leagănă": "legăna",
    "legăn": "legăna",
    "legănă": "legăna",
    "legănai": "legăna",
    "legănam": "legăna",
    "legănăm": "legăna",
    "legănând": "legăna",
    "legănându": "legăna",
    "legănară": "legăna",
    "legănarăm": "legăna",
    "legănarăți": "legăna",
    "legănase": "legăna",
    "legănasem": "legăna",
    "legănaseră": "legăna",
    "legănaserăm": "legăna",
    "legănaserăți": "legăna",
    "legănaseși": "legăna",
    "legănași": "legăna",
    "legănat": "legăna",
    "legănați": "legăna",
    "legănatu": "legăna",
    "legănau": "legăna",
    "legeni": "legăna",
    "nelegănând": "legăna",
    "nelegănându": "legăna",
    "nemailegănând": "legăna",
    "nemailegănându": "legăna",
    "legănarea": "legănare",
    "legănareo": "legănare",
    "legănări": "legănare",
    "legănării": "legănare",
    "legănările": "legănare",
    "legănărilor": "legănare",
    "legănata": "legănat",
    "legănată": "legănat",
    "legănate": "legănat",
    "legănatei": "legănat",
    "legănatele": "legănat",
    "legănatelor": "legănat",
    "legănați": "legănat",
    "legănații": "legănat",
    "legănaților": "legănat",
    "legănatul": "legănat",
    "legănatului": "legănat",
    "legată": "legat",
    "legate": "legat",
    "legați": "legat",
    "legatari": "legatar",
    "legatarii": "legatar",
    "legatarilor": "legatar",
    "legatarul": "legatar",
    "legatarului": "legatar",
    "legația": "legație",
    "legației": "legație",
    "legații": "legație",
    "legațiile": "legație",
    "legațiilor": "legație",
    "legătura": "legătură",
    "legături": "legătură",
    "legăturii": "legătură",
    "legăturile": "legătură",
    "legăturilor": "legătură",
    "l.": "lege",
    "legea": "lege",
    "legi": "lege",
    "legii": "lege",
    "legile": "lege",
    "legilor": "lege",
    "legenda": "legendă",
    "legende": "legendă",
    "legendei": "legendă",
    "legendele": "legendă",
    "legendelor": "legendă",
    "legendara": "legendar",
    "legendară": "legendar",
    "legendare": "legendar",
    "legendarei": "legendar",
    "legendarele": "legendar",
    "legendarelor": "legendar",
    "legendari": "legendar",
    "legendarii": "legendar",
    "legendarilor": "legendar",
    "legendarul": "legendar",
    "legendarului": "legendar",
    "legiferă": "legifera",
    "legiferai": "legifera",
    "legiferam": "legifera",
    "legiferăm": "legifera",
    "legiferând": "legifera",
    "legiferându": "legifera",
    "legiferară": "legifera",
    "legiferarăm": "legifera",
    "legiferarăți": "legifera",
    "legiferase": "legifera",
    "legiferasem": "legifera",
    "legiferaseră": "legifera",
    "legiferaserăm": "legifera",
    "legiferaserăți": "legifera",
    "legiferaseși": "legifera",
    "legiferași": "legifera",
    "legiferat": "legifera",
    "legiferați": "legifera",
    "legiferatu": "legifera",
    "legiferau": "legifera",
    "legiferează": "legifera",
    "legiferez": "legifera",
    "legifereze": "legifera",
    "legiferezi": "legifera",
    "nelegiferând": "legifera",
    "nelegiferându": "legifera",
    "nemailegiferând": "legifera",
    "nemailegiferându": "legifera",
    "legiferarea": "legiferare",
    "legiferării": "legiferare",
    "legiferată": "legiferat",
    "legiferate": "legiferat",
    "legiferați": "legiferat",
    "legionarismul": "legionarism",
    "legionarismului": "legionarism",
    "legislă": "legisla",
    "legislai": "legisla",
    "legislam": "legisla",
    "legislăm": "legisla",
    "legislând": "legisla",
    "legislându": "legisla",
    "legislară": "legisla",
    "legislarăm": "legisla",
    "legislarăți": "legisla",
    "legislase": "legisla",
    "legislasem": "legisla",
    "legislaseră": "legisla",
    "legislaserăm": "legisla",
    "legislaserăți": "legisla",
    "legislaseși": "legisla",
    "legislași": "legisla",
    "legislat": "legisla",
    "legislați": "legisla",
    "legislatu": "legisla",
    "legislau": "legisla",
    "legislează": "legisla",
    "legislez": "legisla",
    "legisleze": "legisla",
    "legislezi": "legisla",
    "nelegislând": "legisla",
    "nelegislându": "legisla",
    "nemailegislând": "legisla",
    "nemailegislându": "legisla",
    "legislată": "legislat",
    "legislate": "legislat",
    "legislați": "legislat",
    "legislația": "legislație",
    "legislației": "legislație",
    "legislații": "legislație",
    "legislațiile": "legislație",
    "legislațiilor": "legislație",
    "legislativa": "legislativ",
    "legislativă": "legislativ",
    "legislative": "legislativ",
    "legislativei": "legislativ",
    "legislativele": "legislativ",
    "legislativelor": "legislativ",
    "legislativi": "legislativ",
    "legislativii": "legislativ",
    "legislativilor": "legislativ",
    "legislativul": "legislativ",
    "legislativului": "legislativ",
    "legislatura": "legislatură",
    "legislaturi": "legislatură",
    "legislaturii": "legislatură",
    "legislaturile": "legislatură",
    "legislaturilor": "legislatură",
    "legislaturo": "legislatură",
    "legista": "legist",
    "legistă": "legist",
    "legiste": "legist",
    "legistei": "legist",
    "legistele": "legist",
    "legistelor": "legist",
    "legiști": "legist",
    "legiștii": "legist",
    "legiștilor": "legist",
    "legistul": "legist",
    "legistului": "legist",
    "legitatea": "legitate",
    "legitateo": "legitate",
    "legități": "legitate",
    "legității": "legitate",
    "legitățile": "legitate",
    "legităților": "legitate",
    "legitima": "legitim",
    "legitimă": "legitim",
    "legitime": "legitim",
    "legitimei": "legitim",
    "legitimele": "legitim",
    "legitimelor": "legitim",
    "legitimi": "legitim",
    "legitimii": "legitim",
    "legitimilor": "legitim",
    "legitimul": "legitim",
    "legitimului": "legitim",
    "legitimă": "legitima",
    "legitimai": "legitima",
    "legitimam": "legitima",
    "legitimăm": "legitima",
    "legitimând": "legitima",
    "legitimându": "legitima",
    "legitimară": "legitima",
    "legitimarăm": "legitima",
    "legitimarăți": "legitima",
    "legitimase": "legitima",
    "legitimasem": "legitima",
    "legitimaseră": "legitima",
    "legitimaserăm": "legitima",
    "legitimaserăți": "legitima",
    "legitimaseși": "legitima",
    "legitimași": "legitima",
    "legitimat": "legitima",
    "legitimați": "legitima",
    "legitimatu": "legitima",
    "legitimau": "legitima",
    "legitimează": "legitima",
    "legitimez": "legitima",
    "legitimeze": "legitima",
    "legitimezi": "legitima",
    "nelegitimând": "legitima",
    "nelegitimându": "legitima",
    "nemailegitimând": "legitima",
    "nemailegitimându": "legitima",
    "legitimarea": "legitimare",
    "legitimareo": "legitimare",
    "legitimări": "legitimare",
    "legitimării": "legitimare",
    "legitimările": "legitimare",
    "legitimărilor": "legitimare",
    "legitimată": "legitimat",
    "legitimate": "legitimat",
    "legitimați": "legitimat",
    "legitimația": "legitimație",
    "legitimației": "legitimație",
    "legitimații": "legitimație",
    "legitimațiile": "legitimație",
    "legitimațiilor": "legitimație",
    "legiuia": "legiui",
    "legiuiai": "legiui",
    "legiuiam": "legiui",
    "legiuiască": "legiui",
    "legiuiați": "legiui",
    "legiuiau": "legiui",
    "legiuiesc": "legiui",
    "legiuiește": "legiui",
    "legiuiești": "legiui",
    "legiuii": "legiui",
    "legiuim": "legiui",
    "legiuind": "legiui",
    "legiuindu": "legiui",
    "legiuiră": "legiui",
    "legiuirăm": "legiui",
    "legiuirăți": "legiui",
    "legiuise": "legiui",
    "legiuisem": "legiui",
    "legiuiseră": "legiui",
    "legiuiserăm": "legiui",
    "legiuiserăți": "legiui",
    "legiuiseși": "legiui",
    "legiuiși": "legiui",
    "legiuit": "legiui",
    "legiuiți": "legiui",
    "legiuitu": "legiui",
    "nelegiuind": "legiui",
    "nelegiuindu": "legiui",
    "nemailegiuind": "legiui",
    "nemailegiuindu": "legiui",
    "legiuirea": "legiuire",
    "legiuiri": "legiuire",
    "legiuirii": "legiuire",
    "legiuirile": "legiuire",
    "legiuirilor": "legiuire",
    "legiuita": "legiuit",
    "legiuită": "legiuit",
    "legiuite": "legiuit",
    "legiuitei": "legiuit",
    "legiuitele": "legiuit",
    "legiuitelor": "legiuit",
    "legiuiți": "legiuit",
    "legiuiții": "legiuit",
    "legiuiților": "legiuit",
    "legiuitul": "legiuit",
    "legiuitului": "legiuit",
    "legiuitoare": "legiuitor",
    "legiuitoarea": "legiuitor",
    "legiuitoarei": "legiuitor",
    "legiuitoarele": "legiuitor",
    "legiuitoarelor": "legiuitor",
    "legiuitori": "legiuitor",
    "legiuitorii": "legiuitor",
    "legiuitorilor": "legiuitor",
    "legiuitorul": "legiuitor",
    "legiuitorului": "legiuitor",
    "leguma": "legumă",
    "legume": "legumă",
    "legumei": "legumă",
    "legumele": "legumă",
    "legumelor": "legumă",
    "legumicultura": "legumicultură",
    "legumiculturi": "legumicultură",
    "legumiculturii": "legumicultură",
    "leguminoasa": "leguminos",
    "leguminoasă": "leguminos",
    "leguminoase": "leguminos",
    "leguminoasei": "leguminos",
    "leguminoasele": "leguminos",
    "leguminoaselor": "leguminos",
    "leguminoaso": "leguminos",
    "leguminoși": "leguminos",
    "leguminoșii": "leguminos",
    "leguminoșilor": "leguminos",
    "leguminosul": "leguminos",
    "leguminosule": "leguminos",
    "leguminosului": "leguminos",
    "lehămețea": "lehămeți",
    "lehămețeai": "lehămeți",
    "lehămețeam": "lehămeți",
    "lehămețească": "lehămeți",
    "lehămețeați": "lehămeți",
    "lehămețeau": "lehămeți",
    "lehămețesc": "lehămeți",
    "lehămețește": "lehămeți",
    "lehămețești": "lehămeți",
    "lehămeții": "lehămeți",
    "lehămețim": "lehămeți",
    "lehămețind": "lehămeți",
    "lehămețindu": "lehămeți",
    "lehămețiră": "lehămeți",
    "lehămețirăm": "lehămeți",
    "lehămețirăți": "lehămeți",
    "lehămețise": "lehămeți",
    "lehămețisem": "lehămeți",
    "lehămețiseră": "lehămeți",
    "lehămețiserăm": "lehămeți",
    "lehămețiserăți": "lehămeți",
    "lehămețiseși": "lehămeți",
    "lehămețiși": "lehămeți",
    "lehămețit": "lehămeți",
    "lehămețiți": "lehămeți",
    "lehămețitu": "lehămeți",
    "nelehămețind": "lehămeți",
    "nelehămețindu": "lehămeți",
    "nemailehămețind": "lehămeți",
    "nemailehămețindu": "lehămeți",
    "lehămetisea": "lehămetisi",
    "lehămetiseai": "lehămetisi",
    "lehămetiseam": "lehămetisi",
    "lehămetisească": "lehămetisi",
    "lehămetiseați": "lehămetisi",
    "lehămetiseau": "lehămetisi",
    "lehămetisesc": "lehămetisi",
    "lehămetisește": "lehămetisi",
    "lehămetisești": "lehămetisi",
    "lehămetisii": "lehămetisi",
    "lehămetisim": "lehămetisi",
    "lehămetisind": "lehămetisi",
    "lehămetisindu": "lehămetisi",
    "lehămetisiră": "lehămetisi",
    "lehămetisirăm": "lehămetisi",
    "lehămetisirăți": "lehămetisi",
    "lehămetisise": "lehămetisi",
    "lehămetisisem": "lehămetisi",
    "lehămetisiseră": "lehămetisi",
    "lehămetisiserăm": "lehămetisi",
    "lehămetisiserăți": "lehămetisi",
    "lehămetisiseși": "lehămetisi",
    "lehămetisiși": "lehămetisi",
    "lehămetisit": "lehămetisi",
    "lehămetisiți": "lehămetisi",
    "lehămetisitu": "lehămetisi",
    "nelehămetisind": "lehămetisi",
    "nelehămetisindu": "lehămetisi",
    "nemailehămetisind": "lehămetisi",
    "nemailehămetisindu": "lehămetisi",
    "lehămetisită": "lehămetisit",
    "lehămetisite": "lehămetisit",
    "lehămetisiți": "lehămetisit",
    "lehămețită": "lehămețit",
    "lehămețite": "lehămețit",
    "lehămețiți": "lehămețit",
    "leita": "leit",
    "leită": "leit",
    "leite": "leit",
    "leitei": "leit",
    "leitele": "leit",
    "leitelor": "leit",
    "leiți": "leit",
    "leiții": "leit",
    "leiților": "leit",
    "leitul": "leit",
    "leitului": "leit",
    "lejera": "lejer",
    "lejeră": "lejer",
    "lejere": "lejer",
    "lejerei": "lejer",
    "lejerele": "lejer",
    "lejerelor": "lejer",
    "lejeri": "lejer",
    "lejerii": "lejer",
    "lejerilor": "lejer",
    "lejerul": "lejer",
    "lejerului": "lejer",
    "lemne": "lemn",
    "lemnele": "lemn",
    "lemnelor": "lemn",
    "lemnul": "lemn",
    "lemnului": "lemn",
    "lemnăria": "lemnărie",
    "lemnăriei": "lemnărie",
    "lemnării": "lemnărie",
    "lemnăriile": "lemnărie",
    "lemnăriilor": "lemnărie",
    "lemnoasa": "lemnos",
    "lemnoasă": "lemnos",
    "lemnoase": "lemnos",
    "lemnoasei": "lemnos",
    "lemnoasele": "lemnos",
    "lemnoaselor": "lemnos",
    "lemnoși": "lemnos",
    "lemnoșii": "lemnos",
    "lemnoșilor": "lemnos",
    "lemnosul": "lemnos",
    "lemnosului": "lemnos",
    "lenea": "lene",
    "lenei": "lene",
    "leneșa": "leneș",
    "leneșă": "leneș",
    "leneșe": "leneș",
    "leneșei": "leneș",
    "leneșele": "leneș",
    "leneșelor": "leneș",
    "leneși": "leneș",
    "leneșii": "leneș",
    "leneșilor": "leneș",
    "leneșul": "leneș",
    "leneșului": "leneș",
    "lenevea": "lenevi",
    "leneveai": "lenevi",
    "leneveam": "lenevi",
    "lenevească": "lenevi",
    "leneveați": "lenevi",
    "leneveau": "lenevi",
    "lenevesc": "lenevi",
    "lenevește": "lenevi",
    "lenevești": "lenevi",
    "lenevii": "lenevi",
    "lenevim": "lenevi",
    "lenevind": "lenevi",
    "lenevindu": "lenevi",
    "leneviră": "lenevi",
    "lenevirăm": "lenevi",
    "lenevirăți": "lenevi",
    "lenevise": "lenevi",
    "lenevisem": "lenevi",
    "leneviseră": "lenevi",
    "leneviserăm": "lenevi",
    "leneviserăți": "lenevi",
    "leneviseși": "lenevi",
    "leneviși": "lenevi",
    "lenevit": "lenevi",
    "leneviți": "lenevi",
    "lenevitu": "lenevi",
    "nelenevind": "lenevi",
    "nelenevindu": "lenevi",
    "nemailenevind": "lenevi",
    "nemailenevindu": "lenevi",
    "lenevirea": "lenevire",
    "leneviri": "lenevire",
    "lenevirii": "lenevire",
    "lenevirile": "lenevire",
    "lenevirilor": "lenevire",
    "lenevită": "lenevit",
    "lenevite": "lenevit",
    "leneviți": "lenevit",
    "lenevoasa": "lenevos",
    "lenevoasă": "lenevos",
    "lenevoase": "lenevos",
    "lenevoasei": "lenevos",
    "lenevoasele": "lenevos",
    "lenevoaselor": "lenevos",
    "lenevoaso": "lenevos",
    "lenevoși": "lenevos",
    "lenevoșii": "lenevos",
    "lenevoșilor": "lenevos",
    "lenevosul": "lenevos",
    "lenevosule": "lenevos",
    "lenevosului": "lenevos",
    "leninismul": "leninism",
    "leninismului": "leninism",
    "leninista": "leninist",
    "leninistă": "leninist",
    "leniniste": "leninist",
    "leninistei": "leninist",
    "leninistele": "leninist",
    "leninistelor": "leninist",
    "leniniști": "leninist",
    "leniniștii": "leninist",
    "leniniștilor": "leninist",
    "leninistul": "leninist",
    "leninistului": "leninist",
    "lenjereasa": "lenjereasă",
    "lenjerese": "lenjereasă",
    "lenjeresei": "lenjereasă",
    "lenjeresele": "lenjereasă",
    "lenjereselor": "lenjereasă",
    "lenjeria": "lenjerie",
    "lenjeriei": "lenjerie",
    "lenjerii": "lenjerie",
    "lenjeriile": "lenjerie",
    "lenjeriilor": "lenjerie",
    "lenta": "lent",
    "lentă": "lent",
    "lente": "lent",
    "lentei": "lent",
    "lentele": "lent",
    "lentelor": "lent",
    "lenți": "lent",
    "lenții": "lent",
    "lenților": "lent",
    "lentul": "lent",
    "lentului": "lent",
    "lentila": "lentilă",
    "lentile": "lentilă",
    "lentilei": "lentilă",
    "lentilele": "lentilă",
    "lentilelor": "lentilă",
    "leoaica": "leoaică",
    "leoaice": "leoaică",
    "leoaicei": "leoaică",
    "leoaicele": "leoaică",
    "leoaicelor": "leoaică",
    "leonina": "leonin",
    "leonină": "leonin",
    "leonine": "leonin",
    "leoninei": "leonin",
    "leoninele": "leonin",
    "leoninelor": "leonin",
    "leonini": "leonin",
    "leoninii": "leonin",
    "leoninilor": "leonin",
    "leonino": "leonin",
    "leoninul": "leonin",
    "leoninule": "leonin",
    "leoninului": "leonin",
    "leopardul": "leopard",
    "leopardului": "leopard",
    "leoparzi": "leopard",
    "leoparzii": "leopard",
    "leoparzilor": "leopard",
    "leorcăia": "leorcăi",
    "leorcăiai": "leorcăi",
    "leorcăiam": "leorcăi",
    "leorcăiască": "leorcăi",
    "leorcăiați": "leorcăi",
    "leorcăiau": "leorcăi",
    "leorcăiesc": "leorcăi",
    "leorcăiește": "leorcăi",
    "leorcăiești": "leorcăi",
    "leorcăii": "leorcăi",
    "leorcăim": "leorcăi",
    "leorcăind": "leorcăi",
    "leorcăindu": "leorcăi",
    "leorcăiră": "leorcăi",
    "leorcăirăm": "leorcăi",
    "leorcăirăți": "leorcăi",
    "leorcăise": "leorcăi",
    "leorcăisem": "leorcăi",
    "leorcăiseră": "leorcăi",
    "leorcăiserăm": "leorcăi",
    "leorcăiserăți": "leorcăi",
    "leorcăiseși": "leorcăi",
    "leorcăiși": "leorcăi",
    "leorcăit": "leorcăi",
    "leorcăiți": "leorcăi",
    "leorcăitu": "leorcăi",
    "neleorcăind": "leorcăi",
    "neleorcăindu": "leorcăi",
    "nemaileorcăind": "leorcăi",
    "nemaileorcăindu": "leorcăi",
    "leorcăită": "leorcăit",
    "leorcăite": "leorcăit",
    "leorcăiți": "leorcăit",
    "leapădă": "lepăda",
    "lepăd": "lepăda",
    "lepădă": "lepăda",
    "lepădai": "lepăda",
    "lepădam": "lepăda",
    "lepădăm": "lepăda",
    "lepădând": "lepăda",
    "lepădându": "lepăda",
    "lepădară": "lepăda",
    "lepădarăm": "lepăda",
    "lepădarăți": "lepăda",
    "lepădase": "lepăda",
    "lepădasem": "lepăda",
    "lepădaseră": "lepăda",
    "lepădaserăm": "lepăda",
    "lepădaserăți": "lepăda",
    "lepădaseși": "lepăda",
    "lepădași": "lepăda",
    "lepădat": "lepăda",
    "lepădați": "lepăda",
    "lepădatu": "lepăda",
    "lepădau": "lepăda",
    "lepezi": "lepăda",
    "nelepădând": "lepăda",
    "nelepădându": "lepăda",
    "nemailepădând": "lepăda",
    "nemailepădându": "lepăda",
    "lepădarea": "lepădare",
    "lepădareo": "lepădare",
    "lepădări": "lepădare",
    "lepădării": "lepădare",
    "lepădările": "lepădare",
    "lepădărilor": "lepădare",
    "lepădată": "lepădat",
    "lepădate": "lepădat",
    "lepădați": "lepădat",
    "lepra": "lepră",
    "lepre": "lepră",
    "leprei": "lepră",
    "leprele": "lepră",
    "leprelor": "lepră",
    "leproasa": "lepros",
    "leproasă": "lepros",
    "leproase": "lepros",
    "leproasei": "lepros",
    "leproasele": "lepros",
    "leproaselor": "lepros",
    "leproși": "lepros",
    "leproșii": "lepros",
    "leproșilor": "lepros",
    "leprosul": "lepros",
    "leprosului": "lepros",
    "leșul": "leș",
    "leșului": "leș",
    "leșuri": "leș",
    "leșurile": "leș",
    "leșurilor": "leș",
    "lesa": "lesă",
    "lese": "lesă",
    "lesei": "lesă",
    "lesele": "lesă",
    "leselor": "lesă",
    "leso": "lesă",
    "leșia": "leșie",
    "leșiei": "leșie",
    "leșii": "leșie",
    "leșiile": "leșie",
    "leșiilor": "leșie",
    "leșinul": "leșin",
    "leșinului": "leșin",
    "leșinuri": "leșin",
    "leșinurile": "leșin",
    "leșinurilor": "leșin",
    "leșin": "leșina",
    "leșină": "leșina",
    "leșinai": "leșina",
    "leșinam": "leșina",
    "leșinăm": "leșina",
    "leșinând": "leșina",
    "leșinându": "leșina",
    "leșinară": "leșina",
    "leșinarăm": "leșina",
    "leșinarăți": "leșina",
    "leșinase": "leșina",
    "leșinasem": "leșina",
    "leșinaseră": "leșina",
    "leșinaserăm": "leșina",
    "leșinaserăți": "leșina",
    "leșinaseși": "leșina",
    "leșinași": "leșina",
    "leșinat": "leșina",
    "leșinați": "leșina",
    "leșinatu": "leșina",
    "leșinau": "leșina",
    "leșine": "leșina",
    "leșini": "leșina",
    "neleșinând": "leșina",
    "neleșinându": "leșina",
    "nemaileșinând": "leșina",
    "nemaileșinându": "leșina",
    "leșinată": "leșinat",
    "leșinate": "leșinat",
    "leșinați": "leșinat",
    "leșioasa": "leșios",
    "leșioasă": "leșios",
    "leșioase": "leșios",
    "leșioasei": "leșios",
    "leșioasele": "leșios",
    "leșioaselor": "leșios",
    "leșioaso": "leșios",
    "leșioși": "leșios",
    "leșioșii": "leșios",
    "leșioșilor": "leșios",
    "leșiosul": "leșios",
    "leșiosule": "leșios",
    "leșiosului": "leșios",
    "lesnicioasa": "lesnicios",
    "lesnicioasă": "lesnicios",
    "lesnicioase": "lesnicios",
    "lesnicioasei": "lesnicios",
    "lesnicioasele": "lesnicios",
    "lesnicioaselor": "lesnicios",
    "lesnicioși": "lesnicios",
    "lesnicioșii": "lesnicios",
    "lesnicioșilor": "lesnicios",
    "lesniciosul": "lesnicios",
    "lesniciosului": "lesnicios",
    "lespedea": "lespede",
    "lespezi": "lespede",
    "lespezii": "lespede",
    "lespezile": "lespede",
    "lespezilor": "lespede",
    "lestul": "lest",
    "lestului": "lest",
    "lesturi": "lest",
    "lesturile": "lest",
    "lesturilor": "lest",
    "letargia": "letargie",
    "letargiei": "letargie",
    "letargii": "letargie",
    "letargiile": "letargie",
    "letargiilor": "letargie",
    "lețcăi": "lețcaie",
    "lețcaia": "lețcaie",
    "lețcăii": "lețcaie",
    "lețcăile": "lețcaie",
    "lețcăilor": "lețcaie",
    "lețcaio": "lețcaie",
    "letoni": "leton",
    "letonii": "leton",
    "letonilor": "leton",
    "letonul": "leton",
    "letonului": "leton",
    "letopisețe": "letopiseț",
    "letopisețele": "letopiseț",
    "letopisețelor": "letopiseț",
    "letopisețul": "letopiseț",
    "letopisețului": "letopiseț",
    "lei": "leu",
    "leii": "leu",
    "leilor": "leu",
    "leul": "leu",
    "leului": "leu",
    "leucocita": "leucocită",
    "leucocite": "leucocită",
    "leucocitei": "leucocită",
    "leucocitele": "leucocită",
    "leucocitelor": "leucocită",
    "leucoplaste": "leucoplast",
    "leucoplastele": "leucoplast",
    "leucoplastelor": "leucoplast",
    "leucoplastul": "leucoplast",
    "leucoplastule": "leucoplast",
    "leucoplastului": "leucoplast",
    "lei-paralei": "leu-paraleu",
    "leușteanul": "leuștean",
    "leușteanului": "leuștean",
    "levănțica": "levănțică",
    "levănțici": "levănțică",
    "levănțicii": "levănțică",
    "levănțicile": "levănțică",
    "levănțicilor": "levănțică",
    "leviere": "levier",
    "levierele": "levier",
    "levierelor": "levier",
    "levierul": "levier",
    "levierului": "levier",
    "levitația": "levitație",
    "levitației": "levitație",
    "levitații": "levitație",
    "levitațiile": "levitație",
    "levitațiilor": "levitație",
    "levitațio": "levitație",
    "lexicul": "lexic",
    "lexicului": "lexic",
    "lexicuri": "lexic",
    "lexicurile": "lexic",
    "lexicurilor": "lexic",
    "lexicografia": "lexicografie",
    "lexicografiei": "lexicografie",
    "lexicografii": "lexicografie",
    "lexicografiile": "lexicografie",
    "lexicografiilor": "lexicografie",
    "lexicologi": "lexicolog",
    "lexicologii": "lexicolog",
    "lexicologilor": "lexicolog",
    "lexicologul": "lexicolog",
    "lexicologului": "lexicolog",
    "lexicologica": "lexicologic",
    "lexicologică": "lexicologic",
    "lexicologice": "lexicologic",
    "lexicologicei": "lexicologic",
    "lexicologicele": "lexicologic",
    "lexicologicelor": "lexicologic",
    "lexicologici": "lexicologic",
    "lexicologicii": "lexicologic",
    "lexicologicilor": "lexicologic",
    "lexicologicul": "lexicologic",
    "lexicologicului": "lexicologic",
    "lexicologia": "lexicologie",
    "lexicologiei": "lexicologie",
    "lexicologii": "lexicologie",
    "lexicoane": "lexicon",
    "lexicoanele": "lexicon",
    "lexicoanelor": "lexicon",
    "lexiconul": "lexicon",
    "lexiconului": "lexicon",
    "leză": "leza",
    "lezai": "leza",
    "lezam": "leza",
    "lezăm": "leza",
    "lezând": "leza",
    "lezându": "leza",
    "lezară": "leza",
    "lezarăm": "leza",
    "lezarăți": "leza",
    "lezase": "leza",
    "lezasem": "leza",
    "lezaseră": "leza",
    "lezaserăm": "leza",
    "lezaserăți": "leza",
    "lezaseși": "leza",
    "lezași": "leza",
    "lezat": "leza",
    "lezați": "leza",
    "lezatu": "leza",
    "lezau": "leza",
    "lezează": "leza",
    "lezez": "leza",
    "lezeze": "leza",
    "lezezi": "leza",
    "nelezând": "leza",
    "nelezându": "leza",
    "nemailezând": "leza",
    "nemailezându": "leza",
    "lezată": "lezat",
    "lezate": "lezat",
    "lezați": "lezat",
    "leziunea": "leziune",
    "leziuni": "leziune",
    "leziunii": "leziune",
    "leziunile": "leziune",
    "leziunilor": "leziune",
    "liana": "liană",
    "liane": "liană",
    "lianei": "liană",
    "lianele": "liană",
    "lianelor": "liană",
    "lianți": "liant",
    "lianții": "liant",
    "lianților": "liant",
    "liantul": "liant",
    "liantule": "liant",
    "liantului": "liant",
    "Libanul": "Liban",
    "Libanului": "Liban",
    "libaneză": "libanez",
    "libaneze": "libanez",
    "libanezi": "libanez",
    "libanezii": "libanez",
    "libanezilor": "libanez",
    "libanezul": "libanez",
    "libanezului": "libanez",
    "libaneza": "libaneză",
    "libaneze": "libaneză",
    "libanezei": "libaneză",
    "libanezele": "libaneză",
    "libanezelor": "libaneză",
    "libația": "libație",
    "libației": "libație",
    "libații": "libație",
    "libațiile": "libație",
    "libațiilor": "libație",
    "libelula": "libelulă",
    "libelule": "libelulă",
    "libelulei": "libelulă",
    "libelulele": "libelulă",
    "libelulelor": "libelulă",
    "libera": "liber",
    "liberă": "liber",
    "libere": "liber",
    "liberei": "liber",
    "liberele": "liber",
    "liberelor": "liber",
    "liberi": "liber",
    "liberii": "liber",
    "liberilor": "liber",
    "liberul": "liber",
    "liberului": "liber",
    "l.c.": "liber_citatus",
    "liberă": "libera",
    "liberai": "libera",
    "liberam": "libera",
    "liberăm": "libera",
    "liberând": "libera",
    "liberându": "libera",
    "liberară": "libera",
    "liberarăm": "libera",
    "liberarăți": "libera",
    "liberase": "libera",
    "liberasem": "libera",
    "liberaseră": "libera",
    "liberaserăm": "libera",
    "liberaserăți": "libera",
    "liberaseși": "libera",
    "liberași": "libera",
    "liberat": "libera",
    "liberați": "libera",
    "liberatu": "libera",
    "liberau": "libera",
    "liberează": "libera",
    "liberez": "libera",
    "libereze": "libera",
    "liberezi": "libera",
    "neliberând": "libera",
    "neliberându": "libera",
    "nemailiberând": "libera",
    "nemailiberându": "libera",
    "liberala": "liberal",
    "liberală": "liberal",
    "liberale": "liberal",
    "liberalei": "liberal",
    "liberalele": "liberal",
    "liberalelor": "liberal",
    "liberali": "liberal",
    "liberalii": "liberal",
    "liberalilor": "liberal",
    "liberalul": "liberal",
    "liberalului": "liberal",
    "liberalisme": "liberalism",
    "liberalismele": "liberalism",
    "liberalismelor": "liberalism",
    "liberalismul": "liberalism",
    "liberalismule": "liberalism",
    "liberalismului": "liberalism",
    "liberalizarea": "liberalizare",
    "liberalizări": "liberalizare",
    "liberalizata": "liberalizat",
    "liberalizată": "liberalizat",
    "liberalizate": "liberalizat",
    "liberalizatei": "liberalizat",
    "liberalizatele": "liberalizat",
    "liberalizatelor": "liberalizat",
    "liberalizați": "liberalizat",
    "liberalizații": "liberalizat",
    "liberalizaților": "liberalizat",
    "liberalizato": "liberalizat",
    "liberalizatul": "liberalizat",
    "liberalizatule": "liberalizat",
    "liberalizatului": "liberalizat",
    "liberată": "liberat",
    "liberate": "liberat",
    "liberați": "liberat",
    "liber-cugetători": "liber-cugetător",
    "liber-cugetătorii": "liber-cugetător",
    "liber-cugetătorilor": "liber-cugetător",
    "liber-cugetătorul": "liber-cugetător",
    "liber-cugetătorului": "liber-cugetător",
    "liber-profesionista": "liber-profesionist",
    "liber-profesionistă": "liber-profesionist",
    "liber-profesioniste": "liber-profesionist",
    "liber-profesionistei": "liber-profesionist",
    "liber-profesionistele": "liber-profesionist",
    "liber-profesionistelor": "liber-profesionist",
    "liber-profesioniști": "liber-profesionist",
    "liber-profesioniștii": "liber-profesionist",
    "liber-profesioniștilor": "liber-profesionist",
    "liber-profesionistul": "liber-profesionist",
    "liber-profesionistului": "liber-profesionist",
    "liber-schimbista": "liber-schimbist",
    "liber-schimbistă": "liber-schimbist",
    "liber-schimbiste": "liber-schimbist",
    "liber-schimbistei": "liber-schimbist",
    "liber-schimbistele": "liber-schimbist",
    "liber-schimbistelor": "liber-schimbist",
    "liber-schimbiști": "liber-schimbist",
    "liber-schimbiștii": "liber-schimbist",
    "liber-schimbiștilor": "liber-schimbist",
    "liber-schimbistul": "liber-schimbist",
    "liber-schimbistului": "liber-schimbist",
    "libertatea": "libertate",
    "libertăți": "libertate",
    "libertății": "libertate",
    "libertățile": "libertate",
    "libertăților": "libertate",
    "libidinoasa": "libidinos",
    "libidinoasă": "libidinos",
    "libidinoase": "libidinos",
    "libidinoasei": "libidinos",
    "libidinoasele": "libidinos",
    "libidinoaselor": "libidinos",
    "libidinoaso": "libidinos",
    "libidinoși": "libidinos",
    "libidinoșii": "libidinos",
    "libidinoșilor": "libidinos",
    "libidinosul": "libidinos",
    "libidinosule": "libidinos",
    "libidinosului": "libidinos",
    "librari": "librar",
    "librarii": "librar",
    "librarilor": "librar",
    "librarul": "librar",
    "librarului": "librar",
    "librăria": "librărie",
    "librăriei": "librărie",
    "librării": "librărie",
    "librăriile": "librărie",
    "librăriilor": "librărie",
    "librete": "libret",
    "libretele": "libret",
    "libretelor": "libret",
    "libretul": "libret",
    "libretului": "libret",
    "licăre": "licăr",
    "licărele": "licăr",
    "licărelor": "licăr",
    "licărul": "licăr",
    "licărule": "licăr",
    "licărului": "licăr",
    "licărea": "licări",
    "licăreai": "licări",
    "licăream": "licări",
    "licărească": "licări",
    "licăreați": "licări",
    "licăreau": "licări",
    "licăresc": "licări",
    "licărește": "licări",
    "licărești": "licări",
    "licării": "licări",
    "licărim": "licări",
    "licărind": "licări",
    "licărindu": "licări",
    "licăriră": "licări",
    "licărirăm": "licări",
    "licărirăți": "licări",
    "licărise": "licări",
    "licărisem": "licări",
    "licăriseră": "licări",
    "licăriserăm": "licări",
    "licăriserăți": "licări",
    "licăriseși": "licări",
    "licăriși": "licări",
    "licărit": "licări",
    "licăriți": "licări",
    "licăritu": "licări",
    "nelicărind": "licări",
    "nelicărindu": "licări",
    "nemailicărind": "licări",
    "nemailicărindu": "licări",
    "licărirea": "licărire",
    "licăriri": "licărire",
    "licăririi": "licărire",
    "licăririle": "licărire",
    "licăririlor": "licărire",
    "licărită": "licărit",
    "licărite": "licărit",
    "licăriți": "licărit",
    "liceala": "liceal",
    "liceală": "liceal",
    "liceale": "liceal",
    "licealei": "liceal",
    "licealele": "liceal",
    "licealelor": "liceal",
    "liceali": "liceal",
    "licealii": "liceal",
    "licealilor": "liceal",
    "licealo": "liceal",
    "licealul": "liceal",
    "licealule": "liceal",
    "licealului": "liceal",
    "liceana": "licean",
    "liceană": "licean",
    "liceano": "licean",
    "liceanul": "licean",
    "liceanule": "licean",
    "liceanului": "licean",
    "liceene": "licean",
    "liceenei": "licean",
    "liceenele": "licean",
    "liceenelor": "licean",
    "liceeni": "licean",
    "liceenii": "licean",
    "liceenilor": "licean",
    "licența": "licență",
    "licențe": "licență",
    "licenței": "licență",
    "licențele": "licență",
    "licențelor": "licență",
    "licențiai": "licenția",
    "licențiam": "licenția",
    "licențiară": "licenția",
    "licențiarăm": "licenția",
    "licențiarăți": "licenția",
    "licențiase": "licenția",
    "licențiasem": "licenția",
    "licențiaseră": "licenția",
    "licențiaserăm": "licenția",
    "licențiaserăți": "licenția",
    "licențiaseși": "licenția",
    "licențiași": "licenția",
    "licențiat": "licenția",
    "licențiați": "licenția",
    "licențiatu": "licenția",
    "licențiau": "licenția",
    "licențiază": "licenția",
    "licenție": "licenția",
    "licențiem": "licenția",
    "licențiez": "licenția",
    "licențieze": "licenția",
    "licențiezi": "licenția",
    "licențiind": "licenția",
    "licențiindu": "licenția",
    "nelicențiind": "licenția",
    "nelicențiindu": "licenția",
    "nemailicențiind": "licenția",
    "nemailicențiindu": "licenția",
    "licențiată": "licențiat",
    "licențiate": "licențiat",
    "licențiați": "licențiat",
    "licențiații": "licențiat",
    "licențiaților": "licențiat",
    "licențiatul": "licențiat",
    "licențiatului": "licențiat",
    "licee": "liceu",
    "liceele": "liceu",
    "liceelor": "liceu",
    "liceul": "liceu",
    "liceului": "liceu",
    "licheaua": "lichea",
    "lichele": "lichea",
    "lichelei": "lichea",
    "lichelele": "lichea",
    "lichelelor": "lichea",
    "lichefiata": "lichefiat",
    "lichefiată": "lichefiat",
    "lichefiate": "lichefiat",
    "lichefiatei": "lichefiat",
    "lichefiatele": "lichefiat",
    "lichefiatelor": "lichefiat",
    "lichefiați": "lichefiat",
    "lichefiații": "lichefiat",
    "lichefiaților": "lichefiat",
    "lichefiatul": "lichefiat",
    "lichefiatului": "lichefiat",
    "lichefierea": "lichefiere",
    "lichefiereo": "lichefiere",
    "lichefieri": "lichefiere",
    "lichefierii": "lichefiere",
    "lichefierile": "lichefiere",
    "lichefierilor": "lichefiere",
    "licheni": "lichen",
    "lichenii": "lichen",
    "lichenilor": "lichen",
    "lichenul": "lichen",
    "lichenului": "lichen",
    "lichida": "lichid",
    "lichidă": "lichid",
    "lichide": "lichid",
    "lichidei": "lichid",
    "lichidele": "lichid",
    "lichidelor": "lichid",
    "lichidul": "lichid",
    "lichidului": "lichid",
    "lichizi": "lichid",
    "lichizii": "lichid",
    "lichizilor": "lichid",
    "lichidă": "lichida",
    "lichidai": "lichida",
    "lichidam": "lichida",
    "lichidăm": "lichida",
    "lichidând": "lichida",
    "lichidându": "lichida",
    "lichidară": "lichida",
    "lichidarăm": "lichida",
    "lichidarăți": "lichida",
    "lichidase": "lichida",
    "lichidasem": "lichida",
    "lichidaseră": "lichida",
    "lichidaserăm": "lichida",
    "lichidaserăți": "lichida",
    "lichidaseși": "lichida",
    "lichidași": "lichida",
    "lichidat": "lichida",
    "lichidați": "lichida",
    "lichidatu": "lichida",
    "lichidau": "lichida",
    "lichidează": "lichida",
    "lichidez": "lichida",
    "lichideze": "lichida",
    "lichidezi": "lichida",
    "nelichidând": "lichida",
    "nelichidându": "lichida",
    "nemailichidând": "lichida",
    "nemailichidându": "lichida",
    "lichidarea": "lichidare",
    "lichidări": "lichidare",
    "lichidării": "lichidare",
    "lichidările": "lichidare",
    "lichidărilor": "lichidare",
    "lichidată": "lichidat",
    "lichidate": "lichidat",
    "lichidați": "lichidat",
    "lichidații": "lichidat",
    "lichidaților": "lichidat",
    "lichidatul": "lichidat",
    "lichidatului": "lichidat",
    "lichidități": "lichiditate",
    "lichiditățile": "lichiditate",
    "lichiorul": "lichior",
    "lichiorului": "lichior",
    "lichioruri": "lichior",
    "lichiorurile": "lichior",
    "lichiorurilor": "lichior",
    "licită": "licita",
    "licitai": "licita",
    "licitam": "licita",
    "licităm": "licita",
    "licitând": "licita",
    "licitându": "licita",
    "licitară": "licita",
    "licitarăm": "licita",
    "licitarăți": "licita",
    "licitase": "licita",
    "licitasem": "licita",
    "licitaseră": "licita",
    "licitaserăm": "licita",
    "licitaserăți": "licita",
    "licitaseși": "licita",
    "licitași": "licita",
    "licitat": "licita",
    "licitați": "licita",
    "licitatu": "licita",
    "licitau": "licita",
    "licitează": "licita",
    "licitez": "licita",
    "liciteze": "licita",
    "licitezi": "licita",
    "nelicitând": "licita",
    "nelicitându": "licita",
    "nemailicitând": "licita",
    "nemailicitându": "licita",
    "licitată": "licitat",
    "licitate": "licitat",
    "licitați": "licitat",
    "licitația": "licitație",
    "licitației": "licitație",
    "licitații": "licitație",
    "licitațiile": "licitație",
    "licitațiilor": "licitație",
    "licoarea": "licoare",
    "licoareo": "licoare",
    "licori": "licoare",
    "licorii": "licoare",
    "licorile": "licoare",
    "licorilor": "licoare",
    "licuricii": "licurici",
    "licuricilor": "licurici",
    "licuriciul": "licurici",
    "licuriciului": "licurici",
    "lideri": "lider",
    "liderii": "lider",
    "liderilor": "lider",
    "liderul": "lider",
    "liderului": "lider",
    "lidera": "lideră",
    "lidere": "lideră",
    "liderei": "lideră",
    "liderele": "lideră",
    "liderelor": "lideră",
    "lidero": "lideră",
    "liftul": "lift",
    "liftului": "lift",
    "lifturi": "lift",
    "lifturile": "lift",
    "lifturilor": "lift",
    "liftieri": "liftier",
    "liftierii": "liftier",
    "liftierilor": "liftier",
    "liftierul": "liftier",
    "liftierule": "liftier",
    "liftierului": "liftier",
    "liga": "ligă",
    "ligi": "ligă",
    "ligii": "ligă",
    "ligile": "ligă",
    "ligilor": "ligă",
    "ligamente": "ligament",
    "ligamentele": "ligament",
    "ligamentelor": "ligament",
    "ligamentul": "ligament",
    "ligamentului": "ligament",
    "ligheanul": "lighean",
    "ligheanului": "lighean",
    "lighene": "lighean",
    "lighenele": "lighean",
    "lighenelor": "lighean",
    "lighioana": "lighioană",
    "lighioane": "lighioană",
    "lighioanei": "lighioană",
    "lighioanele": "lighioană",
    "lighioanelor": "lighioană",
    "lignitul": "lignit",
    "lignitului": "lignit",
    "lihnita": "lihnit",
    "lihnită": "lihnit",
    "lihnite": "lihnit",
    "lihnitei": "lihnit",
    "lihnitele": "lihnit",
    "lihnitelor": "lihnit",
    "lihniți": "lihnit",
    "lihniții": "lihnit",
    "lihniților": "lihnit",
    "lihnitul": "lihnit",
    "lihnitului": "lihnit",
    "liliacul": "liliac",
    "liliacului": "liliac",
    "lilieci": "liliac",
    "liliecii": "liliac",
    "liliecilor": "liliac",
    "Lilianei": "Liliana",
    "limanul": "liman",
    "limanului": "liman",
    "limanuri": "liman",
    "limanurile": "liman",
    "limanurilor": "liman",
    "lb.": "limba",
    "limba": "limbă",
    "limbi": "limbă",
    "limbii": "limbă",
    "limbile": "limbă",
    "limbilor": "limbă",
    "limbaje": "limbaj",
    "limbajele": "limbaj",
    "limbajelor": "limbaj",
    "limbajul": "limbaj",
    "limbajului": "limbaj",
    "limbuta": "limbut",
    "limbută": "limbut",
    "limbute": "limbut",
    "limbutei": "limbut",
    "limbutele": "limbut",
    "limbutelor": "limbut",
    "limbuți": "limbut",
    "limbuții": "limbut",
    "limbuților": "limbut",
    "limbutul": "limbut",
    "limbutului": "limbut",
    "limfa": "limfă",
    "limfe": "limfă",
    "limfei": "limfă",
    "limfele": "limfă",
    "limfelor": "limfă",
    "limită": "limita",
    "limitai": "limita",
    "limitam": "limita",
    "limităm": "limita",
    "limitând": "limita",
    "limitându": "limita",
    "limitară": "limita",
    "limitarăm": "limita",
    "limitarăți": "limita",
    "limitase": "limita",
    "limitasem": "limita",
    "limitaseră": "limita",
    "limitaserăm": "limita",
    "limitaserăți": "limita",
    "limitaseși": "limita",
    "limitași": "limita",
    "limitat": "limita",
    "limitați": "limita",
    "limitatu": "limita",
    "limitau": "limita",
    "limitează": "limita",
    "limitez": "limita",
    "limiteze": "limita",
    "limitezi": "limita",
    "nelimitând": "limita",
    "nelimitându": "limita",
    "nemailimitând": "limita",
    "nemailimitându": "limita",
    "limita": "limită",
    "limite": "limită",
    "limitei": "limită",
    "limitele": "limită",
    "limitelor": "limită",
    "limitarea": "limitare",
    "limitări": "limitare",
    "limitării": "limitare",
    "limitările": "limitare",
    "limitărilor": "limitare",
    "limitata": "limitat",
    "limitată": "limitat",
    "limitate": "limitat",
    "limitatei": "limitat",
    "limitatele": "limitat",
    "limitatelor": "limitat",
    "limitați": "limitat",
    "limitații": "limitat",
    "limitaților": "limitat",
    "limitatul": "limitat",
    "limitatului": "limitat",
    "limitrofa": "limitrof",
    "limitrofă": "limitrof",
    "limitrofe": "limitrof",
    "limitrofei": "limitrof",
    "limitrofele": "limitrof",
    "limitrofelor": "limitrof",
    "limitrofi": "limitrof",
    "limitrofii": "limitrof",
    "limitrofilor": "limitrof",
    "limitroful": "limitrof",
    "limitrofului": "limitrof",
    "limonada": "limonadă",
    "limonade": "limonadă",
    "limonadei": "limonadă",
    "limonadele": "limonadă",
    "limonadelor": "limonadă",
    "limpedea": "limpede",
    "limpedele": "limpede",
    "limpedelui": "limpede",
    "limpezi": "limpede",
    "limpezii": "limpede",
    "limpezile": "limpede",
    "limpezilor": "limpede",
    "limpezea": "limpezi",
    "limpezeai": "limpezi",
    "limpezeam": "limpezi",
    "limpezească": "limpezi",
    "limpezeați": "limpezi",
    "limpezeau": "limpezi",
    "limpezesc": "limpezi",
    "limpezește": "limpezi",
    "limpezești": "limpezi",
    "limpezii": "limpezi",
    "limpezim": "limpezi",
    "limpezind": "limpezi",
    "limpezindu": "limpezi",
    "limpeziră": "limpezi",
    "limpezirăm": "limpezi",
    "limpezirăți": "limpezi",
    "limpezise": "limpezi",
    "limpezisem": "limpezi",
    "limpeziseră": "limpezi",
    "limpeziserăm": "limpezi",
    "limpeziserăți": "limpezi",
    "limpeziseși": "limpezi",
    "limpeziși": "limpezi",
    "limpezit": "limpezi",
    "limpeziți": "limpezi",
    "limpezitu": "limpezi",
    "nelimpezind": "limpezi",
    "nelimpezindu": "limpezi",
    "nemailimpezind": "limpezi",
    "nemailimpezindu": "limpezi",
    "limpezimea": "limpezime",
    "limpezimeo": "limpezime",
    "limpezimi": "limpezime",
    "limpezimii": "limpezime",
    "limpezimile": "limpezime",
    "limpezimilor": "limpezime",
    "limpezirea": "limpezire",
    "limpeziri": "limpezire",
    "limpezirii": "limpezire",
    "limpezirile": "limpezire",
    "limpezirilor": "limpezire",
    "limpezită": "limpezit",
    "limpezite": "limpezit",
    "limpeziți": "limpezit",
    "limuzina": "limuzină",
    "limuzine": "limuzină",
    "limuzinele": "limuzină",
    "limuzinelor": "limuzină",
    "lina": "lin",
    "lină": "lin",
    "line": "lin",
    "linei": "lin",
    "linele": "lin",
    "linelor": "lin",
    "lini": "lin",
    "linii": "lin",
    "linilor": "lin",
    "linul": "lin",
    "linului": "lin",
    "lineara": "linear",
    "lineară": "linear",
    "lineare": "linear",
    "linearei": "linear",
    "linearele": "linear",
    "linearelor": "linear",
    "lineari": "linear",
    "linearii": "linear",
    "linearilor": "linear",
    "linearo": "linear",
    "linearul": "linear",
    "linearule": "linear",
    "linearului": "linear",
    "ling": "linge",
    "lingă": "linge",
    "lingând": "linge",
    "lingându": "linge",
    "lingea": "linge",
    "lingeai": "linge",
    "lingeam": "linge",
    "lingeați": "linge",
    "lingeau": "linge",
    "lingem": "linge",
    "lingeți": "linge",
    "lingi": "linge",
    "lins": "linge",
    "linse": "linge",
    "linsei": "linge",
    "linseră": "linge",
    "linserăm": "linge",
    "linserăți": "linge",
    "linsese": "linge",
    "linsesem": "linge",
    "linseseră": "linge",
    "linseserăm": "linge",
    "linseserăți": "linge",
    "linseseși": "linge",
    "linseși": "linge",
    "linsu": "linge",
    "nelingând": "linge",
    "nelingându": "linge",
    "nemailingând": "linge",
    "nemailingându": "linge",
    "lingoul": "lingou",
    "lingoului": "lingou",
    "lingouri": "lingou",
    "lingourile": "lingou",
    "lingourilor": "lingou",
    "lingura": "lingură",
    "linguri": "lingură",
    "lingurii": "lingură",
    "lingurile": "lingură",
    "lingurilor": "lingură",
    "lingurița": "linguriță",
    "lingurițe": "linguriță",
    "linguriței": "linguriță",
    "lingurițele": "linguriță",
    "lingurițelor": "linguriță",
    "lingușeala": "lingușeală",
    "lingușeli": "lingușeală",
    "lingușelii": "lingușeală",
    "lingușelile": "lingușeală",
    "lingușelilor": "lingușeală",
    "lingușea": "linguși",
    "lingușeai": "linguși",
    "lingușeam": "linguși",
    "lingușească": "linguși",
    "lingușeați": "linguși",
    "lingușeau": "linguși",
    "lingușesc": "linguși",
    "lingușește": "linguși",
    "lingușești": "linguși",
    "lingușii": "linguși",
    "lingușim": "linguși",
    "lingușind": "linguși",
    "lingușindu": "linguși",
    "lingușiră": "linguși",
    "lingușirăm": "linguși",
    "lingușirăți": "linguși",
    "lingușise": "linguși",
    "lingușisem": "linguși",
    "lingușiseră": "linguși",
    "lingușiserăm": "linguși",
    "lingușiserăți": "linguși",
    "lingușiseși": "linguși",
    "lingușiși": "linguși",
    "lingușit": "linguși",
    "lingușiți": "linguși",
    "lingușitu": "linguși",
    "nelingușind": "linguși",
    "nelingușindu": "linguși",
    "nemailingușind": "linguși",
    "nemailingușindu": "linguși",
    "lingușirea": "lingușire",
    "lingușiri": "lingușire",
    "lingușirii": "lingușire",
    "lingușirile": "lingușire",
    "lingușirilor": "lingușire",
    "lingușită": "lingușit",
    "lingușite": "lingușit",
    "lingușiți": "lingușit",
    "lingușitori": "lingușitor",
    "lingușitorii": "lingușitor",
    "lingușitorilor": "lingușitor",
    "lingușitorul": "lingușitor",
    "lingușitorului": "lingușitor",
    "lingviști": "lingvist",
    "lingviștii": "lingvist",
    "lingviștilor": "lingvist",
    "lingvistul": "lingvist",
    "lingvistului": "lingvist",
    "lingvistica": "lingvistic",
    "lingvistică": "lingvistic",
    "lingvistice": "lingvistic",
    "lingvisticei": "lingvistic",
    "lingvisticele": "lingvistic",
    "lingvisticelor": "lingvistic",
    "lingvistici": "lingvistic",
    "lingvisticii": "lingvistic",
    "lingvisticilor": "lingvistic",
    "lingvisticul": "lingvistic",
    "lingvisticului": "lingvistic",
    "lingv.": "lingvistică",
    "lingvistica": "lingvistică",
    "lingvisticele": "lingvistică",
    "lingvistici": "lingvistică",
    "lingvisticii": "lingvistică",
    "lingvisticilor": "lingvistică",
    "liniai": "linia",
    "liniam": "linia",
    "liniară": "linia",
    "liniarăm": "linia",
    "liniarăți": "linia",
    "liniase": "linia",
    "liniasem": "linia",
    "liniaseră": "linia",
    "liniaserăm": "linia",
    "liniaserăți": "linia",
    "liniaseși": "linia",
    "liniași": "linia",
    "liniat": "linia",
    "liniați": "linia",
    "liniatu": "linia",
    "liniau": "linia",
    "liniază": "linia",
    "linie": "linia",
    "liniem": "linia",
    "liniez": "linia",
    "linieze": "linia",
    "liniezi": "linia",
    "liniind": "linia",
    "liniindu": "linia",
    "neliniind": "linia",
    "neliniindu": "linia",
    "nemailiniind": "linia",
    "nemailiniindu": "linia",
    "liniată": "liniat",
    "liniate": "liniat",
    "liniați": "liniat",
    "linia": "linie",
    "liniei": "linie",
    "linii": "linie",
    "liniile": "linie",
    "liniilor": "linie",
    "linioara": "linioară",
    "linioare": "linioară",
    "linioarei": "linioară",
    "linioarele": "linioară",
    "linioarelor": "linioară",
    "liniștea": "liniște",
    "liniști": "liniște",
    "liniștii": "liniște",
    "liniștile": "liniște",
    "liniștilor": "liniște",
    "liniștea": "liniști",
    "linișteai": "liniști",
    "linișteam": "liniști",
    "liniștească": "liniști",
    "linișteați": "liniști",
    "linișteau": "liniști",
    "liniștesc": "liniști",
    "liniștește": "liniști",
    "liniștești": "liniști",
    "liniștii": "liniști",
    "liniștim": "liniști",
    "liniștind": "liniști",
    "liniștindu": "liniști",
    "liniștiră": "liniști",
    "liniștirăm": "liniști",
    "liniștirăți": "liniști",
    "liniștise": "liniști",
    "liniștisem": "liniști",
    "liniștiseră": "liniști",
    "liniștiserăm": "liniști",
    "liniștiserăți": "liniști",
    "liniștiseși": "liniști",
    "liniștiși": "liniști",
    "liniștit": "liniști",
    "liniștiți": "liniști",
    "liniștitu": "liniști",
    "neliniștind": "liniști",
    "neliniștindu": "liniști",
    "nemailiniștind": "liniști",
    "nemailiniștindu": "liniști",
    "liniștirea": "liniștire",
    "liniștireo": "liniștire",
    "liniștiri": "liniștire",
    "liniștirii": "liniștire",
    "liniștirile": "liniștire",
    "liniștirilor": "liniștire",
    "liniștita": "liniștit",
    "liniștită": "liniștit",
    "liniștite": "liniștit",
    "liniștitei": "liniștit",
    "liniștitele": "liniștit",
    "liniștitelor": "liniștit",
    "liniștiți": "liniștit",
    "liniștiții": "liniștit",
    "liniștiților": "liniștit",
    "liniștitul": "liniștit",
    "liniștitului": "liniștit",
    "liniștitoare": "liniștitor",
    "liniștitoarea": "liniștitor",
    "liniștitoarei": "liniștitor",
    "liniștitoarele": "liniștitor",
    "liniștitoarelor": "liniștitor",
    "liniștitoareo": "liniștitor",
    "liniștitori": "liniștitor",
    "liniștitorii": "liniștitor",
    "liniștitorilor": "liniștitor",
    "liniștitorul": "liniștitor",
    "liniștitorule": "liniștitor",
    "liniștitorului": "liniștitor",
    "liniuța": "liniuță",
    "liniuțe": "liniuță",
    "liniuței": "liniuță",
    "liniuțele": "liniuță",
    "liniuțelor": "liniuță",
    "linoleumul": "linoleum",
    "linoleumului": "linoleum",
    "linoleumuri": "linoleum",
    "linoleumurile": "linoleum",
    "linoleumurilor": "linoleum",
    "linotipul": "linotip",
    "linotipule": "linotip",
    "linotipului": "linotip",
    "linotipuri": "linotip",
    "linotipurile": "linotip",
    "linotipurilor": "linotip",
    "linsa": "lins",
    "linsă": "lins",
    "linse": "lins",
    "linsei": "lins",
    "linsele": "lins",
    "linselor": "lins",
    "linși": "lins",
    "linșii": "lins",
    "linșilor": "lins",
    "linsul": "lins",
    "linsului": "lins",
    "linșă": "linșa",
    "linșai": "linșa",
    "linșam": "linșa",
    "linșăm": "linșa",
    "linșând": "linșa",
    "linșându": "linșa",
    "linșară": "linșa",
    "linșarăm": "linșa",
    "linșarăți": "linșa",
    "linșase": "linșa",
    "linșasem": "linșa",
    "linșaseră": "linșa",
    "linșaserăm": "linșa",
    "linșaserăți": "linșa",
    "linșaseși": "linșa",
    "linșași": "linșa",
    "linșat": "linșa",
    "linșați": "linșa",
    "linșatu": "linșa",
    "linșau": "linșa",
    "linșează": "linșa",
    "linșez": "linșa",
    "linșeze": "linșa",
    "linșezi": "linșa",
    "nelinșând": "linșa",
    "nelinșându": "linșa",
    "nemailinșând": "linșa",
    "nemailinșându": "linșa",
    "linșată": "linșat",
    "linșate": "linșat",
    "linșați": "linșat",
    "lintea": "linte",
    "lintei": "linte",
    "lincși": "linx",
    "lincșii": "linx",
    "lincșilor": "linx",
    "linxul": "linx",
    "linxului": "linx",
    "liota": "liotă",
    "liote": "liotă",
    "liotei": "liotă",
    "liotele": "liotă",
    "liotelor": "liotă",
    "lioto": "liotă",
    "lipăia": "lipăi",
    "lipăiai": "lipăi",
    "lipăiam": "lipăi",
    "lipăiască": "lipăi",
    "lipăiați": "lipăi",
    "lipăiau": "lipăi",
    "lipăiesc": "lipăi",
    "lipăiește": "lipăi",
    "lipăiești": "lipăi",
    "lipăii": "lipăi",
    "lipăim": "lipăi",
    "lipăind": "lipăi",
    "lipăindu": "lipăi",
    "lipăiră": "lipăi",
    "lipăirăm": "lipăi",
    "lipăirăți": "lipăi",
    "lipăise": "lipăi",
    "lipăisem": "lipăi",
    "lipăiseră": "lipăi",
    "lipăiserăm": "lipăi",
    "lipăiserăți": "lipăi",
    "lipăiseși": "lipăi",
    "lipăiși": "lipăi",
    "lipăit": "lipăi",
    "lipăiți": "lipăi",
    "lipăitu": "lipăi",
    "nelipăind": "lipăi",
    "nelipăindu": "lipăi",
    "nemailipăind": "lipăi",
    "nemailipăindu": "lipăi",
    "lipăită": "lipăit",
    "lipăite": "lipăit",
    "lipăiți": "lipăit",
    "lipea": "lipi",
    "lipeai": "lipi",
    "lipeam": "lipi",
    "lipească": "lipi",
    "lipeați": "lipi",
    "lipeau": "lipi",
    "lipesc": "lipi",
    "lipește": "lipi",
    "lipești": "lipi",
    "lipii": "lipi",
    "lipim": "lipi",
    "lipind": "lipi",
    "lipindu": "lipi",
    "lipiră": "lipi",
    "lipirăm": "lipi",
    "lipirăți": "lipi",
    "lipise": "lipi",
    "lipisem": "lipi",
    "lipiseră": "lipi",
    "lipiserăm": "lipi",
    "lipiserăți": "lipi",
    "lipiseși": "lipi",
    "lipiși": "lipi",
    "lipit": "lipi",
    "lipiți": "lipi",
    "lipitu": "lipi",
    "nelipind": "lipi",
    "nelipindu": "lipi",
    "nemailipind": "lipi",
    "nemailipindu": "lipi",
    "lipicioasa": "lipicios",
    "lipicioasă": "lipicios",
    "lipicioase": "lipicios",
    "lipicioasei": "lipicios",
    "lipicioasele": "lipicios",
    "lipicioaselor": "lipicios",
    "lipicioși": "lipicios",
    "lipicioșii": "lipicios",
    "lipicioșilor": "lipicios",
    "lipiciosul": "lipicios",
    "lipiciosului": "lipicios",
    "lipită": "lipit",
    "lipite": "lipit",
    "lipiți": "lipit",
    "lipitoarea": "lipitoare",
    "lipitoarele": "lipitoare",
    "lipitori": "lipitoare",
    "lipitorii": "lipitoare",
    "lipitorilor": "lipitoare",
    "lipoveana": "lipovean",
    "lipoveană": "lipovean",
    "lipoveano": "lipovean",
    "lipoveanul": "lipovean",
    "lipoveanule": "lipovean",
    "lipoveanului": "lipovean",
    "lipovene": "lipovean",
    "lipovenei": "lipovean",
    "lipovenele": "lipovean",
    "lipovenelor": "lipovean",
    "lipoveni": "lipovean",
    "lipovenii": "lipovean",
    "lipovenilor": "lipovean",
    "lipsa": "lipsă",
    "lipse": "lipsă",
    "lipsei": "lipsă",
    "lipso": "lipsă",
    "lipsuri": "lipsă",
    "lipsurile": "lipsă",
    "lipsurilor": "lipsă",
    "lipsea": "lipsi",
    "lipseai": "lipsi",
    "lipseam": "lipsi",
    "lipsească": "lipsi",
    "lipseați": "lipsi",
    "lipseau": "lipsi",
    "lipsesc": "lipsi",
    "lipsește": "lipsi",
    "lipsești": "lipsi",
    "lipsii": "lipsi",
    "lipsim": "lipsi",
    "lipsind": "lipsi",
    "lipsindu": "lipsi",
    "lipsiră": "lipsi",
    "lipsirăm": "lipsi",
    "lipsirăți": "lipsi",
    "lipsise": "lipsi",
    "lipsisem": "lipsi",
    "lipsiseră": "lipsi",
    "lipsiserăm": "lipsi",
    "lipsiserăți": "lipsi",
    "lipsiseși": "lipsi",
    "lipsiși": "lipsi",
    "lipsit": "lipsi",
    "lipsiți": "lipsi",
    "lipsitu": "lipsi",
    "lipsita": "lipsit",
    "lipsită": "lipsit",
    "lipsite": "lipsit",
    "lipsitei": "lipsit",
    "lipsitele": "lipsit",
    "lipsitelor": "lipsit",
    "lipsiți": "lipsit",
    "lipsiții": "lipsit",
    "lipsiților": "lipsit",
    "lipsitul": "lipsit",
    "lipsitului": "lipsit",
    "lira": "liră",
    "lire": "liră",
    "lirei": "liră",
    "lirele": "liră",
    "lirelor": "liră",
    "lirica": "liric",
    "lirică": "liric",
    "lirice": "liric",
    "liricei": "liric",
    "liricele": "liric",
    "liricelor": "liric",
    "lirici": "liric",
    "liricii": "liric",
    "liricilor": "liric",
    "liricul": "liric",
    "liricului": "liric",
    "lirica": "lirică",
    "liricele": "lirică",
    "lirici": "lirică",
    "liricii": "lirică",
    "liricilor": "lirică",
    "lista": "listă",
    "liste": "listă",
    "listei": "listă",
    "listele": "listă",
    "listelor": "listă",
    "listarea": "listare",
    "listareo": "listare",
    "listări": "listare",
    "listării": "listare",
    "listările": "listare",
    "listărilor": "listare",
    "litera": "literă",
    "litere": "literă",
    "literei": "literă",
    "literele": "literă",
    "literelor": "literă",
    "literala": "literal",
    "literală": "literal",
    "literale": "literal",
    "literalei": "literal",
    "literalele": "literal",
    "literalelor": "literal",
    "literali": "literal",
    "literalii": "literal",
    "literalilor": "literal",
    "literalul": "literal",
    "literalului": "literal",
    "literara": "literar",
    "literară": "literar",
    "literare": "literar",
    "literarei": "literar",
    "literarele": "literar",
    "literarelor": "literar",
    "literari": "literar",
    "literarii": "literar",
    "literarilor": "literar",
    "literarul": "literar",
    "literarului": "literar",
    "literar-artistică": "literar-artistic",
    "literar-artistice": "literar-artistic",
    "literariză": "literariza",
    "literarizai": "literariza",
    "literarizam": "literariza",
    "literarizăm": "literariza",
    "literarizând": "literariza",
    "literarizându": "literariza",
    "literarizară": "literariza",
    "literarizarăm": "literariza",
    "literarizarăți": "literariza",
    "literarizase": "literariza",
    "literarizasem": "literariza",
    "literarizaseră": "literariza",
    "literarizaserăm": "literariza",
    "literarizaserăți": "literariza",
    "literarizaseși": "literariza",
    "literarizași": "literariza",
    "literarizat": "literariza",
    "literarizați": "literariza",
    "literarizatu": "literariza",
    "literarizau": "literariza",
    "literarizează": "literariza",
    "literarizez": "literariza",
    "literarizeze": "literariza",
    "literarizezi": "literariza",
    "neliterarizând": "literariza",
    "neliterarizându": "literariza",
    "nemailiterarizând": "literariza",
    "nemailiterarizându": "literariza",
    "literarizată": "literarizat",
    "literarizate": "literarizat",
    "literarizați": "literarizat",
    "literata": "literat",
    "literată": "literat",
    "literate": "literat",
    "literatei": "literat",
    "literatele": "literat",
    "literatelor": "literat",
    "literați": "literat",
    "literații": "literat",
    "literaților": "literat",
    "literato": "literat",
    "literatul": "literat",
    "literatule": "literat",
    "literatului": "literat",
    "lit.": "literatură",
    "literatura": "literatură",
    "literaturi": "literatură",
    "literaturii": "literatură",
    "literaturile": "literatură",
    "literaturilor": "literatură",
    "literaturiză": "literaturiza",
    "literaturizai": "literaturiza",
    "literaturizam": "literaturiza",
    "literaturizăm": "literaturiza",
    "literaturizând": "literaturiza",
    "literaturizându": "literaturiza",
    "literaturizară": "literaturiza",
    "literaturizarăm": "literaturiza",
    "literaturizarăți": "literaturiza",
    "literaturizase": "literaturiza",
    "literaturizasem": "literaturiza",
    "literaturizaseră": "literaturiza",
    "literaturizaserăm": "literaturiza",
    "literaturizaserăți": "literaturiza",
    "literaturizaseși": "literaturiza",
    "literaturizași": "literaturiza",
    "literaturizat": "literaturiza",
    "literaturizați": "literaturiza",
    "literaturizatu": "literaturiza",
    "literaturizau": "literaturiza",
    "literaturizează": "literaturiza",
    "literaturizez": "literaturiza",
    "literaturizeze": "literaturiza",
    "literaturizezi": "literaturiza",
    "neliteraturizând": "literaturiza",
    "neliteraturizându": "literaturiza",
    "nemailiteraturizând": "literaturiza",
    "nemailiteraturizându": "literaturiza",
    "literaturizată": "literaturizat",
    "literaturizate": "literaturizat",
    "literaturizați": "literaturizat",
    "litigioasa": "litigios",
    "litigioasă": "litigios",
    "litigioase": "litigios",
    "litigioasei": "litigios",
    "litigioasele": "litigios",
    "litigioaselor": "litigios",
    "litigioși": "litigios",
    "litigioșii": "litigios",
    "litigioșilor": "litigios",
    "litigiosul": "litigios",
    "litigiosului": "litigios",
    "litigii": "litigiu",
    "litigiile": "litigiu",
    "litigiilor": "litigiu",
    "litigiul": "litigiu",
    "litigiului": "litigiu",
    "litografiai": "litografia",
    "litografiam": "litografia",
    "litografiară": "litografia",
    "litografiarăm": "litografia",
    "litografiarăți": "litografia",
    "litografiase": "litografia",
    "litografiasem": "litografia",
    "litografiaseră": "litografia",
    "litografiaserăm": "litografia",
    "litografiaserăți": "litografia",
    "litografiaseși": "litografia",
    "litografiași": "litografia",
    "litografiat": "litografia",
    "litografiați": "litografia",
    "litografiatu": "litografia",
    "litografiau": "litografia",
    "litografiază": "litografia",
    "litografie": "litografia",
    "litografiem": "litografia",
    "litografiez": "litografia",
    "litografieze": "litografia",
    "litografiezi": "litografia",
    "litografiind": "litografia",
    "litografiindu": "litografia",
    "nelitografiind": "litografia",
    "nelitografiindu": "litografia",
    "nemailitografiind": "litografia",
    "nemailitografiindu": "litografia",
    "litografiată": "litografiat",
    "litografiate": "litografiat",
    "litografiați": "litografiat",
    "litografia": "litografie",
    "litografiei": "litografie",
    "litografii": "litografie",
    "litografiile": "litografie",
    "litografiilor": "litografie",
    "litoralul": "litoral",
    "litoralului": "litoral",
    "litoraluri": "litoral",
    "litoralurile": "litoral",
    "litoralurilor": "litoral",
    "l": "litru",
    "litri": "litru",
    "litrii": "litru",
    "litrilor": "litru",
    "litrul": "litru",
    "litrului": "litru",
    "Lituaniei": "Lituania",
    "lituaniana": "lituanian",
    "lituaniană": "lituanian",
    "lituanianul": "lituanian",
    "lituanianului": "lituanian",
    "lituaniene": "lituanian",
    "lituanienei": "lituanian",
    "lituanienele": "lituanian",
    "lituanienelor": "lituanian",
    "lituanieni": "lituanian",
    "lituanienii": "lituanian",
    "lituanienilor": "lituanian",
    "liturghia": "liturghie",
    "liturghiei": "liturghie",
    "liturghii": "liturghie",
    "liturghiile": "liturghie",
    "liturghiilor": "liturghie",
    "liturghisitori": "liturghisitor",
    "liturghisitorii": "liturghisitor",
    "liturghisitorilor": "liturghisitor",
    "liturghisitorul": "liturghisitor",
    "liturghisitorule": "liturghisitor",
    "liturghisitorului": "liturghisitor",
    "liturgica": "liturgic",
    "liturgică": "liturgic",
    "liturgice": "liturgic",
    "liturgicei": "liturgic",
    "liturgicele": "liturgic",
    "liturgicelor": "liturgic",
    "liturgici": "liturgic",
    "liturgicii": "liturgic",
    "liturgicilor": "liturgic",
    "liturgico": "liturgic",
    "liturgicul": "liturgic",
    "liturgicule": "liturgic",
    "liturgicului": "liturgic",
    "livada": "livadă",
    "livezi": "livadă",
    "livezii": "livadă",
    "livezile": "livadă",
    "livezilor": "livadă",
    "livida": "livid",
    "lividă": "livid",
    "livide": "livid",
    "lividei": "livid",
    "lividele": "livid",
    "lividelor": "livid",
    "lividul": "livid",
    "lividului": "livid",
    "livizi": "livid",
    "livizii": "livid",
    "livizilor": "livid",
    "livră": "livra",
    "livrai": "livra",
    "livram": "livra",
    "livrăm": "livra",
    "livrând": "livra",
    "livrându": "livra",
    "livrară": "livra",
    "livrarăm": "livra",
    "livrarăți": "livra",
    "livrase": "livra",
    "livrasem": "livra",
    "livraseră": "livra",
    "livraserăm": "livra",
    "livraserăți": "livra",
    "livraseși": "livra",
    "livrași": "livra",
    "livrat": "livra",
    "livrați": "livra",
    "livratu": "livra",
    "livrau": "livra",
    "livrează": "livra",
    "livrez": "livra",
    "livreze": "livra",
    "livrezi": "livra",
    "nelivrând": "livra",
    "nelivrându": "livra",
    "nemailivrând": "livra",
    "nemailivrându": "livra",
    "livra": "livră",
    "livre": "livră",
    "livrei": "livră",
    "livrele": "livră",
    "livrelor": "livră",
    "livrarea": "livrare",
    "livrări": "livrare",
    "livrării": "livrare",
    "livrările": "livrare",
    "livrărilor": "livrare",
    "livrată": "livrat",
    "livrate": "livrat",
    "livrați": "livrat",
    "livreao": "livrea",
    "livreaua": "livrea",
    "livrele": "livrea",
    "livrelei": "livrea",
    "livrelele": "livrea",
    "livrelelor": "livrea",
    "livreasca": "livresc",
    "livrească": "livresc",
    "livreasco": "livresc",
    "livrescul": "livresc",
    "livrescule": "livresc",
    "livrescului": "livresc",
    "livrești": "livresc",
    "livreștii": "livresc",
    "livreștile": "livresc",
    "livreștilor": "livresc",
    "livrete": "livret",
    "livretele": "livret",
    "livretelor": "livret",
    "livretul": "livret",
    "livretului": "livret",
    "lizibila": "lizibil",
    "lizibilă": "lizibil",
    "lizibile": "lizibil",
    "lizibilei": "lizibil",
    "lizibilele": "lizibil",
    "lizibilelor": "lizibil",
    "lizibili": "lizibil",
    "lizibilii": "lizibil",
    "lizibililor": "lizibil",
    "lizibilul": "lizibil",
    "lizibilului": "lizibil",
    "liziera": "lizieră",
    "liziere": "lizieră",
    "lizierei": "lizieră",
    "lizierele": "lizieră",
    "lizierelor": "lizieră",
    "lobi": "lob",
    "lobii": "lob",
    "lobilor": "lob",
    "lobul": "lob",
    "lobului": "lob",
    "loburi": "lob",
    "loburile": "lob",
    "loburilor": "lob",
    "locu'": "loc",
    "locul": "loc",
    "locului": "loc",
    "locuri": "loc",
    "locurile": "loc",
    "locurilor": "loc",
    "locala": "local",
    "locală": "local",
    "locale": "local",
    "localei": "local",
    "localele": "local",
    "localelor": "local",
    "locali": "local",
    "localii": "local",
    "localilor": "local",
    "localul": "local",
    "localului": "local",
    "localuri": "local",
    "localurile": "local",
    "localurilor": "local",
    "localitatea": "localitate",
    "localități": "localitate",
    "localității": "localitate",
    "localitățile": "localitate",
    "localităților": "localitate",
    "localiză": "localiza",
    "localizai": "localiza",
    "localizam": "localiza",
    "localizăm": "localiza",
    "localizând": "localiza",
    "localizându": "localiza",
    "localizară": "localiza",
    "localizarăm": "localiza",
    "localizarăți": "localiza",
    "localizase": "localiza",
    "localizasem": "localiza",
    "localizaseră": "localiza",
    "localizaserăm": "localiza",
    "localizaserăți": "localiza",
    "localizaseși": "localiza",
    "localizași": "localiza",
    "localizat": "localiza",
    "localizați": "localiza",
    "localizatu": "localiza",
    "localizau": "localiza",
    "localizează": "localiza",
    "localizez": "localiza",
    "localizeze": "localiza",
    "localizezi": "localiza",
    "nelocalizând": "localiza",
    "nelocalizându": "localiza",
    "nemailocalizând": "localiza",
    "nemailocalizându": "localiza",
    "localizată": "localizat",
    "localizate": "localizat",
    "localizați": "localizat",
    "localnica": "localnic",
    "localnică": "localnic",
    "localnice": "localnic",
    "localnicei": "localnic",
    "localnicele": "localnic",
    "localnicelor": "localnic",
    "localnici": "localnic",
    "localnicii": "localnic",
    "localnicilor": "localnic",
    "localnicul": "localnic",
    "localnicului": "localnic",
    "locașul": "locaș",
    "locașului": "locaș",
    "locașuri": "locaș",
    "locașurile": "locaș",
    "locașurilor": "locaș",
    "locatari": "locatar",
    "locatarii": "locatar",
    "locatarilor": "locatar",
    "locatarul": "locatar",
    "locatarului": "locatar",
    "locația": "locație",
    "locației": "locație",
    "locații": "locație",
    "locațiile": "locație",
    "locațiilor": "locație",
    "locative": "locativ",
    "l.c.": "loco_citato",
    "locomotiva": "locomotivă",
    "locomotive": "locomotivă",
    "locomotivei": "locomotivă",
    "locomotivele": "locomotivă",
    "locomotivelor": "locomotivă",
    "locomotoare": "locomotor",
    "locomotoarea": "locomotor",
    "locomotoarei": "locomotor",
    "locomotoarele": "locomotor",
    "locomotoarelor": "locomotor",
    "locomotoareo": "locomotor",
    "locomotori": "locomotor",
    "locomotorii": "locomotor",
    "locomotorilor": "locomotor",
    "locomotorul": "locomotor",
    "locomotorule": "locomotor",
    "locomotorului": "locomotor",
    "locot.": "locotenent",
    "locotenente": "locotenent",
    "locotenenți": "locotenent",
    "locotenenții": "locotenent",
    "locotenenților": "locotenent",
    "locotenentul": "locotenent",
    "locotenentului": "locotenent",
    "lt.": "locotenent",
    "lt.col.": "locotenent_colonel",
    "lt.maj.": "locotenent_major",
    "loc.col.": "locotenent-colonel",
    "locotenenți-colonei": "locotenent-colonel",
    "locotenenții-colonei": "locotenent-colonel",
    "locotenenților-colonei": "locotenent-colonel",
    "locotenentul-colonel": "locotenent-colonel",
    "locotenentului-colonel": "locotenent-colonel",
    "locotenenții-majori": "locotenent-major",
    "locotenenților-majori": "locotenent-major",
    "locotenenți-majori": "locotenent-major",
    "locotenentul-major": "locotenent-major",
    "locotenentului-major": "locotenent-major",
    "locțiitori": "locțiitor",
    "locțiitorii": "locțiitor",
    "locțiitorilor": "locțiitor",
    "locțiitorul": "locțiitor",
    "locțiitorului": "locțiitor",
    "locuia": "locui",
    "locuiai": "locui",
    "locuiam": "locui",
    "locuiască": "locui",
    "locuiați": "locui",
    "locuiau": "locui",
    "locuiesc": "locui",
    "locuiește": "locui",
    "locuiești": "locui",
    "locuii": "locui",
    "locuim": "locui",
    "locuind": "locui",
    "locuindu": "locui",
    "locuiră": "locui",
    "locuirăm": "locui",
    "locuirăți": "locui",
    "locuise": "locui",
    "locuisem": "locui",
    "locuiseră": "locui",
    "locuiserăm": "locui",
    "locuiserăți": "locui",
    "locuiseși": "locui",
    "locuiși": "locui",
    "locuit": "locui",
    "locuiți": "locui",
    "locuitu": "locui",
    "nelocuind": "locui",
    "nelocuindu": "locui",
    "nemailocuind": "locui",
    "nemailocuindu": "locui",
    "locuința": "locuință",
    "locuințe": "locuință",
    "locuinței": "locuință",
    "locuințele": "locuință",
    "locuințelor": "locuință",
    "locuită": "locuit",
    "locuite": "locuit",
    "locuiți": "locuit",
    "locuitoare": "locuitor",
    "locuitoarea": "locuitor",
    "locuitoarei": "locuitor",
    "locuitoarele": "locuitor",
    "locuitoarelor": "locuitor",
    "locuitoareo": "locuitor",
    "locuitori": "locuitor",
    "locuitorii": "locuitor",
    "locuitorilor": "locuitor",
    "locuitorul": "locuitor",
    "locuitorule": "locuitor",
    "locuitorului": "locuitor",
    "loc.": "locuitori",
    "loc.": "locuțiune",
    "locuțiunea": "locuțiune",
    "locuțiuni": "locuțiune",
    "locuțiunii": "locuțiune",
    "locuțiunile": "locuțiune",
    "locuțiunilor": "locuțiune",
    "loc.adj.": "locuțiune_adjectivală",
    "loc.adv.": "locuțiune_adjverbială",
    "loc.conj.": "locuțiune_conjuncțională",
    "loc.prep.": "locuțiune_prepozițională",
    "loc.verb.": "locuțiune_verbală",
    "locutori": "locutor",
    "locutorii": "locutor",
    "locutorilor": "locutor",
    "locutorul": "locutor",
    "locutorule": "locutor",
    "locutorului": "locutor",
    "lodene": "loden",
    "lodenele": "loden",
    "lodenelor": "loden",
    "lodenul": "loden",
    "lodenule": "loden",
    "lodenului": "loden",
    "log.": "logaritm",
    "logaritmi": "logaritm",
    "logaritmii": "logaritm",
    "logaritmilor": "logaritm",
    "logaritmul": "logaritm",
    "logaritmului": "logaritm",
    "logaritmă": "logaritma",
    "logaritmai": "logaritma",
    "logaritmam": "logaritma",
    "logaritmăm": "logaritma",
    "logaritmând": "logaritma",
    "logaritmându": "logaritma",
    "logaritmară": "logaritma",
    "logaritmarăm": "logaritma",
    "logaritmarăți": "logaritma",
    "logaritmase": "logaritma",
    "logaritmasem": "logaritma",
    "logaritmaseră": "logaritma",
    "logaritmaserăm": "logaritma",
    "logaritmaserăți": "logaritma",
    "logaritmaseși": "logaritma",
    "logaritmași": "logaritma",
    "logaritmat": "logaritma",
    "logaritmați": "logaritma",
    "logaritmatu": "logaritma",
    "logaritmau": "logaritma",
    "logaritmează": "logaritma",
    "logaritmez": "logaritma",
    "logaritmeze": "logaritma",
    "logaritmezi": "logaritma",
    "nelogaritmând": "logaritma",
    "nelogaritmându": "logaritma",
    "nemailogaritmând": "logaritma",
    "nemailogaritmându": "logaritma",
    "logaritmată": "logaritmat",
    "logaritmate": "logaritmat",
    "logaritmați": "logaritmat",
    "logica": "logic",
    "logică": "logic",
    "logice": "logic",
    "logicei": "logic",
    "logicele": "logic",
    "logicelor": "logic",
    "logici": "logic",
    "logicii": "logic",
    "logicilor": "logic",
    "logicul": "logic",
    "logicului": "logic",
    "logica": "logică",
    "logicele": "logică",
    "logici": "logică",
    "logicii": "logică",
    "logicilor": "logică",
    "logicianul": "logician",
    "logicianule": "logician",
    "logicianului": "logician",
    "logicieni": "logician",
    "logicienii": "logician",
    "logicienilor": "logician",
    "logico-semantică": "logico-semantic",
    "logistica": "logistică",
    "logistici": "logistică",
    "logisticii": "logistică",
    "logodea": "logodi",
    "logodeai": "logodi",
    "logodeam": "logodi",
    "logodească": "logodi",
    "logodeați": "logodi",
    "logodeau": "logodi",
    "logodesc": "logodi",
    "logodește": "logodi",
    "logodești": "logodi",
    "logodii": "logodi",
    "logodim": "logodi",
    "logodind": "logodi",
    "logodindu": "logodi",
    "logodiră": "logodi",
    "logodirăm": "logodi",
    "logodirăți": "logodi",
    "logodise": "logodi",
    "logodisem": "logodi",
    "logodiseră": "logodi",
    "logodiserăm": "logodi",
    "logodiserăți": "logodi",
    "logodiseși": "logodi",
    "logodiși": "logodi",
    "logodit": "logodi",
    "logodiți": "logodi",
    "logoditu": "logodi",
    "nelogodind": "logodi",
    "nelogodindu": "logodi",
    "nemailogodind": "logodi",
    "nemailogodindu": "logodi",
    "logodită": "logodit",
    "logodite": "logodit",
    "logodiți": "logodit",
    "logodna": "logodnă",
    "logodne": "logodnă",
    "logodnei": "logodnă",
    "logodnele": "logodnă",
    "logodnelor": "logodnă",
    "logodnici": "logodnic",
    "logodnicii": "logodnic",
    "logodnicilor": "logodnic",
    "logodnicul": "logodnic",
    "logodnicului": "logodnic",
    "logodnica": "logodnică",
    "logodnice": "logodnică",
    "logodnicei": "logodnică",
    "logodnicele": "logodnică",
    "logodnicelor": "logodnică",
    "logosul": "logos",
    "logosule": "logos",
    "logosului": "logos",
    "logosuri": "logos",
    "logosurile": "logos",
    "logosurilor": "logos",
    "loiala": "loial",
    "loială": "loial",
    "loiale": "loial",
    "loialei": "loial",
    "loialele": "loial",
    "loialelor": "loial",
    "loiali": "loial",
    "loialii": "loial",
    "loialilor": "loial",
    "loialul": "loial",
    "loialului": "loial",
    "loialitatea": "loialitate",
    "loialități": "loialitate",
    "loialității": "loialitate",
    "loja": "lojă",
    "lojei": "lojă",
    "loji": "lojă",
    "lojile": "lojă",
    "lojilor": "lojă",
    "londoneza": "londonez",
    "londoneză": "londonez",
    "londoneze": "londonez",
    "londonezei": "londonez",
    "londonezele": "londonez",
    "londonezelor": "londonez",
    "londonezi": "londonez",
    "londonezii": "londonez",
    "londonezilor": "londonez",
    "londonezul": "londonez",
    "londonezului": "londonez",
    "Londre": "Londra",
    "Londrei": "Londra",
    "longevitatea": "longevitate",
    "longevități": "longevitate",
    "longevității": "longevitate",
    "longevivi": "longeviv",
    "longevivii": "longeviv",
    "longevivilor": "longeviv",
    "longevivul": "longeviv",
    "longevivule": "longeviv",
    "longevivului": "longeviv",
    "longeviva": "longevivă",
    "longevive": "longevivă",
    "longevivei": "longevivă",
    "longevivele": "longevivă",
    "longevivelor": "longevivă",
    "longevivo": "longevivă",
    "longitudinea": "longitudine",
    "longitudini": "longitudine",
    "longitudinii": "longitudine",
    "longitudinile": "longitudine",
    "longitudinilor": "longitudine",
    "lopata": "lopată",
    "lopeți": "lopată",
    "lopeții": "lopată",
    "lopețile": "lopată",
    "lopeților": "lopată",
    "lopățele": "lopățică",
    "lopățelei": "lopățică",
    "lopățelele": "lopățică",
    "lopățelelor": "lopățică",
    "lopățica": "lopățică",
    "lopățico": "lopățică",
    "L.": "lord",
    "lordul": "lord",
    "lordului": "lord",
    "lorzi": "lord",
    "lorzii": "lord",
    "lorzilor": "lord",
    "Loredanei": "Loredana",
    "lotul": "lot",
    "lotului": "lot",
    "loturi": "lot",
    "loturile": "lot",
    "loturilor": "lot",
    "loteria": "loterie",
    "loteriei": "loterie",
    "loterii": "loterie",
    "loteriile": "loterie",
    "loteriilor": "loterie",
    "lotoul": "loto",
    "lotoului": "loto",
    "lotouri": "loto",
    "lotourile": "loto",
    "lotourilor": "loto",
    "lotofagi": "lotofag",
    "lotuși": "lotus",
    "lotușii": "lotus",
    "lotușilor": "lotus",
    "lotusul": "lotus",
    "lotusule": "lotus",
    "lotusului": "lotus",
    "lovea": "lovi",
    "loveai": "lovi",
    "loveam": "lovi",
    "lovească": "lovi",
    "loveați": "lovi",
    "loveau": "lovi",
    "lovesc": "lovi",
    "lovește": "lovi",
    "lovești": "lovi",
    "lovii": "lovi",
    "lovim": "lovi",
    "lovind": "lovi",
    "lovindu": "lovi",
    "loviră": "lovi",
    "lovirăm": "lovi",
    "lovirăți": "lovi",
    "lovise": "lovi",
    "lovisem": "lovi",
    "loviseră": "lovi",
    "loviserăm": "lovi",
    "loviserăți": "lovi",
    "loviseși": "lovi",
    "loviși": "lovi",
    "lovit": "lovi",
    "loviți": "lovi",
    "lovitu": "lovi",
    "nelovind": "lovi",
    "nelovindu": "lovi",
    "nemailovind": "lovi",
    "nemailovindu": "lovi",
    "lovirea": "lovire",
    "lovireo": "lovire",
    "loviri": "lovire",
    "lovirii": "lovire",
    "lovirile": "lovire",
    "lovirilor": "lovire",
    "lovită": "lovit",
    "lovite": "lovit",
    "loviți": "lovit",
    "lovitura": "lovitură",
    "lovituri": "lovitură",
    "loviturii": "lovitură",
    "loviturile": "lovitură",
    "loviturilor": "lovitură",
    "lozul": "loz",
    "lozului": "loz",
    "lozuri": "loz",
    "lozurile": "loz",
    "lozurilor": "loz",
    "lozinca": "lozincă",
    "lozinci": "lozincă",
    "lozincii": "lozincă",
    "lozincile": "lozincă",
    "lozincilor": "lozincă",
    "ia": "lua",
    "iau": "lua",
    "iei": "lua",
    "lua'": "lua",
    "luă": "lua",
    "luai": "lua",
    "luam": "lua",
    "luăm": "lua",
    "luând": "lua",
    "luându": "lua",
    "luară": "lua",
    "luarăm": "lua",
    "luarăți": "lua",
    "luase": "lua",
    "luasem": "lua",
    "luaseră": "lua",
    "luaserăm": "lua",
    "luaserăți": "lua",
    "luaseși": "lua",
    "luași": "lua",
    "luat": "lua",
    "luați": "lua",
    "luatu": "lua",
    "luau": "lua",
    "neluând": "lua",
    "neluându": "lua",
    "nemailuând": "lua",
    "nemailuându": "lua",
    "luarea": "luare",
    "luareo": "luare",
    "luări": "luare",
    "luării": "luare",
    "luările": "luare",
    "luărilor": "luare",
    "lua'": "luat",
    "luată": "luat",
    "luate": "luat",
    "luați": "luat",
    "lubrifianți": "lubrifiant",
    "lubrifianții": "lubrifiant",
    "lubrifianților": "lubrifiant",
    "lubrifiantul": "lubrifiant",
    "lubrifiantului": "lubrifiant",
    "luceafărul": "luceafăr",
    "luceafărului": "luceafăr",
    "luceferi": "luceafăr",
    "luceferii": "luceafăr",
    "luceferilor": "luceafăr",
    "lucerna": "lucernă",
    "lucerne": "lucernă",
    "lucernei": "lucernă",
    "lucea": "luci",
    "luceai": "luci",
    "luceam": "luci",
    "lucească": "luci",
    "luceați": "luci",
    "luceau": "luci",
    "lucesc": "luci",
    "lucește": "luci",
    "lucești": "luci",
    "lucii": "luci",
    "lucim": "luci",
    "lucind": "luci",
    "lucindu": "luci",
    "luciră": "luci",
    "lucirăm": "luci",
    "lucirăți": "luci",
    "lucise": "luci",
    "lucisem": "luci",
    "luciseră": "luci",
    "luciserăm": "luci",
    "luciserăți": "luci",
    "luciseși": "luci",
    "luciși": "luci",
    "lucit": "luci",
    "luciți": "luci",
    "lucitu": "luci",
    "nelucind": "luci",
    "nelucindu": "luci",
    "nemailucind": "luci",
    "nemailucindu": "luci",
    "lucida": "lucid",
    "lucidă": "lucid",
    "lucide": "lucid",
    "lucidei": "lucid",
    "lucidele": "lucid",
    "lucidelor": "lucid",
    "lucidul": "lucid",
    "lucidului": "lucid",
    "lucizi": "lucid",
    "lucizii": "lucid",
    "lucizilor": "lucid",
    "luciditatea": "luciditate",
    "lucidități": "luciditate",
    "lucidității": "luciditate",
    "lucioasa": "lucios",
    "lucioasă": "lucios",
    "lucioase": "lucios",
    "lucioasei": "lucios",
    "lucioasele": "lucios",
    "lucioaselor": "lucios",
    "lucioși": "lucios",
    "lucioșii": "lucios",
    "lucioșilor": "lucios",
    "luciosul": "lucios",
    "luciosului": "lucios",
    "lucirea": "lucire",
    "lucireo": "lucire",
    "luciri": "lucire",
    "lucirii": "lucire",
    "lucirile": "lucire",
    "lucirilor": "lucire",
    "lucită": "lucit",
    "lucite": "lucit",
    "luciți": "lucit",
    "lucitoare": "lucitor",
    "lucitoarea": "lucitor",
    "lucitoarei": "lucitor",
    "lucitoarele": "lucitor",
    "lucitoarelor": "lucitor",
    "lucitori": "lucitor",
    "lucitorii": "lucitor",
    "lucitorilor": "lucitor",
    "lucitorul": "lucitor",
    "lucitorului": "lucitor",
    "luciul": "luciu",
    "luciului": "luciu",
    "luciuri": "luciu",
    "luciurile": "luciu",
    "luciurilor": "luciu",
    "lucră": "lucra",
    "lucrai": "lucra",
    "lucram": "lucra",
    "lucrăm": "lucra",
    "lucrând": "lucra",
    "lucrându": "lucra",
    "lucrară": "lucra",
    "lucrarăm": "lucra",
    "lucrarăți": "lucra",
    "lucrase": "lucra",
    "lucrasem": "lucra",
    "lucraseră": "lucra",
    "lucraserăm": "lucra",
    "lucraserăți": "lucra",
    "lucraseși": "lucra",
    "lucrași": "lucra",
    "lucrat": "lucra",
    "lucrați": "lucra",
    "lucratu": "lucra",
    "lucrau": "lucra",
    "lucrează": "lucra",
    "lucrez": "lucra",
    "lucreze": "lucra",
    "lucrezi": "lucra",
    "nelucrând": "lucra",
    "nelucrându": "lucra",
    "nemailucrând": "lucra",
    "nemailucrându": "lucra",
    "lucrarea": "lucrare",
    "lucrări": "lucrare",
    "lucrării": "lucrare",
    "lucrările": "lucrare",
    "lucrărilor": "lucrare",
    "lucrată": "lucrat",
    "lucrate": "lucrat",
    "lucrați": "lucrat",
    "lucrativa": "lucrativ",
    "lucrativă": "lucrativ",
    "lucrative": "lucrativ",
    "lucrativei": "lucrativ",
    "lucrativele": "lucrativ",
    "lucrativelor": "lucrativ",
    "lucrativi": "lucrativ",
    "lucrativii": "lucrativ",
    "lucrativilor": "lucrativ",
    "lucrativul": "lucrativ",
    "lucrativului": "lucrativ",
    "lucrătoarea": "lucrătoare",
    "lucrătoarei": "lucrătoare",
    "lucrătoarele": "lucrătoare",
    "lucrătoarelor": "lucrătoare",
    "lucrătoare": "lucrător",
    "lucrătoarea": "lucrător",
    "lucrătoarei": "lucrător",
    "lucrătoarele": "lucrător",
    "lucrătoarelor": "lucrător",
    "lucrători": "lucrător",
    "lucrătorii": "lucrător",
    "lucrătorilor": "lucrător",
    "lucrătorul": "lucrător",
    "lucrătorului": "lucrător",
    "lucrătura": "lucrătură",
    "lucrături": "lucrătură",
    "lucrăturii": "lucrătură",
    "lucrăturile": "lucrătură",
    "lucrăturilor": "lucrătură",
    "lucrăturo": "lucrătură",
    "lucrul": "lucru",
    "lucrului": "lucru",
    "lucruri": "lucru",
    "lucrurile": "lucru",
    "lucrurilor": "lucru",
    "Lufthansei": "Lufthansa",
    "lugubra": "lugubru",
    "lugubră": "lugubru",
    "lugubre": "lugubru",
    "lugubrei": "lugubru",
    "lugubrele": "lugubru",
    "lugubrelor": "lugubru",
    "lugubri": "lugubru",
    "lugubrii": "lugubru",
    "lugubrilor": "lugubru",
    "lugubrul": "lugubru",
    "lugubrului": "lugubru",
    "Luizei": "Luiza",
    "lujeri": "lujer",
    "lujerii": "lujer",
    "lujerilor": "lujer",
    "lujerul": "lujer",
    "lujerului": "lujer",
    "luleaua": "lulea",
    "lulele": "lulea",
    "lulelei": "lulea",
    "lulelele": "lulea",
    "lulelelor": "lulea",
    "lumânarea": "lumânare",
    "lumânări": "lumânare",
    "lumânării": "lumânare",
    "lumânările": "lumânare",
    "lumânărilor": "lumânare",
    "lumea": "lume",
    "lumi": "lume",
    "lumii": "lume",
    "lumile": "lume",
    "lumilor": "lume",
    "lm.": "lumen",
    "lumeni": "lumen",
    "lumenii": "lumen",
    "lumenilor": "lumen",
    "lumenul": "lumen",
    "lumenului": "lumen",
    "lumeasca": "lumesc",
    "lumească": "lumesc",
    "lumescul": "lumesc",
    "lumescului": "lumesc",
    "lumești": "lumesc",
    "lumeștii": "lumesc",
    "lumeștile": "lumesc",
    "lumeștilor": "lumesc",
    "lumină": "lumina",
    "luminai": "lumina",
    "luminam": "lumina",
    "luminăm": "lumina",
    "luminând": "lumina",
    "luminându": "lumina",
    "luminară": "lumina",
    "luminarăm": "lumina",
    "luminarăți": "lumina",
    "luminase": "lumina",
    "luminasem": "lumina",
    "luminaseră": "lumina",
    "luminaserăm": "lumina",
    "luminaserăți": "lumina",
    "luminaseși": "lumina",
    "luminași": "lumina",
    "luminat": "lumina",
    "luminați": "lumina",
    "luminatu": "lumina",
    "luminau": "lumina",
    "luminează": "lumina",
    "luminez": "lumina",
    "lumineze": "lumina",
    "luminezi": "lumina",
    "neluminând": "lumina",
    "neluminându": "lumina",
    "nemailuminând": "lumina",
    "nemailuminându": "lumina",
    "lumina": "lumină",
    "lumini": "lumină",
    "luminii": "lumină",
    "luminile": "lumină",
    "luminilor": "lumină",
    "luminata": "luminat",
    "luminată": "luminat",
    "luminate": "luminat",
    "luminatei": "luminat",
    "luminatele": "luminat",
    "luminatelor": "luminat",
    "luminați": "luminat",
    "luminații": "luminat",
    "luminaților": "luminat",
    "luminatul": "luminat",
    "luminatului": "luminat",
    "luminișul": "luminiș",
    "luminișului": "luminiș",
    "luminișuri": "luminiș",
    "luminișurile": "luminiș",
    "luminișurilor": "luminiș",
    "luminoasa": "luminos",
    "luminoasă": "luminos",
    "luminoase": "luminos",
    "luminoasei": "luminos",
    "luminoasele": "luminos",
    "luminoaselor": "luminos",
    "luminoși": "luminos",
    "luminoșii": "luminos",
    "luminoșilor": "luminos",
    "luminosul": "luminos",
    "luminosului": "luminos",
    "luminozitatea": "luminozitate",
    "luminozități": "luminozitate",
    "luminozității": "luminozitate",
    "luminozitățile": "luminozitate",
    "luminozităților": "luminozitate",
    "luna": "lună",
    "luni": "lună",
    "lunii": "lună",
    "lunile": "lună",
    "lunilor": "lună",
    "lunara": "lunar",
    "lunară": "lunar",
    "lunare": "lunar",
    "lunarei": "lunar",
    "lunarele": "lunar",
    "lunarelor": "lunar",
    "lunari": "lunar",
    "lunarii": "lunar",
    "lunarilor": "lunar",
    "lunarul": "lunar",
    "lunarului": "lunar",
    "lunatica": "lunatic",
    "lunatică": "lunatic",
    "lunatice": "lunatic",
    "lunaticei": "lunatic",
    "lunaticele": "lunatic",
    "lunaticelor": "lunatic",
    "lunatici": "lunatic",
    "lunaticii": "lunatic",
    "lunaticilor": "lunatic",
    "lunatico": "lunatic",
    "lunaticul": "lunatic",
    "lunaticule": "lunatic",
    "lunaticului": "lunatic",
    "lunatismul": "lunatism",
    "lunatismule": "lunatism",
    "lunatismului": "lunatism",
    "lunca": "luncă",
    "lunci": "luncă",
    "luncii": "luncă",
    "luncile": "luncă",
    "luncilor": "luncă",
    "lunec": "luneca",
    "lunecă": "luneca",
    "lunecai": "luneca",
    "lunecam": "luneca",
    "lunecăm": "luneca",
    "lunecând": "luneca",
    "lunecându": "luneca",
    "lunecară": "luneca",
    "lunecarăm": "luneca",
    "lunecarăți": "luneca",
    "lunecase": "luneca",
    "lunecasem": "luneca",
    "lunecaseră": "luneca",
    "lunecaserăm": "luneca",
    "lunecaserăți": "luneca",
    "lunecaseși": "luneca",
    "lunecași": "luneca",
    "lunecat": "luneca",
    "lunecați": "luneca",
    "lunecatu": "luneca",
    "lunecau": "luneca",
    "lunece": "luneca",
    "luneci": "luneca",
    "nelunecând": "luneca",
    "nelunecându": "luneca",
    "nemailunecând": "luneca",
    "nemailunecându": "luneca",
    "lunecată": "lunecat",
    "lunecate": "lunecat",
    "lunecați": "lunecat",
    "lunecoasa": "lunecos",
    "lunecoasă": "lunecos",
    "lunecoase": "lunecos",
    "lunecoasei": "lunecos",
    "lunecoasele": "lunecos",
    "lunecoaselor": "lunecos",
    "lunecoși": "lunecos",
    "lunecoșii": "lunecos",
    "lunecoșilor": "lunecos",
    "lunecosul": "lunecos",
    "lunecosului": "lunecos",
    "lunecușul": "lunecuș",
    "lunecușului": "lunecuș",
    "lunecușuri": "lunecuș",
    "lunecușurile": "lunecuș",
    "lunecușurilor": "lunecuș",
    "luneta": "lunetă",
    "lunete": "lunetă",
    "lunetei": "lunetă",
    "lunetele": "lunetă",
    "lunetelor": "lunetă",
    "lunga": "lung",
    "lungă": "lung",
    "lungi": "lung",
    "lungii": "lung",
    "lungile": "lung",
    "lungilor": "lung",
    "lungul": "lung",
    "lungului": "lung",
    "lungea": "lungi",
    "lungeai": "lungi",
    "lungeam": "lungi",
    "lungească": "lungi",
    "lungeați": "lungi",
    "lungeau": "lungi",
    "lungesc": "lungi",
    "lungește": "lungi",
    "lungești": "lungi",
    "lungii": "lungi",
    "lungim": "lungi",
    "lungind": "lungi",
    "lungindu": "lungi",
    "lungiră": "lungi",
    "lungirăm": "lungi",
    "lungirăți": "lungi",
    "lungise": "lungi",
    "lungisem": "lungi",
    "lungiseră": "lungi",
    "lungiserăm": "lungi",
    "lungiserăți": "lungi",
    "lungiseși": "lungi",
    "lungiși": "lungi",
    "lungit": "lungi",
    "lungiți": "lungi",
    "lungitu": "lungi",
    "l.": "lungime",
    "lungimea": "lungime",
    "lungimi": "lungime",
    "lungimii": "lungime",
    "lungimile": "lungime",
    "lungimilor": "lungime",
    "lungită": "lungit",
    "lungite": "lungit",
    "lungiți": "lungit",
    "lunguiața": "lunguieț",
    "lunguiață": "lunguieț",
    "lunguiațo": "lunguieț",
    "lunguiețe": "lunguieț",
    "lunguieței": "lunguieț",
    "lunguiețele": "lunguieț",
    "lunguiețelor": "lunguieț",
    "lunguieți": "lunguieț",
    "lunguieții": "lunguieț",
    "lunguieților": "lunguieț",
    "lunguiețul": "lunguieț",
    "lunguiețule": "lunguieț",
    "lunguiețului": "lunguieț",
    "L.": "luni",
    "lunea": "luni",
    "lunii": "luni",
    "lunile": "luni",
    "lunilor": "luni",
    "luntrași": "luntraș",
    "luntrașii": "luntraș",
    "luntrașilor": "luntraș",
    "luntrașul": "luntraș",
    "luntrașului": "luntraș",
    "luntrea": "luntre",
    "luntrei": "luntre",
    "luntrele": "luntre",
    "luntrelor": "luntre",
    "lupi": "lup",
    "lupii": "lup",
    "lupilor": "lup",
    "lupul": "lup",
    "lupului": "lup",
    "lupa": "lupă",
    "lupe": "lupă",
    "lupei": "lupă",
    "lupele": "lupă",
    "lupelor": "lupă",
    "Lupeniul": "Lupeni",
    "Lupeniului": "Lupeni",
    "lupoaica": "lupoaică",
    "lupoaice": "lupoaică",
    "lupoaicei": "lupoaică",
    "lupoaicele": "lupoaică",
    "lupoaicelor": "lupoaică",
    "lupt": "lupta",
    "luptă": "lupta",
    "luptai": "lupta",
    "luptam": "lupta",
    "luptăm": "lupta",
    "luptând": "lupta",
    "luptându": "lupta",
    "luptară": "lupta",
    "luptarăm": "lupta",
    "luptarăți": "lupta",
    "luptase": "lupta",
    "luptasem": "lupta",
    "luptaseră": "lupta",
    "luptaserăm": "lupta",
    "luptaserăți": "lupta",
    "luptaseși": "lupta",
    "luptași": "lupta",
    "luptat": "lupta",
    "luptați": "lupta",
    "luptatu": "lupta",
    "luptau": "lupta",
    "lupte": "lupta",
    "lupți": "lupta",
    "neluptând": "lupta",
    "neluptându": "lupta",
    "nemailuptând": "lupta",
    "nemailuptându": "lupta",
    "lupta": "luptă",
    "lupte": "luptă",
    "luptei": "luptă",
    "luptele": "luptă",
    "luptelor": "luptă",
    "luptată": "luptat",
    "luptate": "luptat",
    "luptați": "luptat",
    "luptători": "luptător",
    "luptătorii": "luptător",
    "luptătorilor": "luptător",
    "luptătorul": "luptător",
    "luptătorului": "luptător",
    "Lupușorul": "Lupușoru",
    "Lupușorului": "Lupușoru",
    "lustragii": "lustragiu",
    "lustragiii": "lustragiu",
    "lustragiilor": "lustragiu",
    "lustragiul": "lustragiu",
    "lustragiului": "lustragiu",
    "lustrația": "lustrație",
    "lustrației": "lustrație",
    "lustrații": "lustrație",
    "lustrațiile": "lustrație",
    "lustrațiilor": "lustrație",
    "lustrul": "lustru",
    "lustrului": "lustru",
    "lustruri": "lustru",
    "lustrurile": "lustru",
    "lustrurilor": "lustru",
    "lustruia": "lustrui",
    "lustruiai": "lustrui",
    "lustruiam": "lustrui",
    "lustruiască": "lustrui",
    "lustruiați": "lustrui",
    "lustruiau": "lustrui",
    "lustruiesc": "lustrui",
    "lustruiește": "lustrui",
    "lustruiești": "lustrui",
    "lustruii": "lustrui",
    "lustruim": "lustrui",
    "lustruind": "lustrui",
    "lustruindu": "lustrui",
    "lustruiră": "lustrui",
    "lustruirăm": "lustrui",
    "lustruirăți": "lustrui",
    "lustruise": "lustrui",
    "lustruisem": "lustrui",
    "lustruiseră": "lustrui",
    "lustruiserăm": "lustrui",
    "lustruiserăți": "lustrui",
    "lustruiseși": "lustrui",
    "lustruiși": "lustrui",
    "lustruit": "lustrui",
    "lustruiți": "lustrui",
    "lustruitu": "lustrui",
    "nelustruind": "lustrui",
    "nelustruindu": "lustrui",
    "nemailustruind": "lustrui",
    "nemailustruindu": "lustrui",
    "lustruită": "lustruit",
    "lustruite": "lustruit",
    "lustruiți": "lustruit",
    "lustruitul": "lustruit",
    "lustruitului": "lustruit",
    "lutul": "lut",
    "lutului": "lut",
    "luturi": "lut",
    "luturile": "lut",
    "luturilor": "lut",
    "Lu": "lutețiu",
    "lutețiul": "lutețiu",
    "lutețiului": "lutețiu",
    "lutoasa": "lutos",
    "lutoasă": "lutos",
    "lutoase": "lutos",
    "lutoasei": "lutos",
    "lutoasele": "lutos",
    "lutoaselor": "lutos",
    "lutoaso": "lutos",
    "lutoși": "lutos",
    "lutoșii": "lutos",
    "lutoșilor": "lutos",
    "lutosul": "lutos",
    "lutosule": "lutos",
    "lutosului": "lutos",
    "L": "lux",
    "lucși": "lux",
    "lucșii": "lux",
    "lucșilor": "lux",
    "luxul": "lux",
    "luxului": "lux",
    "luxuri": "lux",
    "luxurile": "lux",
    "luxurilor": "lux",
    "Lx": "lux",
    "luxă": "luxa",
    "luxai": "luxa",
    "luxam": "luxa",
    "luxăm": "luxa",
    "luxând": "luxa",
    "luxându": "luxa",
    "luxară": "luxa",
    "luxarăm": "luxa",
    "luxarăți": "luxa",
    "luxase": "luxa",
    "luxasem": "luxa",
    "luxaseră": "luxa",
    "luxaserăm": "luxa",
    "luxaserăți": "luxa",
    "luxaseși": "luxa",
    "luxași": "luxa",
    "luxat": "luxa",
    "luxați": "luxa",
    "luxatu": "luxa",
    "luxau": "luxa",
    "luxează": "luxa",
    "luxez": "luxa",
    "luxeze": "luxa",
    "luxezi": "luxa",
    "neluxând": "luxa",
    "neluxându": "luxa",
    "nemailuxând": "luxa",
    "nemailuxându": "luxa",
    "luxată": "luxat",
    "luxate": "luxat",
    "luxați": "luxat",
    "luxația": "luxație",
    "luxației": "luxație",
    "luxații": "luxație",
    "luxațiile": "luxație",
    "luxațiilor": "luxație",
    "Luxemburgul": "Luxemburg",
    "Luxemburgului": "Luxemburg",
    "luxoasa": "luxos",
    "luxoasă": "luxos",
    "luxoase": "luxos",
    "luxoasei": "luxos",
    "luxoasele": "luxos",
    "luxoaselor": "luxos",
    "luxoși": "luxos",
    "luxoșii": "luxos",
    "luxoșilor": "luxos",
    "luxosul": "luxos",
    "luxosului": "luxos",
    "luxurianta": "luxuriant",
    "luxuriantă": "luxuriant",
    "luxuriante": "luxuriant",
    "luxuriantei": "luxuriant",
    "luxuriantele": "luxuriant",
    "luxuriantelor": "luxuriant",
    "luxurianți": "luxuriant",
    "luxurianții": "luxuriant",
    "luxurianților": "luxuriant",
    "luxuriantul": "luxuriant",
    "luxuriantului": "luxuriant",
    "Lydianului": "Lydia",
    "Lydiei": "Lydia",
    "maci": "mac",
    "macii": "mac",
    "macilor": "mac",
    "macul": "mac",
    "macului": "mac",
    "macabra": "macabru",
    "macabră": "macabru",
    "macabre": "macabru",
    "macabrei": "macabru",
    "macabrele": "macabru",
    "macabrelor": "macabru",
    "macabri": "macabru",
    "macabrii": "macabru",
    "macabrilor": "macabru",
    "macabrul": "macabru",
    "macabrului": "macabru",
    "macadamul": "macadam",
    "macadamului": "macadam",
    "macadamuri": "macadam",
    "macadamurile": "macadam",
    "macadamurilor": "macadam",
    "măcăia": "măcăi",
    "măcăiai": "măcăi",
    "măcăiam": "măcăi",
    "măcăiați": "măcăi",
    "măcăiau": "măcăi",
    "măcăie": "măcăi",
    "măcăii": "măcăi",
    "măcăim": "măcăi",
    "măcăind": "măcăi",
    "măcăindu": "măcăi",
    "măcăiră": "măcăi",
    "măcăirăm": "măcăi",
    "măcăirăți": "măcăi",
    "măcăise": "măcăi",
    "măcăisem": "măcăi",
    "măcăiseră": "măcăi",
    "măcăiserăm": "măcăi",
    "măcăiserăți": "măcăi",
    "măcăiseși": "măcăi",
    "măcăiși": "măcăi",
    "măcăit": "măcăi",
    "măcăiți": "măcăi",
    "măcăitu": "măcăi",
    "măcăiala": "măcăială",
    "măcăieli": "măcăială",
    "măcăielii": "măcăială",
    "măcăielile": "măcăială",
    "măcăielilor": "măcăială",
    "măcăită": "măcăit",
    "măcăite": "măcăit",
    "măcăiți": "măcăit",
    "măcăitul": "măcăit",
    "măcăitului": "măcăit",
    "măcăituri": "măcăit",
    "măcăiturile": "măcăit",
    "măcăiturilor": "măcăit",
    "măcăitoare": "măcăitor",
    "măcăitoarea": "măcăitor",
    "măcăitoarei": "măcăitor",
    "măcăitoarele": "măcăitor",
    "măcăitoarelor": "măcăitor",
    "măcăitori": "măcăitor",
    "măcăitorii": "măcăitor",
    "măcăitorilor": "măcăitor",
    "măcăitorul": "măcăitor",
    "măcăitorului": "măcăitor",
    "macarale": "macara",
    "macaralei": "macara",
    "macaralele": "macara",
    "macaralelor": "macara",
    "macaraua": "macara",
    "macaragii": "macaragiu",
    "macaragiii": "macaragiu",
    "macaragiilor": "macaragiu",
    "macaragiul": "macaragiu",
    "macaragiului": "macaragiu",
    "macaroana": "macaroană",
    "macaroane": "macaroană",
    "macaroanei": "macaroană",
    "macaroanele": "macaroană",
    "macaroanelor": "macaroană",
    "macazul": "macaz",
    "macazului": "macaz",
    "macazuri": "macaz",
    "macazurile": "macaz",
    "macazurilor": "macaz",
    "măceașa": "măceașă",
    "măceșe": "măceașă",
    "măceșei": "măceașă",
    "măceșele": "măceașă",
    "măceșelor": "măceașă",
    "macedoneana": "macedonean",
    "macedoneană": "macedonean",
    "macedoneanul": "macedonean",
    "macedoneanului": "macedonean",
    "macedonene": "macedonean",
    "macedonenei": "macedonean",
    "macedonenele": "macedonean",
    "macedonenelor": "macedonean",
    "macedoneni": "macedonean",
    "macedonenii": "macedonean",
    "macedonenilor": "macedonean",
    "Macedoniei": "Macedonia",
    "macedoromâna": "macedoromân",
    "macedoromână": "macedoromân",
    "macedoromâne": "macedoromân",
    "macedoromânei": "macedoromân",
    "macedoromânele": "macedoromân",
    "macedoromânelor": "macedoromân",
    "macedoromâni": "macedoromân",
    "macedoromânii": "macedoromân",
    "macedoromânilor": "macedoromân",
    "macedoromânul": "macedoromân",
    "macedoromânului": "macedoromân",
    "măcelul": "măcel",
    "măcelului": "măcel",
    "măceluri": "măcel",
    "măcelurile": "măcel",
    "măcelurilor": "măcel",
    "măcelari": "măcelar",
    "măcelarii": "măcelar",
    "măcelarilor": "măcelar",
    "măcelarul": "măcelar",
    "măcelarului": "măcelar",
    "măcelărea": "măcelări",
    "măcelăreai": "măcelări",
    "măcelăream": "măcelări",
    "măcelărească": "măcelări",
    "măcelăreați": "măcelări",
    "măcelăreau": "măcelări",
    "măcelăresc": "măcelări",
    "măcelărește": "măcelări",
    "măcelărești": "măcelări",
    "măcelării": "măcelări",
    "măcelărim": "măcelări",
    "măcelărind": "măcelări",
    "măcelărindu": "măcelări",
    "măcelăriră": "măcelări",
    "măcelărirăm": "măcelări",
    "măcelărirăți": "măcelări",
    "măcelărise": "măcelări",
    "măcelărisem": "măcelări",
    "măcelăriseră": "măcelări",
    "măcelăriserăm": "măcelări",
    "măcelăriserăți": "măcelări",
    "măcelăriseși": "măcelări",
    "măcelăriși": "măcelări",
    "măcelărit": "măcelări",
    "măcelăriți": "măcelări",
    "măcelăritu": "măcelări",
    "nemăcelărind": "măcelări",
    "nemăcelărindu": "măcelări",
    "nemaimăcelărind": "măcelări",
    "nemaimăcelărindu": "măcelări",
    "măcelărirea": "măcelărire",
    "măcelărireo": "măcelărire",
    "măcelăriri": "măcelărire",
    "măcelăririi": "măcelărire",
    "măcelăririle": "măcelărire",
    "măcelăririlor": "măcelărire",
    "măcelărită": "măcelărit",
    "măcelărite": "măcelărit",
    "măcelăriți": "măcelărit",
    "maceră": "macera",
    "macerai": "macera",
    "maceram": "macera",
    "macerăm": "macera",
    "macerând": "macera",
    "macerându": "macera",
    "macerară": "macera",
    "macerarăm": "macera",
    "macerarăți": "macera",
    "macerase": "macera",
    "macerasem": "macera",
    "maceraseră": "macera",
    "maceraserăm": "macera",
    "maceraserăți": "macera",
    "maceraseși": "macera",
    "macerași": "macera",
    "macerat": "macera",
    "macerați": "macera",
    "maceratu": "macera",
    "macerau": "macera",
    "macerează": "macera",
    "macerez": "macera",
    "macereze": "macera",
    "macerezi": "macera",
    "nemacerând": "macera",
    "nemacerându": "macera",
    "nemaimacerând": "macera",
    "nemaimacerându": "macera",
    "macerată": "macerat",
    "macerate": "macerat",
    "macerați": "macerat",
    "măceși": "măceș",
    "măceșii": "măceș",
    "măceșilor": "măceș",
    "măceșul": "măceș",
    "măceșului": "măceș",
    "macheta": "machetă",
    "machete": "machetă",
    "machetei": "machetă",
    "machetele": "machetă",
    "machetelor": "machetă",
    "machiai": "machia",
    "machiam": "machia",
    "machiară": "machia",
    "machiarăm": "machia",
    "machiarăți": "machia",
    "machiase": "machia",
    "machiasem": "machia",
    "machiaseră": "machia",
    "machiaserăm": "machia",
    "machiaserăți": "machia",
    "machiaseși": "machia",
    "machiași": "machia",
    "machiat": "machia",
    "machiați": "machia",
    "machiatu": "machia",
    "machiau": "machia",
    "machiază": "machia",
    "machie": "machia",
    "machiem": "machia",
    "machiez": "machia",
    "machieze": "machia",
    "machiezi": "machia",
    "machiind": "machia",
    "machiindu": "machia",
    "nemachiind": "machia",
    "nemachiindu": "machia",
    "nemaimachiind": "machia",
    "nemaimachiindu": "machia",
    "machiaje": "machiaj",
    "machiajele": "machiaj",
    "machiajelor": "machiaj",
    "machiajul": "machiaj",
    "machiajului": "machiaj",
    "machiată": "machiat",
    "machiate": "machiat",
    "machiați": "machiat",
    "machiavelica": "machiavelic",
    "machiavelică": "machiavelic",
    "machiavelice": "machiavelic",
    "machiavelicei": "machiavelic",
    "machiavelicele": "machiavelic",
    "machiavelicelor": "machiavelic",
    "machiavelici": "machiavelic",
    "machiavelicii": "machiavelic",
    "machiavelicilor": "machiavelic",
    "machiavelicul": "machiavelic",
    "machiavelicului": "machiavelic",
    "machiavelisme": "machiavelism",
    "machiavelismele": "machiavelism",
    "machiavelismelor": "machiavelism",
    "machiavelismul": "machiavelism",
    "machiavelismului": "machiavelism",
    "machiori": "machior",
    "machiorii": "machior",
    "machiorilor": "machior",
    "machiorul": "machior",
    "machiorului": "machior",
    "macin": "măcina",
    "macină": "măcina",
    "măcină": "măcina",
    "măcinai": "măcina",
    "măcinam": "măcina",
    "măcinăm": "măcina",
    "măcinând": "măcina",
    "măcinându": "măcina",
    "măcinară": "măcina",
    "măcinarăm": "măcina",
    "măcinarăți": "măcina",
    "măcinase": "măcina",
    "măcinasem": "măcina",
    "măcinaseră": "măcina",
    "măcinaserăm": "măcina",
    "măcinaserăți": "măcina",
    "măcinaseși": "măcina",
    "măcinași": "măcina",
    "măcinat": "măcina",
    "măcinați": "măcina",
    "măcinatu": "măcina",
    "măcinau": "măcina",
    "macine": "măcina",
    "macini": "măcina",
    "nemăcinând": "măcina",
    "nemăcinându": "măcina",
    "nemaimăcinând": "măcina",
    "nemaimăcinându": "măcina",
    "măcinarea": "măcinare",
    "măcinareo": "măcinare",
    "măcinări": "măcinare",
    "măcinării": "măcinare",
    "măcinările": "măcinare",
    "măcinărilor": "măcinare",
    "măcinată": "măcinat",
    "măcinate": "măcinat",
    "măcinați": "măcinat",
    "măciuca": "măciucă",
    "măciuci": "măciucă",
    "măciucii": "măciucă",
    "măciucile": "măciucă",
    "măciucilor": "măciucă",
    "macrameul": "macrameu",
    "macrameului": "macrameu",
    "macrameuri": "macrameu",
    "macrameurile": "macrameu",
    "macrameurilor": "macrameu",
    "macroeconomica": "macroeconomic",
    "macroeconomică": "macroeconomic",
    "macroeconomice": "macroeconomic",
    "macroeconomicei": "macroeconomic",
    "macroeconomicele": "macroeconomic",
    "macroeconomicelor": "macroeconomic",
    "macroeconomici": "macroeconomic",
    "macroeconomicii": "macroeconomic",
    "macroeconomicilor": "macroeconomic",
    "macroeconomico": "macroeconomic",
    "macroeconomicul": "macroeconomic",
    "macroeconomicule": "macroeconomic",
    "macroeconomicului": "macroeconomic",
    "macromoleculara": "macromolecular",
    "macromoleculară": "macromolecular",
    "macromoleculare": "macromolecular",
    "macromolecularei": "macromolecular",
    "macromolecularele": "macromolecular",
    "macromolecularelor": "macromolecular",
    "macromoleculari": "macromolecular",
    "macromolecularii": "macromolecular",
    "macromolecularilor": "macromolecular",
    "macromolecularul": "macromolecular",
    "macromolecularului": "macromolecular",
    "macroscopica": "macroscopic",
    "macroscopică": "macroscopic",
    "macroscopice": "macroscopic",
    "macroscopicei": "macroscopic",
    "macroscopicele": "macroscopic",
    "macroscopicelor": "macroscopic",
    "macroscopici": "macroscopic",
    "macroscopicii": "macroscopic",
    "macroscopicilor": "macroscopic",
    "macroscopicul": "macroscopic",
    "macroscopicului": "macroscopic",
    "macrostabilizarea": "macrostabilizare",
    "macrostabilizări": "macrostabilizare",
    "macrostabilizării": "macrostabilizare",
    "macrostabilizările": "macrostabilizare",
    "macrostabilizărilor": "macrostabilizare",
    "macroul": "macrou",
    "macroului": "macrou",
    "macrouri": "macrou",
    "macrourile": "macrou",
    "macrourilor": "macrou",
    "macra": "macru",
    "macră": "macru",
    "macre": "macru",
    "macrei": "macru",
    "macrele": "macru",
    "macrelor": "macru",
    "macri": "macru",
    "macrii": "macru",
    "macrilor": "macru",
    "macrul": "macru",
    "macrului": "macru",
    "maculatura": "maculatură",
    "maculaturi": "maculatură",
    "maculaturii": "maculatură",
    "maculaturile": "maculatură",
    "maculaturilor": "maculatură",
    "Mme": "madame",
    "Madonă": "Madona",
    "Madone": "Madona",
    "Madonei": "Madona",
    "Madonele": "Madona",
    "Madonelor": "Madona",
    "madona": "madonă",
    "madone": "madonă",
    "madonei": "madonă",
    "madonele": "madonă",
    "madonelor": "madonă",
    "Madridul": "Madrid",
    "Madridului": "Madrid",
    "madrigalul": "madrigal",
    "madrigalului": "madrigal",
    "madrigaluri": "madrigal",
    "madrigalurile": "madrigal",
    "madrigalurilor": "madrigal",
    "madrilena": "madrilen",
    "madrilenă": "madrilen",
    "madrilene": "madrilen",
    "madrilenei": "madrilen",
    "madrilenele": "madrilen",
    "madrilenelor": "madrilen",
    "madrileni": "madrilen",
    "madrilenii": "madrilen",
    "madrilenilor": "madrilen",
    "madrileno": "madrilen",
    "madrilenul": "madrilen",
    "madrilenule": "madrilen",
    "madrilenului": "madrilen",
    "mădulare": "mădular",
    "mădularele": "mădular",
    "mădularelor": "mădular",
    "mădularul": "mădular",
    "mădularului": "mădular",
    "măduva": "măduvă",
    "măduve": "măduvă",
    "măduvei": "măduvă",
    "măduvele": "măduvă",
    "măduvelor": "măduvă",
    "maeștri": "maestru",
    "maeștrii": "maestru",
    "maeștrilor": "maestru",
    "maestrul": "maestru",
    "maestrului": "maestru",
    "mafia": "mafie",
    "mafiei": "mafie",
    "mafii": "mafie",
    "mafiile": "mafie",
    "mafiilor": "mafie",
    "mafioți": "mafiot",
    "mafioții": "mafiot",
    "mafioților": "mafiot",
    "mafiotul": "mafiot",
    "mafiotului": "mafiot",
    "magi": "mag",
    "magii": "mag",
    "magilor": "mag",
    "magul": "mag",
    "magului": "mag",
    "măgari": "măgar",
    "măgarii": "măgar",
    "măgarilor": "măgar",
    "măgarul": "măgar",
    "măgarule": "măgar",
    "măgarului": "măgar",
    "măgăreasca": "măgăresc",
    "măgărească": "măgăresc",
    "măgărescul": "măgăresc",
    "măgărescului": "măgăresc",
    "măgărești": "măgăresc",
    "măgăreștii": "măgăresc",
    "măgăreștile": "măgăresc",
    "măgăreștilor": "măgăresc",
    "mag.": "magazie",
    "magazia": "magazie",
    "magaziei": "magazie",
    "magazii": "magazie",
    "magaziile": "magazie",
    "magaziilor": "magazie",
    "magazine": "magazin",
    "magazinele": "magazin",
    "magazinelor": "magazin",
    "magazinu": "magazin",
    "magazinul": "magazin",
    "magazinului": "magazin",
    "magazineri": "magaziner",
    "magazinerii": "magaziner",
    "magazinerilor": "magaziner",
    "magazinerul": "magaziner",
    "magazinerului": "magaziner",
    "Magdei": "Magda",
    "Magdalenei": "Magdalena",
    "maghernițe": "magherniță",
    "maghiara": "maghiar",
    "maghiară": "maghiar",
    "maghiare": "maghiar",
    "maghiarei": "maghiar",
    "maghiarele": "maghiar",
    "maghiarelor": "maghiar",
    "maghiari": "maghiar",
    "maghiarii": "maghiar",
    "maghiarilor": "maghiar",
    "maghiaro": "maghiar",
    "maghiarul": "maghiar",
    "maghiarule": "maghiar",
    "maghiarului": "maghiar",
    "magh.": "maghiară",
    "maghiara": "maghiară",
    "maghiarei": "maghiară",
    "maghiarimea": "maghiarime",
    "maghiarimi": "maghiarime",
    "maghiarimii": "maghiarime",
    "maghiarizata": "maghiarizat",
    "maghiarizată": "maghiarizat",
    "maghiarizate": "maghiarizat",
    "maghiarizatei": "maghiarizat",
    "maghiarizatele": "maghiarizat",
    "maghiarizatelor": "maghiarizat",
    "maghiarizați": "maghiarizat",
    "maghiarizații": "maghiarizat",
    "maghiarizaților": "maghiarizat",
    "maghiarizato": "maghiarizat",
    "maghiarizatul": "maghiarizat",
    "maghiarizatule": "maghiarizat",
    "maghiarizatului": "maghiarizat",
    "magica": "magic",
    "magică": "magic",
    "magice": "magic",
    "magicei": "magic",
    "magicele": "magic",
    "magicelor": "magic",
    "magici": "magic",
    "magicii": "magic",
    "magicilor": "magic",
    "magicul": "magic",
    "magicului": "magic",
    "magicianul": "magician",
    "magicianului": "magician",
    "magicieni": "magician",
    "magicienii": "magician",
    "magicienilor": "magician",
    "magia": "magie",
    "magiei": "magie",
    "magii": "magie",
    "magiile": "magie",
    "magiilor": "magie",
    "magistrala": "magistral",
    "magistrală": "magistral",
    "magistrale": "magistral",
    "magistralei": "magistral",
    "magistralele": "magistral",
    "magistralelor": "magistral",
    "magistrali": "magistral",
    "magistralii": "magistral",
    "magistralilor": "magistral",
    "magistralul": "magistral",
    "magistralului": "magistral",
    "magistrala": "magistrală",
    "magistrale": "magistrală",
    "magistralei": "magistrală",
    "magistralele": "magistrală",
    "magistralelor": "magistrală",
    "magistrați": "magistrat",
    "magistrații": "magistrat",
    "magistraților": "magistrat",
    "magistratul": "magistrat",
    "magistratului": "magistrat",
    "magistratura": "magistratură",
    "magistraturi": "magistratură",
    "magistraturii": "magistratură",
    "magistraturile": "magistratură",
    "magistraturilor": "magistratură",
    "magiștri": "magistru",
    "magiștrii": "magistru",
    "magiștrilor": "magistru",
    "magistrul": "magistru",
    "magistrului": "magistru",
    "magiunul": "magiun",
    "magiunului": "magiun",
    "magiunuri": "magiun",
    "magiunurile": "magiun",
    "magiunurilor": "magiun",
    "magma": "magmă",
    "magme": "magmă",
    "magmei": "magmă",
    "magmele": "magmă",
    "magmelor": "magmă",
    "magmatica": "magmatic",
    "magmatică": "magmatic",
    "magmatice": "magmatic",
    "magmaticei": "magmatic",
    "magmaticele": "magmatic",
    "magmaticelor": "magmatic",
    "magmatici": "magmatic",
    "magmaticii": "magmatic",
    "magmaticilor": "magmatic",
    "magmaticul": "magmatic",
    "magmaticului": "magmatic",
    "magnați": "magnat",
    "magnații": "magnat",
    "magnaților": "magnat",
    "magnatul": "magnat",
    "magnatului": "magnat",
    "magneți": "magnet",
    "magneții": "magnet",
    "magneților": "magnet",
    "magnetul": "magnet",
    "magnetului": "magnet",
    "magnetica": "magnetic",
    "magnetică": "magnetic",
    "magnetice": "magnetic",
    "magneticei": "magnetic",
    "magneticele": "magnetic",
    "magneticelor": "magnetic",
    "magnetici": "magnetic",
    "magneticii": "magnetic",
    "magneticilor": "magnetic",
    "magneticul": "magnetic",
    "magneticului": "magnetic",
    "magnetisme": "magnetism",
    "magnetismele": "magnetism",
    "magnetismelor": "magnetism",
    "magnetismul": "magnetism",
    "magnetismului": "magnetism",
    "mag.": "magnetofon",
    "magnetofoane": "magnetofon",
    "magnetofoanele": "magnetofon",
    "magnetofoanelor": "magnetofon",
    "magnetofonul": "magnetofon",
    "magnetofonului": "magnetofon",
    "magneziul": "magneziu",
    "magneziului": "magneziu",
    "Mg": "magneziu",
    "magnifica": "magnific",
    "magnifică": "magnific",
    "magnifice": "magnific",
    "magnificei": "magnific",
    "magnificele": "magnific",
    "magnificelor": "magnific",
    "magnifici": "magnific",
    "magnificii": "magnific",
    "magnificilor": "magnific",
    "magnificul": "magnific",
    "magnificului": "magnific",
    "magnitudinea": "magnitudine",
    "magnitudineo": "magnitudine",
    "magnitudini": "magnitudine",
    "magnitudinii": "magnitudine",
    "magnitudinile": "magnitudine",
    "magnitudinilor": "magnitudine",
    "magnolia": "magnolie",
    "magnoliei": "magnolie",
    "magnolii": "magnolie",
    "magnoliile": "magnolie",
    "magnoliilor": "magnolie",
    "măgulea": "măguli",
    "măguleai": "măguli",
    "măguleam": "măguli",
    "măgulească": "măguli",
    "măguleați": "măguli",
    "măguleau": "măguli",
    "măgulesc": "măguli",
    "măgulește": "măguli",
    "măgulești": "măguli",
    "măgulii": "măguli",
    "măgulim": "măguli",
    "măgulind": "măguli",
    "măgulindu": "măguli",
    "măguliră": "măguli",
    "măgulirăm": "măguli",
    "măgulirăți": "măguli",
    "măgulise": "măguli",
    "măgulisem": "măguli",
    "măguliseră": "măguli",
    "măguliserăm": "măguli",
    "măguliserăți": "măguli",
    "măguliseși": "măguli",
    "măguliși": "măguli",
    "măgulit": "măguli",
    "măguliți": "măguli",
    "măgulitu": "măguli",
    "nemăgulind": "măguli",
    "nemăgulindu": "măguli",
    "nemaimăgulind": "măguli",
    "nemaimăgulindu": "măguli",
    "măgulită": "măgulit",
    "măgulite": "măgulit",
    "măguliți": "măgulit",
    "măgulitoare": "măgulitor",
    "măgulitoarea": "măgulitor",
    "măgulitoarei": "măgulitor",
    "măgulitoarele": "măgulitor",
    "măgulitoarelor": "măgulitor",
    "măgulitori": "măgulitor",
    "măgulitorii": "măgulitor",
    "măgulitorilor": "măgulitor",
    "măgulitorul": "măgulitor",
    "măgulitorului": "măgulitor",
    "măgura": "măgură",
    "măguri": "măgură",
    "măgurii": "măgură",
    "măgurile": "măgură",
    "măgurilor": "măgură",
    "mahalale": "mahala",
    "mahalalei": "mahala",
    "mahalalele": "mahala",
    "mahalalelor": "mahala",
    "mahalaua": "mahala",
    "maharajahi": "maharajah",
    "maharajahii": "maharajah",
    "maharajahilor": "maharajah",
    "maharajahul": "maharajah",
    "maharajahului": "maharajah",
    "mahmura": "mahmur",
    "mahmură": "mahmur",
    "mahmure": "mahmur",
    "mahmurei": "mahmur",
    "mahmurele": "mahmur",
    "mahmurelor": "mahmur",
    "mahmuri": "mahmur",
    "mahmurii": "mahmur",
    "mahmurilor": "mahmur",
    "mahmurul": "mahmur",
    "mahmurului": "mahmur",
    "mahmureala": "mahmureală",
    "mahmureli": "mahmureală",
    "mahmurelii": "mahmureală",
    "mahmurelile": "mahmureală",
    "mahmurelilor": "mahmureală",
    "mâhnea": "mâhni",
    "mâhneai": "mâhni",
    "mâhneam": "mâhni",
    "mâhnească": "mâhni",
    "mâhneați": "mâhni",
    "mâhneau": "mâhni",
    "mâhnesc": "mâhni",
    "mâhnește": "mâhni",
    "mâhnești": "mâhni",
    "mâhnii": "mâhni",
    "mâhnim": "mâhni",
    "mâhnind": "mâhni",
    "mâhnindu": "mâhni",
    "mâhniră": "mâhni",
    "mâhnirăm": "mâhni",
    "mâhnirăți": "mâhni",
    "mâhnise": "mâhni",
    "mâhnisem": "mâhni",
    "mâhniseră": "mâhni",
    "mâhniserăm": "mâhni",
    "mâhniserăți": "mâhni",
    "mâhniseși": "mâhni",
    "mâhniși": "mâhni",
    "mâhnit": "mâhni",
    "mâhniți": "mâhni",
    "mâhnitu": "mâhni",
    "nemâhnind": "mâhni",
    "nemâhnindu": "mâhni",
    "nemaimâhnind": "mâhni",
    "nemaimâhnindu": "mâhni",
    "mâhnirea": "mâhnire",
    "mâhnireo": "mâhnire",
    "mâhniri": "mâhnire",
    "mâhnirii": "mâhnire",
    "mâhnirile": "mâhnire",
    "mâhnirilor": "mâhnire",
    "mâhnita": "mâhnit",
    "mâhnită": "mâhnit",
    "mâhnite": "mâhnit",
    "mâhnitei": "mâhnit",
    "mâhnitele": "mâhnit",
    "mâhnitelor": "mâhnit",
    "mâhniți": "mâhnit",
    "mâhniții": "mâhnit",
    "mâhniților": "mâhnit",
    "mâhnitul": "mâhnit",
    "mâhnitului": "mâhnit",
    "mahomedana": "mahomedan",
    "mahomedană": "mahomedan",
    "mahomedane": "mahomedan",
    "mahomedanei": "mahomedan",
    "mahomedanele": "mahomedan",
    "mahomedanelor": "mahomedan",
    "mahomedani": "mahomedan",
    "mahomedanii": "mahomedan",
    "mahomedanilor": "mahomedan",
    "mahomedanul": "mahomedan",
    "mahomedanului": "mahomedan",
    "mahomedana": "mahomedană",
    "mahomedane": "mahomedană",
    "mahomedanei": "mahomedană",
    "mahomedanele": "mahomedană",
    "mahomedanelor": "mahomedană",
    "mahomedanisme": "mahomedanism",
    "mahomedanismele": "mahomedanism",
    "mahomedanismelor": "mahomedanism",
    "mahomedanismul": "mahomedanism",
    "mahomedanismului": "mahomedanism",
    "mahoni": "mahon",
    "mahonii": "mahon",
    "mahonilor": "mahon",
    "mahonul": "mahon",
    "mahonului": "mahon",
    "ma'": "mai",
    "mai_marelui": "mai_marele",
    "mai_marii": "mai_marele",
    "mai_marilor": "mai_marele",
    "m.m.c.perf.": "mai_mult_ca_perfect",
    "m.m.p.": "mai_mult_ca_perfect",
    "maiaua": "maia",
    "maiele": "maia",
    "maielei": "maia",
    "maica": "maică",
    "maicăi": "maică",
    "maici": "maică",
    "maicii": "maică",
    "maicile": "maică",
    "maicilor": "maică",
    "măicuța": "măicuță",
    "măicuțe": "măicuță",
    "măicuței": "măicuță",
    "măicuțele": "măicuță",
    "măicuțelor": "măicuță",
    "măicuțo": "măicuță",
    "maidane": "maidan",
    "maidanele": "maidan",
    "maidanelor": "maidan",
    "maidanul": "maidan",
    "maidanului": "maidan",
    "maidanezi": "maidanez",
    "maidanezii": "maidanez",
    "maidanezilor": "maidanez",
    "maidanezul": "maidanez",
    "maidanezului": "maidanez",
    "maiestatea": "maiestate",
    "maiestăți": "maiestate",
    "maiestății": "maiestate",
    "maiestățile": "maiestate",
    "maiestăților": "maiestate",
    "măiestria": "măiestrie",
    "măiestriei": "măiestrie",
    "măiestrii": "măiestrie",
    "măiestriile": "măiestrie",
    "măiestriilor": "măiestrie",
    "măiestrio": "măiestrie",
    "măiastra": "măiestru",
    "măiastră": "măiestru",
    "măiestre": "măiestru",
    "măiestrei": "măiestru",
    "măiestrele": "măiestru",
    "măiestrelor": "măiestru",
    "măieștri": "măiestru",
    "măieștrii": "măiestru",
    "măieștrilor": "măiestru",
    "măiestrul": "măiestru",
    "măiestrului": "măiestru",
    "maiestuoasa": "maiestuos",
    "maiestuoasă": "maiestuos",
    "maiestuoase": "maiestuos",
    "maiestuoasei": "maiestuos",
    "maiestuoasele": "maiestuos",
    "maiestuoaselor": "maiestuos",
    "maiestuoși": "maiestuos",
    "maiestuoșii": "maiestuos",
    "maiestuoșilor": "maiestuos",
    "maiestuosul": "maiestuos",
    "maiestuosului": "maiestuos",
    "maimuța": "maimuță",
    "maimuțe": "maimuță",
    "maimuței": "maimuță",
    "maimuțele": "maimuță",
    "maimuțelor": "maimuță",
    "maimuțărea": "maimuțări",
    "maimuțăreai": "maimuțări",
    "maimuțăream": "maimuțări",
    "maimuțărească": "maimuțări",
    "maimuțăreați": "maimuțări",
    "maimuțăreau": "maimuțări",
    "maimuțăresc": "maimuțări",
    "maimuțărește": "maimuțări",
    "maimuțărești": "maimuțări",
    "maimuțării": "maimuțări",
    "maimuțărim": "maimuțări",
    "maimuțărind": "maimuțări",
    "maimuțărindu": "maimuțări",
    "maimuțăriră": "maimuțări",
    "maimuțărirăm": "maimuțări",
    "maimuțărirăți": "maimuțări",
    "maimuțărise": "maimuțări",
    "maimuțărisem": "maimuțări",
    "maimuțăriseră": "maimuțări",
    "maimuțăriserăm": "maimuțări",
    "maimuțăriserăți": "maimuțări",
    "maimuțăriseși": "maimuțări",
    "maimuțăriși": "maimuțări",
    "maimuțărit": "maimuțări",
    "maimuțăriți": "maimuțări",
    "maimuțăritu": "maimuțări",
    "nemaimaimuțărind": "maimuțări",
    "nemaimaimuțărindu": "maimuțări",
    "nemaimuțărind": "maimuțări",
    "nemaimuțărindu": "maimuțări",
    "maimuțărită": "maimuțărit",
    "maimuțărite": "maimuțărit",
    "maimuțăriți": "maimuțărit",
    "maioneza": "maioneză",
    "maioneze": "maioneză",
    "maionezei": "maioneză",
    "maionezele": "maioneză",
    "maionezelor": "maioneză",
    "maiori": "maior",
    "maiorii": "maior",
    "maiorilor": "maior",
    "maiorul": "maior",
    "maiorului": "maior",
    "maioul": "maiou",
    "maioului": "maiou",
    "maiouri": "maiou",
    "maiourile": "maiou",
    "maiourilor": "maiou",
    "maiștri": "maistru",
    "maiștrii": "maistru",
    "maiștrilor": "maistru",
    "maistrul": "maistru",
    "maistrului": "maistru",
    "majolica": "majolică",
    "majolice": "majolică",
    "majolicei": "majolică",
    "majolicele": "majolică",
    "majolicelor": "majolică",
    "majora": "major",
    "majoră": "major",
    "majore": "major",
    "majorei": "major",
    "majorele": "major",
    "majorelor": "major",
    "majori": "major",
    "majorii": "major",
    "majorilor": "major",
    "majorul": "major",
    "majorului": "major",
    "majoră": "majora",
    "majorai": "majora",
    "majoram": "majora",
    "majorăm": "majora",
    "majorând": "majora",
    "majorându": "majora",
    "majorară": "majora",
    "majorarăm": "majora",
    "majorarăți": "majora",
    "majorase": "majora",
    "majorasem": "majora",
    "majoraseră": "majora",
    "majoraserăm": "majora",
    "majoraserăți": "majora",
    "majoraseși": "majora",
    "majorași": "majora",
    "majorat": "majora",
    "majorați": "majora",
    "majoratu": "majora",
    "majorau": "majora",
    "majorează": "majora",
    "majorez": "majora",
    "majoreze": "majora",
    "majorezi": "majora",
    "nemaimajorând": "majora",
    "nemaimajorându": "majora",
    "nemajorând": "majora",
    "nemajorându": "majora",
    "majorarea": "majorare",
    "majorări": "majorare",
    "majorării": "majorare",
    "majorările": "majorare",
    "majorărilor": "majorare",
    "majorată": "majorat",
    "majorate": "majorat",
    "majoratele": "majorat",
    "majoratelor": "majorat",
    "majorați": "majorat",
    "majoratul": "majorat",
    "majoratului": "majorat",
    "majordomi": "majordom",
    "majordomii": "majordom",
    "majordomilor": "majordom",
    "majordomul": "majordom",
    "majordomului": "majordom",
    "majoritara": "majoritar",
    "majoritară": "majoritar",
    "majoritare": "majoritar",
    "majoritarei": "majoritar",
    "majoritarele": "majoritar",
    "majoritarelor": "majoritar",
    "majoritari": "majoritar",
    "majoritarii": "majoritar",
    "majoritarilor": "majoritar",
    "majoritarul": "majoritar",
    "majoritarului": "majoritar",
    "majoritatea": "majoritate",
    "majorități": "majoritate",
    "majorității": "majoritate",
    "majoritățile": "majoritate",
    "majorităților": "majoritate",
    "majuscula": "majusculă",
    "majuscule": "majusculă",
    "majusculei": "majusculă",
    "majusculele": "majusculă",
    "majusculelor": "majusculă",
    "malul": "mal",
    "malului": "mal",
    "maluri": "mal",
    "malurile": "mal",
    "malurilor": "mal",
    "mâlul": "mâl",
    "mâlului": "mâl",
    "mâluri": "mâl",
    "mâlurile": "mâl",
    "mâlurilor": "mâl",
    "malaci": "malac",
    "malacii": "malac",
    "malacilor": "malac",
    "malacul": "malac",
    "malacului": "malac",
    "maladia": "maladie",
    "maladiei": "maladie",
    "maladii": "maladie",
    "maladiile": "maladie",
    "maladiilor": "maladie",
    "maladiva": "maladiv",
    "maladivă": "maladiv",
    "maladive": "maladiv",
    "maladivei": "maladiv",
    "maladivele": "maladiv",
    "maladivelor": "maladiv",
    "maladivi": "maladiv",
    "maladivii": "maladiv",
    "maladivilor": "maladiv",
    "maladivul": "maladiv",
    "maladivului": "maladiv",
    "Malaeziei": "Malaezia",
    "mălaiul": "mălai",
    "mălaiule": "mălai",
    "mălaiului": "mălai",
    "mălaiuri": "mălai",
    "mălaiurile": "mălai",
    "mălaiurilor": "mălai",
    "mălăiața": "mălăieț",
    "mălăiață": "mălăieț",
    "mălăiețe": "mălăieț",
    "mălăieței": "mălăieț",
    "mălăiețele": "mălăieț",
    "mălăiețelor": "mălăieț",
    "mălăieți": "mălăieț",
    "mălăieții": "mălăieț",
    "mălăieților": "mălăieț",
    "mălăiețul": "mălăieț",
    "mălăiețului": "mălăieț",
    "malaria": "malarie",
    "malariei": "malarie",
    "malarii": "malarie",
    "malariile": "malarie",
    "malariilor": "malarie",
    "malaxoare": "malaxor",
    "malaxoarele": "malaxor",
    "malaxoarelor": "malaxor",
    "malaxorul": "malaxor",
    "malaxorului": "malaxor",
    "maldăre": "maldăr",
    "maldărele": "maldăr",
    "maldărelor": "maldăr",
    "maldărul": "maldăr",
    "maldărului": "maldăr",
    "maleabila": "maleabil",
    "maleabilă": "maleabil",
    "maleabile": "maleabil",
    "maleabilei": "maleabil",
    "maleabilele": "maleabil",
    "maleabilelor": "maleabil",
    "maleabili": "maleabil",
    "maleabilii": "maleabil",
    "maleabililor": "maleabil",
    "maleabilul": "maleabil",
    "maleabilului": "maleabil",
    "maleabilitatea": "maleabilitate",
    "maleabilități": "maleabilitate",
    "maleabilității": "maleabilitate",
    "maleabilitățile": "maleabilitate",
    "maleabilităților": "maleabilitate",
    "malefica": "malefic",
    "malefică": "malefic",
    "malefice": "malefic",
    "maleficei": "malefic",
    "maleficele": "malefic",
    "maleficelor": "malefic",
    "malefici": "malefic",
    "maleficii": "malefic",
    "maleficilor": "malefic",
    "maleficul": "malefic",
    "maleficului": "malefic",
    "malformația": "malformație",
    "malformației": "malformație",
    "malformații": "malformație",
    "malformațiile": "malformație",
    "malformațiilor": "malformație",
    "mâlea": "mâli",
    "mâleai": "mâli",
    "mâleam": "mâli",
    "mâlească": "mâli",
    "mâleați": "mâli",
    "mâleau": "mâli",
    "mâlesc": "mâli",
    "mâlește": "mâli",
    "mâlești": "mâli",
    "mâlii": "mâli",
    "mâlim": "mâli",
    "mâlind": "mâli",
    "mâlindu": "mâli",
    "mâliră": "mâli",
    "mâlirăm": "mâli",
    "mâlirăți": "mâli",
    "mâlise": "mâli",
    "mâlisem": "mâli",
    "mâliseră": "mâli",
    "mâliserăm": "mâli",
    "mâliserăți": "mâli",
    "mâliseși": "mâli",
    "mâliși": "mâli",
    "mâlit": "mâli",
    "mâliți": "mâli",
    "mâlitu": "mâli",
    "nemaimâlind": "mâli",
    "nemaimâlindu": "mâli",
    "nemâlind": "mâli",
    "nemâlindu": "mâli",
    "maligna": "malign",
    "malignă": "malign",
    "maligne": "malign",
    "malignei": "malign",
    "malignele": "malign",
    "malignelor": "malign",
    "maligni": "malign",
    "malignii": "malign",
    "malignilor": "malign",
    "malignul": "malign",
    "malignului": "malign",
    "mâlita": "mâlit",
    "mâlită": "mâlit",
    "mâlite": "mâlit",
    "mâlitei": "mâlit",
    "mâlitele": "mâlit",
    "mâlitelor": "mâlit",
    "mâliți": "mâlit",
    "mâliții": "mâlit",
    "mâliților": "mâlit",
    "mâlitul": "mâlit",
    "mâlitului": "mâlit",
    "maliția": "maliție",
    "maliției": "maliție",
    "maliții": "maliție",
    "malițiile": "maliție",
    "malițiilor": "maliție",
    "malițioasa": "malițios",
    "malițioasă": "malițios",
    "malițioase": "malițios",
    "malițioasei": "malițios",
    "malițioasele": "malițios",
    "malițioaselor": "malițios",
    "malițioși": "malițios",
    "malițioșii": "malițios",
    "malițioșilor": "malițios",
    "malițiosul": "malițios",
    "malițiosului": "malițios",
    "malițiozitatea": "malițiozitate",
    "malițiozități": "malițiozitate",
    "malițiozității": "malițiozitate",
    "malițiozitățile": "malițiozitate",
    "malițiozităților": "malițiozitate",
    "mâloasa": "mâlos",
    "mâloasă": "mâlos",
    "mâloase": "mâlos",
    "mâloasei": "mâlos",
    "mâloasele": "mâlos",
    "mâloaselor": "mâlos",
    "mâloși": "mâlos",
    "mâloșii": "mâlos",
    "mâloșilor": "mâlos",
    "mâlosul": "mâlos",
    "mâlosului": "mâlos",
    "Maltei": "Malta",
    "maltrată": "maltrata",
    "maltratai": "maltrata",
    "maltratam": "maltrata",
    "maltratăm": "maltrata",
    "maltratând": "maltrata",
    "maltratându": "maltrata",
    "maltratară": "maltrata",
    "maltratarăm": "maltrata",
    "maltratarăți": "maltrata",
    "maltratase": "maltrata",
    "maltratasem": "maltrata",
    "maltrataseră": "maltrata",
    "maltrataserăm": "maltrata",
    "maltrataserăți": "maltrata",
    "maltrataseși": "maltrata",
    "maltratași": "maltrata",
    "maltratat": "maltrata",
    "maltratați": "maltrata",
    "maltratatu": "maltrata",
    "maltratau": "maltrata",
    "maltratează": "maltrata",
    "maltratez": "maltrata",
    "maltrateze": "maltrata",
    "maltratezi": "maltrata",
    "nemaimaltratând": "maltrata",
    "nemaimaltratându": "maltrata",
    "nemaltratând": "maltrata",
    "nemaltratându": "maltrata",
    "maltratată": "maltratat",
    "maltratate": "maltratat",
    "maltratați": "maltratat",
    "mălurata": "mălurat",
    "mălurată": "mălurat",
    "mălurate": "mălurat",
    "măluratei": "mălurat",
    "măluratele": "mălurat",
    "măluratelor": "mălurat",
    "mălurați": "mălurat",
    "mălurații": "mălurat",
    "măluraților": "mălurat",
    "măluratul": "mălurat",
    "măluratului": "mălurat",
    "mă-": "mamă",
    "mama": "mamă",
    "mame": "mamă",
    "mamei": "mamă",
    "mamele": "mamă",
    "mamelor": "mamă",
    "mama-mare": "mamă-mare",
    "mamei-mari": "mamă-mare",
    "Mamei-Pădurii": "Mama-Pădurii",
    "mamara": "mamar",
    "mamară": "mamar",
    "mamare": "mamar",
    "mamarei": "mamar",
    "mamarele": "mamar",
    "mamarelor": "mamar",
    "mamari": "mamar",
    "mamarii": "mamar",
    "mamarilor": "mamar",
    "mamarul": "mamar",
    "mamarului": "mamar",
    "mama-soacră": "mamă-soacră",
    "mamei-soacre": "mamă-soacră",
    "mamela": "mamelă",
    "mamele": "mamelă",
    "mamelei": "mamelă",
    "mamelele": "mamelă",
    "mamelelor": "mamelă",
    "mameloane": "mamelon",
    "mameloanele": "mamelon",
    "mameloanelor": "mamelon",
    "mamelonul": "mamelon",
    "mamelonului": "mamelon",
    "mameluci": "mameluc",
    "mamelucii": "mameluc",
    "mamelucilor": "mameluc",
    "mamelucul": "mameluc",
    "mamelucului": "mameluc",
    "mămica": "mămică",
    "mămici": "mămică",
    "mămicii": "mămică",
    "mămicile": "mămică",
    "mămicilor": "mămică",
    "mămico": "mămică",
    "mamifere": "mamifer",
    "mamiferele": "mamifer",
    "mamiferelor": "mamifer",
    "mamiferul": "mamifer",
    "mamiferului": "mamifer",
    "mamoși": "mamoș",
    "mamoșii": "mamoș",
    "mamoșilor": "mamoș",
    "mamoșul": "mamoș",
    "mamoșule": "mamoș",
    "mamoșului": "mamoș",
    "mamuți": "mamut",
    "mamuții": "mamut",
    "mamuților": "mamut",
    "mamutul": "mamut",
    "mamutului": "mamut",
    "mân": "mâna",
    "mână": "mâna",
    "mânai": "mâna",
    "mânam": "mâna",
    "mânăm": "mâna",
    "mânând": "mâna",
    "mânându": "mâna",
    "mânară": "mâna",
    "mânarăm": "mâna",
    "mânarăți": "mâna",
    "mânase": "mâna",
    "mânasem": "mâna",
    "mânaseră": "mâna",
    "mânaserăm": "mâna",
    "mânaserăți": "mâna",
    "mânaseși": "mâna",
    "mânași": "mâna",
    "mânat": "mâna",
    "mânați": "mâna",
    "mânatu": "mâna",
    "mânau": "mâna",
    "mâne": "mâna",
    "mâni": "mâna",
    "nemaimânând": "mâna",
    "nemaimânându": "mâna",
    "nemânând": "mâna",
    "nemânându": "mâna",
    "mâini": "mână",
    "mâinii": "mână",
    "mâinile": "mână",
    "mâinilor": "mână",
    "mâna": "mână",
    "mâni": "mână",
    "managementul": "management",
    "managementului": "management",
    "manageri": "manager",
    "managerii": "manager",
    "managerilor": "manager",
    "managerul": "manager",
    "managerului": "manager",
    "manageriala": "managerial",
    "managerială": "managerial",
    "manageriale": "managerial",
    "managerialei": "managerial",
    "managerialele": "managerial",
    "managerialelor": "managerial",
    "manageriali": "managerial",
    "managerialii": "managerial",
    "managerialilor": "managerial",
    "managerialul": "managerial",
    "managerialului": "managerial",
    "mânăreala": "mânăreală",
    "mânăreli": "mânăreală",
    "mânărelii": "mânăreală",
    "mânărelile": "mânăreală",
    "mânărelilor": "mânăreală",
    "mânăream": "mânări",
    "mânărească": "mânări",
    "mânăreau": "mânări",
    "mânăresc": "mânări",
    "mânărește": "mânări",
    "mânărești": "mânări",
    "mânării": "mânări",
    "mânărim": "mânări",
    "mânărind": "mânări",
    "mânărindu": "mânări",
    "mânăriră": "mânări",
    "mânărirăm": "mânări",
    "mânărirăți": "mânări",
    "mânărise": "mânări",
    "mânărisem": "mânări",
    "mânăriseră": "mânări",
    "mânăriserăm": "mânări",
    "mânăriserăți": "mânări",
    "mânăriseși": "mânări",
    "mânăriși": "mânări",
    "mânărit": "mânări",
    "mânăriți": "mânări",
    "mânăritu": "mânări",
    "mânărită": "mânărit",
    "mânărite": "mânărit",
    "mânăriți": "mânărit",
    "mânăritul": "mânărit",
    "mânăritului": "mânărit",
    "mânăstirea": "mânăstire",
    "mânăstiri": "mânăstire",
    "mânăstirii": "mânăstire",
    "mânăstirile": "mânăstire",
    "mânăstirilor": "mânăstire",
    "măn.": "mănăstire",
    "mănăstirea": "mănăstire",
    "mănăstireo": "mănăstire",
    "mănăstiri": "mănăstire",
    "mănăstirii": "mănăstire",
    "mănăstirile": "mănăstire",
    "mănăstirilor": "mănăstire",
    "mănăstireasca": "mănăstiresc",
    "mănăstirească": "mănăstiresc",
    "mănăstirescul": "mănăstiresc",
    "mănăstirescului": "mănăstiresc",
    "mănăstirești": "mănăstiresc",
    "mănăstireștii": "mănăstiresc",
    "mănăstireștile": "mănăstiresc",
    "mănăstireștilor": "mănăstiresc",
    "mânată": "mânat",
    "mânate": "mânat",
    "mânați": "mânat",
    "mânătarca": "mânătarcă",
    "mânătărci": "mânătarcă",
    "mânătărcii": "mânătarcă",
    "mânătărcile": "mânătarcă",
    "mânătărcilor": "mânătarcă",
    "mănânc": "mânca",
    "mănâncă": "mânca",
    "mănânce": "mânca",
    "mănânci": "mânca",
    "mâncă": "mânca",
    "mâncai": "mânca",
    "mâncam": "mânca",
    "mâncăm": "mânca",
    "mâncând": "mânca",
    "mâncându": "mânca",
    "mâncară": "mânca",
    "mâncarăm": "mânca",
    "mâncarăți": "mânca",
    "mâncase": "mânca",
    "mâncasem": "mânca",
    "mâncaseră": "mânca",
    "mâncaserăm": "mânca",
    "mâncaserăți": "mânca",
    "mâncaseși": "mânca",
    "mâncași": "mânca",
    "mâncat": "mânca",
    "mâncați": "mânca",
    "mâncatu": "mânca",
    "mâncau": "mânca",
    "nemaimâncând": "mânca",
    "nemaimâncându": "mânca",
    "nemâncând": "mânca",
    "nemâncându": "mânca",
    "mâncăcioasa": "mâncăcioasă",
    "mâncăcioase": "mâncăcioasă",
    "mâncăcioasei": "mâncăcioasă",
    "mâncăcioasele": "mâncăcioasă",
    "mâncăcioaselor": "mâncăcioasă",
    "mâncăcioasa": "mâncăcios",
    "mâncăcioasă": "mâncăcios",
    "mâncăcioase": "mâncăcios",
    "mâncăcioasei": "mâncăcios",
    "mâncăcioasele": "mâncăcios",
    "mâncăcioaselor": "mâncăcios",
    "mâncăcioși": "mâncăcios",
    "mâncăcioșii": "mâncăcios",
    "mâncăcioșilor": "mâncăcios",
    "mâncăciosul": "mâncăcios",
    "mâncăciosului": "mâncăcios",
    "mâncarea": "mâncare",
    "mâncări": "mâncare",
    "mâncării": "mâncare",
    "mâncăruri": "mâncare",
    "mâncărurile": "mâncare",
    "mâncărurilor": "mâncare",
    "mâncărimea": "mâncărime",
    "mâncărimi": "mâncărime",
    "mâncărimii": "mâncărime",
    "mâncărimile": "mâncărime",
    "mâncărimilor": "mâncărime",
    "mâncata": "mâncat",
    "mâncată": "mâncat",
    "mâncate": "mâncat",
    "mâncatei": "mâncat",
    "mâncatele": "mâncat",
    "mâncatelor": "mâncat",
    "mâncați": "mâncat",
    "mâncații": "mâncat",
    "mâncaților": "mâncat",
    "mâncatul": "mâncat",
    "mâncatului": "mâncat",
    "mâncătoare": "mâncător",
    "mâncătoarea": "mâncător",
    "mâncătoarei": "mâncător",
    "mâncătoarele": "mâncător",
    "mâncătoarelor": "mâncător",
    "mâncători": "mâncător",
    "mâncătorii": "mâncător",
    "mâncătorilor": "mâncător",
    "mâncătorul": "mâncător",
    "mâncătorului": "mâncător",
    "mâncătoria": "mâncătorie",
    "mâncătoriei": "mâncătorie",
    "mâncătorii": "mâncătorie",
    "mâncătoriile": "mâncătorie",
    "mâncătoriilor": "mâncătorie",
    "mâncătura": "mâncătură",
    "mâncături": "mâncătură",
    "mâncăturii": "mâncătură",
    "mâncăturile": "mâncătură",
    "mâncăturilor": "mâncătură",
    "mâncăi": "mâncău",
    "mâncăii": "mâncău",
    "mâncăilor": "mâncău",
    "mâncăul": "mâncău",
    "mâncăului": "mâncău",
    "mandarina": "mandarină",
    "mandarine": "mandarină",
    "mandarinei": "mandarină",
    "mandarinele": "mandarină",
    "mandarinelor": "mandarină",
    "mandate": "mandat",
    "mandatele": "mandat",
    "mandatelor": "mandat",
    "mandatul": "mandat",
    "mandatului": "mandat",
    "mandibula": "mandibulă",
    "mandibule": "mandibulă",
    "mandibulei": "mandibulă",
    "mandibulele": "mandibulă",
    "mandibulelor": "mandibulă",
    "mândra": "mândră",
    "mândre": "mândră",
    "mândrei": "mândră",
    "mândrele": "mândră",
    "mândrelor": "mândră",
    "mândrețea": "mândrețe",
    "mândrețeo": "mândrețe",
    "mândreți": "mândrețe",
    "mândreții": "mândrețe",
    "mândrețile": "mândrețe",
    "mândreților": "mândrețe",
    "mândrea": "mândri",
    "mândreai": "mândri",
    "mândream": "mândri",
    "mândrească": "mândri",
    "mândreați": "mândri",
    "mândreau": "mândri",
    "mândresc": "mândri",
    "mândrește": "mândri",
    "mândrești": "mândri",
    "mândrii": "mândri",
    "mândrim": "mândri",
    "mândrind": "mândri",
    "mândrindu": "mândri",
    "mândriră": "mândri",
    "mândrirăm": "mândri",
    "mândrirăți": "mândri",
    "mândrise": "mândri",
    "mândrisem": "mândri",
    "mândriseră": "mândri",
    "mândriserăm": "mândri",
    "mândriserăți": "mândri",
    "mândriseși": "mândri",
    "mândriși": "mândri",
    "mândrit": "mândri",
    "mândriți": "mândri",
    "mândritu": "mândri",
    "nemaimândrind": "mândri",
    "nemaimândrindu": "mândri",
    "nemândrind": "mândri",
    "nemândrindu": "mândri",
    "mândria": "mândrie",
    "mândriei": "mândrie",
    "mândrii": "mândrie",
    "mândriile": "mândrie",
    "mândriilor": "mândrie",
    "mândrită": "mândrit",
    "mândrite": "mândrit",
    "mândriți": "mândrit",
    "mândra": "mândru",
    "mândră": "mândru",
    "mândre": "mândru",
    "mândrei": "mândru",
    "mândrele": "mândru",
    "mândrelor": "mândru",
    "mândri": "mândru",
    "mândrii": "mândru",
    "mândrilor": "mândru",
    "mândrul": "mândru",
    "mândrului": "mândru",
    "mâneca": "mânecă",
    "mâneci": "mânecă",
    "mânecii": "mânecă",
    "mânecile": "mânecă",
    "mânecilor": "mânecă",
    "mânecare": "mânecar",
    "mânecarele": "mânecar",
    "mânecarelor": "mânecar",
    "mânecarul": "mânecar",
    "mânecarului": "mânecar",
    "manechine": "manechin",
    "manechinele": "manechin",
    "manechinelor": "manechin",
    "manechinul": "manechin",
    "manechinului": "manechin",
    "manejul": "manej",
    "manejului": "manej",
    "manejuri": "manej",
    "manejurile": "manej",
    "manejurilor": "manej",
    "mânere": "mâner",
    "mânerele": "mâner",
    "mânerelor": "mâner",
    "mânerul": "mâner",
    "mânerului": "mâner",
    "maneta": "manetă",
    "manete": "manetă",
    "manetei": "manetă",
    "manetele": "manetă",
    "manetelor": "manetă",
    "manevră": "manevra",
    "manevrai": "manevra",
    "manevram": "manevra",
    "manevrăm": "manevra",
    "manevrând": "manevra",
    "manevrându": "manevra",
    "manevrară": "manevra",
    "manevrarăm": "manevra",
    "manevrarăți": "manevra",
    "manevrase": "manevra",
    "manevrasem": "manevra",
    "manevraseră": "manevra",
    "manevraserăm": "manevra",
    "manevraserăți": "manevra",
    "manevraseși": "manevra",
    "manevrași": "manevra",
    "manevrat": "manevra",
    "manevrați": "manevra",
    "manevratu": "manevra",
    "manevrau": "manevra",
    "manevrează": "manevra",
    "manevrez": "manevra",
    "manevreze": "manevra",
    "manevrezi": "manevra",
    "nemaimanevrând": "manevra",
    "nemaimanevrându": "manevra",
    "nemanevrând": "manevra",
    "nemanevrându": "manevra",
    "manevra": "manevră",
    "manevre": "manevră",
    "manevrei": "manevră",
    "manevrele": "manevră",
    "manevrelor": "manevră",
    "manevrarea": "manevrare",
    "manevrări": "manevrare",
    "manevrării": "manevrare",
    "manevrările": "manevrare",
    "manevrărilor": "manevrare",
    "manevrată": "manevrat",
    "manevrate": "manevrat",
    "manevrați": "manevrat",
    "mangafale": "mangafa",
    "mangafalei": "mangafa",
    "mangafalele": "mangafa",
    "mangafalelor": "mangafa",
    "mangafaua": "mangafa",
    "mângâi": "mângâia",
    "mângâiai": "mângâia",
    "mângâiam": "mângâia",
    "mângâiară": "mângâia",
    "mângâiarăm": "mângâia",
    "mângâiarăți": "mângâia",
    "mângâiase": "mângâia",
    "mângâiasem": "mângâia",
    "mângâiaseră": "mângâia",
    "mângâiaserăm": "mângâia",
    "mângâiaserăți": "mângâia",
    "mângâiaseși": "mângâia",
    "mângâiași": "mângâia",
    "mângâiat": "mângâia",
    "mângâiați": "mângâia",
    "mângâiatu": "mângâia",
    "mângâiau": "mângâia",
    "mângâie": "mângâia",
    "mângâiem": "mângâia",
    "mângâind": "mângâia",
    "mângâindu": "mângâia",
    "nemaimângâiind": "mângâia",
    "nemaimângâiindu": "mângâia",
    "nemângâiind": "mângâia",
    "nemângâiindu": "mângâia",
    "mângâiată": "mângâiat",
    "mângâiate": "mângâiat",
    "mângâiați": "mângâiat",
    "mângâierea": "mângâiere",
    "mângâiereo": "mângâiere",
    "mângâieri": "mângâiere",
    "mângâierii": "mângâiere",
    "mângâierile": "mângâiere",
    "mângâierilor": "mângâiere",
    "mângâietoare": "mângâietor",
    "mângâietoarea": "mângâietor",
    "mângâietoarei": "mângâietor",
    "mângâietoarele": "mângâietor",
    "mângâietoarelor": "mângâietor",
    "mângâietori": "mângâietor",
    "mângâietorii": "mângâietor",
    "mângâietorilor": "mângâietor",
    "mângâietorul": "mângâietor",
    "mângâietorului": "mângâietor",
    "mângâioasa": "mângâios",
    "mângâioasă": "mângâios",
    "mângâioase": "mângâios",
    "mângâioasei": "mângâios",
    "mângâioasele": "mângâios",
    "mângâioaselor": "mângâios",
    "mângâioși": "mângâios",
    "mângâioșii": "mângâios",
    "mângâioșilor": "mângâios",
    "mângâiosul": "mângâios",
    "mângâiosului": "mângâios",
    "mangalul": "mangal",
    "mangalului": "mangal",
    "manganul": "mangan",
    "manganului": "mangan",
    "Mn": "mangan",
    "mâniai": "mânia",
    "mâniam": "mânia",
    "mâniară": "mânia",
    "mâniarăm": "mânia",
    "mâniarăți": "mânia",
    "mâniase": "mânia",
    "mâniasem": "mânia",
    "mâniaseră": "mânia",
    "mâniaserăm": "mânia",
    "mâniaserăți": "mânia",
    "mâniaseși": "mânia",
    "mâniași": "mânia",
    "mâniat": "mânia",
    "mâniați": "mânia",
    "mâniatu": "mânia",
    "mâniau": "mânia",
    "mânie": "mânia",
    "mâniem": "mânia",
    "mânii": "mânia",
    "mâniind": "mânia",
    "mâniindu": "mânia",
    "nemaimâniind": "mânia",
    "nemaimâniindu": "mânia",
    "nemâniind": "mânia",
    "nemâniindu": "mânia",
    "maniaci": "maniac",
    "maniacii": "maniac",
    "maniacilor": "maniac",
    "maniacul": "maniac",
    "maniacului": "maniac",
    "mâniată": "mâniat",
    "mâniate": "mâniat",
    "mâniați": "mâniat",
    "manichiura": "manichiură",
    "manichiuri": "manichiură",
    "manichiurii": "manichiură",
    "manichiurile": "manichiură",
    "manichiurilor": "manichiură",
    "mania": "manie",
    "maniei": "manie",
    "manii": "manie",
    "maniile": "manie",
    "maniilor": "manie",
    "mânia": "mânie",
    "mâniei": "mânie",
    "mânii": "mânie",
    "mâniile": "mânie",
    "mâniilor": "mânie",
    "maniera": "manieră",
    "maniere": "manieră",
    "manierei": "manieră",
    "manierele": "manieră",
    "manierelor": "manieră",
    "manierata": "manierat",
    "manierată": "manierat",
    "manierate": "manierat",
    "manieratei": "manierat",
    "manieratele": "manierat",
    "manieratelor": "manierat",
    "manierați": "manierat",
    "manierații": "manierat",
    "manieraților": "manierat",
    "manieratul": "manierat",
    "manieratului": "manierat",
    "manierisme": "manierism",
    "manierismele": "manierism",
    "manierismelor": "manierism",
    "manierismul": "manierism",
    "manierismului": "manierism",
    "manifeste": "manifest",
    "manifestele": "manifest",
    "manifestelor": "manifest",
    "manifestul": "manifest",
    "manifestului": "manifest",
    "manifest": "manifesta",
    "manifestă": "manifesta",
    "manifestai": "manifesta",
    "manifestam": "manifesta",
    "manifestăm": "manifesta",
    "manifestând": "manifesta",
    "manifestându": "manifesta",
    "manifestară": "manifesta",
    "manifestarăm": "manifesta",
    "manifestarăți": "manifesta",
    "manifestase": "manifesta",
    "manifestasem": "manifesta",
    "manifestaseră": "manifesta",
    "manifestaserăm": "manifesta",
    "manifestaserăți": "manifesta",
    "manifestaseși": "manifesta",
    "manifestași": "manifesta",
    "manifestat": "manifesta",
    "manifestați": "manifesta",
    "manifestatu": "manifesta",
    "manifestau": "manifesta",
    "manifeste": "manifesta",
    "manifestează": "manifesta",
    "manifestez": "manifesta",
    "manifesteze": "manifesta",
    "manifestezi": "manifesta",
    "manifești": "manifesta",
    "nemaimanifestând": "manifesta",
    "nemaimanifestându": "manifesta",
    "nemanifestând": "manifesta",
    "nemanifestându": "manifesta",
    "manifestanți": "manifestant",
    "manifestanții": "manifestant",
    "manifestanților": "manifestant",
    "manifestantul": "manifestant",
    "manifestantule": "manifestant",
    "manifestantului": "manifestant",
    "manifestanta": "manifestantă",
    "manifestante": "manifestantă",
    "manifestantei": "manifestantă",
    "manifestantele": "manifestantă",
    "manifestantelor": "manifestantă",
    "manifestanto": "manifestantă",
    "manifestarea": "manifestare",
    "manifestări": "manifestare",
    "manifestării": "manifestare",
    "manifestările": "manifestare",
    "manifestărilor": "manifestare",
    "manifestată": "manifestat",
    "manifestate": "manifestat",
    "manifestați": "manifestat",
    "manifestația": "manifestație",
    "manifestației": "manifestație",
    "manifestații": "manifestație",
    "manifestațiile": "manifestație",
    "manifestațiilor": "manifestație",
    "mânioasa": "mânios",
    "mânioasă": "mânios",
    "mânioase": "mânios",
    "mânioasei": "mânios",
    "mânioasele": "mânios",
    "mânioaselor": "mânios",
    "mânioși": "mânios",
    "mânioșii": "mânios",
    "mânioșilor": "mânios",
    "mâniosul": "mânios",
    "mâniosului": "mânios",
    "manipulă": "manipula",
    "manipulai": "manipula",
    "manipulam": "manipula",
    "manipulăm": "manipula",
    "manipulând": "manipula",
    "manipulându": "manipula",
    "manipulară": "manipula",
    "manipularăm": "manipula",
    "manipularăți": "manipula",
    "manipulase": "manipula",
    "manipulasem": "manipula",
    "manipulaseră": "manipula",
    "manipulaserăm": "manipula",
    "manipulaserăți": "manipula",
    "manipulaseși": "manipula",
    "manipulași": "manipula",
    "manipulat": "manipula",
    "manipulați": "manipula",
    "manipulatu": "manipula",
    "manipulau": "manipula",
    "manipulează": "manipula",
    "manipulez": "manipula",
    "manipuleze": "manipula",
    "manipulezi": "manipula",
    "nemaimanipulând": "manipula",
    "nemaimanipulându": "manipula",
    "nemanipulând": "manipula",
    "nemanipulându": "manipula",
    "manipularea": "manipulare",
    "manipulări": "manipulare",
    "manipulării": "manipulare",
    "manipulările": "manipulare",
    "manipulărilor": "manipulare",
    "manipulată": "manipulat",
    "manipulate": "manipulat",
    "manipulați": "manipulat",
    "manipulatoare": "manipulator",
    "manipulatori": "manipulator",
    "mânjeala": "mânjeală",
    "mânjeli": "mânjeală",
    "mânjelii": "mânjeală",
    "mânjelile": "mânjeală",
    "mânjelilor": "mânjeală",
    "mânjea": "mânji",
    "mânjeai": "mânji",
    "mânjeam": "mânji",
    "mânjească": "mânji",
    "mânjeați": "mânji",
    "mânjeau": "mânji",
    "mânjesc": "mânji",
    "mânjește": "mânji",
    "mânjești": "mânji",
    "mânjii": "mânji",
    "mânjim": "mânji",
    "mânjind": "mânji",
    "mânjindu": "mânji",
    "mânjiră": "mânji",
    "mânjirăm": "mânji",
    "mânjirăți": "mânji",
    "mânjise": "mânji",
    "mânjisem": "mânji",
    "mânjiseră": "mânji",
    "mânjiserăm": "mânji",
    "mânjiserăți": "mânji",
    "mânjiseși": "mânji",
    "mânjiși": "mânji",
    "mânjit": "mânji",
    "mânjiți": "mânji",
    "mânjitu": "mânji",
    "nemaimânjind": "mânji",
    "nemaimânjindu": "mânji",
    "nemânjind": "mânji",
    "nemânjindu": "mânji",
    "mânjită": "mânjit",
    "mânjite": "mânjit",
    "mânjiți": "mânjit",
    "manometre": "manometru",
    "manometrele": "manometru",
    "manometrelor": "manometru",
    "manometrul": "manometru",
    "manometrului": "manometru",
    "manopera": "manoperă",
    "manopere": "manoperă",
    "manoperei": "manoperă",
    "manoperele": "manoperă",
    "manoperelor": "manoperă",
    "mănoasa": "mănos",
    "mănoasă": "mănos",
    "mănoase": "mănos",
    "mănoasei": "mănos",
    "mănoasele": "mănos",
    "mănoaselor": "mănos",
    "mănoși": "mănos",
    "mănoșii": "mănos",
    "mănoșilor": "mănos",
    "mănosul": "mănos",
    "mănosului": "mănos",
    "manșa": "manșă",
    "manșe": "manșă",
    "manșei": "manșă",
    "manșele": "manșă",
    "manșelor": "manșă",
    "mansarda": "mansardă",
    "mansarde": "mansardă",
    "mansardei": "mansardă",
    "mansardele": "mansardă",
    "mansardelor": "mansardă",
    "mansardo": "mansardă",
    "manșeta": "manșetă",
    "manșete": "manșetă",
    "manșetei": "manșetă",
    "manșetele": "manșetă",
    "manșetelor": "manșetă",
    "mantale": "manta",
    "mantalei": "manta",
    "mantalele": "manta",
    "mantalelor": "manta",
    "mantaua": "manta",
    "mantia": "mantie",
    "mantiei": "mantie",
    "mantii": "mantie",
    "mantiile": "mantie",
    "mantiilor": "mantie",
    "mantio": "mantie",
    "mantila": "mantilă",
    "mantile": "mantilă",
    "mantilei": "mantilă",
    "mantilele": "mantilă",
    "mantilelor": "mantilă",
    "mântuia": "mântui",
    "mântuiai": "mântui",
    "mântuiam": "mântui",
    "mântuiască": "mântui",
    "mântuiați": "mântui",
    "mântuiau": "mântui",
    "mântuie": "mântui",
    "mântuiesc": "mântui",
    "mântuiește": "mântui",
    "mântuiești": "mântui",
    "mântuii": "mântui",
    "mântuim": "mântui",
    "mântuind": "mântui",
    "mântuindu": "mântui",
    "mântuiră": "mântui",
    "mântuirăm": "mântui",
    "mântuirăți": "mântui",
    "mântuise": "mântui",
    "mântuisem": "mântui",
    "mântuiseră": "mântui",
    "mântuiserăm": "mântui",
    "mântuiserăți": "mântui",
    "mântuiseși": "mântui",
    "mântuiși": "mântui",
    "mântuit": "mântui",
    "mântuiți": "mântui",
    "mântuitu": "mântui",
    "nemaimântuind": "mântui",
    "nemaimântuindu": "mântui",
    "nemântuind": "mântui",
    "nemântuindu": "mântui",
    "mântuiala": "mântuială",
    "mântuieli": "mântuială",
    "mântuielii": "mântuială",
    "mântuirea": "mântuire",
    "mântuireo": "mântuire",
    "mântuiri": "mântuire",
    "mântuirii": "mântuire",
    "mântuirile": "mântuire",
    "mântuirilor": "mântuire",
    "mântuită": "mântuit",
    "mântuite": "mântuit",
    "mântuiți": "mântuit",
    "mântuitoare": "mântuitor",
    "mântuitoarea": "mântuitor",
    "mântuitoarei": "mântuitor",
    "mântuitoarele": "mântuitor",
    "mântuitoarelor": "mântuitor",
    "mântuitori": "mântuitor",
    "mântuitorii": "mântuitor",
    "mântuitorilor": "mântuitor",
    "mântuitorul": "mântuitor",
    "mântuitorule": "mântuitor",
    "mântuitorului": "mântuitor",
    "m.p.": "manu_propria",
    "manuala": "manual",
    "manuală": "manual",
    "manuale": "manual",
    "manualei": "manual",
    "manualele": "manual",
    "manualelor": "manual",
    "manuali": "manual",
    "manualii": "manual",
    "manualilor": "manual",
    "manualul": "manual",
    "manualului": "manual",
    "Manuelei": "Manuela",
    "manufactura": "manufactură",
    "manufacturi": "manufactură",
    "manufacturii": "manufactură",
    "manufacturile": "manufactură",
    "manufacturilor": "manufactură",
    "manufacturiera": "manufacturier",
    "manufacturieră": "manufacturier",
    "manufacturiere": "manufacturier",
    "manufacturierei": "manufacturier",
    "manufacturierele": "manufacturier",
    "manufacturierelor": "manufacturier",
    "manufacturieri": "manufacturier",
    "manufacturierii": "manufacturier",
    "manufacturierilor": "manufacturier",
    "manufacturierul": "manufacturier",
    "manufacturierului": "manufacturier",
    "mânuia": "mânui",
    "mânuiai": "mânui",
    "mânuiam": "mânui",
    "mânuiască": "mânui",
    "mânuiați": "mânui",
    "mânuiau": "mânui",
    "mânuiesc": "mânui",
    "mânuiește": "mânui",
    "mânuiești": "mânui",
    "mânuii": "mânui",
    "mânuim": "mânui",
    "mânuind": "mânui",
    "mânuindu": "mânui",
    "mânuiră": "mânui",
    "mânuirăm": "mânui",
    "mânuirăți": "mânui",
    "mânuise": "mânui",
    "mânuisem": "mânui",
    "mânuiseră": "mânui",
    "mânuiserăm": "mânui",
    "mânuiserăți": "mânui",
    "mânuiseși": "mânui",
    "mânuiși": "mânui",
    "mânuit": "mânui",
    "mânuiți": "mânui",
    "mânuitu": "mânui",
    "nemaimânuind": "mânui",
    "nemaimânuindu": "mânui",
    "nemânuind": "mânui",
    "nemânuindu": "mânui",
    "mânuirea": "mânuire",
    "mânuireo": "mânuire",
    "mânuiri": "mânuire",
    "mânuirii": "mânuire",
    "mânuirile": "mânuire",
    "mânuirilor": "mânuire",
    "mânuită": "mânuit",
    "mânuite": "mânuit",
    "mânuiți": "mânuit",
    "mânuitori": "mânuitor",
    "mânuitorii": "mânuitor",
    "mânuitorilor": "mânuitor",
    "mânuitorul": "mânuitor",
    "mânuitorule": "mânuitor",
    "mânuitorului": "mânuitor",
    "mănunchiul": "mănunchi",
    "mănunchiule": "mănunchi",
    "mănunchiului": "mănunchi",
    "mănunchiuri": "mănunchi",
    "mănunchiurile": "mănunchi",
    "mănunchiurilor": "mănunchi",
    "mănușa": "mănușă",
    "mănuși": "mănușă",
    "mănușii": "mănușă",
    "mănușile": "mănușă",
    "mănușilor": "mănușă",
    "mănușo": "mănușă",
    "manuscripte": "manuscript",
    "manuscriptele": "manuscript",
    "manuscriptelor": "manuscript",
    "manuscriptul": "manuscript",
    "manuscriptului": "manuscript",
    "manuscrise": "manuscris",
    "manuscrisele": "manuscris",
    "manuscriselor": "manuscris",
    "manuscrisul": "manuscris",
    "manuscrisului": "manuscris",
    "ms.": "manuscris",
    "mss.": "manuscrise",
    "mânuța": "mânuță",
    "mânuțe": "mânuță",
    "mânuței": "mânuță",
    "mânuțele": "mânuță",
    "mânuțelor": "mânuță",
    "mânuțo": "mânuță",
    "manutanța": "manutanță",
    "manutanțe": "manutanță",
    "manutanței": "manutanță",
    "manutanțele": "manutanță",
    "manutanțelor": "manutanță",
    "mânji": "mânz",
    "mânjii": "mânz",
    "mânjilor": "mânz",
    "mânzul": "mânz",
    "mânzului": "mânz",
    "mânzărari": "mânzărar",
    "mânzărarii": "mânzărar",
    "mânzărarilor": "mânzărar",
    "mânzărarul": "mânzărar",
    "mânzărarului": "mânzărar",
    "mânzarea": "mânzare",
    "mânzări": "mânzare",
    "mânzării": "mânzare",
    "mânzările": "mânzare",
    "mânzărilor": "mânzare",
    "mânzați": "mânzat",
    "mânzații": "mânzat",
    "mânzaților": "mânzat",
    "mânzatul": "mânzat",
    "mânzatului": "mânzat",
    "mânzata": "mânzată",
    "mânzate": "mânzată",
    "mânzatei": "mânzată",
    "mânzatele": "mânzată",
    "mânzatelor": "mânzată",
    "mapa": "mapă",
    "mape": "mapă",
    "mapei": "mapă",
    "mapele": "mapă",
    "mapelor": "mapă",
    "mapo": "mapă",
    "mapamondul": "mapamond",
    "mapamondului": "mapamond",
    "mapamonduri": "mapamond",
    "mapamondurile": "mapamond",
    "mapamondurilor": "mapamond",
    "mărul": "măr",
    "mărului": "măr",
    "mere": "măr",
    "merele": "măr",
    "merelor": "măr",
    "mărăcinele": "mărăcine",
    "mărăcinelui": "mărăcine",
    "mărăcini": "mărăcine",
    "mărăcinii": "mărăcine",
    "mărăcinilor": "mărăcine",
    "mărăcinoasa": "mărăcinos",
    "mărăcinoasă": "mărăcinos",
    "mărăcinoase": "mărăcinos",
    "mărăcinoasei": "mărăcinos",
    "mărăcinoasele": "mărăcinos",
    "mărăcinoaselor": "mărăcinos",
    "mărăcinoși": "mărăcinos",
    "mărăcinoșii": "mărăcinos",
    "mărăcinoșilor": "mărăcinos",
    "mărăcinosul": "mărăcinos",
    "mărăcinosului": "mărăcinos",
    "mârâia": "mârâi",
    "mârâiai": "mârâi",
    "mârâiam": "mârâi",
    "mârâiați": "mârâi",
    "mârâiau": "mârâi",
    "mârâie": "mârâi",
    "mârâii": "mârâi",
    "mârâim": "mârâi",
    "mârâind": "mârâi",
    "mârâindu": "mârâi",
    "mârâiră": "mârâi",
    "mârâirăm": "mârâi",
    "mârâirăți": "mârâi",
    "mârâise": "mârâi",
    "mârâisem": "mârâi",
    "mârâiseră": "mârâi",
    "mârâiserăm": "mârâi",
    "mârâiserăți": "mârâi",
    "mârâiseși": "mârâi",
    "mârâiși": "mârâi",
    "mârâit": "mârâi",
    "mârâiți": "mârâi",
    "mârâitu": "mârâi",
    "nemaimârâind": "mârâi",
    "nemaimârâindu": "mârâi",
    "nemârâind": "mârâi",
    "nemârâindu": "mârâi",
    "mârâită": "mârâit",
    "mârâite": "mârâit",
    "mârâiți": "mârâit",
    "mârâitoare": "mârâitor",
    "mârâitoarea": "mârâitor",
    "mârâitoarei": "mârâitor",
    "mârâitoarele": "mârâitor",
    "mârâitoarelor": "mârâitor",
    "mârâitori": "mârâitor",
    "mârâitorii": "mârâitor",
    "mârâitorilor": "mârâitor",
    "mârâitorul": "mârâitor",
    "mârâitorului": "mârâitor",
    "Maramureșul": "Maramureș",
    "Maramureșului": "Maramureș",
    "maramureșeana": "maramureșean",
    "maramureșeană": "maramureșean",
    "maramureșeanul": "maramureșean",
    "maramureșeanului": "maramureșean",
    "maramureșene": "maramureșean",
    "maramureșenei": "maramureșean",
    "maramureșenele": "maramureșean",
    "maramureșenelor": "maramureșean",
    "maramureșeni": "maramureșean",
    "maramureșenii": "maramureșean",
    "maramureșenilor": "maramureșean",
    "marasme": "marasm",
    "marasmele": "marasm",
    "marasmelor": "marasm",
    "marasmul": "marasm",
    "marasmului": "marasm",
    "maratonul": "maraton",
    "maratonului": "maraton",
    "maratonuri": "maraton",
    "maratonurile": "maraton",
    "maratonurilor": "maraton",
    "marcă": "marca",
    "marcai": "marca",
    "marcam": "marca",
    "marcăm": "marca",
    "marcând": "marca",
    "marcându": "marca",
    "marcară": "marca",
    "marcarăm": "marca",
    "marcarăți": "marca",
    "marcase": "marca",
    "marcasem": "marca",
    "marcaseră": "marca",
    "marcaserăm": "marca",
    "marcaserăți": "marca",
    "marcaseși": "marca",
    "marcași": "marca",
    "marcat": "marca",
    "marcați": "marca",
    "marcatu": "marca",
    "marcau": "marca",
    "marchează": "marca",
    "marchez": "marca",
    "marcheze": "marca",
    "marchezi": "marca",
    "nemaimarcând": "marca",
    "nemaimarcându": "marca",
    "nemarcând": "marca",
    "nemarcându": "marca",
    "marca": "marcă",
    "mărci": "marcă",
    "mărcii": "marcă",
    "mărcile": "marcă",
    "mărcilor": "marcă",
    "marcanta": "marcant",
    "marcantă": "marcant",
    "marcante": "marcant",
    "marcantei": "marcant",
    "marcantele": "marcant",
    "marcantelor": "marcant",
    "marcanți": "marcant",
    "marcanții": "marcant",
    "marcanților": "marcant",
    "marcantul": "marcant",
    "marcantului": "marcant",
    "marcarea": "marcare",
    "marcareo": "marcare",
    "marcări": "marcare",
    "marcării": "marcare",
    "marcările": "marcare",
    "marcărilor": "marcare",
    "marcata": "marcat",
    "marcată": "marcat",
    "marcate": "marcat",
    "marcatei": "marcat",
    "marcatele": "marcat",
    "marcatelor": "marcat",
    "marcați": "marcat",
    "marcații": "marcat",
    "marcaților": "marcat",
    "marcatul": "marcat",
    "marcatului": "marcat",
    "marchizi": "marchiz",
    "marchizii": "marchiz",
    "marchizilor": "marchiz",
    "marchizul": "marchiz",
    "marchizului": "marchiz",
    "marchiza": "marchiză",
    "marchize": "marchiză",
    "marchizei": "marchiză",
    "marchizele": "marchiză",
    "marchizelor": "marchiză",
    "marcota": "marcotă",
    "marcote": "marcotă",
    "marcotei": "marcotă",
    "marcotele": "marcotă",
    "marcotelor": "marcotă",
    "marcotaje": "marcotaj",
    "marcotajele": "marcotaj",
    "marcotajelor": "marcotaj",
    "marcotajul": "marcotaj",
    "marcotajului": "marcotaj",
    "marea": "mare",
    "marele": "mare",
    "marelui": "mare",
    "mari": "mare",
    "mări": "mare",
    "marii": "mare",
    "mării": "mare",
    "marile": "mare",
    "mările": "mare",
    "marilor": "mare",
    "mărilor": "mare",
    "Mare_Adriatică": "Marea_Adriatică",
    "Mări_Adriatice": "Marea_Adriatică",
    "GB": "Marea_Britanie",
    "Mare_Britanie": "Marea_Britanie",
    "Mari_Britanii": "Marea_Britanie",
    "Marii_Britanii": "Marea_Britanie",
    "Mare_Egee": "Marea_Egee",
    "Mării_Egee": "Marea_Egee",
    "Mării_Negre": "Marea_Neagră",
    "mareea": "maree",
    "mareei": "maree",
    "mareele": "maree",
    "mareelor": "maree",
    "mareeo": "maree",
    "maregrafe": "maregraf",
    "maregrafele": "maregraf",
    "maregrafelor": "maregraf",
    "maregraful": "maregraf",
    "maregrafului": "maregraf",
    "M.": "mareșal",
    "mareșali": "mareșal",
    "mareșalii": "mareșal",
    "mareșalilor": "mareșal",
    "mareșalul": "mareșal",
    "mareșalului": "mareșal",
    "măreața": "măreț",
    "măreață": "măreț",
    "mărețe": "măreț",
    "măreței": "măreț",
    "mărețele": "măreț",
    "mărețelor": "măreț",
    "măreți": "măreț",
    "măreții": "măreț",
    "măreților": "măreț",
    "mărețul": "măreț",
    "mărețului": "măreț",
    "măreția": "măreție",
    "măreției": "măreție",
    "măreții": "măreție",
    "mărețiile": "măreție",
    "mărețiilor": "măreție",
    "marfa": "marfă",
    "mărfi": "marfă",
    "mărfii": "marfă",
    "mărfuri": "marfă",
    "mărfurile": "marfă",
    "mărfurilor": "marfă",
    "margarina": "margarină",
    "margarine": "margarină",
    "margarinei": "margarină",
    "margarinele": "margarină",
    "margarinelor": "margarină",
    "mărgăritare": "mărgăritar",
    "mărgăritarele": "mărgăritar",
    "mărgăritarelor": "mărgăritar",
    "mărgăritarul": "mărgăritar",
    "mărgăritarule": "mărgăritar",
    "mărgăritarului": "mărgăritar",
    "mărgeao": "mărgea",
    "mărgeaua": "mărgea",
    "mărgele": "mărgea",
    "mărgelei": "mărgea",
    "mărgelele": "mărgea",
    "mărgelelor": "mărgea",
    "mărgeane": "mărgean",
    "mărgeanele": "mărgean",
    "mărgeanelor": "mărgean",
    "mărgeanul": "mărgean",
    "mărgeanule": "mărgean",
    "mărgeanului": "mărgean",
    "marginala": "marginal",
    "marginală": "marginal",
    "marginale": "marginal",
    "marginalei": "marginal",
    "marginalele": "marginal",
    "marginalelor": "marginal",
    "marginali": "marginal",
    "marginalii": "marginal",
    "marginalilor": "marginal",
    "marginalul": "marginal",
    "marginalului": "marginal",
    "marginalizarea": "marginalizare",
    "marginalizareo": "marginalizare",
    "marginalizări": "marginalizare",
    "marginalizării": "marginalizare",
    "marginalizările": "marginalizare",
    "marginalizărilor": "marginalizare",
    "mărginașa": "mărginaș",
    "mărginașă": "mărginaș",
    "mărginașe": "mărginaș",
    "mărginașei": "mărginaș",
    "mărginașele": "mărginaș",
    "mărginașelor": "mărginaș",
    "mărginași": "mărginaș",
    "mărginașii": "mărginaș",
    "mărginașilor": "mărginaș",
    "mărginașul": "mărginaș",
    "mărginașului": "mărginaș",
    "marginea": "margine",
    "margini": "margine",
    "marginii": "margine",
    "marginile": "margine",
    "marginilor": "margine",
    "mărginea": "mărgini",
    "mărgineai": "mărgini",
    "mărgineam": "mărgini",
    "mărginească": "mărgini",
    "mărgineați": "mărgini",
    "mărgineau": "mărgini",
    "mărginesc": "mărgini",
    "mărginește": "mărgini",
    "mărginești": "mărgini",
    "mărginii": "mărgini",
    "mărginim": "mărgini",
    "mărginind": "mărgini",
    "mărginindu": "mărgini",
    "mărginiră": "mărgini",
    "mărginirăm": "mărgini",
    "mărginirăți": "mărgini",
    "mărginise": "mărgini",
    "mărginisem": "mărgini",
    "mărginiseră": "mărgini",
    "mărginiserăm": "mărgini",
    "mărginiserăți": "mărgini",
    "mărginiseși": "mărgini",
    "mărginiși": "mărgini",
    "mărginit": "mărgini",
    "mărginiți": "mărgini",
    "mărginitu": "mărgini",
    "nemaimărginind": "mărgini",
    "nemaimărginindu": "mărgini",
    "nemărginind": "mărgini",
    "nemărginindu": "mărgini",
    "mărginirea": "mărginire",
    "mărginiri": "mărginire",
    "mărginirii": "mărginire",
    "mărginirile": "mărginire",
    "mărginirilor": "mărginire",
    "mărginita": "mărginit",
    "mărginită": "mărginit",
    "mărginite": "mărginit",
    "mărginitei": "mărginit",
    "mărginitele": "mărginit",
    "mărginitelor": "mărginit",
    "mărginiți": "mărginit",
    "mărginiții": "mărginit",
    "mărginiților": "mărginit",
    "mărginitul": "mărginit",
    "mărginitului": "mărginit",
    "mere-gutui": "măr-gutui",
    "meri-gutui": "măr-gutui",
    "mărea": "mări",
    "măreai": "mări",
    "măream": "mări",
    "mărească": "mări",
    "măreați": "mări",
    "măreau": "mări",
    "măresc": "mări",
    "mărește": "mări",
    "mărești": "mări",
    "mării": "mări",
    "mărim": "mări",
    "mărind": "mări",
    "mărindu": "mări",
    "măriră": "mări",
    "mărirăm": "mări",
    "mărirăți": "mări",
    "mărise": "mări",
    "mărisem": "mări",
    "măriseră": "mări",
    "măriserăm": "mări",
    "măriserăți": "mări",
    "măriseși": "mări",
    "măriși": "mări",
    "mărit": "mări",
    "măriți": "mări",
    "măritu": "mări",
    "nemaimărind": "mări",
    "nemaimărindu": "mări",
    "nemărind": "mări",
    "nemărindu": "mări",
    "M.": "Maria",
    "Mariei": "Maria",
    "Mărie": "Măria",
    "Măriei": "Măria",
    "Mării": "Măria",
    "Măriile": "Măria",
    "Măriilor": "Măria",
    "Mărio": "Măria",
    "mariaje": "mariaj",
    "mariajele": "mariaj",
    "mariajelor": "mariaj",
    "mariajul": "mariaj",
    "mariajului": "mariaj",
    "Marianei": "Mariana",
    "Maricăi": "Marica",
    "Maricii": "Marica",
    "Marilynei": "Marilyn",
    "mărimea": "mărime",
    "mărimi": "mărime",
    "mărimii": "mărime",
    "mărimile": "mărime",
    "mărimilor": "mărime",
    "marina": "marin",
    "marină": "marin",
    "marine": "marin",
    "marinei": "marin",
    "marinele": "marin",
    "marinelor": "marin",
    "marini": "marin",
    "marinii": "marin",
    "marinilor": "marin",
    "marinul": "marin",
    "marinului": "marin",
    "marină": "marina",
    "marinai": "marina",
    "marinam": "marina",
    "marinăm": "marina",
    "marinând": "marina",
    "marinându": "marina",
    "marinară": "marina",
    "marinarăm": "marina",
    "marinarăți": "marina",
    "marinase": "marina",
    "marinasem": "marina",
    "marinaseră": "marina",
    "marinaserăm": "marina",
    "marinaserăți": "marina",
    "marinaseși": "marina",
    "marinași": "marina",
    "marinat": "marina",
    "marinați": "marina",
    "marinatu": "marina",
    "marinau": "marina",
    "marinează": "marina",
    "marinez": "marina",
    "marineze": "marina",
    "marinezi": "marina",
    "nemaimarinând": "marina",
    "nemaimarinându": "marina",
    "nemarinând": "marina",
    "nemarinându": "marina",
    "marina": "marină",
    "marine": "marină",
    "marinei": "marină",
    "marinele": "marină",
    "marinelor": "marină",
    "marinari": "marinar",
    "marinarii": "marinar",
    "marinarilor": "marinar",
    "marinarul": "marinar",
    "marinarului": "marinar",
    "marinăreasca": "marinăresc",
    "marinărească": "marinăresc",
    "marinărescul": "marinăresc",
    "marinărescului": "marinăresc",
    "marinărești": "marinăresc",
    "marinăreștii": "marinăresc",
    "marinăreștile": "marinăresc",
    "marinăreștilor": "marinăresc",
    "marinata": "marinat",
    "marinată": "marinat",
    "marinate": "marinat",
    "marinatei": "marinat",
    "marinatele": "marinat",
    "marinatelor": "marinat",
    "marinați": "marinat",
    "marinații": "marinat",
    "marinaților": "marinat",
    "marinatul": "marinat",
    "marinatului": "marinat",
    "mărinimia": "mărinimie",
    "mărinimiei": "mărinimie",
    "mărinimii": "mărinimie",
    "mărinimiile": "mărinimie",
    "mărinimiilor": "mărinimie",
    "mărinimoasa": "mărinimos",
    "mărinimoasă": "mărinimos",
    "mărinimoase": "mărinimos",
    "mărinimoasei": "mărinimos",
    "mărinimoasele": "mărinimos",
    "mărinimoaselor": "mărinimos",
    "mărinimoși": "mărinimos",
    "mărinimoșii": "mărinimos",
    "mărinimoșilor": "mărinimos",
    "mărinimosul": "mărinimos",
    "mărinimosului": "mărinimos",
    "Marioară": "Marioara",
    "Marioare": "Marioara",
    "Marioarei": "Marioara",
    "Mărioară": "Mărioara",
    "Mărioare": "Mărioara",
    "Mărioarei": "Mărioara",
    "marioneta": "marionetă",
    "marionete": "marionetă",
    "marionetei": "marionetă",
    "marionetele": "marionetă",
    "marionetelor": "marionetă",
    "mărirea": "mărire",
    "mărireo": "mărire",
    "măriri": "mărire",
    "măririi": "mărire",
    "măririle": "mărire",
    "măririlor": "mărire",
    "mărita": "mărit",
    "mărită": "mărit",
    "mărite": "mărit",
    "măritei": "mărit",
    "măritele": "mărit",
    "măritelor": "mărit",
    "măriți": "mărit",
    "măriții": "mărit",
    "măriților": "mărit",
    "măritul": "mărit",
    "măritului": "mărit",
    "mărit": "mărita",
    "mărită": "mărita",
    "măritai": "mărita",
    "măritam": "mărita",
    "mărităm": "mărita",
    "măritând": "mărita",
    "măritându": "mărita",
    "măritară": "mărita",
    "măritarăm": "mărita",
    "măritarăți": "mărita",
    "măritase": "mărita",
    "măritasem": "mărita",
    "măritaseră": "mărita",
    "măritaserăm": "mărita",
    "măritaserăți": "mărita",
    "măritaseși": "mărita",
    "măritași": "mărita",
    "măritat": "mărita",
    "măritați": "mărita",
    "măritatu": "mărita",
    "măritau": "mărita",
    "mărite": "mărita",
    "măriți": "mărita",
    "nemaimăritând": "mărita",
    "nemaimăritându": "mărita",
    "nemăritând": "mărita",
    "nemăritându": "mărita",
    "măritata": "măritat",
    "măritată": "măritat",
    "măritate": "măritat",
    "măritatei": "măritat",
    "măritatele": "măritat",
    "măritatelor": "măritat",
    "măritați": "măritat",
    "maritima": "maritim",
    "maritimă": "maritim",
    "maritime": "maritim",
    "maritimei": "maritim",
    "maritimele": "maritim",
    "maritimelor": "maritim",
    "maritimi": "maritim",
    "maritimii": "maritim",
    "maritimilor": "maritim",
    "maritimul": "maritim",
    "maritimului": "maritim",
    "marketingul": "marketing",
    "marketingului": "marketing",
    "mârlani": "mârlan",
    "mârlanii": "mârlan",
    "mârlanilor": "mârlan",
    "mârlanul": "mârlan",
    "mârlanului": "mârlan",
    "marmelada": "marmeladă",
    "marmelade": "marmeladă",
    "marmeladei": "marmeladă",
    "marmeladele": "marmeladă",
    "marmeladelor": "marmeladă",
    "marmelado": "marmeladă",
    "marmita": "marmită",
    "marmite": "marmită",
    "marmitei": "marmită",
    "marmitele": "marmită",
    "marmitelor": "marmită",
    "marmora": "marmoră",
    "marmore": "marmoră",
    "marmorei": "marmoră",
    "marmorele": "marmoră",
    "marmorelor": "marmoră",
    "marmoreana": "marmorean",
    "marmoreană": "marmorean",
    "marmoreanul": "marmorean",
    "marmoreanului": "marmorean",
    "marmorene": "marmorean",
    "marmorenei": "marmorean",
    "marmorenele": "marmorean",
    "marmorenelor": "marmorean",
    "marmoreni": "marmorean",
    "marmorenii": "marmorean",
    "marmorenilor": "marmorean",
    "marmura": "marmură",
    "marmuri": "marmură",
    "marmurii": "marmură",
    "marmurile": "marmură",
    "marmurilor": "marmură",
    "marmuro": "marmură",
    "marna": "marnă",
    "marne": "marnă",
    "marnei": "marnă",
    "marnele": "marnă",
    "marnelor": "marnă",
    "maroul": "maro",
    "maroului": "maro",
    "marouri": "maro",
    "marourile": "maro",
    "marourilor": "maro",
    "marochine": "marochin",
    "marochinele": "marochin",
    "marochinelor": "marochin",
    "marochinul": "marochin",
    "marochinului": "marochin",
    "marochinuri": "marochin",
    "marochinurile": "marochin",
    "marochinurilor": "marochin",
    "marochinăria": "marochinărie",
    "marochinăriei": "marochinărie",
    "marochinării": "marochinărie",
    "marochinăriile": "marochinărie",
    "marochinăriilor": "marochinărie",
    "maronia": "maroniu",
    "maronie": "maroniu",
    "maroniei": "maroniu",
    "maronii": "maroniu",
    "maroniii": "maroniu",
    "maroniile": "maroniu",
    "maroniilor": "maroniu",
    "maroniul": "maroniu",
    "maroniului": "maroniu",
    "marșul": "marș",
    "marșului": "marș",
    "marșuri": "marș",
    "marșurile": "marș",
    "marșurilor": "marș",
    "mărșăluia": "mărșălui",
    "mărșăluiai": "mărșălui",
    "mărșăluiam": "mărșălui",
    "mărșăluiască": "mărșălui",
    "mărșăluiați": "mărșălui",
    "mărșăluiau": "mărșălui",
    "mărșăluiesc": "mărșălui",
    "mărșăluiește": "mărșălui",
    "mărșăluiești": "mărșălui",
    "mărșăluii": "mărșălui",
    "mărșăluim": "mărșălui",
    "mărșăluind": "mărșălui",
    "mărșăluindu": "mărșălui",
    "mărșăluiră": "mărșălui",
    "mărșăluirăm": "mărșălui",
    "mărșăluirăți": "mărșălui",
    "mărșăluise": "mărșălui",
    "mărșăluisem": "mărșălui",
    "mărșăluiseră": "mărșălui",
    "mărșăluiserăm": "mărșălui",
    "mărșăluiserăți": "mărșălui",
    "mărșăluiseși": "mărșălui",
    "mărșăluiși": "mărșălui",
    "mărșăluit": "mărșălui",
    "mărșăluiți": "mărșălui",
    "mărșăluitu": "mărșălui",
    "mărșăluită": "mărșăluit",
    "mărșăluite": "mărșăluit",
    "mărșăluiți": "mărșăluit",
    "mărșăluitul": "mărșăluit",
    "mărșăluitule": "mărșăluit",
    "mărșăluitului": "mărșăluit",
    "mârșava": "mârșav",
    "mârșavă": "mârșav",
    "mârșave": "mârșav",
    "mârșavei": "mârșav",
    "mârșavele": "mârșav",
    "mârșavelor": "mârșav",
    "mârșavi": "mârșav",
    "mârșavii": "mârșav",
    "mârșavilor": "mârșav",
    "mârșavul": "mârșav",
    "mârșavului": "mârșav",
    "mârșăvia": "mârșăvie",
    "mârșăviei": "mârșăvie",
    "mârșăvii": "mârșăvie",
    "mârșăviile": "mârșăvie",
    "mârșăviilor": "mârșăvie",
    "marsupii": "marsupiu",
    "marsupiii": "marsupiu",
    "marsupiilor": "marsupiu",
    "marsupiul": "marsupiu",
    "marsupiului": "marsupiu",
    "martelarea": "martelare",
    "martelareo": "martelare",
    "martelări": "martelare",
    "martelării": "martelare",
    "martelările": "martelare",
    "martelărilor": "martelare",
    "M.": "marți",
    "marțea": "marți",
    "marțiala": "marțial",
    "marțială": "marțial",
    "marțiale": "marțial",
    "marțialei": "marțial",
    "marțialele": "marțial",
    "marțialelor": "marțial",
    "marțiali": "marțial",
    "marțialii": "marțial",
    "marțialilor": "marțial",
    "marțialul": "marțial",
    "marțialului": "marțial",
    "mart.": "martie",
    "martiri": "martir",
    "martirii": "martir",
    "martirilor": "martir",
    "martirul": "martir",
    "martirului": "martir",
    "martiraje": "martiraj",
    "martirajele": "martiraj",
    "martirajelor": "martiraj",
    "martirajul": "martiraj",
    "martirajule": "martiraj",
    "martirajului": "martiraj",
    "martirii": "martiriu",
    "martiriile": "martiriu",
    "martiriilor": "martiriu",
    "martiriul": "martiriu",
    "martiriului": "martiriu",
    "martiriză": "martiriza",
    "martirizai": "martiriza",
    "martirizam": "martiriza",
    "martirizăm": "martiriza",
    "martirizând": "martiriza",
    "martirizându": "martiriza",
    "martirizară": "martiriza",
    "martirizarăm": "martiriza",
    "martirizarăți": "martiriza",
    "martirizase": "martiriza",
    "martirizasem": "martiriza",
    "martirizaseră": "martiriza",
    "martirizaserăm": "martiriza",
    "martirizaserăți": "martiriza",
    "martirizaseși": "martiriza",
    "martirizași": "martiriza",
    "martirizat": "martiriza",
    "martirizați": "martiriza",
    "martirizatu": "martiriza",
    "martirizau": "martiriza",
    "martirizează": "martiriza",
    "martirizez": "martiriza",
    "martirizeze": "martiriza",
    "martirizezi": "martiriza",
    "nemaimartirizând": "martiriza",
    "nemaimartirizându": "martiriza",
    "nemartirizând": "martiriza",
    "nemartirizându": "martiriza",
    "martirizarea": "martirizare",
    "martirizareo": "martirizare",
    "martirizări": "martirizare",
    "martirizării": "martirizare",
    "martirizările": "martirizare",
    "martirizărilor": "martirizare",
    "martirizată": "martirizat",
    "martirizate": "martirizat",
    "martirizați": "martirizat",
    "mârțoaga": "mârțoagă",
    "mârțoage": "mârțoagă",
    "mârțoagei": "mârțoagă",
    "mârțoagele": "mârțoagă",
    "mârțoagelor": "mârțoagă",
    "martori": "martor",
    "martorii": "martor",
    "martorilor": "martor",
    "martorul": "martor",
    "martorule": "martor",
    "martorului": "martor",
    "martora": "martoră",
    "martore": "martoră",
    "martorei": "martoră",
    "martorele": "martoră",
    "martorelor": "martoră",
    "martoro": "martoră",
    "mărturia": "mărturie",
    "mărturiei": "mărturie",
    "mărturii": "mărturie",
    "mărturiile": "mărturie",
    "mărturiilor": "mărturie",
    "mărturisea": "mărturisi",
    "mărturiseai": "mărturisi",
    "mărturiseam": "mărturisi",
    "mărturisească": "mărturisi",
    "mărturiseați": "mărturisi",
    "mărturiseau": "mărturisi",
    "mărturisesc": "mărturisi",
    "mărturisește": "mărturisi",
    "mărturisești": "mărturisi",
    "mărturisii": "mărturisi",
    "mărturisim": "mărturisi",
    "mărturisind": "mărturisi",
    "mărturisindu": "mărturisi",
    "mărturisiră": "mărturisi",
    "mărturisirăm": "mărturisi",
    "mărturisirăți": "mărturisi",
    "mărturisise": "mărturisi",
    "mărturisisem": "mărturisi",
    "mărturisiseră": "mărturisi",
    "mărturisiserăm": "mărturisi",
    "mărturisiserăți": "mărturisi",
    "mărturisiseși": "mărturisi",
    "mărturisiși": "mărturisi",
    "mărturisit": "mărturisi",
    "mărturisiți": "mărturisi",
    "mărturisitu": "mărturisi",
    "nemaimărturisind": "mărturisi",
    "nemaimărturisindu": "mărturisi",
    "nemărturisind": "mărturisi",
    "nemărturisindu": "mărturisi",
    "mărturisirea": "mărturisire",
    "mărturisiri": "mărturisire",
    "mărturisirii": "mărturisire",
    "mărturisirile": "mărturisire",
    "mărturisirilor": "mărturisire",
    "mărturisită": "mărturisit",
    "mărturisite": "mărturisit",
    "mărturisiți": "mărturisit",
    "mărunta": "mărunt",
    "măruntă": "mărunt",
    "mărunte": "mărunt",
    "măruntei": "mărunt",
    "măruntele": "mărunt",
    "măruntelor": "mărunt",
    "mărunți": "mărunt",
    "mărunții": "mărunt",
    "mărunților": "mărunt",
    "măruntul": "mărunt",
    "măruntului": "mărunt",
    "măruntaiele": "măruntaie",
    "măruntaielor": "măruntaie",
    "mărunțea": "mărunțel",
    "mărunțeaua": "mărunțel",
    "mărunței": "mărunțel",
    "mărunțeii": "mărunțel",
    "mărunțeilor": "mărunțel",
    "mărunțele": "mărunțel",
    "mărunțelei": "mărunțel",
    "mărunțelele": "mărunțel",
    "mărunțelelor": "mărunțel",
    "mărunțelul": "mărunțel",
    "mărunțelului": "mărunțel",
    "mărunțea": "mărunți",
    "mărunțeai": "mărunți",
    "mărunțeam": "mărunți",
    "mărunțească": "mărunți",
    "mărunțeați": "mărunți",
    "mărunțeau": "mărunți",
    "mărunțesc": "mărunți",
    "mărunțește": "mărunți",
    "mărunțești": "mărunți",
    "mărunții": "mărunți",
    "mărunțim": "mărunți",
    "mărunțind": "mărunți",
    "mărunțindu": "mărunți",
    "mărunțiră": "mărunți",
    "mărunțirăm": "mărunți",
    "mărunțirăți": "mărunți",
    "mărunțise": "mărunți",
    "mărunțisem": "mărunți",
    "mărunțiseră": "mărunți",
    "mărunțiserăm": "mărunți",
    "mărunțiserăți": "mărunți",
    "mărunțiseși": "mărunți",
    "mărunțiși": "mărunți",
    "mărunțit": "mărunți",
    "mărunțiți": "mărunți",
    "mărunțitu": "mărunți",
    "nemaimărunțind": "mărunți",
    "nemaimărunțindu": "mărunți",
    "nemărunțind": "mărunți",
    "nemărunțindu": "mărunți",
    "mărunțișul": "mărunțiș",
    "mărunțișului": "mărunțiș",
    "mărunțișuri": "mărunțiș",
    "mărunțișurile": "mărunțiș",
    "mărunțișurilor": "mărunțiș",
    "mărunțită": "mărunțit",
    "mărunțite": "mărunțit",
    "mărunțiți": "mărunțit",
    "marxismul": "marxism",
    "marxismului": "marxism",
    "marxism-leninismul": "marxism-leninism",
    "marxism-leninismului": "marxism-leninism",
    "marxista": "marxist",
    "marxistă": "marxist",
    "marxiste": "marxist",
    "marxistei": "marxist",
    "marxistele": "marxist",
    "marxistelor": "marxist",
    "marxiști": "marxist",
    "marxiștii": "marxist",
    "marxiștilor": "marxist",
    "marxisto": "marxist",
    "marxistul": "marxist",
    "marxistule": "marxist",
    "marxistului": "marxist",
    "marxist-leniniști": "marxist-leninist",
    "masul": "mas",
    "masului": "mas",
    "masuri": "mas",
    "masurile": "mas",
    "masurilor": "mas",
    "masă": "masa",
    "masai": "masa",
    "masam": "masa",
    "masăm": "masa",
    "masând": "masa",
    "masându": "masa",
    "masară": "masa",
    "masarăm": "masa",
    "masarăți": "masa",
    "masase": "masa",
    "masasem": "masa",
    "masaseră": "masa",
    "masaserăm": "masa",
    "masaserăți": "masa",
    "masaseși": "masa",
    "masași": "masa",
    "masat": "masa",
    "masați": "masa",
    "masatu": "masa",
    "masau": "masa",
    "masează": "masa",
    "masez": "masa",
    "maseze": "masa",
    "masezi": "masa",
    "nemaimasând": "masa",
    "nemaimasându": "masa",
    "nemasând": "masa",
    "nemasându": "masa",
    "masa": "masă",
    "mase": "masă",
    "masei": "masă",
    "masele": "masă",
    "maselor": "masă",
    "mese": "masă",
    "mesei": "masă",
    "mesele": "masă",
    "meselor": "masă",
    "masacră": "masacra",
    "masacrai": "masacra",
    "masacram": "masacra",
    "masacrăm": "masacra",
    "masacrând": "masacra",
    "masacrându": "masacra",
    "masacrară": "masacra",
    "masacrarăm": "masacra",
    "masacrarăți": "masacra",
    "masacrase": "masacra",
    "masacrasem": "masacra",
    "masacraseră": "masacra",
    "masacraserăm": "masacra",
    "masacraserăți": "masacra",
    "masacraseși": "masacra",
    "masacrași": "masacra",
    "masacrat": "masacra",
    "masacrați": "masacra",
    "masacratu": "masacra",
    "masacrau": "masacra",
    "masacrează": "masacra",
    "masacrez": "masacra",
    "masacreze": "masacra",
    "masacrezi": "masacra",
    "nemaimasacrând": "masacra",
    "nemaimasacrându": "masacra",
    "nemasacrând": "masacra",
    "nemasacrându": "masacra",
    "masacrarea": "masacrare",
    "masacrări": "masacrare",
    "masacrării": "masacrare",
    "masacrările": "masacrare",
    "masacrărilor": "masacrare",
    "masacrată": "masacrat",
    "masacrate": "masacrat",
    "masacrați": "masacrat",
    "masacre": "masacru",
    "masacrele": "masacru",
    "masacrelor": "masacru",
    "masacrul": "masacru",
    "masacrului": "masacru",
    "masaje": "masaj",
    "masajele": "masaj",
    "masajelor": "masaj",
    "masajul": "masaj",
    "masajului": "masaj",
    "masată": "masat",
    "masate": "masat",
    "masați": "masat",
    "mască": "masca",
    "mascai": "masca",
    "mascam": "masca",
    "mascăm": "masca",
    "mascând": "masca",
    "mascându": "masca",
    "mascară": "masca",
    "mascarăm": "masca",
    "mascarăți": "masca",
    "mascase": "masca",
    "mascasem": "masca",
    "mascaseră": "masca",
    "mascaserăm": "masca",
    "mascaserăți": "masca",
    "mascaseși": "masca",
    "mascași": "masca",
    "mascat": "masca",
    "mascați": "masca",
    "mascatu": "masca",
    "mascau": "masca",
    "maschează": "masca",
    "maschez": "masca",
    "mascheze": "masca",
    "maschezi": "masca",
    "nemaimascând": "masca",
    "nemaimascându": "masca",
    "nemascând": "masca",
    "nemascându": "masca",
    "masca": "mască",
    "măștii": "mască",
    "măștile": "mască",
    "măștilor": "mască",
    "mascarada": "mascaradă",
    "mascarade": "mascaradă",
    "mascaradei": "mascaradă",
    "mascaradele": "mascaradă",
    "mascaradelor": "mascaradă",
    "mascata": "mascat",
    "mascată": "mascat",
    "mascate": "mascat",
    "mascatei": "mascat",
    "mascatele": "mascat",
    "mascatelor": "mascat",
    "mascați": "mascat",
    "mascații": "mascat",
    "mascaților": "mascat",
    "mascatul": "mascat",
    "mascatului": "mascat",
    "mascota": "mascotă",
    "mascote": "mascotă",
    "mascotei": "mascotă",
    "mascotele": "mascotă",
    "mascotelor": "mascotă",
    "masculi": "mascul",
    "masculii": "mascul",
    "masculilor": "mascul",
    "masculul": "mascul",
    "masculului": "mascul",
    "m.": "masculin",
    "masculina": "masculin",
    "masculină": "masculin",
    "masculine": "masculin",
    "masculinei": "masculin",
    "masculinele": "masculin",
    "masculinelor": "masculin",
    "masculini": "masculin",
    "masculinii": "masculin",
    "masculinilor": "masculin",
    "masculinul": "masculin",
    "masculinului": "masculin",
    "măseao": "măsea",
    "măseaua": "măsea",
    "măsele": "măsea",
    "măselei": "măsea",
    "măselele": "măsea",
    "măselelor": "măsea",
    "măselei-ciutei": "măseaua-ciutei",
    "maseza": "maseză",
    "maseze": "maseză",
    "masezei": "maseză",
    "masezele": "maseză",
    "masezelor": "maseză",
    "mașina": "mașină",
    "mașini": "mașină",
    "mașinii": "mașină",
    "mașinile": "mașină",
    "mașinilor": "mașină",
    "mașinala": "mașinal",
    "mașinală": "mașinal",
    "mașinale": "mașinal",
    "mașinalei": "mașinal",
    "mașinalele": "mașinal",
    "mașinalelor": "mașinal",
    "mașinali": "mașinal",
    "mașinalii": "mașinal",
    "mașinalilor": "mașinal",
    "mașinalul": "mașinal",
    "mașinalului": "mașinal",
    "mașinăria": "mașinărie",
    "mașinăriei": "mașinărie",
    "mașinării": "mașinărie",
    "mașinăriile": "mașinărie",
    "mașinăriilor": "mașinărie",
    "mașinația": "mașinație",
    "mașinației": "mașinație",
    "mașinații": "mașinație",
    "mașinațiile": "mașinație",
    "mașinațiilor": "mașinație",
    "mașinismul": "mașinism",
    "mașinismului": "mașinism",
    "mașinista": "mașinist",
    "mașinistă": "mașinist",
    "mașiniste": "mașinist",
    "mașinistei": "mașinist",
    "mașinistele": "mașinist",
    "mașinistelor": "mașinist",
    "mașiniști": "mașinist",
    "mașiniștii": "mașinist",
    "mașiniștilor": "mașinist",
    "mașinistul": "mașinist",
    "mașinistului": "mașinist",
    "masiva": "masiv",
    "masivă": "masiv",
    "masive": "masiv",
    "masivei": "masiv",
    "masivele": "masiv",
    "masivelor": "masiv",
    "masivi": "masiv",
    "masivii": "masiv",
    "masivilor": "masiv",
    "masivul": "masiv",
    "masivului": "masiv",
    "măslini": "măslin",
    "măslinii": "măslin",
    "măslinilor": "măslin",
    "măslinul": "măslin",
    "măslinule": "măslin",
    "măslinului": "măslin",
    "măslina": "măslină",
    "măsline": "măslină",
    "măslinei": "măslină",
    "măslinele": "măslină",
    "măslinelor": "măslină",
    "măslinia": "măsliniu",
    "măslinie": "măsliniu",
    "măsliniei": "măsliniu",
    "măslinii": "măsliniu",
    "măsliniii": "măsliniu",
    "măsliniile": "măsliniu",
    "măsliniilor": "măsliniu",
    "măsliniul": "măsliniu",
    "măsliniului": "măsliniu",
    "măsluia": "măslui",
    "măsluiai": "măslui",
    "măsluiam": "măslui",
    "măsluiască": "măslui",
    "măsluiați": "măslui",
    "măsluiau": "măslui",
    "măsluiesc": "măslui",
    "măsluiește": "măslui",
    "măsluiești": "măslui",
    "măsluii": "măslui",
    "măsluim": "măslui",
    "măsluind": "măslui",
    "măsluindu": "măslui",
    "măsluiră": "măslui",
    "măsluirăm": "măslui",
    "măsluirăți": "măslui",
    "măsluise": "măslui",
    "măsluisem": "măslui",
    "măsluiseră": "măslui",
    "măsluiserăm": "măslui",
    "măsluiserăți": "măslui",
    "măsluiseși": "măslui",
    "măsluiși": "măslui",
    "măsluit": "măslui",
    "măsluiți": "măslui",
    "măsluitu": "măslui",
    "nemaimăsluind": "măslui",
    "nemaimăsluindu": "măslui",
    "nemăsluind": "măslui",
    "nemăsluindu": "măslui",
    "măsluită": "măsluit",
    "măsluite": "măsluit",
    "măsluiți": "măsluit",
    "masochismul": "masochism",
    "masochismule": "masochism",
    "masochismului": "masochism",
    "masoni": "mason",
    "masonii": "mason",
    "masonilor": "mason",
    "masonul": "mason",
    "masonului": "mason",
    "masoneria": "masonerie",
    "masonerii": "masonerie",
    "masoneriii": "masonerie",
    "masoneriile": "masonerie",
    "masoneriilor": "masonerie",
    "masonerio": "masonerie",
    "masori": "masor",
    "masorii": "masor",
    "masorilor": "masor",
    "masorul": "masor",
    "masorului": "masor",
    "maștera": "mașteră",
    "maștere": "mașteră",
    "mașterei": "mașteră",
    "mașterele": "mașteră",
    "mașterelor": "mașteră",
    "masticația": "masticație",
    "masticației": "masticație",
    "masticații": "masticație",
    "masticațiile": "masticație",
    "masticațiilor": "masticație",
    "masticatoare": "masticator",
    "masticatoarea": "masticator",
    "masticatoarei": "masticator",
    "masticatoarele": "masticator",
    "masticatoarelor": "masticator",
    "masticatori": "masticator",
    "masticatorii": "masticator",
    "masticatorilor": "masticator",
    "masticatorul": "masticator",
    "masticatorului": "masticator",
    "mastodonți": "mastodont",
    "mastodonții": "mastodont",
    "mastodonților": "mastodont",
    "mastodontul": "mastodont",
    "mastodontului": "mastodont",
    "măsoară": "măsura",
    "măsoare": "măsura",
    "măsor": "măsura",
    "măsori": "măsura",
    "măsură": "măsura",
    "măsurai": "măsura",
    "măsuram": "măsura",
    "măsurăm": "măsura",
    "măsurând": "măsura",
    "măsurându": "măsura",
    "măsurară": "măsura",
    "măsurarăm": "măsura",
    "măsurarăți": "măsura",
    "măsurase": "măsura",
    "măsurasem": "măsura",
    "măsuraseră": "măsura",
    "măsuraserăm": "măsura",
    "măsuraserăți": "măsura",
    "măsuraseși": "măsura",
    "măsurași": "măsura",
    "măsurat": "măsura",
    "măsurați": "măsura",
    "măsuratu": "măsura",
    "măsurau": "măsura",
    "nemaimăsurând": "măsura",
    "nemaimăsurându": "măsura",
    "nemăsurând": "măsura",
    "nemăsurându": "măsura",
    "măsura": "măsură",
    "măsuri": "măsură",
    "măsurii": "măsură",
    "măsurile": "măsură",
    "măsurilor": "măsură",
    "măsurarea": "măsurare",
    "măsurareo": "măsurare",
    "măsurări": "măsurare",
    "măsurării": "măsurare",
    "măsurările": "măsurare",
    "măsurărilor": "măsurare",
    "măsurata": "măsurat",
    "măsurată": "măsurat",
    "măsurate": "măsurat",
    "măsuratei": "măsurat",
    "măsuratele": "măsurat",
    "măsuratelor": "măsurat",
    "măsurați": "măsurat",
    "măsurații": "măsurat",
    "măsuraților": "măsurat",
    "măsuratul": "măsurat",
    "măsuratului": "măsurat",
    "măsurătoarea": "măsurătoare",
    "măsurători": "măsurătoare",
    "măsurătorii": "măsurătoare",
    "măsurătorile": "măsurătoare",
    "măsurătorilor": "măsurătoare",
    "măsuța": "măsuță",
    "măsuțe": "măsuță",
    "măsuței": "măsuță",
    "măsuțele": "măsuță",
    "măsuțelor": "măsuță",
    "mata": "mat",
    "mată": "mat",
    "mate": "mat",
    "matei": "mat",
    "matele": "mat",
    "matelor": "mat",
    "mați": "mat",
    "mații": "mat",
    "maților": "mat",
    "matul": "mat",
    "matului": "mat",
    "mațe": "maț",
    "mațele": "maț",
    "mațelor": "maț",
    "mațul": "maț",
    "mațului": "maț",
    "mâți": "mâț",
    "mâții": "mâț",
    "mâților": "mâț",
    "mâțul": "mâț",
    "mâțului": "mâț",
    "matale": "mata",
    "mâța": "mâță",
    "mâțe": "mâță",
    "mâței": "mâță",
    "mâțele": "mâță",
    "mâțelor": "mâță",
    "mătii": "măta",
    "matadori": "matador",
    "matadorii": "matador",
    "matadorilor": "matador",
    "matadorul": "matador",
    "matadorului": "matador",
    "matahala": "matahală",
    "matahale": "matahală",
    "matahalei": "matahală",
    "matahalele": "matahală",
    "matahalelor": "matahală",
    "mătăhăloasa": "mătăhălos",
    "mătăhăloasă": "mătăhălos",
    "mătăhăloase": "mătăhălos",
    "mătăhăloasei": "mătăhălos",
    "mătăhăloasele": "mătăhălos",
    "mătăhăloaselor": "mătăhălos",
    "mătăhăloși": "mătăhălos",
    "mătăhăloșii": "mătăhălos",
    "mătăhăloșilor": "mătăhălos",
    "mătăhălosul": "mătăhălos",
    "mătăhălosului": "mătăhălos",
    "mătania": "mătanie",
    "mătaniei": "mătanie",
    "mătănii": "mătanie",
    "mătăniile": "mătanie",
    "mătăniilor": "mătanie",
    "mătasea": "mătase",
    "mătăsei": "mătase",
    "mătăsi": "mătase",
    "mătăsii": "mătase",
    "mătasuri": "mătase",
    "mătăsuri": "mătase",
    "mătasurile": "mătase",
    "mătăsurile": "mătase",
    "mătasurilor": "mătase",
    "mătăsurilor": "mătase",
    "mătăsii-bradului": "mătasea-bradului",
    "mătăsii-broaștei": "mătasea-broaștei",
    "mătăsoasa": "mătăsos",
    "mătăsoasă": "mătăsos",
    "mătăsoase": "mătăsos",
    "mătăsoasei": "mătăsos",
    "mătăsoasele": "mătăsos",
    "mătăsoaselor": "mătăsos",
    "mătăsoși": "mătăsos",
    "mătăsoșii": "mătăsos",
    "mătăsoșilor": "mătăsos",
    "mătăsosul": "mătăsos",
    "mătăsosului": "mătăsos",
    "matca": "matcă",
    "mătci": "matcă",
    "mătcii": "matcă",
    "mătcile": "matcă",
    "mătcilor": "matcă",
    "mateloți": "matelot",
    "mateloții": "matelot",
    "mateloților": "matelot",
    "matelotul": "matelot",
    "matelotului": "matelot",
    "matematica": "matematic",
    "matematică": "matematic",
    "matematice": "matematic",
    "matematicei": "matematic",
    "matematicele": "matematic",
    "matematicelor": "matematic",
    "matematici": "matematic",
    "matematicii": "matematic",
    "matematicilor": "matematic",
    "matematicul": "matematic",
    "matematicului": "matematic",
    "mat.": "matematică",
    "matematica": "matematică",
    "matematice": "matematică",
    "matematicei": "matematică",
    "matematicele": "matematică",
    "matematicelor": "matematică",
    "matematici": "matematică",
    "matematicii": "matematică",
    "matematicile": "matematică",
    "matematicilor": "matematică",
    "matematico": "matematică",
    "matematicianul": "matematician",
    "matematicianului": "matematician",
    "matematicieni": "matematician",
    "matematicienii": "matematician",
    "matematicienilor": "matematician",
    "materiala": "material",
    "materială": "material",
    "materiale": "material",
    "materialei": "material",
    "materialele": "material",
    "materialelor": "material",
    "materiali": "material",
    "materialii": "material",
    "materialilor": "material",
    "materialul": "material",
    "materialului": "material",
    "mat.": "materiale",
    "materialismul": "materialism",
    "materialismului": "materialism",
    "materialiști": "materialist",
    "materialiștii": "materialist",
    "materialiștilor": "materialist",
    "materialistul": "materialist",
    "materialistului": "materialist",
    "materializă": "materializa",
    "materializai": "materializa",
    "materializam": "materializa",
    "materializăm": "materializa",
    "materializând": "materializa",
    "materializându": "materializa",
    "materializară": "materializa",
    "materializarăm": "materializa",
    "materializarăți": "materializa",
    "materializase": "materializa",
    "materializasem": "materializa",
    "materializaseră": "materializa",
    "materializaserăm": "materializa",
    "materializaserăți": "materializa",
    "materializaseși": "materializa",
    "materializași": "materializa",
    "materializat": "materializa",
    "materializați": "materializa",
    "materializatu": "materializa",
    "materializau": "materializa",
    "materializează": "materializa",
    "materializez": "materializa",
    "materializeze": "materializa",
    "materializezi": "materializa",
    "nemaimaterializând": "materializa",
    "nemaimaterializându": "materializa",
    "nematerializând": "materializa",
    "nematerializându": "materializa",
    "materializată": "materializat",
    "materializate": "materializat",
    "materializați": "materializat",
    "materia": "materie",
    "materiei": "materie",
    "materii": "materie",
    "materiile": "materie",
    "materiilor": "materie",
    "materna": "matern",
    "maternă": "matern",
    "materne": "matern",
    "maternei": "matern",
    "maternele": "matern",
    "maternelor": "matern",
    "materni": "matern",
    "maternii": "matern",
    "maternilor": "matern",
    "maternul": "matern",
    "maternului": "matern",
    "maternitatea": "maternitate",
    "maternități": "maternitate",
    "maternității": "maternitate",
    "maternitățile": "maternitate",
    "maternităților": "maternitate",
    "matinala": "matinal",
    "matinală": "matinal",
    "matinale": "matinal",
    "matinalei": "matinal",
    "matinalele": "matinal",
    "matinalelor": "matinal",
    "matinali": "matinal",
    "matinalii": "matinal",
    "matinalilor": "matinal",
    "matinalul": "matinal",
    "matinalului": "matinal",
    "matinee": "matineu",
    "matineele": "matineu",
    "matineelor": "matineu",
    "matineul": "matineu",
    "matineului": "matineu",
    "mâțișori": "mâțișor",
    "mâțișorii": "mâțișor",
    "mâțișorilor": "mâțișor",
    "mâțișorul": "mâțișor",
    "mâțișorului": "mâțișor",
    "matlasă": "matlasa",
    "matlasai": "matlasa",
    "matlasam": "matlasa",
    "matlasăm": "matlasa",
    "matlasând": "matlasa",
    "matlasându": "matlasa",
    "matlasară": "matlasa",
    "matlasarăm": "matlasa",
    "matlasarăți": "matlasa",
    "matlasase": "matlasa",
    "matlasasem": "matlasa",
    "matlasaseră": "matlasa",
    "matlasaserăm": "matlasa",
    "matlasaserăți": "matlasa",
    "matlasaseși": "matlasa",
    "matlasași": "matlasa",
    "matlasat": "matlasa",
    "matlasați": "matlasa",
    "matlasatu": "matlasa",
    "matlasau": "matlasa",
    "matlasează": "matlasa",
    "matlasez": "matlasa",
    "matlaseze": "matlasa",
    "matlasezi": "matlasa",
    "nemaimatlasând": "matlasa",
    "nemaimatlasându": "matlasa",
    "nematlasând": "matlasa",
    "nematlasându": "matlasa",
    "matlasată": "matlasat",
    "matlasate": "matlasat",
    "matlasați": "matlasat",
    "matostate": "matostat",
    "matostatele": "matostat",
    "matostatelor": "matostat",
    "matostatul": "matostat",
    "matostatului": "matostat",
    "mătrăguna": "mătrăgună",
    "mătrăgune": "mătrăgună",
    "mătrăgunei": "mătrăgună",
    "matrapazlâcul": "matrapazlâc",
    "matrapazlâcului": "matrapazlâc",
    "matrapazlâcuri": "matrapazlâc",
    "matrapazlâcurile": "matrapazlâc",
    "matrapazlâcurilor": "matrapazlâc",
    "mătrășea": "mătrăși",
    "mătrășeai": "mătrăși",
    "mătrășeam": "mătrăși",
    "mătrășească": "mătrăși",
    "mătrășeați": "mătrăși",
    "mătrășeau": "mătrăși",
    "mătrășesc": "mătrăși",
    "mătrășește": "mătrăși",
    "mătrășești": "mătrăși",
    "mătrășii": "mătrăși",
    "mătrășim": "mătrăși",
    "mătrășind": "mătrăși",
    "mătrășindu": "mătrăși",
    "mătrășiră": "mătrăși",
    "mătrășirăm": "mătrăși",
    "mătrășirăți": "mătrăși",
    "mătrășise": "mătrăși",
    "mătrășisem": "mătrăși",
    "mătrășiseră": "mătrăși",
    "mătrășiserăm": "mătrăși",
    "mătrășiserăți": "mătrăși",
    "mătrășiseși": "mătrăși",
    "mătrășiși": "mătrăși",
    "mătrășit": "mătrăși",
    "mătrășiți": "mătrăși",
    "mătrășitu": "mătrăși",
    "nemaimătrășind": "mătrăși",
    "nemaimătrășindu": "mătrăși",
    "nemătrășind": "mătrăși",
    "nemătrășindu": "mătrăși",
    "mătrășită": "mătrășit",
    "mătrășite": "mătrășit",
    "mătrășiți": "mătrășit",
    "mătreții-brazilor": "mătreața-brazilor",
    "mătreții-de-arbori": "mătreață-de-arbori",
    "matriarhatul": "matriarhat",
    "matriarhatului": "matriarhat",
    "matricea": "matrice",
    "matrici": "matrice",
    "matricii": "matrice",
    "matricile": "matrice",
    "matricilor": "matrice",
    "matricidul": "matricid",
    "matricidului": "matricid",
    "matriciduri": "matricid",
    "matricidurile": "matricid",
    "matricidurilor": "matricid",
    "matricola": "matricol",
    "matricolă": "matricol",
    "matricole": "matricol",
    "matricolei": "matricol",
    "matricolele": "matricol",
    "matricolelor": "matricol",
    "matricoli": "matricol",
    "matricolii": "matricol",
    "matricolilor": "matricol",
    "matricolul": "matricol",
    "matricolului": "matricol",
    "matricola": "matricolă",
    "matricole": "matricolă",
    "matricolei": "matricolă",
    "matricolele": "matricolă",
    "matricolelor": "matricolă",
    "matrimoniala": "matrimonial",
    "matrimonială": "matrimonial",
    "matrimoniale": "matrimonial",
    "matrimonialei": "matrimonial",
    "matrimonialele": "matrimonial",
    "matrimonialelor": "matrimonial",
    "matrimoniali": "matrimonial",
    "matrimonialii": "matrimonial",
    "matrimonialilor": "matrimonial",
    "matrimonialul": "matrimonial",
    "matrimonialului": "matrimonial",
    "matrița": "matriță",
    "matrițe": "matriță",
    "matriței": "matriță",
    "matrițele": "matriță",
    "matrițelor": "matriță",
    "matroana": "matroană",
    "matroane": "matroană",
    "matroanei": "matroană",
    "matroanele": "matroană",
    "matroanelor": "matroană",
    "matrozi": "matroz",
    "matrozii": "matroz",
    "matrozilor": "matroz",
    "matrozul": "matroz",
    "matrozului": "matroz",
    "matura": "matur",
    "matură": "matur",
    "mature": "matur",
    "maturei": "matur",
    "maturele": "matur",
    "maturelor": "matur",
    "maturi": "matur",
    "maturii": "matur",
    "maturilor": "matur",
    "maturul": "matur",
    "maturului": "matur",
    "mătur": "mătura",
    "mătură": "mătura",
    "măturai": "mătura",
    "măturam": "mătura",
    "măturăm": "mătura",
    "măturând": "mătura",
    "măturându": "mătura",
    "măturară": "mătura",
    "măturarăm": "mătura",
    "măturarăți": "mătura",
    "măturase": "mătura",
    "măturasem": "mătura",
    "măturaseră": "mătura",
    "măturaserăm": "mătura",
    "măturaserăți": "mătura",
    "măturaseși": "mătura",
    "măturași": "mătura",
    "măturat": "mătura",
    "măturați": "mătura",
    "măturatu": "mătura",
    "măturau": "mătura",
    "măture": "mătura",
    "mături": "mătura",
    "nemaimăturând": "mătura",
    "nemaimăturându": "mătura",
    "nemăturând": "mătura",
    "nemăturându": "mătura",
    "mătura": "mătură",
    "mături": "mătură",
    "măturii": "mătură",
    "măturile": "mătură",
    "măturilor": "mătură",
    "maturarea": "maturare",
    "maturareo": "maturare",
    "maturări": "maturare",
    "maturării": "maturare",
    "maturările": "maturare",
    "maturărilor": "maturare",
    "măturată": "măturat",
    "măturate": "măturat",
    "măturați": "măturat",
    "măturatul": "măturat",
    "măturatului": "măturat",
    "maturația": "maturație",
    "maturației": "maturație",
    "maturații": "maturație",
    "maturațiile": "maturație",
    "maturațiilor": "maturație",
    "măturători": "măturător",
    "măturătorii": "măturător",
    "măturătorilor": "măturător",
    "măturătorul": "măturător",
    "măturătorule": "măturător",
    "măturătorului": "măturător",
    "maturitatea": "maturitate",
    "maturități": "maturitate",
    "maturității": "maturitate",
    "maturitățile": "maturitate",
    "maturităților": "maturitate",
    "maturiză": "maturiza",
    "maturizai": "maturiza",
    "maturizam": "maturiza",
    "maturizăm": "maturiza",
    "maturizând": "maturiza",
    "maturizându": "maturiza",
    "maturizară": "maturiza",
    "maturizarăm": "maturiza",
    "maturizarăți": "maturiza",
    "maturizase": "maturiza",
    "maturizasem": "maturiza",
    "maturizaseră": "maturiza",
    "maturizaserăm": "maturiza",
    "maturizaserăți": "maturiza",
    "maturizaseși": "maturiza",
    "maturizași": "maturiza",
    "maturizat": "maturiza",
    "maturizați": "maturiza",
    "maturizatu": "maturiza",
    "maturizau": "maturiza",
    "maturizează": "maturiza",
    "maturizez": "maturiza",
    "maturizeze": "maturiza",
    "maturizezi": "maturiza",
    "nemaimaturizând": "maturiza",
    "nemaimaturizându": "maturiza",
    "nematurizând": "maturiza",
    "nematurizându": "maturiza",
    "maturizarea": "maturizare",
    "maturizareo": "maturizare",
    "maturizări": "maturizare",
    "maturizării": "maturizare",
    "maturizările": "maturizare",
    "maturizărilor": "maturizare",
    "maturizată": "maturizat",
    "maturizate": "maturizat",
    "maturizați": "maturizat",
    "mătușa": "mătușă",
    "mătuși": "mătușă",
    "mătușii": "mătușă",
    "mătușile": "mătușă",
    "mătușilor": "mătușă",
    "mătușo": "mătușă",
    "matusalemica": "matusalemic",
    "matusalemică": "matusalemic",
    "matusalemice": "matusalemic",
    "matusalemicei": "matusalemic",
    "matusalemicele": "matusalemic",
    "matusalemicelor": "matusalemic",
    "matusalemici": "matusalemic",
    "matusalemicii": "matusalemic",
    "matusalemicilor": "matusalemic",
    "matusalemicul": "matusalemic",
    "matusalemicului": "matusalemic",
    "maura": "maur",
    "maură": "maur",
    "maure": "maur",
    "maurei": "maur",
    "maurele": "maur",
    "maurelor": "maur",
    "mauri": "maur",
    "maurii": "maur",
    "maurilor": "maur",
    "maurul": "maur",
    "maurului": "maur",
    "mausolee": "mausoleu",
    "mausoleele": "mausoleu",
    "mausoleelor": "mausoleu",
    "mausoleul": "mausoleu",
    "mausoleului": "mausoleu",
    "maxilare": "maxilar",
    "maxilarele": "maxilar",
    "maxilarelor": "maxilar",
    "maxilarul": "maxilar",
    "maxilarului": "maxilar",
    "max.": "maxim",
    "maxima": "maxim",
    "maximă": "maxim",
    "maxime": "maxim",
    "maximei": "maxim",
    "maximele": "maxim",
    "maximelor": "maxim",
    "maximi": "maxim",
    "maximii": "maxim",
    "maximilor": "maxim",
    "maximul": "maxim",
    "maximului": "maxim",
    "maximuri": "maxim",
    "maximurile": "maxim",
    "maximurilor": "maxim",
    "maxima": "maximă",
    "maxime": "maximă",
    "maximei": "maximă",
    "maximele": "maximă",
    "maximelor": "maximă",
    "maximala": "maximal",
    "maximală": "maximal",
    "maximale": "maximal",
    "maximalei": "maximal",
    "maximalele": "maximal",
    "maximalelor": "maximal",
    "maximali": "maximal",
    "maximalii": "maximal",
    "maximalilor": "maximal",
    "maximalul": "maximal",
    "maximalului": "maximal",
    "maximumul": "maximum",
    "maximumului": "maximum",
    "măzărichii-cucului": "măzărichea-cucului",
    "măzărichii-negre": "măzăriche-neagră",
    "mâzga": "mâzgă",
    "mâzgălea": "mâzgăli",
    "mâzgăleai": "mâzgăli",
    "mâzgăleam": "mâzgăli",
    "mâzgălească": "mâzgăli",
    "mâzgăleați": "mâzgăli",
    "mâzgăleau": "mâzgăli",
    "mâzgălesc": "mâzgăli",
    "mâzgălește": "mâzgăli",
    "mâzgălești": "mâzgăli",
    "mâzgălii": "mâzgăli",
    "mâzgălim": "mâzgăli",
    "mâzgălind": "mâzgăli",
    "mâzgălindu": "mâzgăli",
    "mâzgăliră": "mâzgăli",
    "mâzgălirăm": "mâzgăli",
    "mâzgălirăți": "mâzgăli",
    "mâzgălise": "mâzgăli",
    "mâzgălisem": "mâzgăli",
    "mâzgăliseră": "mâzgăli",
    "mâzgăliserăm": "mâzgăli",
    "mâzgăliserăți": "mâzgăli",
    "mâzgăliseși": "mâzgăli",
    "mâzgăliși": "mâzgăli",
    "mâzgălit": "mâzgăli",
    "mâzgăliți": "mâzgăli",
    "mâzgălitu": "mâzgăli",
    "nemaimâzgălind": "mâzgăli",
    "nemaimâzgălindu": "mâzgăli",
    "nemâzgălind": "mâzgăli",
    "nemâzgălindu": "mâzgăli",
    "mâzgălită": "mâzgălit",
    "mâzgălite": "mâzgălit",
    "mâzgăliți": "mâzgălit",
    "mâzgoasa": "mâzgos",
    "mâzgoasă": "mâzgos",
    "mâzgoase": "mâzgos",
    "mâzgoasei": "mâzgos",
    "mâzgoasele": "mâzgos",
    "mâzgoaselor": "mâzgos",
    "mâzgoși": "mâzgos",
    "mâzgoșii": "mâzgos",
    "mâzgoșilor": "mâzgos",
    "mâzgosul": "mâzgos",
    "mâzgosului": "mâzgos",
    "mazili": "mazil",
    "mazilii": "mazil",
    "mazililor": "mazil",
    "mazilul": "mazil",
    "mazilului": "mazil",
    "mazilea": "mazili",
    "mazileai": "mazili",
    "mazileam": "mazili",
    "mazilească": "mazili",
    "mazileați": "mazili",
    "mazileau": "mazili",
    "mazilesc": "mazili",
    "mazilește": "mazili",
    "mazilești": "mazili",
    "mazilii": "mazili",
    "mazilim": "mazili",
    "mazilind": "mazili",
    "mazilindu": "mazili",
    "maziliră": "mazili",
    "mazilirăm": "mazili",
    "mazilirăți": "mazili",
    "mazilise": "mazili",
    "mazilisem": "mazili",
    "maziliseră": "mazili",
    "maziliserăm": "mazili",
    "maziliserăți": "mazili",
    "maziliseși": "mazili",
    "maziliși": "mazili",
    "mazilit": "mazili",
    "maziliți": "mazili",
    "mazilitu": "mazili",
    "nemaimazilind": "mazili",
    "nemaimazilindu": "mazili",
    "nemazilind": "mazili",
    "nemazilindu": "mazili",
    "mazilită": "mazilit",
    "mazilite": "mazilit",
    "maziliți": "mazilit",
    "meandre": "meandru",
    "meandrele": "meandru",
    "meandrelor": "meandru",
    "meandrul": "meandru",
    "meandrului": "meandru",
    "meatul": "meat",
    "meatului": "meat",
    "meaturi": "meat",
    "meaturile": "meat",
    "meaturilor": "meat",
    "mecanica": "mecanic",
    "mecanică": "mecanic",
    "mecanice": "mecanic",
    "mecanicei": "mecanic",
    "mecanicele": "mecanic",
    "mecanicelor": "mecanic",
    "mecanici": "mecanic",
    "mecanicii": "mecanic",
    "mecanicilor": "mecanic",
    "mecanicul": "mecanic",
    "mecanicului": "mecanic",
    "mec.": "mecanică",
    "mecanica": "mecanică",
    "mecanicista": "mecanicist",
    "mecanicistă": "mecanicist",
    "mecaniciste": "mecanicist",
    "mecanicistei": "mecanicist",
    "mecanicistele": "mecanicist",
    "mecanicistelor": "mecanicist",
    "mecaniciști": "mecanicist",
    "mecaniciștii": "mecanicist",
    "mecaniciștilor": "mecanicist",
    "mecanicistul": "mecanicist",
    "mecanicistului": "mecanicist",
    "mecanisme": "mecanism",
    "mecanismele": "mecanism",
    "mecanismelor": "mecanism",
    "mecanismul": "mecanism",
    "mecanismului": "mecanism",
    "mecaniză": "mecaniza",
    "mecanizai": "mecaniza",
    "mecanizam": "mecaniza",
    "mecanizăm": "mecaniza",
    "mecanizând": "mecaniza",
    "mecanizându": "mecaniza",
    "mecanizară": "mecaniza",
    "mecanizarăm": "mecaniza",
    "mecanizarăți": "mecaniza",
    "mecanizase": "mecaniza",
    "mecanizasem": "mecaniza",
    "mecanizaseră": "mecaniza",
    "mecanizaserăm": "mecaniza",
    "mecanizaserăți": "mecaniza",
    "mecanizaseși": "mecaniza",
    "mecanizași": "mecaniza",
    "mecanizat": "mecaniza",
    "mecanizați": "mecaniza",
    "mecanizatu": "mecaniza",
    "mecanizau": "mecaniza",
    "mecanizează": "mecaniza",
    "mecanizez": "mecaniza",
    "mecanizeze": "mecaniza",
    "mecanizezi": "mecaniza",
    "nemaimecanizând": "mecaniza",
    "nemaimecanizându": "mecaniza",
    "nemecanizând": "mecaniza",
    "nemecanizându": "mecaniza",
    "mecanizarea": "mecanizare",
    "mecanizări": "mecanizare",
    "mecanizării": "mecanizare",
    "mecanizările": "mecanizare",
    "mecanizărilor": "mecanizare",
    "mecanizata": "mecanizat",
    "mecanizată": "mecanizat",
    "mecanizate": "mecanizat",
    "mecanizatei": "mecanizat",
    "mecanizatele": "mecanizat",
    "mecanizatelor": "mecanizat",
    "mecanizați": "mecanizat",
    "mecanizații": "mecanizat",
    "mecanizaților": "mecanizat",
    "mecanizatul": "mecanizat",
    "mecanizatului": "mecanizat",
    "mecano-chimică": "mecano-chimic",
    "mecano-chimice": "mecano-chimic",
    "mecano-chimici": "mecano-chimic",
    "mecanoterapia": "mecanoterapie",
    "mecanoterapiei": "mecanoterapie",
    "mecanoterapii": "mecanoterapie",
    "mecanoterapiile": "mecanoterapie",
    "mecanoterapiilor": "mecanoterapie",
    "meciu'": "meci",
    "meciul": "meci",
    "meciule": "meci",
    "meciului": "meci",
    "meciuri": "meci",
    "meciurile": "meci",
    "meciurilor": "meci",
    "medaliai": "medalia",
    "medaliam": "medalia",
    "medaliară": "medalia",
    "medaliarăm": "medalia",
    "medaliarăți": "medalia",
    "medaliase": "medalia",
    "medaliasem": "medalia",
    "medaliaseră": "medalia",
    "medaliaserăm": "medalia",
    "medaliaserăți": "medalia",
    "medaliaseși": "medalia",
    "medaliași": "medalia",
    "medaliat": "medalia",
    "medaliați": "medalia",
    "medaliatu": "medalia",
    "medaliau": "medalia",
    "medaliază": "medalia",
    "medalie": "medalia",
    "medaliem": "medalia",
    "medaliez": "medalia",
    "medalieze": "medalia",
    "medaliezi": "medalia",
    "medaliind": "medalia",
    "medaliindu": "medalia",
    "nemaimedaliind": "medalia",
    "nemaimedaliindu": "medalia",
    "nemedaliind": "medalia",
    "nemedaliindu": "medalia",
    "medaliata": "medaliat",
    "medaliată": "medaliat",
    "medaliate": "medaliat",
    "medaliatei": "medaliat",
    "medaliatele": "medaliat",
    "medaliatelor": "medaliat",
    "medaliați": "medaliat",
    "medaliații": "medaliat",
    "medaliaților": "medaliat",
    "medaliatul": "medaliat",
    "medaliatului": "medaliat",
    "medaliata": "medaliată",
    "medaliate": "medaliată",
    "medaliatei": "medaliată",
    "medaliatele": "medaliată",
    "medaliatelor": "medaliată",
    "medalia": "medalie",
    "medaliei": "medalie",
    "medalii": "medalie",
    "medaliile": "medalie",
    "medaliilor": "medalie",
    "medalioane": "medalion",
    "medalioanele": "medalion",
    "medalioanelor": "medalion",
    "medalionul": "medalion",
    "medalionului": "medalion",
    "mediai": "media",
    "mediam": "media",
    "mediară": "media",
    "mediarăm": "media",
    "mediarăți": "media",
    "mediase": "media",
    "mediasem": "media",
    "mediaseră": "media",
    "mediaserăm": "media",
    "mediaserăți": "media",
    "mediaseși": "media",
    "mediași": "media",
    "mediat": "media",
    "mediați": "media",
    "mediatu": "media",
    "mediau": "media",
    "mediază": "media",
    "medie": "media",
    "mediem": "media",
    "mediez": "media",
    "medieze": "media",
    "mediezi": "media",
    "mediind": "media",
    "mediindu": "media",
    "nemaimediind": "media",
    "nemaimediindu": "media",
    "nemediind": "media",
    "nemediindu": "media",
    "mediala": "medial",
    "medială": "medial",
    "mediale": "medial",
    "medialei": "medial",
    "medialele": "medial",
    "medialelor": "medial",
    "mediali": "medial",
    "medialii": "medial",
    "medialilor": "medial",
    "medialul": "medial",
    "medialului": "medial",
    "mediana": "median",
    "mediană": "median",
    "mediane": "median",
    "medianei": "median",
    "medianele": "median",
    "medianelor": "median",
    "mediani": "median",
    "medianii": "median",
    "medianilor": "median",
    "medianul": "median",
    "medianului": "median",
    "mediată": "mediat",
    "mediate": "mediat",
    "mediați": "mediat",
    "mediatica": "mediatic",
    "mediatică": "mediatic",
    "mediatice": "mediatic",
    "mediaticei": "mediatic",
    "mediaticele": "mediatic",
    "mediaticelor": "mediatic",
    "mediatici": "mediatic",
    "mediaticii": "mediatic",
    "mediaticilor": "mediatic",
    "mediaticul": "mediatic",
    "mediaticului": "mediatic",
    "mediatizarea": "mediatizare",
    "mediatizareo": "mediatizare",
    "mediatizări": "mediatizare",
    "mediatizării": "mediatizare",
    "mediatizările": "mediatizare",
    "mediatizărilor": "mediatizare",
    "mediatizata": "mediatizat",
    "mediatizată": "mediatizat",
    "mediatizate": "mediatizat",
    "mediatizatei": "mediatizat",
    "mediatizatele": "mediatizat",
    "mediatizatelor": "mediatizat",
    "mediatizați": "mediatizat",
    "mediatizații": "mediatizat",
    "mediatizaților": "mediatizat",
    "mediatizato": "mediatizat",
    "mediatizatul": "mediatizat",
    "mediatizatule": "mediatizat",
    "mediatizatului": "mediatizat",
    "medici": "medic",
    "medicii": "medic",
    "medicilor": "medic",
    "medicul": "medic",
    "medicului": "medic",
    "medicala": "medical",
    "medicală": "medical",
    "medicale": "medical",
    "medicalei": "medical",
    "medicalele": "medical",
    "medicalelor": "medical",
    "medicali": "medical",
    "medicalii": "medical",
    "medicalilor": "medical",
    "medicalul": "medical",
    "medicalului": "medical",
    "medicamente": "medicament",
    "medicamentele": "medicament",
    "medicamentelor": "medicament",
    "medicamentul": "medicament",
    "medicamentului": "medicament",
    "medicamentoasa": "medicamentos",
    "medicamentoasă": "medicamentos",
    "medicamentoase": "medicamentos",
    "medicamentoasei": "medicamentos",
    "medicamentoasele": "medicamentos",
    "medicamentoaselor": "medicamentos",
    "medicamentoși": "medicamentos",
    "medicamentoșii": "medicamentos",
    "medicamentoșilor": "medicamentos",
    "medicamentosul": "medicamentos",
    "medicamentosului": "medicamentos",
    "medicația": "medicație",
    "medicației": "medicație",
    "medicații": "medicație",
    "medicațiile": "medicație",
    "medicațiilor": "medicație",
    "med.": "medicină",
    "medicina": "medicină",
    "medicine": "medicină",
    "medicinei": "medicină",
    "medicinele": "medicină",
    "medicinelor": "medicină",
    "medicinii": "medicină",
    "medicinala": "medicinal",
    "medicinală": "medicinal",
    "medicinale": "medicinal",
    "medicinalei": "medicinal",
    "medicinalele": "medicinal",
    "medicinalelor": "medicinal",
    "medicinali": "medicinal",
    "medicinalii": "medicinal",
    "medicinalilor": "medicinal",
    "medicinalul": "medicinal",
    "medicinalului": "medicinal",
    "mediciniști": "medicinist",
    "mediciniștii": "medicinist",
    "mediciniștilor": "medicinist",
    "medicinistul": "medicinist",
    "medicinistule": "medicinist",
    "medicinistului": "medicinist",
    "medicinista": "medicinistă",
    "mediciniste": "medicinistă",
    "medicinistei": "medicinistă",
    "medicinistele": "medicinistă",
    "medicinistelor": "medicinistă",
    "medicinisto": "medicinistă",
    "medico-farmaceutică": "medico-farmaceutic",
    "medico-farmaceutice": "medico-farmaceutic",
    "medico-farmaceutici": "medico-farmaceutic",
    "medico-legală": "medico-legal",
    "medico-legale": "medico-legal",
    "medico-legali": "medico-legal",
    "medico-militară": "medico-militar",
    "medico-militare": "medico-militar",
    "medico-militari": "medico-militar",
    "medico-sanitară": "medico-sanitar",
    "medico-sanitare": "medico-sanitar",
    "medico-sanitari": "medico-sanitar",
    "medico-veterinară": "medico-veterinar",
    "medico-veterinare": "medico-veterinar",
    "medico-veterinari": "medico-veterinar",
    "media": "medie",
    "mediei": "medie",
    "medii": "medie",
    "mediile": "medie",
    "mediilor": "medie",
    "medievala": "medieval",
    "medievală": "medieval",
    "medievale": "medieval",
    "medievalei": "medieval",
    "medievalele": "medieval",
    "medievalelor": "medieval",
    "medievali": "medieval",
    "medievalii": "medieval",
    "medievalilor": "medieval",
    "medievalul": "medieval",
    "medievalului": "medieval",
    "medievalistica": "medievalistică",
    "medievalistice": "medievalistică",
    "medievalisticei": "medievalistică",
    "medievalisticele": "medievalistică",
    "medievalisticelor": "medievalistică",
    "medievalistico": "medievalistică",
    "mediocritatea": "mediocritate",
    "mediocrități": "mediocritate",
    "mediocrității": "mediocritate",
    "mediocritățile": "mediocritate",
    "mediocrităților": "mediocritate",
    "mediocra": "mediocru",
    "mediocră": "mediocru",
    "mediocre": "mediocru",
    "mediocrei": "mediocru",
    "mediocrele": "mediocru",
    "mediocrelor": "mediocru",
    "mediocri": "mediocru",
    "mediocrii": "mediocru",
    "mediocrilor": "mediocru",
    "mediocrul": "mediocru",
    "mediocrului": "mediocru",
    "medită": "medita",
    "meditai": "medita",
    "meditam": "medita",
    "medităm": "medita",
    "meditând": "medita",
    "meditându": "medita",
    "meditară": "medita",
    "meditarăm": "medita",
    "meditarăți": "medita",
    "meditase": "medita",
    "meditasem": "medita",
    "meditaseră": "medita",
    "meditaserăm": "medita",
    "meditaserăți": "medita",
    "meditaseși": "medita",
    "meditași": "medita",
    "meditat": "medita",
    "meditați": "medita",
    "meditatu": "medita",
    "meditau": "medita",
    "meditează": "medita",
    "meditez": "medita",
    "mediteze": "medita",
    "meditezi": "medita",
    "nemaimeditând": "medita",
    "nemaimeditându": "medita",
    "nemeditând": "medita",
    "nemeditându": "medita",
    "meditată": "meditat",
    "meditate": "meditat",
    "meditați": "meditat",
    "meditația": "meditație",
    "meditației": "meditație",
    "meditații": "meditație",
    "meditațiile": "meditație",
    "meditațiilor": "meditație",
    "meditativa": "meditativ",
    "meditativă": "meditativ",
    "meditative": "meditativ",
    "meditativei": "meditativ",
    "meditativele": "meditativ",
    "meditativelor": "meditativ",
    "meditativi": "meditativ",
    "meditativii": "meditativ",
    "meditativilor": "meditativ",
    "meditativul": "meditativ",
    "meditativului": "meditativ",
    "Mediterane": "Mediterana",
    "Mediteranei": "Mediterana",
    "mediteraneana": "mediteranean",
    "mediteraneană": "mediteranean",
    "mediteraneanul": "mediteranean",
    "mediteraneanului": "mediteranean",
    "mediteraneene": "mediteranean",
    "mediteraneenei": "mediteranean",
    "mediteraneenele": "mediteranean",
    "mediteraneenelor": "mediteranean",
    "mediteraneeni": "mediteranean",
    "mediteraneenii": "mediteranean",
    "mediteraneenilor": "mediteranean",
    "media": "mediu",
    "medie": "mediu",
    "mediei": "mediu",
    "medii": "mediu",
    "mediii": "mediu",
    "mediile": "mediu",
    "mediilor": "mediu",
    "mediul": "mediu",
    "mediului": "mediu",
    "medulara": "medular",
    "medulară": "medular",
    "medulare": "medular",
    "medularei": "medular",
    "medularele": "medular",
    "medularelor": "medular",
    "medulari": "medular",
    "medularii": "medular",
    "medularilor": "medular",
    "medularul": "medular",
    "medularului": "medular",
    "meduza": "meduză",
    "meduze": "meduză",
    "meduzei": "meduză",
    "meduzele": "meduză",
    "meduzelor": "meduză",
    "mefistofelica": "mefistofelic",
    "mefistofelică": "mefistofelic",
    "mefistofelice": "mefistofelic",
    "mefistofelicei": "mefistofelic",
    "mefistofelicele": "mefistofelic",
    "mefistofelicelor": "mefistofelic",
    "mefistofelici": "mefistofelic",
    "mefistofelicii": "mefistofelic",
    "mefistofelicilor": "mefistofelic",
    "mefistofelicul": "mefistofelic",
    "mefistofelicului": "mefistofelic",
    "megafoane": "megafon",
    "megafoanele": "megafon",
    "megafoanelor": "megafon",
    "megafonul": "megafon",
    "megafonului": "megafon",
    "megaliți": "megalit",
    "megaliții": "megalit",
    "megaliților": "megalit",
    "megalitul": "megalit",
    "megalitului": "megalit",
    "megalitica": "megalitic",
    "megalitică": "megalitic",
    "megalitice": "megalitic",
    "megaliticei": "megalitic",
    "megaliticele": "megalitic",
    "megaliticelor": "megalitic",
    "megalitici": "megalitic",
    "megaliticii": "megalitic",
    "megaliticilor": "megalitic",
    "megaliticul": "megalitic",
    "megaliticului": "megalitic",
    "megalomana": "megaloman",
    "megalomană": "megaloman",
    "megalomane": "megaloman",
    "megalomanei": "megaloman",
    "megalomanele": "megaloman",
    "megalomanelor": "megaloman",
    "megalomani": "megaloman",
    "megalomanii": "megaloman",
    "megalomanilor": "megaloman",
    "megalomanul": "megaloman",
    "megalomanului": "megaloman",
    "megalomana": "megalomană",
    "megalomane": "megalomană",
    "megalomanei": "megalomană",
    "megalomanele": "megalomană",
    "megalomanelor": "megalomană",
    "megalomania": "megalomanie",
    "megalomaniei": "megalomanie",
    "megalomanii": "megalomanie",
    "megalomaniile": "megalomanie",
    "megalomaniilor": "megalomanie",
    "megaterii": "megateriu",
    "megateriii": "megateriu",
    "megateriilor": "megateriu",
    "megateriul": "megateriu",
    "megateriului": "megateriu",
    "megatona": "megatonă",
    "megatone": "megatonă",
    "megatonei": "megatonă",
    "megatonele": "megatonă",
    "megatonelor": "megatonă",
    "mt.": "megatonă",
    "megawați": "megawatt",
    "megawații": "megawatt",
    "megawaților": "megawatt",
    "megawattul": "megawatt",
    "megawattului": "megawatt",
    "mw.": "megawatt",
    "megieșa": "megieș",
    "megieșă": "megieș",
    "megieșe": "megieș",
    "megieșei": "megieș",
    "megieșele": "megieș",
    "megieșelor": "megieș",
    "megieși": "megieș",
    "megieșii": "megieș",
    "megieșilor": "megieș",
    "megieșul": "megieș",
    "megieșului": "megieș",
    "megieșa": "megieșă",
    "megieșe": "megieșă",
    "megieșei": "megieșă",
    "megieșele": "megieșă",
    "megieșelor": "megieșă",
    "Mehedințiul": "Mehedinți",
    "Mehedințiului": "Mehedinți",
    "mehenghe": "mehenghi",
    "mehenghea": "mehenghi",
    "mehenghei": "mehenghi",
    "mehenghele": "mehenghi",
    "mehenghelor": "mehenghi",
    "mehenghii": "mehenghi",
    "mehenghilor": "mehenghi",
    "mehenghiul": "mehenghi",
    "mehenghiului": "mehenghi",
    "meiul": "mei",
    "meiului": "mei",
    "meioza": "meioză",
    "meioze": "meioză",
    "meiozei": "meioză",
    "meișori": "meișor",
    "meișorii": "meișor",
    "meișorilor": "meișor",
    "meișorul": "meișor",
    "meișorului": "meișor",
    "melamina": "melamină",
    "melamine": "melamină",
    "melaminei": "melamină",
    "melana": "melană",
    "melane": "melană",
    "melanei": "melană",
    "melancolica": "melancolic",
    "melancolică": "melancolic",
    "melancolice": "melancolic",
    "melancolicei": "melancolic",
    "melancolicele": "melancolic",
    "melancolicelor": "melancolic",
    "melancolici": "melancolic",
    "melancolicii": "melancolic",
    "melancolicilor": "melancolic",
    "melancolicul": "melancolic",
    "melancolicului": "melancolic",
    "melancolia": "melancolie",
    "melancoliei": "melancolie",
    "melancolii": "melancolie",
    "melancoliile": "melancolie",
    "melancoliilor": "melancolie",
    "Melaniei": "Melania",
    "melanina": "melanină",
    "melanine": "melanină",
    "melaninei": "melanină",
    "melanjul": "melanj",
    "melanjului": "melanj",
    "melanjuri": "melanj",
    "melanjurile": "melanj",
    "melanjurilor": "melanj",
    "melasa": "melasă",
    "melase": "melasă",
    "melasei": "melasă",
    "melci": "melc",
    "melcii": "melc",
    "melcilor": "melc",
    "melcu'": "melc",
    "melcul": "melc",
    "melcului": "melc",
    "meleagul": "meleag",
    "meleagului": "meleag",
    "meleaguri": "meleag",
    "meleagurile": "meleag",
    "meleagurilor": "meleag",
    "melifera": "melifer",
    "meliferă": "melifer",
    "melifere": "melifer",
    "meliferei": "melifer",
    "meliferele": "melifer",
    "meliferelor": "melifer",
    "meliferi": "melifer",
    "meliferii": "melifer",
    "meliferilor": "melifer",
    "meliferul": "melifer",
    "meliferului": "melifer",
    "meliț": "melița",
    "meliță": "melița",
    "melițai": "melița",
    "melițam": "melița",
    "melițăm": "melița",
    "melițând": "melița",
    "melițându": "melița",
    "melițară": "melița",
    "melițarăm": "melița",
    "melițarăți": "melița",
    "melițase": "melița",
    "melițasem": "melița",
    "melițaseră": "melița",
    "melițaserăm": "melița",
    "melițaserăți": "melița",
    "melițaseși": "melița",
    "melițași": "melița",
    "melițat": "melița",
    "melițați": "melița",
    "melițatu": "melița",
    "melițau": "melița",
    "melițe": "melița",
    "meliți": "melița",
    "nemaimelițând": "melița",
    "nemaimelițându": "melița",
    "nemelițând": "melița",
    "nemelițându": "melița",
    "melița": "meliță",
    "melițe": "meliță",
    "meliței": "meliță",
    "melițele": "meliță",
    "melițelor": "meliță",
    "melițată": "melițat",
    "melițate": "melițat",
    "melițați": "melițat",
    "melodica": "melodic",
    "melodică": "melodic",
    "melodice": "melodic",
    "melodicei": "melodic",
    "melodicele": "melodic",
    "melodicelor": "melodic",
    "melodici": "melodic",
    "melodicii": "melodic",
    "melodicilor": "melodic",
    "melodicul": "melodic",
    "melodicului": "melodic",
    "melodica": "melodică",
    "melodice": "melodică",
    "melodicei": "melodică",
    "melodicele": "melodică",
    "melodicelor": "melodică",
    "melodia": "melodie",
    "melodiei": "melodie",
    "melodii": "melodie",
    "melodiile": "melodie",
    "melodiilor": "melodie",
    "melodioasa": "melodios",
    "melodioasă": "melodios",
    "melodioase": "melodios",
    "melodioasei": "melodios",
    "melodioasele": "melodios",
    "melodioaselor": "melodios",
    "melodioși": "melodios",
    "melodioșii": "melodios",
    "melodioșilor": "melodios",
    "melodiosul": "melodios",
    "melodiosului": "melodios",
    "melodrama": "melodramă",
    "melodrame": "melodramă",
    "melodramei": "melodramă",
    "melodramele": "melodramă",
    "melodramelor": "melodramă",
    "melodramatica": "melodramatic",
    "melodramatică": "melodramatic",
    "melodramatice": "melodramatic",
    "melodramaticei": "melodramatic",
    "melodramaticele": "melodramatic",
    "melodramaticelor": "melodramatic",
    "melodramatici": "melodramatic",
    "melodramaticii": "melodramatic",
    "melodramaticilor": "melodramatic",
    "melodramaticul": "melodramatic",
    "melodramaticului": "melodramatic",
    "melomani": "meloman",
    "melomanii": "meloman",
    "melomanilor": "meloman",
    "melomanul": "meloman",
    "melomanului": "meloman",
    "melomana": "melomană",
    "melomane": "melomană",
    "melomanei": "melomană",
    "melomanele": "melomană",
    "melomanelor": "melomană",
    "melopeea": "melopee",
    "melopei": "melopee",
    "melopeii": "melopee",
    "melopeile": "melopee",
    "melopeilor": "melopee",
    "melosul": "melos",
    "melosului": "melos",
    "membra": "membră",
    "membre": "membră",
    "membrei": "membră",
    "membrele": "membră",
    "membrelor": "membră",
    "membrana": "membrană",
    "membrane": "membrană",
    "membranei": "membrană",
    "membranele": "membrană",
    "membranelor": "membrană",
    "membranoasa": "membranos",
    "membranoasă": "membranos",
    "membranoase": "membranos",
    "membranoasei": "membranos",
    "membranoasele": "membranos",
    "membranoaselor": "membranos",
    "membranoși": "membranos",
    "membranoșii": "membranos",
    "membranoșilor": "membranos",
    "membranosul": "membranos",
    "membranosului": "membranos",
    "membri": "membru",
    "membrii": "membru",
    "membrilor": "membru",
    "membrul": "membru",
    "membrului": "membru",
    "mementoul": "memento",
    "mementoului": "memento",
    "memoră": "memora",
    "memorai": "memora",
    "memoram": "memora",
    "memorăm": "memora",
    "memorând": "memora",
    "memorându": "memora",
    "memorară": "memora",
    "memorarăm": "memora",
    "memorarăți": "memora",
    "memorase": "memora",
    "memorasem": "memora",
    "memoraseră": "memora",
    "memoraserăm": "memora",
    "memoraserăți": "memora",
    "memoraseși": "memora",
    "memorași": "memora",
    "memorat": "memora",
    "memorați": "memora",
    "memoratu": "memora",
    "memorau": "memora",
    "memorează": "memora",
    "memorez": "memora",
    "memoreze": "memora",
    "memorezi": "memora",
    "nemaimemorând": "memora",
    "nemaimemorându": "memora",
    "nememorând": "memora",
    "nememorându": "memora",
    "memorabila": "memorabil",
    "memorabilă": "memorabil",
    "memorabile": "memorabil",
    "memorabilei": "memorabil",
    "memorabilele": "memorabil",
    "memorabilelor": "memorabil",
    "memorabili": "memorabil",
    "memorabilii": "memorabil",
    "memorabililor": "memorabil",
    "memorabilul": "memorabil",
    "memorabilului": "memorabil",
    "mem.": "memorandum",
    "memorandumul": "memorandum",
    "memorandumului": "memorandum",
    "memorandumuri": "memorandum",
    "memorandumurile": "memorandum",
    "memorandumurilor": "memorandum",
    "memorarea": "memorare",
    "memorareo": "memorare",
    "memorări": "memorare",
    "memorării": "memorare",
    "memorările": "memorare",
    "memorărilor": "memorare",
    "memorată": "memorat",
    "memorate": "memorat",
    "memorați": "memorat",
    "memoriale": "memorial",
    "memorialele": "memorial",
    "memorialelor": "memorial",
    "memorialul": "memorial",
    "memorialului": "memorial",
    "memorialiști": "memorialist",
    "memorialiștii": "memorialist",
    "memorialiștilor": "memorialist",
    "memorialistul": "memorialist",
    "memorialistule": "memorialist",
    "memorialistului": "memorialist",
    "memorialista": "memorialistă",
    "memorialiste": "memorialistă",
    "memorialistei": "memorialistă",
    "memorialistele": "memorialistă",
    "memorialistelor": "memorialistă",
    "memorialisto": "memorialistă",
    "memorialistica": "memorialistic",
    "memorialistică": "memorialistic",
    "memorialistice": "memorialistic",
    "memorialisticei": "memorialistic",
    "memorialisticele": "memorialistic",
    "memorialisticelor": "memorialistic",
    "memorialistici": "memorialistic",
    "memorialisticii": "memorialistic",
    "memorialisticilor": "memorialistic",
    "memorialistico": "memorialistic",
    "memorialisticul": "memorialistic",
    "memorialisticule": "memorialistic",
    "memorialisticului": "memorialistic",
    "memorialistica": "memorialistică",
    "memorialisticele": "memorialistică",
    "memorialistici": "memorialistică",
    "memorialisticii": "memorialistică",
    "memorialisticilor": "memorialistică",
    "memoria": "memorie",
    "memoriei": "memorie",
    "memorii": "memorie",
    "memoriile": "memorie",
    "memoriilor": "memorie",
    "memoriul": "memoriu",
    "memoriului": "memoriu",
    "memoriză": "memoriza",
    "memorizai": "memoriza",
    "memorizam": "memoriza",
    "memorizăm": "memoriza",
    "memorizând": "memoriza",
    "memorizându": "memoriza",
    "memorizară": "memoriza",
    "memorizarăm": "memoriza",
    "memorizarăți": "memoriza",
    "memorizase": "memoriza",
    "memorizasem": "memoriza",
    "memorizaseră": "memoriza",
    "memorizaserăm": "memoriza",
    "memorizaserăți": "memoriza",
    "memorizaseși": "memoriza",
    "memorizași": "memoriza",
    "memorizat": "memoriza",
    "memorizați": "memoriza",
    "memorizatu": "memoriza",
    "memorizau": "memoriza",
    "memorizează": "memoriza",
    "memorizez": "memoriza",
    "memorizeze": "memoriza",
    "memorizezi": "memoriza",
    "nemaimemorizând": "memoriza",
    "nemaimemorizându": "memoriza",
    "nememorizând": "memoriza",
    "nememorizându": "memoriza",
    "memorizată": "memorizat",
    "memorizate": "memorizat",
    "memorizați": "memorizat",
    "menajul": "menaj",
    "menajului": "menaj",
    "menajuri": "menaj",
    "menajurile": "menaj",
    "menajurilor": "menaj",
    "menajă": "menaja",
    "menajai": "menaja",
    "menajam": "menaja",
    "menajăm": "menaja",
    "menajând": "menaja",
    "menajându": "menaja",
    "menajară": "menaja",
    "menajarăm": "menaja",
    "menajarăți": "menaja",
    "menajase": "menaja",
    "menajasem": "menaja",
    "menajaseră": "menaja",
    "menajaserăm": "menaja",
    "menajaserăți": "menaja",
    "menajaseși": "menaja",
    "menajași": "menaja",
    "menajat": "menaja",
    "menajați": "menaja",
    "menajatu": "menaja",
    "menajau": "menaja",
    "menajează": "menaja",
    "menajez": "menaja",
    "menajeze": "menaja",
    "menajezi": "menaja",
    "nemaimenajând": "menaja",
    "nemaimenajându": "menaja",
    "nemenajând": "menaja",
    "nemenajându": "menaja",
    "menajamente": "menajament",
    "menajamentele": "menajament",
    "menajamentelor": "menajament",
    "menajamentul": "menajament",
    "menajamentului": "menajament",
    "menajată": "menajat",
    "menajate": "menajat",
    "menajați": "menajat",
    "menajera": "menajer",
    "menajeră": "menajer",
    "menajere": "menajer",
    "menajerei": "menajer",
    "menajerele": "menajer",
    "menajerelor": "menajer",
    "menajeri": "menajer",
    "menajerii": "menajer",
    "menajerilor": "menajer",
    "menajerul": "menajer",
    "menajerului": "menajer",
    "menajera": "menajeră",
    "menajere": "menajeră",
    "menajerei": "menajeră",
    "menajerele": "menajeră",
    "menajerelor": "menajeră",
    "menajeria": "menajerie",
    "menajeriei": "menajerie",
    "menajerii": "menajerie",
    "menajeriile": "menajerie",
    "menajeriilor": "menajerie",
    "mendrele": "mendre",
    "mendrelor": "mendre",
    "menestreli": "menestrel",
    "menestrelii": "menestrel",
    "menestrelilor": "menestrel",
    "menestrelul": "menestrel",
    "menestrelului": "menestrel",
    "menghina": "menghină",
    "menghine": "menghină",
    "menghinei": "menghină",
    "menghinele": "menghină",
    "menghinelor": "menghină",
    "menea": "meni",
    "meneai": "meni",
    "meneam": "meni",
    "menească": "meni",
    "meneați": "meni",
    "meneau": "meni",
    "menesc": "meni",
    "menește": "meni",
    "menești": "meni",
    "menii": "meni",
    "menim": "meni",
    "menind": "meni",
    "menindu": "meni",
    "meniră": "meni",
    "menirăm": "meni",
    "menirăți": "meni",
    "menise": "meni",
    "menisem": "meni",
    "meniseră": "meni",
    "meniserăm": "meni",
    "meniserăți": "meni",
    "meniseși": "meni",
    "meniși": "meni",
    "menit": "meni",
    "meniți": "meni",
    "menitu": "meni",
    "nemaimenind": "meni",
    "nemaimenindu": "meni",
    "nemenind": "meni",
    "nemenindu": "meni",
    "meningele": "meninge",
    "meningelor": "meninge",
    "meningelui": "meninge",
    "meningita": "meningită",
    "meningite": "meningită",
    "meningitei": "meningită",
    "meningitele": "meningită",
    "meningitelor": "meningită",
    "menirea": "menire",
    "menireo": "menire",
    "meniri": "menire",
    "menirii": "menire",
    "menirile": "menire",
    "menirilor": "menire",
    "meniscul": "menisc",
    "meniscului": "menisc",
    "meniscuri": "menisc",
    "meniscurile": "menisc",
    "meniscurilor": "menisc",
    "menită": "menit",
    "menite": "menit",
    "meniți": "menit",
    "meniul": "meniu",
    "meniului": "meniu",
    "meniuri": "meniu",
    "meniurile": "meniu",
    "meniurilor": "meniu",
    "menopauza": "menopauză",
    "menopauze": "menopauză",
    "menopauzei": "menopauză",
    "menstruala": "menstrual",
    "menstruală": "menstrual",
    "menstruale": "menstrual",
    "menstrualei": "menstrual",
    "menstrualele": "menstrual",
    "menstrualelor": "menstrual",
    "menstruali": "menstrual",
    "menstrualii": "menstrual",
    "menstrualilor": "menstrual",
    "menstrualul": "menstrual",
    "menstrualului": "menstrual",
    "menstruația": "menstruație",
    "menstruației": "menstruație",
    "menstruații": "menstruație",
    "mensuala": "mensual",
    "mensuală": "mensual",
    "mensuale": "mensual",
    "mensualei": "mensual",
    "mensualele": "mensual",
    "mensualelor": "mensual",
    "mensuali": "mensual",
    "mensualii": "mensual",
    "mensualilor": "mensual",
    "mensualul": "mensual",
    "mensualului": "mensual",
    "menta": "mentă",
    "mente": "mentă",
    "mentei": "mentă",
    "mentala": "mental",
    "mentală": "mental",
    "mentale": "mental",
    "mentalei": "mental",
    "mentalele": "mental",
    "mentalelor": "mental",
    "mentali": "mental",
    "mentalii": "mental",
    "mentalilor": "mental",
    "mentalul": "mental",
    "mentalului": "mental",
    "mentalitatea": "mentalitate",
    "mentalități": "mentalitate",
    "mentalității": "mentalitate",
    "mentalitățile": "mentalitate",
    "mentalităților": "mentalitate",
    "menții": "menține",
    "mențin": "menține",
    "mențină": "menține",
    "menținând": "menține",
    "menținându": "menține",
    "menținea": "menține",
    "mențineai": "menține",
    "mențineam": "menține",
    "mențineați": "menține",
    "mențineau": "menține",
    "menținem": "menține",
    "mențineți": "menține",
    "menținu": "menține",
    "menținui": "menține",
    "menținură": "menține",
    "menținurăm": "menține",
    "menținurăți": "menține",
    "menținuse": "menține",
    "menținusem": "menține",
    "menținuseră": "menține",
    "menținuserăm": "menține",
    "menținuserăți": "menține",
    "menținuseși": "menține",
    "menținuși": "menține",
    "menținut": "menține",
    "menținutu": "menține",
    "menținerea": "menținere",
    "mențineri": "menținere",
    "menținerii": "menținere",
    "menținerile": "menținere",
    "menținerilor": "menținere",
    "menținută": "menținut",
    "menținute": "menținut",
    "menținuți": "menținut",
    "menționă": "menționa",
    "menționai": "menționa",
    "menționam": "menționa",
    "menționăm": "menționa",
    "menționând": "menționa",
    "menționându": "menționa",
    "menționară": "menționa",
    "menționarăm": "menționa",
    "menționarăți": "menționa",
    "menționase": "menționa",
    "menționasem": "menționa",
    "menționaseră": "menționa",
    "menționaserăm": "menționa",
    "menționaserăți": "menționa",
    "menționaseși": "menționa",
    "menționași": "menționa",
    "menționat": "menționa",
    "menționați": "menționa",
    "menționatu": "menționa",
    "menționau": "menționa",
    "menționează": "menționa",
    "menționez": "menționa",
    "menționeze": "menționa",
    "menționezi": "menționa",
    "nemaimenționând": "menționa",
    "nemaimenționându": "menționa",
    "nemenționând": "menționa",
    "nemenționându": "menționa",
    "menționarea": "menționare",
    "menționări": "menționare",
    "menționării": "menționare",
    "menționările": "menționare",
    "menționărilor": "menționare",
    "menționata": "menționat",
    "menționată": "menționat",
    "menționate": "menționat",
    "menționatei": "menționat",
    "menționatele": "menționat",
    "menționatelor": "menționat",
    "menționați": "menționat",
    "menționații": "menționat",
    "menționaților": "menționat",
    "menționato": "menționat",
    "menționatul": "menționat",
    "menționatule": "menționat",
    "menționatului": "menționat",
    "mențiunea": "mențiune",
    "mențiuni": "mențiune",
    "mențiunii": "mențiune",
    "mențiunile": "mențiune",
    "mențiunilor": "mențiune",
    "mentolul": "mentol",
    "mentolului": "mentol",
    "mentolata": "mentolat",
    "mentolată": "mentolat",
    "mentolate": "mentolat",
    "mentolatei": "mentolat",
    "mentolatele": "mentolat",
    "mentolatelor": "mentolat",
    "mentolați": "mentolat",
    "mentolații": "mentolat",
    "mentolaților": "mentolat",
    "mentolatul": "mentolat",
    "mentolatului": "mentolat",
    "mentori": "mentor",
    "mentorii": "mentor",
    "mentorilor": "mentor",
    "mentorul": "mentor",
    "mentorului": "mentor",
    "menuete": "menuet",
    "menuetele": "menuet",
    "menuetelor": "menuet",
    "menuetul": "menuet",
    "menuetului": "menuet",
    "mercantila": "mercantil",
    "mercantilă": "mercantil",
    "mercantile": "mercantil",
    "mercantilei": "mercantil",
    "mercantilele": "mercantil",
    "mercantilelor": "mercantil",
    "mercantili": "mercantil",
    "mercantilii": "mercantil",
    "mercantililor": "mercantil",
    "mercantilul": "mercantil",
    "mercantilului": "mercantil",
    "mercantilismul": "mercantilism",
    "mercantilismului": "mercantilism",
    "mercaptani": "mercaptan",
    "mercaptanii": "mercaptan",
    "mercaptanilor": "mercaptan",
    "mercaptanul": "mercaptan",
    "mercaptanului": "mercaptan",
    "mercenara": "mercenar",
    "mercenară": "mercenar",
    "mercenare": "mercenar",
    "mercenarei": "mercenar",
    "mercenarele": "mercenar",
    "mercenarelor": "mercenar",
    "mercenari": "mercenar",
    "mercenarii": "mercenar",
    "mercenarilor": "mercenar",
    "mercenarul": "mercenar",
    "mercenarului": "mercenar",
    "merceologi": "merceolog",
    "merceologii": "merceolog",
    "merceologilor": "merceolog",
    "merceologul": "merceolog",
    "merceologului": "merceolog",
    "merceologa": "merceologă",
    "merceologe": "merceologă",
    "merceologei": "merceologă",
    "merceologele": "merceologă",
    "merceologelor": "merceologă",
    "merceologia": "merceologie",
    "merceologiei": "merceologie",
    "merceologii": "merceologie",
    "merceologiile": "merceologie",
    "merceologiilor": "merceologie",
    "merceria": "mercerie",
    "merceriei": "mercerie",
    "mercerii": "mercerie",
    "merceriile": "mercerie",
    "merceriilor": "mercerie",
    "merceriză": "merceriza",
    "mercerizai": "merceriza",
    "mercerizam": "merceriza",
    "mercerizăm": "merceriza",
    "mercerizând": "merceriza",
    "mercerizându": "merceriza",
    "mercerizară": "merceriza",
    "mercerizarăm": "merceriza",
    "mercerizarăți": "merceriza",
    "mercerizase": "merceriza",
    "mercerizasem": "merceriza",
    "mercerizaseră": "merceriza",
    "mercerizaserăm": "merceriza",
    "mercerizaserăți": "merceriza",
    "mercerizaseși": "merceriza",
    "mercerizași": "merceriza",
    "mercerizat": "merceriza",
    "mercerizați": "merceriza",
    "mercerizatu": "merceriza",
    "mercerizau": "merceriza",
    "mercerizează": "merceriza",
    "mercerizez": "merceriza",
    "mercerizeze": "merceriza",
    "mercerizezi": "merceriza",
    "nemaimercerizând": "merceriza",
    "nemaimercerizându": "merceriza",
    "nemercerizând": "merceriza",
    "nemercerizându": "merceriza",
    "mercerizată": "mercerizat",
    "mercerizate": "mercerizat",
    "mercerizați": "mercerizat",
    "Hg": "mercur",
    "mercurul": "mercur",
    "mercurului": "mercur",
    "mercuriala": "mercurial",
    "mercurială": "mercurial",
    "mercuriale": "mercurial",
    "mercurialei": "mercurial",
    "mercurialele": "mercurial",
    "mercurialelor": "mercurial",
    "mercuriali": "mercurial",
    "mercurialii": "mercurial",
    "mercurialilor": "mercurial",
    "mercurialul": "mercurial",
    "mercurialului": "mercurial",
    "meargă": "merge",
    "merg": "merge",
    "mergând": "merge",
    "mergându": "merge",
    "mergea": "merge",
    "mergeai": "merge",
    "mergeam": "merge",
    "mergeați": "merge",
    "mergeau": "merge",
    "mergem": "merge",
    "mergeți": "merge",
    "mergi": "merge",
    "mers": "merge",
    "merse": "merge",
    "mersei": "merge",
    "merseră": "merge",
    "merserăm": "merge",
    "merserăți": "merge",
    "mersese": "merge",
    "mersesem": "merge",
    "merseseră": "merge",
    "merseserăm": "merge",
    "merseserăți": "merge",
    "merseseși": "merge",
    "merseși": "merge",
    "nemaimergând": "merge",
    "nemaimergându": "merge",
    "nemergând": "merge",
    "nemergându": "merge",
    "M.": "meridian",
    "meridiane": "meridian",
    "meridianele": "meridian",
    "meridianelor": "meridian",
    "meridianul": "meridian",
    "meridianului": "meridian",
    "meridionala": "meridional",
    "meridională": "meridional",
    "meridionale": "meridional",
    "meridionalei": "meridional",
    "meridionalele": "meridional",
    "meridionalelor": "meridional",
    "meridionali": "meridional",
    "meridionalii": "meridional",
    "meridionalilor": "meridional",
    "meridionalul": "meridional",
    "meridionalului": "meridional",
    "meridionala": "meridională",
    "meridionale": "meridională",
    "meridionalei": "meridională",
    "meridionalele": "meridională",
    "meridionalelor": "meridională",
    "merișoare": "merișor",
    "merișoarele": "merișor",
    "merișoarelor": "merișor",
    "merișori": "merișor",
    "merișorii": "merișor",
    "merișorilor": "merișor",
    "merișorul": "merișor",
    "merișorului": "merișor",
    "merite": "merit",
    "meritele": "merit",
    "meritelor": "merit",
    "meritul": "merit",
    "meritului": "merit",
    "merit": "merita",
    "merită": "merita",
    "meritai": "merita",
    "meritam": "merita",
    "merităm": "merita",
    "meritând": "merita",
    "meritându": "merita",
    "meritară": "merita",
    "meritarăm": "merita",
    "meritarăți": "merita",
    "meritase": "merita",
    "meritasem": "merita",
    "meritaseră": "merita",
    "meritaserăm": "merita",
    "meritaserăți": "merita",
    "meritaseși": "merita",
    "meritași": "merita",
    "meritat": "merita",
    "meritați": "merita",
    "meritatu": "merita",
    "meritau": "merita",
    "merite": "merita",
    "meriți": "merita",
    "nemaimeritând": "merita",
    "nemaimeritându": "merita",
    "nemeritând": "merita",
    "nemeritându": "merita",
    "meritată": "meritat",
    "meritate": "meritat",
    "meritați": "meritat",
    "meritoria": "meritoriu",
    "meritorie": "meritoriu",
    "meritoriei": "meritoriu",
    "meritorii": "meritoriu",
    "meritoriii": "meritoriu",
    "meritoriile": "meritoriu",
    "meritoriilor": "meritoriu",
    "meritoriul": "meritoriu",
    "meritoriului": "meritoriu",
    "merituoasa": "merituos",
    "merituoasă": "merituos",
    "merituoase": "merituos",
    "merituoasei": "merituos",
    "merituoasele": "merituos",
    "merituoaselor": "merituos",
    "merituoși": "merituos",
    "merituoșii": "merituos",
    "merituoșilor": "merituos",
    "merituosul": "merituos",
    "merituosului": "merituos",
    "mersul": "mers",
    "mersului": "mers",
    "mertice": "mertic",
    "merticele": "mertic",
    "merticelor": "mertic",
    "merticul": "mertic",
    "merticului": "mertic",
    "meșa": "meșă",
    "meșe": "meșă",
    "meșei": "meșă",
    "meșele": "meșă",
    "meșelor": "meșă",
    "mesageri": "mesager",
    "mesagerii": "mesager",
    "mesagerilor": "mesager",
    "mesagerul": "mesager",
    "mesagerului": "mesager",
    "mesagera": "mesageră",
    "mesagere": "mesageră",
    "mesagerei": "mesageră",
    "mesagerele": "mesageră",
    "mesagerelor": "mesageră",
    "mesageria": "mesagerie",
    "mesageriei": "mesagerie",
    "mesagerii": "mesagerie",
    "mesageriile": "mesagerie",
    "mesageriilor": "mesagerie",
    "mesaje": "mesaj",
    "mesajele": "mesaj",
    "mesajelor": "mesaj",
    "mesajul": "mesaj",
    "mesajului": "mesaj",
    "meschina": "meschin",
    "meschină": "meschin",
    "meschine": "meschin",
    "meschinei": "meschin",
    "meschinele": "meschin",
    "meschinelor": "meschin",
    "meschini": "meschin",
    "meschinii": "meschin",
    "meschinilor": "meschin",
    "meschinul": "meschin",
    "meschinului": "meschin",
    "meschinăria": "meschinărie",
    "meschinăriei": "meschinărie",
    "meschinării": "meschinărie",
    "meschinăriile": "meschinărie",
    "meschinăriilor": "meschinărie",
    "meseanul": "mesean",
    "meseanului": "mesean",
    "meseni": "mesean",
    "mesenii": "mesean",
    "mesenilor": "mesean",
    "meseriași": "meseriaș",
    "meseriașii": "meseriaș",
    "meseriașilor": "meseriaș",
    "meseriașul": "meseriaș",
    "meseriașului": "meseriaș",
    "meseria": "meserie",
    "meseriei": "meserie",
    "meserii": "meserie",
    "meseriile": "meserie",
    "meseriilor": "meserie",
    "meșina": "meșină",
    "meșine": "meșină",
    "meșinei": "meșină",
    "meșinele": "meșină",
    "meșinelor": "meșină",
    "mest.": "mesteacăn",
    "mesteacănul": "mesteacăn",
    "mesteacănului": "mesteacăn",
    "mesteceni": "mesteacăn",
    "mestecenii": "mesteacăn",
    "mestecenilor": "mesteacăn",
    "mestec": "mesteca",
    "mestecă": "mesteca",
    "mestecai": "mesteca",
    "mestecam": "mesteca",
    "mestecăm": "mesteca",
    "mestecând": "mesteca",
    "mestecându": "mesteca",
    "mestecară": "mesteca",
    "mestecarăm": "mesteca",
    "mestecarăți": "mesteca",
    "mestecase": "mesteca",
    "mestecasem": "mesteca",
    "mestecaseră": "mesteca",
    "mestecaserăm": "mesteca",
    "mestecaserăți": "mesteca",
    "mestecaseși": "mesteca",
    "mestecași": "mesteca",
    "mestecat": "mesteca",
    "mestecați": "mesteca",
    "mestecatu": "mesteca",
    "mestecau": "mesteca",
    "mestece": "mesteca",
    "mesteci": "mesteca",
    "nemaimestecând": "mesteca",
    "nemaimestecându": "mesteca",
    "nemestecând": "mesteca",
    "nemestecându": "mesteca",
    "mestecănișul": "mestecăniș",
    "mestecănișului": "mestecăniș",
    "mestecănișuri": "mestecăniș",
    "mestecănișurile": "mestecăniș",
    "mestecănișurilor": "mestecăniș",
    "mestecată": "mestecat",
    "mestecate": "mestecat",
    "mestecați": "mestecat",
    "meșteri": "meșter",
    "meșterii": "meșter",
    "meșterilor": "meșter",
    "meșterul": "meșter",
    "meșterului": "meșter",
    "meșterea": "meșteri",
    "meștereai": "meșteri",
    "meșteream": "meșteri",
    "meșterească": "meșteri",
    "meștereați": "meșteri",
    "meștereau": "meșteri",
    "meșteresc": "meșteri",
    "meșterește": "meșteri",
    "meșterești": "meșteri",
    "meșterii": "meșteri",
    "meșterim": "meșteri",
    "meșterind": "meșteri",
    "meșterindu": "meșteri",
    "meșteriră": "meșteri",
    "meșterirăm": "meșteri",
    "meșterirăți": "meșteri",
    "meșterise": "meșteri",
    "meșterisem": "meșteri",
    "meșteriseră": "meșteri",
    "meșteriserăm": "meșteri",
    "meșteriserăți": "meșteri",
    "meșteriseși": "meșteri",
    "meșteriși": "meșteri",
    "meșterit": "meșteri",
    "meșteriți": "meșteri",
    "meșteritu": "meșteri",
    "nemaimeșterind": "meșteri",
    "nemaimeșterindu": "meșteri",
    "nemeșterind": "meșteri",
    "nemeșterindu": "meșteri",
    "meșterită": "meșterit",
    "meșterite": "meșterit",
    "meșteriți": "meșterit",
    "meșteșugul": "meșteșug",
    "meșteșugului": "meșteșug",
    "meșteșuguri": "meșteșug",
    "meșteșugurile": "meșteșug",
    "meșteșugurilor": "meșteșug",
    "meșteșugari": "meșteșugar",
    "meșteșugarii": "meșteșugar",
    "meșteșugarilor": "meșteșugar",
    "meșteșugarul": "meșteșugar",
    "meșteșugarului": "meșteșugar",
    "meșteșugăreasca": "meșteșugăresc",
    "meșteșugărească": "meșteșugăresc",
    "meșteșugărescul": "meșteșugăresc",
    "meșteșugărescului": "meșteșugăresc",
    "meșteșugărești": "meșteșugăresc",
    "meșteșugăreștii": "meșteșugăresc",
    "meșteșugăreștile": "meșteșugăresc",
    "meșteșugăreștilor": "meșteșugăresc",
    "meșteșugea": "meșteșugi",
    "meșteșugeai": "meșteșugi",
    "meșteșugeam": "meșteșugi",
    "meșteșugească": "meșteșugi",
    "meșteșugeați": "meșteșugi",
    "meșteșugeau": "meșteșugi",
    "meșteșugesc": "meșteșugi",
    "meșteșugește": "meșteșugi",
    "meșteșugești": "meșteșugi",
    "meșteșugii": "meșteșugi",
    "meșteșugim": "meșteșugi",
    "meșteșugind": "meșteșugi",
    "meșteșugindu": "meșteșugi",
    "meșteșugiră": "meșteșugi",
    "meșteșugirăm": "meșteșugi",
    "meșteșugirăți": "meșteșugi",
    "meșteșugise": "meșteșugi",
    "meșteșugisem": "meșteșugi",
    "meșteșugiseră": "meșteșugi",
    "meșteșugiserăm": "meșteșugi",
    "meșteșugiserăți": "meșteșugi",
    "meșteșugiseși": "meșteșugi",
    "meșteșugiși": "meșteșugi",
    "meșteșugit": "meșteșugi",
    "meșteșugiți": "meșteșugi",
    "meșteșugitu": "meșteșugi",
    "nemaimeșteșugind": "meșteșugi",
    "nemaimeșteșugindu": "meșteșugi",
    "nemeșteșugind": "meșteșugi",
    "nemeșteșugindu": "meșteșugi",
    "meșteșugită": "meșteșugit",
    "meșteșugite": "meșteșugit",
    "meșteșugiți": "meșteșugit",
    "metabolismul": "metabolism",
    "metabolismului": "metabolism",
    "metacarpul": "metacarp",
    "metacarpului": "metacarp",
    "metacarpuri": "metacarp",
    "metacarpurile": "metacarp",
    "metacarpurilor": "metacarp",
    "metafizica": "metafizic",
    "metafizică": "metafizic",
    "metafizice": "metafizic",
    "metafizicei": "metafizic",
    "metafizicele": "metafizic",
    "metafizicelor": "metafizic",
    "metafizici": "metafizic",
    "metafizicii": "metafizic",
    "metafizicilor": "metafizic",
    "metafizicul": "metafizic",
    "metafizicului": "metafizic",
    "metafizica": "metafizică",
    "metafizice": "metafizică",
    "metafizicei": "metafizică",
    "metafora": "metaforă",
    "metafore": "metaforă",
    "metaforei": "metaforă",
    "metaforele": "metaforă",
    "metaforelor": "metaforă",
    "metaforica": "metaforic",
    "metaforică": "metaforic",
    "metaforice": "metaforic",
    "metaforicei": "metaforic",
    "metaforicele": "metaforic",
    "metaforicelor": "metaforic",
    "metaforici": "metaforic",
    "metaforicii": "metaforic",
    "metaforicilor": "metaforic",
    "metaforicul": "metaforic",
    "metaforicului": "metaforic",
    "metagalaxia": "metagalaxie",
    "metagalaxiei": "metagalaxie",
    "metagalaxii": "metagalaxie",
    "metagalaxiile": "metagalaxie",
    "metagalaxiilor": "metagalaxie",
    "metale": "metal",
    "metalele": "metal",
    "metalelor": "metal",
    "metalul": "metal",
    "metalului": "metal",
    "metalica": "metalic",
    "metalică": "metalic",
    "metalice": "metalic",
    "metalicei": "metalic",
    "metalicele": "metalic",
    "metalicelor": "metalic",
    "metalici": "metalic",
    "metalicii": "metalic",
    "metalicilor": "metalic",
    "metalicul": "metalic",
    "metalicului": "metalic",
    "metalifera": "metalifer",
    "metaliferă": "metalifer",
    "metalifere": "metalifer",
    "metaliferei": "metalifer",
    "metaliferele": "metalifer",
    "metaliferelor": "metalifer",
    "metaliferi": "metalifer",
    "metaliferii": "metalifer",
    "metaliferilor": "metalifer",
    "metaliferul": "metalifer",
    "metaliferului": "metalifer",
    "metaliză": "metaliza",
    "metalizai": "metaliza",
    "metalizam": "metaliza",
    "metalizăm": "metaliza",
    "metalizând": "metaliza",
    "metalizându": "metaliza",
    "metalizară": "metaliza",
    "metalizarăm": "metaliza",
    "metalizarăți": "metaliza",
    "metalizase": "metaliza",
    "metalizasem": "metaliza",
    "metalizaseră": "metaliza",
    "metalizaserăm": "metaliza",
    "metalizaserăți": "metaliza",
    "metalizaseși": "metaliza",
    "metalizași": "metaliza",
    "metalizat": "metaliza",
    "metalizați": "metaliza",
    "metalizatu": "metaliza",
    "metalizau": "metaliza",
    "metalizează": "metaliza",
    "metalizez": "metaliza",
    "metalizeze": "metaliza",
    "metalizezi": "metaliza",
    "nemaimetalizând": "metaliza",
    "nemaimetalizându": "metaliza",
    "nemetalizând": "metaliza",
    "nemetalizându": "metaliza",
    "metalizată": "metalizat",
    "metalizate": "metalizat",
    "metalizați": "metalizat",
    "metalografia": "metalografie",
    "metalografiei": "metalografie",
    "metalografii": "metalografie",
    "metalogravura": "metalogravură",
    "metalogravuri": "metalogravură",
    "metalogravurii": "metalogravură",
    "metalogravurile": "metalogravură",
    "metalogravurilor": "metalogravură",
    "metaloidul": "metaloid",
    "metaloidului": "metaloid",
    "metaloizi": "metaloid",
    "metaloizii": "metaloid",
    "metaloizilor": "metaloid",
    "metalurgica": "metalurgic",
    "metalurgică": "metalurgic",
    "metalurgice": "metalurgic",
    "metalurgicei": "metalurgic",
    "metalurgicele": "metalurgic",
    "metalurgicelor": "metalurgic",
    "metalurgici": "metalurgic",
    "metalurgicii": "metalurgic",
    "metalurgicilor": "metalurgic",
    "metalurgicul": "metalurgic",
    "metalurgicului": "metalurgic",
    "met.": "metalurgie",
    "metalurgia": "metalurgie",
    "metalurgiei": "metalurgie",
    "metalurgii": "metalurgie",
    "metalurgiști": "metalurgist",
    "metalurgiștii": "metalurgist",
    "metalurgiștilor": "metalurgist",
    "metalurgistul": "metalurgist",
    "metalurgistului": "metalurgist",
    "metalurgista": "metalurgistă",
    "metalurgiste": "metalurgistă",
    "metalurgistei": "metalurgistă",
    "metalurgistele": "metalurgistă",
    "metalurgistelor": "metalurgistă",
    "metamorfica": "metamorfic",
    "metamorfică": "metamorfic",
    "metamorfice": "metamorfic",
    "metamorficei": "metamorfic",
    "metamorficele": "metamorfic",
    "metamorficelor": "metamorfic",
    "metamorfici": "metamorfic",
    "metamorficii": "metamorfic",
    "metamorficilor": "metamorfic",
    "metamorficul": "metamorfic",
    "metamorficului": "metamorfic",
    "metamorfismul": "metamorfism",
    "metamorfismului": "metamorfism",
    "metamorfoză": "metamorfoza",
    "metamorfozai": "metamorfoza",
    "metamorfozam": "metamorfoza",
    "metamorfozăm": "metamorfoza",
    "metamorfozând": "metamorfoza",
    "metamorfozându": "metamorfoza",
    "metamorfozară": "metamorfoza",
    "metamorfozarăm": "metamorfoza",
    "metamorfozarăți": "metamorfoza",
    "metamorfozase": "metamorfoza",
    "metamorfozasem": "metamorfoza",
    "metamorfozaseră": "metamorfoza",
    "metamorfozaserăm": "metamorfoza",
    "metamorfozaserăți": "metamorfoza",
    "metamorfozaseși": "metamorfoza",
    "metamorfozași": "metamorfoza",
    "metamorfozat": "metamorfoza",
    "metamorfozați": "metamorfoza",
    "metamorfozatu": "metamorfoza",
    "metamorfozau": "metamorfoza",
    "metamorfozează": "metamorfoza",
    "metamorfozez": "metamorfoza",
    "metamorfozeze": "metamorfoza",
    "metamorfozezi": "metamorfoza",
    "nemaimetamorfozând": "metamorfoza",
    "nemaimetamorfozându": "metamorfoza",
    "nemetamorfozând": "metamorfoza",
    "nemetamorfozându": "metamorfoza",
    "metamorfoza": "metamorfoză",
    "metamorfoze": "metamorfoză",
    "metamorfozei": "metamorfoză",
    "metamorfozele": "metamorfoză",
    "metamorfozelor": "metamorfoză",
    "metamorfozarea": "metamorfozare",
    "metamorfozareo": "metamorfozare",
    "metamorfozări": "metamorfozare",
    "metamorfozării": "metamorfozare",
    "metamorfozările": "metamorfozare",
    "metamorfozărilor": "metamorfozare",
    "metamorfozată": "metamorfozat",
    "metamorfozate": "metamorfozat",
    "metamorfozați": "metamorfozat",
    "metanul": "metan",
    "metanului": "metan",
    "metania": "metanie",
    "metaniei": "metanie",
    "metanii": "metanie",
    "metaniile": "metanie",
    "metaniilor": "metanie",
    "metanio": "metanie",
    "metastaza": "metastază",
    "metastaze": "metastază",
    "metastazei": "metastază",
    "metastazele": "metastază",
    "metastazelor": "metastază",
    "metatarsul": "metatars",
    "metatarsului": "metatars",
    "metatarsuri": "metatars",
    "metatarsurile": "metatars",
    "metatarsurilor": "metatars",
    "metateza": "metateză",
    "metateze": "metateză",
    "metatezei": "metateză",
    "metatezele": "metateză",
    "metatezelor": "metateză",
    "metazoare": "metazoar",
    "metazoarele": "metazoar",
    "metazoarelor": "metazoar",
    "metazoarul": "metazoar",
    "metazoarului": "metazoar",
    "meteahna": "meteahnă",
    "metehne": "meteahnă",
    "metehnei": "meteahnă",
    "metehnele": "meteahnă",
    "metehnelor": "meteahnă",
    "meteci": "metec",
    "metecii": "metec",
    "metecilor": "metec",
    "metecul": "metec",
    "metecului": "metec",
    "metempsihoza": "metempsihoză",
    "metempsihoze": "metempsihoză",
    "metempsihozei": "metempsihoză",
    "meteori": "meteor",
    "meteorii": "meteor",
    "meteorilor": "meteor",
    "meteorul": "meteor",
    "meteorului": "meteor",
    "meteorica": "meteoric",
    "meteorică": "meteoric",
    "meteorice": "meteoric",
    "meteoricei": "meteoric",
    "meteoricele": "meteoric",
    "meteoricelor": "meteoric",
    "meteorici": "meteoric",
    "meteoricii": "meteoric",
    "meteoricilor": "meteoric",
    "meteoricul": "meteoric",
    "meteoricului": "meteoric",
    "meteorismul": "meteorism",
    "meteorismului": "meteorism",
    "meteoriți": "meteorit",
    "meteoriții": "meteorit",
    "meteoriților": "meteorit",
    "meteoritul": "meteorit",
    "meteoritului": "meteorit",
    "meteorografe": "meteorograf",
    "meteorografele": "meteorograf",
    "meteorografelor": "meteorograf",
    "meteorograful": "meteorograf",
    "meteorografului": "meteorograf",
    "meteorologi": "meteorolog",
    "meteorologii": "meteorolog",
    "meteorologilor": "meteorolog",
    "meteorologul": "meteorolog",
    "meteorologului": "meteorolog",
    "meteorologica": "meteorologic",
    "meteorologică": "meteorologic",
    "meteorologice": "meteorologic",
    "meteorologicei": "meteorologic",
    "meteorologicele": "meteorologic",
    "meteorologicelor": "meteorologic",
    "meteorologici": "meteorologic",
    "meteorologicii": "meteorologic",
    "meteorologicilor": "meteorologic",
    "meteorologicul": "meteorologic",
    "meteorologicului": "meteorologic",
    "meteor.": "meteorologie",
    "meteorologia": "meteorologie",
    "meteorologiei": "meteorologie",
    "meteorologii": "meteorologie",
    "metereze": "meterez",
    "meterezele": "meterez",
    "meterezelor": "meterez",
    "meterezul": "meterez",
    "meterezului": "meterez",
    "meticuloasa": "meticulos",
    "meticuloasă": "meticulos",
    "meticuloase": "meticulos",
    "meticuloasei": "meticulos",
    "meticuloasele": "meticulos",
    "meticuloaselor": "meticulos",
    "meticuloși": "meticulos",
    "meticuloșii": "meticulos",
    "meticuloșilor": "meticulos",
    "meticulosul": "meticulos",
    "meticulosului": "meticulos",
    "meticulozitatea": "meticulozitate",
    "meticulozități": "meticulozitate",
    "meticulozității": "meticulozitate",
    "meticulozitățile": "meticulozitate",
    "meticulozităților": "meticulozitate",
    "metilul": "metil",
    "metilului": "metil",
    "metilenul": "metilen",
    "metilenului": "metilen",
    "metilica": "metilic",
    "metilică": "metilic",
    "metilice": "metilic",
    "metilicei": "metilic",
    "metilicele": "metilic",
    "metilicelor": "metilic",
    "metilici": "metilic",
    "metilicii": "metilic",
    "metilicilor": "metilic",
    "metilicul": "metilic",
    "metilicului": "metilic",
    "metionina": "metionină",
    "metionine": "metionină",
    "metioninei": "metionină",
    "metioninele": "metionină",
    "metioninelor": "metionină",
    "metisa": "metis",
    "metisă": "metis",
    "metise": "metis",
    "metisei": "metis",
    "metisele": "metis",
    "metiselor": "metis",
    "metiși": "metis",
    "metișii": "metis",
    "metișilor": "metis",
    "metisul": "metis",
    "metisului": "metis",
    "metisa": "metisă",
    "metise": "metisă",
    "metisei": "metisă",
    "metisele": "metisă",
    "metiselor": "metisă",
    "metocul": "metoc",
    "metocului": "metoc",
    "metocuri": "metoc",
    "metocurile": "metoc",
    "metocurilor": "metoc",
    "metoda": "metodă",
    "metode": "metodă",
    "metodei": "metodă",
    "metodele": "metodă",
    "metodelor": "metodă",
    "metodica": "metodic",
    "metodică": "metodic",
    "metodice": "metodic",
    "metodicei": "metodic",
    "metodicele": "metodic",
    "metodicelor": "metodic",
    "metodici": "metodic",
    "metodicii": "metodic",
    "metodicilor": "metodic",
    "metodicul": "metodic",
    "metodicului": "metodic",
    "metodica": "metodică",
    "metodicele": "metodică",
    "metodici": "metodică",
    "metodicii": "metodică",
    "metodicilor": "metodică",
    "metodiști": "metodist",
    "metodiștii": "metodist",
    "metodiștilor": "metodist",
    "metodistul": "metodist",
    "metodistului": "metodist",
    "metodista": "metodistă",
    "metodiste": "metodistă",
    "metodistei": "metodistă",
    "metodistele": "metodistă",
    "metodistelor": "metodistă",
    "metodologica": "metodologic",
    "metodologică": "metodologic",
    "metodologice": "metodologic",
    "metodologicei": "metodologic",
    "metodologicele": "metodologic",
    "metodologicelor": "metodologic",
    "metodologici": "metodologic",
    "metodologicii": "metodologic",
    "metodologicilor": "metodologic",
    "metodologicul": "metodologic",
    "metodologicului": "metodologic",
    "metodologia": "metodologie",
    "metodologiei": "metodologie",
    "metodologii": "metodologie",
    "metonimia": "metonimie",
    "metonimiei": "metonimie",
    "metonimii": "metonimie",
    "metonimiile": "metonimie",
    "metonimiilor": "metonimie",
    "metopa": "metopă",
    "metope": "metopă",
    "metopei": "metopă",
    "metopele": "metopă",
    "metopelor": "metopă",
    "metraje": "metraj",
    "metrajele": "metraj",
    "metrajelor": "metraj",
    "metrajul": "metraj",
    "metrajului": "metraj",
    "mp": "metri_pătrați",
    "metrica": "metric",
    "metrică": "metric",
    "metrice": "metric",
    "metricei": "metric",
    "metricele": "metric",
    "metricelor": "metric",
    "metrici": "metric",
    "metricii": "metric",
    "metricilor": "metric",
    "metricul": "metric",
    "metricului": "metric",
    "metrica": "metrică",
    "metrice": "metrică",
    "metricei": "metrică",
    "metr.": "metrologie",
    "metrologia": "metrologie",
    "metrologiei": "metrologie",
    "metrologii": "metrologie",
    "metrologiile": "metrologie",
    "metrologiilor": "metrologie",
    "metronoame": "metronom",
    "metronoamele": "metronom",
    "metronoamelor": "metronom",
    "metronomul": "metronom",
    "metronomului": "metronom",
    "metropola": "metropolă",
    "metropole": "metropolă",
    "metropolei": "metropolă",
    "metropolele": "metropolă",
    "metropolelor": "metropolă",
    "metroul": "metrou",
    "metroului": "metrou",
    "metrouri": "metrou",
    "metrourile": "metrou",
    "metrourilor": "metrou",
    "m": "metru",
    "metri": "metru",
    "metrii": "metru",
    "metrilor": "metru",
    "metrul": "metru",
    "metrului": "metru",
    "mea": "meu",
    "mei": "meu",
    "mele": "meu",
    "Mexicul": "Mexic",
    "Mexicului": "Mexic",
    "mexicana": "mexican",
    "mexicană": "mexican",
    "mexicane": "mexican",
    "mexicanei": "mexican",
    "mexicanele": "mexican",
    "mexicanelor": "mexican",
    "mexicani": "mexican",
    "mexicanii": "mexican",
    "mexicanilor": "mexican",
    "mexicanul": "mexican",
    "mexicanului": "mexican",
    "mexicanca": "mexicancă",
    "mexicance": "mexicancă",
    "mexicancei": "mexicancă",
    "mexicancele": "mexicancă",
    "mexicancelor": "mexicancă",
    "mezalianța": "mezalianță",
    "mezalianțe": "mezalianță",
    "mezalianței": "mezalianță",
    "mezalianțele": "mezalianță",
    "mezalianțelor": "mezalianță",
    "mezanine": "mezanin",
    "mezaninele": "mezanin",
    "mezaninelor": "mezanin",
    "mezaninul": "mezanin",
    "mezaninului": "mezanin",
    "mezatul": "mezat",
    "mezatului": "mezat",
    "mezelul": "mezel",
    "mezelului": "mezel",
    "mezeluri": "mezel",
    "mezelurile": "mezel",
    "mezelurilor": "mezel",
    "mezelăria": "mezelărie",
    "mezelăriei": "mezelărie",
    "mezelării": "mezelărie",
    "mezelăriile": "mezelărie",
    "mezelăriilor": "mezelărie",
    "mezelicul": "mezelic",
    "mezelicului": "mezelic",
    "mezelicuri": "mezelic",
    "mezelicurile": "mezelic",
    "mezelicurilor": "mezelic",
    "mezentere": "mezenter",
    "mezenterele": "mezenter",
    "mezenterelor": "mezenter",
    "mezenterul": "mezenter",
    "mezenterului": "mezenter",
    "mezina": "mezin",
    "mezină": "mezin",
    "mezine": "mezin",
    "mezinei": "mezin",
    "mezinele": "mezin",
    "mezinelor": "mezin",
    "mezini": "mezin",
    "mezinii": "mezin",
    "mezinilor": "mezin",
    "mezinul": "mezin",
    "mezinului": "mezin",
    "mezina": "mezină",
    "mezine": "mezină",
    "mezinei": "mezină",
    "mezinele": "mezină",
    "mezinelor": "mezină",
    "mezocarpul": "mezocarp",
    "mezocarpului": "mezocarp",
    "mezocarpuri": "mezocarp",
    "mezocarpurile": "mezocarp",
    "mezocarpurilor": "mezocarp",
    "mezoderme": "mezoderm",
    "mezodermele": "mezoderm",
    "mezodermelor": "mezoderm",
    "mezodermul": "mezoderm",
    "mezodermului": "mezoderm",
    "mezoliticul": "mezolitic",
    "mezoliticului": "mezolitic",
    "mezoni": "mezon",
    "mezonii": "mezon",
    "mezonilor": "mezon",
    "mezonul": "mezon",
    "mezonului": "mezon",
    "mezozoicul": "mezozoic",
    "mezozoicului": "mezozoic",
    "mezzo-soprana": "mezzo-soprană",
    "mezzo-soprane": "mezzo-soprană",
    "mezzo-sopranei": "mezzo-soprană",
    "mezzo-sopranele": "mezzo-soprană",
    "mezzo-sopranelor": "mezzo-soprană",
    "miaua": "mia",
    "miele": "mia",
    "mielei": "mia",
    "mielele": "mia",
    "mielelor": "mia",
    "mialgia": "mialgie",
    "mialgiei": "mialgie",
    "mialgii": "mialgie",
    "mialgiile": "mialgie",
    "mialgiilor": "mialgie",
    "miasma": "miasmă",
    "miasme": "miasmă",
    "miasmei": "miasmă",
    "miasmele": "miasmă",
    "miasmelor": "miasmă",
    "mica": "mic",
    "mică": "mic",
    "mici": "mic",
    "micii": "mic",
    "micile": "mic",
    "micilor": "mic",
    "micul": "mic",
    "micului": "mic",
    "mica": "mică",
    "mice": "mică",
    "micei": "mică",
    "micele": "mică",
    "micelor": "mică",
    "micașistul": "micașist",
    "micașistului": "micașist",
    "micașisturi": "micașist",
    "micașisturile": "micașist",
    "micașisturilor": "micașist",
    "mic-burgheză": "mic-burghez",
    "mic-burgheze": "mic-burghez",
    "mic-burghezi": "mic-burghez",
    "micelii": "miceliu",
    "miceliile": "miceliu",
    "miceliilor": "miceliu",
    "miceliul": "miceliu",
    "miceliului": "miceliu",
    "micimea": "micime",
    "micimi": "micime",
    "micimii": "micime",
    "micimile": "micime",
    "micimilor": "micime",
    "micologia": "micologie",
    "micologiei": "micologie",
    "micologii": "micologie",
    "micoza": "micoză",
    "micoze": "micoză",
    "micozei": "micoză",
    "micozele": "micoză",
    "micozelor": "micoză",
    "microbi": "microb",
    "microbii": "microb",
    "microbilor": "microb",
    "microbul": "microb",
    "microbului": "microb",
    "microbiana": "microbian",
    "microbiană": "microbian",
    "microbianul": "microbian",
    "microbianului": "microbian",
    "microbiene": "microbian",
    "microbienei": "microbian",
    "microbienele": "microbian",
    "microbienelor": "microbian",
    "microbieni": "microbian",
    "microbienii": "microbian",
    "microbienilor": "microbian",
    "microbiologia": "microbiologie",
    "microbiologiei": "microbiologie",
    "microbiologii": "microbiologie",
    "microbuze": "microbuz",
    "microbuzele": "microbuz",
    "microbuzelor": "microbuz",
    "microbuzul": "microbuz",
    "microbuzului": "microbuz",
    "microcefala": "microcefal",
    "microcefală": "microcefal",
    "microcefale": "microcefal",
    "microcefalei": "microcefal",
    "microcefalele": "microcefal",
    "microcefalelor": "microcefal",
    "microcefali": "microcefal",
    "microcefalii": "microcefal",
    "microcefalilor": "microcefal",
    "microcefalul": "microcefal",
    "microcefalului": "microcefal",
    "microcefala": "microcefală",
    "microcefale": "microcefală",
    "microcefalei": "microcefală",
    "microcefalele": "microcefală",
    "microcefalelor": "microcefală",
    "microcefalia": "microcefalie",
    "microcefaliei": "microcefalie",
    "microcefalii": "microcefalie",
    "microcefaliile": "microcefalie",
    "microcefaliilor": "microcefalie",
    "microclima": "microclimă",
    "microclime": "microclimă",
    "microclimei": "microclimă",
    "microclimele": "microclimă",
    "microclimelor": "microclimă",
    "microcosmul": "microcosm",
    "microcosmului": "microcosm",
    "microcosmosul": "microcosmos",
    "microcosmosule": "microcosmos",
    "microcosmosului": "microcosmos",
    "microcosmosuri": "microcosmos",
    "microcosmosurile": "microcosmos",
    "microcosmosurilor": "microcosmos",
    "microfilme": "microfilm",
    "microfilmele": "microfilm",
    "microfilmelor": "microfilm",
    "microfilmul": "microfilm",
    "microfilmului": "microfilm",
    "microfoane": "microfon",
    "microfoanele": "microfon",
    "microfoanelor": "microfon",
    "microfonul": "microfon",
    "microfonului": "microfon",
    "microlite": "microlit",
    "microlitele": "microlit",
    "microlitelor": "microlit",
    "microlitul": "microlit",
    "microlitului": "microlit",
    "micrometre": "micrometru",
    "micrometrele": "micrometru",
    "micrometrelor": "micrometru",
    "micrometrul": "micrometru",
    "micrometrului": "micrometru",
    "mc.": "micron",
    "mcn.": "micron",
    "microni": "micron",
    "micronii": "micron",
    "micronilor": "micron",
    "micronul": "micron",
    "micronului": "micron",
    "microorganisme": "microorganism",
    "microorganismele": "microorganism",
    "microorganismelor": "microorganism",
    "microorganismul": "microorganism",
    "microorganismului": "microorganism",
    "micropile": "micropil",
    "micropilele": "micropil",
    "micropilelor": "micropil",
    "micropilul": "micropil",
    "micropilului": "micropil",
    "microporosul": "microporos",
    "microporosului": "microporos",
    "microraioane": "microraion",
    "microraioanele": "microraion",
    "microraioanelor": "microraion",
    "microraionul": "microraion",
    "microraionului": "microraion",
    "microreceptoare": "microreceptor",
    "microreceptoarele": "microreceptor",
    "microreceptoarelor": "microreceptor",
    "microreceptorul": "microreceptor",
    "microreceptorului": "microreceptor",
    "microrecitalul": "microrecital",
    "microrecitalule": "microrecital",
    "microrecitalului": "microrecital",
    "microrecitaluri": "microrecital",
    "microrecitalurile": "microrecital",
    "microrecitalurilor": "microrecital",
    "microscoape": "microscop",
    "microscoapele": "microscop",
    "microscoapelor": "microscop",
    "microscopul": "microscop",
    "microscopului": "microscop",
    "microscopica": "microscopic",
    "microscopică": "microscopic",
    "microscopice": "microscopic",
    "microscopicei": "microscopic",
    "microscopicele": "microscopic",
    "microscopicelor": "microscopic",
    "microscopici": "microscopic",
    "microscopicii": "microscopic",
    "microscopicilor": "microscopic",
    "microscopicul": "microscopic",
    "microscopicului": "microscopic",
    "microscopia": "microscopie",
    "microscopiei": "microscopie",
    "microscopii": "microscopie",
    "microscopiile": "microscopie",
    "microscopiilor": "microscopie",
    "mcsec.": "microsecundă",
    "microsecunda": "microsecundă",
    "microsecunde": "microsecundă",
    "microsecundei": "microsecundă",
    "microsecundele": "microsecundă",
    "microsecundelor": "microsecundă",
    "microspori": "microspor",
    "microsporii": "microspor",
    "microsporilor": "microspor",
    "microsporul": "microspor",
    "microsporului": "microspor",
    "microstructura": "microstructură",
    "microstructuri": "microstructură",
    "microstructurii": "microstructură",
    "microstructurile": "microstructură",
    "microstructurilor": "microstructură",
    "micsandra": "micsandră",
    "micsandre": "micsandră",
    "micsandrei": "micsandră",
    "micsandrele": "micsandră",
    "micsandrelor": "micsandră",
    "micsandrei-de-munte": "micsandră-de-munte",
    "micsandrei-sălbatice": "micsandră-sălbatică",
    "micsandre-sălbatice": "micsandră-sălbatică",
    "micșoră": "micșora",
    "micșorai": "micșora",
    "micșoram": "micșora",
    "micșorăm": "micșora",
    "micșorând": "micșora",
    "micșorându": "micșora",
    "micșorară": "micșora",
    "micșorarăm": "micșora",
    "micșorarăți": "micșora",
    "micșorase": "micșora",
    "micșorasem": "micșora",
    "micșoraseră": "micșora",
    "micșoraserăm": "micșora",
    "micșoraserăți": "micșora",
    "micșoraseși": "micșora",
    "micșorași": "micșora",
    "micșorat": "micșora",
    "micșorați": "micșora",
    "micșoratu": "micșora",
    "micșorau": "micșora",
    "micșorează": "micșora",
    "micșorez": "micșora",
    "micșoreze": "micșora",
    "micșorezi": "micșora",
    "nemaimicșorând": "micșora",
    "nemaimicșorându": "micșora",
    "nemicșorând": "micșora",
    "nemicșorându": "micșora",
    "micșorată": "micșorat",
    "micșorate": "micșorat",
    "micșorați": "micșorat",
    "micșuneaua": "micșunea",
    "micșunele": "micșunea",
    "micșunelei": "micșunea",
    "micșunelele": "micșunea",
    "micșunelelor": "micșunea",
    "micuța": "micuț",
    "micuță": "micuț",
    "micuțe": "micuț",
    "micuței": "micuț",
    "micuțele": "micuț",
    "micuțelor": "micuț",
    "micuți": "micuț",
    "micuții": "micuț",
    "micuților": "micuț",
    "micuțul": "micuț",
    "micuțului": "micuț",
    "midia": "midie",
    "midiei": "midie",
    "midii": "midie",
    "midiile": "midie",
    "midiilor": "midie",
    "mia": "mie",
    "miei": "mie",
    "mielea": "mie",
    "mii": "mie",
    "miile": "mie",
    "miilor": "mie",
    "miei": "miel",
    "mieii": "miel",
    "mieilor": "miel",
    "mielul": "miel",
    "mielului": "miel",
    "mielăreaua": "mielărea",
    "mielărele": "mielărea",
    "mielărelei": "mielărea",
    "mielărelele": "mielărea",
    "mielărelelor": "mielărea",
    "mielita": "mielită",
    "mielite": "mielită",
    "mielitei": "mielită",
    "mielitele": "mielită",
    "mielitelor": "mielită",
    "miercurea": "miercuri",
    "miercurii": "miercuri",
    "miercurile": "miercuri",
    "miercurilor": "miercuri",
    "mierea": "miere",
    "mieri": "miere",
    "mierii": "miere",
    "mierla": "mierlă",
    "mierle": "mierlă",
    "mierlei": "mierlă",
    "mierlele": "mierlă",
    "mierlelor": "mierlă",
    "mieroasa": "mieros",
    "mieroasă": "mieros",
    "mieroase": "mieros",
    "mieroasei": "mieros",
    "mieroasele": "mieros",
    "mieroaselor": "mieros",
    "mieroși": "mieros",
    "mieroșii": "mieros",
    "mieroșilor": "mieros",
    "mierosul": "mieros",
    "mierosului": "mieros",
    "mierța": "mierță",
    "mierțe": "mierță",
    "mierței": "mierță",
    "mierțele": "mierță",
    "mierțelor": "mierță",
    "miaun": "mieuna",
    "miaună": "mieuna",
    "miaune": "mieuna",
    "miauni": "mieuna",
    "mieună": "mieuna",
    "mieunai": "mieuna",
    "mieunam": "mieuna",
    "mieunăm": "mieuna",
    "mieunând": "mieuna",
    "mieunându": "mieuna",
    "mieunară": "mieuna",
    "mieunarăm": "mieuna",
    "mieunarăți": "mieuna",
    "mieunase": "mieuna",
    "mieunasem": "mieuna",
    "mieunaseră": "mieuna",
    "mieunaserăm": "mieuna",
    "mieunaserăți": "mieuna",
    "mieunaseși": "mieuna",
    "mieunași": "mieuna",
    "mieunat": "mieuna",
    "mieunați": "mieuna",
    "mieunatu": "mieuna",
    "mieunau": "mieuna",
    "mieunată": "mieunat",
    "mieunate": "mieunat",
    "mieunați": "mieunat",
    "mieunatul": "mieunat",
    "mieunatului": "mieunat",
    "mieunaturi": "mieunat",
    "mieunaturile": "mieunat",
    "mieunaturilor": "mieunat",
    "miezul": "miez",
    "miezului": "miez",
    "miezuri": "miez",
    "miezurile": "miez",
    "miezurilor": "miez",
    "miezoasa": "miezos",
    "miezoasă": "miezos",
    "miezoase": "miezos",
    "miezoasei": "miezos",
    "miezoasele": "miezos",
    "miezoaselor": "miezos",
    "miezoși": "miezos",
    "miezoșii": "miezos",
    "miezoșilor": "miezos",
    "miezosul": "miezos",
    "miezosului": "miezos",
    "migala": "migală",
    "migale": "migală",
    "migalei": "migală",
    "migăleala": "migăleală",
    "migăleli": "migăleală",
    "migălelii": "migăleală",
    "migălelile": "migăleală",
    "migălelilor": "migăleală",
    "migălea": "migăli",
    "migăleai": "migăli",
    "migăleam": "migăli",
    "migălească": "migăli",
    "migăleați": "migăli",
    "migăleau": "migăli",
    "migălesc": "migăli",
    "migălește": "migăli",
    "migălești": "migăli",
    "migălii": "migăli",
    "migălim": "migăli",
    "migălind": "migăli",
    "migălindu": "migăli",
    "migăliră": "migăli",
    "migălirăm": "migăli",
    "migălirăți": "migăli",
    "migălise": "migăli",
    "migălisem": "migăli",
    "migăliseră": "migăli",
    "migăliserăm": "migăli",
    "migăliserăți": "migăli",
    "migăliseși": "migăli",
    "migăliși": "migăli",
    "migălit": "migăli",
    "migăliți": "migăli",
    "migălitu": "migăli",
    "nemaimigălind": "migăli",
    "nemaimigălindu": "migăli",
    "nemigălind": "migăli",
    "nemigălindu": "migăli",
    "migălită": "migălit",
    "migălite": "migălit",
    "migăliți": "migălit",
    "migăloasa": "migălos",
    "migăloasă": "migălos",
    "migăloase": "migălos",
    "migăloasei": "migălos",
    "migăloasele": "migălos",
    "migăloaselor": "migălos",
    "migăloși": "migălos",
    "migăloșii": "migălos",
    "migăloșilor": "migălos",
    "migălosul": "migălos",
    "migălosului": "migălos",
    "migdali": "migdal",
    "migdalii": "migdal",
    "migdalilor": "migdal",
    "migdalul": "migdal",
    "migdalului": "migdal",
    "migdala": "migdală",
    "migdale": "migdală",
    "migdalei": "migdală",
    "migdalele": "migdală",
    "migdalelor": "migdală",
    "migdalata": "migdalat",
    "migdalată": "migdalat",
    "migdalate": "migdalat",
    "migdalatei": "migdalat",
    "migdalatele": "migdalat",
    "migdalatelor": "migdalat",
    "migdalați": "migdalat",
    "migdalații": "migdalat",
    "migdalaților": "migdalat",
    "migdalatul": "migdalat",
    "migdalatului": "migdalat",
    "migmatite": "migmatit",
    "migmatitele": "migmatit",
    "migmatitelor": "migmatit",
    "migmatitul": "migmatit",
    "migmatitului": "migmatit",
    "mignona": "mignon",
    "mignonă": "mignon",
    "mignone": "mignon",
    "mignonei": "mignon",
    "mignonele": "mignon",
    "mignonelor": "mignon",
    "mignoni": "mignon",
    "mignonii": "mignon",
    "mignonilor": "mignon",
    "mignonul": "mignon",
    "mignonului": "mignon",
    "migră": "migra",
    "migrai": "migra",
    "migram": "migra",
    "migrăm": "migra",
    "migrând": "migra",
    "migrându": "migra",
    "migrară": "migra",
    "migrarăm": "migra",
    "migrarăți": "migra",
    "migrase": "migra",
    "migrasem": "migra",
    "migraseră": "migra",
    "migraserăm": "migra",
    "migraserăți": "migra",
    "migraseși": "migra",
    "migrași": "migra",
    "migrat": "migra",
    "migrați": "migra",
    "migratu": "migra",
    "migrau": "migra",
    "migrează": "migra",
    "migrez": "migra",
    "migreze": "migra",
    "migrezi": "migra",
    "nemaimigrând": "migra",
    "nemaimigrându": "migra",
    "nemigrând": "migra",
    "nemigrându": "migra",
    "migrarea": "migrare",
    "migrareo": "migrare",
    "migrări": "migrare",
    "migrării": "migrare",
    "migrările": "migrare",
    "migrărilor": "migrare",
    "migrată": "migrat",
    "migrate": "migrat",
    "migrați": "migrat",
    "migrațiunea": "migrațiune",
    "migrațiuni": "migrațiune",
    "migrațiunii": "migrațiune",
    "migrațiunile": "migrațiune",
    "migrațiunilor": "migrațiune",
    "migratoare": "migrator",
    "migratoarea": "migrator",
    "migratoarei": "migrator",
    "migratoarele": "migrator",
    "migratoarelor": "migrator",
    "migratori": "migrator",
    "migratorii": "migrator",
    "migratorilor": "migrator",
    "migratorul": "migrator",
    "migratorului": "migrator",
    "migrena": "migrenă",
    "migrene": "migrenă",
    "migrenei": "migrenă",
    "migrenele": "migrenă",
    "migrenelor": "migrenă",
    "Mihaelei": "Mihaela",
    "mihalți": "mihalț",
    "mihalții": "mihalț",
    "mihalților": "mihalț",
    "mihalțul": "mihalț",
    "mihalțului": "mihalț",
    "miimea": "miime",
    "miimi": "miime",
    "miimii": "miime",
    "miimile": "miime",
    "miimilor": "miime",
    "mijea": "miji",
    "mijeai": "miji",
    "mijeam": "miji",
    "mijească": "miji",
    "mijeați": "miji",
    "mijeau": "miji",
    "mijesc": "miji",
    "mijește": "miji",
    "mijești": "miji",
    "mijii": "miji",
    "mijim": "miji",
    "mijind": "miji",
    "mijindu": "miji",
    "mijiră": "miji",
    "mijirăm": "miji",
    "mijirăți": "miji",
    "mijise": "miji",
    "mijisem": "miji",
    "mijiseră": "miji",
    "mijiserăm": "miji",
    "mijiserăți": "miji",
    "mijiseși": "miji",
    "mijiși": "miji",
    "mijit": "miji",
    "mijiți": "miji",
    "mijitu": "miji",
    "nemaimijind": "miji",
    "nemaimijindu": "miji",
    "nemijind": "miji",
    "nemijindu": "miji",
    "mijirea": "mijire",
    "mijireo": "mijire",
    "mijiri": "mijire",
    "mijirii": "mijire",
    "mijirile": "mijire",
    "mijirilor": "mijire",
    "mijită": "mijit",
    "mijite": "mijit",
    "mijiți": "mijit",
    "mijl.": "mijloc",
    "mijloace": "mijloc",
    "mijloacele": "mijloc",
    "mijloacelor": "mijloc",
    "mijlocu'": "mijloc",
    "mijlocul": "mijloc",
    "mijlocului": "mijloc",
    "mijlocuri": "mijloc",
    "mijlocurile": "mijloc",
    "mijlocurilor": "mijloc",
    "mijlocașa": "mijlocaș",
    "mijlocașă": "mijlocaș",
    "mijlocașe": "mijlocaș",
    "mijlocașei": "mijlocaș",
    "mijlocașele": "mijlocaș",
    "mijlocașelor": "mijlocaș",
    "mijlocași": "mijlocaș",
    "mijlocașii": "mijlocaș",
    "mijlocașilor": "mijlocaș",
    "mijlocașul": "mijlocaș",
    "mijlocașului": "mijlocaș",
    "mijlocașa": "mijlocașă",
    "mijlocașe": "mijlocașă",
    "mijlocașei": "mijlocașă",
    "mijlocașele": "mijlocașă",
    "mijlocașelor": "mijlocașă",
    "mijlocea": "mijloci",
    "mijloceai": "mijloci",
    "mijloceam": "mijloci",
    "mijlocească": "mijloci",
    "mijloceați": "mijloci",
    "mijloceau": "mijloci",
    "mijlocesc": "mijloci",
    "mijlocește": "mijloci",
    "mijlocești": "mijloci",
    "mijlocii": "mijloci",
    "mijlocim": "mijloci",
    "mijlocind": "mijloci",
    "mijlocindu": "mijloci",
    "mijlociră": "mijloci",
    "mijlocirăm": "mijloci",
    "mijlocirăți": "mijloci",
    "mijlocise": "mijloci",
    "mijlocisem": "mijloci",
    "mijlociseră": "mijloci",
    "mijlociserăm": "mijloci",
    "mijlociserăți": "mijloci",
    "mijlociseși": "mijloci",
    "mijlociși": "mijloci",
    "mijlocit": "mijloci",
    "mijlociți": "mijloci",
    "mijlocitu": "mijloci",
    "nemaimijlocind": "mijloci",
    "nemaimijlocindu": "mijloci",
    "nemijlocind": "mijloci",
    "nemijlocindu": "mijloci",
    "mijlocirea": "mijlocire",
    "mijlocireo": "mijlocire",
    "mijlociri": "mijlocire",
    "mijlocirii": "mijlocire",
    "mijlocirile": "mijlocire",
    "mijlocirilor": "mijlocire",
    "mijlocită": "mijlocit",
    "mijlocite": "mijlocit",
    "mijlociți": "mijlocit",
    "mijlocitoarea": "mijlocitoare",
    "mijlocitoarei": "mijlocitoare",
    "mijlocitoarele": "mijlocitoare",
    "mijlocitoarelor": "mijlocitoare",
    "mijlocitoareo": "mijlocitoare",
    "mijlocitori": "mijlocitor",
    "mijlocitorii": "mijlocitor",
    "mijlocitorilor": "mijlocitor",
    "mijlocitorul": "mijlocitor",
    "mijlocitorule": "mijlocitor",
    "mijlocitorului": "mijlocitor",
    "mijlocia": "mijlociu",
    "mijlocie": "mijlociu",
    "mijlociei": "mijlociu",
    "mijlocii": "mijlociu",
    "mijlociii": "mijlociu",
    "mijlociile": "mijlociu",
    "mijlociilor": "mijlociu",
    "mijlocio": "mijlociu",
    "mijlociul": "mijlociu",
    "mijlociule": "mijlociu",
    "mijlociului": "mijlociu",
    "mila": "milă",
    "mile": "milă",
    "milei": "milă",
    "milele": "milă",
    "milelor": "milă",
    "milaneza": "milaneză",
    "milaneze": "milaneză",
    "milanezei": "milaneză",
    "milanezele": "milaneză",
    "milanezelor": "milaneză",
    "milenara": "milenar",
    "milenară": "milenar",
    "milenare": "milenar",
    "milenarei": "milenar",
    "milenarele": "milenar",
    "milenarelor": "milenar",
    "milenari": "milenar",
    "milenarii": "milenar",
    "milenarilor": "milenar",
    "milenarul": "milenar",
    "milenarului": "milenar",
    "milen.": "mileniu",
    "milenii": "mileniu",
    "mileniile": "mileniu",
    "mileniilor": "mileniu",
    "mileniul": "mileniu",
    "mileniului": "mileniu",
    "miliare": "miliar",
    "miliarele": "miliar",
    "miliarelor": "miliar",
    "miliarul": "miliar",
    "miliarului": "miliar",
    "miliarde": "miliard",
    "miliardele": "miliard",
    "miliardelor": "miliard",
    "miliardul": "miliard",
    "miliardului": "miliard",
    "miliardari": "miliardar",
    "miliardarii": "miliardar",
    "miliardarilor": "miliardar",
    "miliardarul": "miliardar",
    "miliardarului": "miliardar",
    "miliardara": "miliardară",
    "miliardare": "miliardară",
    "miliardarei": "miliardară",
    "miliardarele": "miliardară",
    "miliardarelor": "miliardară",
    "mld.": "miliarde",
    "miliardimea": "miliardime",
    "miliardimi": "miliardime",
    "miliardimii": "miliardime",
    "miliardimile": "miliardime",
    "miliardimilor": "miliardime",
    "mg": "miligram",
    "miligrame": "miligram",
    "miligramele": "miligram",
    "miligramelor": "miligram",
    "miligramul": "miligram",
    "miligramului": "miligram",
    "mililitre": "mililitru",
    "mililitrele": "mililitru",
    "mililitrelor": "mililitru",
    "mililitrul": "mililitru",
    "mililitrului": "mililitru",
    "ml": "mililitru",
    "milimetrica": "milimetric",
    "milimetrică": "milimetric",
    "milimetrice": "milimetric",
    "milimetricei": "milimetric",
    "milimetricele": "milimetric",
    "milimetricelor": "milimetric",
    "milimetrici": "milimetric",
    "milimetricii": "milimetric",
    "milimetricilor": "milimetric",
    "milimetricul": "milimetric",
    "milimetricului": "milimetric",
    "milimetri": "milimetru",
    "milimetrii": "milimetru",
    "milimetrilor": "milimetru",
    "milimetrul": "milimetru",
    "milimetrului": "milimetru",
    "mm": "milimetru",
    "mil.": "milion",
    "milioane": "milion",
    "milioanele": "milion",
    "milioanelor": "milion",
    "milionul": "milion",
    "milionului": "milion",
    "milionari": "milionar",
    "milionarii": "milionar",
    "milionarilor": "milionar",
    "milionarul": "milionar",
    "milionarului": "milionar",
    "milionara": "milionară",
    "milionare": "milionară",
    "milionarei": "milionară",
    "milionarele": "milionară",
    "milionarelor": "milionară",
    "milionimea": "milionime",
    "milionimi": "milionime",
    "milionimii": "milionime",
    "milionimile": "milionime",
    "milionimilor": "milionime",
    "milită": "milita",
    "militai": "milita",
    "militam": "milita",
    "milităm": "milita",
    "militând": "milita",
    "militându": "milita",
    "militară": "milita",
    "militarăm": "milita",
    "militarăți": "milita",
    "militase": "milita",
    "militasem": "milita",
    "militaseră": "milita",
    "militaserăm": "milita",
    "militaserăți": "milita",
    "militaseși": "milita",
    "militași": "milita",
    "militat": "milita",
    "militați": "milita",
    "militatu": "milita",
    "militau": "milita",
    "militează": "milita",
    "militez": "milita",
    "militeze": "milita",
    "militezi": "milita",
    "nemaimilitând": "milita",
    "nemaimilitându": "milita",
    "nemilitând": "milita",
    "nemilitându": "milita",
    "militanta": "militant",
    "militantă": "militant",
    "militante": "militant",
    "militantei": "militant",
    "militantele": "militant",
    "militantelor": "militant",
    "militanți": "militant",
    "militanții": "militant",
    "militanților": "militant",
    "militantul": "militant",
    "militantului": "militant",
    "militara": "militar",
    "militară": "militar",
    "militare": "militar",
    "militarei": "militar",
    "militarele": "militar",
    "militarelor": "militar",
    "militari": "militar",
    "militarii": "militar",
    "militarilor": "militar",
    "militarul": "militar",
    "militarului": "militar",
    "milităreasca": "milităresc",
    "militărească": "milităresc",
    "militărescul": "milităresc",
    "militărescului": "milităresc",
    "militărești": "milităresc",
    "milităreștii": "milităresc",
    "milităreștile": "milităresc",
    "milităreștilor": "milităresc",
    "mil.": "militărie",
    "milităria": "militărie",
    "milităriei": "militărie",
    "militării": "militărie",
    "milităriile": "militărie",
    "milităriilor": "militărie",
    "militarisme": "militarism",
    "militarismele": "militarism",
    "militarismelor": "militarism",
    "militarismul": "militarism",
    "militarismului": "militarism",
    "militarista": "militarist",
    "militaristă": "militarist",
    "militariste": "militarist",
    "militaristei": "militarist",
    "militaristele": "militarist",
    "militaristelor": "militarist",
    "militariști": "militarist",
    "militariștii": "militarist",
    "militariștilor": "militarist",
    "militaristul": "militarist",
    "militaristului": "militarist",
    "militarista": "militaristă",
    "militariste": "militaristă",
    "militaristei": "militaristă",
    "militaristele": "militaristă",
    "militaristelor": "militaristă",
    "militariză": "militariza",
    "militarizai": "militariza",
    "militarizam": "militariza",
    "militarizăm": "militariza",
    "militarizând": "militariza",
    "militarizându": "militariza",
    "militarizară": "militariza",
    "militarizarăm": "militariza",
    "militarizarăți": "militariza",
    "militarizase": "militariza",
    "militarizasem": "militariza",
    "militarizaseră": "militariza",
    "militarizaserăm": "militariza",
    "militarizaserăți": "militariza",
    "militarizaseși": "militariza",
    "militarizași": "militariza",
    "militarizat": "militariza",
    "militarizați": "militariza",
    "militarizatu": "militariza",
    "militarizau": "militariza",
    "militarizează": "militariza",
    "militarizez": "militariza",
    "militarizeze": "militariza",
    "militarizezi": "militariza",
    "nemaimilitarizând": "militariza",
    "nemaimilitarizându": "militariza",
    "nemilitarizând": "militariza",
    "nemilitarizându": "militariza",
    "militarizarea": "militarizare",
    "militarizări": "militarizare",
    "militarizării": "militarizare",
    "militarizările": "militarizare",
    "militarizărilor": "militarizare",
    "militarizată": "militarizat",
    "militarizate": "militarizat",
    "militarizați": "militarizat",
    "milităroasa": "milităros",
    "milităroasă": "milităros",
    "milităroase": "milităros",
    "milităroasei": "milităros",
    "milităroasele": "milităros",
    "milităroaselor": "milităros",
    "milităroși": "milităros",
    "milităroșii": "milităros",
    "milităroșilor": "milităros",
    "militărosul": "milităros",
    "militărosului": "milităros",
    "militaro-strategice": "militaro-strategic",
    "militaro-strategici": "militaro-strategic",
    "militată": "militat",
    "militate": "militat",
    "militați": "militat",
    "milițianul": "milițian",
    "milițianului": "milițian",
    "milițieni": "milițian",
    "milițienii": "milițian",
    "milițienilor": "milițian",
    "milițianca": "milițiancă",
    "milițience": "milițiancă",
    "milițiencei": "milițiancă",
    "milițiencele": "milițiancă",
    "milițiencelor": "milițiancă",
    "miliția": "miliție",
    "miliției": "miliție",
    "miliții": "miliție",
    "milițiile": "miliție",
    "milițiilor": "miliție",
    "miloaga": "miloagă",
    "miloage": "miloagă",
    "miloagei": "miloagă",
    "miloagele": "miloagă",
    "miloagelor": "miloagă",
    "milogi": "milog",
    "milogii": "milog",
    "milogilor": "milog",
    "milogul": "milog",
    "milogului": "milog",
    "milogea": "milogi",
    "milogeai": "milogi",
    "milogeam": "milogi",
    "milogească": "milogi",
    "milogeați": "milogi",
    "milogeau": "milogi",
    "milogesc": "milogi",
    "milogește": "milogi",
    "milogești": "milogi",
    "milogii": "milogi",
    "milogim": "milogi",
    "milogind": "milogi",
    "milogindu": "milogi",
    "milogiră": "milogi",
    "milogirăm": "milogi",
    "milogirăți": "milogi",
    "milogise": "milogi",
    "milogisem": "milogi",
    "milogiseră": "milogi",
    "milogiserăm": "milogi",
    "milogiserăți": "milogi",
    "milogiseși": "milogi",
    "milogiși": "milogi",
    "milogit": "milogi",
    "milogiți": "milogi",
    "milogitu": "milogi",
    "milogită": "milogit",
    "milogite": "milogit",
    "milogiți": "milogit",
    "miloasa": "milos",
    "miloasă": "milos",
    "miloase": "milos",
    "miloasei": "milos",
    "miloasele": "milos",
    "miloaselor": "milos",
    "miloși": "milos",
    "miloșii": "milos",
    "miloșilor": "milos",
    "milosul": "milos",
    "milosului": "milos",
    "Miloșești-Ialomiței": "Miloșești-Ialomița",
    "milostenia": "milostenie",
    "milosteniei": "milostenie",
    "milostenii": "milostenie",
    "milosteniile": "milostenie",
    "milosteniilor": "milostenie",
    "milostiva": "milostiv",
    "milostivă": "milostiv",
    "milostive": "milostiv",
    "milostivei": "milostiv",
    "milostivele": "milostiv",
    "milostivelor": "milostiv",
    "milostivi": "milostiv",
    "milostivii": "milostiv",
    "milostivilor": "milostiv",
    "milostivul": "milostiv",
    "milostivului": "milostiv",
    "miluia": "milui",
    "miluiai": "milui",
    "miluiam": "milui",
    "miluiască": "milui",
    "miluiați": "milui",
    "miluiau": "milui",
    "miluiesc": "milui",
    "miluiește": "milui",
    "miluiești": "milui",
    "miluii": "milui",
    "miluim": "milui",
    "miluind": "milui",
    "miluindu": "milui",
    "miluiră": "milui",
    "miluirăm": "milui",
    "miluirăți": "milui",
    "miluise": "milui",
    "miluisem": "milui",
    "miluiseră": "milui",
    "miluiserăm": "milui",
    "miluiserăți": "milui",
    "miluiseși": "milui",
    "miluiși": "milui",
    "miluit": "milui",
    "miluiți": "milui",
    "miluitu": "milui",
    "nemaimiluind": "milui",
    "nemaimiluindu": "milui",
    "nemiluind": "milui",
    "nemiluindu": "milui",
    "miluită": "miluit",
    "miluite": "miluit",
    "miluiți": "miluit",
    "mimi": "mim",
    "mimii": "mim",
    "mimilor": "mim",
    "mimul": "mim",
    "mimului": "mim",
    "mimă": "mima",
    "mimai": "mima",
    "mimam": "mima",
    "mimăm": "mima",
    "mimând": "mima",
    "mimându": "mima",
    "mimară": "mima",
    "mimarăm": "mima",
    "mimarăți": "mima",
    "mimase": "mima",
    "mimasem": "mima",
    "mimaseră": "mima",
    "mimaserăm": "mima",
    "mimaserăți": "mima",
    "mimaseși": "mima",
    "mimași": "mima",
    "mimat": "mima",
    "mimați": "mima",
    "mimatu": "mima",
    "mimau": "mima",
    "mimează": "mima",
    "mimez": "mima",
    "mimeze": "mima",
    "mimezi": "mima",
    "nemaimimând": "mima",
    "nemaimimându": "mima",
    "nemimând": "mima",
    "nemimându": "mima",
    "mimată": "mimat",
    "mimate": "mimat",
    "mimați": "mimat",
    "mimetismul": "mimetism",
    "mimetismului": "mimetism",
    "mimica": "mimică",
    "mimice": "mimică",
    "mimicei": "mimică",
    "mimicele": "mimică",
    "mimicelor": "mimică",
    "mimoza": "mimoză",
    "mimoze": "mimoză",
    "mimozei": "mimoză",
    "mimozele": "mimoză",
    "mimozelor": "mimoză",
    "mină": "mina",
    "minai": "mina",
    "minam": "mina",
    "minăm": "mina",
    "minând": "mina",
    "minându": "mina",
    "minară": "mina",
    "minarăm": "mina",
    "minarăți": "mina",
    "minase": "mina",
    "minasem": "mina",
    "minaseră": "mina",
    "minaserăm": "mina",
    "minaserăți": "mina",
    "minaseși": "mina",
    "minași": "mina",
    "minat": "mina",
    "minați": "mina",
    "minatu": "mina",
    "minau": "mina",
    "minează": "mina",
    "minez": "mina",
    "mineze": "mina",
    "minezi": "mina",
    "nemaiminând": "mina",
    "nemaiminându": "mina",
    "neminând": "mina",
    "neminându": "mina",
    "mina": "mină",
    "mine": "mină",
    "minei": "mină",
    "minele": "mină",
    "minelor": "mină",
    "minarete": "minaret",
    "minaretele": "minaret",
    "minaretelor": "minaret",
    "minaretul": "minaret",
    "minaretului": "minaret",
    "minata": "minat",
    "minată": "minat",
    "minate": "minat",
    "minatei": "minat",
    "minatele": "minat",
    "minatelor": "minat",
    "minați": "minat",
    "minații": "minat",
    "minaților": "minat",
    "minatul": "minat",
    "minatului": "minat",
    "mincinoasa": "mincinoasă",
    "mincinoase": "mincinoasă",
    "mincinoasei": "mincinoasă",
    "mincinoasele": "mincinoasă",
    "mincinoaselor": "mincinoasă",
    "mincinoasa": "mincinos",
    "mincinoasă": "mincinos",
    "mincinoase": "mincinos",
    "mincinoasei": "mincinos",
    "mincinoasele": "mincinos",
    "mincinoaselor": "mincinos",
    "mincinoși": "mincinos",
    "mincinoșii": "mincinos",
    "mincinoșilor": "mincinos",
    "mincinosul": "mincinos",
    "mincinosului": "mincinos",
    "minciogul": "minciog",
    "minciogului": "minciog",
    "mincioguri": "minciog",
    "minciogurile": "minciog",
    "minciogurilor": "minciog",
    "minciuna": "minciună",
    "minciuni": "minciună",
    "minciunii": "minciună",
    "minciunile": "minciună",
    "minciunilor": "minciună",
    "mindire": "mindir",
    "mindirele": "mindir",
    "mindirelor": "mindir",
    "mindirul": "mindir",
    "mindirului": "mindir",
    "mineie": "minei",
    "mineiele": "minei",
    "mineielor": "minei",
    "mineiul": "minei",
    "mineiului": "minei",
    "mineri": "miner",
    "minerii": "miner",
    "minerilor": "miner",
    "minerul": "miner",
    "minerului": "miner",
    "min.": "mineral",
    "minerala": "mineral",
    "minerală": "mineral",
    "minerale": "mineral",
    "mineralei": "mineral",
    "mineralele": "mineral",
    "mineralelor": "mineral",
    "minerali": "mineral",
    "mineralii": "mineral",
    "mineralilor": "mineral",
    "mineralo": "mineral",
    "mineralul": "mineral",
    "mineralule": "mineral",
    "mineralului": "mineral",
    "mineraliere": "mineralier",
    "mineralierele": "mineralier",
    "mineralierelor": "mineralier",
    "mineralierul": "mineralier",
    "mineralierului": "mineralier",
    "mineraliză": "mineraliza",
    "mineralizai": "mineraliza",
    "mineralizam": "mineraliza",
    "mineralizăm": "mineraliza",
    "mineralizând": "mineraliza",
    "mineralizându": "mineraliza",
    "mineralizară": "mineraliza",
    "mineralizarăm": "mineraliza",
    "mineralizarăți": "mineraliza",
    "mineralizase": "mineraliza",
    "mineralizasem": "mineraliza",
    "mineralizaseră": "mineraliza",
    "mineralizaserăm": "mineraliza",
    "mineralizaserăți": "mineraliza",
    "mineralizaseși": "mineraliza",
    "mineralizași": "mineraliza",
    "mineralizat": "mineraliza",
    "mineralizați": "mineraliza",
    "mineralizatu": "mineraliza",
    "mineralizau": "mineraliza",
    "mineralizează": "mineraliza",
    "mineralizez": "mineraliza",
    "mineralizeze": "mineraliza",
    "mineralizezi": "mineraliza",
    "nemaimineralizând": "mineraliza",
    "nemaimineralizându": "mineraliza",
    "nemineralizând": "mineraliza",
    "nemineralizându": "mineraliza",
    "mineralizată": "mineralizat",
    "mineralizate": "mineralizat",
    "mineralizați": "mineralizat",
    "mineralizația": "mineralizație",
    "mineralizației": "mineralizație",
    "mineralizații": "mineralizație",
    "mineralizațiile": "mineralizație",
    "mineralizațiilor": "mineralizație",
    "mineralogi": "mineralog",
    "mineralogii": "mineralog",
    "mineralogilor": "mineralog",
    "mineralogul": "mineralog",
    "mineralogului": "mineralog",
    "mineralogia": "mineralogie",
    "mineralogiei": "mineralogie",
    "mineralogii": "mineralogie",
    "mineralogiile": "mineralogie",
    "mineralogiilor": "mineralogie",
    "minereasca": "mineresc",
    "minerească": "mineresc",
    "minerescul": "mineresc",
    "minerescului": "mineresc",
    "minerești": "mineresc",
    "minereștii": "mineresc",
    "minereștile": "mineresc",
    "minereștilor": "mineresc",
    "minereul": "minereu",
    "minereului": "minereu",
    "minereuri": "minereu",
    "minereurile": "minereu",
    "minereurilor": "minereu",
    "mineritul": "minerit",
    "mineritului": "minerit",
    "mingea": "minge",
    "mingi": "minge",
    "mingii": "minge",
    "mingile": "minge",
    "mingilor": "minge",
    "miniatura": "miniatură",
    "miniaturi": "miniatură",
    "miniaturii": "miniatură",
    "miniaturile": "miniatură",
    "miniaturilor": "miniatură",
    "miniaturala": "miniatural",
    "miniaturală": "miniatural",
    "miniaturale": "miniatural",
    "miniaturalei": "miniatural",
    "miniaturalele": "miniatural",
    "miniaturalelor": "miniatural",
    "miniaturali": "miniatural",
    "miniaturalii": "miniatural",
    "miniaturalilor": "miniatural",
    "miniaturalul": "miniatural",
    "miniaturalului": "miniatural",
    "miniaturiști": "miniaturist",
    "miniaturiștii": "miniaturist",
    "miniaturiștilor": "miniaturist",
    "miniaturistul": "miniaturist",
    "miniaturistului": "miniaturist",
    "miniaturista": "miniaturistă",
    "miniaturiste": "miniaturistă",
    "miniaturistei": "miniaturistă",
    "miniaturistele": "miniaturistă",
    "miniaturistelor": "miniaturistă",
    "miniera": "minier",
    "minieră": "minier",
    "miniere": "minier",
    "minierei": "minier",
    "minierele": "minier",
    "minierelor": "minier",
    "minieri": "minier",
    "minierii": "minier",
    "minierilor": "minier",
    "minierul": "minier",
    "minierului": "minier",
    "min.": "minim",
    "minima": "minim",
    "minimă": "minim",
    "minime": "minim",
    "minimei": "minim",
    "minimele": "minim",
    "minimelor": "minim",
    "minimi": "minim",
    "minimii": "minim",
    "minimilor": "minim",
    "minimul": "minim",
    "minimului": "minim",
    "minimuri": "minim",
    "minimurile": "minim",
    "minimurilor": "minim",
    "minima": "minimă",
    "minime": "minimă",
    "minimei": "minimă",
    "minimele": "minimă",
    "minimelor": "minimă",
    "minimala": "minimal",
    "minimală": "minimal",
    "minimale": "minimal",
    "minimalei": "minimal",
    "minimalele": "minimal",
    "minimalelor": "minimal",
    "minimali": "minimal",
    "minimalii": "minimal",
    "minimalilor": "minimal",
    "minimalul": "minimal",
    "minimalului": "minimal",
    "minimaliză": "minimaliza",
    "minimalizai": "minimaliza",
    "minimalizam": "minimaliza",
    "minimalizăm": "minimaliza",
    "minimalizând": "minimaliza",
    "minimalizându": "minimaliza",
    "minimalizară": "minimaliza",
    "minimalizarăm": "minimaliza",
    "minimalizarăți": "minimaliza",
    "minimalizase": "minimaliza",
    "minimalizasem": "minimaliza",
    "minimalizaseră": "minimaliza",
    "minimalizaserăm": "minimaliza",
    "minimalizaserăți": "minimaliza",
    "minimalizaseși": "minimaliza",
    "minimalizași": "minimaliza",
    "minimalizat": "minimaliza",
    "minimalizați": "minimaliza",
    "minimalizatu": "minimaliza",
    "minimalizau": "minimaliza",
    "minimalizează": "minimaliza",
    "minimalizez": "minimaliza",
    "minimalizeze": "minimaliza",
    "minimalizezi": "minimaliza",
    "nemaiminimalizând": "minimaliza",
    "nemaiminimalizându": "minimaliza",
    "neminimalizând": "minimaliza",
    "neminimalizându": "minimaliza",
    "minimalizarea": "minimalizare",
    "minimalizareo": "minimalizare",
    "minimalizări": "minimalizare",
    "minimalizării": "minimalizare",
    "minimalizările": "minimalizare",
    "minimalizărilor": "minimalizare",
    "minimalizată": "minimalizat",
    "minimalizate": "minimalizat",
    "minimalizați": "minimalizat",
    "minimumul": "minimum",
    "minimumului": "minimum",
    "minirecitalul": "minirecital",
    "minirecitalului": "minirecital",
    "minirecitaluri": "minirecital",
    "minirecitalurile": "minirecital",
    "minirecitalurilor": "minirecital",
    "ministere": "minister",
    "ministerele": "minister",
    "ministerelor": "minister",
    "ministerul": "minister",
    "ministerului": "minister",
    "ministeriala": "ministerial",
    "ministerială": "ministerial",
    "ministeriale": "ministerial",
    "ministerialei": "ministerial",
    "ministerialele": "ministerial",
    "ministerialelor": "ministerial",
    "ministeriali": "ministerial",
    "ministerialii": "ministerial",
    "ministerialilor": "ministerial",
    "ministerialul": "ministerial",
    "ministerialului": "ministerial",
    "ministeriate": "ministeriat",
    "ministeriatele": "ministeriat",
    "ministeriatelor": "ministeriat",
    "ministeriatul": "ministeriat",
    "ministeriatului": "ministeriat",
    "Ministerului_Abundenței": "Ministerul_Abundenței",
    "M.A.I.": "Ministerul_Afacerilor_Interne",
    "MI": "Ministerul_de_Interne",
    "MEN": "Ministerul_Educației_Naționale",
    "Mî": "Ministerul_învățământului",
    "miniștri": "ministru",
    "miniștrii": "ministru",
    "miniștrilor": "ministru",
    "ministrul": "ministru",
    "ministrului": "ministru",
    "minii": "miniu",
    "miniile": "miniu",
    "miniilor": "miniu",
    "miniul": "miniu",
    "miniului": "miniu",
    "minora": "minor",
    "minoră": "minor",
    "minore": "minor",
    "minorei": "minor",
    "minorele": "minor",
    "minorelor": "minor",
    "minori": "minor",
    "minorii": "minor",
    "minorilor": "minor",
    "minorul": "minor",
    "minorului": "minor",
    "minoratul": "minorat",
    "minoratului": "minorat",
    "minoriți": "minorit",
    "minoriții": "minorit",
    "minoriților": "minorit",
    "minoritul": "minorit",
    "minoritului": "minorit",
    "minoritara": "minoritar",
    "minoritară": "minoritar",
    "minoritare": "minoritar",
    "minoritarei": "minoritar",
    "minoritarele": "minoritar",
    "minoritarelor": "minoritar",
    "minoritari": "minoritar",
    "minoritarii": "minoritar",
    "minoritarilor": "minoritar",
    "minoritarul": "minoritar",
    "minoritarului": "minoritar",
    "minoritara": "minoritară",
    "minoritare": "minoritară",
    "minoritarei": "minoritară",
    "minoritarele": "minoritară",
    "minoritarelor": "minoritară",
    "minoritatea": "minoritate",
    "minorități": "minoritate",
    "minorității": "minoritate",
    "minoritățile": "minoritate",
    "minorităților": "minoritate",
    "minotauri": "minotaur",
    "minotaurii": "minotaur",
    "minotaurilor": "minotaur",
    "minotaurul": "minotaur",
    "minotaurului": "minotaur",
    "mintala": "mintal",
    "mintală": "mintal",
    "mintale": "mintal",
    "mintalei": "mintal",
    "mintalele": "mintal",
    "mintalelor": "mintal",
    "mintali": "mintal",
    "mintalii": "mintal",
    "mintalilor": "mintal",
    "mintalul": "mintal",
    "mintalului": "mintal",
    "mintea": "minte",
    "minți": "minte",
    "minții": "minte",
    "mințile": "minte",
    "minților": "minte",
    "minteanul": "mintean",
    "minteanului": "mintean",
    "mintene": "mintean",
    "mintenele": "mintean",
    "mintenelor": "mintean",
    "mint": "minți",
    "mintă": "minți",
    "minte": "minți",
    "mințea": "minți",
    "mințeai": "minți",
    "mințeam": "minți",
    "mințeați": "minți",
    "mințeau": "minți",
    "minții": "minți",
    "mințim": "minți",
    "mințind": "minți",
    "mințindu": "minți",
    "mințiră": "minți",
    "mințirăm": "minți",
    "mințirăți": "minți",
    "mințise": "minți",
    "mințisem": "minți",
    "mințiseră": "minți",
    "mințiserăm": "minți",
    "mințiserăți": "minți",
    "mințiseși": "minți",
    "mințiși": "minți",
    "mințit": "minți",
    "mințiți": "minți",
    "mințitu": "minți",
    "nemaimințind": "minți",
    "nemaimințindu": "minți",
    "nemințind": "minți",
    "nemințindu": "minți",
    "mințită": "mințit",
    "mințite": "mințit",
    "mințiți": "mințit",
    "mintoasa": "mintos",
    "mintoasă": "mintos",
    "mintoase": "mintos",
    "mintoasei": "mintos",
    "mintoasele": "mintos",
    "mintoaselor": "mintos",
    "mintoși": "mintos",
    "mintoșii": "mintos",
    "mintoșilor": "mintos",
    "mintosul": "mintos",
    "mintosului": "mintos",
    "minună": "minuna",
    "minunai": "minuna",
    "minunam": "minuna",
    "minunăm": "minuna",
    "minunând": "minuna",
    "minunându": "minuna",
    "minunară": "minuna",
    "minunarăm": "minuna",
    "minunarăți": "minuna",
    "minunase": "minuna",
    "minunasem": "minuna",
    "minunaseră": "minuna",
    "minunaserăm": "minuna",
    "minunaserăți": "minuna",
    "minunaseși": "minuna",
    "minunași": "minuna",
    "minunat": "minuna",
    "minunați": "minuna",
    "minunatu": "minuna",
    "minunau": "minuna",
    "minunează": "minuna",
    "minunez": "minuna",
    "minuneze": "minuna",
    "minunezi": "minuna",
    "nemaiminunând": "minuna",
    "nemaiminunându": "minuna",
    "neminunând": "minuna",
    "neminunându": "minuna",
    "minunata": "minunat",
    "minunată": "minunat",
    "minunate": "minunat",
    "minunatei": "minunat",
    "minunatele": "minunat",
    "minunatelor": "minunat",
    "minunați": "minunat",
    "minunații": "minunat",
    "minunaților": "minunat",
    "minunatul": "minunat",
    "minunatului": "minunat",
    "minunăția": "minunăție",
    "minunăției": "minunăție",
    "minunății": "minunăție",
    "minunățiile": "minunăție",
    "minunățiilor": "minunăție",
    "minunea": "minune",
    "minuni": "minune",
    "minunii": "minune",
    "minunile": "minune",
    "minunilor": "minune",
    "minusul": "minus",
    "minusului": "minus",
    "minusuri": "minus",
    "minusurile": "minus",
    "minusurilor": "minus",
    "minuscula": "minuscul",
    "minusculă": "minuscul",
    "minuscule": "minuscul",
    "minusculei": "minuscul",
    "minusculele": "minuscul",
    "minusculelor": "minuscul",
    "minusculi": "minuscul",
    "minusculii": "minuscul",
    "minusculilor": "minuscul",
    "minusculul": "minuscul",
    "minusculului": "minuscul",
    "min.": "minut",
    "minu": "minut",
    "minu'": "minut",
    "minute": "minut",
    "minutele": "minut",
    "minutelor": "minut",
    "minutul": "minut",
    "minutului": "minut",
    "minutare": "minutar",
    "minutarele": "minutar",
    "minutarelor": "minutar",
    "minutarul": "minutar",
    "minutarului": "minutar",
    "m.": "minute",
    "minuțiozitatea": "minuțiozitate",
    "minuțiozități": "minuțiozitate",
    "minuțiozității": "minuțiozitate",
    "minuțiozitățile": "minuțiozitate",
    "minuțiozităților": "minuțiozitate",
    "mioapa": "mioapă",
    "mioape": "mioapă",
    "mioapei": "mioapă",
    "mioapele": "mioapă",
    "mioapelor": "mioapă",
    "mioara": "mioară",
    "mioare": "mioară",
    "mioarei": "mioară",
    "mioarele": "mioară",
    "mioarelor": "mioară",
    "miocardul": "miocard",
    "miocardului": "miocard",
    "miocardica": "miocardic",
    "miocardică": "miocardic",
    "miocardice": "miocardic",
    "miocardicei": "miocardic",
    "miocardicele": "miocardic",
    "miocardicelor": "miocardic",
    "miocardici": "miocardic",
    "miocardicii": "miocardic",
    "miocardicilor": "miocardic",
    "miocardico": "miocardic",
    "miocardicul": "miocardic",
    "miocardicule": "miocardic",
    "miocardicului": "miocardic",
    "miocardita": "miocardită",
    "miocardite": "miocardită",
    "miocarditei": "miocardită",
    "miocarditele": "miocardită",
    "miocarditelor": "miocardită",
    "miocenul": "miocen",
    "miocenului": "miocen",
    "miogenul": "miogen",
    "miogenului": "miogen",
    "miografe": "miograf",
    "miografele": "miograf",
    "miografelor": "miograf",
    "miograful": "miograf",
    "miografului": "miograf",
    "mioapa": "miop",
    "mioapă": "miop",
    "mioape": "miop",
    "mioapei": "miop",
    "mioapele": "miop",
    "mioapelor": "miop",
    "miopi": "miop",
    "miopii": "miop",
    "miopilor": "miop",
    "miopul": "miop",
    "miopului": "miop",
    "miopia": "miopie",
    "miopiei": "miopie",
    "miopii": "miopie",
    "miopiile": "miopie",
    "miopiilor": "miopie",
    "Mioriței": "Miorița",
    "miorlăita": "miorlăit",
    "miorlăită": "miorlăit",
    "miorlăite": "miorlăit",
    "miorlăitei": "miorlăit",
    "miorlăitele": "miorlăit",
    "miorlăitelor": "miorlăit",
    "miorlăiți": "miorlăit",
    "miorlăiții": "miorlăit",
    "miorlăiților": "miorlăit",
    "miorlăitul": "miorlăit",
    "miorlăitului": "miorlăit",
    "miozina": "miozină",
    "miozine": "miozină",
    "miozinei": "miozină",
    "miozinele": "miozină",
    "miozinelor": "miozină",
    "miozita": "miozită",
    "miozite": "miozită",
    "miozitei": "miozită",
    "miozitele": "miozită",
    "miozitelor": "miozită",
    "mirul": "mir",
    "mirului": "mir",
    "mir": "mira",
    "miră": "mira",
    "mirai": "mira",
    "miram": "mira",
    "mirăm": "mira",
    "mirând": "mira",
    "mirându": "mira",
    "mirară": "mira",
    "mirarăm": "mira",
    "mirarăți": "mira",
    "mirase": "mira",
    "mirasem": "mira",
    "miraseră": "mira",
    "miraserăm": "mira",
    "miraserăți": "mira",
    "miraseși": "mira",
    "mirași": "mira",
    "mirat": "mira",
    "mirați": "mira",
    "miratu": "mira",
    "mirau": "mira",
    "mire": "mira",
    "miri": "mira",
    "nemaimirând": "mira",
    "nemaimirându": "mira",
    "nemirând": "mira",
    "nemirându": "mira",
    "mira": "miră",
    "mire": "miră",
    "mirei": "miră",
    "mirele": "miră",
    "mirelor": "miră",
    "miracole": "miracol",
    "miracolele": "miracol",
    "miracolelor": "miracol",
    "miracolul": "miracol",
    "miracolului": "miracol",
    "miraculoasa": "miraculos",
    "miraculoasă": "miraculos",
    "miraculoase": "miraculos",
    "miraculoasei": "miraculos",
    "miraculoasele": "miraculos",
    "miraculoaselor": "miraculos",
    "miraculoși": "miraculos",
    "miraculoșii": "miraculos",
    "miraculoșilor": "miraculos",
    "miraculosul": "miraculos",
    "miraculosului": "miraculos",
    "miraje": "miraj",
    "mirajele": "miraj",
    "mirajelor": "miraj",
    "mirajul": "miraj",
    "mirajului": "miraj",
    "mirarea": "mirare",
    "mirări": "mirare",
    "mirării": "mirare",
    "mirată": "mirat",
    "mirate": "mirat",
    "mirați": "mirat",
    "M.": "Mircea",
    "mirele": "mire",
    "mirelui": "mire",
    "miri": "mire",
    "mirii": "mire",
    "mirilor": "mire",
    "mireana": "mirean",
    "mireană": "mirean",
    "mireanul": "mirean",
    "mireanului": "mirean",
    "mirene": "mirean",
    "mirenei": "mirean",
    "mirenele": "mirean",
    "mirenelor": "mirean",
    "mireni": "mirean",
    "mirenii": "mirean",
    "mirenilor": "mirean",
    "mireana": "mireană",
    "mirene": "mireană",
    "mirenei": "mireană",
    "mirenele": "mireană",
    "mirenelor": "mireană",
    "mireasa": "mireasă",
    "mirese": "mireasă",
    "miresei": "mireasă",
    "miresele": "mireasă",
    "mireselor": "mireasă",
    "mireasma": "mireasmă",
    "mireasmo": "mireasmă",
    "miresme": "mireasmă",
    "miresmei": "mireasmă",
    "miresmele": "mireasmă",
    "miresmelor": "mireasmă",
    "mireneasca": "mirenesc",
    "mirenească": "mirenesc",
    "mireneasco": "mirenesc",
    "mirenescul": "mirenesc",
    "mirenescule": "mirenesc",
    "mirenescului": "mirenesc",
    "mirenești": "mirenesc",
    "mireneștii": "mirenesc",
    "mireneștile": "mirenesc",
    "mireneștilor": "mirenesc",
    "miriada": "miriadă",
    "miriade": "miriadă",
    "miriadei": "miriadă",
    "miriadele": "miriadă",
    "miriadelor": "miriadă",
    "miriapode": "miriapod",
    "miriapodele": "miriapod",
    "miriapodelor": "miriapod",
    "miriapodul": "miriapod",
    "miriapodului": "miriapod",
    "mirifica": "mirific",
    "mirifică": "mirific",
    "mirifice": "mirific",
    "mirificei": "mirific",
    "mirificele": "mirific",
    "mirificelor": "mirific",
    "mirifici": "mirific",
    "mirificii": "mirific",
    "mirificilor": "mirific",
    "mirificul": "mirific",
    "mirificului": "mirific",
    "miriștea": "miriște",
    "miriști": "miriște",
    "miriștii": "miriște",
    "miriștile": "miriște",
    "miriștilor": "miriște",
    "mirodenia": "mirodenie",
    "mirodeniei": "mirodenie",
    "mirodenii": "mirodenie",
    "mirodeniile": "mirodenie",
    "mirodeniilor": "mirodenie",
    "mironosița": "mironosiță",
    "mironosițe": "mironosiță",
    "mironosiței": "mironosiță",
    "mironosițele": "mironosiță",
    "mironosițelor": "mironosiță",
    "mirosul": "miros",
    "mirosului": "miros",
    "mirosuri": "miros",
    "mirosurile": "miros",
    "mirosurilor": "miros",
    "miroasă": "mirosi",
    "miroase": "mirosi",
    "miros": "mirosi",
    "mirosea": "mirosi",
    "miroseai": "mirosi",
    "miroseam": "mirosi",
    "miroseați": "mirosi",
    "miroseau": "mirosi",
    "miroși": "mirosi",
    "mirosii": "mirosi",
    "mirosim": "mirosi",
    "mirosind": "mirosi",
    "mirosindu": "mirosi",
    "mirosiră": "mirosi",
    "mirosirăm": "mirosi",
    "mirosirăți": "mirosi",
    "mirosise": "mirosi",
    "mirosisem": "mirosi",
    "mirosiseră": "mirosi",
    "mirosiserăm": "mirosi",
    "mirosiserăți": "mirosi",
    "mirosiseși": "mirosi",
    "mirosiși": "mirosi",
    "mirosit": "mirosi",
    "mirosiți": "mirosi",
    "mirositu": "mirosi",
    "nemaimirosind": "mirosi",
    "nemaimirosindu": "mirosi",
    "nemirosind": "mirosi",
    "nemirosindu": "mirosi",
    "mirosită": "mirosit",
    "mirosite": "mirosit",
    "mirosiți": "mirosit",
    "mirositoare": "mirositor",
    "mirositoarea": "mirositor",
    "mirositoarei": "mirositor",
    "mirositoarele": "mirositor",
    "mirositoarelor": "mirositor",
    "mirositori": "mirositor",
    "mirositorii": "mirositor",
    "mirositorilor": "mirositor",
    "mirositorul": "mirositor",
    "mirositorului": "mirositor",
    "mirți": "mirt",
    "mirții": "mirt",
    "mirților": "mirt",
    "mirtul": "mirt",
    "mirtului": "mirt",
    "miruia": "mirui",
    "miruiai": "mirui",
    "miruiam": "mirui",
    "miruiască": "mirui",
    "miruiați": "mirui",
    "miruiau": "mirui",
    "miruiesc": "mirui",
    "miruiește": "mirui",
    "miruiești": "mirui",
    "miruii": "mirui",
    "miruim": "mirui",
    "miruind": "mirui",
    "miruindu": "mirui",
    "miruiră": "mirui",
    "miruirăm": "mirui",
    "miruirăți": "mirui",
    "miruise": "mirui",
    "miruisem": "mirui",
    "miruiseră": "mirui",
    "miruiserăm": "mirui",
    "miruiserăți": "mirui",
    "miruiseși": "mirui",
    "miruiși": "mirui",
    "miruit": "mirui",
    "miruiți": "mirui",
    "miruitu": "mirui",
    "nemaimiruind": "mirui",
    "nemaimiruindu": "mirui",
    "nemiruind": "mirui",
    "nemiruindu": "mirui",
    "miruită": "miruit",
    "miruite": "miruit",
    "miruiți": "miruit",
    "misa": "misă",
    "mise": "misă",
    "misei": "misă",
    "misele": "misă",
    "miselor": "misă",
    "misada": "misadă",
    "misade": "misadă",
    "misadei": "misadă",
    "misadele": "misadă",
    "misadelor": "misadă",
    "mișc": "mișca",
    "mișcă": "mișca",
    "mișcai": "mișca",
    "mișcam": "mișca",
    "mișcăm": "mișca",
    "mișcând": "mișca",
    "mișcându": "mișca",
    "mișcară": "mișca",
    "mișcarăm": "mișca",
    "mișcarăți": "mișca",
    "mișcase": "mișca",
    "mișcasem": "mișca",
    "mișcaseră": "mișca",
    "mișcaserăm": "mișca",
    "mișcaserăți": "mișca",
    "mișcaseși": "mișca",
    "mișcași": "mișca",
    "mișcat": "mișca",
    "mișcați": "mișca",
    "mișcatu": "mișca",
    "mișcau": "mișca",
    "miște": "mișca",
    "miști": "mișca",
    "nemaimișcând": "mișca",
    "nemaimișcându": "mișca",
    "nemișcând": "mișca",
    "nemișcându": "mișca",
    "mișcarea": "mișcare",
    "mișcări": "mișcare",
    "mișcării": "mișcare",
    "mișcările": "mișcare",
    "mișcărilor": "mișcare",
    "mișcata": "mișcat",
    "mișcată": "mișcat",
    "mișcate": "mișcat",
    "mișcatei": "mișcat",
    "mișcatele": "mișcat",
    "mișcatelor": "mișcat",
    "mișcați": "mișcat",
    "mișcații": "mișcat",
    "mișcaților": "mișcat",
    "mișcatul": "mișcat",
    "mișcatului": "mișcat",
    "mișcătoare": "mișcător",
    "mișcătoarea": "mișcător",
    "mișcătoarei": "mișcător",
    "mișcătoarele": "mișcător",
    "mișcătoarelor": "mișcător",
    "mișcători": "mișcător",
    "mișcătorii": "mișcător",
    "mișcătorilor": "mișcător",
    "mișcătorul": "mișcător",
    "mișcătorului": "mișcător",
    "miscibilitatea": "miscibilitate",
    "miscibilități": "miscibilitate",
    "miscibilității": "miscibilitate",
    "miscibilitățile": "miscibilitate",
    "miscibilităților": "miscibilitate",
    "mișeaua": "mișea",
    "mișele": "mișea",
    "mișelei": "mișea",
    "mișelele": "mișea",
    "mișelelor": "mișea",
    "mișea": "mișel",
    "mișeaua": "mișel",
    "mișei": "mișel",
    "mișeii": "mișel",
    "mișeilor": "mișel",
    "mișele": "mișel",
    "mișelei": "mișel",
    "mișelele": "mișel",
    "mișelelor": "mișel",
    "mișelul": "mișel",
    "mișelului": "mișel",
    "mișeleasca": "mișelesc",
    "mișelească": "mișelesc",
    "mișelescul": "mișelesc",
    "mișelescului": "mișelesc",
    "mișelești": "mișelesc",
    "mișeleștii": "mișelesc",
    "mișeleștile": "mișelesc",
    "mișeleștilor": "mișelesc",
    "mișelia": "mișelie",
    "mișeliei": "mișelie",
    "mișelii": "mișelie",
    "mișeliile": "mișelie",
    "mișeliilor": "mișelie",
    "mișelio": "mișelie",
    "misia": "misie",
    "misiei": "misie",
    "misii": "misie",
    "misiile": "misie",
    "misiilor": "misie",
    "misio": "misie",
    "mișina": "mișină",
    "mișine": "mișină",
    "mișinei": "mișină",
    "mișinele": "mișină",
    "mișinelor": "mișină",
    "misionari": "misionar",
    "misionarii": "misionar",
    "misionarilor": "misionar",
    "misionarul": "misionar",
    "misionarului": "misionar",
    "misiți": "misit",
    "misiții": "misit",
    "misiților": "misit",
    "misitul": "misit",
    "misitului": "misit",
    "misiunea": "misiune",
    "misiuni": "misiune",
    "misiunii": "misiune",
    "misiunile": "misiune",
    "misiunilor": "misiune",
    "misiva": "misivă",
    "misive": "misivă",
    "misivei": "misivă",
    "misivele": "misivă",
    "misivelor": "misivă",
    "mișmașul": "mișmaș",
    "mișmașului": "mișmaș",
    "mișmașuri": "mișmaș",
    "mișmașurile": "mișmaș",
    "mișmașurilor": "mișmaș",
    "mistere": "mister",
    "misterele": "mister",
    "misterelor": "mister",
    "misterul": "mister",
    "misterului": "mister",
    "Mr.": "mister",
    "misterioasa": "misterios",
    "misterioasă": "misterios",
    "misterioase": "misterios",
    "misterioasei": "misterios",
    "misterioasele": "misterios",
    "misterioaselor": "misterios",
    "misterioși": "misterios",
    "misterioșii": "misterios",
    "misterioșilor": "misterios",
    "misteriosul": "misterios",
    "misteriosului": "misterios",
    "misterii": "misteriu",
    "misteriile": "misteriu",
    "misteriilor": "misteriu",
    "misteriul": "misteriu",
    "misteriului": "misteriu",
    "mistica": "mistic",
    "mistică": "mistic",
    "mistice": "mistic",
    "misticei": "mistic",
    "misticele": "mistic",
    "misticelor": "mistic",
    "mistici": "mistic",
    "misticii": "mistic",
    "misticilor": "mistic",
    "misticul": "mistic",
    "misticului": "mistic",
    "mistica": "mistică",
    "mistice": "mistică",
    "misticei": "mistică",
    "misticele": "mistică",
    "misticelor": "mistică",
    "misticismul": "misticism",
    "misticismului": "misticism",
    "mistific": "mistifica",
    "mistifică": "mistifica",
    "mistificai": "mistifica",
    "mistificam": "mistifica",
    "mistificăm": "mistifica",
    "mistificând": "mistifica",
    "mistificându": "mistifica",
    "mistificară": "mistifica",
    "mistificarăm": "mistifica",
    "mistificarăți": "mistifica",
    "mistificase": "mistifica",
    "mistificasem": "mistifica",
    "mistificaseră": "mistifica",
    "mistificaserăm": "mistifica",
    "mistificaserăți": "mistifica",
    "mistificaseși": "mistifica",
    "mistificași": "mistifica",
    "mistificat": "mistifica",
    "mistificați": "mistifica",
    "mistificatu": "mistifica",
    "mistificau": "mistifica",
    "mistifice": "mistifica",
    "mistifici": "mistifica",
    "nemaimistificând": "mistifica",
    "nemaimistificându": "mistifica",
    "nemistificând": "mistifica",
    "nemistificându": "mistifica",
    "mistificarea": "mistificare",
    "mistificări": "mistificare",
    "mistificării": "mistificare",
    "mistificările": "mistificare",
    "mistificărilor": "mistificare",
    "mistificată": "mistificat",
    "mistificate": "mistificat",
    "mistificați": "mistificat",
    "mistralul": "mistral",
    "mistralului": "mistral",
    "Mrs.": "mistress",
    "mistreața": "mistreț",
    "mistreață": "mistreț",
    "mistrețe": "mistreț",
    "mistreței": "mistreț",
    "mistrețele": "mistreț",
    "mistrețelor": "mistreț",
    "mistreți": "mistreț",
    "mistreții": "mistreț",
    "mistreților": "mistreț",
    "mistrețul": "mistreț",
    "mistrețului": "mistreț",
    "mistria": "mistrie",
    "mistriei": "mistrie",
    "mistrii": "mistrie",
    "mistriile": "mistrie",
    "mistriilor": "mistrie",
    "mistuia": "mistui",
    "mistuiai": "mistui",
    "mistuiam": "mistui",
    "mistuiați": "mistui",
    "mistuiau": "mistui",
    "mistuie": "mistui",
    "mistuii": "mistui",
    "mistuim": "mistui",
    "mistuind": "mistui",
    "mistuindu": "mistui",
    "mistuiră": "mistui",
    "mistuirăm": "mistui",
    "mistuirăți": "mistui",
    "mistuise": "mistui",
    "mistuisem": "mistui",
    "mistuiseră": "mistui",
    "mistuiserăm": "mistui",
    "mistuiserăți": "mistui",
    "mistuiseși": "mistui",
    "mistuiși": "mistui",
    "mistuit": "mistui",
    "mistuiți": "mistui",
    "mistuitu": "mistui",
    "nemaimistuind": "mistui",
    "nemaimistuindu": "mistui",
    "nemistuind": "mistui",
    "nemistuindu": "mistui",
    "mistuită": "mistuit",
    "mistuite": "mistuit",
    "mistuiți": "mistuit",
    "mistuitoare": "mistuitor",
    "mistuitoarea": "mistuitor",
    "mistuitoarei": "mistuitor",
    "mistuitoarele": "mistuitor",
    "mistuitoarelor": "mistuitor",
    "mistuitori": "mistuitor",
    "mistuitorii": "mistuitor",
    "mistuitorilor": "mistuitor",
    "mistuitorul": "mistuitor",
    "mistuitorului": "mistuitor",
    "mișun": "mișuna",
    "mișună": "mișuna",
    "mișunai": "mișuna",
    "mișunam": "mișuna",
    "mișunăm": "mișuna",
    "mișunând": "mișuna",
    "mișunându": "mișuna",
    "mișunară": "mișuna",
    "mișunarăm": "mișuna",
    "mișunarăți": "mișuna",
    "mișunase": "mișuna",
    "mișunasem": "mișuna",
    "mișunaseră": "mișuna",
    "mișunaserăm": "mișuna",
    "mișunaserăți": "mișuna",
    "mișunaseși": "mișuna",
    "mișunași": "mișuna",
    "mișunat": "mișuna",
    "mișunați": "mișuna",
    "mișunatu": "mișuna",
    "mișunau": "mișuna",
    "mișune": "mișuna",
    "mișuni": "mișuna",
    "nemaimișunând": "mișuna",
    "nemaimișunându": "mișuna",
    "nemișunând": "mișuna",
    "nemișunându": "mișuna",
    "mișunată": "mișunat",
    "mișunate": "mișunat",
    "mișunați": "mișunat",
    "mitul": "mit",
    "mitului": "mit",
    "mituri": "mit",
    "miturile": "mit",
    "miturilor": "mit",
    "mita": "mită",
    "mite": "mită",
    "mitei": "mită",
    "mitele": "mită",
    "mitelor": "mită",
    "mița": "miță",
    "mițe": "miță",
    "miței": "miță",
    "mițele": "miță",
    "mițelor": "miță",
    "mitarnice": "mitarnic",
    "mitica": "mitic",
    "mitică": "mitic",
    "mitice": "mitic",
    "miticei": "mitic",
    "miticele": "mitic",
    "miticelor": "mitic",
    "mitici": "mitic",
    "miticii": "mitic",
    "miticilor": "mitic",
    "miticul": "mitic",
    "miticului": "mitic",
    "mitingul": "miting",
    "mitingului": "miting",
    "mitinguri": "miting",
    "mitingurile": "miting",
    "mitingurilor": "miting",
    "mitocani": "mitocan",
    "mitocanii": "mitocan",
    "mitocanilor": "mitocan",
    "mitocanul": "mitocan",
    "mitocanului": "mitocan",
    "mitocăneasca": "mitocănesc",
    "mitocănească": "mitocănesc",
    "mitocăneasco": "mitocănesc",
    "mitocănescul": "mitocănesc",
    "mitocănescule": "mitocănesc",
    "mitocănescului": "mitocănesc",
    "mitocănești": "mitocănesc",
    "mitocăneștii": "mitocănesc",
    "mitocăneștile": "mitocănesc",
    "mitocăneștilor": "mitocănesc",
    "mitologica": "mitologic",
    "mitologică": "mitologic",
    "mitologice": "mitologic",
    "mitologicei": "mitologic",
    "mitologicele": "mitologic",
    "mitologicelor": "mitologic",
    "mitologici": "mitologic",
    "mitologicii": "mitologic",
    "mitologicilor": "mitologic",
    "mitologicul": "mitologic",
    "mitologicului": "mitologic",
    "mit.": "mitologie",
    "mitol.": "mitologie",
    "mitologia": "mitologie",
    "mitologiei": "mitologie",
    "mitologii": "mitologie",
    "mitologiile": "mitologie",
    "mitologiilor": "mitologie",
    "mitra": "mitră",
    "mitre": "mitră",
    "mitrei": "mitră",
    "mitrele": "mitră",
    "mitrelor": "mitră",
    "mitrala": "mitral",
    "mitrală": "mitral",
    "mitrale": "mitral",
    "mitralei": "mitral",
    "mitralele": "mitral",
    "mitralelor": "mitral",
    "mitrala": "mitrală",
    "mitrale": "mitrală",
    "mitralei": "mitrală",
    "mitralele": "mitrală",
    "mitralelor": "mitrală",
    "mitraliai": "mitralia",
    "mitraliam": "mitralia",
    "mitraliară": "mitralia",
    "mitraliarăm": "mitralia",
    "mitraliarăți": "mitralia",
    "mitraliase": "mitralia",
    "mitraliasem": "mitralia",
    "mitraliaseră": "mitralia",
    "mitraliaserăm": "mitralia",
    "mitraliaserăți": "mitralia",
    "mitraliaseși": "mitralia",
    "mitraliași": "mitralia",
    "mitraliat": "mitralia",
    "mitraliați": "mitralia",
    "mitraliatu": "mitralia",
    "mitraliau": "mitralia",
    "mitraliază": "mitralia",
    "mitralie": "mitralia",
    "mitraliem": "mitralia",
    "mitraliez": "mitralia",
    "mitralieze": "mitralia",
    "mitraliezi": "mitralia",
    "mitraliind": "mitralia",
    "mitraliindu": "mitralia",
    "nemaimitraliind": "mitralia",
    "nemaimitraliindu": "mitralia",
    "nemitraliind": "mitralia",
    "nemitraliindu": "mitralia",
    "mitraliată": "mitraliat",
    "mitraliate": "mitraliat",
    "mitraliați": "mitraliat",
    "mitraliera": "mitralieră",
    "mitraliere": "mitralieră",
    "mitralierei": "mitralieră",
    "mitralierele": "mitralieră",
    "mitralierelor": "mitralieră",
    "mitraliori": "mitralior",
    "mitraliorii": "mitralior",
    "mitraliorilor": "mitralior",
    "mitraliorul": "mitralior",
    "mitraliorului": "mitralior",
    "mitropolia": "mitropolie",
    "mitropoliei": "mitropolie",
    "mitropolii": "mitropolie",
    "mitropoliile": "mitropolie",
    "mitropoliilor": "mitropolie",
    "mitropoliți": "mitropolit",
    "mitropoliții": "mitropolit",
    "mitropoliților": "mitropolit",
    "mitropolitul": "mitropolit",
    "mitropolitului": "mitropolit",
    "mitropolitana": "mitropolitan",
    "mitropolitană": "mitropolitan",
    "mitropolitane": "mitropolitan",
    "mitropolitanei": "mitropolitan",
    "mitropolitanele": "mitropolitan",
    "mitropolitanelor": "mitropolitan",
    "mitropolitani": "mitropolitan",
    "mitropolitanii": "mitropolitan",
    "mitropolitanilor": "mitropolitan",
    "mitropolitanul": "mitropolitan",
    "mitropolitanului": "mitropolitan",
    "mituia": "mitui",
    "mituiai": "mitui",
    "mituiam": "mitui",
    "mituiască": "mitui",
    "mituiați": "mitui",
    "mituiau": "mitui",
    "mituiesc": "mitui",
    "mituiește": "mitui",
    "mituiești": "mitui",
    "mituii": "mitui",
    "mituim": "mitui",
    "mituind": "mitui",
    "mituindu": "mitui",
    "mituiră": "mitui",
    "mituirăm": "mitui",
    "mituirăți": "mitui",
    "mituise": "mitui",
    "mituisem": "mitui",
    "mituiseră": "mitui",
    "mituiserăm": "mitui",
    "mituiserăți": "mitui",
    "mituiseși": "mitui",
    "mituiși": "mitui",
    "mituit": "mitui",
    "mituiți": "mitui",
    "mituitu": "mitui",
    "nemaimituind": "mitui",
    "nemaimituindu": "mitui",
    "nemituind": "mitui",
    "nemituindu": "mitui",
    "mituirea": "mituire",
    "mituiri": "mituire",
    "mituirii": "mituire",
    "mituirile": "mituire",
    "mituirilor": "mituire",
    "mituită": "mituit",
    "mituite": "mituit",
    "mituiți": "mituit",
    "mituitoare": "mituitor",
    "mituitoarea": "mituitor",
    "mituitoarei": "mituitor",
    "mituitoarele": "mituitor",
    "mituitoarelor": "mituitor",
    "mituitori": "mituitor",
    "mituitorii": "mituitor",
    "mituitorilor": "mituitor",
    "mituitorul": "mituitor",
    "mituitorului": "mituitor",
    "mixedemul": "mixedem",
    "mixedemului": "mixedem",
    "micști": "mixt",
    "micștii": "mixt",
    "micștilor": "mixt",
    "mixta": "mixt",
    "mixtă": "mixt",
    "mixte": "mixt",
    "mixtei": "mixt",
    "mixtele": "mixt",
    "mixtelor": "mixt",
    "mixtul": "mixt",
    "mixtului": "mixt",
    "mixtura": "mixtură",
    "mixturi": "mixtură",
    "mixturii": "mixtură",
    "mixturile": "mixtură",
    "mixturilor": "mixtură",
    "miză": "miza",
    "mizai": "miza",
    "mizam": "miza",
    "mizăm": "miza",
    "mizând": "miza",
    "mizându": "miza",
    "mizară": "miza",
    "mizarăm": "miza",
    "mizarăți": "miza",
    "mizase": "miza",
    "mizasem": "miza",
    "mizaseră": "miza",
    "mizaserăm": "miza",
    "mizaserăți": "miza",
    "mizaseși": "miza",
    "mizași": "miza",
    "mizat": "miza",
    "mizați": "miza",
    "mizatu": "miza",
    "mizau": "miza",
    "mizează": "miza",
    "mizez": "miza",
    "mizeze": "miza",
    "mizezi": "miza",
    "nemaimizând": "miza",
    "nemaimizându": "miza",
    "nemizând": "miza",
    "nemizându": "miza",
    "miza": "miză",
    "mize": "miză",
    "mizei": "miză",
    "mizele": "miză",
    "mizelor": "miză",
    "mizanscena": "mizanscenă",
    "mizanscene": "mizanscenă",
    "mizanscenei": "mizanscenă",
    "mizanscenele": "mizanscenă",
    "mizanscenelor": "mizanscenă",
    "mizantropi": "mizantrop",
    "mizantropii": "mizantrop",
    "mizantropilor": "mizantrop",
    "mizantropul": "mizantrop",
    "mizantropului": "mizantrop",
    "mizantropa": "mizantropă",
    "mizantrope": "mizantropă",
    "mizantropei": "mizantropă",
    "mizantropele": "mizantropă",
    "mizantropelor": "mizantropă",
    "mizantropia": "mizantropie",
    "mizantropiei": "mizantropie",
    "mizantropii": "mizantropie",
    "mizantropiile": "mizantropie",
    "mizantropiilor": "mizantropie",
    "mizată": "mizat",
    "mizate": "mizat",
    "mizați": "mizat",
    "mizera": "mizer",
    "mizeră": "mizer",
    "mizere": "mizer",
    "mizerei": "mizer",
    "mizerele": "mizer",
    "mizerelor": "mizer",
    "mizeri": "mizer",
    "mizerii": "mizer",
    "mizerilor": "mizer",
    "mizerul": "mizer",
    "mizerului": "mizer",
    "mizera": "mizeră",
    "mizere": "mizeră",
    "mizerei": "mizeră",
    "mizerele": "mizeră",
    "mizerelor": "mizeră",
    "mizerabila": "mizerabil",
    "mizerabilă": "mizerabil",
    "mizerabile": "mizerabil",
    "mizerabilei": "mizerabil",
    "mizerabilele": "mizerabil",
    "mizerabilelor": "mizerabil",
    "mizerabili": "mizerabil",
    "mizerabilii": "mizerabil",
    "mizerabililor": "mizerabil",
    "mizerabilul": "mizerabil",
    "mizerabilului": "mizerabil",
    "mizerabila": "mizerabilă",
    "mizerabile": "mizerabilă",
    "mizerabilei": "mizerabilă",
    "mizerabilele": "mizerabilă",
    "mizerabilelor": "mizerabilă",
    "mizericordia": "mizericordie",
    "mizericordiei": "mizericordie",
    "mizericordii": "mizericordie",
    "mizericordiile": "mizericordie",
    "mizericordiilor": "mizericordie",
    "mizeria": "mizerie",
    "mizeriei": "mizerie",
    "mizerii": "mizerie",
    "mizeriile": "mizerie",
    "mizeriilor": "mizerie",
    "mlada": "mladă",
    "mlăzi": "mladă",
    "mlăzii": "mladă",
    "mlăzile": "mladă",
    "mlăzilor": "mladă",
    "mlădiai": "mlădia",
    "mlădiam": "mlădia",
    "mlădiară": "mlădia",
    "mlădiarăm": "mlădia",
    "mlădiarăți": "mlădia",
    "mlădiase": "mlădia",
    "mlădiasem": "mlădia",
    "mlădiaseră": "mlădia",
    "mlădiaserăm": "mlădia",
    "mlădiaserăți": "mlădia",
    "mlădiaseși": "mlădia",
    "mlădiași": "mlădia",
    "mlădiat": "mlădia",
    "mlădiați": "mlădia",
    "mlădiatu": "mlădia",
    "mlădiau": "mlădia",
    "mlădiază": "mlădia",
    "mlădie": "mlădia",
    "mlădiem": "mlădia",
    "mlădiez": "mlădia",
    "mlădieze": "mlădia",
    "mlădiezi": "mlădia",
    "mlădiind": "mlădia",
    "mlădiindu": "mlădia",
    "nemaimlădiind": "mlădia",
    "nemaimlădiindu": "mlădia",
    "nemlădiind": "mlădia",
    "nemlădiindu": "mlădia",
    "mlădiată": "mlădiat",
    "mlădiate": "mlădiat",
    "mlădiați": "mlădiat",
    "mlădierea": "mlădiere",
    "mlădiereo": "mlădiere",
    "mlădieri": "mlădiere",
    "mlădierii": "mlădiere",
    "mlădierile": "mlădiere",
    "mlădierilor": "mlădiere",
    "mlădioasa": "mlădios",
    "mlădioasă": "mlădios",
    "mlădioase": "mlădios",
    "mlădioasei": "mlădios",
    "mlădioasele": "mlădios",
    "mlădioaselor": "mlădios",
    "mlădioși": "mlădios",
    "mlădioșii": "mlădios",
    "mlădioșilor": "mlădios",
    "mlădiosul": "mlădios",
    "mlădiosului": "mlădios",
    "mlădița": "mlădiță",
    "mlădițe": "mlădiță",
    "mlădiței": "mlădiță",
    "mlădițele": "mlădiță",
    "mlădițelor": "mlădiță",
    "mlădia": "mlădiu",
    "mlădie": "mlădiu",
    "mlădiei": "mlădiu",
    "mlădii": "mlădiu",
    "mlădiii": "mlădiu",
    "mlădiile": "mlădiu",
    "mlădiilor": "mlădiu",
    "mlădiul": "mlădiu",
    "mlădiului": "mlădiu",
    "mlaja": "mlajă",
    "mlăji": "mlajă",
    "mlăjii": "mlajă",
    "mlăjile": "mlajă",
    "mlăjilor": "mlajă",
    "mlaștina": "mlaștină",
    "mlaștini": "mlaștină",
    "mlaștinii": "mlaștină",
    "mlaștinile": "mlaștină",
    "mlaștinilor": "mlaștină",
    "mlăștinoasa": "mlăștinos",
    "mlăștinoasă": "mlăștinos",
    "mlăștinoase": "mlăștinos",
    "mlăștinoasei": "mlăștinos",
    "mlăștinoasele": "mlăștinos",
    "mlăștinoaselor": "mlăștinos",
    "mlăștinoși": "mlăștinos",
    "mlăștinoșii": "mlăștinos",
    "mlăștinoșilor": "mlăștinos",
    "mlăștinosul": "mlăștinos",
    "mlăștinosului": "mlăștinos",
    "mnemonica": "mnemonic",
    "mnemonică": "mnemonic",
    "mnemonice": "mnemonic",
    "mnemonicei": "mnemonic",
    "mnemonicele": "mnemonic",
    "mnemonicelor": "mnemonic",
    "mnemonici": "mnemonic",
    "mnemonicii": "mnemonic",
    "mnemonicilor": "mnemonic",
    "mnemonicul": "mnemonic",
    "mnemonicului": "mnemonic",
    "mnemotehnica": "mnemotehnic",
    "mnemotehnică": "mnemotehnic",
    "mnemotehnice": "mnemotehnic",
    "mnemotehnicei": "mnemotehnic",
    "mnemotehnicele": "mnemotehnic",
    "mnemotehnicelor": "mnemotehnic",
    "mnemotehnici": "mnemotehnic",
    "mnemotehnicii": "mnemotehnic",
    "mnemotehnicilor": "mnemotehnic",
    "mnemotehnicul": "mnemotehnic",
    "mnemotehnicului": "mnemotehnic",
    "mnemotehnica": "mnemotehnică",
    "mnemotehnici": "mnemotehnică",
    "mnemotehnicii": "mnemotehnică",
    "mnemotehnicile": "mnemotehnică",
    "mnemotehnicilor": "mnemotehnică",
    "moaca": "moacă",
    "moace": "moacă",
    "moacei": "moacă",
    "moacele": "moacă",
    "moacelor": "moacă",
    "moalea": "moale",
    "moalele": "moale",
    "moalelui": "moale",
    "moi": "moale",
    "moii": "moale",
    "moile": "moale",
    "moilor": "moale",
    "moarul": "moar",
    "moarului": "moar",
    "moaruri": "moar",
    "moarurile": "moar",
    "moarurilor": "moar",
    "moara": "moară",
    "mori": "moară",
    "morii": "moară",
    "morile": "moară",
    "morilor": "moară",
    "moarta": "moartă",
    "moarte": "moartă",
    "moartei": "moartă",
    "moartele": "moartă",
    "moartelor": "moartă",
    "moartea": "moarte",
    "morți": "moarte",
    "morții": "moarte",
    "morțile": "moarte",
    "morților": "moarte",
    "moașa": "moașă",
    "moașe": "moașă",
    "moașei": "moașă",
    "moașele": "moașă",
    "moașelor": "moașă",
    "moaștele": "moaște",
    "moaștelor": "moaște",
    "moața": "moață",
    "moațe": "moață",
    "moaței": "moață",
    "moațele": "moață",
    "moațelor": "moață",
    "moațo": "moață",
    "mobilă": "mobil",
    "mobile": "mobil",
    "mobili": "mobil",
    "mobilul": "mobil",
    "mobilului": "mobil",
    "mobilă": "mobila",
    "mobilai": "mobila",
    "mobilam": "mobila",
    "mobilăm": "mobila",
    "mobilând": "mobila",
    "mobilându": "mobila",
    "mobilară": "mobila",
    "mobilarăm": "mobila",
    "mobilarăți": "mobila",
    "mobilase": "mobila",
    "mobilasem": "mobila",
    "mobilaseră": "mobila",
    "mobilaserăm": "mobila",
    "mobilaserăți": "mobila",
    "mobilaseși": "mobila",
    "mobilași": "mobila",
    "mobilat": "mobila",
    "mobilați": "mobila",
    "mobilatu": "mobila",
    "mobilau": "mobila",
    "mobilează": "mobila",
    "mobilez": "mobila",
    "mobileze": "mobila",
    "mobilezi": "mobila",
    "nemaimobilând": "mobila",
    "nemaimobilându": "mobila",
    "nemobilând": "mobila",
    "nemobilându": "mobila",
    "mob.": "mobilă",
    "mobila": "mobilă",
    "mobile": "mobilă",
    "mobilele": "mobilă",
    "mobilelor": "mobilă",
    "mobilată": "mobilat",
    "mobilate": "mobilat",
    "mobilați": "mobilat",
    "mobiliara": "mobiliar",
    "mobiliară": "mobiliar",
    "mobiliare": "mobiliar",
    "mobiliarei": "mobiliar",
    "mobiliarele": "mobiliar",
    "mobiliarelor": "mobiliar",
    "mobiliari": "mobiliar",
    "mobiliarii": "mobiliar",
    "mobiliarilor": "mobiliar",
    "mobiliaro": "mobiliar",
    "mobiliarul": "mobiliar",
    "mobiliarule": "mobiliar",
    "mobiliarului": "mobiliar",
    "mobilierul": "mobilier",
    "mobilierului": "mobilier",
    "mobilitatea": "mobilitate",
    "mobilități": "mobilitate",
    "mobilității": "mobilitate",
    "mobilitățile": "mobilitate",
    "mobilităților": "mobilitate",
    "mobiliză": "mobiliza",
    "mobilizai": "mobiliza",
    "mobilizam": "mobiliza",
    "mobilizăm": "mobiliza",
    "mobilizând": "mobiliza",
    "mobilizându": "mobiliza",
    "mobilizară": "mobiliza",
    "mobilizarăm": "mobiliza",
    "mobilizarăți": "mobiliza",
    "mobilizase": "mobiliza",
    "mobilizasem": "mobiliza",
    "mobilizaseră": "mobiliza",
    "mobilizaserăm": "mobiliza",
    "mobilizaserăți": "mobiliza",
    "mobilizaseși": "mobiliza",
    "mobilizași": "mobiliza",
    "mobilizat": "mobiliza",
    "mobilizați": "mobiliza",
    "mobilizatu": "mobiliza",
    "mobilizau": "mobiliza",
    "mobilizează": "mobiliza",
    "mobilizez": "mobiliza",
    "mobilizeze": "mobiliza",
    "mobilizezi": "mobiliza",
    "nemaimobilizând": "mobiliza",
    "nemaimobilizându": "mobiliza",
    "nemobilizând": "mobiliza",
    "nemobilizându": "mobiliza",
    "mobilizabila": "mobilizabil",
    "mobilizabilă": "mobilizabil",
    "mobilizabile": "mobilizabil",
    "mobilizabilei": "mobilizabil",
    "mobilizabilele": "mobilizabil",
    "mobilizabilelor": "mobilizabil",
    "mobilizabili": "mobilizabil",
    "mobilizabilii": "mobilizabil",
    "mobilizabililor": "mobilizabil",
    "mobilizabilul": "mobilizabil",
    "mobilizabilului": "mobilizabil",
    "mobilizată": "mobilizat",
    "mobilizate": "mobilizat",
    "mobilizați": "mobilizat",
    "mobilizatoare": "mobilizator",
    "mobilizatoarea": "mobilizator",
    "mobilizatoarei": "mobilizator",
    "mobilizatoarele": "mobilizator",
    "mobilizatoarelor": "mobilizator",
    "mobilizatori": "mobilizator",
    "mobilizatorii": "mobilizator",
    "mobilizatorilor": "mobilizator",
    "mobilizatorul": "mobilizator",
    "mobilizatorului": "mobilizator",
    "mocăia": "mocăi",
    "mocăiai": "mocăi",
    "mocăiam": "mocăi",
    "mocăiască": "mocăi",
    "mocăiați": "mocăi",
    "mocăiau": "mocăi",
    "mocăiesc": "mocăi",
    "mocăiește": "mocăi",
    "mocăiești": "mocăi",
    "mocăii": "mocăi",
    "mocăim": "mocăi",
    "mocăind": "mocăi",
    "mocăindu": "mocăi",
    "mocăiră": "mocăi",
    "mocăirăm": "mocăi",
    "mocăirăți": "mocăi",
    "mocăise": "mocăi",
    "mocăisem": "mocăi",
    "mocăiseră": "mocăi",
    "mocăiserăm": "mocăi",
    "mocăiserăți": "mocăi",
    "mocăiseși": "mocăi",
    "mocăiși": "mocăi",
    "mocăit": "mocăi",
    "mocăiți": "mocăi",
    "mocăitu": "mocăi",
    "nemaimocăind": "mocăi",
    "nemaimocăindu": "mocăi",
    "nemocăind": "mocăi",
    "nemocăindu": "mocăi",
    "mocăita": "mocăit",
    "mocăită": "mocăit",
    "mocăite": "mocăit",
    "mocăitei": "mocăit",
    "mocăitele": "mocăit",
    "mocăitelor": "mocăit",
    "mocăiți": "mocăit",
    "mocăiții": "mocăit",
    "mocăiților": "mocăit",
    "mocăitul": "mocăit",
    "mocăitului": "mocăit",
    "mocani": "mocan",
    "mocanii": "mocan",
    "mocanilor": "mocan",
    "mocanul": "mocan",
    "mocanului": "mocan",
    "mocanca": "mocancă",
    "mocance": "mocancă",
    "mocancei": "mocancă",
    "mocancele": "mocancă",
    "mocancelor": "mocancă",
    "mocăneasca": "mocănesc",
    "mocănească": "mocănesc",
    "mocănescul": "mocănesc",
    "mocănescului": "mocănesc",
    "mocănești": "mocănesc",
    "mocăneștii": "mocănesc",
    "mocăneștile": "mocănesc",
    "mocăneștilor": "mocănesc",
    "mocănița": "mocăniță",
    "mocănițe": "mocăniță",
    "mocăniței": "mocăniță",
    "mocănițele": "mocăniță",
    "mocănițelor": "mocăniță",
    "mocârțani": "mocârțan",
    "mocârțanii": "mocârțan",
    "mocârțanilor": "mocârțan",
    "mocârțanul": "mocârțan",
    "mocârțanului": "mocârțan",
    "mocasini": "mocasin",
    "mocasinii": "mocasin",
    "mocasinilor": "mocasin",
    "mocasinul": "mocasin",
    "mocasinului": "mocasin",
    "mocheta": "mochetă",
    "mochete": "mochetă",
    "mochetei": "mochetă",
    "mochetele": "mochetă",
    "mochetelor": "mochetă",
    "mocirla": "mocirlă",
    "mocirle": "mocirlă",
    "mocirlei": "mocirlă",
    "mocirlele": "mocirlă",
    "mocirlelor": "mocirlă",
    "mocirloasa": "mocirlos",
    "mocirloasă": "mocirlos",
    "mocirloase": "mocirlos",
    "mocirloasei": "mocirlos",
    "mocirloasele": "mocirlos",
    "mocirloaselor": "mocirlos",
    "mocirloși": "mocirlos",
    "mocirloșii": "mocirlos",
    "mocirloșilor": "mocirlos",
    "mocirlosul": "mocirlos",
    "mocirlosului": "mocirlos",
    "mocnea": "mocni",
    "mocneai": "mocni",
    "mocneam": "mocni",
    "mocnească": "mocni",
    "mocneați": "mocni",
    "mocneau": "mocni",
    "mocnesc": "mocni",
    "mocnește": "mocni",
    "mocnești": "mocni",
    "mocnii": "mocni",
    "mocnim": "mocni",
    "mocnind": "mocni",
    "mocnindu": "mocni",
    "mocniră": "mocni",
    "mocnirăm": "mocni",
    "mocnirăți": "mocni",
    "mocnise": "mocni",
    "mocnisem": "mocni",
    "mocniseră": "mocni",
    "mocniserăm": "mocni",
    "mocniserăți": "mocni",
    "mocniseși": "mocni",
    "mocniși": "mocni",
    "mocnit": "mocni",
    "mocniți": "mocni",
    "mocnitu": "mocni",
    "nemaimocnind": "mocni",
    "nemaimocnindu": "mocni",
    "nemocnind": "mocni",
    "nemocnindu": "mocni",
    "mocnită": "mocnit",
    "mocnite": "mocnit",
    "mocniți": "mocnit",
    "mocofani": "mocofan",
    "mocofanii": "mocofan",
    "mocofanilor": "mocofan",
    "mocofanul": "mocofan",
    "mocofanului": "mocofan",
    "mocoșea": "mocoși",
    "mocoșeai": "mocoși",
    "mocoșeam": "mocoși",
    "mocoșească": "mocoși",
    "mocoșeați": "mocoși",
    "mocoșeau": "mocoși",
    "mocoșesc": "mocoși",
    "mocoșește": "mocoși",
    "mocoșești": "mocoși",
    "mocoșii": "mocoși",
    "mocoșim": "mocoși",
    "mocoșind": "mocoși",
    "mocoșindu": "mocoși",
    "mocoșiră": "mocoși",
    "mocoșirăm": "mocoși",
    "mocoșirăți": "mocoși",
    "mocoșise": "mocoși",
    "mocoșisem": "mocoși",
    "mocoșiseră": "mocoși",
    "mocoșiserăm": "mocoși",
    "mocoșiserăți": "mocoși",
    "mocoșiseși": "mocoși",
    "mocoșiși": "mocoși",
    "mocoșit": "mocoși",
    "mocoșiți": "mocoși",
    "mocoșitu": "mocoși",
    "nemaimocoșind": "mocoși",
    "nemaimocoșindu": "mocoși",
    "nemocoșind": "mocoși",
    "nemocoșindu": "mocoși",
    "mocoșita": "mocoșit",
    "mocoșită": "mocoșit",
    "mocoșite": "mocoșit",
    "mocoșitei": "mocoșit",
    "mocoșitele": "mocoșit",
    "mocoșitelor": "mocoșit",
    "mocoșiți": "mocoșit",
    "mocoșiții": "mocoșit",
    "mocoșiților": "mocoșit",
    "mocoșitul": "mocoșit",
    "mocoșitului": "mocoșit",
    "modul": "mod",
    "modului": "mod",
    "moduri": "mod",
    "modurile": "mod",
    "modurilor": "mod",
    "moda": "modă",
    "mode": "modă",
    "modei": "modă",
    "modele": "modă",
    "modelor": "modă",
    "modala": "modal",
    "modală": "modal",
    "modale": "modal",
    "modalei": "modal",
    "modalele": "modal",
    "modalelor": "modal",
    "modali": "modal",
    "modalii": "modal",
    "modalilor": "modal",
    "modalul": "modal",
    "modalului": "modal",
    "modalitatea": "modalitate",
    "modalități": "modalitate",
    "modalității": "modalitate",
    "modalitățile": "modalitate",
    "modalităților": "modalitate",
    "md.": "model",
    "modele": "model",
    "modelele": "model",
    "modelelor": "model",
    "modelul": "model",
    "modelului": "model",
    "modelă": "modela",
    "modelai": "modela",
    "modelam": "modela",
    "modelăm": "modela",
    "modelând": "modela",
    "modelându": "modela",
    "modelară": "modela",
    "modelarăm": "modela",
    "modelarăți": "modela",
    "modelase": "modela",
    "modelasem": "modela",
    "modelaseră": "modela",
    "modelaserăm": "modela",
    "modelaserăți": "modela",
    "modelaseși": "modela",
    "modelași": "modela",
    "modelat": "modela",
    "modelați": "modela",
    "modelatu": "modela",
    "modelau": "modela",
    "modelează": "modela",
    "modelez": "modela",
    "modeleze": "modela",
    "modelezi": "modela",
    "nemaimodelând": "modela",
    "nemaimodelându": "modela",
    "nemodelând": "modela",
    "nemodelându": "modela",
    "modelaje": "modelaj",
    "modelajele": "modelaj",
    "modelajelor": "modelaj",
    "modelajul": "modelaj",
    "modelajului": "modelaj",
    "modelată": "modelat",
    "modelate": "modelat",
    "modelați": "modelat",
    "moderă": "modera",
    "moderai": "modera",
    "moderam": "modera",
    "moderăm": "modera",
    "moderând": "modera",
    "moderându": "modera",
    "moderară": "modera",
    "moderarăm": "modera",
    "moderarăți": "modera",
    "moderase": "modera",
    "moderasem": "modera",
    "moderaseră": "modera",
    "moderaserăm": "modera",
    "moderaserăți": "modera",
    "moderaseși": "modera",
    "moderași": "modera",
    "moderat": "modera",
    "moderați": "modera",
    "moderatu": "modera",
    "moderau": "modera",
    "moderează": "modera",
    "moderez": "modera",
    "modereze": "modera",
    "moderezi": "modera",
    "nemaimoderând": "modera",
    "nemaimoderându": "modera",
    "nemoderând": "modera",
    "nemoderându": "modera",
    "moderantista": "moderantist",
    "moderantistă": "moderantist",
    "moderantiste": "moderantist",
    "moderantistei": "moderantist",
    "moderantistele": "moderantist",
    "moderantistelor": "moderantist",
    "moderantiști": "moderantist",
    "moderantiștii": "moderantist",
    "moderantiștilor": "moderantist",
    "moderantistul": "moderantist",
    "moderantistului": "moderantist",
    "moderată": "moderat",
    "moderate": "moderat",
    "moderați": "moderat",
    "moderația": "moderație",
    "moderației": "moderație",
    "moderații": "moderație",
    "moderatoarea": "moderatoare",
    "moderatoarei": "moderatoare",
    "moderatoarele": "moderatoare",
    "moderatoarelor": "moderatoare",
    "moderatoare": "moderator",
    "moderatoarea": "moderator",
    "moderatoarei": "moderator",
    "moderatoarele": "moderator",
    "moderatoarelor": "moderator",
    "moderatori": "moderator",
    "moderatorii": "moderator",
    "moderatorilor": "moderator",
    "moderatorul": "moderator",
    "moderatorului": "moderator",
    "moderna": "modern",
    "modernă": "modern",
    "moderne": "modern",
    "modernei": "modern",
    "modernele": "modern",
    "modernelor": "modern",
    "moderni": "modern",
    "modernii": "modern",
    "modernilor": "modern",
    "modernul": "modern",
    "modernului": "modern",
    "modernismul": "modernism",
    "modernismului": "modernism",
    "modernista": "modernist",
    "modernistă": "modernist",
    "moderniste": "modernist",
    "modernistei": "modernist",
    "modernistele": "modernist",
    "modernistelor": "modernist",
    "moderniști": "modernist",
    "moderniștii": "modernist",
    "moderniștilor": "modernist",
    "modernistul": "modernist",
    "modernistului": "modernist",
    "modernista": "modernistă",
    "moderniste": "modernistă",
    "modernistei": "modernistă",
    "modernistele": "modernistă",
    "modernistelor": "modernistă",
    "moderniză": "moderniza",
    "modernizai": "moderniza",
    "modernizam": "moderniza",
    "modernizăm": "moderniza",
    "modernizând": "moderniza",
    "modernizându": "moderniza",
    "modernizară": "moderniza",
    "modernizarăm": "moderniza",
    "modernizarăți": "moderniza",
    "modernizase": "moderniza",
    "modernizasem": "moderniza",
    "modernizaseră": "moderniza",
    "modernizaserăm": "moderniza",
    "modernizaserăți": "moderniza",
    "modernizaseși": "moderniza",
    "modernizași": "moderniza",
    "modernizat": "moderniza",
    "modernizați": "moderniza",
    "modernizatu": "moderniza",
    "modernizau": "moderniza",
    "modernizează": "moderniza",
    "modernizez": "moderniza",
    "modernizeze": "moderniza",
    "modernizezi": "moderniza",
    "nemaimodernizând": "moderniza",
    "nemaimodernizându": "moderniza",
    "nemodernizând": "moderniza",
    "nemodernizându": "moderniza",
    "modernizarea": "modernizare",
    "modernizări": "modernizare",
    "modernizării": "modernizare",
    "modernizările": "modernizare",
    "modernizărilor": "modernizare",
    "modernizată": "modernizat",
    "modernizate": "modernizat",
    "modernizați": "modernizat",
    "modernizatoare": "modernizator",
    "modernizatoarea": "modernizator",
    "modernizatoarei": "modernizator",
    "modernizatoarele": "modernizator",
    "modernizatoarelor": "modernizator",
    "modernizatori": "modernizator",
    "modernizatorii": "modernizator",
    "modernizatorilor": "modernizator",
    "modernizatorul": "modernizator",
    "modernizatorului": "modernizator",
    "modesta": "modest",
    "modestă": "modest",
    "modeste": "modest",
    "modestei": "modest",
    "modestele": "modest",
    "modestelor": "modest",
    "modești": "modest",
    "modeștii": "modest",
    "modeștilor": "modest",
    "modestul": "modest",
    "modestului": "modest",
    "modestia": "modestie",
    "modestiei": "modestie",
    "modestii": "modestie",
    "modica": "modic",
    "modică": "modic",
    "modice": "modic",
    "modicei": "modic",
    "modicele": "modic",
    "modicelor": "modic",
    "modici": "modic",
    "modicii": "modic",
    "modicilor": "modic",
    "modicul": "modic",
    "modicului": "modic",
    "modific": "modifica",
    "modifică": "modifica",
    "modificai": "modifica",
    "modificam": "modifica",
    "modificăm": "modifica",
    "modificând": "modifica",
    "modificându": "modifica",
    "modificară": "modifica",
    "modificarăm": "modifica",
    "modificarăți": "modifica",
    "modificase": "modifica",
    "modificasem": "modifica",
    "modificaseră": "modifica",
    "modificaserăm": "modifica",
    "modificaserăți": "modifica",
    "modificaseși": "modifica",
    "modificași": "modifica",
    "modificat": "modifica",
    "modificați": "modifica",
    "modificatu": "modifica",
    "modificau": "modifica",
    "modifice": "modifica",
    "modifici": "modifica",
    "nemaimodificând": "modifica",
    "nemaimodificându": "modifica",
    "nemodificând": "modifica",
    "nemodificându": "modifica",
    "modificabila": "modificabil",
    "modificabilă": "modificabil",
    "modificabile": "modificabil",
    "modificabilei": "modificabil",
    "modificabilele": "modificabil",
    "modificabilelor": "modificabil",
    "modificabili": "modificabil",
    "modificabilii": "modificabil",
    "modificabililor": "modificabil",
    "modificabilul": "modificabil",
    "modificabilului": "modificabil",
    "modificarea": "modificare",
    "modificări": "modificare",
    "modificării": "modificare",
    "modificările": "modificare",
    "modificărilor": "modificare",
    "modificată": "modificat",
    "modificate": "modificat",
    "modificați": "modificat",
    "modificatoare": "modificator",
    "modificatoarea": "modificator",
    "modificatoarei": "modificator",
    "modificatoarele": "modificator",
    "modificatoarelor": "modificator",
    "modificatori": "modificator",
    "modificatorii": "modificator",
    "modificatorilor": "modificator",
    "modificatorul": "modificator",
    "modificatorului": "modificator",
    "modista": "modistă",
    "modiste": "modistă",
    "modistei": "modistă",
    "modistele": "modistă",
    "modistelor": "modistă",
    "module": "modul",
    "modulele": "modul",
    "modulelor": "modul",
    "modulul": "modul",
    "modulului": "modul",
    "modulă": "modula",
    "modulai": "modula",
    "modulam": "modula",
    "modulăm": "modula",
    "modulând": "modula",
    "modulându": "modula",
    "modulară": "modula",
    "modularăm": "modula",
    "modularăți": "modula",
    "modulase": "modula",
    "modulasem": "modula",
    "modulaseră": "modula",
    "modulaserăm": "modula",
    "modulaserăți": "modula",
    "modulaseși": "modula",
    "modulași": "modula",
    "modulat": "modula",
    "modulați": "modula",
    "modulatu": "modula",
    "modulau": "modula",
    "modulează": "modula",
    "modulez": "modula",
    "moduleze": "modula",
    "modulezi": "modula",
    "nemaimodulând": "modula",
    "nemaimodulându": "modula",
    "nemodulând": "modula",
    "nemodulându": "modula",
    "modulara": "modular",
    "modulară": "modular",
    "modulare": "modular",
    "modularei": "modular",
    "modularele": "modular",
    "modularelor": "modular",
    "modulari": "modular",
    "modularii": "modular",
    "modularilor": "modular",
    "modularo": "modular",
    "modularul": "modular",
    "modularule": "modular",
    "modularului": "modular",
    "modulată": "modulat",
    "modulate": "modulat",
    "modulați": "modulat",
    "modulația": "modulație",
    "modulației": "modulație",
    "modulații": "modulație",
    "modulațiile": "modulație",
    "modulațiilor": "modulație",
    "module-pilot": "modul-pilot",
    "mofeta": "mofetă",
    "mofete": "mofetă",
    "mofetei": "mofetă",
    "mofetele": "mofetă",
    "mofetelor": "mofetă",
    "mofetica": "mofetic",
    "mofetică": "mofetic",
    "mofetice": "mofetic",
    "mofeticei": "mofetic",
    "mofeticele": "mofetic",
    "mofeticelor": "mofetic",
    "mofetici": "mofetic",
    "mofeticii": "mofetic",
    "mofeticilor": "mofetic",
    "mofeticul": "mofetic",
    "mofeticului": "mofetic",
    "mofluza": "mofluz",
    "mofluză": "mofluz",
    "mofluze": "mofluz",
    "mofluzei": "mofluz",
    "mofluzele": "mofluz",
    "mofluzelor": "mofluz",
    "mofluzi": "mofluz",
    "mofluzii": "mofluz",
    "mofluzilor": "mofluz",
    "mofluzul": "mofluz",
    "mofluzului": "mofluz",
    "moftul": "moft",
    "moftului": "moft",
    "mofturi": "moft",
    "mofturile": "moft",
    "mofturilor": "moft",
    "moftangioaica": "moftangioaică",
    "moftangioaice": "moftangioaică",
    "moftangioaicei": "moftangioaică",
    "moftangioaicele": "moftangioaică",
    "moftangioaicelor": "moftangioaică",
    "moftangii": "moftangiu",
    "moftangiii": "moftangiu",
    "moftangiilor": "moftangiu",
    "moftangiul": "moftangiu",
    "moftangiului": "moftangiu",
    "mofturoasa": "mofturoasă",
    "mofturoase": "mofturoasă",
    "mofturoasei": "mofturoasă",
    "mofturoasele": "mofturoasă",
    "mofturoaselor": "mofturoasă",
    "mofturoasa": "mofturos",
    "mofturoasă": "mofturos",
    "mofturoase": "mofturos",
    "mofturoasei": "mofturos",
    "mofturoasele": "mofturos",
    "mofturoaselor": "mofturos",
    "mofturoși": "mofturos",
    "mofturoșii": "mofturos",
    "mofturoșilor": "mofturos",
    "mofturosul": "mofturos",
    "mofturosului": "mofturos",
    "mogâldeața": "mogâldeață",
    "mogâldețe": "mogâldeață",
    "mogâldeței": "mogâldeață",
    "mogâldețele": "mogâldeață",
    "mogâldețelor": "mogâldeață",
    "mogula": "mogul",
    "mogulă": "mogul",
    "mogule": "mogul",
    "mogulei": "mogul",
    "mogulele": "mogul",
    "mogulelor": "mogul",
    "moguli": "mogul",
    "mogulii": "mogul",
    "mogulilor": "mogul",
    "mogulul": "mogul",
    "mogulului": "mogul",
    "mogula": "mogulă",
    "mogule": "mogulă",
    "mogulei": "mogulă",
    "mogulele": "mogulă",
    "mogulelor": "mogulă",
    "mohairul": "mohair",
    "mohairului": "mohair",
    "mohairuri": "mohair",
    "mohairurile": "mohair",
    "mohairurilor": "mohair",
    "mohorul": "mohor",
    "mohorului": "mohor",
    "mohorâta": "mohorât",
    "mohorâtă": "mohorât",
    "mohorâte": "mohorât",
    "mohorâtei": "mohorât",
    "mohorâtele": "mohorât",
    "mohorâtelor": "mohorât",
    "mohorâți": "mohorât",
    "mohorâții": "mohorât",
    "mohorâților": "mohorât",
    "mohorâtul": "mohorât",
    "mohorâtului": "mohorât",
    "mohoria": "mohoriu",
    "mohorie": "mohoriu",
    "mohoriei": "mohoriu",
    "mohorii": "mohoriu",
    "mohoriii": "mohoriu",
    "mohoriile": "mohoriu",
    "mohoriilor": "mohoriu",
    "mohoriul": "mohoriu",
    "mohoriului": "mohoriu",
    "moina": "moină",
    "moine": "moină",
    "moinei": "moină",
    "moinele": "moină",
    "moinelor": "moină",
    "Moirele": "Moiră",
    "mojare": "mojar",
    "mojarele": "mojar",
    "mojarelor": "mojar",
    "mojarul": "mojar",
    "mojarului": "mojar",
    "mojdreanul": "mojdrean",
    "mojdreanului": "mojdrean",
    "mojdreni": "mojdrean",
    "mojdrenii": "mojdrean",
    "mojdrenilor": "mojdrean",
    "mojica": "mojic",
    "mojică": "mojic",
    "mojice": "mojic",
    "mojicei": "mojic",
    "mojicele": "mojic",
    "mojicelor": "mojic",
    "mojici": "mojic",
    "mojicii": "mojic",
    "mojicilor": "mojic",
    "mojicul": "mojic",
    "mojicului": "mojic",
    "mojica": "mojică",
    "mojice": "mojică",
    "mojicei": "mojică",
    "mojicele": "mojică",
    "mojicelor": "mojică",
    "mojiceasca": "mojicesc",
    "mojicească": "mojicesc",
    "mojicescul": "mojicesc",
    "mojicescului": "mojicesc",
    "mojicești": "mojicesc",
    "mojiceștii": "mojicesc",
    "mojiceștile": "mojicesc",
    "mojiceștilor": "mojicesc",
    "mojicoasa": "mojicos",
    "mojicoasă": "mojicos",
    "mojicoase": "mojicos",
    "mojicoasei": "mojicos",
    "mojicoasele": "mojicos",
    "mojicoaselor": "mojicos",
    "mojicoși": "mojicos",
    "mojicoșii": "mojicos",
    "mojicoșilor": "mojicos",
    "mojicosul": "mojicos",
    "mojicosului": "mojicos",
    "moli": "mol",
    "molii": "mol",
    "molilor": "mol",
    "molul": "mol",
    "molului": "mol",
    "moluri": "mol",
    "molurile": "mol",
    "molurilor": "mol",
    "molani": "molan",
    "molanii": "molan",
    "molanilor": "molan",
    "molanul": "molan",
    "molanului": "molan",
    "molara": "molar",
    "molară": "molar",
    "molare": "molar",
    "molarei": "molar",
    "molarele": "molar",
    "molarelor": "molar",
    "molari": "molar",
    "molarii": "molar",
    "molarilor": "molar",
    "molarul": "molar",
    "molarului": "molar",
    "molasa": "molasă",
    "molase": "molasă",
    "molasei": "molasă",
    "molasele": "molasă",
    "molaselor": "molasă",
    "molateca": "molatec",
    "molatecă": "molatec",
    "molatece": "molatec",
    "molatecei": "molatec",
    "molatecele": "molatec",
    "molatecelor": "molatec",
    "molateci": "molatec",
    "molatecii": "molatec",
    "molatecilor": "molatec",
    "molatecul": "molatec",
    "molatecului": "molatec",
    "molatica": "molatic",
    "molatică": "molatic",
    "molatice": "molatic",
    "molaticei": "molatic",
    "molaticele": "molatic",
    "molaticelor": "molatic",
    "molatici": "molatic",
    "molaticii": "molatic",
    "molaticilor": "molatic",
    "molaticul": "molatic",
    "molaticului": "molatic",
    "molcoma": "molcom",
    "molcomă": "molcom",
    "molcome": "molcom",
    "molcomei": "molcom",
    "molcomele": "molcom",
    "molcomelor": "molcom",
    "molcomi": "molcom",
    "molcomii": "molcom",
    "molcomilor": "molcom",
    "molcomul": "molcom",
    "molcomului": "molcom",
    "molcomea": "molcomi",
    "molcomeai": "molcomi",
    "molcomeam": "molcomi",
    "molcomească": "molcomi",
    "molcomeați": "molcomi",
    "molcomeau": "molcomi",
    "molcomesc": "molcomi",
    "molcomește": "molcomi",
    "molcomești": "molcomi",
    "molcomii": "molcomi",
    "molcomim": "molcomi",
    "molcomind": "molcomi",
    "molcomindu": "molcomi",
    "molcomiră": "molcomi",
    "molcomirăm": "molcomi",
    "molcomirăți": "molcomi",
    "molcomise": "molcomi",
    "molcomisem": "molcomi",
    "molcomiseră": "molcomi",
    "molcomiserăm": "molcomi",
    "molcomiserăți": "molcomi",
    "molcomiseși": "molcomi",
    "molcomiși": "molcomi",
    "molcomit": "molcomi",
    "molcomiți": "molcomi",
    "molcomitu": "molcomi",
    "nemaimolcomind": "molcomi",
    "nemaimolcomindu": "molcomi",
    "nemolcomind": "molcomi",
    "nemolcomindu": "molcomi",
    "molcomită": "molcomit",
    "molcomite": "molcomit",
    "molcomiți": "molcomit",
    "molcomitoare": "molcomitor",
    "molcomitoarea": "molcomitor",
    "molcomitoarei": "molcomitor",
    "molcomitoarele": "molcomitor",
    "molcomitoarelor": "molcomitor",
    "molcomitori": "molcomitor",
    "molcomitorii": "molcomitor",
    "molcomitorilor": "molcomitor",
    "molcomitorul": "molcomitor",
    "molcomitorului": "molcomitor",
    "moldava": "moldav",
    "moldavă": "moldav",
    "moldave": "moldav",
    "moldavei": "moldav",
    "moldavele": "moldav",
    "moldavelor": "moldav",
    "moldavi": "moldav",
    "moldavii": "moldav",
    "moldavilor": "moldav",
    "moldavul": "moldav",
    "moldavului": "moldav",
    "Moldovă": "Moldova",
    "Moldove": "Moldova",
    "Moldovei": "Moldova",
    "moldoveana": "moldovean",
    "moldoveană": "moldovean",
    "moldoveanul": "moldovean",
    "moldoveanului": "moldovean",
    "moldovene": "moldovean",
    "moldovenei": "moldovean",
    "moldovenele": "moldovean",
    "moldovenelor": "moldovean",
    "moldoveni": "moldovean",
    "moldovenii": "moldovean",
    "moldovenilor": "moldovean",
    "moldoveana": "moldoveană",
    "moldovene": "moldoveană",
    "moldovenei": "moldoveană",
    "moldovenele": "moldoveană",
    "moldovenelor": "moldoveană",
    "moldoveanca": "moldoveancă",
    "moldovence": "moldoveancă",
    "moldovencei": "moldoveancă",
    "moldovencele": "moldoveancă",
    "moldovencelor": "moldoveancă",
    "moldoveneasca": "moldovenesc",
    "moldovenească": "moldovenesc",
    "moldovenescul": "moldovenesc",
    "moldovenescului": "moldovenesc",
    "moldovenești": "moldovenesc",
    "moldoveneștii": "moldovenesc",
    "moldoveneștile": "moldovenesc",
    "moldoveneștilor": "moldovenesc",
    "molecula": "moleculă",
    "molecule": "moleculă",
    "moleculei": "moleculă",
    "moleculele": "moleculă",
    "moleculelor": "moleculă",
    "moleculara": "molecular",
    "moleculară": "molecular",
    "moleculare": "molecular",
    "molecularei": "molecular",
    "molecularele": "molecular",
    "molecularelor": "molecular",
    "moleculari": "molecular",
    "molecularii": "molecular",
    "molecularilor": "molecular",
    "molecularul": "molecular",
    "molecularului": "molecular",
    "moleșeala": "moleșeală",
    "moleșeli": "moleșeală",
    "moleșelii": "moleșeală",
    "moleșea": "moleși",
    "moleșeai": "moleși",
    "moleșeam": "moleși",
    "moleșească": "moleși",
    "moleșeați": "moleși",
    "moleșeau": "moleși",
    "moleșesc": "moleși",
    "moleșește": "moleși",
    "moleșești": "moleși",
    "moleșii": "moleși",
    "moleșim": "moleși",
    "moleșind": "moleși",
    "moleșindu": "moleși",
    "moleșiră": "moleși",
    "moleșirăm": "moleși",
    "moleșirăți": "moleși",
    "moleșise": "moleși",
    "moleșisem": "moleși",
    "moleșiseră": "moleși",
    "moleșiserăm": "moleși",
    "moleșiserăți": "moleși",
    "moleșiseși": "moleși",
    "moleșiși": "moleși",
    "moleșit": "moleși",
    "moleșiți": "moleși",
    "moleșitu": "moleși",
    "nemaimoleșind": "moleși",
    "nemaimoleșindu": "moleși",
    "nemoleșind": "moleși",
    "nemoleșindu": "moleși",
    "moleșită": "moleșit",
    "moleșite": "moleșit",
    "moleșiți": "moleșit",
    "moleșitoare": "moleșitor",
    "moleșitoarea": "moleșitor",
    "moleșitoarei": "moleșitor",
    "moleșitoarele": "moleșitor",
    "moleșitoarelor": "moleșitor",
    "moleșitori": "moleșitor",
    "moleșitorii": "moleșitor",
    "moleșitorilor": "moleșitor",
    "moleșitorul": "moleșitor",
    "moleșitorului": "moleșitor",
    "molestă": "molesta",
    "molestai": "molesta",
    "molestam": "molesta",
    "molestăm": "molesta",
    "molestând": "molesta",
    "molestându": "molesta",
    "molestară": "molesta",
    "molestarăm": "molesta",
    "molestarăți": "molesta",
    "molestase": "molesta",
    "molestasem": "molesta",
    "molestaseră": "molesta",
    "molestaserăm": "molesta",
    "molestaserăți": "molesta",
    "molestaseși": "molesta",
    "molestași": "molesta",
    "molestat": "molesta",
    "molestați": "molesta",
    "molestatu": "molesta",
    "molestau": "molesta",
    "molestează": "molesta",
    "molestez": "molesta",
    "molesteze": "molesta",
    "molestezi": "molesta",
    "nemaimolestând": "molesta",
    "nemaimolestându": "molesta",
    "nemolestând": "molesta",
    "nemolestându": "molesta",
    "molestată": "molestat",
    "molestate": "molestat",
    "molestați": "molestat",
    "moleta": "moletă",
    "molete": "moletă",
    "moletei": "moletă",
    "moletele": "moletă",
    "moletelor": "moletă",
    "moletiera": "moletieră",
    "moletiere": "moletieră",
    "moletierei": "moletieră",
    "moletierele": "moletieră",
    "moletierelor": "moletieră",
    "molfăia": "molfăi",
    "molfăiai": "molfăi",
    "molfăiam": "molfăi",
    "molfăiați": "molfăi",
    "molfăiau": "molfăi",
    "molfăie": "molfăi",
    "molfăii": "molfăi",
    "molfăim": "molfăi",
    "molfăind": "molfăi",
    "molfăindu": "molfăi",
    "molfăiră": "molfăi",
    "molfăirăm": "molfăi",
    "molfăirăți": "molfăi",
    "molfăise": "molfăi",
    "molfăisem": "molfăi",
    "molfăiseră": "molfăi",
    "molfăiserăm": "molfăi",
    "molfăiserăți": "molfăi",
    "molfăiseși": "molfăi",
    "molfăiși": "molfăi",
    "molfăit": "molfăi",
    "molfăiți": "molfăi",
    "molfăitu": "molfăi",
    "nemaimolfăind": "molfăi",
    "nemaimolfăindu": "molfăi",
    "nemolfăind": "molfăi",
    "nemolfăindu": "molfăi",
    "molfăită": "molfăit",
    "molfăite": "molfăit",
    "molfăiți": "molfăit",
    "Mo": "molibden",
    "molibdenul": "molibden",
    "molibdenului": "molibden",
    "moliciunea": "moliciune",
    "moliciuni": "moliciune",
    "moliciunii": "moliciune",
    "moliciunile": "moliciune",
    "moliciunilor": "moliciune",
    "molidul": "molid",
    "molidului": "molid",
    "molizi": "molid",
    "molizii": "molid",
    "molizilor": "molid",
    "molia": "molie",
    "moliei": "molie",
    "molii": "molie",
    "moliile": "molie",
    "moliilor": "molie",
    "molia-de-câmp": "molie-de-câmp",
    "molia-de-casă": "molie-de-casă",
    "molia-de-pământ": "molie-de-pământ",
    "molima": "molimă",
    "molime": "molimă",
    "molimei": "molimă",
    "molimele": "molimă",
    "molimelor": "molimă",
    "molipsea": "molipsi",
    "molipseai": "molipsi",
    "molipseam": "molipsi",
    "molipsească": "molipsi",
    "molipseați": "molipsi",
    "molipseau": "molipsi",
    "molipsesc": "molipsi",
    "molipsește": "molipsi",
    "molipsești": "molipsi",
    "molipsii": "molipsi",
    "molipsim": "molipsi",
    "molipsind": "molipsi",
    "molipsindu": "molipsi",
    "molipsiră": "molipsi",
    "molipsirăm": "molipsi",
    "molipsirăți": "molipsi",
    "molipsise": "molipsi",
    "molipsisem": "molipsi",
    "molipsiseră": "molipsi",
    "molipsiserăm": "molipsi",
    "molipsiserăți": "molipsi",
    "molipsiseși": "molipsi",
    "molipsiși": "molipsi",
    "molipsit": "molipsi",
    "molipsiți": "molipsi",
    "molipsitu": "molipsi",
    "nemaimolipsind": "molipsi",
    "nemaimolipsindu": "molipsi",
    "nemolipsind": "molipsi",
    "nemolipsindu": "molipsi",
    "molipsită": "molipsit",
    "molipsite": "molipsit",
    "molipsiți": "molipsit",
    "molipsitoare": "molipsitor",
    "molipsitoarea": "molipsitor",
    "molipsitoarei": "molipsitor",
    "molipsitoarele": "molipsitor",
    "molipsitoarelor": "molipsitor",
    "molipsitori": "molipsitor",
    "molipsitorii": "molipsitor",
    "molipsitorilor": "molipsitor",
    "molipsitorul": "molipsitor",
    "molipsitorului": "molipsitor",
    "molitva": "molitvă",
    "molitve": "molitvă",
    "molitvei": "molitvă",
    "molitvele": "molitvă",
    "molitvelor": "molitvă",
    "molitvelnice": "molitvelnic",
    "molitvelnicele": "molitvelnic",
    "molitvelnicelor": "molitvelnic",
    "molitvelnicul": "molitvelnic",
    "molitvelnicului": "molitvelnic",
    "molotri": "molotru",
    "molotrii": "molotru",
    "molotrilor": "molotru",
    "molotrul": "molotru",
    "molotrului": "molotru",
    "molozul": "moloz",
    "molozului": "moloz",
    "moltonul": "molton",
    "moltonului": "molton",
    "molura": "molură",
    "moluri": "molură",
    "molurii": "molură",
    "molurile": "molură",
    "molurilor": "molură",
    "molusca": "moluscă",
    "moluște": "moluscă",
    "moluștei": "moluscă",
    "moluștele": "moluscă",
    "moluștelor": "moluscă",
    "momâi": "momâie",
    "momâia": "momâie",
    "momâii": "momâie",
    "momâile": "momâie",
    "momâilor": "momâie",
    "momeala": "momeală",
    "momele": "momeală",
    "momelei": "momeală",
    "momelele": "momeală",
    "momelelor": "momeală",
    "momente": "moment",
    "momentele": "moment",
    "momentelor": "moment",
    "momentul": "moment",
    "momentului": "moment",
    "momentana": "momentan",
    "momentană": "momentan",
    "momentane": "momentan",
    "momentanei": "momentan",
    "momentanele": "momentan",
    "momentanelor": "momentan",
    "momentani": "momentan",
    "momentanii": "momentan",
    "momentanilor": "momentan",
    "momentanul": "momentan",
    "momentanului": "momentan",
    "momente-cheie": "moment-cheie",
    "momea": "momi",
    "momeai": "momi",
    "momeam": "momi",
    "momească": "momi",
    "momeați": "momi",
    "momeau": "momi",
    "momesc": "momi",
    "momește": "momi",
    "momești": "momi",
    "momii": "momi",
    "momim": "momi",
    "momind": "momi",
    "momindu": "momi",
    "momiră": "momi",
    "momirăm": "momi",
    "momirăți": "momi",
    "momise": "momi",
    "momisem": "momi",
    "momiseră": "momi",
    "momiserăm": "momi",
    "momiserăți": "momi",
    "momiseși": "momi",
    "momiși": "momi",
    "momit": "momi",
    "momiți": "momi",
    "momitu": "momi",
    "nemaimomind": "momi",
    "nemaimomindu": "momi",
    "nemomind": "momi",
    "nemomindu": "momi",
    "momirea": "momire",
    "momireo": "momire",
    "momiri": "momire",
    "momirii": "momire",
    "momirile": "momire",
    "momirilor": "momire",
    "momită": "momit",
    "momite": "momit",
    "momiți": "momit",
    "momița": "momiță",
    "momițe": "momiță",
    "momiței": "momiță",
    "momițele": "momiță",
    "momițelor": "momiță",
    "momitoare": "momitor",
    "momitoarea": "momitor",
    "momitoarei": "momitor",
    "momitoarele": "momitor",
    "momitoarelor": "momitor",
    "momitori": "momitor",
    "momitorii": "momitor",
    "momitorilor": "momitor",
    "momitorul": "momitor",
    "momitorului": "momitor",
    "monada": "monadă",
    "monade": "monadă",
    "monadei": "monadă",
    "monadele": "monadă",
    "monadelor": "monadă",
    "monahi": "monah",
    "monahii": "monah",
    "monahilor": "monah",
    "monahul": "monah",
    "monahului": "monah",
    "monahala": "monahal",
    "monahală": "monahal",
    "monahale": "monahal",
    "monahalei": "monahal",
    "monahalele": "monahal",
    "monahalelor": "monahal",
    "monahali": "monahal",
    "monahalii": "monahal",
    "monahalilor": "monahal",
    "monahalul": "monahal",
    "monahalului": "monahal",
    "monahiceasca": "monahicesc",
    "monahicească": "monahicesc",
    "monahicescul": "monahicesc",
    "monahicescului": "monahicesc",
    "monahicești": "monahicesc",
    "monahiceștii": "monahicesc",
    "monahiceștile": "monahicesc",
    "monahiceștilor": "monahicesc",
    "monahia": "monahie",
    "monahiei": "monahie",
    "monahii": "monahie",
    "monahiile": "monahie",
    "monahiilor": "monahie",
    "monahio": "monahie",
    "monahismul": "monahism",
    "monahismule": "monahism",
    "monahismului": "monahism",
    "monarhi": "monarh",
    "monarhii": "monarh",
    "monarhilor": "monarh",
    "monarhul": "monarh",
    "monarhului": "monarh",
    "monarhica": "monarhic",
    "monarhică": "monarhic",
    "monarhice": "monarhic",
    "monarhicei": "monarhic",
    "monarhicele": "monarhic",
    "monarhicelor": "monarhic",
    "monarhici": "monarhic",
    "monarhicii": "monarhic",
    "monarhicilor": "monarhic",
    "monarhicul": "monarhic",
    "monarhicului": "monarhic",
    "monarhia": "monarhie",
    "monarhiei": "monarhie",
    "monarhii": "monarhie",
    "monarhiile": "monarhie",
    "monarhiilor": "monarhie",
    "monarhista": "monarhist",
    "monarhistă": "monarhist",
    "monarhiste": "monarhist",
    "monarhistei": "monarhist",
    "monarhistele": "monarhist",
    "monarhistelor": "monarhist",
    "monarhiști": "monarhist",
    "monarhiștii": "monarhist",
    "monarhiștilor": "monarhist",
    "monarhistul": "monarhist",
    "monarhistului": "monarhist",
    "monarhista": "monarhistă",
    "monarhiste": "monarhistă",
    "monarhistei": "monarhistă",
    "monarhistele": "monarhistă",
    "monarhistelor": "monarhistă",
    "monastica": "monastic",
    "monastică": "monastic",
    "monastice": "monastic",
    "monasticei": "monastic",
    "monasticele": "monastic",
    "monasticelor": "monastic",
    "monastici": "monastic",
    "monasticii": "monastic",
    "monasticilor": "monastic",
    "monasticul": "monastic",
    "monasticului": "monastic",
    "mondena": "monden",
    "mondenă": "monden",
    "mondene": "monden",
    "mondenei": "monden",
    "mondenele": "monden",
    "mondenelor": "monden",
    "mondeni": "monden",
    "mondenii": "monden",
    "mondenilor": "monden",
    "mondenul": "monden",
    "mondenului": "monden",
    "mondiala": "mondial",
    "mondială": "mondial",
    "mondiale": "mondial",
    "mondialei": "mondial",
    "mondialele": "mondial",
    "mondialelor": "mondial",
    "mondiali": "mondial",
    "mondialii": "mondial",
    "mondialilor": "mondial",
    "mondialul": "mondial",
    "mondialului": "mondial",
    "mondialele": "mondiale",
    "moneda": "monedă",
    "monede": "monedă",
    "monedei": "monedă",
    "monedele": "monedă",
    "monedelor": "monedă",
    "monezi": "monedă",
    "monezii": "monedă",
    "monezile": "monedă",
    "monezilor": "monedă",
    "monetara": "monetar",
    "monetară": "monetar",
    "monetare": "monetar",
    "monetarei": "monetar",
    "monetarele": "monetar",
    "monetarelor": "monetar",
    "monetari": "monetar",
    "monetarii": "monetar",
    "monetarilor": "monetar",
    "monetarul": "monetar",
    "monetarului": "monetar",
    "monetăria": "monetărie",
    "monetăriei": "monetărie",
    "monetării": "monetărie",
    "monetăriile": "monetărie",
    "monetăriilor": "monetărie",
    "mongola": "mongol",
    "mongolă": "mongol",
    "mongole": "mongol",
    "mongolei": "mongol",
    "mongolele": "mongol",
    "mongolelor": "mongol",
    "mongoli": "mongol",
    "mongolii": "mongol",
    "mongolilor": "mongol",
    "mongolul": "mongol",
    "mongolului": "mongol",
    "mongola": "mongolă",
    "mongole": "mongolă",
    "mongolei": "mongolă",
    "mongolele": "mongolă",
    "mongolelor": "mongolă",
    "Mongolie": "Mongolia",
    "Mongoliei": "Mongolia",
    "Mongolii": "Mongolia",
    "mongolica": "mongolic",
    "mongolică": "mongolic",
    "mongolice": "mongolic",
    "mongolicei": "mongolic",
    "mongolicele": "mongolic",
    "mongolicelor": "mongolic",
    "mongolici": "mongolic",
    "mongolicii": "mongolic",
    "mongolicilor": "mongolic",
    "mongolicul": "mongolic",
    "mongolicului": "mongolic",
    "mongoloida": "mongoloid",
    "mongoloidă": "mongoloid",
    "mongoloide": "mongoloid",
    "mongoloidei": "mongoloid",
    "mongoloidele": "mongoloid",
    "mongoloidelor": "mongoloid",
    "mongoloidul": "mongoloid",
    "mongoloidului": "mongoloid",
    "mongoloizi": "mongoloid",
    "mongoloizii": "mongoloid",
    "mongoloizilor": "mongoloid",
    "monismul": "monism",
    "monismului": "monism",
    "monista": "monist",
    "monistă": "monist",
    "moniste": "monist",
    "monistei": "monist",
    "monistele": "monist",
    "monistelor": "monist",
    "moniști": "monist",
    "moniștii": "monist",
    "moniștilor": "monist",
    "monistul": "monist",
    "monistului": "monist",
    "monitoare": "monitor",
    "monitoarele": "monitor",
    "monitoarelor": "monitor",
    "monitorul": "monitor",
    "monitorului": "monitor",
    "monitoriala": "monitorial",
    "monitorială": "monitorial",
    "monitoriale": "monitorial",
    "monitorialei": "monitorial",
    "monitorialele": "monitorial",
    "monitorialelor": "monitorial",
    "monitoriali": "monitorial",
    "monitorialii": "monitorial",
    "monitorialilor": "monitorial",
    "monitorialul": "monitorial",
    "monitorialului": "monitorial",
    "monitoria": "monitoriu",
    "monitorie": "monitoriu",
    "monitoriei": "monitoriu",
    "monitorii": "monitoriu",
    "monitoriii": "monitoriu",
    "monitoriile": "monitoriu",
    "monitoriilor": "monitoriu",
    "monitoriul": "monitoriu",
    "monitoriului": "monitoriu",
    "monitorizarea": "monitorizare",
    "monitorizări": "monitorizare",
    "monitorizării": "monitorizare",
    "monitorizările": "monitorizare",
    "monitorizărilor": "monitorizare",
    "monoacida": "monoacid",
    "monoacidă": "monoacid",
    "monoacide": "monoacid",
    "monoacidei": "monoacid",
    "monoacidele": "monoacid",
    "monoacidelor": "monoacid",
    "monoacidul": "monoacid",
    "monoacidului": "monoacid",
    "monoacizi": "monoacid",
    "monoacizii": "monoacid",
    "monoacizilor": "monoacid",
    "monoatomica": "monoatomic",
    "monoatomică": "monoatomic",
    "monoatomice": "monoatomic",
    "monoatomicei": "monoatomic",
    "monoatomicele": "monoatomic",
    "monoatomicelor": "monoatomic",
    "monoatomici": "monoatomic",
    "monoatomicii": "monoatomic",
    "monoatomicilor": "monoatomic",
    "monoatomicul": "monoatomic",
    "monoatomicului": "monoatomic",
    "monobazica": "monobazic",
    "monobazică": "monobazic",
    "monobazice": "monobazic",
    "monobazicei": "monobazic",
    "monobazicele": "monobazic",
    "monobazicelor": "monobazic",
    "monobazici": "monobazic",
    "monobazicii": "monobazic",
    "monobazicilor": "monobazic",
    "monobazicul": "monobazic",
    "monobazicului": "monobazic",
    "monocelulara": "monocelular",
    "monocelulară": "monocelular",
    "monocelulare": "monocelular",
    "monocelularei": "monocelular",
    "monocelularele": "monocelular",
    "monocelularelor": "monocelular",
    "monocelulari": "monocelular",
    "monocelularii": "monocelular",
    "monocelularilor": "monocelular",
    "monocelularul": "monocelular",
    "monocelularului": "monocelular",
    "monocilindrica": "monocilindric",
    "monocilindrică": "monocilindric",
    "monocilindrice": "monocilindric",
    "monocilindricei": "monocilindric",
    "monocilindricele": "monocilindric",
    "monocilindricelor": "monocilindric",
    "monocilindrici": "monocilindric",
    "monocilindricii": "monocilindric",
    "monocilindricilor": "monocilindric",
    "monocilindricul": "monocilindric",
    "monocilindricului": "monocilindric",
    "monocinetica": "monocinetic",
    "monocinetică": "monocinetic",
    "monocinetice": "monocinetic",
    "monocineticei": "monocinetic",
    "monocineticele": "monocinetic",
    "monocineticelor": "monocinetic",
    "monocinetici": "monocinetic",
    "monocineticii": "monocinetic",
    "monocineticilor": "monocinetic",
    "monocineticul": "monocinetic",
    "monocineticului": "monocinetic",
    "monocite": "monocit",
    "monocitele": "monocit",
    "monocitelor": "monocit",
    "monocitul": "monocit",
    "monocitului": "monocit",
    "monoclata": "monoclat",
    "monoclată": "monoclat",
    "monoclate": "monoclat",
    "monoclatei": "monoclat",
    "monoclatele": "monoclat",
    "monoclatelor": "monoclat",
    "monoclați": "monoclat",
    "monoclații": "monoclat",
    "monoclaților": "monoclat",
    "monoclatul": "monoclat",
    "monoclatului": "monoclat",
    "monoclinala": "monoclinal",
    "monoclinală": "monoclinal",
    "monoclinale": "monoclinal",
    "monoclinalei": "monoclinal",
    "monoclinalele": "monoclinal",
    "monoclinalelor": "monoclinal",
    "monoclinali": "monoclinal",
    "monoclinalii": "monoclinal",
    "monoclinalilor": "monoclinal",
    "monoclinalul": "monoclinal",
    "monoclinalului": "monoclinal",
    "monoclinica": "monoclinic",
    "monoclinică": "monoclinic",
    "monoclinice": "monoclinic",
    "monoclinicei": "monoclinic",
    "monoclinicele": "monoclinic",
    "monoclinicelor": "monoclinic",
    "monoclinici": "monoclinic",
    "monoclinicii": "monoclinic",
    "monoclinicilor": "monoclinic",
    "monoclinicul": "monoclinic",
    "monoclinicului": "monoclinic",
    "monoclul": "monoclu",
    "monoclului": "monoclu",
    "monocluri": "monoclu",
    "monoclurile": "monoclu",
    "monoclurilor": "monoclu",
    "monocorda": "monocord",
    "monocordă": "monocord",
    "monocorde": "monocord",
    "monocordei": "monocord",
    "monocordele": "monocord",
    "monocordelor": "monocord",
    "monocordul": "monocord",
    "monocordului": "monocord",
    "monocorzi": "monocord",
    "monocorzii": "monocord",
    "monocorzilor": "monocord",
    "monocotiledonați": "monocotiledonat",
    "monocotiledonații": "monocotiledonat",
    "monocotiledonaților": "monocotiledonat",
    "monocotiledonatul": "monocotiledonat",
    "monocotiledonatului": "monocotiledonat",
    "monocroma": "monocrom",
    "monocromă": "monocrom",
    "monocrome": "monocrom",
    "monocromei": "monocrom",
    "monocromele": "monocrom",
    "monocromelor": "monocrom",
    "monocromi": "monocrom",
    "monocromii": "monocrom",
    "monocromilor": "monocrom",
    "monocromul": "monocrom",
    "monocromului": "monocrom",
    "monocromatica": "monocromatic",
    "monocromatică": "monocromatic",
    "monocromatice": "monocromatic",
    "monocromaticei": "monocromatic",
    "monocromaticele": "monocromatic",
    "monocromaticelor": "monocromatic",
    "monocromatici": "monocromatic",
    "monocromaticii": "monocromatic",
    "monocromaticilor": "monocromatic",
    "monocromaticul": "monocromatic",
    "monocromaticului": "monocromatic",
    "monoculara": "monocular",
    "monoculară": "monocular",
    "monoculare": "monocular",
    "monocularei": "monocular",
    "monocularele": "monocular",
    "monocularelor": "monocular",
    "monoculari": "monocular",
    "monocularii": "monocular",
    "monocularilor": "monocular",
    "monocularul": "monocular",
    "monocularului": "monocular",
    "monocultura": "monocultură",
    "monoculturi": "monocultură",
    "monoculturii": "monocultură",
    "monoculturile": "monocultură",
    "monoculturilor": "monocultură",
    "monodactila": "monodactil",
    "monodactilă": "monodactil",
    "monodactile": "monodactil",
    "monodactilei": "monodactil",
    "monodactilele": "monodactil",
    "monodactilelor": "monodactil",
    "monodactili": "monodactil",
    "monodactilii": "monodactil",
    "monodactililor": "monodactil",
    "monodactilul": "monodactil",
    "monodactilului": "monodactil",
    "monodia": "monodie",
    "monodiei": "monodie",
    "monodii": "monodie",
    "monodiile": "monodie",
    "monodiilor": "monodie",
    "monofaga": "monofag",
    "monofagă": "monofag",
    "monofage": "monofag",
    "monofagei": "monofag",
    "monofagele": "monofag",
    "monofagelor": "monofag",
    "monofagi": "monofag",
    "monofagii": "monofag",
    "monofagilor": "monofag",
    "monofagul": "monofag",
    "monofagului": "monofag",
    "monofazata": "monofazat",
    "monofazată": "monofazat",
    "monofazate": "monofazat",
    "monofazatei": "monofazat",
    "monofazatele": "monofazat",
    "monofazatelor": "monofazat",
    "monofazați": "monofazat",
    "monofazații": "monofazat",
    "monofazaților": "monofazat",
    "monofazatul": "monofazat",
    "monofazatului": "monofazat",
    "monofazica": "monofazic",
    "monofazică": "monofazic",
    "monofazice": "monofazic",
    "monofazicei": "monofazic",
    "monofazicele": "monofazic",
    "monofazicelor": "monofazic",
    "monofazici": "monofazic",
    "monofazicii": "monofazic",
    "monofazicilor": "monofazic",
    "monofazicul": "monofazic",
    "monofazicului": "monofazic",
    "monogama": "monogam",
    "monogamă": "monogam",
    "monogame": "monogam",
    "monogamei": "monogam",
    "monogamele": "monogam",
    "monogamelor": "monogam",
    "monogami": "monogam",
    "monogamii": "monogam",
    "monogamilor": "monogam",
    "monogamul": "monogam",
    "monogamului": "monogam",
    "monogama": "monogamă",
    "monogame": "monogamă",
    "monogamei": "monogamă",
    "monogamele": "monogamă",
    "monogamelor": "monogamă",
    "monogamica": "monogamic",
    "monogamică": "monogamic",
    "monogamice": "monogamic",
    "monogamicei": "monogamic",
    "monogamicele": "monogamic",
    "monogamicelor": "monogamic",
    "monogamici": "monogamic",
    "monogamicii": "monogamic",
    "monogamicilor": "monogamic",
    "monogamicul": "monogamic",
    "monogamicului": "monogamic",
    "monogamia": "monogamie",
    "monogamiei": "monogamie",
    "monogamii": "monogamie",
    "monogamiile": "monogamie",
    "monogamiilor": "monogamie",
    "monogenetica": "monogenetic",
    "monogenetică": "monogenetic",
    "monogenetice": "monogenetic",
    "monogeneticei": "monogenetic",
    "monogeneticele": "monogenetic",
    "monogeneticelor": "monogenetic",
    "monogenetici": "monogenetic",
    "monogeneticii": "monogenetic",
    "monogeneticilor": "monogenetic",
    "monogeneticul": "monogenetic",
    "monogeneticului": "monogenetic",
    "monogeneza": "monogeneză",
    "monogeneze": "monogeneză",
    "monogenezei": "monogeneză",
    "monogenezele": "monogeneză",
    "monogenezelor": "monogeneză",
    "monografi": "monograf",
    "monografii": "monograf",
    "monografilor": "monograf",
    "monograful": "monograf",
    "monografule": "monograf",
    "monografului": "monograf",
    "monografica": "monografic",
    "monografică": "monografic",
    "monografice": "monografic",
    "monograficei": "monografic",
    "monograficele": "monografic",
    "monograficelor": "monografic",
    "monografici": "monografic",
    "monograficii": "monografic",
    "monograficilor": "monografic",
    "monograficul": "monografic",
    "monograficului": "monografic",
    "monografia": "monografie",
    "monografiei": "monografie",
    "monografii": "monografie",
    "monografiile": "monografie",
    "monografiilor": "monografie",
    "monograma": "monogramă",
    "monograme": "monogramă",
    "monogramei": "monogramă",
    "monogramele": "monogramă",
    "monogramelor": "monogramă",
    "monogranulara": "monogranular",
    "monogranulară": "monogranular",
    "monogranulare": "monogranular",
    "monogranularei": "monogranular",
    "monogranularele": "monogranular",
    "monogranularelor": "monogranular",
    "monogranulari": "monogranular",
    "monogranularii": "monogranular",
    "monogranularilor": "monogranular",
    "monogranularul": "monogranular",
    "monogranularului": "monogranular",
    "monoica": "monoic",
    "monoică": "monoic",
    "monoice": "monoic",
    "monoicei": "monoic",
    "monoicele": "monoic",
    "monoicelor": "monoic",
    "monoici": "monoic",
    "monoicii": "monoic",
    "monoicilor": "monoic",
    "monoicul": "monoic",
    "monoicului": "monoic",
    "monoindustriala": "monoindustrial",
    "monoindustriale": "monoindustrial",
    "monoindustrialei": "monoindustrial",
    "monoindustrialele": "monoindustrial",
    "monoindustrialelor": "monoindustrial",
    "monoindustriali": "monoindustrial",
    "monoindustrialii": "monoindustrial",
    "monoindustrialilor": "monoindustrial",
    "monolingva": "monolingv",
    "monolingvă": "monolingv",
    "monolingve": "monolingv",
    "monolingvei": "monolingv",
    "monolingvele": "monolingv",
    "monolingvelor": "monolingv",
    "monolingvi": "monolingv",
    "monolingvii": "monolingv",
    "monolingvilor": "monolingv",
    "monolingvul": "monolingv",
    "monolingvului": "monolingv",
    "monolita": "monolit",
    "monolită": "monolit",
    "monolite": "monolit",
    "monolitei": "monolit",
    "monolitele": "monolit",
    "monolitelor": "monolit",
    "monoliți": "monolit",
    "monoliții": "monolit",
    "monoliților": "monolit",
    "monolitul": "monolit",
    "monolitului": "monolit",
    "monolitica": "monolitic",
    "monolitică": "monolitic",
    "monolitice": "monolitic",
    "monoliticei": "monolitic",
    "monoliticele": "monolitic",
    "monoliticelor": "monolitic",
    "monolitici": "monolitic",
    "monoliticii": "monolitic",
    "monoliticilor": "monolitic",
    "monoliticul": "monolitic",
    "monoliticului": "monolitic",
    "monoloage": "monolog",
    "monoloagele": "monolog",
    "monoloagelor": "monolog",
    "monologul": "monolog",
    "monologului": "monolog",
    "monologă": "monologa",
    "monologai": "monologa",
    "monologam": "monologa",
    "monologăm": "monologa",
    "monologând": "monologa",
    "monologându": "monologa",
    "monologară": "monologa",
    "monologarăm": "monologa",
    "monologarăți": "monologa",
    "monologase": "monologa",
    "monologasem": "monologa",
    "monologaseră": "monologa",
    "monologaserăm": "monologa",
    "monologaserăți": "monologa",
    "monologaseși": "monologa",
    "monologași": "monologa",
    "monologat": "monologa",
    "monologați": "monologa",
    "monologatu": "monologa",
    "monologau": "monologa",
    "monologhează": "monologa",
    "monologhez": "monologa",
    "monologheze": "monologa",
    "monologhezi": "monologa",
    "nemaimonologând": "monologa",
    "nemaimonologându": "monologa",
    "nemonologând": "monologa",
    "nemonologându": "monologa",
    "monologată": "monologat",
    "monologate": "monologat",
    "monologați": "monologat",
    "monologica": "monologic",
    "monologică": "monologic",
    "monologice": "monologic",
    "monologicei": "monologic",
    "monologicele": "monologic",
    "monologicelor": "monologic",
    "monologici": "monologic",
    "monologicii": "monologic",
    "monologicilor": "monologic",
    "monologicul": "monologic",
    "monologicului": "monologic",
    "monoame": "monom",
    "monoamele": "monom",
    "monoamelor": "monom",
    "monomul": "monom",
    "monomului": "monom",
    "monomeri": "monomer",
    "monomerii": "monomer",
    "monomerilor": "monomer",
    "monomerul": "monomer",
    "monomerului": "monomer",
    "monoplane": "monoplan",
    "monoplanele": "monoplan",
    "monoplanelor": "monoplan",
    "monoplanul": "monoplan",
    "monoplanului": "monoplan",
    "monopolul": "monopol",
    "monopolule": "monopol",
    "monopolului": "monopol",
    "monopoluri": "monopol",
    "monopolurile": "monopol",
    "monopolurilor": "monopol",
    "monopolista": "monopolist",
    "monopolistă": "monopolist",
    "monopoliste": "monopolist",
    "monopolistei": "monopolist",
    "monopolistele": "monopolist",
    "monopolistelor": "monopolist",
    "monopoliști": "monopolist",
    "monopoliștii": "monopolist",
    "monopoliștilor": "monopolist",
    "monopolistul": "monopolist",
    "monopolistului": "monopolist",
    "monopoliză": "monopoliza",
    "monopolizai": "monopoliza",
    "monopolizam": "monopoliza",
    "monopolizăm": "monopoliza",
    "monopolizând": "monopoliza",
    "monopolizându": "monopoliza",
    "monopolizară": "monopoliza",
    "monopolizarăm": "monopoliza",
    "monopolizarăți": "monopoliza",
    "monopolizase": "monopoliza",
    "monopolizasem": "monopoliza",
    "monopolizaseră": "monopoliza",
    "monopolizaserăm": "monopoliza",
    "monopolizaserăți": "monopoliza",
    "monopolizaseși": "monopoliza",
    "monopolizași": "monopoliza",
    "monopolizat": "monopoliza",
    "monopolizați": "monopoliza",
    "monopolizatu": "monopoliza",
    "monopolizau": "monopoliza",
    "monopolizează": "monopoliza",
    "monopolizez": "monopoliza",
    "monopolizeze": "monopoliza",
    "monopolizezi": "monopoliza",
    "nemaimonopolizând": "monopoliza",
    "nemaimonopolizându": "monopoliza",
    "nemonopolizând": "monopoliza",
    "nemonopolizându": "monopoliza",
    "monopolizarea": "monopolizare",
    "monopolizareo": "monopolizare",
    "monopolizări": "monopolizare",
    "monopolizării": "monopolizare",
    "monopolizările": "monopolizare",
    "monopolizărilor": "monopolizare",
    "monopolizată": "monopolizat",
    "monopolizate": "monopolizat",
    "monopolizați": "monopolizat",
    "monopolizatoare": "monopolizator",
    "monopolizatoarea": "monopolizator",
    "monopolizatoarei": "monopolizator",
    "monopolizatoarele": "monopolizator",
    "monopolizatoarelor": "monopolizator",
    "monopolizatori": "monopolizator",
    "monopolizatorii": "monopolizator",
    "monopolizatorilor": "monopolizator",
    "monopolizatorul": "monopolizator",
    "monopolizatorului": "monopolizator",
    "monoptera": "monopter",
    "monopteră": "monopter",
    "monoptere": "monopter",
    "monopterei": "monopter",
    "monopterele": "monopter",
    "monopterelor": "monopter",
    "monopteri": "monopter",
    "monopterii": "monopter",
    "monopterilor": "monopter",
    "monopterul": "monopter",
    "monopterului": "monopter",
    "monoraiul": "monorai",
    "monoraiului": "monorai",
    "monoraiuri": "monorai",
    "monoraiurile": "monorai",
    "monoraiurilor": "monorai",
    "monorima": "monorimă",
    "monorime": "monorimă",
    "monorimei": "monorimă",
    "monorimele": "monorimă",
    "monorimelor": "monorimă",
    "monosemantica": "monosemantic",
    "monosemantică": "monosemantic",
    "monosemantice": "monosemantic",
    "monosemanticei": "monosemantic",
    "monosemanticele": "monosemantic",
    "monosemanticelor": "monosemantic",
    "monosemantici": "monosemantic",
    "monosemanticii": "monosemantic",
    "monosemanticilor": "monosemantic",
    "monosemanticul": "monosemantic",
    "monosemanticului": "monosemantic",
    "monosilaba": "monosilab",
    "monosilabă": "monosilab",
    "monosilabe": "monosilab",
    "monosilabei": "monosilab",
    "monosilabele": "monosilab",
    "monosilabelor": "monosilab",
    "monosilabi": "monosilab",
    "monosilabii": "monosilab",
    "monosilabilor": "monosilab",
    "monosilabul": "monosilab",
    "monosilabului": "monosilab",
    "monosilabica": "monosilabic",
    "monosilabică": "monosilabic",
    "monosilabice": "monosilabic",
    "monosilabicei": "monosilabic",
    "monosilabicele": "monosilabic",
    "monosilabicelor": "monosilabic",
    "monosilabici": "monosilabic",
    "monosilabicii": "monosilabic",
    "monosilabicilor": "monosilabic",
    "monosilabicul": "monosilabic",
    "monosilabicului": "monosilabic",
    "monoșina": "monoșină",
    "monoșine": "monoșină",
    "monoșinei": "monoșină",
    "monoșinele": "monoșină",
    "monoșinelor": "monoșină",
    "monoteismul": "monoteism",
    "monoteismului": "monoteism",
    "monoteista": "monoteist",
    "monoteistă": "monoteist",
    "monoteiste": "monoteist",
    "monoteistei": "monoteist",
    "monoteistele": "monoteist",
    "monoteistelor": "monoteist",
    "monoteiști": "monoteist",
    "monoteiștii": "monoteist",
    "monoteiștilor": "monoteist",
    "monoteistul": "monoteist",
    "monoteistului": "monoteist",
    "monoteista": "monoteistă",
    "monoteiste": "monoteistă",
    "monoteistei": "monoteistă",
    "monoteistele": "monoteistă",
    "monoteistelor": "monoteistă",
    "monotipa": "monotip",
    "monotipă": "monotip",
    "monotipe": "monotip",
    "monotipei": "monotip",
    "monotipele": "monotip",
    "monotipelor": "monotip",
    "monotipi": "monotip",
    "monotipii": "monotip",
    "monotipilor": "monotip",
    "monotipul": "monotip",
    "monotipului": "monotip",
    "monotipuri": "monotip",
    "monotipurile": "monotip",
    "monotipurilor": "monotip",
    "monotona": "monoton",
    "monotonă": "monoton",
    "monotone": "monoton",
    "monotonei": "monoton",
    "monotonele": "monoton",
    "monotonelor": "monoton",
    "monotoni": "monoton",
    "monotonii": "monoton",
    "monotonilor": "monoton",
    "monotonul": "monoton",
    "monotonului": "monoton",
    "monotonia": "monotonie",
    "monotoniei": "monotonie",
    "monotonii": "monotonie",
    "monotoniile": "monotonie",
    "monotoniilor": "monotonie",
    "monovalenta": "monovalent",
    "monovalentă": "monovalent",
    "monovalente": "monovalent",
    "monovalentei": "monovalent",
    "monovalentele": "monovalent",
    "monovalentelor": "monovalent",
    "monovalenți": "monovalent",
    "monovalenții": "monovalent",
    "monovalenților": "monovalent",
    "monovalentul": "monovalent",
    "monovalentului": "monovalent",
    "monoverbe": "monoverb",
    "monoverbele": "monoverb",
    "monoverbelor": "monoverb",
    "monoverbul": "monoverb",
    "monoverbului": "monoverb",
    "monoxila": "monoxil",
    "monoxilă": "monoxil",
    "monoxile": "monoxil",
    "monoxilei": "monoxil",
    "monoxilele": "monoxil",
    "monoxilelor": "monoxil",
    "monoxili": "monoxil",
    "monoxilii": "monoxil",
    "monoxililor": "monoxil",
    "monoxilul": "monoxil",
    "monoxilului": "monoxil",
    "monseniori": "monsenior",
    "monseniorii": "monsenior",
    "monseniorilor": "monsenior",
    "monseniorul": "monsenior",
    "monseniorului": "monsenior",
    "Mons.": "monsieur",
    "monștri": "monstru",
    "monștrii": "monstru",
    "monștrilor": "monstru",
    "monstrul": "monstru",
    "monstrului": "monstru",
    "monstruoasa": "monstruos",
    "monstruoasă": "monstruos",
    "monstruoase": "monstruos",
    "monstruoasei": "monstruos",
    "monstruoasele": "monstruos",
    "monstruoaselor": "monstruos",
    "monstruoși": "monstruos",
    "monstruoșii": "monstruos",
    "monstruoșilor": "monstruos",
    "monstruosul": "monstruos",
    "monstruosului": "monstruos",
    "monstruozitatea": "monstruozitate",
    "monstruozități": "monstruozitate",
    "monstruozității": "monstruozitate",
    "monstruozitățile": "monstruozitate",
    "monstruozităților": "monstruozitate",
    "montul": "mont",
    "montului": "mont",
    "monturi": "mont",
    "monturile": "mont",
    "monturilor": "mont",
    "montă": "monta",
    "montai": "monta",
    "montam": "monta",
    "montăm": "monta",
    "montând": "monta",
    "montându": "monta",
    "montară": "monta",
    "montarăm": "monta",
    "montarăți": "monta",
    "montase": "monta",
    "montasem": "monta",
    "montaseră": "monta",
    "montaserăm": "monta",
    "montaserăți": "monta",
    "montaseși": "monta",
    "montași": "monta",
    "montat": "monta",
    "montați": "monta",
    "montatu": "monta",
    "montau": "monta",
    "montează": "monta",
    "montez": "monta",
    "monteze": "monta",
    "montezi": "monta",
    "nemaimontând": "monta",
    "nemaimontându": "monta",
    "nemontând": "monta",
    "nemontându": "monta",
    "montagnarda": "montagnard",
    "montagnardă": "montagnard",
    "montagnarde": "montagnard",
    "montagnardei": "montagnard",
    "montagnardele": "montagnard",
    "montagnardelor": "montagnard",
    "montagnardul": "montagnard",
    "montagnardului": "montagnard",
    "montagnarzi": "montagnard",
    "montagnarzii": "montagnard",
    "montagnarzilor": "montagnard",
    "montaje": "montaj",
    "montajele": "montaj",
    "montajelor": "montaj",
    "montajul": "montaj",
    "montajului": "montaj",
    "montana": "montan",
    "montană": "montan",
    "montane": "montan",
    "montanei": "montan",
    "montanele": "montan",
    "montanelor": "montan",
    "montani": "montan",
    "montanii": "montan",
    "montanilor": "montan",
    "montanul": "montan",
    "montanului": "montan",
    "montanta": "montant",
    "montantă": "montant",
    "montante": "montant",
    "montantei": "montant",
    "montantele": "montant",
    "montantelor": "montant",
    "montanți": "montant",
    "montanții": "montant",
    "montanților": "montant",
    "montantul": "montant",
    "montantului": "montant",
    "montarea": "montare",
    "montareo": "montare",
    "montări": "montare",
    "montării": "montare",
    "montările": "montare",
    "montărilor": "montare",
    "montată": "montat",
    "montate": "montat",
    "montați": "montat",
    "montatori": "montator",
    "montatorii": "montator",
    "montatorilor": "montator",
    "montatorul": "montator",
    "montatorule": "montator",
    "montatorului": "montator",
    "montura": "montură",
    "monturi": "montură",
    "monturii": "montură",
    "monturile": "montură",
    "monturilor": "montură",
    "mon.": "monument",
    "monumente": "monument",
    "monumentele": "monument",
    "monumentelor": "monument",
    "monumentul": "monument",
    "monumentului": "monument",
    "monumentala": "monumental",
    "monumentală": "monumental",
    "monumentale": "monumental",
    "monumentalei": "monumental",
    "monumentalele": "monumental",
    "monumentalelor": "monumental",
    "monumentali": "monumental",
    "monumentalii": "monumental",
    "monumentalilor": "monumental",
    "monumentalul": "monumental",
    "monumentalului": "monumental",
    "monumentalitatea": "monumentalitate",
    "monumentalități": "monumentalitate",
    "monumentalității": "monumentalitate",
    "monumentalitățile": "monumentalitate",
    "monumentalităților": "monumentalitate",
    "mopși": "mops",
    "mopșii": "mops",
    "mopșilor": "mops",
    "mopsul": "mops",
    "mopsului": "mops",
    "morala": "moral",
    "morală": "moral",
    "morale": "moral",
    "moralei": "moral",
    "moralele": "moral",
    "moralelor": "moral",
    "morali": "moral",
    "moralii": "moral",
    "moralilor": "moral",
    "moralul": "moral",
    "moralului": "moral",
    "moraluri": "moral",
    "moralurile": "moral",
    "moralurilor": "moral",
    "morala": "morală",
    "morale": "morală",
    "moralei": "morală",
    "moralele": "morală",
    "moralelor": "morală",
    "moraliceasca": "moralicesc",
    "moralicească": "moralicesc",
    "moralicescul": "moralicesc",
    "moralicescului": "moralicesc",
    "moralicești": "moralicesc",
    "moraliceștii": "moralicesc",
    "moraliceștile": "moralicesc",
    "moraliceștilor": "moralicesc",
    "moraliști": "moralist",
    "moraliștii": "moralist",
    "moraliștilor": "moralist",
    "moralistul": "moralist",
    "moralistului": "moralist",
    "moralitatea": "moralitate",
    "moralități": "moralitate",
    "moralității": "moralitate",
    "moralitățile": "moralitate",
    "moralităților": "moralitate",
    "moraliză": "moraliza",
    "moralizai": "moraliza",
    "moralizam": "moraliza",
    "moralizăm": "moraliza",
    "moralizând": "moraliza",
    "moralizându": "moraliza",
    "moralizară": "moraliza",
    "moralizarăm": "moraliza",
    "moralizarăți": "moraliza",
    "moralizase": "moraliza",
    "moralizasem": "moraliza",
    "moralizaseră": "moraliza",
    "moralizaserăm": "moraliza",
    "moralizaserăți": "moraliza",
    "moralizaseși": "moraliza",
    "moralizași": "moraliza",
    "moralizat": "moraliza",
    "moralizați": "moraliza",
    "moralizatu": "moraliza",
    "moralizau": "moraliza",
    "moralizează": "moraliza",
    "moralizez": "moraliza",
    "moralizeze": "moraliza",
    "moralizezi": "moraliza",
    "moralizată": "moralizat",
    "moralizate": "moralizat",
    "moralizați": "moralizat",
    "moralizatoare": "moralizator",
    "moralizatoarea": "moralizator",
    "moralizatoarei": "moralizator",
    "moralizatoarele": "moralizator",
    "moralizatoarelor": "moralizator",
    "moralizatori": "moralizator",
    "moralizatorii": "moralizator",
    "moralizatorilor": "moralizator",
    "moralizatorul": "moralizator",
    "moralizatorului": "moralizator",
    "morari": "morar",
    "morarii": "morar",
    "morarilor": "morar",
    "morarul": "morar",
    "morarului": "morar",
    "morăreasca": "morăresc",
    "morărească": "morăresc",
    "morărescul": "morăresc",
    "morărescului": "morăresc",
    "morărești": "morăresc",
    "morăreștii": "morăresc",
    "morăreștile": "morăresc",
    "morăreștilor": "morăresc",
    "morăritul": "morărit",
    "morăritului": "morărit",
    "morărița": "morăriță",
    "morărițe": "morăriță",
    "morăriței": "morăriță",
    "morărițele": "morăriță",
    "morărițelor": "morăriță",
    "moratorii": "moratoriu",
    "moratoriile": "moratoriu",
    "moratoriilor": "moratoriu",
    "moratoriul": "moratoriu",
    "moratoriului": "moratoriu",
    "morava": "morav",
    "moravă": "morav",
    "morave": "morav",
    "moravei": "morav",
    "moravele": "morav",
    "moravelor": "morav",
    "moravi": "morav",
    "moravii": "morav",
    "moravilor": "morav",
    "moravul": "morav",
    "moravului": "morav",
    "moravurile": "moravuri",
    "moravurilor": "moravuri",
    "morbul": "morb",
    "morbului": "morb",
    "morburi": "morb",
    "morburile": "morb",
    "morburilor": "morb",
    "morbida": "morbid",
    "morbidă": "morbid",
    "morbide": "morbid",
    "morbidei": "morbid",
    "morbidele": "morbid",
    "morbidelor": "morbid",
    "morbidul": "morbid",
    "morbidului": "morbid",
    "morbizi": "morbid",
    "morbizii": "morbid",
    "morbizilor": "morbid",
    "morbidețea": "morbidețe",
    "morbideți": "morbidețe",
    "morbideții": "morbidețe",
    "morbiditatea": "morbiditate",
    "morbidități": "morbiditate",
    "morbidității": "morbiditate",
    "morbiditățile": "morbiditate",
    "morbidităților": "morbiditate",
    "morboasa": "morbos",
    "morboasă": "morbos",
    "morboase": "morbos",
    "morboasei": "morbos",
    "morboasele": "morbos",
    "morboaselor": "morbos",
    "morboși": "morbos",
    "morboșii": "morbos",
    "morboșilor": "morbos",
    "morbosul": "morbos",
    "morbosului": "morbos",
    "morcovi": "morcov",
    "morcovii": "morcov",
    "morcovilor": "morcov",
    "morcovul": "morcov",
    "morcovului": "morcov",
    "morcovia": "morcoviu",
    "morcovie": "morcoviu",
    "morcoviei": "morcoviu",
    "morcovii": "morcoviu",
    "morcoviii": "morcoviu",
    "morcoviile": "morcoviu",
    "morcoviilor": "morcoviu",
    "morcoviul": "morcoviu",
    "morcoviului": "morcoviu",
    "mordanta": "mordant",
    "mordantă": "mordant",
    "mordante": "mordant",
    "mordantei": "mordant",
    "mordantele": "mordant",
    "mordantelor": "mordant",
    "mordanți": "mordant",
    "mordanții": "mordant",
    "mordanților": "mordant",
    "mordantul": "mordant",
    "mordantului": "mordant",
    "morena": "morenă",
    "morene": "morenă",
    "morenei": "morenă",
    "morenele": "morenă",
    "morenelor": "morenă",
    "moreasca": "moresc",
    "morească": "moresc",
    "morescul": "moresc",
    "morescului": "moresc",
    "morești": "moresc",
    "moreștii": "moresc",
    "moreștile": "moresc",
    "moreștilor": "moresc",
    "morfeme": "morfem",
    "morfemele": "morfem",
    "morfemelor": "morfem",
    "morfemul": "morfem",
    "morfemului": "morfem",
    "morfematica": "morfematic",
    "morfematică": "morfematic",
    "morfematice": "morfematic",
    "morfematicei": "morfematic",
    "morfematicele": "morfematic",
    "morfematicelor": "morfematic",
    "morfematici": "morfematic",
    "morfematicii": "morfematic",
    "morfematicilor": "morfematic",
    "morfematicul": "morfematic",
    "morfematicului": "morfematic",
    "morfina": "morfină",
    "morfine": "morfină",
    "morfinei": "morfină",
    "morfinomana": "morfinoman",
    "morfinomană": "morfinoman",
    "morfinomane": "morfinoman",
    "morfinomanei": "morfinoman",
    "morfinomanele": "morfinoman",
    "morfinomanelor": "morfinoman",
    "morfinomani": "morfinoman",
    "morfinomanii": "morfinoman",
    "morfinomanilor": "morfinoman",
    "morfinomanul": "morfinoman",
    "morfinomanului": "morfinoman",
    "morfinomana": "morfinomană",
    "morfinomane": "morfinomană",
    "morfinomanei": "morfinomană",
    "morfinomanele": "morfinomană",
    "morfinomanelor": "morfinomană",
    "morfinomania": "morfinomanie",
    "morfinomaniei": "morfinomanie",
    "morfinomanii": "morfinomanie",
    "morfofiziologica": "morfofiziologic",
    "morfofiziologică": "morfofiziologic",
    "morfofiziologice": "morfofiziologic",
    "morfofiziologicei": "morfofiziologic",
    "morfofiziologicele": "morfofiziologic",
    "morfofiziologicelor": "morfofiziologic",
    "morfofiziologici": "morfofiziologic",
    "morfofiziologicii": "morfofiziologic",
    "morfofiziologicilor": "morfofiziologic",
    "morfofiziologicul": "morfofiziologic",
    "morfofiziologicului": "morfofiziologic",
    "morfolea": "morfoli",
    "morfoleai": "morfoli",
    "morfoleam": "morfoli",
    "morfolească": "morfoli",
    "morfoleați": "morfoli",
    "morfoleau": "morfoli",
    "morfolesc": "morfoli",
    "morfolește": "morfoli",
    "morfolești": "morfoli",
    "morfolii": "morfoli",
    "morfolim": "morfoli",
    "morfolind": "morfoli",
    "morfolindu": "morfoli",
    "morfoliră": "morfoli",
    "morfolirăm": "morfoli",
    "morfolirăți": "morfoli",
    "morfolise": "morfoli",
    "morfolisem": "morfoli",
    "morfoliseră": "morfoli",
    "morfoliserăm": "morfoli",
    "morfoliserăți": "morfoli",
    "morfoliseși": "morfoli",
    "morfoliși": "morfoli",
    "morfolit": "morfoli",
    "morfoliți": "morfoli",
    "morfolitu": "morfoli",
    "nemaimorfolind": "morfoli",
    "nemaimorfolindu": "morfoli",
    "nemorfolind": "morfoli",
    "nemorfolindu": "morfoli",
    "morfolită": "morfolit",
    "morfolite": "morfolit",
    "morfoliți": "morfolit",
    "morfologica": "morfologic",
    "morfologică": "morfologic",
    "morfologice": "morfologic",
    "morfologicei": "morfologic",
    "morfologicele": "morfologic",
    "morfologicelor": "morfologic",
    "morfologici": "morfologic",
    "morfologicii": "morfologic",
    "morfologicilor": "morfologic",
    "morfologicul": "morfologic",
    "morfologicului": "morfologic",
    "morfologia": "morfologie",
    "morfologiei": "morfologie",
    "morfologii": "morfologie",
    "morga": "morgă",
    "morgi": "morgă",
    "morgii": "morgă",
    "morgile": "morgă",
    "morgilor": "morgă",
    "morișca": "morișcă",
    "moriști": "morișcă",
    "moriștii": "morișcă",
    "moriștile": "morișcă",
    "moriștilor": "morișcă",
    "mormăia": "mormăi",
    "mormăiai": "mormăi",
    "mormăiam": "mormăi",
    "mormăiați": "mormăi",
    "mormăiau": "mormăi",
    "mormăie": "mormăi",
    "mormăii": "mormăi",
    "mormăim": "mormăi",
    "mormăind": "mormăi",
    "mormăindu": "mormăi",
    "mormăiră": "mormăi",
    "mormăirăm": "mormăi",
    "mormăirăți": "mormăi",
    "mormăise": "mormăi",
    "mormăisem": "mormăi",
    "mormăiseră": "mormăi",
    "mormăiserăm": "mormăi",
    "mormăiserăți": "mormăi",
    "mormăiseși": "mormăi",
    "mormăiși": "mormăi",
    "mormăit": "mormăi",
    "mormăiți": "mormăi",
    "mormăitu": "mormăi",
    "nemaimormăind": "mormăi",
    "nemaimormăindu": "mormăi",
    "nemormăind": "mormăi",
    "nemormăindu": "mormăi",
    "mormăită": "mormăit",
    "mormăite": "mormăit",
    "mormăiți": "mormăit",
    "mormăitul": "mormăit",
    "mormăitului": "mormăit",
    "mormăituri": "mormăit",
    "mormăiturile": "mormăit",
    "mormăiturilor": "mormăit",
    "mormane": "morman",
    "mormanele": "morman",
    "mormanelor": "morman",
    "mormanul": "morman",
    "mormanului": "morman",
    "mormântul": "mormânt",
    "mormântului": "mormânt",
    "morminte": "mormânt",
    "mormintele": "mormânt",
    "mormintelor": "mormânt",
    "morm.com.": "mormânt_comun",
    "mormântala": "mormântal",
    "mormântală": "mormântal",
    "mormântale": "mormântal",
    "mormântalei": "mormântal",
    "mormântalele": "mormântal",
    "mormântalelor": "mormântal",
    "mormântali": "mormântal",
    "mormântalii": "mormântal",
    "mormântalilor": "mormântal",
    "mormântalul": "mormântal",
    "mormântalului": "mormântal",
    "mormoloci": "mormoloc",
    "mormolocii": "mormoloc",
    "mormolocilor": "mormoloc",
    "mormolocul": "mormoloc",
    "mormolocului": "mormoloc",
    "morocănoasa": "morocănos",
    "morocănoasă": "morocănos",
    "morocănoase": "morocănos",
    "morocănoasei": "morocănos",
    "morocănoasele": "morocănos",
    "morocănoaselor": "morocănos",
    "morocănoși": "morocănos",
    "morocănoșii": "morocănos",
    "morocănoșilor": "morocănos",
    "morocănosul": "morocănos",
    "morocănosului": "morocănos",
    "moroii": "moroi",
    "moroilor": "moroi",
    "moroiul": "moroi",
    "moroiului": "moroi",
    "morsa": "morsă",
    "morse": "morsă",
    "morsei": "morsă",
    "morsele": "morsă",
    "morselor": "morsă",
    "moarta": "mort",
    "moartă": "mort",
    "moarte": "mort",
    "moartei": "mort",
    "moartele": "mort",
    "moartelor": "mort",
    "morți": "mort",
    "morții": "mort",
    "morților": "mort",
    "mortu'": "mort",
    "mortul": "mort",
    "mortului": "mort",
    "mortăciunea": "mortăciune",
    "mortăciuni": "mortăciune",
    "mortăciunii": "mortăciune",
    "mortăciunile": "mortăciune",
    "mortăciunilor": "mortăciune",
    "mortala": "mortal",
    "mortală": "mortal",
    "mortale": "mortal",
    "mortalei": "mortal",
    "mortalele": "mortal",
    "mortalelor": "mortal",
    "mortali": "mortal",
    "mortalii": "mortal",
    "mortalilor": "mortal",
    "mortalul": "mortal",
    "mortalului": "mortal",
    "mortalitatea": "mortalitate",
    "mortalități": "mortalitate",
    "mortalității": "mortalitate",
    "mortalitățile": "mortalitate",
    "mortalităților": "mortalitate",
    "mortare": "mortar",
    "mortarele": "mortar",
    "mortarelor": "mortar",
    "mortarul": "mortar",
    "mortarului": "mortar",
    "moartezându": "morteza",
    "moartezatu": "morteza",
    "moartezau": "morteza",
    "morteză": "morteza",
    "mortezai": "morteza",
    "mortezam": "morteza",
    "mortezăm": "morteza",
    "mortezând": "morteza",
    "mortezară": "morteza",
    "mortezarăm": "morteza",
    "mortezarăți": "morteza",
    "mortezase": "morteza",
    "mortezasem": "morteza",
    "mortezaseră": "morteza",
    "mortezaserăm": "morteza",
    "mortezaserăți": "morteza",
    "mortezaseși": "morteza",
    "mortezași": "morteza",
    "mortezat": "morteza",
    "mortezați": "morteza",
    "mortezează": "morteza",
    "mortezez": "morteza",
    "mortezeze": "morteza",
    "mortezezi": "morteza",
    "nemaimortezând": "morteza",
    "nemaimortezându": "morteza",
    "nemortezând": "morteza",
    "nemortezându": "morteza",
    "morteza": "morteză",
    "morteze": "morteză",
    "mortezei": "morteză",
    "mortezele": "morteză",
    "mortezelor": "morteză",
    "mortezată": "mortezat",
    "mortezate": "mortezat",
    "mortezați": "mortezat",
    "mortiere": "mortier",
    "mortierele": "mortier",
    "mortierelor": "mortier",
    "mortierul": "mortier",
    "mortierului": "mortier",
    "mortifianta": "mortifiant",
    "mortifiantă": "mortifiant",
    "mortifiante": "mortifiant",
    "mortifiantei": "mortifiant",
    "mortifiantele": "mortifiant",
    "mortifiantelor": "mortifiant",
    "mortifianți": "mortifiant",
    "mortifianții": "mortifiant",
    "mortifianților": "mortifiant",
    "mortifiantul": "mortifiant",
    "mortifiantului": "mortifiant",
    "mortuara": "mortuar",
    "mortuară": "mortuar",
    "mortuare": "mortuar",
    "mortuarei": "mortuar",
    "mortuarele": "mortuar",
    "mortuarelor": "mortuar",
    "mortuari": "mortuar",
    "mortuarii": "mortuar",
    "mortuarilor": "mortuar",
    "mortuarul": "mortuar",
    "mortuarului": "mortuar",
    "moruni": "morun",
    "morunii": "morun",
    "morunilor": "morun",
    "morunul": "morun",
    "morunului": "morun",
    "morva": "morvă",
    "morve": "morvă",
    "morvei": "morvă",
    "morvele": "morvă",
    "morvelor": "morvă",
    "morvoasa": "morvos",
    "morvoasă": "morvos",
    "morvoase": "morvos",
    "morvoasei": "morvos",
    "morvoasele": "morvos",
    "morvoaselor": "morvos",
    "morvoși": "morvos",
    "morvoșii": "morvos",
    "morvoșilor": "morvos",
    "morvosul": "morvos",
    "morvosului": "morvos",
    "moși": "moș",
    "moșii": "moș",
    "moșilor": "moș",
    "moșul": "moș",
    "moșului": "moș",
    "Moș-Ajunul": "Moș-Ajun",
    "Moș-Ajunului": "Moș-Ajun",
    "moscul": "mosc",
    "moscului": "mosc",
    "moscuri": "mosc",
    "moscurile": "mosc",
    "moscurilor": "mosc",
    "moști": "mosc",
    "moștii": "mosc",
    "moștilor": "mosc",
    "moscata": "moscat",
    "moscată": "moscat",
    "moscate": "moscat",
    "moscatei": "moscat",
    "moscatele": "moscat",
    "moscatelor": "moscat",
    "moscați": "moscat",
    "moscații": "moscat",
    "moscaților": "moscat",
    "moscatul": "moscat",
    "moscatului": "moscat",
    "moscheea": "moschee",
    "moschei": "moschee",
    "moscheii": "moschee",
    "moscheile": "moschee",
    "moscheilor": "moschee",
    "Moscovă": "Moscova",
    "Moscove": "Moscova",
    "Moscovei": "Moscova",
    "moscovita": "moscovit",
    "moscovită": "moscovit",
    "moscovite": "moscovit",
    "moscovitei": "moscovit",
    "moscovitele": "moscovit",
    "moscovitelor": "moscovit",
    "moscoviți": "moscovit",
    "moscoviții": "moscovit",
    "moscoviților": "moscovit",
    "moscovitul": "moscovit",
    "moscovitului": "moscovit",
    "moscovita": "moscovită",
    "moscovite": "moscovită",
    "moscovitei": "moscovită",
    "moscovitele": "moscovită",
    "moscovitelor": "moscovită",
    "moșea": "moși",
    "moșeai": "moși",
    "moșeam": "moși",
    "moșească": "moși",
    "moșeați": "moși",
    "moșeau": "moși",
    "moșesc": "moși",
    "moșește": "moși",
    "moșești": "moși",
    "moșii": "moși",
    "moșim": "moși",
    "moșind": "moși",
    "moșindu": "moși",
    "moșiră": "moși",
    "moșirăm": "moși",
    "moșirăți": "moși",
    "moșise": "moși",
    "moșisem": "moși",
    "moșiseră": "moși",
    "moșiserăm": "moși",
    "moșiserăți": "moși",
    "moșiseși": "moși",
    "moșiși": "moși",
    "moșit": "moși",
    "moșiți": "moși",
    "moșitu": "moși",
    "nemaimoșind": "moși",
    "nemaimoșindu": "moși",
    "nemoșind": "moși",
    "nemoșindu": "moși",
    "moșia": "moșie",
    "moșiei": "moșie",
    "moșii": "moșie",
    "moșiile": "moșie",
    "moșiilor": "moșie",
    "moșieri": "moșier",
    "moșierii": "moșier",
    "moșierilor": "moșier",
    "moșierul": "moșier",
    "moșierului": "moșier",
    "moșiereasa": "moșiereasă",
    "moșierese": "moșiereasă",
    "moșieresei": "moșiereasă",
    "moșieresele": "moșiereasă",
    "moșiereselor": "moșiereasă",
    "moșiereasca": "moșieresc",
    "moșierească": "moșieresc",
    "moșierescul": "moșieresc",
    "moșierescului": "moșieresc",
    "moșierești": "moșieresc",
    "moșiereștii": "moșieresc",
    "moșiereștile": "moșieresc",
    "moșiereștilor": "moșieresc",
    "moșierimea": "moșierime",
    "moșierimi": "moșierime",
    "moșierimii": "moșierime",
    "moșierimile": "moșierime",
    "moșierimilor": "moșierime",
    "moșită": "moșit",
    "moșite": "moșit",
    "moșiți": "moșit",
    "moșmoana": "moșmoană",
    "moșmoane": "moșmoană",
    "moșmoanei": "moșmoană",
    "moșmoanele": "moșmoană",
    "moșmoanelor": "moșmoană",
    "moșmoni": "moșmon",
    "moșmonii": "moșmon",
    "moșmonilor": "moșmon",
    "moșmonul": "moșmon",
    "moșmonului": "moșmon",
    "moșmondea": "moșmondi",
    "moșmondeai": "moșmondi",
    "moșmondeam": "moșmondi",
    "moșmondească": "moșmondi",
    "moșmondeați": "moșmondi",
    "moșmondeau": "moșmondi",
    "moșmondesc": "moșmondi",
    "moșmondește": "moșmondi",
    "moșmondești": "moșmondi",
    "moșmondii": "moșmondi",
    "moșmondim": "moșmondi",
    "moșmondind": "moșmondi",
    "moșmondindu": "moșmondi",
    "moșmondiră": "moșmondi",
    "moșmondirăm": "moșmondi",
    "moșmondirăți": "moșmondi",
    "moșmondise": "moșmondi",
    "moșmondisem": "moșmondi",
    "moșmondiseră": "moșmondi",
    "moșmondiserăm": "moșmondi",
    "moșmondiserăți": "moșmondi",
    "moșmondiseși": "moșmondi",
    "moșmondiși": "moșmondi",
    "moșmondit": "moșmondi",
    "moșmondiți": "moșmondi",
    "moșmonditu": "moșmondi",
    "moșmondită": "moșmondit",
    "moșmondite": "moșmondit",
    "moșmondiți": "moșmondit",
    "moșmonea": "moșmoni",
    "moșmoneai": "moșmoni",
    "moșmoneam": "moșmoni",
    "moșmonească": "moșmoni",
    "moșmoneați": "moșmoni",
    "moșmoneau": "moșmoni",
    "moșmonesc": "moșmoni",
    "moșmonește": "moșmoni",
    "moșmonești": "moșmoni",
    "moșmonii": "moșmoni",
    "moșmonim": "moșmoni",
    "moșmonind": "moșmoni",
    "moșmonindu": "moșmoni",
    "moșmoniră": "moșmoni",
    "moșmonirăm": "moșmoni",
    "moșmonirăți": "moșmoni",
    "moșmonise": "moșmoni",
    "moșmonisem": "moșmoni",
    "moșmoniseră": "moșmoni",
    "moșmoniserăm": "moșmoni",
    "moșmoniserăți": "moșmoni",
    "moșmoniseși": "moșmoni",
    "moșmoniși": "moșmoni",
    "moșmonit": "moșmoni",
    "moșmoniți": "moșmoni",
    "moșmonitu": "moșmoni",
    "nemaimoșmonind": "moșmoni",
    "nemaimoșmonindu": "moșmoni",
    "nemoșmonind": "moșmoni",
    "nemoșmonindu": "moșmoni",
    "moșmonită": "moșmonit",
    "moșmonite": "moșmonit",
    "moșmoniți": "moșmonit",
    "moșneagul": "moșneag",
    "moșneagului": "moșneag",
    "moșnegi": "moșneag",
    "moșnegii": "moșneag",
    "moșnegilor": "moșneag",
    "moșneanul": "moșnean",
    "moșneanului": "moșnean",
    "moșneni": "moșnean",
    "moșnenii": "moșnean",
    "moșnenilor": "moșnean",
    "moșnegeasca": "moșnegesc",
    "moșnegească": "moșnegesc",
    "moșnegescul": "moșnegesc",
    "moșnegescului": "moșnegesc",
    "moșnegești": "moșnegesc",
    "moșnegeștii": "moșnegesc",
    "moșnegeștile": "moșnegesc",
    "moșnegeștilor": "moșnegesc",
    "mosoare": "mosor",
    "mosoarele": "mosor",
    "mosoarelor": "mosor",
    "mosorul": "mosor",
    "mosorului": "mosor",
    "moștenea": "moșteni",
    "moșteneai": "moșteni",
    "moșteneam": "moșteni",
    "moștenească": "moșteni",
    "moșteneați": "moșteni",
    "moșteneau": "moșteni",
    "moștenesc": "moșteni",
    "moștenește": "moșteni",
    "moștenești": "moșteni",
    "moștenii": "moșteni",
    "moștenim": "moșteni",
    "moștenind": "moșteni",
    "moștenindu": "moșteni",
    "moșteniră": "moșteni",
    "moștenirăm": "moșteni",
    "moștenirăți": "moșteni",
    "moștenise": "moșteni",
    "moștenisem": "moșteni",
    "moșteniseră": "moșteni",
    "moșteniserăm": "moșteni",
    "moșteniserăți": "moșteni",
    "moșteniseși": "moșteni",
    "moșteniși": "moșteni",
    "moștenit": "moșteni",
    "moșteniți": "moșteni",
    "moștenitu": "moșteni",
    "nemaimoștenind": "moșteni",
    "nemaimoștenindu": "moșteni",
    "nemoștenind": "moșteni",
    "nemoștenindu": "moșteni",
    "moștenirea": "moștenire",
    "moșteniri": "moștenire",
    "moștenirii": "moștenire",
    "moștenirile": "moștenire",
    "moștenirilor": "moștenire",
    "moștenită": "moștenit",
    "moștenite": "moștenit",
    "moșteniți": "moștenit",
    "moștenitoarea": "moștenitoare",
    "moștenitoarei": "moștenitoare",
    "moștenitoarele": "moștenitoare",
    "moștenitoarelor": "moștenitoare",
    "moștenitori": "moștenitor",
    "moștenitorii": "moștenitor",
    "moștenitorilor": "moștenitor",
    "moștenitorul": "moștenitor",
    "moștenitorului": "moștenitor",
    "mostra": "mostră",
    "mostre": "mostră",
    "mostrei": "mostră",
    "mostrele": "mostră",
    "mostrelor": "mostră",
    "moți": "moț",
    "moțul": "moț",
    "moțului": "moț",
    "moțuri": "moț",
    "moțurile": "moț",
    "moțurilor": "moț",
    "moțăia": "moțăi",
    "moțăiai": "moțăi",
    "moțăiam": "moțăi",
    "moțăiați": "moțăi",
    "moțăiau": "moțăi",
    "moțăie": "moțăi",
    "moțăii": "moțăi",
    "moțăim": "moțăi",
    "moțăind": "moțăi",
    "moțăindu": "moțăi",
    "moțăiră": "moțăi",
    "moțăirăm": "moțăi",
    "moțăirăți": "moțăi",
    "moțăise": "moțăi",
    "moțăisem": "moțăi",
    "moțăiseră": "moțăi",
    "moțăiserăm": "moțăi",
    "moțăiserăți": "moțăi",
    "moțăiseși": "moțăi",
    "moțăiși": "moțăi",
    "moțăit": "moțăi",
    "moțăiți": "moțăi",
    "moțăitu": "moțăi",
    "nemaimoțăind": "moțăi",
    "nemaimoțăindu": "moțăi",
    "nemoțăind": "moțăi",
    "nemoțăindu": "moțăi",
    "moțăiala": "moțăială",
    "moțăieli": "moțăială",
    "moțăielii": "moțăială",
    "moțăielile": "moțăială",
    "moțăielilor": "moțăială",
    "moțăită": "moțăit",
    "moțăite": "moțăit",
    "moțăiți": "moțăit",
    "motani": "motan",
    "motanii": "motan",
    "motanilor": "motan",
    "motanul": "motan",
    "motanului": "motan",
    "motănași": "motănaș",
    "motănașii": "motănaș",
    "motănașilor": "motănaș",
    "motănașul": "motănaș",
    "motănașule": "motănaș",
    "motănașului": "motănaș",
    "motelul": "motel",
    "motelului": "motel",
    "moteluri": "motel",
    "motelurile": "motel",
    "motelurilor": "motel",
    "moțeasca": "moțesc",
    "moțească": "moțesc",
    "moțescul": "moțesc",
    "moțescului": "moțesc",
    "moțești": "moțesc",
    "moțeștii": "moțesc",
    "moțeștile": "moțesc",
    "moțeștilor": "moțesc",
    "motetul": "motet",
    "motetului": "motet",
    "motilitatea": "motilitate",
    "motilități": "motilitate",
    "motilității": "motilitate",
    "motilitățile": "motilitate",
    "motilităților": "motilitate",
    "moționala": "moțional",
    "moțională": "moțional",
    "moționale": "moțional",
    "moționalei": "moțional",
    "moționalele": "moțional",
    "moționalelor": "moțional",
    "moționali": "moțional",
    "moționalii": "moțional",
    "moționalilor": "moțional",
    "moționalul": "moțional",
    "moționalului": "moțional",
    "moțiunea": "moțiune",
    "moțiuni": "moțiune",
    "moțiunii": "moțiune",
    "moțiunile": "moțiune",
    "moțiunilor": "moțiune",
    "motive": "motiv",
    "motivele": "motiv",
    "motivelor": "motiv",
    "motivul": "motiv",
    "motivului": "motiv",
    "motivă": "motiva",
    "motivai": "motiva",
    "motivam": "motiva",
    "motivăm": "motiva",
    "motivând": "motiva",
    "motivându": "motiva",
    "motivară": "motiva",
    "motivarăm": "motiva",
    "motivarăți": "motiva",
    "motivase": "motiva",
    "motivasem": "motiva",
    "motivaseră": "motiva",
    "motivaserăm": "motiva",
    "motivaserăți": "motiva",
    "motivaseși": "motiva",
    "motivași": "motiva",
    "motivat": "motiva",
    "motivați": "motiva",
    "motivatu": "motiva",
    "motivau": "motiva",
    "motivează": "motiva",
    "motivez": "motiva",
    "motiveze": "motiva",
    "motivezi": "motiva",
    "nemaimotivând": "motiva",
    "nemaimotivându": "motiva",
    "nemotivând": "motiva",
    "nemotivându": "motiva",
    "motivarea": "motivare",
    "motivări": "motivare",
    "motivării": "motivare",
    "motivările": "motivare",
    "motivărilor": "motivare",
    "motivată": "motivat",
    "motivate": "motivat",
    "motivați": "motivat",
    "motivația": "motivație",
    "motivației": "motivație",
    "motivații": "motivație",
    "motivațiile": "motivație",
    "motivațiilor": "motivație",
    "motoul": "moto",
    "motoului": "moto",
    "motouri": "moto",
    "motourile": "moto",
    "motourilor": "moto",
    "motocicleta": "motocicletă",
    "motociclete": "motocicletă",
    "motocicletei": "motocicletă",
    "motocicletele": "motocicletă",
    "motocicletelor": "motocicletă",
    "motociclismul": "motociclism",
    "motociclismului": "motociclism",
    "motociclista": "motociclist",
    "motociclistă": "motociclist",
    "motocicliste": "motociclist",
    "motociclistei": "motociclist",
    "motociclistele": "motociclist",
    "motociclistelor": "motociclist",
    "motocicliști": "motociclist",
    "motocicliștii": "motociclist",
    "motocicliștilor": "motociclist",
    "motociclistul": "motociclist",
    "motociclistului": "motociclist",
    "motociclista": "motociclistă",
    "motocicliste": "motociclistă",
    "motociclistei": "motociclistă",
    "motociclistele": "motociclistă",
    "motociclistelor": "motociclistă",
    "motocompresoare": "motocompresor",
    "motocompresoarele": "motocompresor",
    "motocompresoarelor": "motocompresor",
    "motocompresorul": "motocompresor",
    "motocompresorului": "motocompresor",
    "motocrosul": "motocros",
    "motocrosului": "motocros",
    "motocrosuri": "motocros",
    "motocrosurile": "motocros",
    "motocrosurilor": "motocros",
    "motomecanizata": "motomecanizat",
    "motomecanizată": "motomecanizat",
    "motomecanizate": "motomecanizat",
    "motomecanizatei": "motomecanizat",
    "motomecanizatele": "motomecanizat",
    "motomecanizatelor": "motomecanizat",
    "motomecanizați": "motomecanizat",
    "motomecanizații": "motomecanizat",
    "motomecanizaților": "motomecanizat",
    "motomecanizatul": "motomecanizat",
    "motomecanizatului": "motomecanizat",
    "motonava": "motonavă",
    "motonave": "motonavă",
    "motonavei": "motonavă",
    "motonavele": "motonavă",
    "motonavelor": "motonavă",
    "motopompa": "motopompă",
    "motopompe": "motopompă",
    "motopompei": "motopompă",
    "motopompele": "motopompă",
    "motopompelor": "motopompă",
    "motopropulsoare": "motopropulsor",
    "motopropulsoarele": "motopropulsor",
    "motopropulsoarelor": "motopropulsor",
    "motopropulsorul": "motopropulsor",
    "motopropulsorului": "motopropulsor",
    "motoare": "motor",
    "motoarea": "motor",
    "motoarei": "motor",
    "motoarele": "motor",
    "motoarelor": "motor",
    "motori": "motor",
    "motorii": "motor",
    "motorilor": "motor",
    "motorul": "motor",
    "motorului": "motor",
    "motoreactoare": "motoreactor",
    "motoreactoarele": "motoreactor",
    "motoreactoarelor": "motoreactor",
    "motoreactorul": "motoreactor",
    "motoreactorului": "motoreactor",
    "motoreta": "motoretă",
    "motorete": "motoretă",
    "motoretei": "motoretă",
    "motoretele": "motoretă",
    "motoretelor": "motoretă",
    "motorina": "motorină",
    "motorine": "motorină",
    "motorinei": "motorină",
    "motorinele": "motorină",
    "motorinelor": "motorină",
    "motoriză": "motoriza",
    "motorizai": "motoriza",
    "motorizam": "motoriza",
    "motorizăm": "motoriza",
    "motorizând": "motoriza",
    "motorizându": "motoriza",
    "motorizară": "motoriza",
    "motorizarăm": "motoriza",
    "motorizarăți": "motoriza",
    "motorizase": "motoriza",
    "motorizasem": "motoriza",
    "motorizaseră": "motoriza",
    "motorizaserăm": "motoriza",
    "motorizaserăți": "motoriza",
    "motorizaseși": "motoriza",
    "motorizași": "motoriza",
    "motorizat": "motoriza",
    "motorizați": "motoriza",
    "motorizatu": "motoriza",
    "motorizau": "motoriza",
    "motorizează": "motoriza",
    "motorizez": "motoriza",
    "motorizeze": "motoriza",
    "motorizezi": "motoriza",
    "nemaimotorizând": "motoriza",
    "nemaimotorizându": "motoriza",
    "nemotorizând": "motoriza",
    "nemotorizându": "motoriza",
    "motorizată": "motorizat",
    "motorizate": "motorizat",
    "motorizați": "motorizat",
    "mototoala": "mototoală",
    "mototoale": "mototoală",
    "mototoalei": "mototoală",
    "mototoalele": "mototoală",
    "mototoalelor": "mototoală",
    "mototoala": "mototol",
    "mototoală": "mototol",
    "mototoale": "mototol",
    "mototoalei": "mototol",
    "mototoalele": "mototol",
    "mototoalelor": "mototol",
    "mototoli": "mototol",
    "mototolii": "mototol",
    "mototolilor": "mototol",
    "mototolul": "mototol",
    "mototolului": "mototol",
    "mototolea": "mototoli",
    "mototoleai": "mototoli",
    "mototoleam": "mototoli",
    "mototolească": "mototoli",
    "mototoleați": "mototoli",
    "mototoleau": "mototoli",
    "mototolesc": "mototoli",
    "mototolește": "mototoli",
    "mototolești": "mototoli",
    "mototolii": "mototoli",
    "mototolim": "mototoli",
    "mototolind": "mototoli",
    "mototolindu": "mototoli",
    "mototoliră": "mototoli",
    "mototolirăm": "mototoli",
    "mototolirăți": "mototoli",
    "mototolise": "mototoli",
    "mototolisem": "mototoli",
    "mototoliseră": "mototoli",
    "mototoliserăm": "mototoli",
    "mototoliserăți": "mototoli",
    "mototoliseși": "mototoli",
    "mototoliși": "mototoli",
    "mototolit": "mototoli",
    "mototoliți": "mototoli",
    "mototolitu": "mototoli",
    "nemaimototolind": "mototoli",
    "nemaimototolindu": "mototoli",
    "nemototolind": "mototoli",
    "nemototolindu": "mototoli",
    "mototolită": "mototolit",
    "mototolite": "mototolit",
    "mototoliți": "mototolit",
    "motricitatea": "motricitate",
    "motricități": "motricitate",
    "motricității": "motricitate",
    "motricitățile": "motricitate",
    "motricităților": "motricitate",
    "movila": "movilă",
    "movile": "movilă",
    "movilei": "movilă",
    "movilele": "movilă",
    "movilelor": "movilă",
    "movilea": "movili",
    "movileai": "movili",
    "movileam": "movili",
    "movilească": "movili",
    "movileați": "movili",
    "movileau": "movili",
    "movilesc": "movili",
    "movilește": "movili",
    "movilești": "movili",
    "movilii": "movili",
    "movilim": "movili",
    "movilind": "movili",
    "movilindu": "movili",
    "moviliră": "movili",
    "movilirăm": "movili",
    "movilirăți": "movili",
    "movilise": "movili",
    "movilisem": "movili",
    "moviliseră": "movili",
    "moviliserăm": "movili",
    "moviliserăți": "movili",
    "moviliseși": "movili",
    "moviliși": "movili",
    "movilit": "movili",
    "moviliți": "movili",
    "movilitu": "movili",
    "nemaimovilind": "movili",
    "nemaimovilindu": "movili",
    "nemovilind": "movili",
    "nemovilindu": "movili",
    "movilită": "movilit",
    "movilite": "movilit",
    "moviliți": "movilit",
    "mozaica": "mozaic",
    "mozaică": "mozaic",
    "mozaice": "mozaic",
    "mozaicei": "mozaic",
    "mozaicele": "mozaic",
    "mozaicelor": "mozaic",
    "mozaici": "mozaic",
    "mozaicii": "mozaic",
    "mozaicilor": "mozaic",
    "mozaicul": "mozaic",
    "mozaicului": "mozaic",
    "mozaicuri": "mozaic",
    "mozaicurile": "mozaic",
    "mozaicurilor": "mozaic",
    "mozaismul": "mozaism",
    "mozaismului": "mozaism",
    "mozolea": "mozoli",
    "mozoleai": "mozoli",
    "mozoleam": "mozoli",
    "mozolească": "mozoli",
    "mozoleați": "mozoli",
    "mozoleau": "mozoli",
    "mozolesc": "mozoli",
    "mozolește": "mozoli",
    "mozolești": "mozoli",
    "mozolii": "mozoli",
    "mozolim": "mozoli",
    "mozolind": "mozoli",
    "mozolindu": "mozoli",
    "mozoliră": "mozoli",
    "mozolirăm": "mozoli",
    "mozolirăți": "mozoli",
    "mozolise": "mozoli",
    "mozolisem": "mozoli",
    "mozoliseră": "mozoli",
    "mozoliserăm": "mozoli",
    "mozoliserăți": "mozoli",
    "mozoliseși": "mozoli",
    "mozoliși": "mozoli",
    "mozolit": "mozoli",
    "mozoliți": "mozoli",
    "mozolitu": "mozoli",
    "nemaimozolind": "mozoli",
    "nemaimozolindu": "mozoli",
    "nemozolind": "mozoli",
    "nemozolindu": "mozoli",
    "mozolită": "mozolit",
    "mozolite": "mozolit",
    "mozoliți": "mozolit",
    "mranița": "mraniță",
    "mranițe": "mraniță",
    "mraniței": "mraniță",
    "mreaja": "mreajă",
    "mreje": "mreajă",
    "mrejei": "mreajă",
    "mrejele": "mreajă",
    "mrejelor": "mreajă",
    "mreana": "mreană",
    "mrene": "mreană",
    "mrenei": "mreană",
    "mrenele": "mreană",
    "mrenelor": "mreană",
    "muabila": "muabil",
    "muabilă": "muabil",
    "muabile": "muabil",
    "muabilei": "muabil",
    "muabilele": "muabil",
    "muabilelor": "muabil",
    "muabili": "muabil",
    "muabilii": "muabil",
    "muabililor": "muabil",
    "muabilul": "muabil",
    "muabilului": "muabil",
    "muci": "muc",
    "mucii": "muc",
    "mucilor": "muc",
    "mucul": "muc",
    "mucului": "muc",
    "mucuri": "muc",
    "mucurile": "muc",
    "mucurilor": "muc",
    "mucalita": "mucalit",
    "mucalită": "mucalit",
    "mucalite": "mucalit",
    "mucalitei": "mucalit",
    "mucalitele": "mucalit",
    "mucalitelor": "mucalit",
    "mucaliți": "mucalit",
    "mucaliții": "mucalit",
    "mucaliților": "mucalit",
    "mucalitul": "mucalit",
    "mucalitului": "mucalit",
    "mucavale": "mucava",
    "mucavalei": "mucava",
    "mucavalele": "mucava",
    "mucavalelor": "mucava",
    "mucavaua": "mucava",
    "muceda": "muced",
    "mucedă": "muced",
    "mucede": "muced",
    "mucedei": "muced",
    "mucedele": "muced",
    "mucedelor": "muced",
    "mucedul": "muced",
    "mucedului": "muced",
    "mucezi": "muced",
    "mucezii": "muced",
    "mucezilor": "muced",
    "mucegaiul": "mucegai",
    "mucegaiului": "mucegai",
    "mucegaiuri": "mucegai",
    "mucegaiurile": "mucegai",
    "mucegaiurilor": "mucegai",
    "mucegăioasa": "mucegăios",
    "mucegăioasă": "mucegăios",
    "mucegăioase": "mucegăios",
    "mucegăioasei": "mucegăios",
    "mucegăioasele": "mucegăios",
    "mucegăioaselor": "mucegăios",
    "mucegăioși": "mucegăios",
    "mucegăioșii": "mucegăios",
    "mucegăioșilor": "mucegăios",
    "mucegăiosul": "mucegăios",
    "mucegăiosului": "mucegăios",
    "mucegăita": "mucegăit",
    "mucegăită": "mucegăit",
    "mucegăite": "mucegăit",
    "mucegăitei": "mucegăit",
    "mucegăitele": "mucegăit",
    "mucegăitelor": "mucegăit",
    "mucegăiți": "mucegăit",
    "mucegăiții": "mucegăit",
    "mucegăiților": "mucegăit",
    "mucegăitul": "mucegăit",
    "mucegăitului": "mucegăit",
    "mucenica": "mucenic",
    "mucenică": "mucenic",
    "mucenice": "mucenic",
    "mucenicei": "mucenic",
    "mucenicele": "mucenic",
    "mucenicelor": "mucenic",
    "mucenici": "mucenic",
    "mucenicii": "mucenic",
    "mucenicilor": "mucenic",
    "mucenicul": "mucenic",
    "mucenicului": "mucenic",
    "mucenica": "mucenică",
    "mucenice": "mucenică",
    "mucenicei": "mucenică",
    "mucenicele": "mucenică",
    "mucenicelor": "mucenică",
    "mucenicia": "mucenicie",
    "muceniciei": "mucenicie",
    "mucenicii": "mucenicie",
    "mucenița": "muceniță",
    "mucenițe": "muceniță",
    "muceniței": "muceniță",
    "mucenițele": "muceniță",
    "mucenițelor": "muceniță",
    "mucenițo": "muceniță",
    "mucezea": "mucezi",
    "mucezeai": "mucezi",
    "mucezeam": "mucezi",
    "mucezească": "mucezi",
    "mucezeați": "mucezi",
    "mucezeau": "mucezi",
    "mucezesc": "mucezi",
    "mucezește": "mucezi",
    "mucezești": "mucezi",
    "mucezii": "mucezi",
    "mucezim": "mucezi",
    "mucezind": "mucezi",
    "mucezindu": "mucezi",
    "muceziră": "mucezi",
    "mucezirăm": "mucezi",
    "mucezirăți": "mucezi",
    "mucezise": "mucezi",
    "mucezisem": "mucezi",
    "muceziseră": "mucezi",
    "muceziserăm": "mucezi",
    "muceziserăți": "mucezi",
    "muceziseși": "mucezi",
    "muceziși": "mucezi",
    "mucezit": "mucezi",
    "muceziți": "mucezi",
    "mucezitu": "mucezi",
    "nemaimucezind": "mucezi",
    "nemaimucezindu": "mucezi",
    "nemucezind": "mucezi",
    "nemucezindu": "mucezi",
    "mucezită": "mucezit",
    "mucezite": "mucezit",
    "muceziți": "mucezit",
    "muchia": "muchie",
    "muchiei": "muchie",
    "muchii": "muchie",
    "muchiile": "muchie",
    "muchiilor": "muchie",
    "mucilaginoasa": "mucilaginos",
    "mucilaginoasă": "mucilaginos",
    "mucilaginoase": "mucilaginos",
    "mucilaginoasei": "mucilaginos",
    "mucilaginoasele": "mucilaginos",
    "mucilaginoaselor": "mucilaginos",
    "mucilaginoși": "mucilaginos",
    "mucilaginoșii": "mucilaginos",
    "mucilaginoșilor": "mucilaginos",
    "mucilaginosul": "mucilaginos",
    "mucilaginosului": "mucilaginos",
    "mucilagii": "mucilagiu",
    "mucilagiile": "mucilagiu",
    "mucilagiilor": "mucilagiu",
    "mucilagiul": "mucilagiu",
    "mucilagiului": "mucilagiu",
    "mucoasa": "mucoasă",
    "mucoase": "mucoasă",
    "mucoasei": "mucoasă",
    "mucoasele": "mucoasă",
    "mucoaselor": "mucoasă",
    "mucoasa": "mucos",
    "mucoasă": "mucos",
    "mucoase": "mucos",
    "mucoasei": "mucos",
    "mucoasele": "mucos",
    "mucoaselor": "mucos",
    "mucoși": "mucos",
    "mucoșii": "mucos",
    "mucoșilor": "mucos",
    "mucosul": "mucos",
    "mucosului": "mucos",
    "mucozitatea": "mucozitate",
    "mucozități": "mucozitate",
    "mucozității": "mucozitate",
    "mucozitățile": "mucozitate",
    "mucozităților": "mucozitate",
    "mucusul": "mucus",
    "mucusului": "mucus",
    "muezini": "muezin",
    "muezinii": "muezin",
    "muezinilor": "muezin",
    "muezinul": "muezin",
    "muezinului": "muezin",
    "mufa": "mufă",
    "mufe": "mufă",
    "mufei": "mufă",
    "mufele": "mufă",
    "mufelor": "mufă",
    "mufla": "muflă",
    "mufle": "muflă",
    "muflei": "muflă",
    "muflele": "muflă",
    "muflelor": "muflă",
    "mufloni": "muflon",
    "muflonii": "muflon",
    "muflonilor": "muflon",
    "muflonul": "muflon",
    "muflonului": "muflon",
    "muftii": "muftiu",
    "muftiii": "muftiu",
    "muftiilor": "muftiu",
    "muftiul": "muftiu",
    "muftiului": "muftiu",
    "mugete": "muget",
    "mugetele": "muget",
    "mugetelor": "muget",
    "mugetul": "muget",
    "mugetului": "muget",
    "mugea": "mugi",
    "mugeai": "mugi",
    "mugeam": "mugi",
    "mugească": "mugi",
    "mugeați": "mugi",
    "mugeau": "mugi",
    "mugesc": "mugi",
    "mugește": "mugi",
    "mugești": "mugi",
    "mugii": "mugi",
    "mugim": "mugi",
    "mugind": "mugi",
    "mugindu": "mugi",
    "mugiră": "mugi",
    "mugirăm": "mugi",
    "mugirăți": "mugi",
    "mugise": "mugi",
    "mugisem": "mugi",
    "mugiseră": "mugi",
    "mugiserăm": "mugi",
    "mugiserăți": "mugi",
    "mugiseși": "mugi",
    "mugiși": "mugi",
    "mugit": "mugi",
    "mugiți": "mugi",
    "mugitu": "mugi",
    "muginda": "mugind",
    "mugindă": "mugind",
    "muginde": "mugind",
    "mugindei": "mugind",
    "mugindele": "mugind",
    "mugindelor": "mugind",
    "mugindul": "mugind",
    "mugindului": "mugind",
    "muginzi": "mugind",
    "muginzii": "mugind",
    "muginzilor": "mugind",
    "mugită": "mugit",
    "mugite": "mugit",
    "mugiți": "mugit",
    "mugitoare": "mugitor",
    "mugitoarea": "mugitor",
    "mugitoarei": "mugitor",
    "mugitoarele": "mugitor",
    "mugitoarelor": "mugitor",
    "mugitori": "mugitor",
    "mugitorii": "mugitor",
    "mugitorilor": "mugitor",
    "mugitorul": "mugitor",
    "mugitorului": "mugitor",
    "mugurele": "mugure",
    "mugurelui": "mugure",
    "muguri": "mugure",
    "mugurii": "mugure",
    "mugurilor": "mugure",
    "moaie": "muia",
    "moi": "muia",
    "muiai": "muia",
    "muiam": "muia",
    "muiară": "muia",
    "muiarăm": "muia",
    "muiarăți": "muia",
    "muiase": "muia",
    "muiasem": "muia",
    "muiaseră": "muia",
    "muiaserăm": "muia",
    "muiaserăți": "muia",
    "muiaseși": "muia",
    "muiași": "muia",
    "muiat": "muia",
    "muiați": "muia",
    "muiatu": "muia",
    "muiau": "muia",
    "muie": "muia",
    "muiem": "muia",
    "muind": "muia",
    "muindu": "muia",
    "nemaimuind": "muia",
    "nemaimuindu": "muia",
    "nemuind": "muia",
    "nemuindu": "muia",
    "muianta": "muiant",
    "muiantă": "muiant",
    "muiante": "muiant",
    "muiantei": "muiant",
    "muiantele": "muiant",
    "muiantelor": "muiant",
    "muianți": "muiant",
    "muianții": "muiant",
    "muianților": "muiant",
    "muiantul": "muiant",
    "muiantului": "muiant",
    "muiată": "muiat",
    "muiate": "muiat",
    "muiați": "muiat",
    "muieratica": "muieratic",
    "muieratică": "muieratic",
    "muieratice": "muieratic",
    "muieraticei": "muieratic",
    "muieraticele": "muieratic",
    "muieraticelor": "muieratic",
    "muieratici": "muieratic",
    "muieraticii": "muieratic",
    "muieraticilor": "muieratic",
    "muieraticul": "muieratic",
    "muieraticului": "muieratic",
    "muierea": "muiere",
    "muieri": "muiere",
    "muierii": "muiere",
    "muierile": "muiere",
    "muierilor": "muiere",
    "muiereasca": "muieresc",
    "muierească": "muieresc",
    "muierescul": "muieresc",
    "muierescului": "muieresc",
    "muierești": "muieresc",
    "muiereștii": "muieresc",
    "muiereștile": "muieresc",
    "muiereștilor": "muieresc",
    "muieroasa": "muieros",
    "muieroasă": "muieros",
    "muieroase": "muieros",
    "muieroasei": "muieros",
    "muieroasele": "muieros",
    "muieroaselor": "muieros",
    "muieroși": "muieros",
    "muieroșii": "muieros",
    "muieroșilor": "muieros",
    "muierosul": "muieros",
    "muierosului": "muieros",
    "muierușca": "muierușcă",
    "muierușco": "muierușcă",
    "muieruște": "muierușcă",
    "muieruștei": "muierușcă",
    "muieruștele": "muierușcă",
    "muieruștelor": "muierușcă",
    "mujdeiul": "mujdei",
    "mujdeiului": "mujdei",
    "mulă": "mula",
    "mulai": "mula",
    "mulam": "mula",
    "mulăm": "mula",
    "mulând": "mula",
    "mulându": "mula",
    "mulară": "mula",
    "mularăm": "mula",
    "mularăți": "mula",
    "mulase": "mula",
    "mulasem": "mula",
    "mulaseră": "mula",
    "mulaserăm": "mula",
    "mulaserăți": "mula",
    "mulaseși": "mula",
    "mulași": "mula",
    "mulat": "mula",
    "mulați": "mula",
    "mulatu": "mula",
    "mulau": "mula",
    "mulează": "mula",
    "mulez": "mula",
    "muleze": "mula",
    "mulezi": "mula",
    "nemaimulând": "mula",
    "nemaimulându": "mula",
    "nemulând": "mula",
    "nemulându": "mula",
    "mulaje": "mulaj",
    "mulajele": "mulaj",
    "mulajelor": "mulaj",
    "mulajul": "mulaj",
    "mulajului": "mulaj",
    "mulată": "mulat",
    "mulate": "mulat",
    "mulați": "mulat",
    "mulatra": "mulatră",
    "mulatre": "mulatră",
    "mulatrei": "mulatră",
    "mulatrele": "mulatră",
    "mulatrelor": "mulatră",
    "mulatri": "mulatru",
    "mulatrii": "mulatru",
    "mulatrilor": "mulatru",
    "mulatrul": "mulatru",
    "mulatrului": "mulatru",
    "mulgătoare": "mulgător",
    "mulgătoarea": "mulgător",
    "mulgătoarei": "mulgător",
    "mulgătoarele": "mulgător",
    "mulgătoarelor": "mulgător",
    "mulgători": "mulgător",
    "mulgătorii": "mulgător",
    "mulgătorilor": "mulgător",
    "mulgătorul": "mulgător",
    "mulgătorului": "mulgător",
    "mulg": "mulge",
    "mulgă": "mulge",
    "mulgând": "mulge",
    "mulgându": "mulge",
    "mulgea": "mulge",
    "mulgeai": "mulge",
    "mulgeam": "mulge",
    "mulgeați": "mulge",
    "mulgeau": "mulge",
    "mulgem": "mulge",
    "mulgeți": "mulge",
    "mulgi": "mulge",
    "muls": "mulge",
    "mulse": "mulge",
    "mulsei": "mulge",
    "mulseră": "mulge",
    "mulserăm": "mulge",
    "mulserăți": "mulge",
    "mulsese": "mulge",
    "mulsesem": "mulge",
    "mulseseră": "mulge",
    "mulseserăm": "mulge",
    "mulseserăți": "mulge",
    "mulseseși": "mulge",
    "mulseși": "mulge",
    "mulsu": "mulge",
    "nemaimulgând": "mulge",
    "nemaimulgându": "mulge",
    "nemulgând": "mulge",
    "nemulgându": "mulge",
    "mulineta": "mulinetă",
    "mulinete": "mulinetă",
    "mulinetei": "mulinetă",
    "mulinetele": "mulinetă",
    "mulinetelor": "mulinetă",
    "mulsă": "muls",
    "mulse": "muls",
    "mulși": "muls",
    "mulsul": "muls",
    "mulsului": "muls",
    "mulsoarea": "mulsoare",
    "mulsori": "mulsoare",
    "mulsorii": "mulsoare",
    "mulsorile": "mulsoare",
    "mulsorilor": "mulsoare",
    "mul'": "mult",
    "multa": "mult",
    "multă": "mult",
    "multe": "mult",
    "multei": "mult",
    "multele": "mult",
    "multelor": "mult",
    "mulți": "mult",
    "mulții": "mult",
    "multo": "mult",
    "multor": "mult",
    "multora": "mult",
    "multul": "mult",
    "multule": "mult",
    "multului": "mult",
    "multicelulara": "multicelular",
    "multicelulară": "multicelular",
    "multicelulare": "multicelular",
    "multicelularei": "multicelular",
    "multicelularele": "multicelular",
    "multicelularelor": "multicelular",
    "multicelulari": "multicelular",
    "multicelularii": "multicelular",
    "multicelularilor": "multicelular",
    "multicelularul": "multicelular",
    "multicelularului": "multicelular",
    "multicolora": "multicolor",
    "multicoloră": "multicolor",
    "multicolore": "multicolor",
    "multicolorei": "multicolor",
    "multicolorele": "multicolor",
    "multicolorelor": "multicolor",
    "multicolori": "multicolor",
    "multicolorii": "multicolor",
    "multicolorilor": "multicolor",
    "multicolorul": "multicolor",
    "multicolorului": "multicolor",
    "multiflora": "multiflor",
    "multifloră": "multiflor",
    "multiflore": "multiflor",
    "multiflorei": "multiflor",
    "multiflorele": "multiflor",
    "multiflorelor": "multiflor",
    "multiflori": "multiflor",
    "multiflorii": "multiflor",
    "multiflorilor": "multiflor",
    "multiflorul": "multiflor",
    "multiflorului": "multiflor",
    "multiforma": "multiform",
    "multiformă": "multiform",
    "multiforme": "multiform",
    "multiformei": "multiform",
    "multiformele": "multiform",
    "multiformelor": "multiform",
    "multiformi": "multiform",
    "multiformii": "multiform",
    "multiformilor": "multiform",
    "multiformul": "multiform",
    "multiformului": "multiform",
    "multilaterala": "multilateral",
    "multilaterală": "multilateral",
    "multilaterale": "multilateral",
    "multilateralei": "multilateral",
    "multilateralele": "multilateral",
    "multilateralelor": "multilateral",
    "multilaterali": "multilateral",
    "multilateralii": "multilateral",
    "multilateralilor": "multilateral",
    "multilateralul": "multilateral",
    "multilateralului": "multilateral",
    "multilingva": "multilingv",
    "multilingvă": "multilingv",
    "multilingve": "multilingv",
    "multilingvei": "multilingv",
    "multilingvele": "multilingv",
    "multilingvelor": "multilingv",
    "multilingvi": "multilingv",
    "multilingvii": "multilingv",
    "multilingvilor": "multilingv",
    "multilingvul": "multilingv",
    "multilingvului": "multilingv",
    "multilobata": "multilobat",
    "multilobată": "multilobat",
    "multilobate": "multilobat",
    "multilobatei": "multilobat",
    "multilobatele": "multilobat",
    "multilobatelor": "multilobat",
    "multilobați": "multilobat",
    "multilobații": "multilobat",
    "multilobaților": "multilobat",
    "multilobatul": "multilobat",
    "multilobatului": "multilobat",
    "mulțimea": "mulțime",
    "mulțimi": "mulțime",
    "mulțimii": "mulțime",
    "mulțimile": "mulțime",
    "mulțimilor": "mulțime",
    "multimilenara": "multimilenar",
    "multimilenară": "multimilenar",
    "multimilenare": "multimilenar",
    "multimilenarei": "multimilenar",
    "multimilenarele": "multimilenar",
    "multimilenarelor": "multimilenar",
    "multimilenari": "multimilenar",
    "multimilenarii": "multimilenar",
    "multimilenarilor": "multimilenar",
    "multimilenarul": "multimilenar",
    "multimilenarului": "multimilenar",
    "multimiliardara": "multimiliardar",
    "multimiliardară": "multimiliardar",
    "multimiliardare": "multimiliardar",
    "multimiliardarei": "multimiliardar",
    "multimiliardarele": "multimiliardar",
    "multimiliardarelor": "multimiliardar",
    "multimiliardari": "multimiliardar",
    "multimiliardarii": "multimiliardar",
    "multimiliardarilor": "multimiliardar",
    "multimiliardarul": "multimiliardar",
    "multimiliardarului": "multimiliardar",
    "multimilionara": "multimilionar",
    "multimilionară": "multimilionar",
    "multimilionare": "multimilionar",
    "multimilionarei": "multimilionar",
    "multimilionarele": "multimilionar",
    "multimilionarelor": "multimilionar",
    "multimilionari": "multimilionar",
    "multimilionarii": "multimilionar",
    "multimilionarilor": "multimilionar",
    "multimilionarul": "multimilionar",
    "multimilionarului": "multimilionar",
    "multimilionara": "multimilionară",
    "multimilionare": "multimilionară",
    "multimilionarei": "multimilionară",
    "multimilionarele": "multimilionară",
    "multimilionarelor": "multimilionară",
    "multinaționala": "multinațional",
    "multinațională": "multinațional",
    "multinaționale": "multinațional",
    "multinaționalei": "multinațional",
    "multinaționalele": "multinațional",
    "multinaționalelor": "multinațional",
    "multinaționali": "multinațional",
    "multinaționalii": "multinațional",
    "multinaționalilor": "multinațional",
    "multinaționalul": "multinațional",
    "multinaționalului": "multinațional",
    "multiplic": "multiplica",
    "multiplică": "multiplica",
    "multiplicai": "multiplica",
    "multiplicam": "multiplica",
    "multiplicăm": "multiplica",
    "multiplicând": "multiplica",
    "multiplicându": "multiplica",
    "multiplicară": "multiplica",
    "multiplicarăm": "multiplica",
    "multiplicarăți": "multiplica",
    "multiplicase": "multiplica",
    "multiplicasem": "multiplica",
    "multiplicaseră": "multiplica",
    "multiplicaserăm": "multiplica",
    "multiplicaserăți": "multiplica",
    "multiplicaseși": "multiplica",
    "multiplicași": "multiplica",
    "multiplicat": "multiplica",
    "multiplicați": "multiplica",
    "multiplicatu": "multiplica",
    "multiplicau": "multiplica",
    "multiplice": "multiplica",
    "multiplici": "multiplica",
    "nemaimultiplicând": "multiplica",
    "nemaimultiplicându": "multiplica",
    "nemultiplicând": "multiplica",
    "nemultiplicându": "multiplica",
    "multiplicabila": "multiplicabil",
    "multiplicabilă": "multiplicabil",
    "multiplicabile": "multiplicabil",
    "multiplicabilei": "multiplicabil",
    "multiplicabilele": "multiplicabil",
    "multiplicabilelor": "multiplicabil",
    "multiplicabili": "multiplicabil",
    "multiplicabilii": "multiplicabil",
    "multiplicabililor": "multiplicabil",
    "multiplicabilul": "multiplicabil",
    "multiplicabilului": "multiplicabil",
    "multiplicată": "multiplicat",
    "multiplicate": "multiplicat",
    "multiplicați": "multiplicat",
    "multiplicativa": "multiplicativ",
    "multiplicativă": "multiplicativ",
    "multiplicative": "multiplicativ",
    "multiplicativei": "multiplicativ",
    "multiplicativele": "multiplicativ",
    "multiplicativelor": "multiplicativ",
    "multiplicativi": "multiplicativ",
    "multiplicativii": "multiplicativ",
    "multiplicativilor": "multiplicativ",
    "multiplicativul": "multiplicativ",
    "multiplicativului": "multiplicativ",
    "multiplicitatea": "multiplicitate",
    "multiplicități": "multiplicitate",
    "multiplicității": "multiplicitate",
    "multipla": "multiplu",
    "multiplă": "multiplu",
    "multiple": "multiplu",
    "multiplei": "multiplu",
    "multiplele": "multiplu",
    "multiplelor": "multiplu",
    "multipli": "multiplu",
    "multiplii": "multiplu",
    "multiplilor": "multiplu",
    "multiplul": "multiplu",
    "multiplului": "multiplu",
    "multipolara": "multipolar",
    "multipolară": "multipolar",
    "multipolare": "multipolar",
    "multipolarei": "multipolar",
    "multipolarele": "multipolar",
    "multipolarelor": "multipolar",
    "multipolari": "multipolar",
    "multipolarii": "multipolar",
    "multipolarilor": "multipolar",
    "multipolarul": "multipolar",
    "multipolarului": "multipolar",
    "multiseculara": "multisecular",
    "multiseculară": "multisecular",
    "multiseculare": "multisecular",
    "multisecularei": "multisecular",
    "multisecularele": "multisecular",
    "multisecularelor": "multisecular",
    "multiseculari": "multisecular",
    "multisecularii": "multisecular",
    "multisecularilor": "multisecular",
    "multisecularul": "multisecular",
    "multisecularului": "multisecular",
    "multișoara": "multișor",
    "multișoară": "multișor",
    "multișoare": "multișor",
    "multișoarei": "multișor",
    "multișoarele": "multișor",
    "multișoarelor": "multișor",
    "multișoaro": "multișor",
    "multișori": "multișor",
    "multișorii": "multișor",
    "multișorilor": "multișor",
    "multișorul": "multișor",
    "multișorule": "multișor",
    "multișorului": "multișor",
    "multitudinea": "multitudine",
    "multitudini": "multitudine",
    "multitudinii": "multitudine",
    "multitudinile": "multitudine",
    "multitudinilor": "multitudine",
    "mulțumea": "mulțumi",
    "mulțumeai": "mulțumi",
    "mulțumeam": "mulțumi",
    "mulțumească": "mulțumi",
    "mulțumeați": "mulțumi",
    "mulțumeau": "mulțumi",
    "mulțumesc": "mulțumi",
    "mulțumește": "mulțumi",
    "mulțumești": "mulțumi",
    "mulțumii": "mulțumi",
    "mulțumim": "mulțumi",
    "mulțumind": "mulțumi",
    "mulțumindu": "mulțumi",
    "mulțumiră": "mulțumi",
    "mulțumirăm": "mulțumi",
    "mulțumirăți": "mulțumi",
    "mulțumise": "mulțumi",
    "mulțumisem": "mulțumi",
    "mulțumiseră": "mulțumi",
    "mulțumiserăm": "mulțumi",
    "mulțumiserăți": "mulțumi",
    "mulțumiseși": "mulțumi",
    "mulțumiși": "mulțumi",
    "mulțumit": "mulțumi",
    "mulțumiți": "mulțumi",
    "mulțumitu": "mulțumi",
    "nemaimulțumind": "mulțumi",
    "nemaimulțumindu": "mulțumi",
    "nemulțumind": "mulțumi",
    "nemulțumindu": "mulțumi",
    "mulțumirea": "mulțumire",
    "mulțumiri": "mulțumire",
    "mulțumirii": "mulțumire",
    "mulțumirile": "mulțumire",
    "mulțumirilor": "mulțumire",
    "mulțumita": "mulțumit",
    "mulțumită": "mulțumit",
    "mulțumite": "mulțumit",
    "mulțumitei": "mulțumit",
    "mulțumitele": "mulțumit",
    "mulțumitelor": "mulțumit",
    "mulțumiți": "mulțumit",
    "mulțumiții": "mulțumit",
    "mulțumiților": "mulțumit",
    "mulțumitul": "mulțumit",
    "mulțumitului": "mulțumit",
    "mulțumitoare": "mulțumitor",
    "mulțumitoarea": "mulțumitor",
    "mulțumitoarei": "mulțumitor",
    "mulțumitoarele": "mulțumitor",
    "mulțumitoarelor": "mulțumitor",
    "mulțumitori": "mulțumitor",
    "mulțumitorii": "mulțumitor",
    "mulțumitorilor": "mulțumitor",
    "mulțumitorul": "mulțumitor",
    "mulțumitorului": "mulțumitor",
    "mulura": "mulură",
    "muluri": "mulură",
    "mulurii": "mulură",
    "mulurile": "mulură",
    "mulurilor": "mulură",
    "muma": "mumă",
    "mume": "mumă",
    "mumei": "mumă",
    "mumele": "mumă",
    "mumelor": "mumă",
    "mumo": "mumă",
    "Mumei-Pădurii": "Muma-Pădurii",
    "mumia": "mumie",
    "mumiei": "mumie",
    "mumii": "mumie",
    "mumiile": "mumie",
    "mumiilor": "mumie",
    "mumific": "mumifica",
    "mumifică": "mumifica",
    "mumificai": "mumifica",
    "mumificam": "mumifica",
    "mumificăm": "mumifica",
    "mumificând": "mumifica",
    "mumificându": "mumifica",
    "mumificară": "mumifica",
    "mumificarăm": "mumifica",
    "mumificarăți": "mumifica",
    "mumificase": "mumifica",
    "mumificasem": "mumifica",
    "mumificaseră": "mumifica",
    "mumificaserăm": "mumifica",
    "mumificaserăți": "mumifica",
    "mumificaseși": "mumifica",
    "mumificași": "mumifica",
    "mumificat": "mumifica",
    "mumificați": "mumifica",
    "mumificatu": "mumifica",
    "mumificau": "mumifica",
    "mumifice": "mumifica",
    "mumifici": "mumifica",
    "nemaimumificând": "mumifica",
    "nemaimumificându": "mumifica",
    "nemumificând": "mumifica",
    "nemumificându": "mumifica",
    "mumificată": "mumificat",
    "mumificate": "mumificat",
    "mumificați": "mumificat",
    "munca": "muncă",
    "munci": "muncă",
    "muncii": "muncă",
    "muncile": "muncă",
    "muncilor": "muncă",
    "muncele": "muncel",
    "muncelele": "muncel",
    "muncelelor": "muncel",
    "muncelul": "muncel",
    "muncelului": "muncel",
    "muncea": "munci",
    "munceai": "munci",
    "munceam": "munci",
    "muncească": "munci",
    "munceați": "munci",
    "munceau": "munci",
    "muncesc": "munci",
    "muncește": "munci",
    "muncești": "munci",
    "muncii": "munci",
    "muncim": "munci",
    "muncind": "munci",
    "muncindu": "munci",
    "munciră": "munci",
    "muncirăm": "munci",
    "muncirăți": "munci",
    "muncise": "munci",
    "muncisem": "munci",
    "munciseră": "munci",
    "munciserăm": "munci",
    "munciserăți": "munci",
    "munciseși": "munci",
    "munciși": "munci",
    "muncit": "munci",
    "munciți": "munci",
    "muncitu": "munci",
    "nemaimuncind": "munci",
    "nemaimuncindu": "munci",
    "nemuncind": "munci",
    "nemuncindu": "munci",
    "muncită": "muncit",
    "muncite": "muncit",
    "munciți": "muncit",
    "muncitul": "muncit",
    "muncitului": "muncit",
    "muncitoarea": "muncitoare",
    "muncitoarei": "muncitoare",
    "muncitoarele": "muncitoare",
    "muncitoarelor": "muncitoare",
    "muncitoare": "muncitor",
    "muncitoarea": "muncitor",
    "muncitoarei": "muncitor",
    "muncitoarele": "muncitor",
    "muncitoarelor": "muncitor",
    "muncitori": "muncitor",
    "muncitorii": "muncitor",
    "muncitorilor": "muncitor",
    "muncitorul": "muncitor",
    "muncitorului": "muncitor",
    "muncitoreasca": "muncitoresc",
    "muncitorească": "muncitoresc",
    "muncitorescul": "muncitoresc",
    "muncitorescului": "muncitoresc",
    "muncitorești": "muncitoresc",
    "muncitoreștii": "muncitoresc",
    "muncitoreștile": "muncitoresc",
    "muncitoreștilor": "muncitoresc",
    "municipala": "municipal",
    "municipală": "municipal",
    "municipale": "municipal",
    "municipalei": "municipal",
    "municipalele": "municipal",
    "municipalelor": "municipal",
    "municipali": "municipal",
    "municipalii": "municipal",
    "municipalilor": "municipal",
    "municipalul": "municipal",
    "municipalului": "municipal",
    "municipalitatea": "municipalitate",
    "municipalități": "municipalitate",
    "municipalității": "municipalitate",
    "municipalitățile": "municipalitate",
    "municipalităților": "municipalitate",
    "municipii": "municipiu",
    "municipiii": "municipiu",
    "municipiilor": "municipiu",
    "municipiul": "municipiu",
    "municipiului": "municipiu",
    "munificenta": "munificent",
    "munificentă": "munificent",
    "munificente": "munificent",
    "munificentei": "munificent",
    "munificentele": "munificent",
    "munificentelor": "munificent",
    "munificenți": "munificent",
    "munificenții": "munificent",
    "munificenților": "munificent",
    "munificentul": "munificent",
    "munificentului": "munificent",
    "muniția": "muniție",
    "muniției": "muniție",
    "muniții": "muniție",
    "munițiile": "muniție",
    "munițiilor": "muniție",
    "M.": "munte",
    "muntele": "munte",
    "muntelui": "munte",
    "munți": "munte",
    "munții": "munte",
    "munților": "munte",
    "munteana": "muntean",
    "munteană": "muntean",
    "munteanca": "muntean",
    "munteancă": "muntean",
    "munteanul": "muntean",
    "munteanului": "muntean",
    "muntence": "muntean",
    "muntencei": "muntean",
    "muntencele": "muntean",
    "muntencelor": "muntean",
    "muntene": "muntean",
    "muntenei": "muntean",
    "muntenele": "muntean",
    "muntenelor": "muntean",
    "munteni": "muntean",
    "muntenii": "muntean",
    "muntenilor": "muntean",
    "munteana": "munteană",
    "muntene": "munteană",
    "muntenei": "munteană",
    "muntenele": "munteană",
    "muntenelor": "munteană",
    "munteanca": "munteancă",
    "muntence": "munteancă",
    "muntencei": "munteancă",
    "muntencele": "munteancă",
    "muntencelor": "munteancă",
    "munteneasca": "muntenesc",
    "muntenească": "muntenesc",
    "muntenescul": "muntenesc",
    "muntenescului": "muntenesc",
    "muntenești": "muntenesc",
    "munteneștii": "muntenesc",
    "munteneștile": "muntenesc",
    "munteneștilor": "muntenesc",
    "Muntenie": "Muntenia",
    "Munteniei": "Muntenia",
    "mții.": "munții",
    "muntoasa": "muntos",
    "muntoasă": "muntos",
    "muntoase": "muntos",
    "muntoasei": "muntos",
    "muntoasele": "muntos",
    "muntoaselor": "muntos",
    "muntoși": "muntos",
    "muntoșii": "muntos",
    "muntoșilor": "muntos",
    "muntosul": "muntos",
    "muntosului": "muntos",
    "muri": "mur",
    "murii": "mur",
    "murilor": "mur",
    "murul": "mur",
    "murului": "mur",
    "mură": "mura",
    "murai": "mura",
    "muram": "mura",
    "murăm": "mura",
    "murând": "mura",
    "murându": "mura",
    "murară": "mura",
    "murarăm": "mura",
    "murarăți": "mura",
    "murase": "mura",
    "murasem": "mura",
    "muraseră": "mura",
    "muraserăm": "mura",
    "muraserăți": "mura",
    "muraseși": "mura",
    "murași": "mura",
    "murat": "mura",
    "murați": "mura",
    "muratu": "mura",
    "murau": "mura",
    "murează": "mura",
    "murez": "mura",
    "mureze": "mura",
    "murezi": "mura",
    "nemaimurând": "mura",
    "nemaimurându": "mura",
    "nemurând": "mura",
    "nemurându": "mura",
    "mura": "mură",
    "mure": "mură",
    "murei": "mură",
    "murele": "mură",
    "murelor": "mură",
    "murala": "mural",
    "murală": "mural",
    "murale": "mural",
    "muralei": "mural",
    "muralele": "mural",
    "muralelor": "mural",
    "murali": "mural",
    "muralii": "mural",
    "muralilor": "mural",
    "muralul": "mural",
    "muralului": "mural",
    "murată": "murat",
    "murate": "murat",
    "murați": "murat",
    "murătura": "murătură",
    "murături": "murătură",
    "murăturii": "murătură",
    "murăturile": "murătură",
    "murăturilor": "murătură",
    "murdara": "murdar",
    "murdară": "murdar",
    "murdare": "murdar",
    "murdarei": "murdar",
    "murdarele": "murdar",
    "murdarelor": "murdar",
    "murdari": "murdar",
    "murdarii": "murdar",
    "murdarilor": "murdar",
    "murdarul": "murdar",
    "murdarului": "murdar",
    "murdărea": "murdări",
    "murdăreai": "murdări",
    "murdăream": "murdări",
    "murdărească": "murdări",
    "murdăreați": "murdări",
    "murdăreau": "murdări",
    "murdăresc": "murdări",
    "murdărește": "murdări",
    "murdărești": "murdări",
    "murdării": "murdări",
    "murdărim": "murdări",
    "murdărind": "murdări",
    "murdărindu": "murdări",
    "murdăriră": "murdări",
    "murdărirăm": "murdări",
    "murdărirăți": "murdări",
    "murdărise": "murdări",
    "murdărisem": "murdări",
    "murdăriseră": "murdări",
    "murdăriserăm": "murdări",
    "murdăriserăți": "murdări",
    "murdăriseși": "murdări",
    "murdăriși": "murdări",
    "murdărit": "murdări",
    "murdăriți": "murdări",
    "murdăritu": "murdări",
    "nemaimurdărind": "murdări",
    "nemaimurdărindu": "murdări",
    "nemurdărind": "murdări",
    "nemurdărindu": "murdări",
    "murdăria": "murdărie",
    "murdăriei": "murdărie",
    "murdării": "murdărie",
    "murdăriile": "murdărie",
    "murdăriilor": "murdărie",
    "murdărită": "murdărit",
    "murdărite": "murdărit",
    "murdăriți": "murdărit",
    "murga": "murg",
    "murgă": "murg",
    "murge": "murg",
    "murgei": "murg",
    "murgele": "murg",
    "murgelor": "murg",
    "murgi": "murg",
    "murgii": "murg",
    "murgilor": "murg",
    "murgul": "murg",
    "murgului": "murg",
    "murga": "murgă",
    "murge": "murgă",
    "murgei": "murgă",
    "murgele": "murgă",
    "murgelor": "murgă",
    "moară": "muri",
    "moare": "muri",
    "mor": "muri",
    "mori": "muri",
    "murea": "muri",
    "mureai": "muri",
    "muream": "muri",
    "mureați": "muri",
    "mureau": "muri",
    "murii": "muri",
    "murim": "muri",
    "murind": "muri",
    "murindu": "muri",
    "muriră": "muri",
    "murirăm": "muri",
    "murirăți": "muri",
    "murise": "muri",
    "murisem": "muri",
    "muriseră": "muri",
    "muriserăm": "muri",
    "muriserăți": "muri",
    "muriseși": "muri",
    "muriși": "muri",
    "murit": "muri",
    "muriți": "muri",
    "nemaimurind": "muri",
    "nemaimurindu": "muri",
    "nemurind": "muri",
    "nemurindu": "muri",
    "muribunda": "muribund",
    "muribundă": "muribund",
    "muribunde": "muribund",
    "muribundei": "muribund",
    "muribundele": "muribund",
    "muribundelor": "muribund",
    "muribundul": "muribund",
    "muribundului": "muribund",
    "muribunzi": "muribund",
    "muribunzii": "muribund",
    "muribunzilor": "muribund",
    "muribunda": "muribundă",
    "muribunde": "muribundă",
    "muribundei": "muribundă",
    "muribundele": "muribundă",
    "muribundelor": "muribundă",
    "murinda": "murind",
    "murindă": "murind",
    "murinde": "murind",
    "murindei": "murind",
    "murindele": "murind",
    "murindelor": "murind",
    "murindul": "murind",
    "murindului": "murind",
    "murinzi": "murind",
    "murinzii": "murind",
    "murinzilor": "murind",
    "muritoarea": "muritoare",
    "muritoarei": "muritoare",
    "muritoarele": "muritoare",
    "muritoarelor": "muritoare",
    "muritoare": "muritor",
    "muritoarea": "muritor",
    "muritoarei": "muritor",
    "muritoarele": "muritor",
    "muritoarelor": "muritor",
    "muritori": "muritor",
    "muritorii": "muritor",
    "muritorilor": "muritor",
    "muritorul": "muritor",
    "muritorului": "muritor",
    "murmuitoare": "murmuitor",
    "murmuitoarea": "murmuitor",
    "murmuitoarei": "murmuitor",
    "murmuitoarele": "murmuitor",
    "murmuitoarelor": "murmuitor",
    "murmuitori": "murmuitor",
    "murmuitorii": "murmuitor",
    "murmuitorilor": "murmuitor",
    "murmuitorul": "murmuitor",
    "murmuitorului": "murmuitor",
    "murmure": "murmur",
    "murmurele": "murmur",
    "murmurelor": "murmur",
    "murmurul": "murmur",
    "murmurului": "murmur",
    "murmur": "murmura",
    "murmură": "murmura",
    "murmurai": "murmura",
    "murmuram": "murmura",
    "murmurăm": "murmura",
    "murmurând": "murmura",
    "murmurându": "murmura",
    "murmurară": "murmura",
    "murmurarăm": "murmura",
    "murmurarăți": "murmura",
    "murmurase": "murmura",
    "murmurasem": "murmura",
    "murmuraseră": "murmura",
    "murmuraserăm": "murmura",
    "murmuraserăți": "murmura",
    "murmuraseși": "murmura",
    "murmurași": "murmura",
    "murmurat": "murmura",
    "murmurați": "murmura",
    "murmuratu": "murmura",
    "murmurau": "murmura",
    "murmure": "murmura",
    "murmuri": "murmura",
    "nemaimurmurând": "murmura",
    "nemaimurmurându": "murmura",
    "nemurmurând": "murmura",
    "nemurmurându": "murmura",
    "murmurată": "murmurat",
    "murmurate": "murmurat",
    "murmurați": "murmurat",
    "murmurătoare": "murmurător",
    "murmurătoarea": "murmurător",
    "murmurătoarei": "murmurător",
    "murmurătoarele": "murmurător",
    "murmurătoarelor": "murmurător",
    "murmurători": "murmurător",
    "murmurătorii": "murmurător",
    "murmurătorilor": "murmurător",
    "murmurătorul": "murmurător",
    "murmurătorului": "murmurător",
    "muruiala": "muruială",
    "muruieli": "muruială",
    "muruielii": "muruială",
    "muruielile": "muruială",
    "muruielilor": "muruială",
    "musacale": "musaca",
    "musacalei": "musaca",
    "musacalele": "musaca",
    "musacalelor": "musaca",
    "musacaua": "musaca",
    "musafiri": "musafir",
    "musafirii": "musafir",
    "musafirilor": "musafir",
    "musafirul": "musafir",
    "musafirului": "musafir",
    "musafira": "musafiră",
    "musafire": "musafiră",
    "musafirei": "musafiră",
    "musafirele": "musafiră",
    "musafirelor": "musafiră",
    "mușamale": "mușama",
    "mușamalei": "mușama",
    "mușamalele": "mușama",
    "mușamalelor": "mușama",
    "mușamaua": "mușama",
    "mușamaliză": "mușamaliza",
    "mușamalizai": "mușamaliza",
    "mușamalizam": "mușamaliza",
    "mușamalizăm": "mușamaliza",
    "mușamalizând": "mușamaliza",
    "mușamalizându": "mușamaliza",
    "mușamalizară": "mușamaliza",
    "mușamalizarăm": "mușamaliza",
    "mușamalizarăți": "mușamaliza",
    "mușamalizase": "mușamaliza",
    "mușamalizasem": "mușamaliza",
    "mușamalizaseră": "mușamaliza",
    "mușamalizaserăm": "mușamaliza",
    "mușamalizaserăți": "mușamaliza",
    "mușamalizaseși": "mușamaliza",
    "mușamalizași": "mușamaliza",
    "mușamalizat": "mușamaliza",
    "mușamalizați": "mușamaliza",
    "mușamalizatu": "mușamaliza",
    "mușamalizau": "mușamaliza",
    "mușamalizează": "mușamaliza",
    "mușamalizez": "mușamaliza",
    "mușamalizeze": "mușamaliza",
    "mușamalizezi": "mușamaliza",
    "nemaimușamalizând": "mușamaliza",
    "nemaimușamalizându": "mușamaliza",
    "nemușamalizând": "mușamaliza",
    "nemușamalizându": "mușamaliza",
    "mușamalizarea": "mușamalizare",
    "mușamalizată": "mușamalizat",
    "mușamalizate": "mușamalizat",
    "mușamalizați": "mușamalizat",
    "musca": "muscă",
    "muște": "muscă",
    "muștei": "muscă",
    "muștele": "muscă",
    "muștelor": "muscă",
    "mușc": "mușca",
    "mușcă": "mușca",
    "mușcai": "mușca",
    "mușcam": "mușca",
    "mușcăm": "mușca",
    "mușcând": "mușca",
    "mușcându": "mușca",
    "mușcară": "mușca",
    "mușcarăm": "mușca",
    "mușcarăți": "mușca",
    "mușcase": "mușca",
    "mușcasem": "mușca",
    "mușcaseră": "mușca",
    "mușcaserăm": "mușca",
    "mușcaserăți": "mușca",
    "mușcaseși": "mușca",
    "mușcași": "mușca",
    "mușcat": "mușca",
    "mușcați": "mușca",
    "mușcatu": "mușca",
    "mușcau": "mușca",
    "muște": "mușca",
    "muști": "mușca",
    "nemaimușcând": "mușca",
    "nemaimușcându": "mușca",
    "nemușcând": "mușca",
    "nemușcându": "mușca",
    "muscăleasca": "muscălesc",
    "muscălească": "muscălesc",
    "muscălescul": "muscălesc",
    "muscălescului": "muscălesc",
    "muscălești": "muscălesc",
    "muscăleștii": "muscălesc",
    "muscăleștile": "muscălesc",
    "muscăleștilor": "muscălesc",
    "muscari": "muscar",
    "muscarii": "muscar",
    "muscarilor": "muscar",
    "muscarul": "muscar",
    "muscarului": "muscar",
    "muscatul": "muscat",
    "muscatului": "muscat",
    "mușcată": "mușcat",
    "mușcate": "mușcat",
    "mușcați": "mușcat",
    "mușcata": "mușcată",
    "mușcate": "mușcată",
    "mușcatei": "mușcată",
    "mușcatele": "mușcată",
    "mușcatelor": "mușcată",
    "mușcătoare": "mușcător",
    "mușcătoarea": "mușcător",
    "mușcătoarei": "mușcător",
    "mușcătoarele": "mușcător",
    "mușcătoarelor": "mușcător",
    "mușcători": "mușcător",
    "mușcătorii": "mușcător",
    "mușcătorilor": "mușcător",
    "mușcătorul": "mușcător",
    "mușcătorului": "mușcător",
    "mușcătura": "mușcătură",
    "mușcături": "mușcătură",
    "mușcăturii": "mușcătură",
    "mușcăturile": "mușcătură",
    "mușcăturilor": "mușcătură",
    "mușcăturo": "mușcătură",
    "muscele": "muscel",
    "muscelele": "muscel",
    "muscelelor": "muscel",
    "muscelul": "muscel",
    "muscelului": "muscel",
    "muscheta": "muschetă",
    "muschete": "muschetă",
    "muschetei": "muschetă",
    "muschetele": "muschetă",
    "muschetelor": "muschetă",
    "mușchetari": "mușchetar",
    "mușchetarii": "mușchetar",
    "mușchetarilor": "mușchetar",
    "mușchetarul": "mușchetar",
    "mușchetarului": "mușchetar",
    "mușchii": "mușchi",
    "mușchilor": "mușchi",
    "mușchiul": "mușchi",
    "mușchiului": "mușchi",
    "mușchiulara": "mușchiular",
    "mușchiulară": "mușchiular",
    "mușchiulare": "mușchiular",
    "mușchiularei": "mușchiular",
    "mușchiularele": "mușchiular",
    "mușchiularelor": "mușchiular",
    "mușchiulari": "mușchiular",
    "mușchiularii": "mușchiular",
    "mușchiularilor": "mușchiular",
    "mușchiularo": "mușchiular",
    "mușchiularul": "mușchiular",
    "mușchiularule": "mușchiular",
    "mușchiularului": "mușchiular",
    "mușchiuloasa": "mușchiulos",
    "mușchiuloasă": "mușchiulos",
    "mușchiuloase": "mușchiulos",
    "mușchiuloasei": "mușchiulos",
    "mușchiuloasele": "mușchiulos",
    "mușchiuloaselor": "mușchiulos",
    "mușchiuloaso": "mușchiulos",
    "mușchiuloși": "mușchiulos",
    "mușchiuloșii": "mușchiulos",
    "mușchiuloșilor": "mușchiulos",
    "mușchiulosul": "mușchiulos",
    "mușchiulosule": "mușchiulos",
    "mușchiulosului": "mușchiulos",
    "muscoii": "muscoi",
    "muscoilor": "muscoi",
    "muscoiul": "muscoi",
    "muscoiule": "muscoi",
    "muscoiului": "muscoi",
    "musculara": "muscular",
    "musculară": "muscular",
    "musculare": "muscular",
    "muscularei": "muscular",
    "muscularele": "muscular",
    "muscularelor": "muscular",
    "musculari": "muscular",
    "muscularii": "muscular",
    "muscularilor": "muscular",
    "muscularul": "muscular",
    "muscularului": "muscular",
    "musculata": "musculat",
    "musculată": "musculat",
    "musculate": "musculat",
    "musculatei": "musculat",
    "musculatele": "musculat",
    "musculatelor": "musculat",
    "musculați": "musculat",
    "musculații": "musculat",
    "musculaților": "musculat",
    "musculatul": "musculat",
    "musculatului": "musculat",
    "musculatura": "musculatură",
    "musculaturi": "musculatură",
    "musculaturii": "musculatură",
    "musculaturile": "musculatură",
    "musculaturilor": "musculatură",
    "musculița": "musculiță",
    "musculițe": "musculiță",
    "musculiței": "musculiță",
    "musculițele": "musculiță",
    "musculițelor": "musculiță",
    "musculițo": "musculiță",
    "musculoasa": "musculos",
    "musculoasă": "musculos",
    "musculoase": "musculos",
    "musculoasei": "musculos",
    "musculoasele": "musculos",
    "musculoaselor": "musculos",
    "musculoși": "musculos",
    "musculoșii": "musculos",
    "musculoșilor": "musculos",
    "musculosul": "musculos",
    "musculosului": "musculos",
    "muselina": "muselină",
    "museline": "muselină",
    "muselinei": "muselină",
    "mușețelul": "mușețel",
    "mușețelului": "mușețel",
    "MTV": "Music_Television",
    "mușița": "mușiță",
    "mușițe": "mușiță",
    "mușiței": "mușiță",
    "mușițele": "mușiță",
    "mușițelor": "mușiță",
    "musoni": "muson",
    "musonii": "muson",
    "musonilor": "muson",
    "musonul": "muson",
    "musonului": "muson",
    "mustul": "must",
    "mustului": "must",
    "musturi": "must",
    "musturile": "must",
    "musturilor": "must",
    "mustăcea": "mustăci",
    "mustăceai": "mustăci",
    "mustăceam": "mustăci",
    "mustăcească": "mustăci",
    "mustăceați": "mustăci",
    "mustăceau": "mustăci",
    "mustăcesc": "mustăci",
    "mustăcește": "mustăci",
    "mustăcești": "mustăci",
    "mustăcii": "mustăci",
    "mustăcim": "mustăci",
    "mustăcind": "mustăci",
    "mustăcindu": "mustăci",
    "mustăciră": "mustăci",
    "mustăcirăm": "mustăci",
    "mustăcirăți": "mustăci",
    "mustăcise": "mustăci",
    "mustăcisem": "mustăci",
    "mustăciseră": "mustăci",
    "mustăciserăm": "mustăci",
    "mustăciserăți": "mustăci",
    "mustăciseși": "mustăci",
    "mustăciși": "mustăci",
    "mustăcit": "mustăci",
    "mustăciți": "mustăci",
    "mustăcitu": "mustăci",
    "mustăcioasa": "mustăcios",
    "mustăcioasă": "mustăcios",
    "mustăcioase": "mustăcios",
    "mustăcioasei": "mustăcios",
    "mustăcioasele": "mustăcios",
    "mustăcioaselor": "mustăcios",
    "mustăcioși": "mustăcios",
    "mustăcioșii": "mustăcios",
    "mustăcioșilor": "mustăcios",
    "mustăciosul": "mustăcios",
    "mustăciosului": "mustăcios",
    "mustăcită": "mustăcit",
    "mustăcite": "mustăcit",
    "mustăciți": "mustăcit",
    "muștaru'": "muștar",
    "muștarul": "muștar",
    "muștarului": "muștar",
    "mustăria": "mustărie",
    "mustăriei": "mustărie",
    "mustării": "mustărie",
    "mustăriile": "mustărie",
    "mustăriilor": "mustărie",
    "mustața": "mustață",
    "mustăți": "mustață",
    "mustății": "mustață",
    "mustățile": "mustață",
    "mustăților": "mustață",
    "mușterii": "mușteriu",
    "mușteriii": "mușteriu",
    "mușteriilor": "mușteriu",
    "mușteriul": "mușteriu",
    "mușteriului": "mușteriu",
    "mustea": "musti",
    "musteai": "musti",
    "musteam": "musti",
    "mustească": "musti",
    "musteați": "musti",
    "musteau": "musti",
    "mustesc": "musti",
    "mustește": "musti",
    "mustești": "musti",
    "mustii": "musti",
    "mustim": "musti",
    "mustind": "musti",
    "mustindu": "musti",
    "mustiră": "musti",
    "mustirăm": "musti",
    "mustirăți": "musti",
    "mustise": "musti",
    "mustisem": "musti",
    "mustiseră": "musti",
    "mustiserăm": "musti",
    "mustiserăți": "musti",
    "mustiseși": "musti",
    "mustiși": "musti",
    "mustit": "musti",
    "mustiți": "musti",
    "mustitu": "musti",
    "mustirea": "mustire",
    "mustiri": "mustire",
    "mustirii": "mustire",
    "mustirile": "mustire",
    "mustirilor": "mustire",
    "mustită": "mustit",
    "mustite": "mustit",
    "mustiți": "mustit",
    "muștiucul": "muștiuc",
    "muștiucului": "muștiuc",
    "muștiucuri": "muștiuc",
    "muștiucurile": "muștiuc",
    "muștiucurilor": "muștiuc",
    "mustoasa": "mustos",
    "mustoasă": "mustos",
    "mustoase": "mustos",
    "mustoasei": "mustos",
    "mustoasele": "mustos",
    "mustoaselor": "mustos",
    "mustoși": "mustos",
    "mustoșii": "mustos",
    "mustoșilor": "mustos",
    "mustosul": "mustos",
    "mustosului": "mustos",
    "mustră": "mustra",
    "mustrai": "mustra",
    "mustram": "mustra",
    "mustrăm": "mustra",
    "mustrând": "mustra",
    "mustrându": "mustra",
    "mustrară": "mustra",
    "mustrarăm": "mustra",
    "mustrarăți": "mustra",
    "mustrase": "mustra",
    "mustrasem": "mustra",
    "mustraseră": "mustra",
    "mustraserăm": "mustra",
    "mustraserăți": "mustra",
    "mustraseși": "mustra",
    "mustrași": "mustra",
    "mustrat": "mustra",
    "mustrați": "mustra",
    "mustratu": "mustra",
    "mustrau": "mustra",
    "mustre": "mustra",
    "mustri": "mustra",
    "mustru": "mustra",
    "nemaimustrând": "mustra",
    "nemaimustrându": "mustra",
    "nemustrând": "mustra",
    "nemustrându": "mustra",
    "mustrarea": "mustrare",
    "mustrări": "mustrare",
    "mustrării": "mustrare",
    "mustrările": "mustrare",
    "mustrărilor": "mustrare",
    "mustrată": "mustrat",
    "mustrate": "mustrat",
    "mustrați": "mustrat",
    "mustrătoare": "mustrător",
    "mustrătoarea": "mustrător",
    "mustrătoarei": "mustrător",
    "mustrătoarele": "mustrător",
    "mustrătoarelor": "mustrător",
    "mustrători": "mustrător",
    "mustrătorii": "mustrător",
    "mustrătorilor": "mustrător",
    "mustrătorul": "mustrător",
    "mustrătorului": "mustrător",
    "mustuia": "mustui",
    "mustuiai": "mustui",
    "mustuiam": "mustui",
    "mustuiască": "mustui",
    "mustuiați": "mustui",
    "mustuiau": "mustui",
    "mustuiesc": "mustui",
    "mustuiește": "mustui",
    "mustuiești": "mustui",
    "mustuii": "mustui",
    "mustuim": "mustui",
    "mustuind": "mustui",
    "mustuindu": "mustui",
    "mustuiră": "mustui",
    "mustuirăm": "mustui",
    "mustuirăți": "mustui",
    "mustuise": "mustui",
    "mustuisem": "mustui",
    "mustuiseră": "mustui",
    "mustuiserăm": "mustui",
    "mustuiserăți": "mustui",
    "mustuiseși": "mustui",
    "mustuiși": "mustui",
    "mustuit": "mustui",
    "mustuiți": "mustui",
    "mustuitu": "mustui",
    "nemaimustuind": "mustui",
    "nemaimustuindu": "mustui",
    "nemustuind": "mustui",
    "nemustuindu": "mustui",
    "mustuită": "mustuit",
    "mustuite": "mustuit",
    "mustuiți": "mustuit",
    "musulmana": "musulman",
    "musulmană": "musulman",
    "musulmane": "musulman",
    "musulmanei": "musulman",
    "musulmanele": "musulman",
    "musulmanelor": "musulman",
    "musulmani": "musulman",
    "musulmanii": "musulman",
    "musulmanilor": "musulman",
    "musulmanul": "musulman",
    "musulmanului": "musulman",
    "musulmana": "musulmană",
    "musulmane": "musulmană",
    "musulmanei": "musulmană",
    "musulmanele": "musulmană",
    "musulmanelor": "musulmană",
    "mușuroaie": "mușuroi",
    "mușuroaiele": "mușuroi",
    "mușuroaielor": "mușuroi",
    "mușuroiul": "mușuroi",
    "mușuroiului": "mușuroi",
    "muta": "mut",
    "mută": "mut",
    "mute": "mut",
    "mutei": "mut",
    "mutele": "mut",
    "mutelor": "mut",
    "muți": "mut",
    "muții": "mut",
    "muților": "mut",
    "mutul": "mut",
    "mutului": "mut",
    "mut": "muta",
    "mută": "muta",
    "mutai": "muta",
    "mutam": "muta",
    "mutăm": "muta",
    "mutând": "muta",
    "mutându": "muta",
    "mutară": "muta",
    "mutarăm": "muta",
    "mutarăți": "muta",
    "mutase": "muta",
    "mutasem": "muta",
    "mutaseră": "muta",
    "mutaserăm": "muta",
    "mutaserăți": "muta",
    "mutaseși": "muta",
    "mutași": "muta",
    "mutat": "muta",
    "mutați": "muta",
    "mutatu": "muta",
    "mutau": "muta",
    "mute": "muta",
    "muți": "muta",
    "nemaimutând": "muta",
    "nemaimutându": "muta",
    "nemutând": "muta",
    "nemutându": "muta",
    "muta": "mută",
    "mute": "mută",
    "mutei": "mută",
    "mutele": "mută",
    "mutelor": "mută",
    "mutabila": "mutabil",
    "mutabilă": "mutabil",
    "mutabile": "mutabil",
    "mutabilei": "mutabil",
    "mutabilele": "mutabil",
    "mutabilelor": "mutabil",
    "mutabili": "mutabil",
    "mutabilii": "mutabil",
    "mutabililor": "mutabil",
    "mutabilul": "mutabil",
    "mutabilului": "mutabil",
    "mutabilitatea": "mutabilitate",
    "mutabilități": "mutabilitate",
    "mutabilității": "mutabilitate",
    "mutabilitățile": "mutabilitate",
    "mutabilităților": "mutabilitate",
    "mutarea": "mutare",
    "mutări": "mutare",
    "mutării": "mutare",
    "mutările": "mutare",
    "mutărilor": "mutare",
    "mutată": "mutat",
    "mutate": "mutat",
    "mutați": "mutat",
    "mutația": "mutație",
    "mutației": "mutație",
    "mutații": "mutație",
    "mutațiile": "mutație",
    "mutațiilor": "mutație",
    "mutaționismul": "mutaționism",
    "mutaționismului": "mutaționism",
    "mutatoare": "mutator",
    "mutatoarele": "mutator",
    "mutatoarelor": "mutator",
    "mutatorul": "mutator",
    "mutatorului": "mutator",
    "mutătoare": "mutător",
    "mutătoarea": "mutător",
    "mutătoarei": "mutător",
    "mutătoarele": "mutător",
    "mutătoarelor": "mutător",
    "mutători": "mutător",
    "mutătorii": "mutător",
    "mutătorilor": "mutător",
    "mutătorul": "mutător",
    "mutătorului": "mutător",
    "muțenia": "muțenie",
    "muțeniei": "muțenie",
    "muțenii": "muțenie",
    "muțeniile": "muțenie",
    "muțeniilor": "muțenie",
    "muteasca": "mutesc",
    "mutească": "mutesc",
    "mutescul": "mutesc",
    "mutescului": "mutesc",
    "mutești": "mutesc",
    "muteștii": "mutesc",
    "muteștile": "mutesc",
    "muteștilor": "mutesc",
    "mutilă": "mutila",
    "mutilai": "mutila",
    "mutilam": "mutila",
    "mutilăm": "mutila",
    "mutilând": "mutila",
    "mutilându": "mutila",
    "mutilară": "mutila",
    "mutilarăm": "mutila",
    "mutilarăți": "mutila",
    "mutilase": "mutila",
    "mutilasem": "mutila",
    "mutilaseră": "mutila",
    "mutilaserăm": "mutila",
    "mutilaserăți": "mutila",
    "mutilaseși": "mutila",
    "mutilași": "mutila",
    "mutilat": "mutila",
    "mutilați": "mutila",
    "mutilatu": "mutila",
    "mutilau": "mutila",
    "mutilează": "mutila",
    "mutilez": "mutila",
    "mutileze": "mutila",
    "mutilezi": "mutila",
    "nemaimutilând": "mutila",
    "nemaimutilându": "mutila",
    "nemutilând": "mutila",
    "nemutilându": "mutila",
    "mutilanta": "mutilant",
    "mutilantă": "mutilant",
    "mutilante": "mutilant",
    "mutilantei": "mutilant",
    "mutilantele": "mutilant",
    "mutilantelor": "mutilant",
    "mutilanți": "mutilant",
    "mutilanții": "mutilant",
    "mutilanților": "mutilant",
    "mutilantul": "mutilant",
    "mutilantului": "mutilant",
    "mutilarea": "mutilare",
    "mutilareo": "mutilare",
    "mutilări": "mutilare",
    "mutilării": "mutilare",
    "mutilările": "mutilare",
    "mutilărilor": "mutilare",
    "mutilată": "mutilat",
    "mutilate": "mutilat",
    "mutilați": "mutilat",
    "mutilatoare": "mutilator",
    "mutilatoarea": "mutilator",
    "mutilatoarei": "mutilator",
    "mutilatoarele": "mutilator",
    "mutilatoarelor": "mutilator",
    "mutilatori": "mutilator",
    "mutilatorii": "mutilator",
    "mutilatorilor": "mutilator",
    "mutilatorul": "mutilator",
    "mutilatorului": "mutilator",
    "mutismul": "mutism",
    "mutismului": "mutism",
    "mutra": "mutră",
    "mutre": "mutră",
    "mutrei": "mutră",
    "mutrele": "mutră",
    "mutrelor": "mutră",
    "mutuala": "mutual",
    "mutuală": "mutual",
    "mutuale": "mutual",
    "mutualei": "mutual",
    "mutualele": "mutual",
    "mutualelor": "mutual",
    "mutuali": "mutual",
    "mutualii": "mutual",
    "mutualilor": "mutual",
    "mutualul": "mutual",
    "mutualului": "mutual",
    "mutualista": "mutualist",
    "mutualistă": "mutualist",
    "mutualiste": "mutualist",
    "mutualistei": "mutualist",
    "mutualistele": "mutualist",
    "mutualistelor": "mutualist",
    "mutualiști": "mutualist",
    "mutualiștii": "mutualist",
    "mutualiștilor": "mutualist",
    "mutualistul": "mutualist",
    "mutualistului": "mutualist",
    "muza": "muză",
    "muze": "muză",
    "muzei": "muză",
    "muzele": "muză",
    "muzelor": "muză",
    "muzeala": "muzeal",
    "muzeală": "muzeal",
    "muzeale": "muzeal",
    "muzealei": "muzeal",
    "muzealele": "muzeal",
    "muzealelor": "muzeal",
    "muzeali": "muzeal",
    "muzealii": "muzeal",
    "muzealilor": "muzeal",
    "muzealul": "muzeal",
    "muzealului": "muzeal",
    "muzeistica": "muzeistic",
    "muzeistică": "muzeistic",
    "muzeistice": "muzeistic",
    "muzeisticei": "muzeistic",
    "muzeisticele": "muzeistic",
    "muzeisticelor": "muzeistic",
    "muzeistici": "muzeistic",
    "muzeisticii": "muzeistic",
    "muzeisticilor": "muzeistic",
    "muzeisticul": "muzeistic",
    "muzeisticului": "muzeistic",
    "muzeografa": "muzeograf",
    "muzeografă": "muzeograf",
    "muzeografe": "muzeograf",
    "muzeografei": "muzeograf",
    "muzeografele": "muzeograf",
    "muzeografelor": "muzeograf",
    "muzeografi": "muzeograf",
    "muzeografii": "muzeograf",
    "muzeografilor": "muzeograf",
    "muzeograful": "muzeograf",
    "muzeografului": "muzeograf",
    "muzeografa": "muzeografă",
    "muzeografe": "muzeografă",
    "muzeografei": "muzeografă",
    "muzeografele": "muzeografă",
    "muzeografelor": "muzeografă",
    "muzeografica": "muzeografic",
    "muzeografică": "muzeografic",
    "muzeografice": "muzeografic",
    "muzeograficei": "muzeografic",
    "muzeograficele": "muzeografic",
    "muzeograficelor": "muzeografic",
    "muzeografici": "muzeografic",
    "muzeograficii": "muzeografic",
    "muzeograficilor": "muzeografic",
    "muzeograficul": "muzeografic",
    "muzeograficului": "muzeografic",
    "muzeografia": "muzeografie",
    "muzeografiei": "muzeografie",
    "muzeografii": "muzeografie",
    "muzeologi": "muzeolog",
    "muzeologii": "muzeolog",
    "muzeologilor": "muzeolog",
    "muzeologul": "muzeolog",
    "muzeologului": "muzeolog",
    "muzeologia": "muzeologie",
    "muzeologiei": "muzeologie",
    "muzeologii": "muzeologie",
    "muzeologiile": "muzeologie",
    "muzeologiilor": "muzeologie",
    "muzee": "muzeu",
    "muzeele": "muzeu",
    "muzeelor": "muzeu",
    "muzeul": "muzeu",
    "muzeului": "muzeu",
    "muz.": "muzică",
    "muzica": "muzică",
    "muzici": "muzică",
    "muzicii": "muzică",
    "muzicile": "muzică",
    "muzicilor": "muzică",
    "muzicala": "muzical",
    "muzicală": "muzical",
    "muzicale": "muzical",
    "muzicalei": "muzical",
    "muzicalele": "muzical",
    "muzicalelor": "muzical",
    "muzicali": "muzical",
    "muzicalii": "muzical",
    "muzicalilor": "muzical",
    "muzicalul": "muzical",
    "muzicalului": "muzical",
    "muzicalitatea": "muzicalitate",
    "muzicalități": "muzicalitate",
    "muzicalității": "muzicalitate",
    "muzicalitățile": "muzicalitate",
    "muzicalităților": "muzicalitate",
    "muzicanți": "muzicant",
    "muzicanții": "muzicant",
    "muzicanților": "muzicant",
    "muzicantul": "muzicant",
    "muzicantului": "muzicant",
    "muzicianul": "muzician",
    "muzicianului": "muzician",
    "muzicieni": "muzician",
    "muzicienii": "muzician",
    "muzicienilor": "muzician",
    "muziciana": "muziciană",
    "muziciene": "muziciană",
    "muzicienei": "muziciană",
    "muzicienele": "muziciană",
    "muzicienelor": "muziciană",
    "muzicologi": "muzicolog",
    "muzicologii": "muzicolog",
    "muzicologilor": "muzicolog",
    "muzicologul": "muzicolog",
    "muzicologului": "muzicolog",
    "muzicologica": "muzicologic",
    "muzicologică": "muzicologic",
    "muzicologice": "muzicologic",
    "muzicologicei": "muzicologic",
    "muzicologicele": "muzicologic",
    "muzicologicelor": "muzicologic",
    "muzicologici": "muzicologic",
    "muzicologicii": "muzicologic",
    "muzicologicilor": "muzicologic",
    "muzicologicul": "muzicologic",
    "muzicologicului": "muzicologic",
    "muzicologia": "muzicologie",
    "muzicologiei": "muzicologie",
    "muzicologii": "muzicologie",
    "muzicologiile": "muzicologie",
    "muzicologiilor": "muzicologie",
    "muzicuța": "muzicuță",
    "muzicuțe": "muzicuță",
    "muzicuței": "muzicuță",
    "muzicuțele": "muzicuță",
    "muzicuțelor": "muzicuță",
    "nababi": "nabab",
    "nababii": "nabab",
    "nababilor": "nabab",
    "nababul": "nabab",
    "nababului": "nabab",
    "năbădăile": "năbădăi",
    "năbădăilor": "năbădăi",
    "năbădăioasa": "năbădăios",
    "năbădăioasă": "năbădăios",
    "năbădăioase": "năbădăios",
    "năbădăioasei": "năbădăios",
    "năbădăioasele": "năbădăios",
    "năbădăioaselor": "năbădăios",
    "năbădăioși": "năbădăios",
    "năbădăioșii": "năbădăios",
    "năbădăioșilor": "năbădăios",
    "năbădăiosul": "năbădăios",
    "năbădăiosului": "năbădăios",
    "nabedernița": "nabederniță",
    "nabedernițe": "nabederniță",
    "nabederniței": "nabederniță",
    "nabedernițele": "nabederniță",
    "nabedernițelor": "nabederniță",
    "năbucul": "năbuc",
    "năbucului": "năbuc",
    "năbușeala": "năbușeală",
    "năbușeli": "năbușeală",
    "năbușelii": "năbușeală",
    "năbușelile": "năbușeală",
    "năbușelilor": "năbușeală",
    "năbușea": "năbuși",
    "năbușeai": "năbuși",
    "năbușeam": "năbuși",
    "năbușească": "năbuși",
    "năbușeați": "năbuși",
    "năbușeau": "năbuși",
    "năbușesc": "năbuși",
    "năbușește": "năbuși",
    "năbușești": "năbuși",
    "năbușii": "năbuși",
    "năbușim": "năbuși",
    "năbușind": "năbuși",
    "năbușindu": "năbuși",
    "năbușiră": "năbuși",
    "năbușirăm": "năbuși",
    "năbușirăți": "năbuși",
    "năbușise": "năbuși",
    "năbușisem": "năbuși",
    "năbușiseră": "năbuși",
    "năbușiserăm": "năbuși",
    "năbușiserăți": "năbuși",
    "năbușiseși": "năbuși",
    "năbușiși": "năbuși",
    "năbușit": "năbuși",
    "năbușiți": "năbuși",
    "nemainăbușind": "năbuși",
    "nemainăbușindu": "năbuși",
    "nenăbușind": "năbuși",
    "nenăbușindu": "năbuși",
    "năbușirea": "năbușire",
    "năbușiri": "năbușire",
    "năbușirii": "năbușire",
    "năbușirile": "năbușire",
    "năbușirilor": "năbușire",
    "năbușită": "năbușit",
    "năbușite": "năbușit",
    "năbușiți": "năbușit",
    "năbușitoare": "năbușitor",
    "năbușitoarea": "năbușitor",
    "năbușitoarei": "năbușitor",
    "năbușitoarele": "năbușitor",
    "năbușitoarelor": "năbușitor",
    "năbușitori": "năbușitor",
    "năbușitorii": "năbușitor",
    "năbușitorilor": "năbușitor",
    "năbușitorul": "năbușitor",
    "năbușitorului": "năbușitor",
    "năcăjita": "năcăjit",
    "năcăjită": "năcăjit",
    "năcăjite": "năcăjit",
    "năcăjitei": "năcăjit",
    "năcăjitele": "năcăjit",
    "năcăjitelor": "năcăjit",
    "năcăjiți": "năcăjit",
    "năcăjiții": "năcăjit",
    "năcăjiților": "năcăjit",
    "năcăjitul": "năcăjit",
    "năcăjitului": "năcăjit",
    "nacela": "nacelă",
    "nacele": "nacelă",
    "nacelei": "nacelă",
    "nacelele": "nacelă",
    "nacelelor": "nacelă",
    "năclăia": "năclăi",
    "năclăiai": "năclăi",
    "năclăiam": "năclăi",
    "năclăiască": "năclăi",
    "năclăiați": "năclăi",
    "năclăiau": "năclăi",
    "năclăiesc": "năclăi",
    "năclăiește": "năclăi",
    "năclăiești": "năclăi",
    "năclăii": "năclăi",
    "năclăim": "năclăi",
    "năclăind": "năclăi",
    "năclăindu": "năclăi",
    "năclăiră": "năclăi",
    "năclăirăm": "năclăi",
    "năclăirăți": "năclăi",
    "năclăise": "năclăi",
    "năclăisem": "năclăi",
    "năclăiseră": "năclăi",
    "năclăiserăm": "năclăi",
    "năclăiserăți": "năclăi",
    "năclăiseși": "năclăi",
    "năclăiși": "năclăi",
    "năclăit": "năclăi",
    "năclăiți": "năclăi",
    "nemainăclăind": "năclăi",
    "nemainăclăindu": "năclăi",
    "nenăclăind": "năclăi",
    "nenăclăindu": "năclăi",
    "năclăioasa": "năclăios",
    "năclăioasă": "năclăios",
    "năclăioase": "năclăios",
    "năclăioasei": "năclăios",
    "năclăioasele": "năclăios",
    "năclăioaselor": "năclăios",
    "năclăioși": "năclăios",
    "năclăioșii": "năclăios",
    "năclăioșilor": "năclăios",
    "năclăiosul": "năclăios",
    "năclăiosului": "năclăios",
    "năclăită": "năclăit",
    "năclăite": "năclăit",
    "năclăiți": "năclăit",
    "nacritul": "nacrit",
    "nacritului": "nacrit",
    "nada": "nadă",
    "nade": "nadă",
    "nadei": "nadă",
    "nadele": "nadă",
    "nadelor": "nadă",
    "nădăjduia": "nădăjdui",
    "nădăjduiai": "nădăjdui",
    "nădăjduiam": "nădăjdui",
    "nădăjduiască": "nădăjdui",
    "nădăjduiați": "nădăjdui",
    "nădăjduiau": "nădăjdui",
    "nădăjduiesc": "nădăjdui",
    "nădăjduiește": "nădăjdui",
    "nădăjduiești": "nădăjdui",
    "nădăjduii": "nădăjdui",
    "nădăjduim": "nădăjdui",
    "nădăjduind": "nădăjdui",
    "nădăjduindu": "nădăjdui",
    "nădăjduiră": "nădăjdui",
    "nădăjduirăm": "nădăjdui",
    "nădăjduirăți": "nădăjdui",
    "nădăjduise": "nădăjdui",
    "nădăjduisem": "nădăjdui",
    "nădăjduiseră": "nădăjdui",
    "nădăjduiserăm": "nădăjdui",
    "nădăjduiserăți": "nădăjdui",
    "nădăjduiseși": "nădăjdui",
    "nădăjduiși": "nădăjdui",
    "nădăjduit": "nădăjdui",
    "nădăjduiți": "nădăjdui",
    "nemainădăjduind": "nădăjdui",
    "nemainădăjduindu": "nădăjdui",
    "nenădăjduind": "nădăjdui",
    "nenădăjduindu": "nădăjdui",
    "nădăjduită": "nădăjduit",
    "nădăjduite": "nădăjduit",
    "nădăjduiți": "nădăjduit",
    "nădejdea": "nădejde",
    "nădejdi": "nădejde",
    "nădejdii": "nădejde",
    "nădejdile": "nădejde",
    "nădejdilor": "nădejde",
    "nadiceanca": "nadiceancă",
    "nadicence": "nadiceancă",
    "nadicencei": "nadiceancă",
    "nadicencele": "nadiceancă",
    "nadicencelor": "nadiceancă",
    "nadirul": "nadir",
    "nadirului": "nadir",
    "nădragi": "nădrag",
    "nădragii": "nădrag",
    "nădragilor": "nădrag",
    "nădragul": "nădrag",
    "nădragului": "nădrag",
    "năduful": "năduf",
    "nădufului": "năduf",
    "nădufuri": "năduf",
    "nădufurile": "năduf",
    "nădufurilor": "năduf",
    "nădușeala": "nădușeală",
    "nădușeli": "nădușeală",
    "nădușelii": "nădușeală",
    "nădușelile": "nădușeală",
    "nădușelilor": "nădușeală",
    "nădușea": "năduși",
    "nădușeai": "năduși",
    "nădușeam": "năduși",
    "nădușească": "năduși",
    "nădușeați": "năduși",
    "nădușeau": "năduși",
    "nădușesc": "năduși",
    "nădușește": "năduși",
    "nădușești": "năduși",
    "nădușii": "năduși",
    "nădușim": "năduși",
    "nădușind": "năduși",
    "nădușindu": "năduși",
    "nădușiră": "năduși",
    "nădușirăm": "năduși",
    "nădușirăți": "năduși",
    "nădușise": "năduși",
    "nădușisem": "năduși",
    "nădușiseră": "năduși",
    "nădușiserăm": "năduși",
    "nădușiserăți": "năduși",
    "nădușiseși": "năduși",
    "nădușiși": "năduși",
    "nădușit": "năduși",
    "nădușiți": "năduși",
    "nemainădușind": "năduși",
    "nemainădușindu": "năduși",
    "nenădușind": "năduși",
    "nenădușindu": "năduși",
    "nădușită": "nădușit",
    "nădușite": "nădușit",
    "nădușiți": "nădușit",
    "nădușitoare": "nădușitor",
    "nădușitoarea": "nădușitor",
    "nădușitoarei": "nădușitor",
    "nădușitoarele": "nădușitor",
    "nădușitoarelor": "nădușitor",
    "nădușitori": "nădușitor",
    "nădușitorii": "nădușitor",
    "nădușitorilor": "nădușitor",
    "nădușitorul": "nădușitor",
    "nădușitorului": "nădușitor",
    "năframa": "năframă",
    "năframe": "năframă",
    "năframei": "năframă",
    "năframele": "năframă",
    "năframelor": "năframă",
    "naftalina": "naftalină",
    "naftaline": "naftalină",
    "naftalinei": "naftalină",
    "naftenați": "naftenat",
    "naftenații": "naftenat",
    "naftenaților": "naftenat",
    "naftenatul": "naftenat",
    "naftenatului": "naftenat",
    "naftolat": "naftenat",
    "naftolați": "naftenat",
    "naftolații": "naftenat",
    "naftolaților": "naftenat",
    "naftolatul": "naftenat",
    "naftolatului": "naftenat",
    "naftenica": "naftenic",
    "naftenică": "naftenic",
    "naftenice": "naftenic",
    "naftenicei": "naftenic",
    "naftenicele": "naftenic",
    "naftenicelor": "naftenic",
    "naftenici": "naftenic",
    "naftenicii": "naftenic",
    "naftenicilor": "naftenic",
    "naftenicul": "naftenic",
    "naftenicului": "naftenic",
    "naftoli": "naftol",
    "naftolii": "naftol",
    "naftolilor": "naftol",
    "naftolul": "naftol",
    "naftolului": "naftol",
    "nafura": "nafură",
    "nafure": "nafură",
    "nafurei": "nafură",
    "năfurica": "năfurică",
    "năfurici": "năfurică",
    "năfuricii": "năfurică",
    "năfuricile": "năfurică",
    "năfuricilor": "năfurică",
    "năgara": "năgară",
    "năgare": "năgară",
    "năgarei": "năgară",
    "nagâți": "nagâț",
    "nagâții": "nagâț",
    "nagâților": "nagâț",
    "nagâțul": "nagâț",
    "nagâțului": "nagâț",
    "naiul": "nai",
    "naiului": "nai",
    "naiuri": "nai",
    "naiurile": "nai",
    "naiurilor": "nai",
    "naiada": "naiadă",
    "naiade": "naiadă",
    "naiadei": "naiadă",
    "naiadele": "naiadă",
    "naiadelor": "naiadă",
    "naibei": "naiba",
    "naibii": "naiba",
    "nailoane": "nailon",
    "nailoanele": "nailon",
    "nailoanelor": "nailon",
    "nailonul": "nailon",
    "nailonului": "nailon",
    "năimea": "năimi",
    "năimeai": "năimi",
    "năimeam": "năimi",
    "năimească": "năimi",
    "năimeați": "năimi",
    "năimeau": "năimi",
    "năimesc": "năimi",
    "năimește": "năimi",
    "năimești": "năimi",
    "năimii": "năimi",
    "năimim": "năimi",
    "năimind": "năimi",
    "năimindu": "năimi",
    "năimiră": "năimi",
    "năimirăm": "năimi",
    "năimirăți": "năimi",
    "năimise": "năimi",
    "năimisem": "năimi",
    "năimiseră": "năimi",
    "năimiserăm": "năimi",
    "năimiserăți": "năimi",
    "năimiseși": "năimi",
    "năimiși": "năimi",
    "năimit": "năimi",
    "năimiți": "năimi",
    "nemainăimind": "năimi",
    "nemainăimindu": "năimi",
    "nenăimind": "năimi",
    "nenăimindu": "năimi",
    "năimită": "năimit",
    "năimite": "năimit",
    "năimiți": "năimit",
    "naiști": "naist",
    "naiștii": "naist",
    "naiștilor": "naist",
    "naistul": "naist",
    "naistului": "naist",
    "naista": "naistă",
    "naiste": "naistă",
    "naistei": "naistă",
    "naistele": "naistă",
    "naistelor": "naistă",
    "naiva": "naiv",
    "naivă": "naiv",
    "naive": "naiv",
    "naivei": "naiv",
    "naivele": "naiv",
    "naivelor": "naiv",
    "naivi": "naiv",
    "naivii": "naiv",
    "naivilor": "naiv",
    "naivul": "naiv",
    "naivului": "naiv",
    "naiva": "naivă",
    "naive": "naivă",
    "naivei": "naivă",
    "naivele": "naivă",
    "naivelor": "naivă",
    "naivitatea": "naivitate",
    "naivități": "naivitate",
    "naivității": "naivitate",
    "naivitățile": "naivitate",
    "naivităților": "naivitate",
    "nalba": "nalbă",
    "nalbe": "nalbă",
    "nalbei": "nalbă",
    "nalbele": "nalbă",
    "nalbelor": "nalbă",
    "nălbari": "nălbar",
    "nălbarii": "nălbar",
    "nălbarilor": "nălbar",
    "nălbarul": "nălbar",
    "nălbarului": "nălbar",
    "nălbea": "nălbi",
    "nălbeai": "nălbi",
    "nălbeam": "nălbi",
    "nălbească": "nălbi",
    "nălbeați": "nălbi",
    "nălbeau": "nălbi",
    "nălbesc": "nălbi",
    "nălbește": "nălbi",
    "nălbești": "nălbi",
    "nălbii": "nălbi",
    "nălbim": "nălbi",
    "nălbind": "nălbi",
    "nălbindu": "nălbi",
    "nălbiră": "nălbi",
    "nălbirăm": "nălbi",
    "nălbirăți": "nălbi",
    "nălbise": "nălbi",
    "nălbisem": "nălbi",
    "nălbiseră": "nălbi",
    "nălbiserăm": "nălbi",
    "nălbiserăți": "nălbi",
    "nălbiseși": "nălbi",
    "nălbiși": "nălbi",
    "nălbit": "nălbi",
    "nălbiți": "nălbi",
    "nemainălbind": "nălbi",
    "nemainălbindu": "nălbi",
    "nenălbind": "nălbi",
    "nenălbindu": "nălbi",
    "nălbită": "nălbit",
    "nălbite": "nălbit",
    "nălbiți": "nălbit",
    "năluca": "nălucă",
    "năluci": "nălucă",
    "nălucii": "nălucă",
    "nălucile": "nălucă",
    "nălucilor": "nălucă",
    "nălucea": "năluci",
    "năluceai": "năluci",
    "năluceam": "năluci",
    "nălucească": "năluci",
    "năluceați": "năluci",
    "năluceau": "năluci",
    "nălucesc": "năluci",
    "nălucește": "năluci",
    "nălucești": "năluci",
    "nălucii": "năluci",
    "nălucim": "năluci",
    "nălucind": "năluci",
    "nălucindu": "năluci",
    "năluciră": "năluci",
    "nălucirăm": "năluci",
    "nălucirăți": "năluci",
    "nălucise": "năluci",
    "nălucisem": "năluci",
    "năluciseră": "năluci",
    "năluciserăm": "năluci",
    "năluciserăți": "năluci",
    "năluciseși": "năluci",
    "năluciși": "năluci",
    "nălucit": "năluci",
    "năluciți": "năluci",
    "nemainălucind": "năluci",
    "nemainălucindu": "năluci",
    "nenălucind": "năluci",
    "nenălucindu": "năluci",
    "nălucită": "nălucit",
    "nălucite": "nălucit",
    "năluciți": "nălucit",
    "nălucitoare": "nălucitor",
    "nălucitoarea": "nălucitor",
    "nălucitoarei": "nălucitor",
    "nălucitoarele": "nălucitor",
    "nălucitoarelor": "nălucitor",
    "nălucitori": "nălucitor",
    "nălucitorii": "nălucitor",
    "nălucitorilor": "nălucitor",
    "nălucitorul": "nălucitor",
    "nălucitorului": "nălucitor",
    "nămetele": "nămete",
    "nămetelui": "nămete",
    "nămeți": "nămete",
    "nămeții": "nămete",
    "nămeților": "nămete",
    "nămețea": "nămeți",
    "nămețeai": "nămeți",
    "nămețeam": "nămeți",
    "nămețească": "nămeți",
    "nămețeați": "nămeți",
    "nămețeau": "nămeți",
    "nămețesc": "nămeți",
    "nămețește": "nămeți",
    "nămețești": "nămeți",
    "nămeții": "nămeți",
    "nămețim": "nămeți",
    "nămețind": "nămeți",
    "nămețindu": "nămeți",
    "nămețiră": "nămeți",
    "nămețirăm": "nămeți",
    "nămețirăți": "nămeți",
    "nămețise": "nămeți",
    "nămețisem": "nămeți",
    "nămețiseră": "nămeți",
    "nămețiserăm": "nămeți",
    "nămețiserăți": "nămeți",
    "nămețiseși": "nămeți",
    "nămețiși": "nămeți",
    "nămețit": "nămeți",
    "nămețiți": "nămeți",
    "nemainămețind": "nămeți",
    "nemainămețindu": "nămeți",
    "nenămețind": "nămeți",
    "nenămețindu": "nămeți",
    "nămețita": "nămețit",
    "nămețită": "nămețit",
    "nămețite": "nămețit",
    "nămețitei": "nămețit",
    "nămețitele": "nămețit",
    "nămețitelor": "nămețit",
    "nămețiți": "nămețit",
    "nămețiții": "nămețit",
    "nămețiților": "nămețit",
    "nămețitul": "nămețit",
    "nămețitului": "nămețit",
    "namiaza": "namiază",
    "nămiezi": "namiază",
    "nămiezii": "namiază",
    "nămiezile": "namiază",
    "nămiezilor": "namiază",
    "namibiana": "namibian",
    "namibiană": "namibian",
    "namibianul": "namibian",
    "namibianului": "namibian",
    "namibiene": "namibian",
    "namibienei": "namibian",
    "namibienele": "namibian",
    "namibienelor": "namibian",
    "namibieni": "namibian",
    "namibienii": "namibian",
    "namibienilor": "namibian",
    "namibiana": "namibiană",
    "namibiene": "namibiană",
    "namibienei": "namibiană",
    "namibienele": "namibiană",
    "namibienelor": "namibiană",
    "namila": "namilă",
    "namile": "namilă",
    "namilei": "namilă",
    "namilele": "namilă",
    "namilelor": "namilă",
    "nămolul": "nămol",
    "nămolului": "nămol",
    "nămoluri": "nămol",
    "nămolurile": "nămol",
    "nămolurilor": "nămol",
    "nămolea": "nămoli",
    "nămoleai": "nămoli",
    "nămoleam": "nămoli",
    "nămolească": "nămoli",
    "nămoleați": "nămoli",
    "nămoleau": "nămoli",
    "nămolesc": "nămoli",
    "nămolește": "nămoli",
    "nămolești": "nămoli",
    "nămolii": "nămoli",
    "nămolim": "nămoli",
    "nămolind": "nămoli",
    "nămolindu": "nămoli",
    "nămoliră": "nămoli",
    "nămolirăm": "nămoli",
    "nămolirăți": "nămoli",
    "nămolise": "nămoli",
    "nămolisem": "nămoli",
    "nămoliseră": "nămoli",
    "nămoliserăm": "nămoli",
    "nămoliserăți": "nămoli",
    "nămoliseși": "nămoli",
    "nămoliși": "nămoli",
    "nămolit": "nămoli",
    "nămoliți": "nămoli",
    "nemainămolind": "nămoli",
    "nemainămolindu": "nămoli",
    "nenămolind": "nămoli",
    "nenămolindu": "nămoli",
    "nămolită": "nămolit",
    "nămolite": "nămolit",
    "nămoliți": "nămolit",
    "nămoloasa": "nămolos",
    "nămoloasă": "nămolos",
    "nămoloase": "nămolos",
    "nămoloasei": "nămolos",
    "nămoloasele": "nămolos",
    "nămoloaselor": "nămolos",
    "nămoloși": "nămolos",
    "nămoloșii": "nămolos",
    "nămoloșilor": "nămolos",
    "nămolosul": "nămolos",
    "nămolosului": "nămolos",
    "nana": "nană",
    "nane": "nană",
    "nanei": "nană",
    "nanele": "nană",
    "nanelor": "nană",
    "nănașul": "nănaș",
    "nănașului": "nănaș",
    "nănașa": "nănașă",
    "nanchinul": "nanchin",
    "nanchinului": "nanchin",
    "nanchinuri": "nanchin",
    "nanchinurile": "nanchin",
    "nanchinurilor": "nanchin",
    "nandul": "nandu",
    "nandului": "nandu",
    "nanghinul": "nanghin",
    "nanghinului": "nanghin",
    "nanghinuri": "nanghin",
    "nanghinurile": "nanghin",
    "nanghinurilor": "nanghin",
    "nanisme": "nanism",
    "nanismele": "nanism",
    "nanismelor": "nanism",
    "nanismul": "nanism",
    "nanismului": "nanism",
    "n.": "nano",
    "nanomelia": "nanomelie",
    "nanomeliei": "nanomelie",
    "nanomelii": "nanomelie",
    "naosul": "naos",
    "naosului": "naos",
    "naosuri": "naos",
    "naosurile": "naos",
    "naosurilor": "naos",
    "napi": "nap",
    "napii": "nap",
    "napilor": "nap",
    "napul": "nap",
    "napului": "nap",
    "năpădea": "năpădi",
    "năpădeai": "năpădi",
    "năpădeam": "năpădi",
    "năpădească": "năpădi",
    "năpădeați": "năpădi",
    "năpădeau": "năpădi",
    "năpădesc": "năpădi",
    "năpădește": "năpădi",
    "năpădești": "năpădi",
    "năpădii": "năpădi",
    "năpădim": "năpădi",
    "năpădind": "năpădi",
    "năpădindu": "năpădi",
    "năpădiră": "năpădi",
    "năpădirăm": "năpădi",
    "năpădirăți": "năpădi",
    "năpădise": "năpădi",
    "năpădisem": "năpădi",
    "năpădiseră": "năpădi",
    "năpădiserăm": "năpădi",
    "năpădiserăți": "năpădi",
    "năpădiseși": "năpădi",
    "năpădiși": "năpădi",
    "năpădit": "năpădi",
    "năpădiți": "năpădi",
    "nemainăpădind": "năpădi",
    "nemainăpădindu": "năpădi",
    "nenăpădind": "năpădi",
    "nenăpădindu": "năpădi",
    "năpădită": "năpădit",
    "năpădite": "năpădit",
    "năpădiți": "năpădit",
    "napalmul": "napalm",
    "napalmului": "napalm",
    "năpârca": "năpârcă",
    "năpârci": "năpârcă",
    "năpârcii": "năpârcă",
    "năpârcile": "năpârcă",
    "năpârcilor": "năpârcă",
    "năpârlea": "năpârli",
    "năpârleai": "năpârli",
    "năpârleam": "năpârli",
    "năpârlească": "năpârli",
    "năpârleați": "năpârli",
    "năpârleau": "năpârli",
    "năpârlesc": "năpârli",
    "năpârlește": "năpârli",
    "năpârlești": "năpârli",
    "năpârlii": "năpârli",
    "năpârlim": "năpârli",
    "năpârlind": "năpârli",
    "năpârlindu": "năpârli",
    "năpârliră": "năpârli",
    "năpârlirăm": "năpârli",
    "năpârlirăți": "năpârli",
    "năpârlise": "năpârli",
    "năpârlisem": "năpârli",
    "năpârliseră": "năpârli",
    "năpârliserăm": "năpârli",
    "năpârliserăți": "năpârli",
    "năpârliseși": "năpârli",
    "năpârliși": "năpârli",
    "năpârlit": "năpârli",
    "năpârliți": "năpârli",
    "nemainăpârlind": "năpârli",
    "nemainăpârlindu": "năpârli",
    "nenăpârlind": "năpârli",
    "nenăpârlindu": "năpârli",
    "năpârlită": "năpârlit",
    "năpârlite": "năpârlit",
    "năpârliți": "năpârlit",
    "năpârstoaca": "năpârstoacă",
    "năpârstoace": "năpârstoacă",
    "năpârstoacei": "năpârstoacă",
    "năpârstoacele": "năpârstoacă",
    "năpârstoacelor": "năpârstoacă",
    "năpârstoci": "năpârstoc",
    "năpârstocii": "năpârstoc",
    "năpârstocilor": "năpârstoc",
    "năpârstocul": "năpârstoc",
    "năpârstocului": "năpârstoc",
    "năpasta": "năpastă",
    "năpaste": "năpastă",
    "năpastei": "năpastă",
    "năpastele": "năpastă",
    "năpastelor": "năpastă",
    "năpăstuia": "năpăstui",
    "năpăstuiai": "năpăstui",
    "năpăstuiam": "năpăstui",
    "năpăstuiască": "năpăstui",
    "năpăstuiați": "năpăstui",
    "năpăstuiau": "năpăstui",
    "năpăstuiesc": "năpăstui",
    "năpăstuiește": "năpăstui",
    "năpăstuiești": "năpăstui",
    "năpăstuii": "năpăstui",
    "năpăstuim": "năpăstui",
    "năpăstuind": "năpăstui",
    "năpăstuindu": "năpăstui",
    "năpăstuiră": "năpăstui",
    "năpăstuirăm": "năpăstui",
    "năpăstuirăți": "năpăstui",
    "năpăstuise": "năpăstui",
    "năpăstuisem": "năpăstui",
    "năpăstuiseră": "năpăstui",
    "năpăstuiserăm": "năpăstui",
    "năpăstuiserăți": "năpăstui",
    "năpăstuiseși": "năpăstui",
    "năpăstuiși": "năpăstui",
    "năpăstuit": "năpăstui",
    "năpăstuiți": "năpăstui",
    "nemainăpăstuind": "năpăstui",
    "nemainăpăstuindu": "năpăstui",
    "nenăpăstuind": "năpăstui",
    "nenăpăstuindu": "năpăstui",
    "năpăstuită": "năpăstuit",
    "năpăstuite": "năpăstuit",
    "năpăstuiți": "năpăstuit",
    "napoleoni": "napoleon",
    "napoleonii": "napoleon",
    "napoleonilor": "napoleon",
    "napoleonul": "napoleon",
    "napoleonului": "napoleon",
    "napoleoniana": "napoleonian",
    "napoleoniană": "napoleonian",
    "napoleonianul": "napoleonian",
    "napoleonianului": "napoleonian",
    "napoleoniene": "napoleonian",
    "napoleonienei": "napoleonian",
    "napoleonienele": "napoleonian",
    "napoleonienelor": "napoleonian",
    "napoleonieni": "napoleonian",
    "napoleonienii": "napoleonian",
    "napoleonienilor": "napoleonian",
    "napolitana": "napolitan",
    "napolitană": "napolitan",
    "napolitane": "napolitan",
    "napolitanei": "napolitan",
    "napolitanele": "napolitan",
    "napolitanelor": "napolitan",
    "napolitani": "napolitan",
    "napolitanii": "napolitan",
    "napolitanilor": "napolitan",
    "napolitanul": "napolitan",
    "napolitanului": "napolitan",
    "napolitana": "napolitană",
    "napolitane": "napolitană",
    "napolitanei": "napolitană",
    "napolitanele": "napolitană",
    "napolitanelor": "napolitană",
    "năprasnica": "năprasnic",
    "năprasnică": "năprasnic",
    "năprasnice": "năprasnic",
    "năprasnicei": "năprasnic",
    "năprasnicele": "năprasnic",
    "năprasnicelor": "năprasnic",
    "năprasnici": "năprasnic",
    "năprasnicii": "năprasnic",
    "năprasnicilor": "năprasnic",
    "năprasnicul": "năprasnic",
    "năprasnicului": "năprasnic",
    "năpustea": "năpusti",
    "năpusteai": "năpusti",
    "năpusteam": "năpusti",
    "năpustească": "năpusti",
    "năpusteați": "năpusti",
    "năpusteau": "năpusti",
    "năpustesc": "năpusti",
    "năpustește": "năpusti",
    "năpustești": "năpusti",
    "năpustii": "năpusti",
    "năpustim": "năpusti",
    "năpustind": "năpusti",
    "năpustindu": "năpusti",
    "năpustiră": "năpusti",
    "năpustirăm": "năpusti",
    "năpustirăți": "năpusti",
    "năpustise": "năpusti",
    "năpustisem": "năpusti",
    "năpustiseră": "năpusti",
    "năpustiserăm": "năpusti",
    "năpustiserăți": "năpusti",
    "năpustiseși": "năpusti",
    "năpustiși": "năpusti",
    "năpustit": "năpusti",
    "năpustiți": "năpusti",
    "nemainăpustind": "năpusti",
    "nemainăpustindu": "năpusti",
    "nenăpustind": "năpusti",
    "nenăpustindu": "năpusti",
    "năpustirea": "năpustire",
    "năpustiri": "năpustire",
    "năpustirii": "năpustire",
    "năpustirile": "năpustire",
    "năpustirilor": "năpustire",
    "năpustită": "năpustit",
    "năpustite": "năpustit",
    "năpustiți": "năpustit",
    "nară": "nara",
    "narai": "nara",
    "naram": "nara",
    "narăm": "nara",
    "narând": "nara",
    "narându": "nara",
    "narară": "nara",
    "nararăm": "nara",
    "nararăți": "nara",
    "narase": "nara",
    "narasem": "nara",
    "naraseră": "nara",
    "naraserăm": "nara",
    "naraserăți": "nara",
    "naraseși": "nara",
    "narași": "nara",
    "narat": "nara",
    "narați": "nara",
    "narau": "nara",
    "narează": "nara",
    "narez": "nara",
    "nareze": "nara",
    "narezi": "nara",
    "nemainarând": "nara",
    "nemainarându": "nara",
    "nenarând": "nara",
    "nenarându": "nara",
    "nara": "nară",
    "nări": "nară",
    "nării": "nară",
    "nările": "nară",
    "nărilor": "nară",
    "narată": "narat",
    "narate": "narat",
    "narați": "narat",
    "narațiunea": "narațiune",
    "narațiuni": "narațiune",
    "narațiunii": "narațiune",
    "narațiunile": "narațiune",
    "narațiunilor": "narațiune",
    "narativa": "narativ",
    "narativă": "narativ",
    "narative": "narativ",
    "narativei": "narativ",
    "narativele": "narativ",
    "narativelor": "narativ",
    "narativi": "narativ",
    "narativii": "narativ",
    "narativilor": "narativ",
    "narativul": "narativ",
    "narativului": "narativ",
    "naratoarea": "naratoare",
    "naratoarei": "naratoare",
    "naratoarele": "naratoare",
    "naratoarelor": "naratoare",
    "naratori": "narator",
    "naratorii": "narator",
    "naratorilor": "narator",
    "naratorul": "narator",
    "naratorului": "narator",
    "năravul": "nărav",
    "năravului": "nărav",
    "năravuri": "nărav",
    "năravurile": "nărav",
    "năravurilor": "nărav",
    "nărăvașa": "nărăvaș",
    "nărăvașă": "nărăvaș",
    "nărăvașe": "nărăvaș",
    "nărăvașei": "nărăvaș",
    "nărăvașele": "nărăvaș",
    "nărăvașelor": "nărăvaș",
    "nărăvași": "nărăvaș",
    "nărăvașii": "nărăvaș",
    "nărăvașilor": "nărăvaș",
    "nărăvașul": "nărăvaș",
    "nărăvașului": "nărăvaș",
    "nărăveala": "nărăveală",
    "nărăveli": "nărăveală",
    "nărăvelii": "nărăveală",
    "nărăvelile": "nărăveală",
    "nărăvelilor": "nărăveală",
    "nărăvea": "nărăvi",
    "nărăveai": "nărăvi",
    "nărăveam": "nărăvi",
    "nărăvească": "nărăvi",
    "nărăveați": "nărăvi",
    "nărăveau": "nărăvi",
    "nărăvesc": "nărăvi",
    "nărăvește": "nărăvi",
    "nărăvești": "nărăvi",
    "nărăvii": "nărăvi",
    "nărăvim": "nărăvi",
    "nărăvind": "nărăvi",
    "nărăvindu": "nărăvi",
    "nărăviră": "nărăvi",
    "nărăvirăm": "nărăvi",
    "nărăvirăți": "nărăvi",
    "nărăvise": "nărăvi",
    "nărăvisem": "nărăvi",
    "nărăviseră": "nărăvi",
    "nărăviserăm": "nărăvi",
    "nărăviserăți": "nărăvi",
    "nărăviseși": "nărăvi",
    "nărăviși": "nărăvi",
    "nărăvit": "nărăvi",
    "nărăviți": "nărăvi",
    "nemainărăvind": "nărăvi",
    "nemainărăvindu": "nărăvi",
    "nenărăvind": "nărăvi",
    "nenărăvindu": "nărăvi",
    "nărăvită": "nărăvit",
    "nărăvite": "nărăvit",
    "nărăviți": "nărăvit",
    "narcisul": "narcis",
    "narcisului": "narcis",
    "narcisa": "narcisă",
    "narcise": "narcisă",
    "narcisei": "narcisă",
    "narcisele": "narcisă",
    "narciselor": "narcisă",
    "narcisica": "narcisic",
    "narcisică": "narcisic",
    "narcisice": "narcisic",
    "narcisicei": "narcisic",
    "narcisicele": "narcisic",
    "narcisicelor": "narcisic",
    "narcisici": "narcisic",
    "narcisicii": "narcisic",
    "narcisicilor": "narcisic",
    "narcisicul": "narcisic",
    "narcisicului": "narcisic",
    "narcisista": "narcisist",
    "narcisistă": "narcisist",
    "narcisiste": "narcisist",
    "narcisistei": "narcisist",
    "narcisistele": "narcisist",
    "narcisistelor": "narcisist",
    "narcisiști": "narcisist",
    "narcisiștii": "narcisist",
    "narcisiștilor": "narcisist",
    "narcisistul": "narcisist",
    "narcisistului": "narcisist",
    "narcolepsia": "narcolepsie",
    "narcolepsiei": "narcolepsie",
    "narcolepsii": "narcolepsie",
    "narcotica": "narcotic",
    "narcotică": "narcotic",
    "narcotice": "narcotic",
    "narcoticei": "narcotic",
    "narcoticele": "narcotic",
    "narcoticelor": "narcotic",
    "narcotici": "narcotic",
    "narcoticii": "narcotic",
    "narcoticilor": "narcotic",
    "narcoticul": "narcotic",
    "narcoticului": "narcotic",
    "narcotina": "narcotină",
    "narcotine": "narcotină",
    "narcotinei": "narcotină",
    "narcotinele": "narcotină",
    "narcotinelor": "narcotină",
    "narcotiză": "narcotiza",
    "narcotizai": "narcotiza",
    "narcotizam": "narcotiza",
    "narcotizăm": "narcotiza",
    "narcotizând": "narcotiza",
    "narcotizându": "narcotiza",
    "narcotizară": "narcotiza",
    "narcotizarăm": "narcotiza",
    "narcotizarăți": "narcotiza",
    "narcotizase": "narcotiza",
    "narcotizasem": "narcotiza",
    "narcotizaseră": "narcotiza",
    "narcotizaserăm": "narcotiza",
    "narcotizaserăți": "narcotiza",
    "narcotizaseși": "narcotiza",
    "narcotizași": "narcotiza",
    "narcotizat": "narcotiza",
    "narcotizați": "narcotiza",
    "narcotizau": "narcotiza",
    "narcotizează": "narcotiza",
    "narcotizez": "narcotiza",
    "narcotizeze": "narcotiza",
    "narcotizezi": "narcotiza",
    "nemainarcotizând": "narcotiza",
    "nemainarcotizându": "narcotiza",
    "nenarcotizând": "narcotiza",
    "nenarcotizându": "narcotiza",
    "narcotizată": "narcotizat",
    "narcotizate": "narcotizat",
    "narcotizați": "narcotizat",
    "narcoza": "narcoză",
    "narcoze": "narcoză",
    "narcozei": "narcoză",
    "narcozele": "narcoză",
    "narcozelor": "narcoză",
    "nardul": "nard",
    "nardului": "nard",
    "narghileaua": "narghilea",
    "narghilele": "narghilea",
    "narghilelei": "narghilea",
    "narghilelele": "narghilea",
    "narghilelelor": "narghilea",
    "narodnici": "narodnic",
    "narodnicii": "narodnic",
    "narodnicilor": "narodnic",
    "narodnicul": "narodnic",
    "narodnicului": "narodnic",
    "narodnica": "narodnică",
    "narodnice": "narodnică",
    "narodnicei": "narodnică",
    "narodnicele": "narodnică",
    "narodnicelor": "narodnică",
    "narodnicisme": "narodnicism",
    "narodnicismele": "narodnicism",
    "narodnicismelor": "narodnicism",
    "narodnicismul": "narodnicism",
    "narodnicismului": "narodnicism",
    "năruia": "nărui",
    "năruiai": "nărui",
    "năruiam": "nărui",
    "năruiască": "nărui",
    "năruiați": "nărui",
    "năruiau": "nărui",
    "năruiesc": "nărui",
    "năruiește": "nărui",
    "năruiești": "nărui",
    "năruii": "nărui",
    "năruim": "nărui",
    "năruind": "nărui",
    "năruindu": "nărui",
    "năruiră": "nărui",
    "năruirăm": "nărui",
    "năruirăți": "nărui",
    "năruise": "nărui",
    "năruisem": "nărui",
    "năruiseră": "nărui",
    "năruiserăm": "nărui",
    "năruiserăți": "nărui",
    "năruiseși": "nărui",
    "năruiși": "nărui",
    "năruit": "nărui",
    "năruiți": "nărui",
    "nemainăruind": "nărui",
    "nemainăruindu": "nărui",
    "nenăruind": "nărui",
    "nenăruindu": "nărui",
    "năruită": "năruit",
    "năruite": "năruit",
    "năruiți": "năruit",
    "năruitura": "năruitură",
    "năruituri": "năruitură",
    "năruiturii": "năruitură",
    "năruiturile": "năruitură",
    "năruiturilor": "năruitură",
    "narvali": "narval",
    "narvalii": "narval",
    "narvalilor": "narval",
    "narvalul": "narval",
    "narvalului": "narval",
    "nasul": "nas",
    "nasului": "nas",
    "nasuri": "nas",
    "nasurile": "nas",
    "nasurilor": "nas",
    "nași": "naș",
    "nașii": "naș",
    "nașilor": "naș",
    "nașul": "naș",
    "nașului": "naș",
    "năsădea": "năsădi",
    "năsădeai": "năsădi",
    "năsădeam": "năsădi",
    "năsădească": "năsădi",
    "năsădeați": "năsădi",
    "năsădeau": "năsădi",
    "năsădesc": "năsădi",
    "năsădește": "năsădi",
    "năsădești": "năsădi",
    "năsădii": "năsădi",
    "năsădim": "năsădi",
    "năsădind": "năsădi",
    "năsădindu": "năsădi",
    "năsădiră": "năsădi",
    "năsădirăm": "năsădi",
    "năsădirăți": "năsădi",
    "năsădise": "năsădi",
    "năsădisem": "năsădi",
    "năsădiseră": "năsădi",
    "năsădiserăm": "năsădi",
    "năsădiserăți": "năsădi",
    "năsădiseși": "năsădi",
    "năsădiși": "năsădi",
    "năsădit": "năsădi",
    "năsădiți": "năsădi",
    "nemainăsădind": "năsădi",
    "nemainăsădindu": "năsădi",
    "nenăsădind": "năsădi",
    "nenăsădindu": "năsădi",
    "năsădită": "năsădit",
    "năsădite": "năsădit",
    "năsădiți": "năsădit",
    "năsăudeana": "năsăudean",
    "năsăudeană": "năsăudean",
    "năsăudeanul": "năsăudean",
    "năsăudeanului": "năsăudean",
    "năsăudene": "năsăudean",
    "năsăudenei": "năsăudean",
    "năsăudenele": "năsăudean",
    "năsăudenelor": "năsăudean",
    "năsăudeni": "năsăudean",
    "năsăudenii": "năsăudean",
    "năsăudenilor": "năsăudean",
    "născânda": "născând",
    "născândă": "născând",
    "născânde": "născând",
    "născândei": "născând",
    "născândele": "născând",
    "născândelor": "născând",
    "născândul": "născând",
    "născândului": "născând",
    "născânzi": "născând",
    "născânzii": "născând",
    "născânzilor": "născând",
    "născătoarea": "născătoare",
    "născători": "născătoare",
    "născătorii": "născătoare",
    "născătorile": "născătoare",
    "născătorilor": "născătoare",
    "născocea": "născoci",
    "născoceai": "născoci",
    "născoceam": "născoci",
    "născocească": "născoci",
    "născoceați": "născoci",
    "născoceau": "născoci",
    "născocesc": "născoci",
    "născocește": "născoci",
    "născocești": "născoci",
    "născocii": "născoci",
    "născocim": "născoci",
    "născocind": "născoci",
    "născocindu": "născoci",
    "născociră": "născoci",
    "născocirăm": "născoci",
    "născocirăți": "născoci",
    "născocise": "născoci",
    "născocisem": "născoci",
    "născociseră": "născoci",
    "născociserăm": "născoci",
    "născociserăți": "născoci",
    "născociseși": "născoci",
    "născociși": "născoci",
    "născocit": "născoci",
    "născociți": "născoci",
    "nemainăscocind": "născoci",
    "nemainăscocindu": "născoci",
    "nenăscocind": "născoci",
    "nenăscocindu": "născoci",
    "născocirea": "născocire",
    "născociri": "născocire",
    "născocirii": "născocire",
    "născocirile": "născocire",
    "născocirilor": "născocire",
    "născocită": "născocit",
    "născocite": "născocit",
    "născociți": "născocit",
    "născocitoare": "născocitor",
    "născocitoarea": "născocitor",
    "născocitoarei": "născocitor",
    "născocitoarele": "născocitor",
    "născocitoarelor": "născocitor",
    "născocitori": "născocitor",
    "născocitorii": "născocitor",
    "născocitorilor": "născocitor",
    "născocitorul": "născocitor",
    "născocitorului": "născocitor",
    "născuta": "născut",
    "născută": "născut",
    "născute": "născut",
    "născutei": "născut",
    "născutele": "născut",
    "născutelor": "născut",
    "născuți": "născut",
    "născuții": "născut",
    "născuților": "născut",
    "născutul": "născut",
    "născutului": "născut",
    "născuta": "născută",
    "născute": "născută",
    "născutei": "născută",
    "născutele": "născută",
    "născutelor": "născută",
    "nășea": "năși",
    "nășeai": "năși",
    "nășeam": "năși",
    "nășească": "năși",
    "nășeați": "năși",
    "nășeau": "năși",
    "nășesc": "năși",
    "nășește": "năși",
    "nășești": "năși",
    "nășii": "năși",
    "nășim": "năși",
    "nășind": "năși",
    "nășindu": "năși",
    "nășiră": "năși",
    "nășirăm": "năși",
    "nășirăți": "năși",
    "nășise": "năși",
    "nășisem": "năși",
    "nășiseră": "năși",
    "nășiserăm": "năși",
    "nășiserăți": "năși",
    "nășiseși": "năși",
    "nășiși": "năși",
    "nășit": "năși",
    "nășiți": "năși",
    "nemainășind": "năși",
    "nemainășindu": "năși",
    "nenășind": "năși",
    "nenășindu": "năși",
    "nasicorni": "nasicorn",
    "nasicornii": "nasicorn",
    "nasicornilor": "nasicorn",
    "nasicornul": "nasicorn",
    "nasicornului": "nasicorn",
    "nășia": "nășie",
    "nășiei": "nășie",
    "nășii": "nășie",
    "nășiile": "nășie",
    "nășiilor": "nășie",
    "nășită": "nășit",
    "nășite": "nășit",
    "nășiți": "nășit",
    "nășitul": "nășit",
    "nășitului": "nășit",
    "nasoala": "nasol",
    "nasoală": "nasol",
    "nasoale": "nasol",
    "nasoalei": "nasol",
    "nasoalele": "nasol",
    "nasoalelor": "nasol",
    "nasoli": "nasol",
    "nasolii": "nasol",
    "nasolilor": "nasol",
    "nasolul": "nasol",
    "nasolului": "nasol",
    "năsoasa": "năsos",
    "năsoasă": "năsos",
    "năsoase": "năsos",
    "năsoasei": "năsos",
    "năsoasele": "năsos",
    "năsoaselor": "năsos",
    "năsoși": "năsos",
    "năsoșii": "năsos",
    "năsoșilor": "năsos",
    "năsosul": "năsos",
    "năsosului": "năsos",
    "năstașnica": "năstașnic",
    "năstașnică": "năstașnic",
    "năstașnice": "năstașnic",
    "năstașnicei": "năstașnic",
    "năstașnicele": "năstașnic",
    "năstașnicelor": "năstașnic",
    "năstașnici": "năstașnic",
    "năstașnicii": "năstașnic",
    "năstașnicilor": "năstașnic",
    "năstașnicul": "năstașnic",
    "năstașnicului": "năstașnic",
    "nasc": "naște",
    "nască": "naște",
    "născând": "naște",
    "născându": "naște",
    "născu": "naște",
    "născu'": "naște",
    "născui": "naște",
    "născură": "naște",
    "născurăm": "naște",
    "născurăți": "naște",
    "născuse": "naște",
    "născusem": "naște",
    "născuseră": "naște",
    "născuserăm": "naște",
    "născuserăți": "naște",
    "născuseși": "naște",
    "născuși": "naște",
    "născut": "naște",
    "năștea": "naște",
    "nășteai": "naște",
    "nășteam": "naște",
    "nășteați": "naște",
    "nășteau": "naște",
    "naștem": "naște",
    "nașteți": "naște",
    "naști": "naște",
    "nemainăscând": "naște",
    "nemainăscându": "naște",
    "nenăscând": "naște",
    "nenăscându": "naște",
    "nașterea": "naștere",
    "nașteri": "naștere",
    "nașterii": "naștere",
    "nașterile": "naștere",
    "nașterilor": "naștere",
    "nastia": "nastie",
    "nastiei": "nastie",
    "nastii": "nastie",
    "nastiile": "nastie",
    "nastiilor": "nastie",
    "nastratineasca": "nastratinesc",
    "nastratinească": "nastratinesc",
    "nastratinescul": "nastratinesc",
    "nastratinescului": "nastratinesc",
    "nastratinești": "nastratinesc",
    "nastratineștii": "nastratinesc",
    "nastratineștile": "nastratinesc",
    "nastratineștilor": "nastratinesc",
    "năstrușnica": "năstrușnic",
    "năstrușnică": "năstrușnic",
    "năstrușnice": "năstrușnic",
    "năstrușnicei": "năstrușnic",
    "năstrușnicele": "năstrușnic",
    "năstrușnicelor": "năstrușnic",
    "năstrușnici": "năstrușnic",
    "năstrușnicii": "năstrușnic",
    "năstrușnicilor": "năstrușnic",
    "năstrușnicul": "năstrușnic",
    "năstrușnicului": "năstrușnic",
    "năstrușnicia": "năstrușnicie",
    "năstrușniciei": "năstrușnicie",
    "năstrușnicii": "năstrușnicie",
    "năstrușniciile": "năstrușnicie",
    "năstrușniciilor": "năstrușnicie",
    "nasturele": "nasture",
    "nasturelui": "nasture",
    "nasturi": "nasture",
    "nasturii": "nasture",
    "nasturilor": "nasture",
    "nătăfleața": "nătăfleață",
    "nătăflețe": "nătăfleață",
    "nătăfleței": "nătăfleață",
    "nătăflețele": "nătăfleață",
    "nătăflețelor": "nătăfleață",
    "nătăfleața": "nătăfleț",
    "nătăfleață": "nătăfleț",
    "nătăflețe": "nătăfleț",
    "nătăfleței": "nătăfleț",
    "nătăflețele": "nătăfleț",
    "nătăflețelor": "nătăfleț",
    "nătăfleți": "nătăfleț",
    "nătăfleții": "nătăfleț",
    "nătăfleților": "nătăfleț",
    "nătăflețul": "nătăfleț",
    "nătăflețului": "nătăfleț",
    "natala": "natal",
    "natală": "natal",
    "natale": "natal",
    "natalei": "natal",
    "natalele": "natal",
    "natalelor": "natal",
    "natali": "natal",
    "natalii": "natal",
    "natalilor": "natal",
    "natalul": "natal",
    "natalului": "natal",
    "natalitatea": "natalitate",
    "natalități": "natalitate",
    "natalității": "natalitate",
    "natalitățile": "natalitate",
    "natalităților": "natalitate",
    "nătânga": "nătâng",
    "nătângă": "nătâng",
    "nătânge": "nătâng",
    "nătângei": "nătâng",
    "nătângele": "nătâng",
    "nătângelor": "nătâng",
    "nătângi": "nătâng",
    "nătângii": "nătâng",
    "nătângilor": "nătâng",
    "nătângul": "nătâng",
    "nătângului": "nătâng",
    "nătânga": "nătângă",
    "nătânge": "nătângă",
    "nătângei": "nătângă",
    "nătângele": "nătângă",
    "nătângelor": "nătângă",
    "nătărăi": "nătărău",
    "nătărăii": "nătărău",
    "nătărăilor": "nătărău",
    "nătărăul": "nătărău",
    "nătărăului": "nătărău",
    "nătăroaica": "nătăroaică",
    "nătăroaice": "nătăroaică",
    "nătăroaicei": "nătăroaică",
    "nătăroaicele": "nătăroaică",
    "nătăroaicelor": "nătăroaică",
    "natația": "natație",
    "natației": "natație",
    "natații": "natație",
    "nația": "nație",
    "nației": "nație",
    "nații": "nație",
    "națiile": "nație",
    "națiilor": "nație",
    "naț.": "național",
    "naționala": "național",
    "națională": "național",
    "naționale": "național",
    "naționalei": "național",
    "naționalele": "național",
    "naționalelor": "național",
    "naționali": "național",
    "naționalii": "național",
    "naționalilor": "național",
    "naționalul": "național",
    "naționalului": "național",
    "naționala": "națională",
    "naționale": "națională",
    "naționalei": "națională",
    "naționalele": "națională",
    "naționalelor": "națională",
    "naționalisme": "naționalism",
    "naționalismele": "naționalism",
    "naționalismelor": "naționalism",
    "naționalismul": "naționalism",
    "naționalismului": "naționalism",
    "naționalista": "naționalist",
    "naționalistă": "naționalist",
    "naționaliste": "naționalist",
    "naționalistei": "naționalist",
    "naționalistele": "naționalist",
    "naționalistelor": "naționalist",
    "naționaliști": "naționalist",
    "naționaliștii": "naționalist",
    "naționaliștilor": "naționalist",
    "naționalistul": "naționalist",
    "naționalistului": "naționalist",
    "naționalista": "naționalistă",
    "naționaliste": "naționalistă",
    "naționalistei": "naționalistă",
    "naționalistele": "naționalistă",
    "naționalistelor": "naționalistă",
    "naționalist-extremista": "naționalist-extremist",
    "naționalist-extremistă": "naționalist-extremist",
    "naționalist-extremiste": "naționalist-extremist",
    "naționalist-extremistei": "naționalist-extremist",
    "naționalist-extremistele": "naționalist-extremist",
    "naționalist-extremistelor": "naționalist-extremist",
    "naționalist-extremiști": "naționalist-extremist",
    "naționalist-extremiștii": "naționalist-extremist",
    "naționalist-extremiștilor": "naționalist-extremist",
    "naționalist-extremisto": "naționalist-extremist",
    "naționalist-extremistul": "naționalist-extremist",
    "naționalist-extremistule": "naționalist-extremist",
    "naționalist-extremistului": "naționalist-extremist",
    "naționalist-extremista": "naționalist-extremistă",
    "naționalist-extremiste": "naționalist-extremistă",
    "naționalist-extremistei": "naționalist-extremistă",
    "naționalist-extremistele": "naționalist-extremistă",
    "naționalist-extremistelor": "naționalist-extremistă",
    "naționalist-extremisto": "naționalist-extremistă",
    "naționalist-socialista": "naționalist-socialist",
    "naționalist-socialistă": "naționalist-socialist",
    "naționalist-socialiste": "naționalist-socialist",
    "naționalist-socialistei": "naționalist-socialist",
    "naționalist-socialistele": "naționalist-socialist",
    "naționalist-socialistelor": "naționalist-socialist",
    "naționalist-socialiști": "naționalist-socialist",
    "naționalist-socialiștii": "naționalist-socialist",
    "naționalist-socialiștilor": "naționalist-socialist",
    "naționalist-socialisto": "naționalist-socialist",
    "naționalist-socialistul": "naționalist-socialist",
    "naționalist-socialistule": "naționalist-socialist",
    "naționalist-socialistului": "naționalist-socialist",
    "național-socialistă": "naționalist-socialist",
    "naționalist-socialista": "naționalist-socialistă",
    "naționalist-socialiste": "naționalist-socialistă",
    "naționalist-socialistei": "naționalist-socialistă",
    "naționalist-socialistele": "naționalist-socialistă",
    "naționalist-socialistelor": "naționalist-socialistă",
    "naționalist-socialisto": "naționalist-socialistă",
    "naționalitatea": "naționalitate",
    "naționalități": "naționalitate",
    "naționalității": "naționalitate",
    "naționalitățile": "naționalitate",
    "naționalităților": "naționalitate",
    "naționaliză": "naționaliza",
    "naționalizai": "naționaliza",
    "naționalizam": "naționaliza",
    "naționalizăm": "naționaliza",
    "naționalizând": "naționaliza",
    "naționalizându": "naționaliza",
    "naționalizară": "naționaliza",
    "naționalizarăm": "naționaliza",
    "naționalizarăți": "naționaliza",
    "naționalizase": "naționaliza",
    "naționalizasem": "naționaliza",
    "naționalizaseră": "naționaliza",
    "naționalizaserăm": "naționaliza",
    "naționalizaserăți": "naționaliza",
    "naționalizaseși": "naționaliza",
    "naționalizași": "naționaliza",
    "naționalizat": "naționaliza",
    "naționalizați": "naționaliza",
    "naționalizau": "naționaliza",
    "naționalizează": "naționaliza",
    "naționalizez": "naționaliza",
    "naționalizeze": "naționaliza",
    "naționalizezi": "naționaliza",
    "nemainaționalizând": "naționaliza",
    "nemainaționalizându": "naționaliza",
    "nenaționalizând": "naționaliza",
    "nenaționalizându": "naționaliza",
    "naționalizarea": "naționalizare",
    "naționalizări": "naționalizare",
    "naționalizării": "naționalizare",
    "naționalizările": "naționalizare",
    "naționalizărilor": "naționalizare",
    "naționalizată": "naționalizat",
    "naționalizate": "naționalizat",
    "naționalizați": "naționalizat",
    "național-socialiști": "național-socialist",
    "național-socialiștii": "național-socialist",
    "național-socialiștilor": "național-socialist",
    "național-socialistul": "național-socialist",
    "național-socialistului": "național-socialist",
    "națiunea": "națiune",
    "națiuni": "națiune",
    "națiunii": "națiune",
    "națiunile": "națiune",
    "națiunilor": "națiune",
    "nativa": "nativ",
    "nativă": "nativ",
    "native": "nativ",
    "nativei": "nativ",
    "nativele": "nativ",
    "nativelor": "nativ",
    "nativi": "nativ",
    "nativii": "nativ",
    "nativilor": "nativ",
    "nativul": "nativ",
    "nativului": "nativ",
    "natura": "natură",
    "naturi": "natură",
    "naturii": "natură",
    "naturile": "natură",
    "naturilor": "natură",
    "naturala": "natural",
    "naturală": "natural",
    "naturale": "natural",
    "naturalei": "natural",
    "naturalele": "natural",
    "naturalelor": "natural",
    "naturali": "natural",
    "naturalii": "natural",
    "naturalilor": "natural",
    "naturalul": "natural",
    "naturalului": "natural",
    "naturalețea": "naturalețe",
    "naturaleți": "naturalețe",
    "naturaleții": "naturalețe",
    "naturalismul": "naturalism",
    "naturalismului": "naturalism",
    "naturalista": "naturalist",
    "naturalistă": "naturalist",
    "naturaliste": "naturalist",
    "naturalistei": "naturalist",
    "naturalistele": "naturalist",
    "naturalistelor": "naturalist",
    "naturaliști": "naturalist",
    "naturaliștii": "naturalist",
    "naturaliștilor": "naturalist",
    "naturalistul": "naturalist",
    "naturalistului": "naturalist",
    "naturalista": "naturalistă",
    "naturaliste": "naturalistă",
    "naturalistei": "naturalistă",
    "naturalistele": "naturalistă",
    "naturalistelor": "naturalistă",
    "naturaliză": "naturaliza",
    "naturalizai": "naturaliza",
    "naturalizam": "naturaliza",
    "naturalizăm": "naturaliza",
    "naturalizând": "naturaliza",
    "naturalizându": "naturaliza",
    "naturalizară": "naturaliza",
    "naturalizarăm": "naturaliza",
    "naturalizarăți": "naturaliza",
    "naturalizase": "naturaliza",
    "naturalizasem": "naturaliza",
    "naturalizaseră": "naturaliza",
    "naturalizaserăm": "naturaliza",
    "naturalizaserăți": "naturaliza",
    "naturalizaseși": "naturaliza",
    "naturalizași": "naturaliza",
    "naturalizat": "naturaliza",
    "naturalizați": "naturaliza",
    "naturalizau": "naturaliza",
    "naturalizează": "naturaliza",
    "naturalizez": "naturaliza",
    "naturalizeze": "naturaliza",
    "naturalizezi": "naturaliza",
    "nemainaturalizând": "naturaliza",
    "nemainaturalizându": "naturaliza",
    "nenaturalizând": "naturaliza",
    "nenaturalizându": "naturaliza",
    "naturalizată": "naturalizat",
    "naturalizate": "naturalizat",
    "naturalizați": "naturalizat",
    "naturismul": "naturism",
    "naturismului": "naturism",
    "naturista": "naturist",
    "naturistă": "naturist",
    "naturiste": "naturist",
    "naturistei": "naturist",
    "naturistele": "naturist",
    "naturistelor": "naturist",
    "naturiști": "naturist",
    "naturiștii": "naturist",
    "naturiștilor": "naturist",
    "naturistul": "naturist",
    "naturistului": "naturist",
    "năuca": "năuc",
    "năucă": "năuc",
    "năuce": "năuc",
    "năucei": "năuc",
    "năucele": "năuc",
    "năucelor": "năuc",
    "năuci": "năuc",
    "năucii": "năuc",
    "năucilor": "năuc",
    "năucul": "năuc",
    "năucului": "năuc",
    "năuceala": "năuceală",
    "năuceli": "năuceală",
    "năucelii": "năuceală",
    "năucelile": "năuceală",
    "năucelilor": "năuceală",
    "năucea": "năuci",
    "năuceai": "năuci",
    "năuceam": "năuci",
    "năucească": "năuci",
    "năuceați": "năuci",
    "năuceau": "năuci",
    "năucesc": "năuci",
    "năucește": "năuci",
    "năucești": "năuci",
    "năucii": "năuci",
    "năucim": "năuci",
    "năucind": "năuci",
    "năucindu": "năuci",
    "năuciră": "năuci",
    "năucirăm": "năuci",
    "năucirăți": "năuci",
    "năucise": "năuci",
    "năucisem": "năuci",
    "năuciseră": "năuci",
    "năuciserăm": "năuci",
    "năuciserăți": "năuci",
    "năuciseși": "năuci",
    "năuciși": "năuci",
    "năucit": "năuci",
    "năuciți": "năuci",
    "nemainăucind": "năuci",
    "nemainăucindu": "năuci",
    "nenăucind": "năuci",
    "nenăucindu": "năuci",
    "năucită": "năucit",
    "năucite": "năucit",
    "năuciți": "năucit",
    "năucitoare": "năucitor",
    "năucitoarea": "năucitor",
    "năucitoarei": "năucitor",
    "năucitoarele": "năucitor",
    "năucitoarelor": "năucitor",
    "năucitori": "năucitor",
    "năucitorii": "năucitor",
    "năucitorilor": "năucitor",
    "năucitorul": "năucitor",
    "năucitorului": "năucitor",
    "naufragiai": "naufragia",
    "naufragiam": "naufragia",
    "naufragiară": "naufragia",
    "naufragiarăm": "naufragia",
    "naufragiarăți": "naufragia",
    "naufragiase": "naufragia",
    "naufragiasem": "naufragia",
    "naufragiaseră": "naufragia",
    "naufragiaserăm": "naufragia",
    "naufragiaserăți": "naufragia",
    "naufragiaseși": "naufragia",
    "naufragiași": "naufragia",
    "naufragiat": "naufragia",
    "naufragiați": "naufragia",
    "naufragiau": "naufragia",
    "naufragiază": "naufragia",
    "naufragie": "naufragia",
    "naufragiem": "naufragia",
    "naufragiez": "naufragia",
    "naufragieze": "naufragia",
    "naufragiezi": "naufragia",
    "naufragiind": "naufragia",
    "naufragiindu": "naufragia",
    "nemainaufragiind": "naufragia",
    "nemainaufragiindu": "naufragia",
    "nenaufragiind": "naufragia",
    "nenaufragiindu": "naufragia",
    "naufragiată": "naufragiat",
    "naufragiate": "naufragiat",
    "naufragiați": "naufragiat",
    "naufragii": "naufragiu",
    "naufragiile": "naufragiu",
    "naufragiilor": "naufragiu",
    "naufragiul": "naufragiu",
    "naufragiului": "naufragiu",
    "naupatia": "naupatie",
    "naupatiei": "naupatie",
    "naupatii": "naupatie",
    "naupatiile": "naupatie",
    "naupatiilor": "naupatie",
    "năutul": "năut",
    "năutului": "năut",
    "nautica": "nautic",
    "nautică": "nautic",
    "nautice": "nautic",
    "nauticei": "nautic",
    "nauticele": "nautic",
    "nauticelor": "nautic",
    "nautici": "nautic",
    "nauticii": "nautic",
    "nauticilor": "nautic",
    "nauticul": "nautic",
    "nauticului": "nautic",
    "nautili": "nautil",
    "nautilii": "nautil",
    "nautililor": "nautil",
    "nautilul": "nautil",
    "nautilului": "nautil",
    "năutie": "năutiu",
    "năutiea": "năutiu",
    "năutii": "năutiu",
    "năutiii": "năutiu",
    "năutiile": "năutiu",
    "năutiilor": "năutiu",
    "năutiul": "năutiu",
    "năutiului": "năutiu",
    "nava": "navă",
    "nave": "navă",
    "navei": "navă",
    "navele": "navă",
    "navelor": "navă",
    "năvădea": "năvădi",
    "năvădeai": "năvădi",
    "năvădeam": "năvădi",
    "năvădească": "năvădi",
    "năvădeați": "năvădi",
    "năvădeau": "năvădi",
    "năvădesc": "năvădi",
    "năvădește": "năvădi",
    "năvădești": "năvădi",
    "năvădii": "năvădi",
    "năvădim": "năvădi",
    "năvădind": "năvădi",
    "năvădindu": "năvădi",
    "năvădiră": "năvădi",
    "năvădirăm": "năvădi",
    "năvădirăți": "năvădi",
    "năvădise": "năvădi",
    "năvădisem": "năvădi",
    "năvădiseră": "năvădi",
    "năvădiserăm": "năvădi",
    "năvădiserăți": "năvădi",
    "năvădiseși": "năvădi",
    "năvădiși": "năvădi",
    "năvădit": "năvădi",
    "năvădiți": "năvădi",
    "nemainăvădind": "năvădi",
    "nemainăvădindu": "năvădi",
    "nenăvădind": "năvădi",
    "nenăvădindu": "năvădi",
    "năvădită": "năvădit",
    "năvădite": "năvădit",
    "năvădiți": "năvădit",
    "nav.": "naval",
    "navala": "naval",
    "navală": "naval",
    "navale": "naval",
    "navalei": "naval",
    "navalele": "naval",
    "navalelor": "naval",
    "navali": "naval",
    "navalii": "naval",
    "navalilor": "naval",
    "navalul": "naval",
    "navalului": "naval",
    "năvala": "năvală",
    "năvale": "năvală",
    "năvalei": "năvală",
    "năvălea": "năvăli",
    "năvăleai": "năvăli",
    "năvăleam": "năvăli",
    "năvălească": "năvăli",
    "năvăleați": "năvăli",
    "năvăleau": "năvăli",
    "năvălesc": "năvăli",
    "năvălește": "năvăli",
    "năvălești": "năvăli",
    "năvălii": "năvăli",
    "năvălim": "năvăli",
    "năvălind": "năvăli",
    "năvălindu": "năvăli",
    "năvăliră": "năvăli",
    "năvălirăm": "năvăli",
    "năvălirăți": "năvăli",
    "năvălise": "năvăli",
    "năvălisem": "năvăli",
    "năvăliseră": "năvăli",
    "năvăliserăm": "năvăli",
    "năvăliserăți": "năvăli",
    "năvăliseși": "năvăli",
    "năvăliși": "năvăli",
    "năvălit": "năvăli",
    "năvăliți": "năvăli",
    "nemainăvălind": "năvăli",
    "nemainăvălindu": "năvăli",
    "nenăvălind": "năvăli",
    "nenăvălindu": "năvăli",
    "năvălită": "năvălit",
    "năvălite": "năvălit",
    "năvăliți": "năvălit",
    "năvălitoarea": "năvălitoare",
    "năvălitoarei": "năvălitoare",
    "năvălitoarele": "năvălitoare",
    "năvălitoarelor": "năvălitoare",
    "năvălitoare": "năvălitor",
    "năvălitoarea": "năvălitor",
    "năvălitoarei": "năvălitor",
    "năvălitoarele": "năvălitor",
    "năvălitoarelor": "năvălitor",
    "năvălitori": "năvălitor",
    "năvălitorii": "năvălitor",
    "năvălitorilor": "năvălitor",
    "năvălitorul": "năvălitor",
    "năvălitorului": "năvălitor",
    "năvalnica": "năvalnic",
    "năvalnică": "năvalnic",
    "năvalnice": "năvalnic",
    "năvalnicei": "năvalnic",
    "năvalnicele": "năvalnic",
    "năvalnicelor": "năvalnic",
    "năvalnici": "năvalnic",
    "năvalnicii": "năvalnic",
    "năvalnicilor": "năvalnic",
    "năvalnicul": "năvalnic",
    "năvalnicului": "năvalnic",
    "naveta": "navetă",
    "navete": "navetă",
    "navetei": "navetă",
    "navetele": "navetă",
    "navetelor": "navetă",
    "navetista": "navetist",
    "navetistă": "navetist",
    "navetiste": "navetist",
    "navetistei": "navetist",
    "navetistele": "navetist",
    "navetistelor": "navetist",
    "navetiști": "navetist",
    "navetiștii": "navetist",
    "navetiștilor": "navetist",
    "navetistul": "navetist",
    "navetistului": "navetist",
    "navigă": "naviga",
    "navigai": "naviga",
    "navigam": "naviga",
    "navigăm": "naviga",
    "navigând": "naviga",
    "navigându": "naviga",
    "navigară": "naviga",
    "navigarăm": "naviga",
    "navigarăți": "naviga",
    "navigase": "naviga",
    "navigasem": "naviga",
    "navigaseră": "naviga",
    "navigaserăm": "naviga",
    "navigaserăți": "naviga",
    "navigaseși": "naviga",
    "navigași": "naviga",
    "navigat": "naviga",
    "navigați": "naviga",
    "navigau": "naviga",
    "navighează": "naviga",
    "navighez": "naviga",
    "navigheze": "naviga",
    "navighezi": "naviga",
    "nemainavigând": "naviga",
    "nemainavigându": "naviga",
    "nenavigând": "naviga",
    "nenavigându": "naviga",
    "navigabila": "navigabil",
    "navigabilă": "navigabil",
    "navigabile": "navigabil",
    "navigabilei": "navigabil",
    "navigabilele": "navigabil",
    "navigabilelor": "navigabil",
    "navigabili": "navigabil",
    "navigabilii": "navigabil",
    "navigabililor": "navigabil",
    "navigabilul": "navigabil",
    "navigabilului": "navigabil",
    "naviganta": "navigant",
    "navigantă": "navigant",
    "navigante": "navigant",
    "navigantei": "navigant",
    "navigantele": "navigant",
    "navigantelor": "navigant",
    "naviganți": "navigant",
    "naviganții": "navigant",
    "naviganților": "navigant",
    "navigantul": "navigant",
    "navigantului": "navigant",
    "navigată": "navigat",
    "navigate": "navigat",
    "navigați": "navigat",
    "navigația": "navigație",
    "navigației": "navigație",
    "navigații": "navigație",
    "navigațiile": "navigație",
    "navigațiilor": "navigație",
    "navigatoarea": "navigatoare",
    "navigatoarei": "navigatoare",
    "navigatoarele": "navigatoare",
    "navigatoarelor": "navigatoare",
    "navigatori": "navigator",
    "navigatorii": "navigator",
    "navigatorilor": "navigator",
    "navigatorul": "navigator",
    "navigatorului": "navigator",
    "navigrafe": "navigraf",
    "navigrafele": "navigraf",
    "navigrafelor": "navigraf",
    "navigraful": "navigraf",
    "navigrafului": "navigraf",
    "navlosea": "navlosi",
    "navloseai": "navlosi",
    "navloseam": "navlosi",
    "navlosească": "navlosi",
    "navloseați": "navlosi",
    "navloseau": "navlosi",
    "navlosesc": "navlosi",
    "navlosește": "navlosi",
    "navlosești": "navlosi",
    "navlosii": "navlosi",
    "navlosim": "navlosi",
    "navlosind": "navlosi",
    "navlosindu": "navlosi",
    "navlosiră": "navlosi",
    "navlosirăm": "navlosi",
    "navlosirăți": "navlosi",
    "navlosise": "navlosi",
    "navlosisem": "navlosi",
    "navlosiseră": "navlosi",
    "navlosiserăm": "navlosi",
    "navlosiserăți": "navlosi",
    "navlosiseși": "navlosi",
    "navlosiși": "navlosi",
    "navlosit": "navlosi",
    "navlosiți": "navlosi",
    "nemainavlosind": "navlosi",
    "nemainavlosindu": "navlosi",
    "nenavlosind": "navlosi",
    "nenavlosindu": "navlosi",
    "navlosită": "navlosit",
    "navlosite": "navlosit",
    "navlosiți": "navlosit",
    "năvoade": "năvod",
    "năvoadele": "năvod",
    "năvoadelor": "năvod",
    "năvodul": "năvod",
    "năvodului": "năvod",
    "năvodarul": "năvodar",
    "năvodarului": "năvodar",
    "navomodele": "navomodel",
    "navomodelele": "navomodel",
    "navomodelelor": "navomodel",
    "navomodelul": "navomodel",
    "navomodelului": "navomodel",
    "navomodelisme": "navomodelism",
    "navomodelismele": "navomodelism",
    "navomodelismelor": "navomodelism",
    "navomodelismul": "navomodelism",
    "navomodelismului": "navomodelism",
    "navomodeliști": "navomodelist",
    "navomodeliștii": "navomodelist",
    "navomodeliștilor": "navomodelist",
    "navomodelistul": "navomodelist",
    "navomodelistului": "navomodelist",
    "navomodelista": "navomodelistă",
    "navomodeliste": "navomodelistă",
    "navomodelistei": "navomodelistă",
    "navomodelistele": "navomodelistă",
    "navomodelistelor": "navomodelistă",
    "nazala": "nazal",
    "nazală": "nazal",
    "nazale": "nazal",
    "nazalei": "nazal",
    "nazalele": "nazal",
    "nazalelor": "nazal",
    "nazali": "nazal",
    "nazalii": "nazal",
    "nazalilor": "nazal",
    "nazalul": "nazal",
    "nazalului": "nazal",
    "nazalitatea": "nazalitate",
    "nazalități": "nazalitate",
    "nazalității": "nazalitate",
    "nazaliză": "nazaliza",
    "nazalizai": "nazaliza",
    "nazalizam": "nazaliza",
    "nazalizăm": "nazaliza",
    "nazalizând": "nazaliza",
    "nazalizându": "nazaliza",
    "nazalizară": "nazaliza",
    "nazalizarăm": "nazaliza",
    "nazalizarăți": "nazaliza",
    "nazalizase": "nazaliza",
    "nazalizasem": "nazaliza",
    "nazalizaseră": "nazaliza",
    "nazalizaserăm": "nazaliza",
    "nazalizaserăți": "nazaliza",
    "nazalizaseși": "nazaliza",
    "nazalizași": "nazaliza",
    "nazalizat": "nazaliza",
    "nazalizați": "nazaliza",
    "nazalizau": "nazaliza",
    "nazalizează": "nazaliza",
    "nazalizez": "nazaliza",
    "nazalizeze": "nazaliza",
    "nazalizezi": "nazaliza",
    "nemainazalizând": "nazaliza",
    "nemainazalizându": "nazaliza",
    "nenazalizând": "nazaliza",
    "nenazalizându": "nazaliza",
    "nazalizată": "nazalizat",
    "nazalizate": "nazalizat",
    "nazalizați": "nazalizat",
    "năzară": "năzări",
    "năzare": "năzări",
    "năzărea": "năzări",
    "năzărească": "năzări",
    "năzăreau": "năzări",
    "năzăresc": "năzări",
    "năzărește": "năzări",
    "năzărindu": "năzări",
    "năzăriră": "năzări",
    "năzărise": "năzări",
    "năzăriseră": "năzări",
    "nemainăzărind": "năzări",
    "nemainăzărindu": "năzări",
    "nenăzărind": "năzări",
    "nenăzărindu": "năzări",
    "nazarineana": "nazarinean",
    "nazarineană": "nazarinean",
    "nazarineanul": "nazarinean",
    "nazarineanului": "nazarinean",
    "nazarinene": "nazarinean",
    "nazarinenei": "nazarinean",
    "nazarinenele": "nazarinean",
    "nazarinenelor": "nazarinean",
    "nazarineni": "nazarinean",
    "nazarinenii": "nazarinean",
    "nazarinenilor": "nazarinean",
    "năzbâtia": "năzbâtie",
    "năzbâtiei": "năzbâtie",
    "năzbâtii": "năzbâtie",
    "năzbâtiile": "năzbâtie",
    "năzbâtiilor": "năzbâtie",
    "năzdrăvana": "năzdrăvan",
    "năzdrăvană": "năzdrăvan",
    "năzdrăvane": "năzdrăvan",
    "năzdrăvanei": "năzdrăvan",
    "năzdrăvanele": "năzdrăvan",
    "năzdrăvanelor": "năzdrăvan",
    "năzdrăvani": "năzdrăvan",
    "năzdrăvanii": "năzdrăvan",
    "năzdrăvanilor": "năzdrăvan",
    "năzdrăvanul": "năzdrăvan",
    "năzdrăvanului": "năzdrăvan",
    "năzdrăvănia": "năzdrăvănie",
    "năzdrăvăniei": "năzdrăvănie",
    "năzdrăvănii": "năzdrăvănie",
    "năzdrăvăniile": "năzdrăvănie",
    "năzdrăvăniilor": "năzdrăvănie",
    "nazismul": "nazism",
    "nazismului": "nazism",
    "nazista": "nazist",
    "nazistă": "nazist",
    "naziste": "nazist",
    "nazistei": "nazist",
    "nazistele": "nazist",
    "nazistelor": "nazist",
    "naziști": "nazist",
    "naziștii": "nazist",
    "naziștilor": "nazist",
    "nazistul": "nazist",
    "nazistului": "nazist",
    "nazofaringiana": "nazofaringian",
    "nazofaringiană": "nazofaringian",
    "nazofaringianul": "nazofaringian",
    "nazofaringianului": "nazofaringian",
    "nazofaringiene": "nazofaringian",
    "nazofaringienei": "nazofaringian",
    "nazofaringienele": "nazofaringian",
    "nazofaringienelor": "nazofaringian",
    "nazofaringieni": "nazofaringian",
    "nazofaringienii": "nazofaringian",
    "nazofaringienilor": "nazofaringian",
    "năzuia": "năzui",
    "năzuiai": "năzui",
    "năzuiam": "năzui",
    "năzuiască": "năzui",
    "năzuiați": "năzui",
    "năzuiau": "năzui",
    "năzuiesc": "năzui",
    "năzuiește": "năzui",
    "năzuiești": "năzui",
    "năzuii": "năzui",
    "năzuim": "năzui",
    "năzuind": "năzui",
    "năzuindu": "năzui",
    "năzuiră": "năzui",
    "năzuirăm": "năzui",
    "năzuirăți": "năzui",
    "năzuise": "năzui",
    "năzuisem": "năzui",
    "năzuiseră": "năzui",
    "năzuiserăm": "năzui",
    "năzuiserăți": "năzui",
    "năzuiseși": "năzui",
    "năzuiși": "năzui",
    "năzuit": "năzui",
    "năzuiți": "năzui",
    "nemainăzuind": "năzui",
    "nemainăzuindu": "năzui",
    "nenăzuind": "năzui",
    "nenăzuindu": "năzui",
    "năzuința": "năzuință",
    "năzuințe": "năzuință",
    "năzuinței": "năzuință",
    "năzuințele": "năzuință",
    "năzuințelor": "năzuință",
    "năzuită": "năzuit",
    "năzuite": "năzuit",
    "năzuiți": "năzuit",
    "nazurile": "nazuri",
    "nazurilor": "nazuri",
    "năzuroasa": "năzuros",
    "năzuroasă": "năzuros",
    "năzuroase": "năzuros",
    "năzuroasei": "năzuros",
    "năzuroasele": "năzuros",
    "năzuroaselor": "năzuros",
    "năzuroși": "năzuros",
    "năzuroșii": "năzuros",
    "năzuroșilor": "năzuros",
    "năzurosul": "năzuros",
    "năzurosului": "năzuros",
    "neale": "nea",
    "nealei": "nea",
    "neaua": "nea",
    "neabandonata": "neabandonat",
    "neabandonată": "neabandonat",
    "neabandonate": "neabandonat",
    "neabandonatei": "neabandonat",
    "neabandonatele": "neabandonat",
    "neabandonatelor": "neabandonat",
    "neabandonați": "neabandonat",
    "neabandonații": "neabandonat",
    "neabandonaților": "neabandonat",
    "neabandonatul": "neabandonat",
    "neabandonatului": "neabandonat",
    "neabătuta": "neabătut",
    "neabătută": "neabătut",
    "neabătute": "neabătut",
    "neabătutei": "neabătut",
    "neabătutele": "neabătut",
    "neabătutelor": "neabătut",
    "neabătuți": "neabătut",
    "neabătuții": "neabătut",
    "neabătuților": "neabătut",
    "neabătutul": "neabătut",
    "neabătutului": "neabătut",
    "neabdicata": "neabdicat",
    "neabdicată": "neabdicat",
    "neabdicate": "neabdicat",
    "neabdicatei": "neabdicat",
    "neabdicatele": "neabdicat",
    "neabdicatelor": "neabdicat",
    "neabdicați": "neabdicat",
    "neabdicații": "neabdicat",
    "neabdicaților": "neabdicat",
    "neabdicatul": "neabdicat",
    "neabdicatului": "neabdicat",
    "neabilitata": "neabilitat",
    "neabilitată": "neabilitat",
    "neabilitate": "neabilitat",
    "neabilitatei": "neabilitat",
    "neabilitatele": "neabilitat",
    "neabilitatelor": "neabilitat",
    "neabilitați": "neabilitat",
    "neabilitații": "neabilitat",
    "neabilitaților": "neabilitat",
    "neabilitatul": "neabilitat",
    "neabilitatului": "neabilitat",
    "neabolita": "neabolit",
    "neabolită": "neabolit",
    "neabolite": "neabolit",
    "neabolitei": "neabolit",
    "neabolitele": "neabolit",
    "neabolitelor": "neabolit",
    "neaboliți": "neabolit",
    "neaboliții": "neabolit",
    "neaboliților": "neabolit",
    "neabolitul": "neabolit",
    "neabolitului": "neabolit",
    "neabonata": "neabonat",
    "neabonată": "neabonat",
    "neabonate": "neabonat",
    "neabonatei": "neabonat",
    "neabonatele": "neabonat",
    "neabonatelor": "neabonat",
    "neabonați": "neabonat",
    "neabonații": "neabonat",
    "neabonaților": "neabonat",
    "neabonatul": "neabonat",
    "neabonatului": "neabonat",
    "neabordata": "neabordat",
    "neabordată": "neabordat",
    "neabordate": "neabordat",
    "neabordatei": "neabordat",
    "neabordatele": "neabordat",
    "neabordatelor": "neabordat",
    "neabordați": "neabordat",
    "neabordații": "neabordat",
    "neabordaților": "neabordat",
    "neabordatul": "neabordat",
    "neabordatului": "neabordat",
    "neabreviata": "neabreviat",
    "neabreviată": "neabreviat",
    "neabreviate": "neabreviat",
    "neabreviatei": "neabreviat",
    "neabreviatele": "neabreviat",
    "neabreviatelor": "neabreviat",
    "neabreviați": "neabreviat",
    "neabreviații": "neabreviat",
    "neabreviaților": "neabreviat",
    "neabreviatul": "neabreviat",
    "neabreviatului": "neabreviat",
    "neabrogata": "neabrogat",
    "neabrogată": "neabrogat",
    "neabrogate": "neabrogat",
    "neabrogatei": "neabrogat",
    "neabrogatele": "neabrogat",
    "neabrogatelor": "neabrogat",
    "neabrogați": "neabrogat",
    "neabrogații": "neabrogat",
    "neabrogaților": "neabrogat",
    "neabrogatul": "neabrogat",
    "neabrogatului": "neabrogat",
    "neabrutizata": "neabrutizat",
    "neabrutizată": "neabrutizat",
    "neabrutizate": "neabrutizat",
    "neabrutizatei": "neabrutizat",
    "neabrutizatele": "neabrutizat",
    "neabrutizatelor": "neabrutizat",
    "neabrutizați": "neabrutizat",
    "neabrutizații": "neabrutizat",
    "neabrutizaților": "neabrutizat",
    "neabrutizatul": "neabrutizat",
    "neabrutizatului": "neabrutizat",
    "neabsolutizata": "neabsolutizat",
    "neabsolutizată": "neabsolutizat",
    "neabsolutizate": "neabsolutizat",
    "neabsolutizatei": "neabsolutizat",
    "neabsolutizatele": "neabsolutizat",
    "neabsolutizatelor": "neabsolutizat",
    "neabsolutizați": "neabsolutizat",
    "neabsolutizații": "neabsolutizat",
    "neabsolutizaților": "neabsolutizat",
    "neabsolutizatul": "neabsolutizat",
    "neabsolutizatului": "neabsolutizat",
    "neabsolvita": "neabsolvit",
    "neabsolvită": "neabsolvit",
    "neabsolvite": "neabsolvit",
    "neabsolvitei": "neabsolvit",
    "neabsolvitele": "neabsolvit",
    "neabsolvitelor": "neabsolvit",
    "neabsolviți": "neabsolvit",
    "neabsolviții": "neabsolvit",
    "neabsolviților": "neabsolvit",
    "neabsolvitul": "neabsolvit",
    "neabsolvitului": "neabsolvit",
    "neabsorbita": "neabsorbit",
    "neabsorbită": "neabsorbit",
    "neabsorbite": "neabsorbit",
    "neabsorbitei": "neabsorbit",
    "neabsorbitele": "neabsorbit",
    "neabsorbitelor": "neabsorbit",
    "neabsorbiți": "neabsorbit",
    "neabsorbiții": "neabsorbit",
    "neabsorbiților": "neabsorbit",
    "neabsorbitul": "neabsorbit",
    "neabsorbitului": "neabsorbit",
    "neabstractizata": "neabstractizat",
    "neabstractizată": "neabstractizat",
    "neabstractizate": "neabstractizat",
    "neabstractizatei": "neabstractizat",
    "neabstractizatele": "neabstractizat",
    "neabstractizatelor": "neabstractizat",
    "neabstractizați": "neabstractizat",
    "neabstractizații": "neabstractizat",
    "neabstractizaților": "neabstractizat",
    "neabstractizatul": "neabstractizat",
    "neabstractizatului": "neabstractizat",
    "neabstrasa": "neabstras",
    "neabstrasă": "neabstras",
    "neabstrase": "neabstras",
    "neabstrasei": "neabstras",
    "neabstrasele": "neabstras",
    "neabstraselor": "neabstras",
    "neabstrași": "neabstras",
    "neabstrașii": "neabstras",
    "neabstrașilor": "neabstras",
    "neabstrasul": "neabstras",
    "neabstrasului": "neabstras",
    "neabținuta": "neabținut",
    "neabținută": "neabținut",
    "neabținute": "neabținut",
    "neabținutei": "neabținut",
    "neabținutele": "neabținut",
    "neabținutelor": "neabținut",
    "neabținuți": "neabținut",
    "neabținuții": "neabținut",
    "neabținuților": "neabținut",
    "neabținutul": "neabținut",
    "neabținutului": "neabținut",
    "neabundată": "neabundat",
    "neabundate": "neabundat",
    "neabundați": "neabundat",
    "neabuzată": "neabuzat",
    "neabuzate": "neabuzat",
    "neabuzați": "neabuzat",
    "neacaparata": "neacaparat",
    "neacaparată": "neacaparat",
    "neacaparate": "neacaparat",
    "neacaparatei": "neacaparat",
    "neacaparatele": "neacaparat",
    "neacaparatelor": "neacaparat",
    "neacaparați": "neacaparat",
    "neacaparații": "neacaparat",
    "neacaparaților": "neacaparat",
    "neacaparatul": "neacaparat",
    "neacaparatului": "neacaparat",
    "neaccedată": "neaccedat",
    "neaccedate": "neaccedat",
    "neaccedați": "neaccedat",
    "neaccelerata": "neaccelerat",
    "neaccelerată": "neaccelerat",
    "neaccelerate": "neaccelerat",
    "neacceleratei": "neaccelerat",
    "neacceleratele": "neaccelerat",
    "neacceleratelor": "neaccelerat",
    "neaccelerați": "neaccelerat",
    "neaccelerații": "neaccelerat",
    "neacceleraților": "neaccelerat",
    "neacceleratul": "neaccelerat",
    "neacceleratului": "neaccelerat",
    "neacc.": "neaccentuat",
    "neaccentuata": "neaccentuat",
    "neaccentuată": "neaccentuat",
    "neaccentuate": "neaccentuat",
    "neaccentuatei": "neaccentuat",
    "neaccentuatele": "neaccentuat",
    "neaccentuatelor": "neaccentuat",
    "neaccentuați": "neaccentuat",
    "neaccentuații": "neaccentuat",
    "neaccentuaților": "neaccentuat",
    "neaccentuatul": "neaccentuat",
    "neaccentuatului": "neaccentuat",
    "neacceptata": "neacceptat",
    "neacceptată": "neacceptat",
    "neacceptate": "neacceptat",
    "neacceptatei": "neacceptat",
    "neacceptatele": "neacceptat",
    "neacceptatelor": "neacceptat",
    "neacceptați": "neacceptat",
    "neacceptații": "neacceptat",
    "neacceptaților": "neacceptat",
    "neacceptatul": "neacceptat",
    "neacceptatului": "neacceptat",
    "neaccidentata": "neaccidentat",
    "neaccidentată": "neaccidentat",
    "neaccidentate": "neaccidentat",
    "neaccidentatei": "neaccidentat",
    "neaccidentatele": "neaccidentat",
    "neaccidentatelor": "neaccidentat",
    "neaccidentați": "neaccidentat",
    "neaccidentații": "neaccidentat",
    "neaccidentaților": "neaccidentat",
    "neaccidentatul": "neaccidentat",
    "neaccidentatului": "neaccidentat",
    "neachitata": "neachitat",
    "neachitată": "neachitat",
    "neachitate": "neachitat",
    "neachitatei": "neachitat",
    "neachitatele": "neachitat",
    "neachitatelor": "neachitat",
    "neachitați": "neachitat",
    "neachitații": "neachitat",
    "neachitaților": "neachitat",
    "neachitatul": "neachitat",
    "neachitatului": "neachitat",
    "neachiziționata": "neachiziționat",
    "neachiziționată": "neachiziționat",
    "neachiziționate": "neachiziționat",
    "neachiziționatei": "neachiziționat",
    "neachiziționatele": "neachiziționat",
    "neachiziționatelor": "neachiziționat",
    "neachiziționați": "neachiziționat",
    "neachiziționații": "neachiziționat",
    "neachiziționaților": "neachiziționat",
    "neachiziționatul": "neachiziționat",
    "neachiziționatului": "neachiziționat",
    "neacidulata": "neacidulat",
    "neacidulată": "neacidulat",
    "neacidulate": "neacidulat",
    "neacidulatei": "neacidulat",
    "neacidulatele": "neacidulat",
    "neacidulatelor": "neacidulat",
    "neacidulați": "neacidulat",
    "neacidulații": "neacidulat",
    "neacidulaților": "neacidulat",
    "neacidulatul": "neacidulat",
    "neacidulatului": "neacidulat",
    "neaciuata": "neaciuat",
    "neaciuată": "neaciuat",
    "neaciuate": "neaciuat",
    "neaciuatei": "neaciuat",
    "neaciuatele": "neaciuat",
    "neaciuatelor": "neaciuat",
    "neaciuați": "neaciuat",
    "neaciuații": "neaciuat",
    "neaciuaților": "neaciuat",
    "neaciuatul": "neaciuat",
    "neaciuatului": "neaciuat",
    "neaclamata": "neaclamat",
    "neaclamată": "neaclamat",
    "neaclamate": "neaclamat",
    "neaclamatei": "neaclamat",
    "neaclamatele": "neaclamat",
    "neaclamatelor": "neaclamat",
    "neaclamați": "neaclamat",
    "neaclamații": "neaclamat",
    "neaclamaților": "neaclamat",
    "neaclamatul": "neaclamat",
    "neaclamatului": "neaclamat",
    "neaclimatizata": "neaclimatizat",
    "neaclimatizată": "neaclimatizat",
    "neaclimatizate": "neaclimatizat",
    "neaclimatizatei": "neaclimatizat",
    "neaclimatizatele": "neaclimatizat",
    "neaclimatizatelor": "neaclimatizat",
    "neaclimatizați": "neaclimatizat",
    "neaclimatizații": "neaclimatizat",
    "neaclimatizaților": "neaclimatizat",
    "neaclimatizatul": "neaclimatizat",
    "neaclimatizatului": "neaclimatizat",
    "neacomodata": "neacomodat",
    "neacomodată": "neacomodat",
    "neacomodate": "neacomodat",
    "neacomodatei": "neacomodat",
    "neacomodatele": "neacomodat",
    "neacomodatelor": "neacomodat",
    "neacomodați": "neacomodat",
    "neacomodații": "neacomodat",
    "neacomodaților": "neacomodat",
    "neacomodatul": "neacomodat",
    "neacomodatului": "neacomodat",
    "neacompaniata": "neacompaniat",
    "neacompaniată": "neacompaniat",
    "neacompaniate": "neacompaniat",
    "neacompaniatei": "neacompaniat",
    "neacompaniatele": "neacompaniat",
    "neacompaniatelor": "neacompaniat",
    "neacompaniați": "neacompaniat",
    "neacompaniații": "neacompaniat",
    "neacompaniaților": "neacompaniat",
    "neacompaniatul": "neacompaniat",
    "neacompaniatului": "neacompaniat",
    "neacoperita": "neacoperit",
    "neacoperită": "neacoperit",
    "neacoperite": "neacoperit",
    "neacoperitei": "neacoperit",
    "neacoperitele": "neacoperit",
    "neacoperitelor": "neacoperit",
    "neacoperiți": "neacoperit",
    "neacoperiții": "neacoperit",
    "neacoperiților": "neacoperit",
    "neacoperitul": "neacoperit",
    "neacoperitului": "neacoperit",
    "neacordarea": "neacordare",
    "neacordări": "neacordare",
    "neacordării": "neacordare",
    "neacordările": "neacordare",
    "neacordărilor": "neacordare",
    "neacordata": "neacordat",
    "neacordată": "neacordat",
    "neacordate": "neacordat",
    "neacordatei": "neacordat",
    "neacordatele": "neacordat",
    "neacordatelor": "neacordat",
    "neacordați": "neacordat",
    "neacordații": "neacordat",
    "neacordaților": "neacordat",
    "neacordatul": "neacordat",
    "neacordatului": "neacordat",
    "neacostata": "neacostat",
    "neacostată": "neacostat",
    "neacostate": "neacostat",
    "neacostatei": "neacostat",
    "neacostatele": "neacostat",
    "neacostatelor": "neacostat",
    "neacostați": "neacostat",
    "neacostații": "neacostat",
    "neacostaților": "neacostat",
    "neacostatul": "neacostat",
    "neacostatului": "neacostat",
    "neacreditata": "neacreditat",
    "neacreditată": "neacreditat",
    "neacreditate": "neacreditat",
    "neacreditatei": "neacreditat",
    "neacreditatele": "neacreditat",
    "neacreditatelor": "neacreditat",
    "neacreditați": "neacreditat",
    "neacreditații": "neacreditat",
    "neacreditaților": "neacreditat",
    "neacreditatul": "neacreditat",
    "neacreditatului": "neacreditat",
    "neacrita": "neacrit",
    "neacrită": "neacrit",
    "neacrite": "neacrit",
    "neacritei": "neacrit",
    "neacritele": "neacrit",
    "neacritelor": "neacrit",
    "neacriți": "neacrit",
    "neacriții": "neacrit",
    "neacriților": "neacrit",
    "neacrittul": "neacrit",
    "neacritului": "neacrit",
    "neacționata": "neacționat",
    "neacționată": "neacționat",
    "neacționate": "neacționat",
    "neacționatei": "neacționat",
    "neacționatele": "neacționat",
    "neacționatelor": "neacționat",
    "neacționați": "neacționat",
    "neacționații": "neacționat",
    "neacționaților": "neacționat",
    "neacționatul": "neacționat",
    "neacționatului": "neacționat",
    "neactivata": "neactivat",
    "neactivată": "neactivat",
    "neactivate": "neactivat",
    "neactivatei": "neactivat",
    "neactivatele": "neactivat",
    "neactivatelor": "neactivat",
    "neactivați": "neactivat",
    "neactivații": "neactivat",
    "neactivaților": "neactivat",
    "neactivatul": "neactivat",
    "neactivatului": "neactivat",
    "neactivizata": "neactivizat",
    "neactivizată": "neactivizat",
    "neactivizate": "neactivizat",
    "neactivizatei": "neactivizat",
    "neactivizatele": "neactivizat",
    "neactivizatelor": "neactivizat",
    "neactivizați": "neactivizat",
    "neactivizații": "neactivizat",
    "neactivizaților": "neactivizat",
    "neactivizatul": "neactivizat",
    "neactivizatului": "neactivizat",
    "neactualizata": "neactualizat",
    "neactualizată": "neactualizat",
    "neactualizate": "neactualizat",
    "neactualizatei": "neactualizat",
    "neactualizatele": "neactualizat",
    "neactualizatelor": "neactualizat",
    "neactualizați": "neactualizat",
    "neactualizații": "neactualizat",
    "neactualizaților": "neactualizat",
    "neactualizatul": "neactualizat",
    "neactualizatului": "neactualizat",
    "neacumulata": "neacumulat",
    "neacumulată": "neacumulat",
    "neacumulate": "neacumulat",
    "neacumulatei": "neacumulat",
    "neacumulatele": "neacumulat",
    "neacumulatelor": "neacumulat",
    "neacumulați": "neacumulat",
    "neacumulații": "neacumulat",
    "neacumulaților": "neacumulat",
    "neacumulatul": "neacumulat",
    "neacumulatului": "neacumulat",
    "neacuzata": "neacuzat",
    "neacuzată": "neacuzat",
    "neacuzate": "neacuzat",
    "neacuzatei": "neacuzat",
    "neacuzatele": "neacuzat",
    "neacuzatelor": "neacuzat",
    "neacuzați": "neacuzat",
    "neacuzații": "neacuzat",
    "neacuzaților": "neacuzat",
    "neacuzatul": "neacuzat",
    "neacuzatului": "neacuzat",
    "neadâncita": "neadâncit",
    "neadâncită": "neadâncit",
    "neadâncite": "neadâncit",
    "neadâncitei": "neadâncit",
    "neadâncitele": "neadâncit",
    "neadâncitelor": "neadâncit",
    "neadânciți": "neadâncit",
    "neadânciții": "neadâncit",
    "neadânciților": "neadâncit",
    "neadâncitul": "neadâncit",
    "neadâncitului": "neadâncit",
    "neadăpata": "neadăpat",
    "neadăpată": "neadăpat",
    "neadăpate": "neadăpat",
    "neadăpatei": "neadăpat",
    "neadăpatele": "neadăpat",
    "neadăpatelor": "neadăpat",
    "neadăpați": "neadăpat",
    "neadăpații": "neadăpat",
    "neadăpaților": "neadăpat",
    "neadăpatul": "neadăpat",
    "neadăpatului": "neadăpat",
    "neadăpostita": "neadăpostit",
    "neadăpostită": "neadăpostit",
    "neadăpostite": "neadăpostit",
    "neadăpostitei": "neadăpostit",
    "neadăpostitele": "neadăpostit",
    "neadăpostitelor": "neadăpostit",
    "neadăpostiți": "neadăpostit",
    "neadăpostiții": "neadăpostit",
    "neadăpostiților": "neadăpostit",
    "neadăpostitul": "neadăpostit",
    "neadăpostitului": "neadăpostit",
    "neadaptata": "neadaptat",
    "neadaptată": "neadaptat",
    "neadaptate": "neadaptat",
    "neadaptatei": "neadaptat",
    "neadaptatele": "neadaptat",
    "neadaptatelor": "neadaptat",
    "neadaptați": "neadaptat",
    "neadaptații": "neadaptat",
    "neadaptaților": "neadaptat",
    "neadaptatul": "neadaptat",
    "neadaptatului": "neadaptat",
    "neadăugata": "neadăugat",
    "neadăugată": "neadăugat",
    "neadăugate": "neadăugat",
    "neadăugatei": "neadăugat",
    "neadăugatele": "neadăugat",
    "neadăugatelor": "neadăugat",
    "neadăugați": "neadăugat",
    "neadăugații": "neadăugat",
    "neadăugaților": "neadăugat",
    "neadăugatul": "neadăugat",
    "neadăugatului": "neadăugat",
    "neademenita": "neademenit",
    "neademenită": "neademenit",
    "neademenite": "neademenit",
    "neademenitei": "neademenit",
    "neademenitele": "neademenit",
    "neademenitelor": "neademenit",
    "neademeniți": "neademenit",
    "neademeniții": "neademenit",
    "neademeniților": "neademenit",
    "neademenitul": "neademenit",
    "neademenitului": "neademenit",
    "neaderata": "neaderat",
    "neaderată": "neaderat",
    "neaderate": "neaderat",
    "neaderatei": "neaderat",
    "neaderatele": "neaderat",
    "neaderatelor": "neaderat",
    "neaderați": "neaderat",
    "neaderații": "neaderat",
    "neaderaților": "neaderat",
    "neaderatul": "neaderat",
    "neaderatului": "neaderat",
    "neadevărul": "neadevăr",
    "neadevărului": "neadevăr",
    "neadevăruri": "neadevăr",
    "neadevărurile": "neadevăr",
    "neadevărurilor": "neadevăr",
    "neadevărata": "neadevărat",
    "neadevărată": "neadevărat",
    "neadevărate": "neadevărat",
    "neadevăratei": "neadevărat",
    "neadevăratele": "neadevărat",
    "neadevăratelor": "neadevărat",
    "neadevărați": "neadevărat",
    "neadevărații": "neadevărat",
    "neadevăraților": "neadevărat",
    "neadevăratul": "neadevărat",
    "neadevăratului": "neadevărat",
    "neadeverita": "neadeverit",
    "neadeverită": "neadeverit",
    "neadeverite": "neadeverit",
    "neadeveritei": "neadeverit",
    "neadeveritele": "neadeverit",
    "neadeveritelor": "neadeverit",
    "neadeveriți": "neadeverit",
    "neadeveriții": "neadeverit",
    "neadeveriților": "neadeverit",
    "neadeveritul": "neadeverit",
    "neadeveritului": "neadeverit",
    "neadiată": "neadiat",
    "neadiate": "neadiat",
    "neadiați": "neadiat",
    "neadjudecata": "neadjudecat",
    "neadjudecată": "neadjudecat",
    "neadjudecate": "neadjudecat",
    "neadjudecatei": "neadjudecat",
    "neadjudecatele": "neadjudecat",
    "neadjudecatelor": "neadjudecat",
    "neadjudecați": "neadjudecat",
    "neadjudecații": "neadjudecat",
    "neadjudecaților": "neadjudecat",
    "neadjudecatul": "neadjudecat",
    "neadjudecatului": "neadjudecat",
    "neadministrata": "neadministrat",
    "neadministrată": "neadministrat",
    "neadministrate": "neadministrat",
    "neadministratei": "neadministrat",
    "neadministratele": "neadministrat",
    "neadministratelor": "neadministrat",
    "neadministrați": "neadministrat",
    "neadministrații": "neadministrat",
    "neadministraților": "neadministrat",
    "neadministratul": "neadministrat",
    "neadministratului": "neadministrat",
    "neadmirata": "neadmirat",
    "neadmirată": "neadmirat",
    "neadmirate": "neadmirat",
    "neadmiratei": "neadmirat",
    "neadmiratele": "neadmirat",
    "neadmiratelor": "neadmirat",
    "neadmirați": "neadmirat",
    "neadmirații": "neadmirat",
    "neadmiraților": "neadmirat",
    "neadmiratul": "neadmirat",
    "neadmiratului": "neadmirat",
    "neadmisa": "neadmis",
    "neadmisă": "neadmis",
    "neadmise": "neadmis",
    "neadmisei": "neadmis",
    "neadmisele": "neadmis",
    "neadmiselor": "neadmis",
    "neadmiși": "neadmis",
    "neadmișii": "neadmis",
    "neadmișilor": "neadmis",
    "neadmisul": "neadmis",
    "neadmisului": "neadmis",
    "neadmonestata": "neadmonestat",
    "neadmonestată": "neadmonestat",
    "neadmonestate": "neadmonestat",
    "neadmonestatei": "neadmonestat",
    "neadmonestatele": "neadmonestat",
    "neadmonestatelor": "neadmonestat",
    "neadmonestați": "neadmonestat",
    "neadmonestații": "neadmonestat",
    "neadmonestaților": "neadmonestat",
    "neadmonestatul": "neadmonestat",
    "neadmonestatului": "neadmonestat",
    "neadnotata": "neadnotat",
    "neadnotată": "neadnotat",
    "neadnotate": "neadnotat",
    "neadnotatei": "neadnotat",
    "neadnotatele": "neadnotat",
    "neadnotatelor": "neadnotat",
    "neadnotați": "neadnotat",
    "neadnotații": "neadnotat",
    "neadnotaților": "neadnotat",
    "neadnotatul": "neadnotat",
    "neadnotatului": "neadnotat",
    "neadoptata": "neadoptat",
    "neadoptată": "neadoptat",
    "neadoptate": "neadoptat",
    "neadoptatei": "neadoptat",
    "neadoptatele": "neadoptat",
    "neadoptatelor": "neadoptat",
    "neadoptați": "neadoptat",
    "neadoptații": "neadoptat",
    "neadoptaților": "neadoptat",
    "neadoptatul": "neadoptat",
    "neadoptatului": "neadoptat",
    "neadorata": "neadorat",
    "neadorată": "neadorat",
    "neadorate": "neadorat",
    "neadoratei": "neadorat",
    "neadoratele": "neadorat",
    "neadoratelor": "neadorat",
    "neadorați": "neadorat",
    "neadorații": "neadorat",
    "neadoraților": "neadorat",
    "neadoratul": "neadorat",
    "neadoratului": "neadorat",
    "neadormirea": "neadormire",
    "neadormiri": "neadormire",
    "neadormirii": "neadormire",
    "neadormirile": "neadormire",
    "neadormirilor": "neadormire",
    "neadormita": "neadormit",
    "neadormită": "neadormit",
    "neadormite": "neadormit",
    "neadormitei": "neadormit",
    "neadormitele": "neadormit",
    "neadormitelor": "neadormit",
    "neadormiți": "neadormit",
    "neadormiții": "neadormit",
    "neadormiților": "neadormit",
    "neadormitul": "neadormit",
    "neadormitului": "neadormit",
    "neadresata": "neadresat",
    "neadresată": "neadresat",
    "neadresate": "neadresat",
    "neadresatei": "neadresat",
    "neadresatele": "neadresat",
    "neadresatelor": "neadresat",
    "neadresați": "neadresat",
    "neadresații": "neadresat",
    "neadresaților": "neadresat",
    "neadresatul": "neadresat",
    "neadresatului": "neadresat",
    "neadulata": "neadulat",
    "neadulată": "neadulat",
    "neadulate": "neadulat",
    "neadulatei": "neadulat",
    "neadulatele": "neadulat",
    "neadulatelor": "neadulat",
    "neadulați": "neadulat",
    "neadulații": "neadulat",
    "neadulaților": "neadulat",
    "neadulatul": "neadulat",
    "neadulatului": "neadulat",
    "neadulmecata": "neadulmecat",
    "neadulmecată": "neadulmecat",
    "neadulmecate": "neadulmecat",
    "neadulmecatei": "neadulmecat",
    "neadulmecatele": "neadulmecat",
    "neadulmecatelor": "neadulmecat",
    "neadulmecați": "neadulmecat",
    "neadulmecații": "neadulmecat",
    "neadulmecaților": "neadulmecat",
    "neadulmecatul": "neadulmecat",
    "neadulmecatului": "neadulmecat",
    "neadumbrita": "neadumbrit",
    "neadumbrită": "neadumbrit",
    "neadumbrite": "neadumbrit",
    "neadumbritei": "neadumbrit",
    "neadumbritele": "neadumbrit",
    "neadumbritelor": "neadumbrit",
    "neadumbriți": "neadumbrit",
    "neadumbriții": "neadumbrit",
    "neadumbriților": "neadumbrit",
    "neadumbritul": "neadumbrit",
    "neadumbritului": "neadumbrit",
    "neadunata": "neadunat",
    "neadunată": "neadunat",
    "neadunate": "neadunat",
    "neadunatei": "neadunat",
    "neadunatele": "neadunat",
    "neadunatelor": "neadunat",
    "neadunați": "neadunat",
    "neadunații": "neadunat",
    "neadunaților": "neadunat",
    "neadunatul": "neadunat",
    "neadunatului": "neadunat",
    "neadusa": "neadus",
    "neadusă": "neadus",
    "neaduse": "neadus",
    "neadusei": "neadus",
    "neadusele": "neadus",
    "neaduselor": "neadus",
    "neaduși": "neadus",
    "neadușii": "neadus",
    "neadușilor": "neadus",
    "neadusul": "neadus",
    "neadusului": "neadus",
    "neafânata": "neafânat",
    "neafânată": "neafânat",
    "neafânate": "neafânat",
    "neafânatei": "neafânat",
    "neafânatele": "neafânat",
    "neafânatelor": "neafânat",
    "neafânați": "neafânat",
    "neafânații": "neafânat",
    "neafânaților": "neafânat",
    "neafânatul": "neafânat",
    "neafânatului": "neafânat",
    "neafectata": "neafectat",
    "neafectată": "neafectat",
    "neafectate": "neafectat",
    "neafectatei": "neafectat",
    "neafectatele": "neafectat",
    "neafectatelor": "neafectat",
    "neafectați": "neafectat",
    "neafectații": "neafectat",
    "neafectaților": "neafectat",
    "neafectatul": "neafectat",
    "neafectatului": "neafectat",
    "neafiliata": "neafiliat",
    "neafiliată": "neafiliat",
    "neafiliate": "neafiliat",
    "neafiliatei": "neafiliat",
    "neafiliatele": "neafiliat",
    "neafiliatelor": "neafiliat",
    "neafiliați": "neafiliat",
    "neafiliații": "neafiliat",
    "neafiliaților": "neafiliat",
    "neafiliatul": "neafiliat",
    "neafiliatului": "neafiliat",
    "neafirmata": "neafirmat",
    "neafirmată": "neafirmat",
    "neafirmate": "neafirmat",
    "neafirmatei": "neafirmat",
    "neafirmatele": "neafirmat",
    "neafirmatelor": "neafirmat",
    "neafirmați": "neafirmat",
    "neafirmații": "neafirmat",
    "neafirmaților": "neafirmat",
    "neafirmatul": "neafirmat",
    "neafirmatului": "neafirmat",
    "neafișata": "neafișat",
    "neafișată": "neafișat",
    "neafișate": "neafișat",
    "neafișatei": "neafișat",
    "neafișatele": "neafișat",
    "neafișatelor": "neafișat",
    "neafișați": "neafișat",
    "neafișații": "neafișat",
    "neafișaților": "neafișat",
    "neafișatul": "neafișat",
    "neafișatului": "neafișat",
    "neaflata": "neaflat",
    "neaflată": "neaflat",
    "neaflate": "neaflat",
    "neaflatei": "neaflat",
    "neaflatele": "neaflat",
    "neaflatelor": "neaflat",
    "neaflați": "neaflat",
    "neaflații": "neaflat",
    "neaflaților": "neaflat",
    "neaflatul": "neaflat",
    "neaflatului": "neaflat",
    "neafundata": "neafundat",
    "neafundată": "neafundat",
    "neafundate": "neafundat",
    "neafundatei": "neafundat",
    "neafundatele": "neafundat",
    "neafundatelor": "neafundat",
    "neafundați": "neafundat",
    "neafundații": "neafundat",
    "neafundaților": "neafundat",
    "neafundatul": "neafundat",
    "neafundatului": "neafundat",
    "neagasanților": "neagasat",
    "neagasata": "neagasat",
    "neagasată": "neagasat",
    "neagasate": "neagasat",
    "neagasatei": "neagasat",
    "neagasatele": "neagasat",
    "neagasatelor": "neagasat",
    "neagasați": "neagasat",
    "neagasații": "neagasat",
    "neagasaților": "neagasat",
    "neagasatul": "neagasat",
    "neagasatului": "neagasat",
    "neagățata": "neagățat",
    "neagățată": "neagățat",
    "neagățate": "neagățat",
    "neagățatei": "neagățat",
    "neagățatele": "neagățat",
    "neagățatelor": "neagățat",
    "neagățați": "neagățat",
    "neagățații": "neagățat",
    "neagățaților": "neagățat",
    "neagățatul": "neagățat",
    "neagățatului": "neagățat",
    "neagitata": "neagitat",
    "neagitată": "neagitat",
    "neagitate": "neagitat",
    "neagitatei": "neagitat",
    "neagitatele": "neagitat",
    "neagitatelor": "neagitat",
    "neagitați": "neagitat",
    "neagitații": "neagitat",
    "neagitaților": "neagitat",
    "neagitatul": "neagitat",
    "neagitatului": "neagitat",
    "neaglomerata": "neaglomerat",
    "neaglomerată": "neaglomerat",
    "neaglomerate": "neaglomerat",
    "neaglomeratei": "neaglomerat",
    "neaglomeratele": "neaglomerat",
    "neaglomeratelor": "neaglomerat",
    "neaglomerați": "neaglomerat",
    "neaglomerații": "neaglomerat",
    "neaglomeraților": "neaglomerat",
    "neaglomeratul": "neaglomerat",
    "neaglomeratului": "neaglomerat",
    "neaglutinată": "neaglutinat",
    "neaglutinate": "neaglutinat",
    "neaglutinați": "neaglutinat",
    "neagonisita": "neagonisit",
    "neagonisită": "neagonisit",
    "neagonisite": "neagonisit",
    "neagonisitei": "neagonisit",
    "neagonisitele": "neagonisit",
    "neagonisitelor": "neagonisit",
    "neagonisiți": "neagonisit",
    "neagonisiții": "neagonisit",
    "neagonisiților": "neagonisit",
    "neagonisitul": "neagonisit",
    "neagonisitului": "neagonisit",
    "neagonizată": "neagonizat",
    "neagonizate": "neagonizat",
    "neagonizați": "neagonizat",
    "neagravata": "neagravat",
    "neagravată": "neagravat",
    "neagravate": "neagravat",
    "neagravatei": "neagravat",
    "neagravatele": "neagravat",
    "neagravatelor": "neagravat",
    "neagravați": "neagravat",
    "neagravații": "neagravat",
    "neagravaților": "neagravat",
    "neagravatul": "neagravat",
    "neagravatului": "neagravat",
    "neagreata": "neagreat",
    "neagreată": "neagreat",
    "neagreate": "neagreat",
    "neagreatei": "neagreat",
    "neagreatele": "neagreat",
    "neagreatelor": "neagreat",
    "neagreați": "neagreat",
    "neagreații": "neagreat",
    "neagreaților": "neagreat",
    "neagreatul": "neagreat",
    "neagreatului": "neagreat",
    "neagregata": "neagregat",
    "neagregată": "neagregat",
    "neagregate": "neagregat",
    "neagregatei": "neagregat",
    "neagregatele": "neagregat",
    "neagregatelor": "neagregat",
    "neagregați": "neagregat",
    "neagregații": "neagregat",
    "neagregaților": "neagregat",
    "neagregatul": "neagregat",
    "neagregatului": "neagregat",
    "neagresiunea": "neagresiune",
    "neagresiuni": "neagresiune",
    "neagresiunii": "neagresiune",
    "neagresiunile": "neagresiune",
    "neagresiunilor": "neagresiune",
    "neahtiata": "neahtiat",
    "neahtiată": "neahtiat",
    "neahtiate": "neahtiat",
    "neahtiatei": "neahtiat",
    "neahtiatele": "neahtiat",
    "neahtiatelor": "neahtiat",
    "neahtiați": "neahtiat",
    "neahtiații": "neahtiat",
    "neahtiaților": "neahtiat",
    "neahtiatul": "neahtiat",
    "neahtiatului": "neahtiat",
    "neaiurată": "neaiurat",
    "neaiurate": "neaiurat",
    "neaiurați": "neaiurat",
    "neajunsa": "neajuns",
    "neajunsă": "neajuns",
    "neajunse": "neajuns",
    "neajunsei": "neajuns",
    "neajunsele": "neajuns",
    "neajunselor": "neajuns",
    "neajunși": "neajuns",
    "neajunșii": "neajuns",
    "neajunșilor": "neajuns",
    "neajunsul": "neajuns",
    "neajunsului": "neajuns",
    "neajunsuri": "neajuns",
    "neajunsurile": "neajuns",
    "neajunsurilor": "neajuns",
    "neajustata": "neajustat",
    "neajustată": "neajustat",
    "neajustate": "neajustat",
    "neajustatei": "neajustat",
    "neajustatele": "neajustat",
    "neajustatelor": "neajustat",
    "neajustați": "neajustat",
    "neajustații": "neajustat",
    "neajustaților": "neajustat",
    "neajustatul": "neajustat",
    "neajustatului": "neajustat",
    "neajutași": "neajutat",
    "neajutata": "neajutat",
    "neajutată": "neajutat",
    "neajutate": "neajutat",
    "neajutatei": "neajutat",
    "neajutatele": "neajutat",
    "neajutatelor": "neajutat",
    "neajutații": "neajutat",
    "neajutaților": "neajutat",
    "neajutatul": "neajutat",
    "neajutatului": "neajutat",
    "neajutorarea": "neajutorare",
    "neajutorări": "neajutorare",
    "neajutorării": "neajutorare",
    "neajutorările": "neajutorare",
    "neajutorărilor": "neajutorare",
    "neajutorata": "neajutorat",
    "neajutorată": "neajutorat",
    "neajutorate": "neajutorat",
    "neajutoratei": "neajutorat",
    "neajutoratele": "neajutorat",
    "neajutoratelor": "neajutorat",
    "neajutorați": "neajutorat",
    "neajutorații": "neajutorat",
    "neajutoraților": "neajutorat",
    "neajutoratul": "neajutorat",
    "neajutoratului": "neajutorat",
    "nealambicata": "nealambicat",
    "nealambicată": "nealambicat",
    "nealambicate": "nealambicat",
    "nealambicatei": "nealambicat",
    "nealambicatele": "nealambicat",
    "nealambicatelor": "nealambicat",
    "nealambicați": "nealambicat",
    "nealambicații": "nealambicat",
    "nealambicaților": "nealambicat",
    "nealambicatul": "nealambicat",
    "nealambicatului": "nealambicat",
    "nealarmata": "nealarmat",
    "nealarmată": "nealarmat",
    "nealarmate": "nealarmat",
    "nealarmatei": "nealarmat",
    "nealarmatele": "nealarmat",
    "nealarmatelor": "nealarmat",
    "nealarmați": "nealarmat",
    "nealarmații": "nealarmat",
    "nealarmaților": "nealarmat",
    "nealarmatul": "nealarmat",
    "nealarmatului": "nealarmat",
    "nealăturata": "nealăturat",
    "nealăturată": "nealăturat",
    "nealăturate": "nealăturat",
    "nealăturatele": "nealăturat",
    "nealăturatelor": "nealăturat",
    "nealăturati": "nealăturat",
    "nealăturați": "nealăturat",
    "nealăturații": "nealăturat",
    "nealăturaților": "nealăturat",
    "nealăturatul": "nealăturat",
    "nealăturatului": "nealăturat",
    "nealbita": "nealbit",
    "nealbită": "nealbit",
    "nealbite": "nealbit",
    "nealbitei": "nealbit",
    "nealbitele": "nealbit",
    "nealbitelor": "nealbit",
    "nealbiți": "nealbit",
    "nealbiții": "nealbit",
    "nealbiților": "nealbit",
    "nealbitul": "nealbit",
    "nealbitului": "nealbit",
    "nealcătuita": "nealcătuit",
    "nealcătuită": "nealcătuit",
    "nealcătuite": "nealcătuit",
    "nealcătuitei": "nealcătuit",
    "nealcătuitele": "nealcătuit",
    "nealcătuitelor": "nealcătuit",
    "nealcătuiți": "nealcătuit",
    "nealcătuiții": "nealcătuit",
    "nealcătuiților": "nealcătuit",
    "nealcătuitul": "nealcătuit",
    "nealcătuitului": "nealcătuit",
    "nealergata": "nealergat",
    "nealergată": "nealergat",
    "nealergate": "nealergat",
    "nealergatei": "nealergat",
    "nealergatele": "nealergat",
    "nealergatelor": "nealergat",
    "nealergați": "nealergat",
    "nealergații": "nealergat",
    "nealergaților": "nealergat",
    "nealergatul": "nealergat",
    "nealergatului": "nealergat",
    "nealeasa": "neales",
    "nealeasă": "neales",
    "nealese": "neales",
    "nealesei": "neales",
    "nealesele": "neales",
    "nealeselor": "neales",
    "nealeși": "neales",
    "nealeșii": "neales",
    "nealeșilor": "neales",
    "nealesul": "neales",
    "nealesului": "neales",
    "nealezata": "nealezat",
    "nealezată": "nealezat",
    "nealezate": "nealezat",
    "nealezatei": "nealezat",
    "nealezatele": "nealezat",
    "nealezatelor": "nealezat",
    "nealezați": "nealezat",
    "nealezații": "nealezat",
    "nealezaților": "nealezat",
    "nealezatul": "nealezat",
    "nealezatului": "nealezat",
    "nealfabetizata": "nealfabetizat",
    "nealfabetizată": "nealfabetizat",
    "nealfabetizate": "nealfabetizat",
    "nealfabetizatei": "nealfabetizat",
    "nealfabetizatele": "nealfabetizat",
    "nealfabetizatelor": "nealfabetizat",
    "nealfabetizați": "nealfabetizat",
    "nealfabetizații": "nealfabetizat",
    "nealfabetizaților": "nealfabetizat",
    "nealfabetizatul": "nealfabetizat",
    "nealfabetizatului": "nealfabetizat",
    "nealiata": "nealiat",
    "nealiată": "nealiat",
    "nealiate": "nealiat",
    "nealiatei": "nealiat",
    "nealiatele": "nealiat",
    "nealiatelor": "nealiat",
    "nealiați": "nealiat",
    "nealiații": "nealiat",
    "nealiaților": "nealiat",
    "nealiatul": "nealiat",
    "nealiatului": "nealiat",
    "nealienata": "nealienat",
    "nealienată": "nealienat",
    "nealienate": "nealienat",
    "nealienatei": "nealienat",
    "nealienatele": "nealienat",
    "nealienatelor": "nealienat",
    "nealienați": "nealienat",
    "nealienații": "nealienat",
    "nealienaților": "nealienat",
    "nealienatul": "nealienat",
    "nealienatului": "nealienat",
    "nealimentata": "nealimentat",
    "nealimentată": "nealimentat",
    "nealimentate": "nealimentat",
    "nealimentatei": "nealimentat",
    "nealimentatele": "nealimentat",
    "nealimentatelor": "nealimentat",
    "nealimentați": "nealimentat",
    "nealimentații": "nealimentat",
    "nealimentaților": "nealimentat",
    "nealimentatul": "nealimentat",
    "nealimentatului": "nealimentat",
    "nealinata": "nealinat",
    "nealinată": "nealinat",
    "nealinate": "nealinat",
    "nealinatei": "nealinat",
    "nealinatele": "nealinat",
    "nealinatelor": "nealinat",
    "nealinați": "nealinat",
    "nealinații": "nealinat",
    "nealinaților": "nealinat",
    "nealinatul": "nealinat",
    "nealinatului": "nealinat",
    "nealiniata": "nealiniat",
    "nealiniată": "nealiniat",
    "nealiniate": "nealiniat",
    "nealiniatei": "nealiniat",
    "nealiniatele": "nealiniat",
    "nealiniatelor": "nealiniat",
    "nealiniați": "nealiniat",
    "nealiniații": "nealiniat",
    "nealiniaților": "nealiniat",
    "nealiniatul": "nealiniat",
    "nealiniatului": "nealiniat",
    "nealinierea": "nealiniere",
    "nealinieri": "nealiniere",
    "nealinierii": "nealiniere",
    "nealinierile": "nealiniere",
    "nealinierilor": "nealiniere",
    "nealintata": "nealintat",
    "nealintată": "nealintat",
    "nealintate": "nealintat",
    "nealintatei": "nealintat",
    "nealintatele": "nealintat",
    "nealintatelor": "nealintat",
    "nealintați": "nealintat",
    "nealintații": "nealintat",
    "nealintaților": "nealintat",
    "nealintatul": "nealintat",
    "nealintatului": "nealintat",
    "nealocata": "nealocat",
    "nealocată": "nealocat",
    "nealocate": "nealocat",
    "nealocatei": "nealocat",
    "nealocatele": "nealocat",
    "nealocatelor": "nealocat",
    "nealocați": "nealocat",
    "nealocații": "nealocat",
    "nealocaților": "nealocat",
    "nealocatul": "nealocat",
    "nealocatului": "nealocat",
    "nealterata": "nealterat",
    "nealterată": "nealterat",
    "nealterate": "nealterat",
    "nealteratei": "nealterat",
    "nealteratele": "nealterat",
    "nealteratelor": "nealterat",
    "nealterați": "nealterat",
    "nealterații": "nealterat",
    "nealteraților": "nealterat",
    "nealteratul": "nealterat",
    "nealteratului": "nealterat",
    "nealternata": "nealternat",
    "nealternată": "nealternat",
    "nealternate": "nealternat",
    "nealternatei": "nealternat",
    "nealternatele": "nealternat",
    "nealternatelor": "nealternat",
    "nealternați": "nealternat",
    "nealternații": "nealternat",
    "nealternaților": "nealternat",
    "nealternatul": "nealternat",
    "nealternatului": "nealternat",
    "nealunecata": "nealunecat",
    "nealunecată": "nealunecat",
    "nealunecate": "nealunecat",
    "nealunecatei": "nealunecat",
    "nealunecatele": "nealunecat",
    "nealunecatelor": "nealunecat",
    "nealunecați": "nealunecat",
    "nealunecații": "nealunecat",
    "nealunecaților": "nealunecat",
    "nealunecatul": "nealunecat",
    "nealunecatului": "nealunecat",
    "nealungata": "nealungat",
    "nealungată": "nealungat",
    "nealungate": "nealungat",
    "nealungatei": "nealungat",
    "nealungatele": "nealungat",
    "nealungatelor": "nealungat",
    "nealungați": "nealungat",
    "nealungații": "nealungat",
    "nealungaților": "nealungat",
    "nealungatul": "nealungat",
    "nealungatului": "nealungat",
    "nealunizata": "nealunizat",
    "nealunizată": "nealunizat",
    "nealunizate": "nealunizat",
    "nealunizatei": "nealunizat",
    "nealunizatele": "nealunizat",
    "nealunizatelor": "nealunizat",
    "nealunizați": "nealunizat",
    "nealunizații": "nealunizat",
    "nealunizaților": "nealunizat",
    "nealunizatul": "nealunizat",
    "nealunizatului": "nealunizat",
    "neamul": "neam",
    "neamului": "neam",
    "neamuri": "neam",
    "neamurile": "neam",
    "neamurilor": "neam",
    "neamăgita": "neamăgit",
    "neamăgită": "neamăgit",
    "neamăgite": "neamăgit",
    "neamăgitei": "neamăgit",
    "neamăgitele": "neamăgit",
    "neamăgitelor": "neamăgit",
    "neamăgiți": "neamăgit",
    "neamăgiții": "neamăgit",
    "neamăgiților": "neamăgit",
    "neamăgitul": "neamăgit",
    "neamăgitului": "neamăgit",
    "neamânata": "neamânat",
    "neamânată": "neamânat",
    "neamânate": "neamânat",
    "neamânatei": "neamânat",
    "neamânatele": "neamânat",
    "neamânatelor": "neamânat",
    "neamânați": "neamânat",
    "neamânații": "neamânat",
    "neamânaților": "neamânat",
    "neamânatul": "neamânat",
    "neamânatului": "neamânat",
    "neamanetata": "neamanetat",
    "neamanetată": "neamanetat",
    "neamanetate": "neamanetat",
    "neamanetatei": "neamanetat",
    "neamanetatele": "neamanetat",
    "neamanetatelor": "neamanetat",
    "neamanetați": "neamanetat",
    "neamanetații": "neamanetat",
    "neamanetaților": "neamanetat",
    "neamanetatul": "neamanetat",
    "neamanetatului": "neamanetat",
    "neamărâta": "neamărât",
    "neamărâtă": "neamărât",
    "neamărâte": "neamărât",
    "neamărâtei": "neamărât",
    "neamărâtele": "neamărât",
    "neamărâtelor": "neamărât",
    "neamărâți": "neamărât",
    "neamărâții": "neamărât",
    "neamărâților": "neamărât",
    "neamărâtul": "neamărât",
    "neamărâtului": "neamărât",
    "neambalata": "neambalat",
    "neambalată": "neambalat",
    "neambalate": "neambalat",
    "neambalatei": "neambalat",
    "neambalatele": "neambalat",
    "neambalatelor": "neambalat",
    "neambalați": "neambalat",
    "neambalații": "neambalat",
    "neambalaților": "neambalat",
    "neambalatul": "neambalat",
    "neambalatului": "neambalat",
    "neambiționata": "neambiționat",
    "neambiționată": "neambiționat",
    "neambiționate": "neambiționat",
    "neambiționatei": "neambiționat",
    "neambiționatele": "neambiționat",
    "neambiționatelor": "neambiționat",
    "neambiționați": "neambiționat",
    "neambiționații": "neambiționat",
    "neambiționaților": "neambiționat",
    "neambiționatul": "neambiționat",
    "neambiționatului": "neambiționat",
    "neameliorata": "neameliorat",
    "neameliorată": "neameliorat",
    "neameliorate": "neameliorat",
    "neamelioratei": "neameliorat",
    "neamelioratele": "neameliorat",
    "neamelioratelor": "neameliorat",
    "neameliorați": "neameliorat",
    "neameliorații": "neameliorat",
    "neamelioraților": "neameliorat",
    "neamelioratul": "neameliorat",
    "neamelioratului": "neameliorat",
    "neamenajata": "neamenajat",
    "neamenajată": "neamenajat",
    "neamenajate": "neamenajat",
    "neamenajatei": "neamenajat",
    "neamenajatele": "neamenajat",
    "neamenajatelor": "neamenajat",
    "neamenajați": "neamenajat",
    "neamenajații": "neamenajat",
    "neamenajaților": "neamenajat",
    "neamenajatul": "neamenajat",
    "neamenajatului": "neamenajat",
    "neamendata": "neamendat",
    "neamendată": "neamendat",
    "neamendate": "neamendat",
    "neamendatei": "neamendat",
    "neamendatele": "neamendat",
    "neamendatelor": "neamendat",
    "neamendați": "neamendat",
    "neamendații": "neamendat",
    "neamendaților": "neamendat",
    "neamendatul": "neamendat",
    "neamendatului": "neamendat",
    "neamenințata": "neamenințat",
    "neamenințată": "neamenințat",
    "neamenințate": "neamenințat",
    "neamenințatei": "neamenințat",
    "neamenințatele": "neamenințat",
    "neamenințatelor": "neamenințat",
    "neamenințați": "neamenințat",
    "neamenințații": "neamenințat",
    "neamenințaților": "neamenințat",
    "neamenințatul": "neamenințat",
    "neamenințatului": "neamenințat",
    "neamestecul": "neamestec",
    "neamestecului": "neamestec",
    "neamestecuri": "neamestec",
    "neamestecurile": "neamestec",
    "neamestecurilor": "neamestec",
    "neamestecata": "neamestecat",
    "neamestecată": "neamestecat",
    "neamestecate": "neamestecat",
    "neamestecatei": "neamestecat",
    "neamestecatele": "neamestecat",
    "neamestecatelor": "neamestecat",
    "neamestecați": "neamestecat",
    "neamestecații": "neamestecat",
    "neamestecaților": "neamestecat",
    "neamestecatul": "neamestecat",
    "neamestecatului": "neamestecat",
    "neamețita": "neamețit",
    "neamețită": "neamețit",
    "neamețite": "neamețit",
    "neamețitei": "neamețit",
    "neamețitele": "neamețit",
    "neamețitelor": "neamețit",
    "neamețiți": "neamețit",
    "neamețiții": "neamețit",
    "neamețiților": "neamețit",
    "neamețitul": "neamețit",
    "neamețitului": "neamețit",
    "neamintita": "neamintit",
    "neamintită": "neamintit",
    "neamintite": "neamintit",
    "neamintitei": "neamintit",
    "neamintitele": "neamintit",
    "neamintitelor": "neamintit",
    "neamintiți": "neamintit",
    "neamintiții": "neamintit",
    "neamintiților": "neamintit",
    "neamintitul": "neamintit",
    "neamintitului": "neamintit",
    "neamnistiata": "neamnistiat",
    "neamnistiată": "neamnistiat",
    "neamnistiate": "neamnistiat",
    "neamnistiatei": "neamnistiat",
    "neamnistiatele": "neamnistiat",
    "neamnistiatelor": "neamnistiat",
    "neamnistiați": "neamnistiat",
    "neamnistiații": "neamnistiat",
    "neamnistiaților": "neamnistiat",
    "neamnistiatul": "neamnistiat",
    "neamnistiatului": "neamnistiat",
    "neamorțita": "neamorțit",
    "neamorțită": "neamorțit",
    "neamorțite": "neamorțit",
    "neamorțitei": "neamorțit",
    "neamorțitele": "neamorțit",
    "neamorțitelor": "neamorțit",
    "neamorțiți": "neamorțit",
    "neamorțiții": "neamorțit",
    "neamorțiților": "neamorțit",
    "neamorțitul": "neamorțit",
    "neamorțitului": "neamorțit",
    "neamortizata": "neamortizat",
    "neamortizată": "neamortizat",
    "neamortizate": "neamortizat",
    "neamortizatei": "neamortizat",
    "neamortizatele": "neamortizat",
    "neamortizatelor": "neamortizat",
    "neamortizați": "neamortizat",
    "neamortizații": "neamortizat",
    "neamortizaților": "neamortizat",
    "neamortizatul": "neamortizat",
    "neamortizatului": "neamortizat",
    "neamplasata": "neamplasat",
    "neamplasată": "neamplasat",
    "neamplasate": "neamplasat",
    "neamplasatei": "neamplasat",
    "neamplasatele": "neamplasat",
    "neamplasatelor": "neamplasat",
    "neamplasați": "neamplasat",
    "neamplasații": "neamplasat",
    "neamplasaților": "neamplasat",
    "neamplasatul": "neamplasat",
    "neamplasatului": "neamplasat",
    "neamplificata": "neamplificat",
    "neamplificată": "neamplificat",
    "neamplificate": "neamplificat",
    "neamplificatei": "neamplificat",
    "neamplificatele": "neamplificat",
    "neamplificatelor": "neamplificat",
    "neamplificați": "neamplificat",
    "neamplificații": "neamplificat",
    "neamplificaților": "neamplificat",
    "neamplificatul": "neamplificat",
    "neamplificatului": "neamplificat",
    "neamputata": "neamputat",
    "neamputată": "neamputat",
    "neamputate": "neamputat",
    "neamputatei": "neamputat",
    "neamputatele": "neamputat",
    "neamputatelor": "neamputat",
    "neamputați": "neamputat",
    "neamputații": "neamputat",
    "neamputaților": "neamputat",
    "neamputatul": "neamputat",
    "neamputatului": "neamputat",
    "neamțul": "neamț",
    "neamțului": "neamț",
    "nemți": "neamț",
    "nemții": "neamț",
    "nemților": "neamț",
    "neamurgita": "neamurgit",
    "neamurgită": "neamurgit",
    "neamurgite": "neamurgit",
    "neamurgitei": "neamurgit",
    "neamurgitele": "neamurgit",
    "neamurgitelor": "neamurgit",
    "neamurgiți": "neamurgit",
    "neamurgiții": "neamurgit",
    "neamurgiților": "neamurgit",
    "neamurgitul": "neamurgit",
    "neamurgitului": "neamurgit",
    "neamuțita": "neamuțit",
    "neamuțită": "neamuțit",
    "neamuțite": "neamuțit",
    "neamuțitei": "neamuțit",
    "neamuțitele": "neamuțit",
    "neamuțitelor": "neamuțit",
    "neamuțiți": "neamuțit",
    "neamuțiții": "neamuțit",
    "neamuțiților": "neamuțit",
    "neamuțitul": "neamuțit",
    "neamuțitului": "neamuțit",
    "neamuzata": "neamuzat",
    "neamuzată": "neamuzat",
    "neamuzate": "neamuzat",
    "neamuzatei": "neamuzat",
    "neamuzatele": "neamuzat",
    "neamuzatelor": "neamuzat",
    "neamuzați": "neamuzat",
    "neamuzații": "neamuzat",
    "neamuzaților": "neamuzat",
    "neamuzatul": "neamuzat",
    "neamuzatului": "neamuzat",
    "neanalizata": "neanalizat",
    "neanalizată": "neanalizat",
    "neanalizate": "neanalizat",
    "neanalizatei": "neanalizat",
    "neanalizatele": "neanalizat",
    "neanalizatelor": "neanalizat",
    "neanalizați": "neanalizat",
    "neanalizații": "neanalizat",
    "neanalizaților": "neanalizat",
    "neanalizatul": "neanalizat",
    "neanalizatului": "neanalizat",
    "neanchetata": "neanchetat",
    "neanchetată": "neanchetat",
    "neanchetate": "neanchetat",
    "neanchetatei": "neanchetat",
    "neanchetatele": "neanchetat",
    "neanchetatelor": "neanchetat",
    "neanchetați": "neanchetat",
    "neanchetații": "neanchetat",
    "neanchetaților": "neanchetat",
    "neanchetatul": "neanchetat",
    "neanchetatului": "neanchetat",
    "neanchilozata": "neanchilozat",
    "neanchilozată": "neanchilozat",
    "neanchilozate": "neanchilozat",
    "neanchilozatei": "neanchilozat",
    "neanchilozatele": "neanchilozat",
    "neanchilozatelor": "neanchilozat",
    "neanchilozați": "neanchilozat",
    "neanchilozații": "neanchilozat",
    "neanchilozaților": "neanchilozat",
    "neanchilozatul": "neanchilozat",
    "neanchilozatului": "neanchilozat",
    "neancorata": "neancorat",
    "neancorată": "neancorat",
    "neancorate": "neancorat",
    "neancoratei": "neancorat",
    "neancoratele": "neancorat",
    "neancoratelor": "neancorat",
    "neancorați": "neancorat",
    "neancorații": "neancorat",
    "neancoraților": "neancorat",
    "neancoratul": "neancorat",
    "neancoratului": "neancorat",
    "neanemiata": "neanemiat",
    "neanemiată": "neanemiat",
    "neanemiate": "neanemiat",
    "neanemiatei": "neanemiat",
    "neanemiatele": "neanemiat",
    "neanemiatelor": "neanemiat",
    "neanemiați": "neanemiat",
    "neanemiații": "neanemiat",
    "neanemiaților": "neanemiat",
    "neanemiatul": "neanemiat",
    "neanemiatului": "neanemiat",
    "neanexata": "neanexat",
    "neanexată": "neanexat",
    "neanexate": "neanexat",
    "neanexatei": "neanexat",
    "neanexatele": "neanexat",
    "neanexatelor": "neanexat",
    "neanexați": "neanexat",
    "neanexații": "neanexat",
    "neanexaților": "neanexat",
    "neanexatul": "neanexat",
    "neanexatului": "neanexat",
    "neangajata": "neangajat",
    "neangajată": "neangajat",
    "neangajate": "neangajat",
    "neangajatei": "neangajat",
    "neangajatele": "neangajat",
    "neangajatelor": "neangajat",
    "neangajați": "neangajat",
    "neangajații": "neangajat",
    "neangajaților": "neangajat",
    "neangajatul": "neangajat",
    "neangajatului": "neangajat",
    "neangrenata": "neangrenat",
    "neangrenată": "neangrenat",
    "neangrenate": "neangrenat",
    "neangrenatei": "neangrenat",
    "neangrenatele": "neangrenat",
    "neangrenatelor": "neangrenat",
    "neangrenați": "neangrenat",
    "neangrenații": "neangrenat",
    "neangrenaților": "neangrenat",
    "neangrenatul": "neangrenat",
    "neangrenatului": "neangrenat",
    "neanihilata": "neanihilat",
    "neanihilată": "neanihilat",
    "neanihilate": "neanihilat",
    "neanihilatei": "neanihilat",
    "neanihilatele": "neanihilat",
    "neanihilatelor": "neanihilat",
    "neanihilați": "neanihilat",
    "neanihilații": "neanihilat",
    "neanihilaților": "neanihilat",
    "neanihilatul": "neanihilat",
    "neanihilatului": "neanihilat",
    "neanimata": "neanimat",
    "neanimată": "neanimat",
    "neanimate": "neanimat",
    "neanimatei": "neanimat",
    "neanimatele": "neanimat",
    "neanimatelor": "neanimat",
    "neanimați": "neanimat",
    "neanimații": "neanimat",
    "neanimaților": "neanimat",
    "neanimatul": "neanimat",
    "neanimatului": "neanimat",
    "neaniversata": "neaniversat",
    "neaniversată": "neaniversat",
    "neaniversate": "neaniversat",
    "neaniversatei": "neaniversat",
    "neaniversatele": "neaniversat",
    "neaniversatelor": "neaniversat",
    "neaniversați": "neaniversat",
    "neaniversații": "neaniversat",
    "neaniversaților": "neaniversat",
    "neaniversatul": "neaniversat",
    "neaniversatului": "neaniversat",
    "neantul": "neant",
    "neantului": "neant",
    "neanticipata": "neanticipat",
    "neanticipată": "neanticipat",
    "neanticipate": "neanticipat",
    "neanticipatei": "neanticipat",
    "neanticipatele": "neanticipat",
    "neanticipatelor": "neanticipat",
    "neanticipați": "neanticipat",
    "neanticipații": "neanticipat",
    "neanticipaților": "neanticipat",
    "neanticipatul": "neanticipat",
    "neanticipatului": "neanticipat",
    "neantrenata": "neantrenat",
    "neantrenată": "neantrenat",
    "neantrenate": "neantrenat",
    "neantrenatei": "neantrenat",
    "neantrenatele": "neantrenat",
    "neantrenatelor": "neantrenat",
    "neantrenați": "neantrenat",
    "neantrenații": "neantrenat",
    "neantrenaților": "neantrenat",
    "neantrenatul": "neantrenat",
    "neantrenatului": "neantrenat",
    "neanulata": "neanulat",
    "neanulată": "neanulat",
    "neanulate": "neanulat",
    "neanulatei": "neanulat",
    "neanulatele": "neanulat",
    "neanulatelor": "neanulat",
    "neanulați": "neanulat",
    "neanulații": "neanulat",
    "neanulaților": "neanulat",
    "neanulatul": "neanulat",
    "neanulatului": "neanulat",
    "neanunțata": "neanunțat",
    "neanunțată": "neanunțat",
    "neanunțate": "neanunțat",
    "neanunțatei": "neanunțat",
    "neanunțatele": "neanunțat",
    "neanunțatelor": "neanunțat",
    "neanunțați": "neanunțat",
    "neanunțații": "neanunțat",
    "neanunțaților": "neanunțat",
    "neanunțatul": "neanunțat",
    "neanunțatului": "neanunțat",
    "neaoșa": "neaoș",
    "neaoșă": "neaoș",
    "neaoșe": "neaoș",
    "neaoșei": "neaoș",
    "neaoșele": "neaoș",
    "neaoșelor": "neaoș",
    "neaoși": "neaoș",
    "neaoșii": "neaoș",
    "neaoșilor": "neaoș",
    "neaoșul": "neaoș",
    "neaoșului": "neaoș",
    "neapărata": "neapărat",
    "neapărată": "neapărat",
    "neapărate": "neapărat",
    "neapăratei": "neapărat",
    "neapăratele": "neapărat",
    "neapăratelor": "neapărat",
    "neapărați": "neapărat",
    "neapărații": "neapărat",
    "neapăraților": "neapărat",
    "neapăratul": "neapărat",
    "neapăratului": "neapărat",
    "neaparținuta": "neaparținut",
    "neaparținută": "neaparținut",
    "neaparținute": "neaparținut",
    "neaparținutei": "neaparținut",
    "neaparținutele": "neaparținut",
    "neaparținutelor": "neaparținut",
    "neaparținuți": "neaparținut",
    "neaparținuții": "neaparținut",
    "neaparținuților": "neaparținut",
    "neaparținutul": "neaparținut",
    "neaparținutului": "neaparținut",
    "neapăruta": "neapărut",
    "neapărută": "neapărut",
    "neapărute": "neapărut",
    "neapărutei": "neapărut",
    "neapărutele": "neapărut",
    "neapărutelor": "neapărut",
    "neapăruți": "neapărut",
    "neapăruții": "neapărut",
    "neapăruților": "neapărut",
    "neapărutul": "neapărut",
    "neapărutului": "neapărut",
    "neapăsarea": "neapăsare",
    "neapăsări": "neapăsare",
    "neapăsării": "neapăsare",
    "neapăsările": "neapăsare",
    "neapăsata": "neapăsat",
    "neapăsată": "neapăsat",
    "neapăsate": "neapăsat",
    "neapăsatei": "neapăsat",
    "neapăsatele": "neapăsat",
    "neapăsatelor": "neapăsat",
    "neapăsați": "neapăsat",
    "neapăsații": "neapăsat",
    "neapăsaților": "neapăsat",
    "neapăsatul": "neapăsat",
    "neapăsatului": "neapăsat",
    "neapăsătoare": "neapăsător",
    "neapăsătoarea": "neapăsător",
    "neapăsătoarei": "neapăsător",
    "neapăsătoarele": "neapăsător",
    "neapăsătoarelor": "neapăsător",
    "neapăsători": "neapăsător",
    "neapăsătorii": "neapăsător",
    "neapăsătorilor": "neapăsător",
    "neapăsătorul": "neapăsător",
    "neapăsătorului": "neapăsător",
    "neapelata": "neapelat",
    "neapelată": "neapelat",
    "neapelate": "neapelat",
    "neapelatei": "neapelat",
    "neapelatele": "neapelat",
    "neapelatelor": "neapelat",
    "neapelați": "neapelat",
    "neapelații": "neapelat",
    "neapelaților": "neapelat",
    "neapelatul": "neapelat",
    "neapelatului": "neapelat",
    "neapetisanta": "neapetisant",
    "neapetisantă": "neapetisant",
    "neapetisante": "neapetisant",
    "neapetisantei": "neapetisant",
    "neapetisantele": "neapetisant",
    "neapetisantelor": "neapetisant",
    "neapetisanți": "neapetisant",
    "neapetisanții": "neapetisant",
    "neapetisanților": "neapetisant",
    "neapetisantul": "neapetisant",
    "neapetisantului": "neapetisant",
    "neaplanata": "neaplanat",
    "neaplanată": "neaplanat",
    "neaplanate": "neaplanat",
    "neaplanatei": "neaplanat",
    "neaplanatele": "neaplanat",
    "neaplanatelor": "neaplanat",
    "neaplanați": "neaplanat",
    "neaplanații": "neaplanat",
    "neaplanaților": "neaplanat",
    "neaplanatul": "neaplanat",
    "neaplanatului": "neaplanat",
    "neaplatizata": "neaplatizat",
    "neaplatizată": "neaplatizat",
    "neaplatizate": "neaplatizat",
    "neaplatizatei": "neaplatizat",
    "neaplatizatele": "neaplatizat",
    "neaplatizatelor": "neaplatizat",
    "neaplatizați": "neaplatizat",
    "neaplatizații": "neaplatizat",
    "neaplatizaților": "neaplatizat",
    "neaplatizatul": "neaplatizat",
    "neaplatizatului": "neaplatizat",
    "neaplaudata": "neaplaudat",
    "neaplaudată": "neaplaudat",
    "neaplaudate": "neaplaudat",
    "neaplaudatei": "neaplaudat",
    "neaplaudatele": "neaplaudat",
    "neaplaudatelor": "neaplaudat",
    "neaplaudați": "neaplaudat",
    "neaplaudații": "neaplaudat",
    "neaplaudaților": "neaplaudat",
    "neaplaudatul": "neaplaudat",
    "neaplaudatului": "neaplaudat",
    "neaplecata": "neaplecat",
    "neaplecată": "neaplecat",
    "neaplecate": "neaplecat",
    "neaplecatei": "neaplecat",
    "neaplecatele": "neaplecat",
    "neaplecatelor": "neaplecat",
    "neaplecați": "neaplecat",
    "neaplecații": "neaplecat",
    "neaplecaților": "neaplecat",
    "neaplecatul": "neaplecat",
    "neaplecatului": "neaplecat",
    "neaplicata": "neaplicat",
    "neaplicată": "neaplicat",
    "neaplicate": "neaplicat",
    "neaplicatei": "neaplicat",
    "neaplicatele": "neaplicat",
    "neaplicatelor": "neaplicat",
    "neaplicați": "neaplicat",
    "neaplicații": "neaplicat",
    "neaplicaților": "neaplicat",
    "neaplicatul": "neaplicat",
    "neaplicatului": "neaplicat",
    "neapostrofata": "neapostrofat",
    "neapostrofată": "neapostrofat",
    "neapostrofate": "neapostrofat",
    "neapostrofatei": "neapostrofat",
    "neapostrofatele": "neapostrofat",
    "neapostrofatelor": "neapostrofat",
    "neapostrofați": "neapostrofat",
    "neapostrofații": "neapostrofat",
    "neapostrofaților": "neapostrofat",
    "neapostrofatul": "neapostrofat",
    "neapostrofatului": "neapostrofat",
    "neapreciata": "neapreciat",
    "neapreciată": "neapreciat",
    "neapreciate": "neapreciat",
    "neapreciatei": "neapreciat",
    "neapreciatele": "neapreciat",
    "neapreciatelor": "neapreciat",
    "neapreciați": "neapreciat",
    "neapreciații": "neapreciat",
    "neapreciaților": "neapreciat",
    "neapreciatul": "neapreciat",
    "neapreciatului": "neapreciat",
    "neaprinsa": "neaprins",
    "neaprinsă": "neaprins",
    "neaprinse": "neaprins",
    "neaprinsei": "neaprins",
    "neaprinsele": "neaprins",
    "neaprinselor": "neaprins",
    "neaprinși": "neaprins",
    "neaprinșii": "neaprins",
    "neaprinșilor": "neaprins",
    "neaprinsul": "neaprins",
    "neaprinsului": "neaprins",
    "neaprobata": "neaprobat",
    "neaprobată": "neaprobat",
    "neaprobate": "neaprobat",
    "neaprobatei": "neaprobat",
    "neaprobatele": "neaprobat",
    "neaprobatelor": "neaprobat",
    "neaprobați": "neaprobat",
    "neaprobații": "neaprobat",
    "neaprobaților": "neaprobat",
    "neaprobatul": "neaprobat",
    "neaprobatului": "neaprobat",
    "neaprofundata": "neaprofundat",
    "neaprofundată": "neaprofundat",
    "neaprofundate": "neaprofundat",
    "neaprofundatei": "neaprofundat",
    "neaprofundatele": "neaprofundat",
    "neaprofundatelor": "neaprofundat",
    "neaprofundați": "neaprofundat",
    "neaprofundații": "neaprofundat",
    "neaprofundaților": "neaprofundat",
    "neaprofundatul": "neaprofundat",
    "neaprofundatului": "neaprofundat",
    "neapropiata": "neapropiat",
    "neapropiată": "neapropiat",
    "neapropiate": "neapropiat",
    "neapropiatei": "neapropiat",
    "neapropiatele": "neapropiat",
    "neapropiatelor": "neapropiat",
    "neapropiați": "neapropiat",
    "neapropiații": "neapropiat",
    "neapropiaților": "neapropiat",
    "neapropiatul": "neapropiat",
    "neapropiatului": "neapropiat",
    "neaprovizionata": "neaprovizionat",
    "neaprovizionată": "neaprovizionat",
    "neaprovizionate": "neaprovizionat",
    "neaprovizionatei": "neaprovizionat",
    "neaprovizionatele": "neaprovizionat",
    "neaprovizionatelor": "neaprovizionat",
    "neaprovizionați": "neaprovizionat",
    "neaprovizionații": "neaprovizionat",
    "neaprovizionaților": "neaprovizionat",
    "neaprovizionatul": "neaprovizionat",
    "neaprovizionatului": "neaprovizionat",
    "neapucata": "neapucat",
    "neapucată": "neapucat",
    "neapucate": "neapucat",
    "neapucatei": "neapucat",
    "neapucatele": "neapucat",
    "neapucatelor": "neapucat",
    "neapucați": "neapucat",
    "neapucații": "neapucat",
    "neapucaților": "neapucat",
    "neapucatul": "neapucat",
    "neapucatului": "neapucat",
    "neapusa": "neapus",
    "neapusă": "neapus",
    "neapuse": "neapus",
    "neapusei": "neapus",
    "neapusele": "neapus",
    "neapuselor": "neapus",
    "neapuși": "neapus",
    "neapușii": "neapus",
    "neapușilor": "neapus",
    "neapusul": "neapus",
    "neapusului": "neapus",
    "nearanjata": "nearanjat",
    "nearanjată": "nearanjat",
    "nearanjate": "nearanjat",
    "nearanjatei": "nearanjat",
    "nearanjatele": "nearanjat",
    "nearanjatelor": "nearanjat",
    "nearanjați": "nearanjat",
    "nearanjații": "nearanjat",
    "nearanjaților": "nearanjat",
    "nearanjatul": "nearanjat",
    "nearanjatului": "nearanjat",
    "nearată": "nearat",
    "nearate": "nearat",
    "nearați": "nearat",
    "nearătata": "nearătat",
    "nearătată": "nearătat",
    "nearătate": "nearătat",
    "nearătatei": "nearătat",
    "nearătatele": "nearătat",
    "nearătatelor": "nearătat",
    "nearătați": "nearătat",
    "nearătații": "nearătat",
    "nearătaților": "nearătat",
    "nearătatul": "nearătat",
    "nearătatului": "nearătat",
    "nearborata": "nearborat",
    "nearborată": "nearborat",
    "nearborate": "nearborat",
    "nearboratei": "nearborat",
    "nearboratele": "nearborat",
    "nearboratelor": "nearborat",
    "nearborați": "nearborat",
    "nearborații": "nearborat",
    "nearboraților": "nearborat",
    "nearboratul": "nearborat",
    "nearboratului": "nearborat",
    "nearendata": "nearendat",
    "nearendată": "nearendat",
    "nearendate": "nearendat",
    "nearendatei": "nearendat",
    "nearendatele": "nearendat",
    "nearendatelor": "nearendat",
    "nearendați": "nearendat",
    "nearendații": "nearendat",
    "nearendaților": "nearendat",
    "nearendatul": "nearendat",
    "nearendatului": "nearendat",
    "nearestata": "nearestat",
    "nearestată": "nearestat",
    "nearestate": "nearestat",
    "nearestatei": "nearestat",
    "nearestatele": "nearestat",
    "nearestatelor": "nearestat",
    "nearestați": "nearestat",
    "nearestații": "nearestat",
    "nearestaților": "nearestat",
    "nearestatul": "nearestat",
    "nearestatului": "nearestat",
    "neargăsita": "neargăsit",
    "neargăsită": "neargăsit",
    "neargăsite": "neargăsit",
    "neargăsitei": "neargăsit",
    "neargăsitele": "neargăsit",
    "neargăsitelor": "neargăsit",
    "neargăsiți": "neargăsit",
    "neargăsiții": "neargăsit",
    "neargăsiților": "neargăsit",
    "neargăsitul": "neargăsit",
    "neargăsitului": "neargăsit",
    "neargumentata": "neargumentat",
    "neargumentată": "neargumentat",
    "neargumentate": "neargumentat",
    "neargumentatei": "neargumentat",
    "neargumentatele": "neargumentat",
    "neargumentatelor": "neargumentat",
    "neargumentați": "neargumentat",
    "neargumentații": "neargumentat",
    "neargumentaților": "neargumentat",
    "neargumentatul": "neargumentat",
    "neargumentatului": "neargumentat",
    "nearmata": "nearmat",
    "nearmată": "nearmat",
    "nearmate": "nearmat",
    "nearmatei": "nearmat",
    "nearmatele": "nearmat",
    "nearmatelor": "nearmat",
    "nearmați": "nearmat",
    "nearmații": "nearmat",
    "nearmaților": "nearmat",
    "nearmatul": "nearmat",
    "nearmatului": "nearmat",
    "nearmonizata": "nearmonizat",
    "nearmonizată": "nearmonizat",
    "nearmonizate": "nearmonizat",
    "nearmonizatei": "nearmonizat",
    "nearmonizatele": "nearmonizat",
    "nearmonizatelor": "nearmonizat",
    "nearmonizați": "nearmonizat",
    "nearmonizații": "nearmonizat",
    "nearmonizaților": "nearmonizat",
    "nearmonizatul": "nearmonizat",
    "nearmonizatului": "nearmonizat",
    "nearogata": "nearogat",
    "nearogată": "nearogat",
    "nearogate": "nearogat",
    "nearogatei": "nearogat",
    "nearogatele": "nearogat",
    "nearogatelor": "nearogat",
    "nearogați": "nearogat",
    "nearogații": "nearogat",
    "nearogaților": "nearogat",
    "nearogatul": "nearogat",
    "nearogatului": "nearogat",
    "nearsă": "nears",
    "nearse": "nears",
    "nearși": "nears",
    "nearticulata": "nearticulat",
    "nearticulată": "nearticulat",
    "nearticulate": "nearticulat",
    "nearticulatei": "nearticulat",
    "nearticulatele": "nearticulat",
    "nearticulatelor": "nearticulat",
    "nearticulați": "nearticulat",
    "nearticulații": "nearticulat",
    "nearticulaților": "nearticulat",
    "nearticulatul": "nearticulat",
    "nearticulatului": "nearticulat",
    "nearuncata": "nearuncat",
    "nearuncată": "nearuncat",
    "nearuncate": "nearuncat",
    "nearuncatei": "nearuncat",
    "nearuncatele": "nearuncat",
    "nearuncatelor": "nearuncat",
    "nearuncați": "nearuncat",
    "nearuncații": "nearuncat",
    "nearuncaților": "nearuncat",
    "nearuncatul": "nearuncat",
    "nearuncatului": "nearuncat",
    "neasaltata": "neasaltat",
    "neasaltată": "neasaltat",
    "neasaltate": "neasaltat",
    "neasaltatei": "neasaltat",
    "neasaltatele": "neasaltat",
    "neasaltatelor": "neasaltat",
    "neasaltați": "neasaltat",
    "neasaltații": "neasaltat",
    "neasaltaților": "neasaltat",
    "neasaltatul": "neasaltat",
    "neasaltatului": "neasaltat",
    "neasamblata": "neasamblat",
    "neasamblată": "neasamblat",
    "neasamblate": "neasamblat",
    "neasamblatei": "neasamblat",
    "neasamblatele": "neasamblat",
    "neasamblatelor": "neasamblat",
    "neasamblați": "neasamblat",
    "neasamblații": "neasamblat",
    "neasamblaților": "neasamblat",
    "neasamblatul": "neasamblat",
    "neasamblatului": "neasamblat",
    "neasanata": "neasanat",
    "neasanată": "neasanat",
    "neasanate": "neasanat",
    "neasanatei": "neasanat",
    "neasanatele": "neasanat",
    "neasanatelor": "neasanat",
    "neasanați": "neasanat",
    "neasanații": "neasanat",
    "neasanaților": "neasanat",
    "neasanatul": "neasanat",
    "neasanatului": "neasanat",
    "neasasinata": "neasasinat",
    "neasasinată": "neasasinat",
    "neasasinate": "neasasinat",
    "neasasinatei": "neasasinat",
    "neasasinatele": "neasasinat",
    "neasasinatelor": "neasasinat",
    "neasasinați": "neasasinat",
    "neasasinații": "neasasinat",
    "neasasinaților": "neasasinat",
    "neasasinatul": "neasasinat",
    "neasasinatului": "neasasinat",
    "neascultarea": "neascultare",
    "neascultări": "neascultare",
    "neascultării": "neascultare",
    "neascultările": "neascultare",
    "neascultărilor": "neascultare",
    "neascultata": "neascultat",
    "neascultată": "neascultat",
    "neascultate": "neascultat",
    "neascultatei": "neascultat",
    "neascultatele": "neascultat",
    "neascultatelor": "neascultat",
    "neascultați": "neascultat",
    "neascultații": "neascultat",
    "neascultaților": "neascultat",
    "neascultatul": "neascultat",
    "neascultatului": "neascultat",
    "neascultătoare": "neascultător",
    "neascultătoarea": "neascultător",
    "neascultătoarei": "neascultător",
    "neascultătoarele": "neascultător",
    "neascultătoarelor": "neascultător",
    "neascultători": "neascultător",
    "neascultătorii": "neascultător",
    "neascultătorilor": "neascultător",
    "neascultătorul": "neascultător",
    "neascultătorului": "neascultător",
    "neascunsa": "neascuns",
    "neascunsă": "neascuns",
    "neascunse": "neascuns",
    "neascunsei": "neascuns",
    "neascunsele": "neascuns",
    "neascunselor": "neascuns",
    "neascunși": "neascuns",
    "neascunșii": "neascuns",
    "neascunșilor": "neascuns",
    "neascunsul": "neascuns",
    "neascunsului": "neascuns",
    "neascuțita": "neascuțit",
    "neascuțită": "neascuțit",
    "neascuțite": "neascuțit",
    "neascuțitei": "neascuțit",
    "neascuțitele": "neascuțit",
    "neascuțitelor": "neascuțit",
    "neascuțiții": "neascuțit",
    "neascuțiților": "neascuțit",
    "neascuțitul": "neascuțit",
    "neascuțitului": "neascuțit",
    "neasediata": "neasediat",
    "neasediată": "neasediat",
    "neasediate": "neasediat",
    "neasediatei": "neasediat",
    "neasediatele": "neasediat",
    "neasediatelor": "neasediat",
    "neasediați": "neasediat",
    "neasediații": "neasediat",
    "neasediaților": "neasediat",
    "neasediatul": "neasediat",
    "neasediatului": "neasediat",
    "neaselenizata": "neaselenizat",
    "neaselenizată": "neaselenizat",
    "neaselenizate": "neaselenizat",
    "neaselenizatei": "neaselenizat",
    "neaselenizatele": "neaselenizat",
    "neaselenizatelor": "neaselenizat",
    "neaselenizați": "neaselenizat",
    "neaselenizații": "neaselenizat",
    "neaselenizaților": "neaselenizat",
    "neaselenizatul": "neaselenizat",
    "neaselenizatului": "neaselenizat",
    "neasemănata": "neasemănat",
    "neasemănată": "neasemănat",
    "neasemănate": "neasemănat",
    "neasemănatei": "neasemănat",
    "neasemănatele": "neasemănat",
    "neasemănatelor": "neasemănat",
    "neasemănați": "neasemănat",
    "neasemănații": "neasemănat",
    "neasemănaților": "neasemănat",
    "neasemănatul": "neasemănat",
    "neasemănatului": "neasemănat",
    "neasemănătoare": "neasemănător",
    "neasemănătoarea": "neasemănător",
    "neasemănătoarei": "neasemănător",
    "neasemănătoarele": "neasemănător",
    "neasemănătoarelor": "neasemănător",
    "neasemănători": "neasemănător",
    "neasemănătorii": "neasemănător",
    "neasemănătorilor": "neasemănător",
    "neasemănătorul": "neasemănător",
    "neasemănătorului": "neasemănător",
    "neasemuita": "neasemuit",
    "neasemuită": "neasemuit",
    "neasemuite": "neasemuit",
    "neasemuitei": "neasemuit",
    "neasemuitele": "neasemuit",
    "neasemuitelor": "neasemuit",
    "neasemuiți": "neasemuit",
    "neasemuiții": "neasemuit",
    "neasemuiților": "neasemuit",
    "neasemuitul": "neasemuit",
    "neasemuitului": "neasemuit",
    "neaservita": "neaservit",
    "neaservită": "neaservit",
    "neaservite": "neaservit",
    "neaservitei": "neaservit",
    "neaservitele": "neaservit",
    "neaservitelor": "neaservit",
    "neaserviți": "neaservit",
    "neaserviții": "neaservit",
    "neaserviților": "neaservit",
    "neaservitul": "neaservit",
    "neaservitului": "neaservit",
    "neașezata": "neașezat",
    "neașezată": "neașezat",
    "neașezate": "neașezat",
    "neașezatei": "neașezat",
    "neașezatele": "neașezat",
    "neașezatelor": "neașezat",
    "neașezați": "neașezat",
    "neașezații": "neașezat",
    "neașezaților": "neașezat",
    "neașezatul": "neașezat",
    "neașezatului": "neașezat",
    "neasezonata": "neasezonat",
    "neasezonată": "neasezonat",
    "neasezonate": "neasezonat",
    "neasezonatei": "neasezonat",
    "neasezonatele": "neasezonat",
    "neasezonatelor": "neasezonat",
    "neasezonați": "neasezonat",
    "neasezonații": "neasezonat",
    "neasezonaților": "neasezonat",
    "neasezonatul": "neasezonat",
    "neasezonatului": "neasezonat",
    "neasfixiata": "neasfixiat",
    "neasfixiată": "neasfixiat",
    "neasfixiate": "neasfixiat",
    "neasfixiatei": "neasfixiat",
    "neasfixiatele": "neasfixiat",
    "neasfixiatelor": "neasfixiat",
    "neasfixiați": "neasfixiat",
    "neasfixiații": "neasfixiat",
    "neasfixiaților": "neasfixiat",
    "neasfixiatul": "neasfixiat",
    "neasfixiatului": "neasfixiat",
    "neasigurata": "neasigurat",
    "neasigurată": "neasigurat",
    "neasigurate": "neasigurat",
    "neasiguratei": "neasigurat",
    "neasiguratele": "neasigurat",
    "neasiguratelor": "neasigurat",
    "neasigurați": "neasigurat",
    "neasigurații": "neasigurat",
    "neasiguraților": "neasigurat",
    "neasiguratul": "neasigurat",
    "neasiguratului": "neasigurat",
    "neasimilata": "neasimilat",
    "neasimilată": "neasimilat",
    "neasimilate": "neasimilat",
    "neasimilatei": "neasimilat",
    "neasimilatele": "neasimilat",
    "neasimilatelor": "neasimilat",
    "neasimilați": "neasimilat",
    "neasimilații": "neasimilat",
    "neasimilaților": "neasimilat",
    "neasimilatul": "neasimilat",
    "neasimilatului": "neasimilat",
    "neasistata": "neasistat",
    "neasistată": "neasistat",
    "neasistate": "neasistat",
    "neasistatei": "neasistat",
    "neasistatele": "neasistat",
    "neasistatelor": "neasistat",
    "neasistați": "neasistat",
    "neasistații": "neasistat",
    "neasistaților": "neasistat",
    "neasistatul": "neasistat",
    "neasistatului": "neasistat",
    "neasmuțita": "neasmuțit",
    "neasmuțită": "neasmuțit",
    "neasmuțite": "neasmuțit",
    "neasmuțitei": "neasmuțit",
    "neasmuțitele": "neasmuțit",
    "neasmuțitelor": "neasmuțit",
    "neasmuțiții": "neasmuțit",
    "neasmuțiților": "neasmuțit",
    "neasmuțitul": "neasmuțit",
    "neasmuțitului": "neasmuțit",
    "neasociata": "neasociat",
    "neasociată": "neasociat",
    "neasociate": "neasociat",
    "neasociatei": "neasociat",
    "neasociatele": "neasociat",
    "neasociatelor": "neasociat",
    "neasociați": "neasociat",
    "neasociații": "neasociat",
    "neasociaților": "neasociat",
    "neasociatul": "neasociat",
    "neasociatului": "neasociat",
    "neasortata": "neasortat",
    "neasortată": "neasortat",
    "neasortate": "neasortat",
    "neasortatei": "neasortat",
    "neasortatele": "neasortat",
    "neasortatelor": "neasortat",
    "neasortați": "neasortat",
    "neasortații": "neasortat",
    "neasortaților": "neasortat",
    "neasortatul": "neasortat",
    "neasortatului": "neasortat",
    "neaspirata": "neaspirat",
    "neaspirată": "neaspirat",
    "neaspirate": "neaspirat",
    "neaspiratei": "neaspirat",
    "neaspiratele": "neaspirat",
    "neaspiratelor": "neaspirat",
    "neaspirați": "neaspirat",
    "neaspirații": "neaspirat",
    "neaspiraților": "neaspirat",
    "neaspiratul": "neaspirat",
    "neaspiratului": "neaspirat",
    "neastâmpărul": "neastâmpăr",
    "neastâmpărului": "neastâmpăr",
    "neastâmpărata": "neastâmpărat",
    "neastâmpărată": "neastâmpărat",
    "neastâmpărate": "neastâmpărat",
    "neastâmpăratei": "neastâmpărat",
    "neastâmpăratele": "neastâmpărat",
    "neastâmpăratelor": "neastâmpărat",
    "neastâmpărați": "neastâmpărat",
    "neastâmpărații": "neastâmpărat",
    "neastâmpăraților": "neastâmpărat",
    "neastâmpăratul": "neastâmpărat",
    "neastâmpăratului": "neastâmpărat",
    "neașteptata": "neașteptat",
    "neașteptată": "neașteptat",
    "neașteptate": "neașteptat",
    "neașteptatei": "neașteptat",
    "neașteptatele": "neașteptat",
    "neașteptatelor": "neașteptat",
    "neașteptați": "neașteptat",
    "neașteptații": "neașteptat",
    "neașteptaților": "neașteptat",
    "neașteptatul": "neașteptat",
    "neașteptatului": "neașteptat",
    "neașternuta": "neașternut",
    "neașternutei": "neașternut",
    "neașternutele": "neașternut",
    "neașternutelor": "neașternut",
    "neașternuții": "neașternut",
    "neașternuților": "neașternut",
    "neașternutul": "neașternut",
    "neașternutului": "neașternut",
    "neașternută": "neașternutu",
    "neașternute": "neașternutu",
    "neașternuți": "neașternutu",
    "neastupata": "neastupat",
    "neastupată": "neastupat",
    "neastupate": "neastupat",
    "neastupatei": "neastupat",
    "neastupatele": "neastupat",
    "neastupatelor": "neastupat",
    "neastupați": "neastupat",
    "neastupații": "neastupat",
    "neastupaților": "neastupat",
    "neastupatul": "neastupat",
    "neastupatului": "neastupat",
    "neasumata": "neasumat",
    "neasumată": "neasumat",
    "neasumate": "neasumat",
    "neasumatei": "neasumat",
    "neasumatele": "neasumat",
    "neasumatelor": "neasumat",
    "neasumați": "neasumat",
    "neasumații": "neasumat",
    "neasumaților": "neasumat",
    "neasumatul": "neasumat",
    "neasumatului": "neasumat",
    "neasuprita": "neasuprit",
    "neasuprită": "neasuprit",
    "neasuprite": "neasuprit",
    "neasupritei": "neasuprit",
    "neasupritele": "neasuprit",
    "neasupritelor": "neasuprit",
    "neasupriți": "neasuprit",
    "neasupriții": "neasuprit",
    "neasupriților": "neasuprit",
    "neasupritul": "neasuprit",
    "neasupritului": "neasuprit",
    "neasurzita": "neasurzit",
    "neasurzită": "neasurzit",
    "neasurzite": "neasurzit",
    "neasurzitei": "neasurzit",
    "neasurzitele": "neasurzit",
    "neasurzitelor": "neasurzit",
    "neasurziți": "neasurzit",
    "neasurziții": "neasurzit",
    "neasurziților": "neasurzit",
    "neasurzitul": "neasurzit",
    "neasurzitului": "neasurzit",
    "neatacata": "neatacat",
    "neatacată": "neatacat",
    "neatacate": "neatacat",
    "neatacatei": "neatacat",
    "neatacatele": "neatacat",
    "neatacatelor": "neatacat",
    "neatacați": "neatacat",
    "neatacații": "neatacat",
    "neatacaților": "neatacat",
    "neatacatul": "neatacat",
    "neatacatului": "neatacat",
    "neatârnarea": "neatârnare",
    "neatârnări": "neatârnare",
    "neatârnării": "neatârnare",
    "neatârnările": "neatârnare",
    "neatârnărilor": "neatârnare",
    "neatârnata": "neatârnat",
    "neatârnată": "neatârnat",
    "neatârnate": "neatârnat",
    "neatârnatei": "neatârnat",
    "neatârnatele": "neatârnat",
    "neatârnatelor": "neatârnat",
    "neatârnați": "neatârnat",
    "neatârnații": "neatârnat",
    "neatârnaților": "neatârnat",
    "neatârnatul": "neatârnat",
    "neatârnatului": "neatârnat",
    "neatașata": "neatașat",
    "neatașată": "neatașat",
    "neatașate": "neatașat",
    "neatașatei": "neatașat",
    "neatașatele": "neatașat",
    "neatașatelor": "neatașat",
    "neatașați": "neatașat",
    "neatașații": "neatașat",
    "neatașaților": "neatașat",
    "neatașatul": "neatașat",
    "neatașatului": "neatașat",
    "neațâțata": "neațâțat",
    "neațâțată": "neațâțat",
    "neațâțate": "neațâțat",
    "neațâțatei": "neațâțat",
    "neațâțatele": "neațâțat",
    "neațâțatelor": "neațâțat",
    "neațâțați": "neațâțat",
    "neațâțații": "neațâțat",
    "neațâțaților": "neațâțat",
    "neațâțatului": "neațâțat",
    "neațâțiatul": "neațâțat",
    "neatenta": "neatent",
    "neatentă": "neatent",
    "neatente": "neatent",
    "neatentei": "neatent",
    "neatentele": "neatent",
    "neatentelor": "neatent",
    "neatenți": "neatent",
    "neatenții": "neatent",
    "neatenților": "neatent",
    "neatentul": "neatent",
    "neatentului": "neatent",
    "neatentata": "neatentat",
    "neatentată": "neatentat",
    "neatentate": "neatentat",
    "neatentatei": "neatentat",
    "neatentatele": "neatentat",
    "neatentatelor": "neatentat",
    "neatentați": "neatentat",
    "neatentații": "neatentat",
    "neatentaților": "neatentat",
    "neatentatul": "neatentat",
    "neatentatului": "neatentat",
    "neatenția": "neatenție",
    "neatenției": "neatenție",
    "neatenții": "neatenție",
    "neatențiile": "neatenție",
    "neatențiilor": "neatenție",
    "neatenuata": "neatenuat",
    "neatenuată": "neatenuat",
    "neatenuate": "neatenuat",
    "neatenuatei": "neatenuat",
    "neatenuatele": "neatenuat",
    "neatenuatelor": "neatenuat",
    "neatenuați": "neatenuat",
    "neatenuații": "neatenuat",
    "neatenuaților": "neatenuat",
    "neatenuatul": "neatenuat",
    "neatenuatului": "neatenuat",
    "neaterizata": "neaterizat",
    "neaterizată": "neaterizat",
    "neaterizate": "neaterizat",
    "neaterizatei": "neaterizat",
    "neaterizatele": "neaterizat",
    "neaterizatelor": "neaterizat",
    "neaterizați": "neaterizat",
    "neaterizații": "neaterizat",
    "neaterizaților": "neaterizat",
    "neaterizatul": "neaterizat",
    "neaterizatului": "neaterizat",
    "neatestata": "neatestat",
    "neatestată": "neatestat",
    "neatestate": "neatestat",
    "neatestatei": "neatestat",
    "neatestatele": "neatestat",
    "neatestatelor": "neatestat",
    "neatestați": "neatestat",
    "neatestații": "neatestat",
    "neatestaților": "neatestat",
    "neatestatul": "neatestat",
    "neatestatului": "neatestat",
    "neatinsa": "neatins",
    "neatinsă": "neatins",
    "neatinse": "neatins",
    "neatinsei": "neatins",
    "neatinsele": "neatins",
    "neatinselor": "neatins",
    "neatinși": "neatins",
    "neatinșii": "neatins",
    "neatinșilor": "neatins",
    "neatinsul": "neatins",
    "neatinsului": "neatins",
    "neaținuta": "neaținut",
    "neaținută": "neaținut",
    "neaținute": "neaținut",
    "neaținutei": "neaținut",
    "neaținutele": "neaținut",
    "neaținutelor": "neaținut",
    "neaținuți": "neaținut",
    "neaținuții": "neaținut",
    "neaținuților": "neaținut",
    "neaținutul": "neaținut",
    "neaținutului": "neaținut",
    "neațipită": "neațipit",
    "neațipite": "neațipit",
    "neațipiți": "neațipit",
    "neatrasa": "neatras",
    "neatrasă": "neatras",
    "neatrase": "neatras",
    "neatrasei": "neatras",
    "neatrasele": "neatras",
    "neatraselor": "neatras",
    "neatrași": "neatras",
    "neatrașii": "neatras",
    "neatrașilor": "neatras",
    "neatrasul": "neatras",
    "neatrasului": "neatras",
    "neatribuita": "neatribuit",
    "neatribuită": "neatribuit",
    "neatribuite": "neatribuit",
    "neatribuitei": "neatribuit",
    "neatribuitele": "neatribuit",
    "neatribuitelor": "neatribuit",
    "neatribuiți": "neatribuit",
    "neatribuiții": "neatribuit",
    "neatribuiților": "neatribuit",
    "neatribuitul": "neatribuit",
    "neatribuitului": "neatribuit",
    "neatrofiata": "neatrofiat",
    "neatrofiată": "neatrofiat",
    "neatrofiate": "neatrofiat",
    "neatrofiatei": "neatrofiat",
    "neatrofiatele": "neatrofiat",
    "neatrofiatelor": "neatrofiat",
    "neatrofiați": "neatrofiat",
    "neatrofiații": "neatrofiat",
    "neatrofiaților": "neatrofiat",
    "neatrofiatul": "neatrofiat",
    "neatrofiatului": "neatrofiat",
    "neaudiata": "neaudiat",
    "neaudiată": "neaudiat",
    "neaudiate": "neaudiat",
    "neaudiatei": "neaudiat",
    "neaudiatele": "neaudiat",
    "neaudiatelor": "neaudiat",
    "neaudiați": "neaudiat",
    "neaudiații": "neaudiat",
    "neaudiaților": "neaudiat",
    "neaudiatul": "neaudiat",
    "neaudiatului": "neaudiat",
    "neaugmentata": "neaugmentat",
    "neaugmentată": "neaugmentat",
    "neaugmentate": "neaugmentat",
    "neaugmentatei": "neaugmentat",
    "neaugmentatele": "neaugmentat",
    "neaugmentatelor": "neaugmentat",
    "neaugmentați": "neaugmentat",
    "neaugmentații": "neaugmentat",
    "neaugmentaților": "neaugmentat",
    "neaugmentatul": "neaugmentat",
    "neaugmentatului": "neaugmentat",
    "neaurita": "neaurit",
    "neaurită": "neaurit",
    "neaurite": "neaurit",
    "neauritei": "neaurit",
    "neauritele": "neaurit",
    "neauritelor": "neaurit",
    "neauriți": "neaurit",
    "neauriții": "neaurit",
    "neauriților": "neaurit",
    "neauritul": "neaurit",
    "neauritului": "neaurit",
    "neautentificata": "neautentificat",
    "neautentificată": "neautentificat",
    "neautentificate": "neautentificat",
    "neautentificatei": "neautentificat",
    "neautentificatele": "neautentificat",
    "neautentificatelor": "neautentificat",
    "neautentificați": "neautentificat",
    "neautentificații": "neautentificat",
    "neautentificaților": "neautentificat",
    "neautentificatul": "neautentificat",
    "neautentificatului": "neautentificat",
    "neautorizarea": "neautorizare",
    "neautorizări": "neautorizare",
    "neautorizării": "neautorizare",
    "neautorizările": "neautorizare",
    "neautorizata": "neautorizat",
    "neautorizată": "neautorizat",
    "neautorizate": "neautorizat",
    "neautorizatei": "neautorizat",
    "neautorizatele": "neautorizat",
    "neautorizatelor": "neautorizat",
    "neautorizați": "neautorizat",
    "neautorizații": "neautorizat",
    "neautorizaților": "neautorizat",
    "neautorizatul": "neautorizat",
    "neautorizatului": "neautorizat",
    "neauzita": "neauzit",
    "neauzită": "neauzit",
    "neauzite": "neauzit",
    "neauzitei": "neauzit",
    "neauzitele": "neauzit",
    "neauzitelor": "neauzit",
    "neauziți": "neauzit",
    "neauziții": "neauzit",
    "neauziților": "neauzit",
    "neauzitul": "neauzit",
    "neauzitului": "neauzit",
    "neavansata": "neavansat",
    "neavansată": "neavansat",
    "neavansate": "neavansat",
    "neavansatei": "neavansat",
    "neavansatele": "neavansat",
    "neavansatelor": "neavansat",
    "neavansați": "neavansat",
    "neavansații": "neavansat",
    "neavansaților": "neavansat",
    "neavansatul": "neavansat",
    "neavansatului": "neavansat",
    "neavariata": "neavariat",
    "neavariată": "neavariat",
    "neavariate": "neavariat",
    "neavariatei": "neavariat",
    "neavariatele": "neavariat",
    "neavariatelor": "neavariat",
    "neavariați": "neavariat",
    "neavariații": "neavariat",
    "neavariaților": "neavariat",
    "neavariatul": "neavariat",
    "neavariatului": "neavariat",
    "neavenita": "neavenit",
    "neavenită": "neavenit",
    "neavenite": "neavenit",
    "neavenitei": "neavenit",
    "neavenitele": "neavenit",
    "neavenitelor": "neavenit",
    "neaveniți": "neavenit",
    "neaveniții": "neavenit",
    "neaveniților": "neavenit",
    "neavenitul": "neavenit",
    "neavenitului": "neavenit",
    "neaventurata": "neaventurat",
    "neaventurată": "neaventurat",
    "neaventurate": "neaventurat",
    "neaventuratei": "neaventurat",
    "neaventuratele": "neaventurat",
    "neaventuratelor": "neaventurat",
    "neaventurați": "neaventurat",
    "neaventurații": "neaventurat",
    "neaventuraților": "neaventurat",
    "neaventuratul": "neaventurat",
    "neaventuratului": "neaventurat",
    "neavertizata": "neavertizat",
    "neavertizată": "neavertizat",
    "neavertizate": "neavertizat",
    "neavertizatei": "neavertizat",
    "neavertizatele": "neavertizat",
    "neavertizatelor": "neavertizat",
    "neavertizați": "neavertizat",
    "neavertizații": "neavertizat",
    "neavertizaților": "neavertizat",
    "neavertizatul": "neavertizat",
    "neavertizatului": "neavertizat",
    "neavizata": "neavizat",
    "neavizată": "neavizat",
    "neavizate": "neavizat",
    "neavizatei": "neavizat",
    "neavizatele": "neavizat",
    "neavizatelor": "neavizat",
    "neavizați": "neavizat",
    "neavizații": "neavizat",
    "neavizaților": "neavizat",
    "neavizatul": "neavizat",
    "neavizatului": "neavizat",
    "neavortata": "neavortat",
    "neavortată": "neavortat",
    "neavortate": "neavortat",
    "neavortatei": "neavortat",
    "neavortatele": "neavortat",
    "neavortatelor": "neavortat",
    "neavortați": "neavortat",
    "neavortații": "neavortat",
    "neavortaților": "neavortat",
    "neavortatul": "neavortat",
    "neavortatului": "neavortat",
    "neavuta": "neavut",
    "neavută": "neavut",
    "neavute": "neavut",
    "neavutei": "neavut",
    "neavutele": "neavut",
    "neavutelor": "neavut",
    "neavuți": "neavut",
    "neavuții": "neavut",
    "neavuților": "neavut",
    "neavutul": "neavut",
    "neavutului": "neavut",
    "neaxata": "neaxat",
    "neaxată": "neaxat",
    "neaxate": "neaxat",
    "neaxatei": "neaxat",
    "neaxatele": "neaxat",
    "neaxatelor": "neaxat",
    "neaxați": "neaxat",
    "neaxații": "neaxat",
    "neaxaților": "neaxat",
    "neaxatul": "neaxat",
    "neaxatului": "neaxat",
    "neazvârlita": "neazvârlit",
    "neazvârlită": "neazvârlit",
    "neazvârlite": "neazvârlit",
    "neazvârlitei": "neazvârlit",
    "neazvârlitele": "neazvârlit",
    "neazvârlitelor": "neazvârlit",
    "neazvârliți": "neazvârlit",
    "neazvârliții": "neazvârlit",
    "neazvârliților": "neazvârlit",
    "neazvârlitul": "neazvârlit",
    "neazvârlitului": "neazvârlit",
    "nebadijonata": "nebadijonat",
    "nebadijonată": "nebadijonat",
    "nebadijonate": "nebadijonat",
    "nebadijonatei": "nebadijonat",
    "nebadijonatele": "nebadijonat",
    "nebadijonatelor": "nebadijonat",
    "nebadijonați": "nebadijonat",
    "nebadijonații": "nebadijonat",
    "nebadijonaților": "nebadijonat",
    "nebadijonatul": "nebadijonat",
    "nebadijonatului": "nebadijonat",
    "nebăgarea": "nebăgare",
    "nebăgări": "nebăgare",
    "nebăgării": "nebăgare",
    "nebăgările": "nebăgare",
    "nebăgărilor": "nebăgare",
    "nebăgata": "nebăgat",
    "nebăgată": "nebăgat",
    "nebăgate": "nebăgat",
    "nebăgatei": "nebăgat",
    "nebăgatele": "nebăgat",
    "nebăgatelor": "nebăgat",
    "nebăgați": "nebăgat",
    "nebăgații": "nebăgat",
    "nebăgaților": "nebăgat",
    "nebăgatul": "nebăgat",
    "nebăgatului": "nebăgat",
    "nebagatelizata": "nebagatelizat",
    "nebagatelizată": "nebagatelizat",
    "nebagatelizate": "nebagatelizat",
    "nebagatelizatei": "nebagatelizat",
    "nebagatelizatele": "nebagatelizat",
    "nebagatelizatelor": "nebagatelizat",
    "nebagatelizați": "nebagatelizat",
    "nebagatelizații": "nebagatelizat",
    "nebagatelizaților": "nebagatelizat",
    "nebagatelizatul": "nebagatelizat",
    "nebagatelizatului": "nebagatelizat",
    "nebălăbănita": "nebălăbănit",
    "nebălăbănită": "nebălăbănit",
    "nebălăbănite": "nebălăbănit",
    "nebălăbănitei": "nebălăbănit",
    "nebălăbănitele": "nebălăbănit",
    "nebălăbănitelor": "nebălăbănit",
    "nebălăbăniți": "nebălăbănit",
    "nebălăbăniții": "nebălăbănit",
    "nebălăbăniților": "nebălăbănit",
    "nebălăbănitul": "nebălăbănit",
    "nebălăbănitului": "nebălăbănit",
    "nebălăcita": "nebălăcit",
    "nebălăcită": "nebălăcit",
    "nebălăcite": "nebălăcit",
    "nebălăcitei": "nebălăcit",
    "nebălăcitele": "nebălăcit",
    "nebălăcitelor": "nebălăcit",
    "nebălăciți": "nebălăcit",
    "nebălăciții": "nebălăcit",
    "nebălăciților": "nebălăcit",
    "nebălăcitul": "nebălăcit",
    "nebălăcitului": "nebălăcit",
    "nebălmăjita": "nebălmăjit",
    "nebălmăjită": "nebălmăjit",
    "nebălmăjite": "nebălmăjit",
    "nebălmăjitei": "nebălmăjit",
    "nebălmăjitele": "nebălmăjit",
    "nebălmăjitelor": "nebălmăjit",
    "nebălmăjiți": "nebălmăjit",
    "nebălmăjiții": "nebălmăjit",
    "nebălmăjiților": "nebălmăjit",
    "nebălmăjitul": "nebălmăjit",
    "nebălmăjitului": "nebălmăjit",
    "nebalonata": "nebalonat",
    "nebalonată": "nebalonat",
    "nebalonate": "nebalonat",
    "nebalonatei": "nebalonat",
    "nebalonatele": "nebalonat",
    "nebalonatelor": "nebalonat",
    "nebalonați": "nebalonat",
    "nebalonații": "nebalonat",
    "nebalonaților": "nebalonat",
    "nebalonatul": "nebalonat",
    "nebalonatului": "nebalonat",
    "nebandajata": "nebandajat",
    "nebandajată": "nebandajat",
    "nebandajate": "nebandajat",
    "nebandajatei": "nebandajat",
    "nebandajatele": "nebandajat",
    "nebandajatelor": "nebandajat",
    "nebandajați": "nebandajat",
    "nebandajații": "nebandajat",
    "nebandajaților": "nebandajat",
    "nebandajatul": "nebandajat",
    "nebandajatului": "nebandajat",
    "nebântuita": "nebântuit",
    "nebântuită": "nebântuit",
    "nebântuite": "nebântuit",
    "nebântuitei": "nebântuit",
    "nebântuitele": "nebântuit",
    "nebântuitelor": "nebântuit",
    "nebântuiți": "nebântuit",
    "nebântuiții": "nebântuit",
    "nebântuiților": "nebântuit",
    "nebântuitul": "nebântuit",
    "nebântuitului": "nebântuit",
    "nebănuita": "nebănuit",
    "nebănuită": "nebănuit",
    "nebănuite": "nebănuit",
    "nebănuitei": "nebănuit",
    "nebănuitele": "nebănuit",
    "nebănuitelor": "nebănuit",
    "nebănuiți": "nebănuit",
    "nebănuiții": "nebănuit",
    "nebănuiților": "nebănuit",
    "nebănuitul": "nebănuit",
    "nebănuitului": "nebănuit",
    "nebarata": "nebarat",
    "nebarată": "nebarat",
    "nebarate": "nebarat",
    "nebaratei": "nebarat",
    "nebaratele": "nebarat",
    "nebaratelor": "nebarat",
    "nebarați": "nebarat",
    "nebarații": "nebarat",
    "nebaraților": "nebarat",
    "nebaratul": "nebarat",
    "nebaratului": "nebarat",
    "nebărbierita": "nebărbierit",
    "nebărbierită": "nebărbierit",
    "nebărbierite": "nebărbierit",
    "nebărbieritei": "nebărbierit",
    "nebărbieritele": "nebărbierit",
    "nebărbieritelor": "nebărbierit",
    "nebărbieriți": "nebărbierit",
    "nebărbieriții": "nebărbierit",
    "nebărbieriților": "nebărbierit",
    "nebărbieritul": "nebărbierit",
    "nebărbieritului": "nebărbierit",
    "nebâțâita": "nebâțâit",
    "nebâțâită": "nebâțâit",
    "nebâțâite": "nebâțâit",
    "nebâțâitei": "nebâțâit",
    "nebâțâitele": "nebâțâit",
    "nebâțâitelor": "nebâțâit",
    "nebâțâiți": "nebâțâit",
    "nebâțâiții": "nebâțâit",
    "nebâțâiților": "nebâțâit",
    "nebâțâitul": "nebâțâit",
    "nebâțâitului": "nebâțâit",
    "nebatjocorita": "nebatjocorit",
    "nebatjocorită": "nebatjocorit",
    "nebatjocorite": "nebatjocorit",
    "nebatjocoritei": "nebatjocorit",
    "nebatjocoritele": "nebatjocorit",
    "nebatjocoritelor": "nebatjocorit",
    "nebatjocoriți": "nebatjocorit",
    "nebatjocoriții": "nebatjocorit",
    "nebatjocoriților": "nebatjocorit",
    "nebatjocoritul": "nebatjocorit",
    "nebatjocoritului": "nebatjocorit",
    "nebătuta": "nebătut",
    "nebătută": "nebătut",
    "nebătute": "nebătut",
    "nebătutei": "nebătut",
    "nebătutele": "nebătut",
    "nebătutelor": "nebătut",
    "nebătuți": "nebătut",
    "nebătuții": "nebătut",
    "nebătuților": "nebătut",
    "nebătutul": "nebătut",
    "nebătutului": "nebătut",
    "nebăuta": "nebăut",
    "nebăută": "nebăut",
    "nebăute": "nebăut",
    "nebăutei": "nebăut",
    "nebăutele": "nebăut",
    "nebăutelor": "nebăut",
    "nebăuți": "nebăut",
    "nebăuții": "nebăut",
    "nebăuților": "nebăut",
    "nebăutul": "nebăut",
    "nebăutului": "nebăut",
    "nebâzâita": "nebâzâit",
    "nebâzâită": "nebâzâit",
    "nebâzâite": "nebâzâit",
    "nebâzâitei": "nebâzâit",
    "nebâzâitele": "nebâzâit",
    "nebâzâitelor": "nebâzâit",
    "nebâzâiți": "nebâzâit",
    "nebâzâiții": "nebâzâit",
    "nebâzâiților": "nebâzâit",
    "nebâzâitul": "nebâzâit",
    "nebâzâitului": "nebâzâit",
    "nebazata": "nebazat",
    "nebazată": "nebazat",
    "nebazate": "nebazat",
    "nebazatei": "nebazat",
    "nebazatele": "nebazat",
    "nebazatelor": "nebazat",
    "nebazați": "nebazat",
    "nebazații": "nebazat",
    "nebazaților": "nebazat",
    "nebazatul": "nebazat",
    "nebazatului": "nebazat",
    "nebehăita": "nebehăit",
    "nebehăită": "nebehăit",
    "nebehăite": "nebehăit",
    "nebehăitei": "nebehăit",
    "nebehăitele": "nebehăit",
    "nebehăitelor": "nebehăit",
    "nebehăiți": "nebehăit",
    "nebehăiții": "nebehăit",
    "nebehăiților": "nebehăit",
    "nebehăitul": "nebehăit",
    "nebehăitului": "nebehăit",
    "nebeligeranta": "nebeligerant",
    "nebeligerantă": "nebeligerant",
    "nebeligerante": "nebeligerant",
    "nebeligerantei": "nebeligerant",
    "nebeligerantele": "nebeligerant",
    "nebeligerantelor": "nebeligerant",
    "nebeligeranți": "nebeligerant",
    "nebeligeranții": "nebeligerant",
    "nebeligeranților": "nebeligerant",
    "nebeligerantul": "nebeligerant",
    "nebeligerantului": "nebeligerant",
    "nebeligeranța": "nebeligeranță",
    "nebeligeranțe": "nebeligeranță",
    "nebeligeranței": "nebeligeranță",
    "nebeligeranțele": "nebeligeranță",
    "nebeligeranțelor": "nebeligeranță",
    "nebeneficiata": "nebeneficiat",
    "nebeneficiată": "nebeneficiat",
    "nebeneficiate": "nebeneficiat",
    "nebeneficiatei": "nebeneficiat",
    "nebeneficiatele": "nebeneficiat",
    "nebeneficiatelor": "nebeneficiat",
    "nebeneficiați": "nebeneficiat",
    "nebeneficiații": "nebeneficiat",
    "nebeneficiaților": "nebeneficiat",
    "nebeneficiatul": "nebeneficiat",
    "nebeneficiatului": "nebeneficiat",
    "nebiciuita": "nebiciuit",
    "nebiciuită": "nebiciuit",
    "nebiciuite": "nebiciuit",
    "nebiciuitei": "nebiciuit",
    "nebiciuitele": "nebiciuit",
    "nebiciuitelor": "nebiciuit",
    "nebiciuiți": "nebiciuit",
    "nebiciuiții": "nebiciuit",
    "nebiciuiților": "nebiciuit",
    "nebiciuitul": "nebiciuit",
    "nebiciuitului": "nebiciuit",
    "nebifata": "nebifat",
    "nebifată": "nebifat",
    "nebifate": "nebifat",
    "nebifatei": "nebifat",
    "nebifatele": "nebifat",
    "nebifatelor": "nebifat",
    "nebifați": "nebifat",
    "nebifații": "nebifat",
    "nebifaților": "nebifat",
    "nebifatul": "nebifat",
    "nebifatului": "nebifat",
    "nebifurcata": "nebifurcat",
    "nebifurcată": "nebifurcat",
    "nebifurcate": "nebifurcat",
    "nebifurcatei": "nebifurcat",
    "nebifurcatele": "nebifurcat",
    "nebifurcatelor": "nebifurcat",
    "nebifurcați": "nebifurcat",
    "nebifurcații": "nebifurcat",
    "nebifurcaților": "nebifurcat",
    "nebifurcatul": "nebifurcat",
    "nebifurcatului": "nebifurcat",
    "nebinemeritata": "nebinemeritat",
    "nebinemeritată": "nebinemeritat",
    "nebinemeritate": "nebinemeritat",
    "nebinemeritatei": "nebinemeritat",
    "nebinemeritatele": "nebinemeritat",
    "nebinemeritatelor": "nebinemeritat",
    "nebinemeritați": "nebinemeritat",
    "nebinemeritații": "nebinemeritat",
    "nebinemeritaților": "nebinemeritat",
    "nebinemeritatul": "nebinemeritat",
    "nebinemeritatului": "nebinemeritat",
    "nebinevoita": "nebinevoit",
    "nebinevoită": "nebinevoit",
    "nebinevoite": "nebinevoit",
    "nebinevoitei": "nebinevoit",
    "nebinevoitele": "nebinevoit",
    "nebinevoitelor": "nebinevoit",
    "nebinevoiți": "nebinevoit",
    "nebinevoiții": "nebinevoit",
    "nebinevoiților": "nebinevoit",
    "nebinevoitul": "nebinevoit",
    "nebinevoitului": "nebinevoit",
    "nebiruita": "nebiruit",
    "nebiruită": "nebiruit",
    "nebiruite": "nebiruit",
    "nebiruitei": "nebiruit",
    "nebiruitele": "nebiruit",
    "nebiruitelor": "nebiruit",
    "nebiruiți": "nebiruit",
    "nebiruiții": "nebiruit",
    "nebiruiților": "nebiruit",
    "nebiruitul": "nebiruit",
    "nebiruitului": "nebiruit",
    "nebisata": "nebisat",
    "nebisată": "nebisat",
    "nebisate": "nebisat",
    "nebisatei": "nebisat",
    "nebisatele": "nebisat",
    "nebisatelor": "nebisat",
    "nebisați": "nebisat",
    "nebisații": "nebisat",
    "nebisaților": "nebisat",
    "nebisatul": "nebisat",
    "nebisatului": "nebisat",
    "nebizuita": "nebizuit",
    "nebizuită": "nebizuit",
    "nebizuite": "nebizuit",
    "nebizuitei": "nebizuit",
    "nebizuitele": "nebizuit",
    "nebizuitelor": "nebizuit",
    "nebizuiți": "nebizuit",
    "nebizuiții": "nebizuit",
    "nebizuiților": "nebizuit",
    "nebizuitul": "nebizuit",
    "nebizuitului": "nebizuit",
    "neblamata": "neblamat",
    "neblamată": "neblamat",
    "neblamate": "neblamat",
    "neblamatei": "neblamat",
    "neblamatele": "neblamat",
    "neblamatelor": "neblamat",
    "neblamați": "neblamat",
    "neblamații": "neblamat",
    "neblamaților": "neblamat",
    "neblamatul": "neblamat",
    "neblamatului": "neblamat",
    "neblazata": "neblazat",
    "neblazată": "neblazat",
    "neblazate": "neblazat",
    "neblazatei": "neblazat",
    "neblazatele": "neblazat",
    "neblazatelor": "neblazat",
    "neblazați": "neblazat",
    "neblazații": "neblazat",
    "neblazaților": "neblazat",
    "neblazatul": "neblazat",
    "neblazatului": "neblazat",
    "nebleotocărita": "nebleotocărit",
    "nebleotocărită": "nebleotocărit",
    "nebleotocărite": "nebleotocărit",
    "nebleotocăritei": "nebleotocărit",
    "nebleotocăritele": "nebleotocărit",
    "nebleotocăritelor": "nebleotocărit",
    "nebleotocăriți": "nebleotocărit",
    "nebleotocăriții": "nebleotocărit",
    "nebleotocăriților": "nebleotocărit",
    "nebleotocăritul": "nebleotocărit",
    "nebleotocăritului": "nebleotocărit",
    "neblocata": "neblocat",
    "neblocată": "neblocat",
    "neblocate": "neblocat",
    "neblocatei": "neblocat",
    "neblocatele": "neblocat",
    "neblocatelor": "neblocat",
    "neblocați": "neblocat",
    "neblocații": "neblocat",
    "neblocaților": "neblocat",
    "neblocatul": "neblocat",
    "neblocatului": "neblocat",
    "nebobinata": "nebobinat",
    "nebobinată": "nebobinat",
    "nebobinate": "nebobinat",
    "nebobinatei": "nebobinat",
    "nebobinatele": "nebobinat",
    "nebobinatelor": "nebobinat",
    "nebobinați": "nebobinat",
    "nebobinații": "nebobinat",
    "nebobinaților": "nebobinat",
    "nebobinatul": "nebobinat",
    "nebobinatului": "nebobinat",
    "nebodogănita": "nebodogănit",
    "nebodogănită": "nebodogănit",
    "nebodogănite": "nebodogănit",
    "nebodogănitei": "nebodogănit",
    "nebodogănitele": "nebodogănit",
    "nebodogănitelor": "nebodogănit",
    "nebodogăniți": "nebodogănit",
    "nebodogăniții": "nebodogănit",
    "nebodogăniților": "nebodogănit",
    "nebodogănitul": "nebodogănit",
    "nebodogănitului": "nebodogănit",
    "neboicotata": "neboicotat",
    "neboicotată": "neboicotat",
    "neboicotate": "neboicotat",
    "neboicotatei": "neboicotat",
    "neboicotatele": "neboicotat",
    "neboicotatelor": "neboicotat",
    "neboicotați": "neboicotat",
    "neboicotații": "neboicotat",
    "neboicotaților": "neboicotat",
    "neboicotatul": "neboicotat",
    "neboicotatului": "neboicotat",
    "nebolborosita": "nebolborosit",
    "nebolborosită": "nebolborosit",
    "nebolborosite": "nebolborosit",
    "nebolborositei": "nebolborosit",
    "nebolborositele": "nebolborosit",
    "nebolborositelor": "nebolborosit",
    "nebolborosiți": "nebolborosit",
    "nebolborosiții": "nebolborosit",
    "nebolborosiților": "nebolborosit",
    "nebolborositul": "nebolborosit",
    "nebolborositului": "nebolborosit",
    "nebombardata": "nebombardat",
    "nebombardată": "nebombardat",
    "nebombardate": "nebombardat",
    "nebombardatei": "nebombardat",
    "nebombardatele": "nebombardat",
    "nebombardatelor": "nebombardat",
    "nebombardați": "nebombardat",
    "nebombardații": "nebombardat",
    "nebombardaților": "nebombardat",
    "nebombardatul": "nebombardat",
    "nebombardatului": "nebombardat",
    "nebombata": "nebombat",
    "nebombată": "nebombat",
    "nebombate": "nebombat",
    "nebombatei": "nebombat",
    "nebombatele": "nebombat",
    "nebombatelor": "nebombat",
    "nebombați": "nebombat",
    "nebombații": "nebombat",
    "nebombaților": "nebombat",
    "nebombatul": "nebombat",
    "nebombatului": "nebombat",
    "nebonificata": "nebonificat",
    "nebonificată": "nebonificat",
    "nebonificate": "nebonificat",
    "nebonificatei": "nebonificat",
    "nebonificatele": "nebonificat",
    "nebonificatelor": "nebonificat",
    "nebonificați": "nebonificat",
    "nebonificații": "nebonificat",
    "nebonificaților": "nebonificat",
    "nebonificatul": "nebonificat",
    "nebonificatului": "nebonificat",
    "neboscorodita": "neboscorodit",
    "neboscorodită": "neboscorodit",
    "neboscorodite": "neboscorodit",
    "neboscoroditei": "neboscorodit",
    "neboscoroditele": "neboscorodit",
    "neboscoroditelor": "neboscorodit",
    "neboscorodiți": "neboscorodit",
    "neboscorodiții": "neboscorodit",
    "neboscorodiților": "neboscorodit",
    "neboscoroditul": "neboscorodit",
    "neboscoroditului": "neboscorodit",
    "neboxata": "neboxat",
    "neboxată": "neboxat",
    "neboxate": "neboxat",
    "neboxatei": "neboxat",
    "neboxatele": "neboxat",
    "neboxatelor": "neboxat",
    "neboxați": "neboxat",
    "neboxații": "neboxat",
    "neboxaților": "neboxat",
    "neboxatul": "neboxat",
    "neboxatului": "neboxat",
    "nebrăzdata": "nebrăzdat",
    "nebrăzdată": "nebrăzdat",
    "nebrăzdate": "nebrăzdat",
    "nebrăzdatei": "nebrăzdat",
    "nebrăzdatele": "nebrăzdat",
    "nebrăzdatelor": "nebrăzdat",
    "nebrăzdați": "nebrăzdat",
    "nebrăzdații": "nebrăzdat",
    "nebrăzdaților": "nebrăzdat",
    "nebrăzdatul": "nebrăzdat",
    "nebrăzdatului": "nebrăzdat",
    "nebrevetata": "nebrevetat",
    "nebrevetată": "nebrevetat",
    "nebrevetate": "nebrevetat",
    "nebrevetatei": "nebrevetat",
    "nebrevetatele": "nebrevetat",
    "nebrevetatelor": "nebrevetat",
    "nebrevetați": "nebrevetat",
    "nebrevetații": "nebrevetat",
    "nebrevetaților": "nebrevetat",
    "nebrevetatul": "nebrevetat",
    "nebrevetatului": "nebrevetat",
    "nebrodată": "nebrodat",
    "nebrodate": "nebrodat",
    "nebrodați": "nebrodat",
    "nebroșata": "nebroșat",
    "nebroșată": "nebroșat",
    "nebroșate": "nebroșat",
    "nebroșatei": "nebroșat",
    "nebroșatele": "nebroșat",
    "nebroșatelor": "nebroșat",
    "nebroșați": "nebroșat",
    "nebroșații": "nebroșat",
    "nebroșaților": "nebroșat",
    "nebroșatul": "nebroșat",
    "nebroșatului": "nebroșat",
    "nebruftuluita": "nebruftuluit",
    "nebruftuluită": "nebruftuluit",
    "nebruftuluite": "nebruftuluit",
    "nebruftuluitei": "nebruftuluit",
    "nebruftuluitele": "nebruftuluit",
    "nebruftuluitelor": "nebruftuluit",
    "nebruftuluiți": "nebruftuluit",
    "nebruftuluiții": "nebruftuluit",
    "nebruftuluiților": "nebruftuluit",
    "nebruftuluitul": "nebruftuluit",
    "nebruftuluitului": "nebruftuluit",
    "nebruiata": "nebruiat",
    "nebruiată": "nebruiat",
    "nebruiate": "nebruiat",
    "nebruiatei": "nebruiat",
    "nebruiatele": "nebruiat",
    "nebruiatelor": "nebruiat",
    "nebruiați": "nebruiat",
    "nebruiații": "nebruiat",
    "nebruiaților": "nebruiat",
    "nebruiatul": "nebruiat",
    "nebruiatului": "nebruiat",
    "nebruscata": "nebruscat",
    "nebruscată": "nebruscat",
    "nebruscate": "nebruscat",
    "nebruscatei": "nebruscat",
    "nebruscatele": "nebruscat",
    "nebruscatelor": "nebruscat",
    "nebruscați": "nebruscat",
    "nebruscații": "nebruscat",
    "nebruscaților": "nebruscat",
    "nebruscatul": "nebruscat",
    "nebruscatului": "nebruscat",
    "nebubuita": "nebubuit",
    "nebubuită": "nebubuit",
    "nebubuite": "nebubuit",
    "nebubuitei": "nebubuit",
    "nebubuitele": "nebubuit",
    "nebubuitelor": "nebubuit",
    "nebubuiți": "nebubuit",
    "nebubuiții": "nebubuit",
    "nebubuiților": "nebubuit",
    "nebubuitul": "nebubuit",
    "nebubuitului": "nebubuit",
    "nebuciumata": "nebuciumat",
    "nebuciumată": "nebuciumat",
    "nebuciumate": "nebuciumat",
    "nebuciumatei": "nebuciumat",
    "nebuciumatele": "nebuciumat",
    "nebuciumatelor": "nebuciumat",
    "nebuciumați": "nebuciumat",
    "nebuciumații": "nebuciumat",
    "nebuciumaților": "nebuciumat",
    "nebuciumatul": "nebuciumat",
    "nebuciumatului": "nebuciumat",
    "nebucurata": "nebucurat",
    "nebucurată": "nebucurat",
    "nebucurate": "nebucurat",
    "nebucuratei": "nebucurat",
    "nebucuratele": "nebucurat",
    "nebucuratelor": "nebucurat",
    "nebucurați": "nebucurat",
    "nebucurații": "nebucurat",
    "nebucuraților": "nebucurat",
    "nebucuratul": "nebucurat",
    "nebucuratului": "nebucurat",
    "nebufnita": "nebufnit",
    "nebufnită": "nebufnit",
    "nebufnite": "nebufnit",
    "nebufnitei": "nebufnit",
    "nebufnitele": "nebufnit",
    "nebufnitelor": "nebufnit",
    "nebufniți": "nebufnit",
    "nebufniții": "nebufnit",
    "nebufniților": "nebufnit",
    "nebufnitul": "nebufnit",
    "nebufnitului": "nebufnit",
    "nebuhăita": "nebuhăit",
    "nebuhăită": "nebuhăit",
    "nebuhăite": "nebuhăit",
    "nebuhăitei": "nebuhăit",
    "nebuhăitele": "nebuhăit",
    "nebuhăitelor": "nebuhăit",
    "nebuhăiți": "nebuhăit",
    "nebuhăiții": "nebuhăit",
    "nebuhăiților": "nebuhăit",
    "nebuhăitul": "nebuhăit",
    "nebuhăitului": "nebuhăit",
    "nebuimăcita": "nebuimăcit",
    "nebuimăcită": "nebuimăcit",
    "nebuimăcite": "nebuimăcit",
    "nebuimăcitei": "nebuimăcit",
    "nebuimăcitele": "nebuimăcit",
    "nebuimăcitelor": "nebuimăcit",
    "nebuimăciți": "nebuimăcit",
    "nebuimăciții": "nebuimăcit",
    "nebuimăciților": "nebuimăcit",
    "nebuimăcitul": "nebuimăcit",
    "nebuimăcitului": "nebuimăcit",
    "nebulara": "nebular",
    "nebulară": "nebular",
    "nebulare": "nebular",
    "nebularei": "nebular",
    "nebularele": "nebular",
    "nebularelor": "nebular",
    "nebulari": "nebular",
    "nebularii": "nebular",
    "nebularilor": "nebular",
    "nebularul": "nebular",
    "nebularului": "nebular",
    "nebulbucata": "nebulbucat",
    "nebulbucată": "nebulbucat",
    "nebulbucate": "nebulbucat",
    "nebulbucatei": "nebulbucat",
    "nebulbucatele": "nebulbucat",
    "nebulbucatelor": "nebulbucat",
    "nebulbucați": "nebulbucat",
    "nebulbucații": "nebulbucat",
    "nebulbucaților": "nebulbucat",
    "nebulbucatul": "nebulbucat",
    "nebulbucatului": "nebulbucat",
    "nebuloasa": "nebulos",
    "nebuloasă": "nebulos",
    "nebuloase": "nebulos",
    "nebuloasei": "nebulos",
    "nebuloasele": "nebulos",
    "nebuloaselor": "nebulos",
    "nebuloși": "nebulos",
    "nebuloșii": "nebulos",
    "nebuloșilor": "nebulos",
    "nebulosul": "nebulos",
    "nebulosului": "nebulos",
    "nebulozitatea": "nebulozitate",
    "nebulozități": "nebulozitate",
    "nebulozității": "nebulozitate",
    "nebulozitățile": "nebulozitate",
    "nebulozităților": "nebulozitate",
    "nebuna": "nebun",
    "nebună": "nebun",
    "nebune": "nebun",
    "nebunei": "nebun",
    "nebunele": "nebun",
    "nebunelor": "nebun",
    "nebuni": "nebun",
    "nebunii": "nebun",
    "nebunilor": "nebun",
    "nebunul": "nebun",
    "nebunului": "nebun",
    "nebuna": "nebună",
    "nebune": "nebună",
    "nebunei": "nebună",
    "nebunele": "nebună",
    "nebunelor": "nebună",
    "nebunarița": "nebunariță",
    "nebunarițe": "nebunariță",
    "nebunariței": "nebunariță",
    "nebunarițele": "nebunariță",
    "nebunarițelor": "nebunariță",
    "nebunatica": "nebunatic",
    "nebunatică": "nebunatic",
    "nebunatice": "nebunatic",
    "nebunaticei": "nebunatic",
    "nebunaticele": "nebunatic",
    "nebunaticelor": "nebunatic",
    "nebunatici": "nebunatic",
    "nebunaticii": "nebunatic",
    "nebunaticilor": "nebunatic",
    "nebunaticul": "nebunatic",
    "nebunaticului": "nebunatic",
    "nebuneala": "nebuneală",
    "nebuneli": "nebuneală",
    "nebunelii": "nebuneală",
    "nebunelilor": "nebuneală",
    "nebuneasca": "nebunesc",
    "nebunească": "nebunesc",
    "nebunescul": "nebunesc",
    "nebunescului": "nebunesc",
    "nebunești": "nebunesc",
    "nebuneștii": "nebunesc",
    "nebuneștile": "nebunesc",
    "nebuneștilor": "nebunesc",
    "nebunia": "nebunie",
    "nebuniei": "nebunie",
    "nebunii": "nebunie",
    "nebuniile": "nebunie",
    "nebuniilor": "nebunie",
    "neburdușita": "neburdușit",
    "neburdușită": "neburdușit",
    "neburdușite": "neburdușit",
    "neburdușitei": "neburdușit",
    "neburdușitele": "neburdușit",
    "neburdușitelor": "neburdușit",
    "neburdușiți": "neburdușit",
    "neburdușiții": "neburdușit",
    "neburdușiților": "neburdușit",
    "neburdușitul": "neburdușit",
    "neburdușitului": "neburdușit",
    "neburnițata": "neburnițat",
    "neburnițată": "neburnițat",
    "neburnițate": "neburnițat",
    "neburnițatei": "neburnițat",
    "neburnițatele": "neburnițat",
    "neburnițatelor": "neburnițat",
    "neburnițați": "neburnițat",
    "neburnițații": "neburnițat",
    "neburnițaților": "neburnițat",
    "neburnițatul": "neburnițat",
    "neburnițatului": "neburnițat",
    "neburzuluita": "neburzuluit",
    "neburzuluită": "neburzuluit",
    "neburzuluite": "neburzuluit",
    "neburzuluitei": "neburzuluit",
    "neburzuluitele": "neburzuluit",
    "neburzuluitelor": "neburzuluit",
    "neburzuluiți": "neburzuluit",
    "neburzuluiții": "neburzuluit",
    "neburzuluiților": "neburzuluit",
    "neburzuluitul": "neburzuluit",
    "neburzuluitului": "neburzuluit",
    "nebușita": "nebușit",
    "nebușită": "nebușit",
    "nebușite": "nebușit",
    "nebușitei": "nebușit",
    "nebușitele": "nebușit",
    "nebușitelor": "nebușit",
    "nebușiți": "nebușit",
    "nebușiții": "nebușit",
    "nebușiților": "nebușit",
    "nebușitul": "nebușit",
    "nebușitului": "nebușit",
    "necabrată": "necabrat",
    "necabrate": "necabrat",
    "necabrați": "necabrat",
    "necăciulită": "necăciulit",
    "necăciulite": "necăciulit",
    "necăciuliți": "necăciulit",
    "necadastrată": "necadastrat",
    "necadastrate": "necadastrat",
    "necadastrați": "necadastrat",
    "necădelnițată": "necădelnițat",
    "necădelnițate": "necădelnițat",
    "necădelnițați": "necădelnițat",
    "necadențata": "necadențat",
    "necadențată": "necadențat",
    "necadențate": "necadențat",
    "necadențatei": "necadențat",
    "necadențatele": "necadențat",
    "necadențatelor": "necadențat",
    "necadențați": "necadențat",
    "necadențații": "necadențat",
    "necadențaților": "necadențat",
    "necadențatul": "necadențat",
    "necadențatului": "necadențat",
    "necadmiată": "necadmiat",
    "necadmiate": "necadmiat",
    "necadmiați": "necadmiat",
    "necadrată": "necadrat",
    "necadrate": "necadrat",
    "necadrați": "necadrat",
    "necăinată": "necăinat",
    "necăinate": "necăinat",
    "necăinați": "necăinat",
    "necăită": "necăit",
    "necăite": "necăit",
    "necăiți": "necăit",
    "necăjea": "necăji",
    "necăjeai": "necăji",
    "necăjeam": "necăji",
    "necăjească": "necăji",
    "necăjeați": "necăji",
    "necăjeau": "necăji",
    "necăjesc": "necăji",
    "necăjește": "necăji",
    "necăjești": "necăji",
    "necăjii": "necăji",
    "necăjim": "necăji",
    "necăjind": "necăji",
    "necăjindu": "necăji",
    "necăjiră": "necăji",
    "necăjirăm": "necăji",
    "necăjirăți": "necăji",
    "necăjise": "necăji",
    "necăjisem": "necăji",
    "necăjiseră": "necăji",
    "necăjiserăm": "necăji",
    "necăjiserăți": "necăji",
    "necăjiseși": "necăji",
    "necăjiși": "necăji",
    "necăjit": "necăji",
    "necăjiți": "necăji",
    "nemainecăjindu": "necăji",
    "nenecăjindu": "necăji",
    "necăjita": "necăjit",
    "necăjită": "necăjit",
    "necăjite": "necăjit",
    "necăjitei": "necăjit",
    "necăjitele": "necăjit",
    "necăjitelor": "necăjit",
    "necăjiți": "necăjit",
    "necăjiții": "necăjit",
    "necăjiților": "necăjit",
    "necăjitul": "necăjit",
    "necăjitului": "necăjit",
    "necălăfătuită": "necălăfătuit",
    "necălăfătuite": "necălăfătuit",
    "necălăfătuiți": "necălăfătuit",
    "necălărită": "necălărit",
    "necălărite": "necălărit",
    "necălăriți": "necălărit",
    "necalată": "necalat",
    "necalate": "necalat",
    "necalați": "necalat",
    "necălătorita": "necălătorit",
    "necălătorită": "necălătorit",
    "necălătorite": "necălătorit",
    "necălătoritei": "necălătorit",
    "necălătoritele": "necălătorit",
    "necălătoritelor": "necălătorit",
    "necălătoriți": "necălătorit",
    "necălătoriții": "necălătorit",
    "necălătoriților": "necălătorit",
    "necălătoritul": "necălătorit",
    "necălătoritului": "necălătorit",
    "necălăuzită": "necălăuzit",
    "necălăuzite": "necălăuzit",
    "necălăuziți": "necălăuzit",
    "necălcata": "necălcat",
    "necălcată": "necălcat",
    "necălcate": "necălcat",
    "necălcatei": "necălcat",
    "necălcatele": "necălcat",
    "necălcatelor": "necălcat",
    "necălcați": "necălcat",
    "necălcații": "necălcat",
    "necălcaților": "necălcat",
    "necălcatul": "necălcat",
    "necălcatului": "necălcat",
    "necalchiată": "necalchiat",
    "necalchiate": "necalchiat",
    "necalchiați": "necalchiat",
    "necalcifiata": "necalcifiat",
    "necalcifiată": "necalcifiat",
    "necalcifiate": "necalcifiat",
    "necalcifiatei": "necalcifiat",
    "necalcifiatele": "necalcifiat",
    "necalcifiatelor": "necalcifiat",
    "necalcifiați": "necalcifiat",
    "necalcifiații": "necalcifiat",
    "necalcifiaților": "necalcifiat",
    "necalcifiatul": "necalcifiat",
    "necalcifiatului": "necalcifiat",
    "necalcificata": "necalcificat",
    "necalcificată": "necalcificat",
    "necalcificate": "necalcificat",
    "necalcificatei": "necalcificat",
    "necalcificatele": "necalcificat",
    "necalcificatelor": "necalcificat",
    "necalcificați": "necalcificat",
    "necalcificații": "necalcificat",
    "necalcificaților": "necalcificat",
    "necalcificatul": "necalcificat",
    "necalcificatului": "necalcificat",
    "necalcinata": "necalcinat",
    "necalcinată": "necalcinat",
    "necalcinate": "necalcinat",
    "necalcinatei": "necalcinat",
    "necalcinatele": "necalcinat",
    "necalcinatelor": "necalcinat",
    "necalcinați": "necalcinat",
    "necalcinații": "necalcinat",
    "necalcinaților": "necalcinat",
    "necalcinatul": "necalcinat",
    "necalcinatului": "necalcinat",
    "necalculabila": "necalculabil",
    "necalculabilă": "necalculabil",
    "necalculabile": "necalculabil",
    "necalculabilei": "necalculabil",
    "necalculabilele": "necalculabil",
    "necalculabilelor": "necalculabil",
    "necalculabili": "necalculabil",
    "necalculabilii": "necalculabil",
    "necalculabililor": "necalculabil",
    "necalculabilul": "necalculabil",
    "necalculabilului": "necalculabil",
    "necalculata": "necalculat",
    "necalculată": "necalculat",
    "necalculate": "necalculat",
    "necalculatei": "necalculat",
    "necalculatele": "necalculat",
    "necalculatelor": "necalculat",
    "necalculați": "necalculat",
    "necalculații": "necalculat",
    "necalculaților": "necalculat",
    "necalculatul": "necalculat",
    "necalculatului": "necalculat",
    "necalfatată": "necalfatat",
    "necalfatate": "necalfatat",
    "necalfatați": "necalfatat",
    "necalibrată": "necalibrat",
    "necalibrate": "necalibrat",
    "necalibrați": "necalibrat",
    "necalicită": "necalicit",
    "necalicite": "necalicit",
    "necaliciți": "necalicit",
    "necalificata": "necalificat",
    "necalificată": "necalificat",
    "necalificate": "necalificat",
    "necalificatei": "necalificat",
    "necalificatele": "necalificat",
    "necalificatelor": "necalificat",
    "necalificați": "necalificat",
    "necalificații": "necalificat",
    "necalificaților": "necalificat",
    "necalificatul": "necalificat",
    "necalificatului": "necalificat",
    "necaligrafiată": "necaligrafiat",
    "necaligrafiate": "necaligrafiat",
    "necaligrafiați": "necaligrafiat",
    "necălita": "necălit",
    "necălită": "necălit",
    "necălite": "necălit",
    "necălitei": "necălit",
    "necălitele": "necălit",
    "necălitelor": "necălit",
    "necăliți": "necălit",
    "necăliții": "necălit",
    "necăliților": "necălit",
    "necălitul": "necălit",
    "necălitului": "necălit",
    "necalmată": "necalmat",
    "necalmate": "necalmat",
    "necalmați": "necalmat",
    "necalomniată": "necalomniat",
    "necalomniate": "necalomniat",
    "necalomniați": "necalomniat",
    "necălugărită": "necălugărit",
    "necălugărite": "necălugărit",
    "necălugăriți": "necălugărit",
    "necampată": "necampat",
    "necampate": "necampat",
    "necampați": "necampat",
    "necamuflata": "necamuflat",
    "necamuflată": "necamuflat",
    "necamuflate": "necamuflat",
    "necamuflatei": "necamuflat",
    "necamuflatele": "necamuflat",
    "necamuflatelor": "necamuflat",
    "necamuflați": "necamuflat",
    "necamuflații": "necamuflat",
    "necamuflaților": "necamuflat",
    "necamuflatul": "necamuflat",
    "necamuflatului": "necamuflat",
    "necanalizata": "necanalizat",
    "necanalizată": "necanalizat",
    "necanalizate": "necanalizat",
    "necanalizatei": "necanalizat",
    "necanalizatele": "necanalizat",
    "necanalizatelor": "necanalizat",
    "necanalizați": "necanalizat",
    "necanalizații": "necanalizat",
    "necanalizaților": "necanalizat",
    "necanalizatul": "necanalizat",
    "necanalizatului": "necanalizat",
    "necandidată": "necandidat",
    "necandidate": "necandidat",
    "necandidați": "necandidat",
    "necangrenata": "necangrenat",
    "necangrenată": "necangrenat",
    "necangrenate": "necangrenat",
    "necangrenatei": "necangrenat",
    "necangrenatele": "necangrenat",
    "necangrenatelor": "necangrenat",
    "necangrenați": "necangrenat",
    "necangrenații": "necangrenat",
    "necangrenaților": "necangrenat",
    "necangrenatul": "necangrenat",
    "necangrenatului": "necangrenat",
    "necănită": "necănit",
    "necănite": "necănit",
    "necăniți": "necănit",
    "necanonită": "necanonit",
    "necanonite": "necanonit",
    "necanoniți": "necanonit",
    "necanonizată": "necanonizat",
    "necanonizate": "necanonizat",
    "necanonizați": "necanonizat",
    "necântărita": "necântărit",
    "necântărită": "necântărit",
    "necântărite": "necântărit",
    "necântăritei": "necântărit",
    "necântăritele": "necântărit",
    "necântăritelor": "necântărit",
    "necântăriți": "necântărit",
    "necântăriții": "necântărit",
    "necântăriților": "necântărit",
    "necântăritul": "necântărit",
    "necântăritului": "necântărit",
    "necântată": "necântat",
    "necântate": "necântat",
    "necântați": "necântat",
    "necăpătată": "necăpătat",
    "necăpătate": "necăpătat",
    "necăpătați": "necăpătat",
    "necăpătuita": "necăpătuit",
    "necăpătuită": "necăpătuit",
    "necăpătuite": "necăpătuit",
    "necăpătuitei": "necăpătuit",
    "necăpătuitele": "necăpătuit",
    "necăpătuitelor": "necăpătuit",
    "necăpătuiți": "necăpătuit",
    "necăpătuiții": "necăpătuit",
    "necăpătuiților": "necăpătuit",
    "necăpătuitul": "necăpătuit",
    "necăpătuitului": "necăpătuit",
    "necăpiata": "necăpiat",
    "necăpiată": "necăpiat",
    "necăpiate": "necăpiat",
    "necăpiatei": "necăpiat",
    "necăpiatele": "necăpiat",
    "necăpiatelor": "necăpiat",
    "necăpiați": "necăpiat",
    "necăpiații": "necăpiat",
    "necăpiaților": "necăpiat",
    "necăpiatul": "necăpiat",
    "necăpiatului": "necăpiat",
    "necapitalizată": "necapitalizat",
    "necapitalizate": "necapitalizat",
    "necapitalizați": "necapitalizat",
    "necapitonata": "necapitonat",
    "necapitonată": "necapitonat",
    "necapitonate": "necapitonat",
    "necapitonatei": "necapitonat",
    "necapitonatele": "necapitonat",
    "necapitonatelor": "necapitonat",
    "necapitonați": "necapitonat",
    "necapitonații": "necapitonat",
    "necapitonaților": "necapitonat",
    "necapitonatul": "necapitonat",
    "necapitonatului": "necapitonat",
    "necapitulată": "necapitulat",
    "necapitulate": "necapitulat",
    "necapitulați": "necapitulat",
    "necapotată": "necapotat",
    "necapotate": "necapotat",
    "necapotați": "necapotat",
    "necapsată": "necapsat",
    "necapsate": "necapsat",
    "necapsați": "necapsat",
    "necaptată": "necaptat",
    "necaptate": "necaptat",
    "necaptați": "necaptat",
    "necaptivata": "necaptivat",
    "necaptivată": "necaptivat",
    "necaptivate": "necaptivat",
    "necaptivatei": "necaptivat",
    "necaptivatele": "necaptivat",
    "necaptivatelor": "necaptivat",
    "necaptivați": "necaptivat",
    "necaptivații": "necaptivat",
    "necaptivaților": "necaptivat",
    "necaptivatul": "necaptivat",
    "necaptivatului": "necaptivat",
    "necapturată": "necapturat",
    "necapturate": "necapturat",
    "necapturați": "necapturat",
    "necăptușită": "necăptușit",
    "necăptușite": "necăptușit",
    "necăptușiți": "necăptușit",
    "necărăbănită": "necărăbănit",
    "necărăbănite": "necărăbănit",
    "necărăbăniți": "necărăbănit",
    "necaracterizată": "necaracterizat",
    "necaracterizate": "necaracterizat",
    "necaracterizați": "necaracterizat",
    "necârâita": "necârâit",
    "necârâită": "necârâit",
    "necârâite": "necârâit",
    "necârâitei": "necârâit",
    "necârâitele": "necârâit",
    "necârâitelor": "necârâit",
    "necârâiți": "necârâit",
    "necârâiții": "necârâit",
    "necârâiților": "necârâit",
    "necârâitul": "necârâit",
    "necârâitului": "necârâit",
    "necărată": "necărat",
    "necărate": "necărat",
    "necărați": "necărat",
    "necărăușită": "necărăușit",
    "necărăușite": "necărăușit",
    "necărăușiți": "necărăușit",
    "necarbonatată": "necarbonatat",
    "necarbonatate": "necarbonatat",
    "necarbonatați": "necarbonatat",
    "necarbonizată": "necarbonizat",
    "necarbonizate": "necarbonizat",
    "necarbonizați": "necarbonizat",
    "necarburată": "necarburat",
    "necarburate": "necarburat",
    "necarburați": "necarburat",
    "necârcâită": "necârcâit",
    "necârcâite": "necârcâit",
    "necârcâiți": "necârcâit",
    "necârcălită": "necârcălit",
    "necârcălite": "necârcălit",
    "necârcăliți": "necârcălit",
    "necârcotită": "necârcotit",
    "necârcotite": "necârcotit",
    "necârcotiți": "necârcotit",
    "necârduită": "necârduit",
    "necârduite": "necârduit",
    "necârduiți": "necârduit",
    "necariata": "necariat",
    "necariată": "necariat",
    "necariate": "necariat",
    "necariatei": "necariat",
    "necariatele": "necariat",
    "necariatelor": "necariat",
    "necariați": "necariat",
    "necariații": "necariat",
    "necariaților": "necariat",
    "necariatul": "necariat",
    "necariatului": "necariat",
    "necaricaturizată": "necaricaturizat",
    "necaricaturizate": "necaricaturizat",
    "necaricaturizați": "necaricaturizat",
    "necârlionțata": "necârlionțat",
    "necârlionțată": "necârlionțat",
    "necârlionțate": "necârlionțat",
    "necârlionțatei": "necârlionțat",
    "necârlionțatele": "necârlionțat",
    "necârlionțatelor": "necârlionțat",
    "necârlionțați": "necârlionțat",
    "necârlionțații": "necârlionțat",
    "necârlionțaților": "necârlionțat",
    "necârlionțatul": "necârlionțat",
    "necârlionțatului": "necârlionțat",
    "necârmită": "necârmit",
    "necârmite": "necârmit",
    "necârmiți": "necârmit",
    "necârmuită": "necârmuit",
    "necârmuite": "necârmuit",
    "necârmuiți": "necârmuit",
    "necârnită": "necârnit",
    "necârnite": "necârnit",
    "necârniți": "necârnit",
    "necărnosită": "necărnosit",
    "necărnosite": "necărnosit",
    "necărnosiți": "necărnosit",
    "necârpăcită": "necârpăcit",
    "necârpăcite": "necârpăcit",
    "necârpăciți": "necârpăcit",
    "necârpită": "necârpit",
    "necârpite": "necârpit",
    "necârpiți": "necârpit",
    "necartată": "necartat",
    "necartate": "necartat",
    "necartați": "necartat",
    "necartelată": "necartelat",
    "necartelate": "necartelat",
    "necartelați": "necartelat",
    "necârtită": "necârtit",
    "necârtite": "necârtit",
    "necârtiți": "necârtit",
    "necartografiată": "necartografiat",
    "necartografiate": "necartografiat",
    "necartografiați": "necartografiat",
    "necartonata": "necartonat",
    "necartonată": "necartonat",
    "necartonate": "necartonat",
    "necartonatei": "necartonat",
    "necartonatele": "necartonat",
    "necartonatelor": "necartonat",
    "necartonați": "necartonat",
    "necartonații": "necartonat",
    "necartonaților": "necartonat",
    "necartonatul": "necartonat",
    "necartonatului": "necartonat",
    "necăsăpită": "necăsăpit",
    "necăsăpite": "necăsăpit",
    "necăsăpiți": "necăsăpit",
    "necasată": "necasat",
    "necasate": "necasat",
    "necasați": "necasat",
    "necăsătorita": "necăsătorit",
    "necăsătorită": "necăsătorit",
    "necăsătorite": "necăsătorit",
    "necăsătoritei": "necăsătorit",
    "necăsătoritele": "necăsătorit",
    "necăsătoritelor": "necăsătorit",
    "necăsătoriți": "necăsătorit",
    "necăsătoriții": "necăsătorit",
    "necăsătoriților": "necăsătorit",
    "necăsătoritul": "necăsătorit",
    "necăsătoritului": "necăsătorit",
    "necăscata": "necăscat",
    "necăscată": "necăscat",
    "necăscate": "necăscat",
    "necăscatei": "necăscat",
    "necăscatele": "necăscat",
    "necăscatelor": "necăscat",
    "necăscați": "necăscat",
    "necăscații": "necăscat",
    "necăscaților": "necăscat",
    "necăscatul": "necăscat",
    "necăscatului": "necăscat",
    "necâștigata": "necâștigat",
    "necâștigată": "necâștigat",
    "necâștigate": "necâștigat",
    "necâștigatei": "necâștigat",
    "necâștigatele": "necâștigat",
    "necâștigatelor": "necâștigat",
    "necâștigați": "necâștigat",
    "necâștigații": "necâștigat",
    "necâștigaților": "necâștigat",
    "necâștigatul": "necâștigat",
    "necâștigatului": "necâștigat",
    "necastrată": "necastrat",
    "necastrate": "necastrat",
    "necastrați": "necastrat",
    "necășunată": "necășunat",
    "necășunate": "necășunat",
    "necășunați": "necășunat",
    "necatadicsită": "necatadicsit",
    "necatadicsite": "necatadicsit",
    "necatadicsiți": "necatadicsit",
    "necatalizată": "necatalizat",
    "necatalizate": "necatalizat",
    "necatalizați": "necatalizat",
    "necatalogată": "necatalogat",
    "necatalogate": "necatalogat",
    "necatalogați": "necatalogat",
    "necătănită": "necătănit",
    "necătănite": "necătănit",
    "necătăniți": "necătănit",
    "necățărată": "necățărat",
    "necățărate": "necățărat",
    "necățărați": "necățărat",
    "necategorisită": "necategorisit",
    "necategorisite": "necategorisit",
    "necategorisiți": "necategorisit",
    "necătrănita": "necătrănit",
    "necătrănită": "necătrănit",
    "necătrănite": "necătrănit",
    "necătrănitei": "necătrănit",
    "necătrănitele": "necătrănit",
    "necătrănitelor": "necătrănit",
    "necătrăniți": "necătrănit",
    "necătrăniții": "necătrănit",
    "necătrăniților": "necătrănit",
    "necătrănitul": "necătrănit",
    "necătrănitului": "necătrănit",
    "necăutata": "necăutat",
    "necăutată": "necăutat",
    "necăutate": "necăutat",
    "necăutatei": "necăutat",
    "necăutatele": "necăutat",
    "necăutatelor": "necăutat",
    "necăutați": "necăutat",
    "necăutații": "necăutat",
    "necăutaților": "necăutat",
    "necăutatul": "necăutat",
    "necăutatului": "necăutat",
    "necauterizată": "necauterizat",
    "necauterizate": "necauterizat",
    "necauterizați": "necauterizat",
    "necauzată": "necauzat",
    "necauzate": "necauzat",
    "necauzați": "necauzat",
    "necazul": "necaz",
    "necazului": "necaz",
    "necazuri": "necaz",
    "necazurile": "necaz",
    "necazurilor": "necaz",
    "necazată": "necazat",
    "necazate": "necazat",
    "necazați": "necazat",
    "necăznita": "necăznit",
    "necăznită": "necăznit",
    "necăznite": "necăznit",
    "necăznitei": "necăznit",
    "necăznitele": "necăznit",
    "necăznitelor": "necăznit",
    "necăzniți": "necăznit",
    "necăzniții": "necăznit",
    "necăzniților": "necăznit",
    "necăznitul": "necăznit",
    "necăznitului": "necăznit",
    "necăzută": "necăzut",
    "necăzute": "necăzut",
    "necăzuți": "necăzut",
    "necăzuții": "necăzut",
    "necăzuților": "necăzut",
    "necăzutul": "necăzut",
    "necăzutului": "necăzut",
    "necedată": "necedat",
    "necedate": "necedat",
    "necedați": "necedat",
    "necelebrată": "necelebrat",
    "necelebrate": "necelebrat",
    "necelebrați": "necelebrat",
    "necementată": "necementat",
    "necementate": "necementat",
    "necementați": "necementat",
    "necentralizată": "necentralizat",
    "necentralizate": "necentralizat",
    "necentralizați": "necentralizat",
    "necentrata": "necentrat",
    "necentrată": "necentrat",
    "necentrate": "necentrat",
    "necentratei": "necentrat",
    "necentratele": "necentrat",
    "necentratelor": "necentrat",
    "necentrați": "necentrat",
    "necentrații": "necentrat",
    "necentraților": "necentrat",
    "necentratul": "necentrat",
    "necentratului": "necentrat",
    "necentrifugată": "necentrifugat",
    "necentrifugate": "necentrifugat",
    "necentrifugați": "necentrifugat",
    "necenzurata": "necenzurat",
    "necenzurată": "necenzurat",
    "necenzurate": "necenzurat",
    "necenzuratei": "necenzurat",
    "necenzuratele": "necenzurat",
    "necenzuratelor": "necenzurat",
    "necenzurați": "necenzurat",
    "necenzurații": "necenzurat",
    "necenzuraților": "necenzurat",
    "necenzuratul": "necenzurat",
    "necenzuratului": "necenzurat",
    "necercata": "necercat",
    "necercată": "necercat",
    "necercate": "necercat",
    "necercatei": "necercat",
    "necercatele": "necercat",
    "necercatelor": "necercat",
    "necercați": "necercat",
    "necercații": "necercat",
    "necercaților": "necercat",
    "necercatul": "necercat",
    "necercatului": "necercat",
    "necercetată": "necercetat",
    "necercetate": "necercetat",
    "necercetați": "necercetat",
    "necernita": "necernit",
    "necernită": "necernit",
    "necernite": "necernit",
    "necernitei": "necernit",
    "necernitele": "necernit",
    "necernitelor": "necernit",
    "necerniți": "necernit",
    "necerniții": "necernit",
    "necerniților": "necernit",
    "necernitul": "necernit",
    "necernitului": "necernit",
    "necernuta": "necernut",
    "necernută": "necernut",
    "necernute": "necernut",
    "necernutei": "necernut",
    "necernutele": "necernut",
    "necernutelor": "necernut",
    "necernuți": "necernut",
    "necernuții": "necernut",
    "necernuților": "necernut",
    "necernutul": "necernut",
    "necernutului": "necernut",
    "necerșetorită": "necerșetorit",
    "necerșetorite": "necerșetorit",
    "necerșetoriți": "necerșetorit",
    "necerșită": "necerșit",
    "necerșite": "necerșit",
    "necerșiți": "necerșit",
    "necertata": "necertat",
    "necertată": "necertat",
    "necertate": "necertat",
    "necertatei": "necertat",
    "necertatele": "necertat",
    "necertatelor": "necertat",
    "necertați": "necertat",
    "necertații": "necertat",
    "necertaților": "necertat",
    "necertatul": "necertat",
    "necertatului": "necertat",
    "necertificată": "necertificat",
    "necertificate": "necertificat",
    "necertificați": "necertificat",
    "neceruită": "neceruit",
    "neceruite": "neceruit",
    "neceruiți": "neceruit",
    "necerută": "necerut",
    "necerute": "necerut",
    "neceruți": "necerut",
    "necesara": "necesar",
    "necesară": "necesar",
    "necesare": "necesar",
    "necesarei": "necesar",
    "necesarele": "necesar",
    "necesarelor": "necesar",
    "necesari": "necesar",
    "necesarii": "necesar",
    "necesarilor": "necesar",
    "necesarul": "necesar",
    "necesarului": "necesar",
    "necesionată": "necesionat",
    "necesionate": "necesionat",
    "necesionați": "necesionat",
    "necesit": "necesita",
    "necesită": "necesita",
    "necesitai": "necesita",
    "necesitam": "necesita",
    "necesităm": "necesita",
    "necesitând": "necesita",
    "necesitându": "necesita",
    "necesitară": "necesita",
    "necesitarăm": "necesita",
    "necesitarăți": "necesita",
    "necesitase": "necesita",
    "necesitasem": "necesita",
    "necesitaseră": "necesita",
    "necesitaserăm": "necesita",
    "necesitaserăți": "necesita",
    "necesitaseși": "necesita",
    "necesitași": "necesita",
    "necesitat": "necesita",
    "necesitați": "necesita",
    "necesitau": "necesita",
    "necesite": "necesita",
    "necesiți": "necesita",
    "nemainecesitând": "necesita",
    "nemainecesitându": "necesita",
    "nenecesitând": "necesita",
    "nenecesitându": "necesita",
    "necesitată": "necesitat",
    "necesitate": "necesitat",
    "necesitați": "necesitat",
    "necesitatea": "necesitate",
    "necesități": "necesitate",
    "necesității": "necesitate",
    "necesitățile": "necesitate",
    "necesităților": "necesitate",
    "necetluită": "necetluit",
    "necetluite": "necetluit",
    "necetluiți": "necetluit",
    "nechefuită": "nechefuit",
    "nechefuite": "nechefuit",
    "nechefuiți": "nechefuit",
    "nechelălăita": "nechelălăit",
    "nechelălăită": "nechelălăit",
    "nechelălăite": "nechelălăit",
    "nechelălăitei": "nechelălăit",
    "nechelălăitele": "nechelălăit",
    "nechelălăitelor": "nechelălăit",
    "nechelălăiți": "nechelălăit",
    "nechelălăiții": "nechelălăit",
    "nechelălăiților": "nechelălăit",
    "nechelălăitul": "nechelălăit",
    "nechelălăitului": "nechelălăit",
    "nechelfănită": "nechelfănit",
    "nechelfănite": "nechelfănit",
    "nechelfăniți": "nechelfănit",
    "nechelită": "nechelit",
    "nechelite": "nechelit",
    "necheliți": "nechelit",
    "necheltuită": "necheltuit",
    "necheltuite": "necheltuit",
    "necheltuiți": "necheltuit",
    "nechemata": "nechemat",
    "nechemată": "nechemat",
    "nechemate": "nechemat",
    "nechematei": "nechemat",
    "nechematele": "nechemat",
    "nechematelor": "nechemat",
    "nechemați": "nechemat",
    "nechemații": "nechemat",
    "nechemaților": "nechemat",
    "nechematul": "nechemat",
    "nechematului": "nechemat",
    "nechemata": "nechemată",
    "nechemate": "nechemată",
    "nechematei": "nechemată",
    "nechematele": "nechemată",
    "nechematelor": "nechemată",
    "nechestionată": "nechestionat",
    "nechestionate": "nechestionat",
    "nechestionați": "nechestionat",
    "nechează": "necheza",
    "nechez": "necheza",
    "necheză": "necheza",
    "nechezai": "necheza",
    "nechezam": "necheza",
    "nechezăm": "necheza",
    "nechezând": "necheza",
    "nechezară": "necheza",
    "nechezarăm": "necheza",
    "nechezarăți": "necheza",
    "nechezase": "necheza",
    "nechezasem": "necheza",
    "nechezaseră": "necheza",
    "nechezaserăm": "necheza",
    "nechezaserăți": "necheza",
    "nechezaseși": "necheza",
    "nechezași": "necheza",
    "nechezat": "necheza",
    "nechezați": "necheza",
    "nechezau": "necheza",
    "necheze": "necheza",
    "nechezi": "necheza",
    "nechezășuită": "nechezășuit",
    "nechezășuite": "nechezășuit",
    "nechezășuiți": "nechezășuit",
    "nechezată": "nechezat",
    "nechezate": "nechezat",
    "nechezați": "nechezat",
    "nechezatul": "nechezat",
    "nechezatului": "nechezat",
    "nechezaturi": "nechezat",
    "nechezaturile": "nechezat",
    "nechezaturilor": "nechezat",
    "nechezătoare": "nechezător",
    "nechezătoarea": "nechezător",
    "nechezătoarei": "nechezător",
    "nechezătoarele": "nechezător",
    "nechezătoarelor": "nechezător",
    "nechezători": "nechezător",
    "nechezătorii": "nechezător",
    "nechezătorilor": "nechezător",
    "nechezătorul": "nechezător",
    "nechezătorului": "nechezător",
    "nechiaburită": "nechiaburit",
    "nechiaburite": "nechiaburit",
    "nechiaburiți": "nechiaburit",
    "nechibzuința": "nechibzuință",
    "nechibzuințe": "nechibzuință",
    "nechibzuinței": "nechibzuință",
    "nechibzuințele": "nechibzuință",
    "nechibzuințelor": "nechibzuință",
    "nechibzuita": "nechibzuit",
    "nechibzuită": "nechibzuit",
    "nechibzuite": "nechibzuit",
    "nechibzuitei": "nechibzuit",
    "nechibzuitele": "nechibzuit",
    "nechibzuitelor": "nechibzuit",
    "nechibzuiți": "nechibzuit",
    "nechibzuiții": "nechibzuit",
    "nechibzuiților": "nechibzuit",
    "nechibzuitul": "nechibzuit",
    "nechibzuitului": "nechibzuit",
    "nechicotită": "nechicotit",
    "nechicotite": "nechicotit",
    "nechicotiți": "nechicotit",
    "nechiftită": "nechiftit",
    "nechiftite": "nechiftit",
    "nechiftiți": "nechiftit",
    "nechihăită": "nechihăit",
    "nechihăite": "nechihăit",
    "nechihăiți": "nechihăit",
    "nechimizată": "nechimizat",
    "nechimizate": "nechimizat",
    "nechimizați": "nechimizat",
    "nechinuita": "nechinuit",
    "nechinuită": "nechinuit",
    "nechinuite": "nechinuit",
    "nechinuitei": "nechinuit",
    "nechinuitele": "nechinuit",
    "nechinuitelor": "nechinuit",
    "nechinuiți": "nechinuit",
    "nechinuiții": "nechinuit",
    "nechinuiților": "nechinuit",
    "nechinuitul": "nechinuit",
    "nechinuitului": "nechinuit",
    "nechiorăită": "nechiorăit",
    "nechiorăite": "nechiorăit",
    "nechiorăiți": "nechiorăit",
    "nechiorâtă": "nechiorât",
    "nechiorâte": "nechiorât",
    "nechiorâți": "nechiorât",
    "nechirăită": "nechirăit",
    "nechirăite": "nechirăit",
    "nechirăiți": "nechirăit",
    "nechircita": "nechircit",
    "nechircită": "nechircit",
    "nechircite": "nechircit",
    "nechircitei": "nechircit",
    "nechircitele": "nechircit",
    "nechircitelor": "nechircit",
    "nechirciți": "nechircit",
    "nechirciții": "nechircit",
    "nechirciților": "nechircit",
    "nechircitul": "nechircit",
    "nechircitului": "nechircit",
    "nechițăită": "nechițăit",
    "nechițăite": "nechițăit",
    "nechițăiți": "nechițăit",
    "nechițcăită": "nechițcăit",
    "nechițcăite": "nechițcăit",
    "nechițcăiți": "nechițcăit",
    "nechitita": "nechitit",
    "nechitită": "nechitit",
    "nechitite": "nechitit",
    "nechititei": "nechitit",
    "nechititele": "nechitit",
    "nechititelor": "nechitit",
    "nechitiți": "nechitit",
    "nechitiții": "nechitit",
    "nechitiților": "nechitit",
    "nechititul": "nechitit",
    "nechititului": "nechitit",
    "nechituită": "nechituit",
    "nechituite": "nechituit",
    "nechituiți": "nechituit",
    "nechiuită": "nechiuit",
    "nechiuite": "nechiuit",
    "nechiuiți": "nechiuit",
    "nechiulită": "nechiulit",
    "nechiulite": "nechiulit",
    "nechiuliți": "nechiulit",
    "nechiuretată": "nechiuretat",
    "nechiuretate": "nechiuretat",
    "nechiuretați": "nechiuretat",
    "nechivernisita": "nechivernisit",
    "nechivernisită": "nechivernisit",
    "nechivernisite": "nechivernisit",
    "nechivernisitei": "nechivernisit",
    "nechivernisitele": "nechivernisit",
    "nechivernisitelor": "nechivernisit",
    "nechivernisiți": "nechivernisit",
    "nechivernisiții": "nechivernisit",
    "nechivernisiților": "nechivernisit",
    "nechivernisitul": "nechivernisit",
    "nechivernisitului": "nechivernisit",
    "necicălită": "necicălit",
    "necicălite": "necicălit",
    "necicăliți": "necicălit",
    "necicatrizata": "necicatrizat",
    "necicatrizată": "necicatrizat",
    "necicatrizate": "necicatrizat",
    "necicatrizatei": "necicatrizat",
    "necicatrizatele": "necicatrizat",
    "necicatrizatelor": "necicatrizat",
    "necicatrizați": "necicatrizat",
    "necicatrizații": "necicatrizat",
    "necicatrizaților": "necicatrizat",
    "necicatrizatul": "necicatrizat",
    "necicatrizatului": "necicatrizat",
    "necifrata": "necifrat",
    "necifrată": "necifrat",
    "necifrate": "necifrat",
    "necifratei": "necifrat",
    "necifratele": "necifrat",
    "necifratelor": "necifrat",
    "necifrați": "necifrat",
    "necifrații": "necifrat",
    "necifraților": "necifrat",
    "necifratul": "necifrat",
    "necifratului": "necifrat",
    "necihăită": "necihăit",
    "necihăite": "necihăit",
    "necihăiți": "necihăit",
    "necimentată": "necimentat",
    "necimentate": "necimentat",
    "necimentați": "necimentat",
    "necimilită": "necimilit",
    "necimilite": "necimilit",
    "necimiliți": "necimilit",
    "necinată": "necinat",
    "necinate": "necinat",
    "necinați": "necinat",
    "necinematografiată": "necinematografiat",
    "necinematografiate": "necinematografiat",
    "necinematografiați": "necinematografiat",
    "necinstea": "necinste",
    "necinstele": "necinste",
    "necinstelor": "necinste",
    "necinsti": "necinste",
    "necinstii": "necinste",
    "necinstea": "necinsti",
    "necinsteai": "necinsti",
    "necinsteam": "necinsti",
    "necinstească": "necinsti",
    "necinsteați": "necinsti",
    "necinsteau": "necinsti",
    "necinstesc": "necinsti",
    "necinstește": "necinsti",
    "necinstești": "necinsti",
    "necinstii": "necinsti",
    "necinstim": "necinsti",
    "necinstind": "necinsti",
    "necinstindu": "necinsti",
    "necinstiră": "necinsti",
    "necinstirăm": "necinsti",
    "necinstirăți": "necinsti",
    "necinstise": "necinsti",
    "necinstisem": "necinsti",
    "necinstiseră": "necinsti",
    "necinstiserăm": "necinsti",
    "necinstiserăți": "necinsti",
    "necinstiseși": "necinsti",
    "necinstiși": "necinsti",
    "necinstit": "necinsti",
    "necinstiți": "necinsti",
    "nemainecinstindu": "necinsti",
    "nenecinstindu": "necinsti",
    "necinstirea": "necinstire",
    "necinstiri": "necinstire",
    "necinstirii": "necinstire",
    "necinstirile": "necinstire",
    "necinstirilor": "necinstire",
    "necinstita": "necinstit",
    "necinstită": "necinstit",
    "necinstite": "necinstit",
    "necinstitei": "necinstit",
    "necinstitele": "necinstit",
    "necinstitelor": "necinstit",
    "necinstiți": "necinstit",
    "necinstiții": "necinstit",
    "necinstiților": "necinstit",
    "necinstitul": "necinstit",
    "necinstitului": "necinstit",
    "neciobănită": "neciobănit",
    "neciobănite": "neciobănit",
    "neciobăniți": "neciobănit",
    "neciobită": "neciobit",
    "neciobite": "neciobit",
    "neciobiți": "neciobit",
    "neciocănită": "neciocănit",
    "neciocănite": "neciocănit",
    "neciocăniți": "neciocănit",
    "neciocârtită": "neciocârtit",
    "neciocârtite": "neciocârtit",
    "neciocârtiți": "neciocârtit",
    "neciocnita": "neciocnit",
    "neciocnită": "neciocnit",
    "neciocnite": "neciocnit",
    "neciocnitei": "neciocnit",
    "neciocnitele": "neciocnit",
    "neciocnitelor": "neciocnit",
    "neciocniți": "neciocnit",
    "neciocniții": "neciocnit",
    "neciocniților": "neciocnit",
    "neciocnitul": "neciocnit",
    "neciocnitului": "neciocnit",
    "neciocoită": "neciocoit",
    "neciocoite": "neciocoit",
    "neciocoiți": "neciocoit",
    "neciomăgită": "neciomăgit",
    "neciomăgite": "neciomăgit",
    "neciomăgiți": "neciomăgit",
    "neciondănită": "neciondănit",
    "neciondănite": "neciondănit",
    "neciondăniți": "neciondănit",
    "neciopârțită": "neciopârțit",
    "neciopârțite": "neciopârțit",
    "neciopârțiți": "neciopârțit",
    "necioplirea": "necioplire",
    "neciopliri": "necioplire",
    "necioplirii": "necioplire",
    "necioplirile": "necioplire",
    "necioplirilor": "necioplire",
    "necioplita": "necioplit",
    "necioplită": "necioplit",
    "necioplite": "necioplit",
    "necioplitei": "necioplit",
    "necioplitele": "necioplit",
    "necioplitelor": "necioplit",
    "neciopliți": "necioplit",
    "neciopliții": "necioplit",
    "neciopliților": "necioplit",
    "necioplitul": "necioplit",
    "necioplitului": "necioplit",
    "neciordită": "neciordit",
    "neciordite": "neciordit",
    "neciordiți": "neciordit",
    "neciorovăită": "neciorovăit",
    "neciorovăite": "neciorovăit",
    "neciorovăiți": "neciorovăit",
    "necirculată": "necirculat",
    "necirculate": "necirculat",
    "necirculați": "necirculat",
    "necircumscrisa": "necircumscris",
    "necircumscrisă": "necircumscris",
    "necircumscrise": "necircumscris",
    "necircumscrisei": "necircumscris",
    "necircumscrisele": "necircumscris",
    "necircumscriselor": "necircumscris",
    "necircumscriși": "necircumscris",
    "necircumscrișii": "necircumscris",
    "necircumscrișilor": "necircumscris",
    "necircumscrisul": "necircumscris",
    "necircumscrisului": "necircumscris",
    "neciripită": "neciripit",
    "neciripite": "neciripit",
    "neciripiți": "neciripit",
    "necisluită": "necisluit",
    "necisluite": "necisluit",
    "necisluiți": "necisluit",
    "necitată": "necitat",
    "necitate": "necitat",
    "necitați": "necitat",
    "neciteața": "neciteț",
    "neciteață": "neciteț",
    "necitețe": "neciteț",
    "neciteței": "neciteț",
    "necitețele": "neciteț",
    "necitețelor": "neciteț",
    "neciteți": "neciteț",
    "neciteții": "neciteț",
    "neciteților": "neciteț",
    "necitețul": "neciteț",
    "necitețului": "neciteț",
    "necitita": "necitit",
    "necitită": "necitit",
    "necitite": "necitit",
    "necititei": "necitit",
    "necititele": "necitit",
    "necititelor": "necitit",
    "necitiți": "necitit",
    "necitiții": "necitit",
    "necitiților": "necitit",
    "necititul": "necitit",
    "necititului": "necitit",
    "neciufulita": "neciufulit",
    "neciufulită": "neciufulit",
    "neciufulite": "neciufulit",
    "neciufulitei": "neciufulit",
    "neciufulitele": "neciufulit",
    "neciufulitelor": "neciufulit",
    "neciufuliți": "neciufulit",
    "neciufuliții": "neciufulit",
    "neciufuliților": "neciufulit",
    "neciufulitul": "neciufulit",
    "neciufulitului": "neciufulit",
    "neciugulită": "neciugulit",
    "neciugulite": "neciugulit",
    "neciuguliți": "neciugulit",
    "neciulită": "neciulit",
    "neciulite": "neciulit",
    "neciuliți": "neciulit",
    "neciumpăvită": "neciumpăvit",
    "neciumpăvite": "neciumpăvit",
    "neciumpăviți": "neciumpăvit",
    "neciungită": "neciungit",
    "neciungite": "neciungit",
    "neciungiți": "neciungit",
    "neciuntită": "neciuntit",
    "neciuntite": "neciuntit",
    "neciuntiți": "neciuntit",
    "neciupita": "neciupit",
    "neciupită": "neciupit",
    "neciupite": "neciupit",
    "neciupitei": "neciupit",
    "neciupitele": "neciupit",
    "neciupitelor": "neciupit",
    "neciupiți": "neciupit",
    "neciupiții": "neciupit",
    "neciupiților": "neciupit",
    "neciupitul": "neciupit",
    "neciupitului": "neciupit",
    "neciuruită": "neciuruit",
    "neciuruite": "neciuruit",
    "neciuruiți": "neciuruit",
    "necivilizata": "necivilizat",
    "necivilizată": "necivilizat",
    "necivilizate": "necivilizat",
    "necivilizatei": "necivilizat",
    "necivilizatele": "necivilizat",
    "necivilizatelor": "necivilizat",
    "necivilizați": "necivilizat",
    "necivilizații": "necivilizat",
    "necivilizaților": "necivilizat",
    "necivilizatul": "necivilizat",
    "necivilizatului": "necivilizat",
    "necizelata": "necizelat",
    "necizelată": "necizelat",
    "necizelate": "necizelat",
    "necizelatei": "necizelat",
    "necizelatele": "necizelat",
    "necizelatelor": "necizelat",
    "necizelați": "necizelat",
    "necizelații": "necizelat",
    "necizelaților": "necizelat",
    "necizelatul": "necizelat",
    "necizelatului": "necizelat",
    "neclăbucită": "neclăbucit",
    "neclăbucite": "neclăbucit",
    "neclăbuciți": "neclăbucit",
    "neclădită": "neclădit",
    "neclădite": "neclădit",
    "neclădiți": "neclădit",
    "neclămpănită": "neclămpănit",
    "neclămpănite": "neclămpănit",
    "neclămpăniți": "neclămpănit",
    "neclănțănită": "neclănțănit",
    "neclănțănite": "neclănțănit",
    "neclănțăniți": "neclănțănit",
    "neclara": "neclar",
    "neclară": "neclar",
    "neclare": "neclar",
    "neclarei": "neclar",
    "neclarele": "neclar",
    "neclarelor": "neclar",
    "neclari": "neclar",
    "neclarii": "neclar",
    "neclarilor": "neclar",
    "neclarul": "neclar",
    "neclarului": "neclar",
    "neclarificată": "neclarificat",
    "neclarificate": "neclarificat",
    "neclarificați": "neclarificat",
    "neclaritatea": "neclaritate",
    "neclarități": "neclaritate",
    "neclarității": "neclaritate",
    "neclaritățile": "neclaritate",
    "neclarităților": "neclaritate",
    "neclasată": "neclasat",
    "neclasate": "neclasat",
    "neclasați": "neclasat",
    "neclasificată": "neclasificat",
    "neclasificate": "neclasificat",
    "neclasificați": "neclasificat",
    "neclătinată": "neclătinat",
    "neclătinate": "neclătinat",
    "neclătinați": "neclătinat",
    "neclătita": "neclătit",
    "neclătită": "neclătit",
    "neclătite": "neclătit",
    "neclătitei": "neclătit",
    "neclătitele": "neclătit",
    "neclătitelor": "neclătit",
    "neclătiți": "neclătit",
    "neclătiții": "neclătit",
    "neclătiților": "neclătit",
    "neclătitul": "neclătit",
    "neclătitului": "neclătit",
    "neclaustrată": "neclaustrat",
    "neclaustrate": "neclaustrat",
    "neclaustrați": "neclaustrat",
    "neclaxonată": "neclaxonat",
    "neclaxonate": "neclaxonat",
    "neclaxonați": "neclaxonat",
    "neclefăită": "neclefăit",
    "neclefăite": "neclefăit",
    "neclefăiți": "neclefăit",
    "neclevetită": "neclevetit",
    "neclevetite": "neclevetit",
    "neclevetiți": "neclevetit",
    "neclincănită": "neclincănit",
    "neclincănite": "neclincănit",
    "neclincăniți": "neclincănit",
    "neclintirea": "neclintire",
    "neclintiri": "neclintire",
    "neclintirii": "neclintire",
    "neclintirile": "neclintire",
    "neclintirilor": "neclintire",
    "neclintita": "neclintit",
    "neclintită": "neclintit",
    "neclintite": "neclintit",
    "neclintitei": "neclintit",
    "neclintitele": "neclintit",
    "neclintitelor": "neclintit",
    "neclintiți": "neclintit",
    "neclintiții": "neclintit",
    "neclintiților": "neclintit",
    "neclintitul": "neclintit",
    "neclintitului": "neclintit",
    "neclipită": "neclipit",
    "neclipite": "neclipit",
    "neclipiți": "neclipit",
    "neclipocită": "neclipocit",
    "neclipocite": "neclipocit",
    "neclipociți": "neclipocit",
    "neclivată": "neclivat",
    "neclivate": "neclivat",
    "neclivați": "neclivat",
    "neclocita": "neclocit",
    "neclocită": "neclocit",
    "neclocite": "neclocit",
    "neclocitei": "neclocit",
    "neclocitele": "neclocit",
    "neclocitelor": "neclocit",
    "neclociți": "neclocit",
    "neclociții": "neclocit",
    "neclociților": "neclocit",
    "neclocitul": "neclocit",
    "neclocitului": "neclocit",
    "neclocotita": "neclocotit",
    "neclocotită": "neclocotit",
    "neclocotite": "neclocotit",
    "neclocotitei": "neclocotit",
    "neclocotitele": "neclocotit",
    "neclocotitelor": "neclocotit",
    "neclocotiți": "neclocotit",
    "neclocotiții": "neclocotit",
    "neclocotiților": "neclocotit",
    "neclocotitul": "neclocotit",
    "neclocotitului": "neclocotit",
    "necloncănită": "necloncănit",
    "necloncănite": "necloncănit",
    "necloncăniți": "necloncănit",
    "neclopoțită": "neclopoțit",
    "neclopoțite": "neclopoțit",
    "neclopoțiți": "neclopoțit",
    "necloroformizată": "necloroformizat",
    "necloroformizate": "necloroformizat",
    "necloroformizați": "necloroformizat",
    "necoabitată": "necoabitat",
    "necoabitate": "necoabitat",
    "necoabitați": "necoabitat",
    "necoafata": "necoafat",
    "necoafată": "necoafat",
    "necoafate": "necoafat",
    "necoafatei": "necoafat",
    "necoafatele": "necoafat",
    "necoafatelor": "necoafat",
    "necoafați": "necoafat",
    "necoafații": "necoafat",
    "necoafaților": "necoafat",
    "necoafatul": "necoafat",
    "necoafatului": "necoafat",
    "necoagulata": "necoagulat",
    "necoagulată": "necoagulat",
    "necoagulate": "necoagulat",
    "necoagulatei": "necoagulat",
    "necoagulatele": "necoagulat",
    "necoagulatelor": "necoagulat",
    "necoagulați": "necoagulat",
    "necoagulații": "necoagulat",
    "necoagulaților": "necoagulat",
    "necoagulatul": "necoagulat",
    "necoagulatului": "necoagulat",
    "necoalizată": "necoalizat",
    "necoalizate": "necoalizat",
    "necoalizați": "necoalizat",
    "necobită": "necobit",
    "necobite": "necobit",
    "necobiți": "necobit",
    "necoborâtă": "necoborât",
    "necoborâte": "necoborât",
    "necoborâți": "necoborât",
    "necocârjata": "necocârjat",
    "necocârjată": "necocârjat",
    "necocârjate": "necocârjat",
    "necocârjatei": "necocârjat",
    "necocârjatele": "necocârjat",
    "necocârjatelor": "necocârjat",
    "necocârjați": "necocârjat",
    "necocârjații": "necocârjat",
    "necocârjaților": "necocârjat",
    "necocârjatul": "necocârjat",
    "necocârjatului": "necocârjat",
    "necocârjita": "necocârjit",
    "necocârjită": "necocârjit",
    "necocârjite": "necocârjit",
    "necocârjitei": "necocârjit",
    "necocârjitele": "necocârjit",
    "necocârjitelor": "necocârjit",
    "necocârjiți": "necocârjit",
    "necocârjiții": "necocârjit",
    "necocârjiților": "necocârjit",
    "necocârjitul": "necocârjit",
    "necocârjitului": "necocârjit",
    "necochetată": "necochetat",
    "necochetate": "necochetat",
    "necochetați": "necochetat",
    "necoclita": "necoclit",
    "necoclită": "necoclit",
    "necoclite": "necoclit",
    "necoclitei": "necoclit",
    "necoclitele": "necoclit",
    "necoclitelor": "necoclit",
    "necocliți": "necoclit",
    "necocliții": "necoclit",
    "necocliților": "necoclit",
    "necoclitul": "necoclit",
    "necoclitului": "necoclit",
    "necocoloșită": "necocoloșit",
    "necocoloșite": "necocoloșit",
    "necocoloșiți": "necocoloșit",
    "necocoșata": "necocoșat",
    "necocoșată": "necocoșat",
    "necocoșate": "necocoșat",
    "necocoșatei": "necocoșat",
    "necocoșatele": "necocoșat",
    "necocoșatelor": "necocoșat",
    "necocoșați": "necocoșat",
    "necocoșații": "necocoșat",
    "necocoșaților": "necocoșat",
    "necocoșatul": "necocoșat",
    "necocoșatului": "necocoșat",
    "necocoțată": "necocoțat",
    "necocoțate": "necocoțat",
    "necocoțați": "necocoțat",
    "necocsificată": "necocsificat",
    "necocsificate": "necocsificat",
    "necocsificați": "necocsificat",
    "necodificată": "necodificat",
    "necodificate": "necodificat",
    "necodificați": "necodificat",
    "necodită": "necodit",
    "necodite": "necodit",
    "necodiți": "necodit",
    "necofleșită": "necofleșit",
    "necofleșite": "necofleșit",
    "necofleșiți": "necofleșit",
    "necoincisă": "necoincis",
    "necoincise": "necoincis",
    "necoinciși": "necoincis",
    "necojita": "necojit",
    "necojită": "necojit",
    "necojite": "necojit",
    "necojitei": "necojit",
    "necojitele": "necojit",
    "necojitelor": "necojit",
    "necojiți": "necojit",
    "necojiții": "necojit",
    "necojiților": "necojit",
    "necojitul": "necojit",
    "necojitului": "necojit",
    "necolaborată": "necolaborat",
    "necolaborate": "necolaborat",
    "necolaborați": "necolaborat",
    "necolaționată": "necolaționat",
    "necolaționate": "necolaționat",
    "necolaționați": "necolaționat",
    "necolbăita": "necolbăit",
    "necolbăită": "necolbăit",
    "necolbăite": "necolbăit",
    "necolbăitei": "necolbăit",
    "necolbăitele": "necolbăit",
    "necolbăitelor": "necolbăit",
    "necolbăiți": "necolbăit",
    "necolbăiții": "necolbăit",
    "necolbăiților": "necolbăit",
    "necolbăitul": "necolbăit",
    "necolbăitului": "necolbăit",
    "necolcăită": "necolcăit",
    "necolcăite": "necolcăit",
    "necolcăiți": "necolcăit",
    "necolectată": "necolectat",
    "necolectate": "necolectat",
    "necolectați": "necolectat",
    "necolecționată": "necolecționat",
    "necolecționate": "necolecționat",
    "necolecționați": "necolecționat",
    "necolectivizată": "necolectivizat",
    "necolectivizate": "necolectivizat",
    "necolectivizați": "necolectivizat",
    "necolindată": "necolindat",
    "necolindate": "necolindat",
    "necolindați": "necolindat",
    "necolonizată": "necolonizat",
    "necolonizate": "necolonizat",
    "necolonizați": "necolonizat",
    "necolorata": "necolorat",
    "necolorată": "necolorat",
    "necolorate": "necolorat",
    "necoloratei": "necolorat",
    "necoloratele": "necolorat",
    "necoloratelor": "necolorat",
    "necolorați": "necolorat",
    "necolorații": "necolorat",
    "necoloraților": "necolorat",
    "necoloratul": "necolorat",
    "necoloratului": "necolorat",
    "necolportată": "necolportat",
    "necolportate": "necolportat",
    "necolportați": "necolportat",
    "necomandată": "necomandat",
    "necomandate": "necomandat",
    "necomandați": "necomandat",
    "necomanditată": "necomanditat",
    "necomanditate": "necomanditat",
    "necomanditați": "necomanditat",
    "necomasată": "necomasat",
    "necomasate": "necomasat",
    "necomasați": "necomasat",
    "necombatanta": "necombatant",
    "necombatantă": "necombatant",
    "necombatante": "necombatant",
    "necombatantei": "necombatant",
    "necombatantele": "necombatant",
    "necombatantelor": "necombatant",
    "necombatanți": "necombatant",
    "necombatanții": "necombatant",
    "necombatanților": "necombatant",
    "necombatantul": "necombatant",
    "necombatantului": "necombatant",
    "necombătută": "necombătut",
    "necombătute": "necombătut",
    "necombătuți": "necombătut",
    "necombinată": "necombinat",
    "necombinate": "necombinat",
    "necombinați": "necombinat",
    "necomemorată": "necomemorat",
    "necomemorate": "necomemorat",
    "necomemorați": "necomemorat",
    "necomentată": "necomentat",
    "necomentate": "necomentat",
    "necomentați": "necomentat",
    "necomercializată": "necomercializat",
    "necomercializate": "necomercializat",
    "necomercializați": "necomercializat",
    "necomisă": "necomis",
    "necomise": "necomis",
    "necomiși": "necomis",
    "necompactată": "necompactat",
    "necompactate": "necompactat",
    "necompactați": "necompactat",
    "necomparata": "necomparat",
    "necomparată": "necomparat",
    "necomparate": "necomparat",
    "necomparatei": "necomparat",
    "necomparatele": "necomparat",
    "necomparatelor": "necomparat",
    "necomparați": "necomparat",
    "necomparații": "necomparat",
    "necomparaților": "necomparat",
    "necomparatul": "necomparat",
    "necomparatului": "necomparat",
    "necompartimentata": "necompartimentat",
    "necompartimentată": "necompartimentat",
    "necompartimentate": "necompartimentat",
    "necompartimentatei": "necompartimentat",
    "necompartimentatele": "necompartimentat",
    "necompartimentatelor": "necompartimentat",
    "necompartimentați": "necompartimentat",
    "necompartimentații": "necompartimentat",
    "necompartimentaților": "necompartimentat",
    "necompartimentatul": "necompartimentat",
    "necompartimentatului": "necompartimentat",
    "necompărută": "necompărut",
    "necompărute": "necompărut",
    "necompăruți": "necompărut",
    "necompensată": "necompensat",
    "necompensate": "necompensat",
    "necompensați": "necompensat",
    "necompetitivă": "necompetitiv",
    "necompetitive": "necompetitiv",
    "necompetitivi": "necompetitiv",
    "necompilată": "necompilat",
    "necompilate": "necompilat",
    "necompilați": "necompilat",
    "necomplectată": "necomplectat",
    "necomplectate": "necomplectat",
    "necomplectați": "necomplectat",
    "necompletată": "necompletat",
    "necompletate": "necompletat",
    "necompletați": "necompletat",
    "necomplicata": "necomplicat",
    "necomplicată": "necomplicat",
    "necomplicate": "necomplicat",
    "necomplicatei": "necomplicat",
    "necomplicatele": "necomplicat",
    "necomplicatelor": "necomplicat",
    "necomplicați": "necomplicat",
    "necomplicații": "necomplicat",
    "necomplicaților": "necomplicat",
    "necomplicatul": "necomplicat",
    "necomplicatului": "necomplicat",
    "necomplimentată": "necomplimentat",
    "necomplimentate": "necomplimentat",
    "necomplimentați": "necomplimentat",
    "necomplinită": "necomplinit",
    "necomplinite": "necomplinit",
    "necompliniți": "necomplinit",
    "necomplotată": "necomplotat",
    "necomplotate": "necomplotat",
    "necomplotați": "necomplotat",
    "necomportată": "necomportat",
    "necomportate": "necomportat",
    "necomportați": "necomportat",
    "necompostată": "necompostat",
    "necompostate": "necompostat",
    "necompostați": "necompostat",
    "necomprimata": "necomprimat",
    "necomprimată": "necomprimat",
    "necomprimate": "necomprimat",
    "necomprimatei": "necomprimat",
    "necomprimatele": "necomprimat",
    "necomprimatelor": "necomprimat",
    "necomprimați": "necomprimat",
    "necomprimații": "necomprimat",
    "necomprimaților": "necomprimat",
    "necomprimatul": "necomprimat",
    "necomprimatului": "necomprimat",
    "necompromisa": "necompromis",
    "necompromisă": "necompromis",
    "necompromise": "necompromis",
    "necompromisei": "necompromis",
    "necompromisele": "necompromis",
    "necompromiselor": "necompromis",
    "necompromiși": "necompromis",
    "necompromișii": "necompromis",
    "necompromișilor": "necompromis",
    "necompromisul": "necompromis",
    "necompromisului": "necompromis",
    "necompusa": "necompus",
    "necompusă": "necompus",
    "necompuse": "necompus",
    "necompusei": "necompus",
    "necompusele": "necompus",
    "necompuselor": "necompus",
    "necompuși": "necompus",
    "necompușii": "necompus",
    "necompușilor": "necompus",
    "necompusul": "necompus",
    "necompusului": "necompus",
    "necomunicată": "necomunicat",
    "necomunicate": "necomunicat",
    "necomunicați": "necomunicat",
    "necomunista": "necomunist",
    "necomunistă": "necomunist",
    "necomuniste": "necomunist",
    "necomunistei": "necomunist",
    "necomunistele": "necomunist",
    "necomunistelor": "necomunist",
    "necomuniști": "necomunist",
    "necomuniștii": "necomunist",
    "necomuniștilor": "necomunist",
    "necomunistul": "necomunist",
    "necomunistului": "necomunist",
    "necomutată": "necomutat",
    "necomutate": "necomutat",
    "necomutați": "necomutat",
    "neconcasată": "neconcasat",
    "neconcasate": "neconcasat",
    "neconcasați": "neconcasat",
    "neconcediată": "neconcediat",
    "neconcediate": "neconcediat",
    "neconcediați": "neconcediat",
    "neconcentrata": "neconcentrat",
    "neconcentrată": "neconcentrat",
    "neconcentrate": "neconcentrat",
    "neconcentratei": "neconcentrat",
    "neconcentratele": "neconcentrat",
    "neconcentratelor": "neconcentrat",
    "neconcentrați": "neconcentrat",
    "neconcentrații": "neconcentrat",
    "neconcentraților": "neconcentrat",
    "neconcentratul": "neconcentrat",
    "neconcentratului": "neconcentrat",
    "neconceputa": "neconceput",
    "neconcepută": "neconceput",
    "neconcepute": "neconceput",
    "neconceputei": "neconceput",
    "neconceputele": "neconceput",
    "neconceputelor": "neconceput",
    "neconcepuți": "neconceput",
    "neconcepuții": "neconceput",
    "neconcepuților": "neconceput",
    "neconceputul": "neconceput",
    "neconceputului": "neconceput",
    "neconcertată": "neconcertat",
    "neconcertate": "neconcertat",
    "neconcertați": "neconcertat",
    "neconcesionată": "neconcesionat",
    "neconcesionate": "neconcesionat",
    "neconcesionați": "neconcesionat",
    "neconchisă": "neconchis",
    "neconchise": "neconchis",
    "neconchiși": "neconchis",
    "neconciliată": "neconciliat",
    "neconciliate": "neconciliat",
    "neconciliați": "neconciliat",
    "neconcordanta": "neconcordant",
    "neconcordantă": "neconcordant",
    "neconcordante": "neconcordant",
    "neconcordantei": "neconcordant",
    "neconcordantele": "neconcordant",
    "neconcordantelor": "neconcordant",
    "neconcordanți": "neconcordant",
    "neconcordanții": "neconcordant",
    "neconcordanților": "neconcordant",
    "neconcordantul": "neconcordant",
    "neconcordantului": "neconcordant",
    "neconcordanța": "neconcordanță",
    "neconcordanțe": "neconcordanță",
    "neconcordanței": "neconcordanță",
    "neconcordanțele": "neconcordanță",
    "neconcordanțelor": "neconcordanță",
    "neconcordată": "neconcordat",
    "neconcordate": "neconcordat",
    "neconcordați": "neconcordat",
    "neconcretizată": "neconcretizat",
    "neconcretizate": "neconcretizat",
    "neconcretizați": "neconcretizat",
    "neconcurată": "neconcurat",
    "neconcurate": "neconcurat",
    "neconcurați": "neconcurat",
    "necondamnată": "necondamnat",
    "necondamnate": "necondamnat",
    "necondamnați": "necondamnat",
    "necondensata": "necondensat",
    "necondensată": "necondensat",
    "necondensate": "necondensat",
    "necondensatei": "necondensat",
    "necondensatele": "necondensat",
    "necondensatelor": "necondensat",
    "necondensați": "necondensat",
    "necondensații": "necondensat",
    "necondensaților": "necondensat",
    "necondensatul": "necondensat",
    "necondensatului": "necondensat",
    "necondimentată": "necondimentat",
    "necondimentate": "necondimentat",
    "necondimentați": "necondimentat",
    "necondiționala": "necondițional",
    "necondițională": "necondițional",
    "necondiționale": "necondițional",
    "necondiționalei": "necondițional",
    "necondiționalele": "necondițional",
    "necondiționalelor": "necondițional",
    "necondiționali": "necondițional",
    "necondiționalii": "necondițional",
    "necondiționalilor": "necondițional",
    "necondiționalul": "necondițional",
    "necondiționalului": "necondițional",
    "necondiționata": "necondiționat",
    "necondiționată": "necondiționat",
    "necondiționate": "necondiționat",
    "necondiționatei": "necondiționat",
    "necondiționatele": "necondiționat",
    "necondiționatelor": "necondiționat",
    "necondiționați": "necondiționat",
    "necondiționații": "necondiționat",
    "necondiționaților": "necondiționat",
    "necondiționatul": "necondiționat",
    "necondiționatului": "necondiționat",
    "necondusă": "necondus",
    "neconduse": "necondus",
    "neconduși": "necondus",
    "neconectată": "neconectat",
    "neconectate": "neconectat",
    "neconectați": "neconectat",
    "neconexată": "neconexat",
    "neconexate": "neconexat",
    "neconexați": "neconexat",
    "neconfecționată": "neconfecționat",
    "neconfecționate": "neconfecționat",
    "neconfecționați": "neconfecționat",
    "neconferențiată": "neconferențiat",
    "neconferențiate": "neconferențiat",
    "neconferențiați": "neconferențiat",
    "neconferită": "neconferit",
    "neconferite": "neconferit",
    "neconferiți": "neconferit",
    "neconfesată": "neconfesat",
    "neconfesate": "neconfesat",
    "neconfesați": "neconfesat",
    "neconfiată": "neconfiat",
    "neconfiate": "neconfiat",
    "neconfiați": "neconfiat",
    "neconfigurată": "neconfigurat",
    "neconfigurate": "neconfigurat",
    "neconfigurați": "neconfigurat",
    "neconfirmată": "neconfirmat",
    "neconfirmate": "neconfirmat",
    "neconfirmați": "neconfirmat",
    "neconfiscată": "neconfiscat",
    "neconfiscate": "neconfiscat",
    "neconfiscați": "neconfiscat",
    "neconforma": "neconform",
    "neconformă": "neconform",
    "neconforme": "neconform",
    "neconformei": "neconform",
    "neconformele": "neconform",
    "neconformelor": "neconform",
    "neconformi": "neconform",
    "neconformii": "neconform",
    "neconformilor": "neconform",
    "neconformata": "neconformat",
    "neconformată": "neconformat",
    "neconformate": "neconformat",
    "neconformatei": "neconformat",
    "neconformatele": "neconformat",
    "neconformatelor": "neconformat",
    "neconformați": "neconformat",
    "neconformații": "neconformat",
    "neconformaților": "neconformat",
    "neconformatul": "neconformat",
    "neconformatului": "neconformat",
    "neconformismul": "neconformism",
    "neconformismului": "neconformism",
    "neconformista": "neconformist",
    "neconformistă": "neconformist",
    "neconformiste": "neconformist",
    "neconformistei": "neconformist",
    "neconformistele": "neconformist",
    "neconformistelor": "neconformist",
    "neconformiști": "neconformist",
    "neconformiștii": "neconformist",
    "neconformiștilor": "neconformist",
    "neconformistul": "neconformist",
    "neconformistului": "neconformist",
    "neconformista": "neconformistă",
    "neconformiste": "neconformistă",
    "neconformistei": "neconformistă",
    "neconformistele": "neconformistă",
    "neconformistelor": "neconformistă",
    "neconfruntată": "neconfruntat",
    "neconfruntate": "neconfruntat",
    "neconfruntați": "neconfruntat",
    "neconfundata": "neconfundat",
    "neconfundată": "neconfundat",
    "neconfundate": "neconfundat",
    "neconfundatei": "neconfundat",
    "neconfundatele": "neconfundat",
    "neconfundatelor": "neconfundat",
    "neconfundați": "neconfundat",
    "neconfundații": "neconfundat",
    "neconfundaților": "neconfundat",
    "neconfundatul": "neconfundat",
    "neconfundatului": "neconfundat",
    "necongelata": "necongelat",
    "necongelată": "necongelat",
    "necongelate": "necongelat",
    "necongelatei": "necongelat",
    "necongelatele": "necongelat",
    "necongelatelor": "necongelat",
    "necongelați": "necongelat",
    "necongelații": "necongelat",
    "necongelaților": "necongelat",
    "necongelatul": "necongelat",
    "necongelatului": "necongelat",
    "necongestionata": "necongestionat",
    "necongestionată": "necongestionat",
    "necongestionate": "necongestionat",
    "necongestionatei": "necongestionat",
    "necongestionatele": "necongestionat",
    "necongestionatelor": "necongestionat",
    "necongestionați": "necongestionat",
    "necongestionații": "necongestionat",
    "necongestionaților": "necongestionat",
    "necongestionatul": "necongestionat",
    "necongestionatului": "necongestionat",
    "neconjugata": "neconjugat",
    "neconjugată": "neconjugat",
    "neconjugate": "neconjugat",
    "neconjugatei": "neconjugat",
    "neconjugatele": "neconjugat",
    "neconjugatelor": "neconjugat",
    "neconjugați": "neconjugat",
    "neconjugații": "neconjugat",
    "neconjugaților": "neconjugat",
    "neconjugatul": "neconjugat",
    "neconjugatului": "neconjugat",
    "neconjurată": "neconjurat",
    "neconjurate": "neconjurat",
    "neconjurați": "neconjurat",
    "neconsacrata": "neconsacrat",
    "neconsacrată": "neconsacrat",
    "neconsacrate": "neconsacrat",
    "neconsacratei": "neconsacrat",
    "neconsacratele": "neconsacrat",
    "neconsacratelor": "neconsacrat",
    "neconsacrați": "neconsacrat",
    "neconsacrații": "neconsacrat",
    "neconsacraților": "neconsacrat",
    "neconsacratul": "neconsacrat",
    "neconsacratului": "neconsacrat",
    "neconsemnată": "neconsemnat",
    "neconsemnate": "neconsemnat",
    "neconsemnați": "neconsemnat",
    "neconservată": "neconservat",
    "neconservate": "neconservat",
    "neconservați": "neconservat",
    "neconsiderată": "neconsiderat",
    "neconsiderate": "neconsiderat",
    "neconsiderați": "neconsiderat",
    "neconsiliată": "neconsiliat",
    "neconsiliate": "neconsiliat",
    "neconsiliați": "neconsiliat",
    "neconsistată": "neconsistat",
    "neconsistate": "neconsistat",
    "neconsistați": "neconsistat",
    "neconsolata": "neconsolat",
    "neconsolată": "neconsolat",
    "neconsolate": "neconsolat",
    "neconsolatei": "neconsolat",
    "neconsolatele": "neconsolat",
    "neconsolatelor": "neconsolat",
    "neconsolați": "neconsolat",
    "neconsolații": "neconsolat",
    "neconsolaților": "neconsolat",
    "neconsolatul": "neconsolat",
    "neconsolatului": "neconsolat",
    "neconsolidată": "neconsolidat",
    "neconsolidate": "neconsolidat",
    "neconsolidați": "neconsolidat",
    "neconspectată": "neconspectat",
    "neconspectate": "neconspectat",
    "neconspectați": "neconspectat",
    "neconspirată": "neconspirat",
    "neconspirate": "neconspirat",
    "neconspirați": "neconspirat",
    "neconstată": "neconstat",
    "neconstate": "neconstat",
    "neconstați": "neconstat",
    "neconstatată": "neconstatat",
    "neconstatate": "neconstatat",
    "neconstatați": "neconstatat",
    "neconsternata": "neconsternat",
    "neconsternată": "neconsternat",
    "neconsternate": "neconsternat",
    "neconsternatei": "neconsternat",
    "neconsternatele": "neconsternat",
    "neconsternatelor": "neconsternat",
    "neconsternați": "neconsternat",
    "neconsternații": "neconsternat",
    "neconsternaților": "neconsternat",
    "neconsternatul": "neconsternat",
    "neconsternatului": "neconsternat",
    "neconștientizata": "neconștientizat",
    "neconștientizată": "neconștientizat",
    "neconștientizate": "neconștientizat",
    "neconștientizatei": "neconștientizat",
    "neconștientizatele": "neconștientizat",
    "neconștientizatelor": "neconștientizat",
    "neconștientizați": "neconștientizat",
    "neconștientizații": "neconștientizat",
    "neconștientizaților": "neconștientizat",
    "neconștientizatul": "neconștientizat",
    "neconștientizatului": "neconștientizat",
    "neconstipata": "neconstipat",
    "neconstipată": "neconstipat",
    "neconstipate": "neconstipat",
    "neconstipatei": "neconstipat",
    "neconstipatele": "neconstipat",
    "neconstipatelor": "neconstipat",
    "neconstipați": "neconstipat",
    "neconstipații": "neconstipat",
    "neconstipaților": "neconstipat",
    "neconstipatul": "neconstipat",
    "neconstipatului": "neconstipat",
    "neconstituita": "neconstituit",
    "neconstituită": "neconstituit",
    "neconstituite": "neconstituit",
    "neconstituitei": "neconstituit",
    "neconstituitele": "neconstituit",
    "neconstituitelor": "neconstituit",
    "neconstituiți": "neconstituit",
    "neconstituiții": "neconstituit",
    "neconstituiților": "neconstituit",
    "neconstituitul": "neconstituit",
    "neconstituitului": "neconstituit",
    "neconstituționala": "neconstituțional",
    "neconstituțională": "neconstituțional",
    "neconstituționale": "neconstituțional",
    "neconstituționalei": "neconstituțional",
    "neconstituționalele": "neconstituțional",
    "neconstituționalelor": "neconstituțional",
    "neconstituționali": "neconstituțional",
    "neconstituționalii": "neconstituțional",
    "neconstituționalilor": "neconstituțional",
    "neconstruită": "neconstruit",
    "neconstruite": "neconstruit",
    "neconstruiți": "neconstruit",
    "neconsultată": "neconsultat",
    "neconsultate": "neconsultat",
    "neconsultați": "neconsultat",
    "neconsumată": "neconsumat",
    "neconsumate": "neconsumat",
    "neconsumați": "neconsumat",
    "necontabilizată": "necontabilizat",
    "necontabilizate": "necontabilizat",
    "necontabilizați": "necontabilizat",
    "necontagiată": "necontagiat",
    "necontagiate": "necontagiat",
    "necontagiați": "necontagiat",
    "necontaminată": "necontaminat",
    "necontaminate": "necontaminat",
    "necontaminați": "necontaminat",
    "necontată": "necontat",
    "necontate": "necontat",
    "necontați": "necontat",
    "necontemplată": "necontemplat",
    "necontemplate": "necontemplat",
    "necontemplați": "necontemplat",
    "necontenita": "necontenit",
    "necontenită": "necontenit",
    "necontenite": "necontenit",
    "necontenitei": "necontenit",
    "necontenitele": "necontenit",
    "necontenitelor": "necontenit",
    "neconteniți": "necontenit",
    "neconteniții": "necontenit",
    "neconteniților": "necontenit",
    "necontenitul": "necontenit",
    "necontenitului": "necontenit",
    "necontestata": "necontestat",
    "necontestată": "necontestat",
    "necontestate": "necontestat",
    "necontestatei": "necontestat",
    "necontestatele": "necontestat",
    "necontestatelor": "necontestat",
    "necontestați": "necontestat",
    "necontestații": "necontestat",
    "necontestaților": "necontestat",
    "necontestatul": "necontestat",
    "necontestatului": "necontestat",
    "necontinuată": "necontinuat",
    "necontinuate": "necontinuat",
    "necontinuați": "necontinuat",
    "neconținută": "neconținut",
    "neconținute": "neconținut",
    "neconținuți": "neconținut",
    "necontopită": "necontopit",
    "necontopite": "necontopit",
    "necontopiți": "necontopit",
    "necontorsionată": "necontorsionat",
    "necontorsionate": "necontorsionat",
    "necontorsionați": "necontorsionat",
    "necontracarată": "necontracarat",
    "necontracarate": "necontracarat",
    "necontracarați": "necontracarat",
    "necontractată": "necontractat",
    "necontractate": "necontractat",
    "necontractați": "necontractat",
    "necontramandată": "necontramandat",
    "necontramandate": "necontramandat",
    "necontramandați": "necontramandat",
    "necontrariata": "necontrariat",
    "necontrariată": "necontrariat",
    "necontrariate": "necontrariat",
    "necontrariatei": "necontrariat",
    "necontrariatele": "necontrariat",
    "necontrariatelor": "necontrariat",
    "necontrariați": "necontrariat",
    "necontrariații": "necontrariat",
    "necontrariaților": "necontrariat",
    "necontrariatul": "necontrariat",
    "necontrariatului": "necontrariat",
    "necontrasa": "necontras",
    "necontrasă": "necontras",
    "necontrase": "necontras",
    "necontrasei": "necontras",
    "necontrasele": "necontras",
    "necontraselor": "necontras",
    "necontrași": "necontras",
    "necontrașii": "necontras",
    "necontrașilor": "necontras",
    "necontrasul": "necontras",
    "necontrasului": "necontras",
    "necontrastată": "necontrastat",
    "necontrastate": "necontrastat",
    "necontrastați": "necontrastat",
    "necontravenită": "necontravenit",
    "necontravenite": "necontravenit",
    "necontraveniți": "necontravenit",
    "necontrazisă": "necontrazis",
    "necontrazise": "necontrazis",
    "necontraziși": "necontrazis",
    "necontribuită": "necontribuit",
    "necontribuite": "necontribuit",
    "necontribuiți": "necontribuit",
    "necontrolata": "necontrolat",
    "necontrolată": "necontrolat",
    "necontrolate": "necontrolat",
    "necontrolatei": "necontrolat",
    "necontrolatele": "necontrolat",
    "necontrolatelor": "necontrolat",
    "necontrolați": "necontrolat",
    "necontrolații": "necontrolat",
    "necontrolaților": "necontrolat",
    "necontrolatul": "necontrolat",
    "necontrolatului": "necontrolat",
    "neconturata": "neconturat",
    "neconturată": "neconturat",
    "neconturate": "neconturat",
    "neconturatei": "neconturat",
    "neconturatele": "neconturat",
    "neconturatelor": "neconturat",
    "neconturați": "neconturat",
    "neconturații": "neconturat",
    "neconturaților": "neconturat",
    "neconturatul": "neconturat",
    "neconturatului": "neconturat",
    "neconturbată": "neconturbat",
    "neconturbate": "neconturbat",
    "neconturbați": "neconturbat",
    "necontuzionată": "necontuzionat",
    "necontuzionate": "necontuzionat",
    "necontuzionați": "necontuzionat",
    "neconvenită": "neconvenit",
    "neconvenite": "neconvenit",
    "neconveniți": "neconvenit",
    "neconversă": "neconvers",
    "neconverse": "neconvers",
    "neconverși": "neconvers",
    "neconversată": "neconversat",
    "neconversate": "neconversat",
    "neconversați": "neconversat",
    "neconvertită": "neconvertit",
    "neconvertite": "neconvertit",
    "neconvertiți": "neconvertit",
    "neconvingătoare": "neconvingător",
    "neconvingătoarea": "neconvingător",
    "neconvingătoarei": "neconvingător",
    "neconvingătoarele": "neconvingător",
    "neconvingătoarelor": "neconvingător",
    "neconvingători": "neconvingător",
    "neconvingătorii": "neconvingător",
    "neconvingătorilor": "neconvingător",
    "neconvingătorul": "neconvingător",
    "neconvingătorului": "neconvingător",
    "neconvinsa": "neconvins",
    "neconvinsă": "neconvins",
    "neconvinse": "neconvins",
    "neconvinsei": "neconvins",
    "neconvinsele": "neconvins",
    "neconvinselor": "neconvins",
    "neconvinși": "neconvins",
    "neconvinșii": "neconvins",
    "neconvinșilor": "neconvins",
    "neconvinsul": "neconvins",
    "neconvinsului": "neconvins",
    "neconvocată": "neconvocat",
    "neconvocate": "neconvocat",
    "neconvocați": "neconvocat",
    "neconvulsionata": "neconvulsionat",
    "neconvulsionată": "neconvulsionat",
    "neconvulsionate": "neconvulsionat",
    "neconvulsionatei": "neconvulsionat",
    "neconvulsionatele": "neconvulsionat",
    "neconvulsionatelor": "neconvulsionat",
    "neconvulsionați": "neconvulsionat",
    "neconvulsionații": "neconvulsionat",
    "neconvulsionaților": "neconvulsionat",
    "neconvulsionatul": "neconvulsionat",
    "neconvulsionatului": "neconvulsionat",
    "necooperată": "necooperat",
    "necooperate": "necooperat",
    "necooperați": "necooperat",
    "necooptată": "necooptat",
    "necooptate": "necooptat",
    "necooptați": "necooptat",
    "necoordonata": "necoordonat",
    "necoordonată": "necoordonat",
    "necoordonate": "necoordonat",
    "necoordonatei": "necoordonat",
    "necoordonatele": "necoordonat",
    "necoordonatelor": "necoordonat",
    "necoordonați": "necoordonat",
    "necoordonații": "necoordonat",
    "necoordonaților": "necoordonat",
    "necoordonatul": "necoordonat",
    "necoordonatului": "necoordonat",
    "necopiată": "necopiat",
    "necopiate": "necopiat",
    "necopiați": "necopiat",
    "necopilărită": "necopilărit",
    "necopilărite": "necopilărit",
    "necopilăriți": "necopilărit",
    "necopleșită": "necopleșit",
    "necopleșite": "necopleșit",
    "necopleșiți": "necopleșit",
    "necoapta": "necopt",
    "necoaptă": "necopt",
    "necoapte": "necopt",
    "necoaptei": "necopt",
    "necoaptele": "necopt",
    "necoaptelor": "necopt",
    "necopți": "necopt",
    "necopții": "necopt",
    "necopților": "necopt",
    "necoptul": "necopt",
    "necoptului": "necopt",
    "necopulată": "necopulat",
    "necopulate": "necopulat",
    "necopulați": "necopulat",
    "necorcita": "necorcit",
    "necorcită": "necorcit",
    "necorcite": "necorcit",
    "necorcitei": "necorcit",
    "necorcitele": "necorcit",
    "necorcitelor": "necorcit",
    "necorciți": "necorcit",
    "necorciții": "necorcit",
    "necorciților": "necorcit",
    "necorcitul": "necorcit",
    "necorcitului": "necorcit",
    "necorectată": "necorectat",
    "necorectate": "necorectat",
    "necorectați": "necorectat",
    "necorespondată": "necorespondat",
    "necorespondate": "necorespondat",
    "necorespondați": "necorespondat",
    "necorespunsă": "necorespuns",
    "necorespunse": "necorespuns",
    "necorespunși": "necorespuns",
    "necorespunzătoare": "necorespunzător",
    "necorespunzătoarea": "necorespunzător",
    "necorespunzătoarei": "necorespunzător",
    "necorespunzătoarele": "necorespunzător",
    "necorespunzătoarelor": "necorespunzător",
    "necorespunzători": "necorespunzător",
    "necorespunzătorii": "necorespunzător",
    "necorespunzătorilor": "necorespunzător",
    "necorespunzătorul": "necorespunzător",
    "necorespunzătorului": "necorespunzător",
    "necorijată": "necorijat",
    "necorijate": "necorijat",
    "necorijați": "necorijat",
    "necoroborată": "necoroborat",
    "necoroborate": "necoroborat",
    "necoroborați": "necoroborat",
    "necoroiata": "necoroiat",
    "necoroiată": "necoroiat",
    "necoroiate": "necoroiat",
    "necoroiatei": "necoroiat",
    "necoroiatele": "necoroiat",
    "necoroiatelor": "necoroiat",
    "necoroiați": "necoroiat",
    "necoroiații": "necoroiat",
    "necoroiaților": "necoroiat",
    "necoroiatul": "necoroiat",
    "necoroiatului": "necoroiat",
    "necorupta": "necorupt",
    "necoruptă": "necorupt",
    "necorupte": "necorupt",
    "necoruptei": "necorupt",
    "necoruptele": "necorupt",
    "necoruptelor": "necorupt",
    "necorupți": "necorupt",
    "necorupții": "necorupt",
    "necorupților": "necorupt",
    "necoruptul": "necorupt",
    "necoruptului": "necorupt",
    "necoșcovita": "necoșcovit",
    "necoșcovită": "necoșcovit",
    "necoșcovite": "necoșcovit",
    "necoșcovitei": "necoșcovit",
    "necoșcovitele": "necoșcovit",
    "necoșcovitelor": "necoșcovit",
    "necoșcoviți": "necoșcovit",
    "necoșcoviții": "necoșcovit",
    "necoșcoviților": "necoșcovit",
    "necoșcovitul": "necoșcovit",
    "necoșcovitului": "necoșcovit",
    "necosită": "necosit",
    "necosite": "necosit",
    "necosiți": "necosit",
    "necosorâtă": "necosorât",
    "necosorâte": "necosorât",
    "necosorâți": "necosorât",
    "necostată": "necostat",
    "necostate": "necostat",
    "necostați": "necostat",
    "necostumata": "necostumat",
    "necostumată": "necostumat",
    "necostumate": "necostumat",
    "necostumatei": "necostumat",
    "necostumatele": "necostumat",
    "necostumatelor": "necostumat",
    "necostumați": "necostumat",
    "necostumații": "necostumat",
    "necostumaților": "necostumat",
    "necostumatul": "necostumat",
    "necostumatului": "necostumat",
    "necotată": "necotat",
    "necotate": "necotat",
    "necotați": "necotat",
    "necotcodăcită": "necotcodăcit",
    "necotcodăcite": "necotcodăcit",
    "necotcodăciți": "necotcodăcit",
    "necotita": "necotit",
    "necotită": "necotit",
    "necotite": "necotit",
    "necotitei": "necotit",
    "necotitele": "necotit",
    "necotitelor": "necotit",
    "necotiți": "necotit",
    "necotiții": "necotit",
    "necotiților": "necotit",
    "necotitul": "necotit",
    "necotitului": "necotit",
    "necotizată": "necotizat",
    "necotizate": "necotizat",
    "necotizați": "necotizat",
    "necotonogită": "necotonogit",
    "necotonogite": "necotonogit",
    "necotonogiți": "necotonogit",
    "necotrobăită": "necotrobăit",
    "necotrobăite": "necotrobăit",
    "necotrobăiți": "necotrobăit",
    "necotropită": "necotropit",
    "necotropite": "necotropit",
    "necotropiți": "necotropit",
    "necovârșită": "necovârșit",
    "necovârșite": "necovârșit",
    "necovârșiți": "necovârșit",
    "necovăsită": "necovăsit",
    "necovăsite": "necovăsit",
    "necovăsiți": "necovăsit",
    "necovăsiții": "necovăsit",
    "necovăsiților": "necovăsit",
    "necovăsitul": "necovăsit",
    "necovăsitului": "necovăsit",
    "necrăcănata": "necrăcănat",
    "necrăcănată": "necrăcănat",
    "necrăcănate": "necrăcănat",
    "necrăcănatei": "necrăcănat",
    "necrăcănatele": "necrăcănat",
    "necrăcănatelor": "necrăcănat",
    "necrăcănați": "necrăcănat",
    "necrăcănații": "necrăcănat",
    "necrăcănaților": "necrăcănat",
    "necrăcănatul": "necrăcănat",
    "necrăcănatului": "necrăcănat",
    "necrăcita": "necrăcit",
    "necrăcită": "necrăcit",
    "necrăcite": "necrăcit",
    "necrăcitei": "necrăcit",
    "necrăcitele": "necrăcit",
    "necrăcitelor": "necrăcit",
    "necrăciți": "necrăcit",
    "necrăciții": "necrăcit",
    "necrăciților": "necrăcit",
    "necrăcitul": "necrăcit",
    "necrăcitului": "necrăcit",
    "necrâcnită": "necrâcnit",
    "necrâcnite": "necrâcnit",
    "necrâcniți": "necrâcnit",
    "necramponată": "necramponat",
    "necramponate": "necramponat",
    "necramponați": "necramponat",
    "necrâmpoțită": "necrâmpoțit",
    "necrâmpoțite": "necrâmpoțit",
    "necrâmpoțiți": "necrâmpoțit",
    "necrănțănită": "necrănțănit",
    "necrănțănite": "necrănțănit",
    "necrănțăniți": "necrănțănit",
    "necrăpata": "necrăpat",
    "necrăpată": "necrăpat",
    "necrăpate": "necrăpat",
    "necrăpatei": "necrăpat",
    "necrăpatele": "necrăpat",
    "necrăpatelor": "necrăpat",
    "necrăpați": "necrăpat",
    "necrăpații": "necrăpat",
    "necrăpaților": "necrăpat",
    "necrăpatul": "necrăpat",
    "necrăpatului": "necrăpat",
    "necravașată": "necravașat",
    "necravașate": "necravașat",
    "necravașați": "necravașat",
    "necreată": "necreat",
    "necreate": "necreat",
    "necreați": "necreat",
    "necredincioasa": "necredincioasă",
    "necredincioase": "necredincioasă",
    "necredincioasei": "necredincioasă",
    "necredincioasele": "necredincioasă",
    "necredincioaselor": "necredincioasă",
    "necredincioasa": "necredincios",
    "necredincioasă": "necredincios",
    "necredincioase": "necredincios",
    "necredincioasei": "necredincios",
    "necredincioasele": "necredincios",
    "necredincioaselor": "necredincios",
    "necredincioși": "necredincios",
    "necredincioșii": "necredincios",
    "necredincioșilor": "necredincios",
    "necredinciosul": "necredincios",
    "necredinciosului": "necredincios",
    "necredința": "necredință",
    "necredințe": "necredință",
    "necredinței": "necredință",
    "necredințele": "necredință",
    "necredințelor": "necredință",
    "necreditată": "necreditat",
    "necreditate": "necreditat",
    "necreditați": "necreditat",
    "necreionată": "necreionat",
    "necreionate": "necreionat",
    "necreionați": "necreionat",
    "necrescuta": "necrescut",
    "necrescută": "necrescut",
    "necrescute": "necrescut",
    "necrescutei": "necrescut",
    "necrescutele": "necrescut",
    "necrescutelor": "necrescut",
    "necrescuți": "necrescut",
    "necrescuții": "necrescut",
    "necrescuților": "necrescut",
    "necrescutul": "necrescut",
    "necrescutului": "necrescut",
    "necrestata": "necrestat",
    "necrestată": "necrestat",
    "necrestate": "necrestat",
    "necrestatei": "necrestat",
    "necrestatele": "necrestat",
    "necrestatelor": "necrestat",
    "necrestați": "necrestat",
    "necrestații": "necrestat",
    "necrestaților": "necrestat",
    "necrestatul": "necrestat",
    "necrestatului": "necrestat",
    "necreștina": "necreștin",
    "necreștină": "necreștin",
    "necreștine": "necreștin",
    "necreștinei": "necreștin",
    "necreștinele": "necreștin",
    "necreștinelor": "necreștin",
    "necreștini": "necreștin",
    "necreștinii": "necreștin",
    "necreștinilor": "necreștin",
    "necreștinul": "necreștin",
    "necreștinului": "necreștin",
    "necreștinată": "necreștinat",
    "necreștinate": "necreștinat",
    "necreștinați": "necreștinat",
    "necrezuta": "necrezut",
    "necrezută": "necrezut",
    "necrezute": "necrezut",
    "necrezutei": "necrezut",
    "necrezutele": "necrezut",
    "necrezutelor": "necrezut",
    "necrezuți": "necrezut",
    "necrezuții": "necrezut",
    "necrezuților": "necrezut",
    "necrezutul": "necrezut",
    "necrezutului": "necrezut",
    "necrispata": "necrispat",
    "necrispată": "necrispat",
    "necrispate": "necrispat",
    "necrispatei": "necrispat",
    "necrispatele": "necrispat",
    "necrispatelor": "necrispat",
    "necrispați": "necrispat",
    "necrispații": "necrispat",
    "necrispaților": "necrispat",
    "necrispatul": "necrispat",
    "necrispatului": "necrispat",
    "necristalizată": "necristalizat",
    "necristalizate": "necristalizat",
    "necristalizați": "necristalizat",
    "necriticată": "necriticat",
    "necriticate": "necriticat",
    "necriticați": "necriticat",
    "necrofaga": "necrofag",
    "necrofagă": "necrofag",
    "necrofage": "necrofag",
    "necrofagei": "necrofag",
    "necrofagele": "necrofag",
    "necrofagelor": "necrofag",
    "necrofagi": "necrofag",
    "necrofagii": "necrofag",
    "necrofagilor": "necrofag",
    "necrofagul": "necrofag",
    "necrofagului": "necrofag",
    "necrofaga": "necrofagă",
    "necrofage": "necrofagă",
    "necrofagei": "necrofagă",
    "necrofagele": "necrofagă",
    "necrofagelor": "necrofagă",
    "necrofagia": "necrofagie",
    "necrofagiei": "necrofagie",
    "necrofagii": "necrofagie",
    "necrofagiile": "necrofagie",
    "necrofagiilor": "necrofagie",
    "necrofori": "necrofor",
    "necroforii": "necrofor",
    "necroforilor": "necrofor",
    "necroforul": "necrofor",
    "necroforului": "necrofor",
    "necroită": "necroit",
    "necroite": "necroit",
    "necroiți": "necroit",
    "necrologul": "necrolog",
    "necrologului": "necrolog",
    "necrologuri": "necrolog",
    "necrologurile": "necrolog",
    "necrologurilor": "necrolog",
    "necrologia": "necrologie",
    "necrologiei": "necrologie",
    "necrologii": "necrologie",
    "necrologiile": "necrologie",
    "necrologiilor": "necrologie",
    "necromani": "necroman",
    "necromanii": "necroman",
    "necromanilor": "necroman",
    "necromanul": "necroman",
    "necromanului": "necroman",
    "necromana": "necromană",
    "necromane": "necromană",
    "necromanei": "necromană",
    "necromanele": "necromană",
    "necromanelor": "necromană",
    "necromanți": "necromant",
    "necromanții": "necromant",
    "necromanților": "necromant",
    "necromantul": "necromant",
    "necromantului": "necromant",
    "necromanta": "necromantă",
    "necromante": "necromantă",
    "necromantei": "necromantă",
    "necromantele": "necromantă",
    "necromantelor": "necromantă",
    "necromantica": "necromantic",
    "necromantică": "necromantic",
    "necromantice": "necromantic",
    "necromanticei": "necromantic",
    "necromanticele": "necromantic",
    "necromanticelor": "necromantic",
    "necromantici": "necromantic",
    "necromanticii": "necromantic",
    "necromanticilor": "necromantic",
    "necromanticul": "necromantic",
    "necromanticului": "necromantic",
    "necromanția": "necromanție",
    "necromanției": "necromanție",
    "necromanții": "necromanție",
    "necromanțiile": "necromanție",
    "necromanțiilor": "necromanție",
    "necromata": "necromat",
    "necromată": "necromat",
    "necromate": "necromat",
    "necromatei": "necromat",
    "necromatele": "necromat",
    "necromatelor": "necromat",
    "necromați": "necromat",
    "necromații": "necromat",
    "necromaților": "necromat",
    "necromatul": "necromat",
    "necromatului": "necromat",
    "necroncănită": "necroncănit",
    "necroncănite": "necroncănit",
    "necroncăniți": "necroncănit",
    "necronometrată": "necronometrat",
    "necronometrate": "necronometrat",
    "necronometrați": "necronometrat",
    "necropola": "necropolă",
    "necropole": "necropolă",
    "necropolei": "necropolă",
    "necropolele": "necropolă",
    "necropolelor": "necropolă",
    "necroșetată": "necroșetat",
    "necroșetate": "necroșetat",
    "necroșetați": "necroșetat",
    "necrotomia": "necrotomie",
    "necrotomiei": "necrotomie",
    "necrotomii": "necrotomie",
    "necrotomiile": "necrotomie",
    "necrotomiilor": "necrotomie",
    "necroză": "necroza",
    "necrozai": "necroza",
    "necrozam": "necroza",
    "necrozăm": "necroza",
    "necrozând": "necroza",
    "necrozându": "necroza",
    "necrozară": "necroza",
    "necrozarăm": "necroza",
    "necrozarăți": "necroza",
    "necrozase": "necroza",
    "necrozasem": "necroza",
    "necrozaseră": "necroza",
    "necrozaserăm": "necroza",
    "necrozaserăți": "necroza",
    "necrozaseși": "necroza",
    "necrozași": "necroza",
    "necrozat": "necroza",
    "necrozați": "necroza",
    "necrozau": "necroza",
    "necrozează": "necroza",
    "necrozez": "necroza",
    "necrozeze": "necroza",
    "necrozezi": "necroza",
    "nemainecrozându": "necroza",
    "nenecrozându": "necroza",
    "necroza": "necroză",
    "necroze": "necroză",
    "necrozei": "necroză",
    "necrozele": "necroză",
    "necrozelor": "necroză",
    "necrozata": "necrozat",
    "necrozată": "necrozat",
    "necrozate": "necrozat",
    "necrozatei": "necrozat",
    "necrozatele": "necrozat",
    "necrozatelor": "necrozat",
    "necrozați": "necrozat",
    "necrozații": "necrozat",
    "necrozaților": "necrozat",
    "necrozatul": "necrozat",
    "necrozatului": "necrozat",
    "necrucificată": "necrucificat",
    "necrucificate": "necrucificat",
    "necrucificați": "necrucificat",
    "necrucita": "necrucit",
    "necrucită": "necrucit",
    "necrucite": "necrucit",
    "necrucitei": "necrucit",
    "necrucitele": "necrucit",
    "necrucitelor": "necrucit",
    "necruciți": "necrucit",
    "necruciții": "necrucit",
    "necruciților": "necrucit",
    "necrucitul": "necrucit",
    "necrucitului": "necrucit",
    "necruțarea": "necruțare",
    "necruțari": "necruțare",
    "necruțarii": "necruțare",
    "necruțarile": "necruțare",
    "necruțarilor": "necruțare",
    "necruțată": "necruțat",
    "necruțate": "necruțat",
    "necruțați": "necruțat",
    "necruțătoare": "necruțător",
    "necruțătoarea": "necruțător",
    "necruțătoarei": "necruțător",
    "necruțătoarele": "necruțător",
    "necruțătoarelor": "necruțător",
    "necruțători": "necruțător",
    "necruțătorii": "necruțător",
    "necruțătorilor": "necruțător",
    "necruțătorul": "necruțător",
    "necruțătorului": "necruțător",
    "nectare": "nectar",
    "nectarele": "nectar",
    "nectarelor": "nectar",
    "nectarul": "nectar",
    "nectarului": "nectar",
    "nectariile": "nectarii",
    "nectariilor": "nectarii",
    "nectitorită": "nectitorit",
    "nectitorite": "nectitorit",
    "nectitoriți": "nectitorit",
    "nectonul": "necton",
    "nectonului": "necton",
    "necucerită": "necucerit",
    "necucerite": "necucerit",
    "necuceriți": "necucerit",
    "necucernica": "necucernic",
    "necucernică": "necucernic",
    "necucernice": "necucernic",
    "necucernicei": "necucernic",
    "necucernicele": "necucernic",
    "necucernicelor": "necucernic",
    "necucernici": "necucernic",
    "necucernicii": "necucernic",
    "necucernicilor": "necucernic",
    "necucernico": "necucernic",
    "necucernicul": "necucernic",
    "necucernicule": "necucernic",
    "necucernicului": "necucernic",
    "necucernicia": "necucernicie",
    "necucerniciei": "necucernicie",
    "necucernicii": "necucernicie",
    "necucerniciile": "necucernicie",
    "necucerniciilor": "necucernicie",
    "necucernicio": "necucernicie",
    "necuconită": "necuconit",
    "necuconite": "necuconit",
    "necuconiți": "necuconit",
    "necucurigată": "necucurigat",
    "necucurigate": "necucurigat",
    "necucurigați": "necucurigat",
    "necufundată": "necufundat",
    "necufundate": "necufundat",
    "necufundați": "necufundat",
    "necugetarea": "necugetare",
    "necugetări": "necugetare",
    "necugetării": "necugetare",
    "necugetările": "necugetare",
    "necugetărilor": "necugetare",
    "necugetata": "necugetat",
    "necugetată": "necugetat",
    "necugetate": "necugetat",
    "necugetatei": "necugetat",
    "necugetatele": "necugetat",
    "necugetatelor": "necugetat",
    "necugetați": "necugetat",
    "necugetații": "necugetat",
    "necugetaților": "necugetat",
    "necugetatul": "necugetat",
    "necugetatului": "necugetat",
    "necuibărită": "necuibărit",
    "necuibărite": "necuibărit",
    "necuibăriți": "necuibărit",
    "necuibată": "necuibat",
    "necuibate": "necuibat",
    "necuibați": "necuibat",
    "neculcată": "neculcat",
    "neculcate": "neculcat",
    "neculcați": "neculcat",
    "neculeasă": "necules",
    "neculese": "necules",
    "neculeși": "necules",
    "neculminată": "neculminat",
    "neculminate": "neculminat",
    "neculminați": "neculminat",
    "necultivată": "necultivat",
    "necultivate": "necultivat",
    "necultivați": "necultivat",
    "neculturalizată": "neculturalizat",
    "neculturalizate": "neculturalizat",
    "neculturalizați": "neculturalizat",
    "necuminecată": "necuminecat",
    "necuminecate": "necuminecat",
    "necuminecați": "necuminecat",
    "necumpănirea": "necumpănire",
    "necumpăniri": "necumpănire",
    "necumpănirii": "necumpănire",
    "necumpănirile": "necumpănire",
    "necumpănirilor": "necumpănire",
    "necumpănita": "necumpănit",
    "necumpănită": "necumpănit",
    "necumpănite": "necumpănit",
    "necumpănitei": "necumpănit",
    "necumpănitele": "necumpănit",
    "necumpănitelor": "necumpănit",
    "necumpăniți": "necumpănit",
    "necumpăniții": "necumpănit",
    "necumpăniților": "necumpănit",
    "necumpănitul": "necumpănit",
    "necumpănitului": "necumpănit",
    "necumpărată": "necumpărat",
    "necumpărate": "necumpărat",
    "necumpărați": "necumpărat",
    "necumpătata": "necumpătat",
    "necumpătată": "necumpătat",
    "necumpătate": "necumpătat",
    "necumpătatei": "necumpătat",
    "necumpătatele": "necumpătat",
    "necumpătatelor": "necumpătat",
    "necumpătați": "necumpătat",
    "necumpătații": "necumpătat",
    "necumpătaților": "necumpătat",
    "necumpătatul": "necumpătat",
    "necumpătatului": "necumpătat",
    "necumpătata": "necumpătată",
    "necumpătate": "necumpătată",
    "necumpătatei": "necumpătată",
    "necumpătatele": "necumpătată",
    "necumpătatelor": "necumpătată",
    "necumulată": "necumulat",
    "necumulate": "necumulat",
    "necumulați": "necumulat",
    "necunoașterea": "necunoaștere",
    "necunoașteri": "necunoaștere",
    "necunoașterii": "necunoaștere",
    "necunoașterile": "necunoaștere",
    "necunoașterilor": "necunoaștere",
    "necunoscătoare": "necunoscător",
    "necunoscătoarea": "necunoscător",
    "necunoscătoarei": "necunoscător",
    "necunoscătoarele": "necunoscător",
    "necunoscătoarelor": "necunoscător",
    "necunoscători": "necunoscător",
    "necunoscătorii": "necunoscător",
    "necunoscătorilor": "necunoscător",
    "necunoscătorul": "necunoscător",
    "necunoscătorului": "necunoscător",
    "necunoscuta": "necunoscut",
    "necunoscută": "necunoscut",
    "necunoscute": "necunoscut",
    "necunoscutei": "necunoscut",
    "necunoscutele": "necunoscut",
    "necunoscutelor": "necunoscut",
    "necunoscuți": "necunoscut",
    "necunoscuții": "necunoscut",
    "necunoscuților": "necunoscut",
    "necunoscutul": "necunoscut",
    "necunoscutului": "necunoscut",
    "necunoscuta": "necunoscută",
    "necunoscute": "necunoscută",
    "necunoscutei": "necunoscută",
    "necunoscutele": "necunoscută",
    "necunoscutelor": "necunoscută",
    "necunoștința": "necunoștință",
    "necunoștințe": "necunoștință",
    "necunoștinței": "necunoștință",
    "necunoștințele": "necunoștință",
    "necunoștințelor": "necunoștință",
    "necununata": "necununat",
    "necununată": "necununat",
    "necununate": "necununat",
    "necununatei": "necununat",
    "necununatele": "necununat",
    "necununatelor": "necununat",
    "necununați": "necununat",
    "necununații": "necununat",
    "necununaților": "necununat",
    "necununatul": "necununat",
    "necununatului": "necununat",
    "necuplata": "necuplat",
    "necuplată": "necuplat",
    "necuplate": "necuplat",
    "necuplatei": "necuplat",
    "necuplatele": "necuplat",
    "necuplatelor": "necuplat",
    "necuplați": "necuplat",
    "necuplații": "necuplat",
    "necuplaților": "necuplat",
    "necuplatul": "necuplat",
    "necuplatului": "necuplat",
    "necuprinsa": "necuprins",
    "necuprinsă": "necuprins",
    "necuprinse": "necuprins",
    "necuprinsei": "necuprins",
    "necuprinsele": "necuprins",
    "necuprinselor": "necuprins",
    "necuprinși": "necuprins",
    "necuprinșii": "necuprins",
    "necuprinșilor": "necuprins",
    "necuprinsul": "necuprins",
    "necuprinsului": "necuprins",
    "necuprinsa": "necuprinsă",
    "necuprinse": "necuprinsă",
    "necuprinsei": "necuprinsă",
    "necuprinsele": "necuprinsă",
    "necuprinselor": "necuprinsă",
    "necurata": "necurat",
    "necurată": "necurat",
    "necurate": "necurat",
    "necuratei": "necurat",
    "necuratele": "necurat",
    "necuratelor": "necurat",
    "necurați": "necurat",
    "necurații": "necurat",
    "necuraților": "necurat",
    "necuratul": "necurat",
    "necuratului": "necurat",
    "necurățată": "necurățat",
    "necurățate": "necurățat",
    "necurățați": "necurățat",
    "necurățeniea": "necurățenie",
    "necurățenii": "necurățenie",
    "necurățeniii": "necurățenie",
    "necurățeniile": "necurățenie",
    "necurățeniilor": "necurățenie",
    "necurățită": "necurățit",
    "necurățite": "necurățit",
    "necurățiți": "necurățit",
    "necurbata": "necurbat",
    "necurbată": "necurbat",
    "necurbate": "necurbat",
    "necurbatei": "necurbat",
    "necurbatele": "necurbat",
    "necurbatelor": "necurbat",
    "necurbați": "necurbat",
    "necurbații": "necurbat",
    "necurbaților": "necurbat",
    "necurbatul": "necurbat",
    "necurbatului": "necurbat",
    "necurentată": "necurentat",
    "necurentate": "necurentat",
    "necurentați": "necurentat",
    "necurmata": "necurmat",
    "necurmată": "necurmat",
    "necurmate": "necurmat",
    "necurmatei": "necurmat",
    "necurmatele": "necurmat",
    "necurmatelor": "necurmat",
    "necurmați": "necurmat",
    "necurmații": "necurmat",
    "necurmaților": "necurmat",
    "necurmatul": "necurmat",
    "necurmatului": "necurmat",
    "necursă": "necurs",
    "necurse": "necurs",
    "necurși": "necurs",
    "necurtată": "necurtat",
    "necurtate": "necurtat",
    "necurtați": "necurtat",
    "necusută": "necusut",
    "necusute": "necusut",
    "necusuți": "necusut",
    "necutata": "necutat",
    "necutată": "necutat",
    "necutate": "necutat",
    "necutatei": "necutat",
    "necutatele": "necutat",
    "necutatelor": "necutat",
    "necutați": "necutat",
    "necutații": "necutat",
    "necutaților": "necutat",
    "necutatul": "necutat",
    "necutatului": "necutat",
    "necutezată": "necutezat",
    "necutezate": "necutezat",
    "necutezați": "necutezat",
    "necutreierată": "necutreierat",
    "necutreierate": "necutreierat",
    "necutreierați": "necutreierat",
    "necutremurată": "necutremurat",
    "necutremurate": "necutremurat",
    "necutremurați": "necutremurat",
    "necuvântată": "necuvântat",
    "necuvântate": "necuvântat",
    "necuvântați": "necuvântat",
    "necuvântătoarea": "necuvântătoare",
    "necuvântătoarei": "necuvântătoare",
    "necuvântătoarele": "necuvântătoare",
    "necuvântătoarelor": "necuvântătoare",
    "necuvântătoare": "necuvântător",
    "necuvântătoarea": "necuvântător",
    "necuvântătoarei": "necuvântător",
    "necuvântătoarele": "necuvântător",
    "necuvântătoarelor": "necuvântător",
    "necuvântători": "necuvântător",
    "necuvântătorii": "necuvântător",
    "necuvântătorilor": "necuvântător",
    "necuvântătorul": "necuvântător",
    "necuvântătorului": "necuvântător",
    "necuvenita": "necuvenit",
    "necuvenită": "necuvenit",
    "necuvenite": "necuvenit",
    "necuvenitei": "necuvenit",
    "necuvenitele": "necuvenit",
    "necuvenitelor": "necuvenit",
    "necuveniți": "necuvenit",
    "necuveniții": "necuvenit",
    "necuveniților": "necuvenit",
    "necuvenitul": "necuvenit",
    "necuvenitului": "necuvenit",
    "necuviincioasa": "necuviincios",
    "necuviincioasă": "necuviincios",
    "necuviincioase": "necuviincios",
    "necuviincioasei": "necuviincios",
    "necuviincioasele": "necuviincios",
    "necuviincioaselor": "necuviincios",
    "necuviincioși": "necuviincios",
    "necuviincioșii": "necuviincios",
    "necuviincioșilor": "necuviincios",
    "necuviinciosul": "necuviincios",
    "necuviinciosului": "necuviincios",
    "necuviința": "necuviință",
    "necuviințe": "necuviință",
    "necuviinței": "necuviință",
    "necuviințele": "necuviință",
    "necuviințelor": "necuviință",
    "necvadruplată": "necvadruplat",
    "necvadruplate": "necvadruplat",
    "necvadruplați": "necvadruplat",
    "nedactilografiata": "nedactilografiat",
    "nedactilografiată": "nedactilografiat",
    "nedactilografiate": "nedactilografiat",
    "nedactilografiatei": "nedactilografiat",
    "nedactilografiatele": "nedactilografiat",
    "nedactilografiatelor": "nedactilografiat",
    "nedactilografiați": "nedactilografiat",
    "nedactilografiații": "nedactilografiat",
    "nedactilografiaților": "nedactilografiat",
    "nedactilografiatul": "nedactilografiat",
    "nedactilografiatului": "nedactilografiat",
    "nedădăcită": "nedădăcit",
    "nedădăcite": "nedădăcit",
    "nedădăciți": "nedădăcit",
    "nedăinuită": "nedăinuit",
    "nedăinuite": "nedăinuit",
    "nedăinuiți": "nedăinuit",
    "nedăltuita": "nedăltuit",
    "nedăltuită": "nedăltuit",
    "nedăltuite": "nedăltuit",
    "nedăltuitei": "nedăltuit",
    "nedăltuitele": "nedăltuit",
    "nedăltuitelor": "nedăltuit",
    "nedăltuiți": "nedăltuit",
    "nedăltuiții": "nedăltuit",
    "nedăltuiților": "nedăltuit",
    "nedăltuitul": "nedăltuit",
    "nedăltuitului": "nedăltuit",
    "nedamblagită": "nedamblagit",
    "nedamblagite": "nedamblagit",
    "nedamblagiți": "nedamblagit",
    "nedăngănită": "nedăngănit",
    "nedăngănite": "nedăngănit",
    "nedăngăniți": "nedăngănit",
    "nedansată": "nedansat",
    "nedansate": "nedansat",
    "nedansați": "nedansat",
    "nedantelata": "nedantelat",
    "nedantelată": "nedantelat",
    "nedantelate": "nedantelat",
    "nedantelatei": "nedantelat",
    "nedantelatele": "nedantelat",
    "nedantelatelor": "nedantelat",
    "nedantelați": "nedantelat",
    "nedantelații": "nedantelat",
    "nedantelaților": "nedantelat",
    "nedantelatul": "nedantelat",
    "nedantelatului": "nedantelat",
    "nedănțuită": "nedănțuit",
    "nedănțuite": "nedănțuit",
    "nedănțuiți": "nedănțuit",
    "nedărăcită": "nedărăcit",
    "nedărăcite": "nedărăcit",
    "nedărăciți": "nedărăcit",
    "nedărâmata": "nedărâmat",
    "nedărâmată": "nedărâmat",
    "nedărâmate": "nedărâmat",
    "nedărâmatei": "nedărâmat",
    "nedărâmatele": "nedărâmat",
    "nedărâmatelor": "nedărâmat",
    "nedărâmați": "nedărâmat",
    "nedărâmații": "nedărâmat",
    "nedărâmaților": "nedărâmat",
    "nedărâmatul": "nedărâmat",
    "nedărâmatului": "nedărâmat",
    "nedărăpănata": "nedărăpănat",
    "nedărăpănată": "nedărăpănat",
    "nedărăpănate": "nedărăpănat",
    "nedărăpănatei": "nedărăpănat",
    "nedărăpănatele": "nedărăpănat",
    "nedărăpănatelor": "nedărăpănat",
    "nedărăpănați": "nedărăpănat",
    "nedărăpănații": "nedărăpănat",
    "nedărăpănaților": "nedărăpănat",
    "nedărăpănatul": "nedărăpănat",
    "nedărăpănatului": "nedărăpănat",
    "nedârdâită": "nedârdâit",
    "nedârdâite": "nedârdâit",
    "nedârdâiți": "nedârdâit",
    "nedăruită": "nedăruit",
    "nedăruite": "nedăruit",
    "nedăruiți": "nedăruit",
    "nedăscălita": "nedăscălit",
    "nedăscălită": "nedăscălit",
    "nedăscălite": "nedăscălit",
    "nedăscălitei": "nedăscălit",
    "nedăscălitele": "nedăscălit",
    "nedăscălitelor": "nedăscălit",
    "nedăscăliți": "nedăscălit",
    "nedăscăliții": "nedăscălit",
    "nedăscăliților": "nedăscălit",
    "nedăscălitul": "nedăscălit",
    "nedăscălitului": "nedăscălit",
    "nedată": "nedat",
    "nedate": "nedat",
    "nedatei": "nedat",
    "nedatele": "nedat",
    "nedatelor": "nedat",
    "nedați": "nedat",
    "nedații": "nedat",
    "nedaților": "nedat",
    "nedatului": "nedat",
    "nedata": "nedatat",
    "nedatata": "nedatat",
    "nedatată": "nedatat",
    "nedatate": "nedatat",
    "nedatatei": "nedatat",
    "nedatatele": "nedatat",
    "nedatatelor": "nedatat",
    "nedatați": "nedatat",
    "nedatații": "nedatat",
    "nedataților": "nedatat",
    "nedatatul": "nedatat",
    "nedatatului": "nedatat",
    "nedatul": "nedatat",
    "nedatorata": "nedatorat",
    "nedatorată": "nedatorat",
    "nedatorate": "nedatorat",
    "nedatoratei": "nedatorat",
    "nedatoratele": "nedatorat",
    "nedatoratelor": "nedatorat",
    "nedatorați": "nedatorat",
    "nedatorații": "nedatorat",
    "nedatoraților": "nedatorat",
    "nedatoratul": "nedatorat",
    "nedatoratului": "nedatorat",
    "nedăunată": "nedăunat",
    "nedăunate": "nedăunat",
    "nedăunați": "nedăunat",
    "nedebarasată": "nedebarasat",
    "nedebarasate": "nedebarasat",
    "nedebarasați": "nedebarasat",
    "nedebarcată": "nedebarcat",
    "nedebarcate": "nedebarcat",
    "nedebarcați": "nedebarcat",
    "nedebilitată": "nedebilitat",
    "nedebilitate": "nedebilitat",
    "nedebilitați": "nedebilitat",
    "nedebitată": "nedebitat",
    "nedebitate": "nedebitat",
    "nedebitați": "nedebitat",
    "nedeblocată": "nedeblocat",
    "nedeblocate": "nedeblocat",
    "nedeblocați": "nedeblocat",
    "nedebordată": "nedebordat",
    "nedebordate": "nedebordat",
    "nedebordați": "nedebordat",
    "nedebreiată": "nedebreiat",
    "nedebreiate": "nedebreiat",
    "nedebreiați": "nedebreiat",
    "nedebutată": "nedebutat",
    "nedebutate": "nedebutat",
    "nedebutați": "nedebutat",
    "nedecalcată": "nedecalcat",
    "nedecalcate": "nedecalcat",
    "nedecalcați": "nedecalcat",
    "nedecalcifiată": "nedecalcifiat",
    "nedecalcifiate": "nedecalcifiat",
    "nedecalcifiați": "nedecalcifiat",
    "nedecalcificată": "nedecalcificat",
    "nedecalcificate": "nedecalcificat",
    "nedecalcificați": "nedecalcificat",
    "nedecantată": "nedecantat",
    "nedecantate": "nedecantat",
    "nedecantați": "nedecantat",
    "nedecapată": "nedecapat",
    "nedecapate": "nedecapat",
    "nedecapați": "nedecapat",
    "nedecapitata": "nedecapitat",
    "nedecapitată": "nedecapitat",
    "nedecapitate": "nedecapitat",
    "nedecapitatei": "nedecapitat",
    "nedecapitatele": "nedecapitat",
    "nedecapitatelor": "nedecapitat",
    "nedecapitați": "nedecapitat",
    "nedecapitații": "nedecapitat",
    "nedecapitaților": "nedecapitat",
    "nedecapitatul": "nedecapitat",
    "nedecapitatului": "nedecapitat",
    "nedecapotabila": "nedecapotabil",
    "nedecapotabilă": "nedecapotabil",
    "nedecapotabile": "nedecapotabil",
    "nedecapotabilei": "nedecapotabil",
    "nedecapotabilele": "nedecapotabil",
    "nedecapotabilelor": "nedecapotabil",
    "nedecapotabili": "nedecapotabil",
    "nedecapotabilii": "nedecapotabil",
    "nedecapotabililor": "nedecapotabil",
    "nedecapotabilul": "nedecapotabil",
    "nedecapotabilului": "nedecapotabil",
    "nedecarburata": "nedecarburat",
    "nedecarburată": "nedecarburat",
    "nedecarburate": "nedecarburat",
    "nedecarburatei": "nedecarburat",
    "nedecarburatele": "nedecarburat",
    "nedecarburatelor": "nedecarburat",
    "nedecarburați": "nedecarburat",
    "nedecarburații": "nedecarburat",
    "nedecarburaților": "nedecarburat",
    "nedecarburatul": "nedecarburat",
    "nedecarburatului": "nedecarburat",
    "nedecăzută": "nedecăzut",
    "nedecăzute": "nedecăzut",
    "nedecăzuți": "nedecăzut",
    "nedecedata": "nedecedat",
    "nedecedată": "nedecedat",
    "nedecedate": "nedecedat",
    "nedecedatei": "nedecedat",
    "nedecedatele": "nedecedat",
    "nedecedatelor": "nedecedat",
    "nedecedați": "nedecedat",
    "nedecedații": "nedecedat",
    "nedecedaților": "nedecedat",
    "nedecedatul": "nedecedat",
    "nedecedatului": "nedecedat",
    "nedecepționata": "nedecepționat",
    "nedecepționată": "nedecepționat",
    "nedecepționate": "nedecepționat",
    "nedecepționatei": "nedecepționat",
    "nedecepționatele": "nedecepționat",
    "nedecepționatelor": "nedecepționat",
    "nedecepționați": "nedecepționat",
    "nedecepționații": "nedecepționat",
    "nedecepționaților": "nedecepționat",
    "nedecepționatul": "nedecepționat",
    "nedecepționatului": "nedecepționat",
    "nedecernată": "nedecernat",
    "nedecernate": "nedecernat",
    "nedecernați": "nedecernat",
    "nedecimată": "nedecimat",
    "nedecimate": "nedecimat",
    "nedecimați": "nedecimat",
    "nedecisa": "nedecis",
    "nedecisă": "nedecis",
    "nedecise": "nedecis",
    "nedecisei": "nedecis",
    "nedecisele": "nedecis",
    "nedeciselor": "nedecis",
    "nedeciși": "nedecis",
    "nedecișii": "nedecis",
    "nedecișilor": "nedecis",
    "nedecisul": "nedecis",
    "nedecisului": "nedecis",
    "nedeclamată": "nedeclamat",
    "nedeclamate": "nedeclamat",
    "nedeclamați": "nedeclamat",
    "nedeclanșată": "nedeclanșat",
    "nedeclanșate": "nedeclanșat",
    "nedeclanșați": "nedeclanșat",
    "nedeclarata": "nedeclarat",
    "nedeclarată": "nedeclarat",
    "nedeclarate": "nedeclarat",
    "nedeclaratei": "nedeclarat",
    "nedeclaratele": "nedeclarat",
    "nedeclaratelor": "nedeclarat",
    "nedeclarați": "nedeclarat",
    "nedeclarații": "nedeclarat",
    "nedeclaraților": "nedeclarat",
    "nedeclaratul": "nedeclarat",
    "nedeclaratului": "nedeclarat",
    "nedeclasata": "nedeclasat",
    "nedeclasată": "nedeclasat",
    "nedeclasate": "nedeclasat",
    "nedeclasatei": "nedeclasat",
    "nedeclasatele": "nedeclasat",
    "nedeclasatelor": "nedeclasat",
    "nedeclasați": "nedeclasat",
    "nedeclasații": "nedeclasat",
    "nedeclasaților": "nedeclasat",
    "nedeclasatul": "nedeclasat",
    "nedeclasatului": "nedeclasat",
    "nedeclinată": "nedeclinat",
    "nedeclinate": "nedeclinat",
    "nedeclinați": "nedeclinat",
    "nedecofrată": "nedecofrat",
    "nedecofrate": "nedecofrat",
    "nedecofrați": "nedecofrat",
    "nedecolată": "nedecolat",
    "nedecolate": "nedecolat",
    "nedecolați": "nedecolat",
    "nedecolorata": "nedecolorat",
    "nedecolorată": "nedecolorat",
    "nedecolorate": "nedecolorat",
    "nedecoloratei": "nedecolorat",
    "nedecoloratele": "nedecolorat",
    "nedecoloratelor": "nedecolorat",
    "nedecolorați": "nedecolorat",
    "nedecolorații": "nedecolorat",
    "nedecoloraților": "nedecolorat",
    "nedecoloratul": "nedecolorat",
    "nedecoloratului": "nedecolorat",
    "nedecoltata": "nedecoltat",
    "nedecoltată": "nedecoltat",
    "nedecoltate": "nedecoltat",
    "nedecoltatei": "nedecoltat",
    "nedecoltatele": "nedecoltat",
    "nedecoltatelor": "nedecoltat",
    "nedecoltați": "nedecoltat",
    "nedecoltații": "nedecoltat",
    "nedecoltaților": "nedecoltat",
    "nedecoltatul": "nedecoltat",
    "nedecoltatului": "nedecoltat",
    "nedecomandată": "nedecomandat",
    "nedecomandate": "nedecomandat",
    "nedecomandați": "nedecomandat",
    "nedeconcertată": "nedeconcertat",
    "nedeconcertate": "nedeconcertat",
    "nedeconcertați": "nedeconcertat",
    "nedeconectată": "nedeconectat",
    "nedeconectate": "nedeconectat",
    "nedeconectați": "nedeconectat",
    "nedeconspirată": "nedeconspirat",
    "nedeconspirate": "nedeconspirat",
    "nedeconspirați": "nedeconspirat",
    "nedecontabilă": "nedecontabil",
    "nedecontabile": "nedecontabil",
    "nedecontabili": "nedecontabil",
    "nedecontată": "nedecontat",
    "nedecontate": "nedecontat",
    "nedecontați": "nedecontat",
    "nedecorata": "nedecorat",
    "nedecorată": "nedecorat",
    "nedecorate": "nedecorat",
    "nedecoratei": "nedecorat",
    "nedecoratele": "nedecorat",
    "nedecoratelor": "nedecorat",
    "nedecorați": "nedecorat",
    "nedecorații": "nedecorat",
    "nedecoraților": "nedecorat",
    "nedecoratul": "nedecorat",
    "nedecoratului": "nedecorat",
    "nedecorticata": "nedecorticat",
    "nedecorticată": "nedecorticat",
    "nedecorticate": "nedecorticat",
    "nedecorticatei": "nedecorticat",
    "nedecorticatele": "nedecorticat",
    "nedecorticatelor": "nedecorticat",
    "nedecorticați": "nedecorticat",
    "nedecorticații": "nedecorticat",
    "nedecorticaților": "nedecorticat",
    "nedecorticatul": "nedecorticat",
    "nedecorticatului": "nedecorticat",
    "nedecretată": "nedecretat",
    "nedecretate": "nedecretat",
    "nedecretați": "nedecretat",
    "nedecroșată": "nedecroșat",
    "nedecroșate": "nedecroșat",
    "nedecroșați": "nedecroșat",
    "nedecupata": "nedecupat",
    "nedecupată": "nedecupat",
    "nedecupate": "nedecupat",
    "nedecupatei": "nedecupat",
    "nedecupatele": "nedecupat",
    "nedecupatelor": "nedecupat",
    "nedecupați": "nedecupat",
    "nedecupații": "nedecupat",
    "nedecupaților": "nedecupat",
    "nedecupatul": "nedecupat",
    "nedecupatului": "nedecupat",
    "nedecuplată": "nedecuplat",
    "nedecuplate": "nedecuplat",
    "nedecuplați": "nedecuplat",
    "nededicată": "nededicat",
    "nededicate": "nededicat",
    "nededicați": "nededicat",
    "nededublata": "nededublat",
    "nededublată": "nededublat",
    "nededublate": "nededublat",
    "nededublatei": "nededublat",
    "nededublatele": "nededublat",
    "nededublatelor": "nededublat",
    "nededublați": "nededublat",
    "nededublații": "nededublat",
    "nededublaților": "nededublat",
    "nededublatul": "nededublat",
    "nededublatului": "nededublat",
    "nededulcită": "nededulcit",
    "nededulcite": "nededulcit",
    "nededulciți": "nededulcit",
    "nededusa": "nededus",
    "nededusă": "nededus",
    "nededuse": "nededus",
    "nededusei": "nededus",
    "nededusele": "nededus",
    "nededuselor": "nededus",
    "nededuși": "nededus",
    "nededușii": "nededus",
    "nededușilor": "nededus",
    "nededusul": "nededus",
    "nededusului": "nededus",
    "nedefăimată": "nedefăimat",
    "nedefăimate": "nedefăimat",
    "nedefăimați": "nedefăimat",
    "nedefalcată": "nedefalcat",
    "nedefalcate": "nedefalcat",
    "nedefalcați": "nedefalcat",
    "nedefecată": "nedefecat",
    "nedefecate": "nedefecat",
    "nedefecați": "nedefecat",
    "nedefectata": "nedefectat",
    "nedefectată": "nedefectat",
    "nedefectate": "nedefectat",
    "nedefectatei": "nedefectat",
    "nedefectatele": "nedefectat",
    "nedefectatelor": "nedefectat",
    "nedefectați": "nedefectat",
    "nedefectații": "nedefectat",
    "nedefectaților": "nedefectat",
    "nedefectatul": "nedefectat",
    "nedefectatului": "nedefectat",
    "nedeferită": "nedeferit",
    "nedeferite": "nedeferit",
    "nedeferiți": "nedeferit",
    "nedeferizată": "nedeferizat",
    "nedeferizate": "nedeferizat",
    "nedeferizați": "nedeferizat",
    "nedefertilizată": "nedefertilizat",
    "nedefertilizate": "nedefertilizat",
    "nedefertilizați": "nedefertilizat",
    "nedefibrată": "nedefibrat",
    "nedefibrate": "nedefibrat",
    "nedefibrați": "nedefibrat",
    "nedefilată": "nedefilat",
    "nedefilate": "nedefilat",
    "nedefilați": "nedefilat",
    "nedefinita": "nedefinit",
    "nedefinită": "nedefinit",
    "nedefinite": "nedefinit",
    "nedefinitei": "nedefinit",
    "nedefinitele": "nedefinit",
    "nedefinitelor": "nedefinit",
    "nedefiniți": "nedefinit",
    "nedefiniții": "nedefinit",
    "nedefiniților": "nedefinit",
    "nedefinitul": "nedefinit",
    "nedefinitului": "nedefinit",
    "nedefinitivată": "nedefinitivat",
    "nedefinitivate": "nedefinitivat",
    "nedefinitivați": "nedefinitivat",
    "nedeflorată": "nedeflorat",
    "nedeflorate": "nedeflorat",
    "nedeflorați": "nedeflorat",
    "nedeformata": "nedeformat",
    "nedeformată": "nedeformat",
    "nedeformate": "nedeformat",
    "nedeformatei": "nedeformat",
    "nedeformatele": "nedeformat",
    "nedeformatelor": "nedeformat",
    "nedeformați": "nedeformat",
    "nedeformații": "nedeformat",
    "nedeformaților": "nedeformat",
    "nedeformatul": "nedeformat",
    "nedeformatului": "nedeformat",
    "nedefraudata": "nedefraudat",
    "nedefraudată": "nedefraudat",
    "nedefraudate": "nedefraudat",
    "nedefraudatei": "nedefraudat",
    "nedefraudatele": "nedefraudat",
    "nedefraudatelor": "nedefraudat",
    "nedefraudați": "nedefraudat",
    "nedefraudații": "nedefraudat",
    "nedefraudaților": "nedefraudat",
    "nedefraudatul": "nedefraudat",
    "nedefraudatului": "nedefraudat",
    "nedefrișata": "nedefrișat",
    "nedefrișată": "nedefrișat",
    "nedefrișate": "nedefrișat",
    "nedefrișatei": "nedefrișat",
    "nedefrișatele": "nedefrișat",
    "nedefrișatelor": "nedefrișat",
    "nedefrișați": "nedefrișat",
    "nedefrișații": "nedefrișat",
    "nedefrișaților": "nedefrișat",
    "nedefrișatul": "nedefrișat",
    "nedefrișatului": "nedefrișat",
    "nedegajata": "nedegajat",
    "nedegajată": "nedegajat",
    "nedegajate": "nedegajat",
    "nedegajatei": "nedegajat",
    "nedegajatele": "nedegajat",
    "nedegajatelor": "nedegajat",
    "nedegajați": "nedegajat",
    "nedegajații": "nedegajat",
    "nedegajaților": "nedegajat",
    "nedegajatul": "nedegajat",
    "nedegajatului": "nedegajat",
    "nedegerata": "nedegerat",
    "nedegerată": "nedegerat",
    "nedegerate": "nedegerat",
    "nedegeratei": "nedegerat",
    "nedegeratele": "nedegerat",
    "nedegeratelor": "nedegerat",
    "nedegerați": "nedegerat",
    "nedegerații": "nedegerat",
    "nedegeraților": "nedegerat",
    "nedegeratul": "nedegerat",
    "nedegeratului": "nedegerat",
    "nedeghizata": "nedeghizat",
    "nedeghizată": "nedeghizat",
    "nedeghizate": "nedeghizat",
    "nedeghizatei": "nedeghizat",
    "nedeghizatele": "nedeghizat",
    "nedeghizatelor": "nedeghizat",
    "nedeghizați": "nedeghizat",
    "nedeghizații": "nedeghizat",
    "nedeghizaților": "nedeghizat",
    "nedeghizatul": "nedeghizat",
    "nedeghizatului": "nedeghizat",
    "nedegradata": "nedegradat",
    "nedegradată": "nedegradat",
    "nedegradate": "nedegradat",
    "nedegradatei": "nedegradat",
    "nedegradatele": "nedegradat",
    "nedegradatelor": "nedegradat",
    "nedegradați": "nedegradat",
    "nedegradații": "nedegradat",
    "nedegradaților": "nedegradat",
    "nedegradatul": "nedegradat",
    "nedegradatului": "nedegradat",
    "nedegresată": "nedegresat",
    "nedegresate": "nedegresat",
    "nedegresați": "nedegresat",
    "nedegrevata": "nedegrevat",
    "nedegrevată": "nedegrevat",
    "nedegrevate": "nedegrevat",
    "nedegrevatei": "nedegrevat",
    "nedegrevatele": "nedegrevat",
    "nedegrevatelor": "nedegrevat",
    "nedegrevați": "nedegrevat",
    "nedegrevații": "nedegrevat",
    "nedegrevaților": "nedegrevat",
    "nedegrevatul": "nedegrevat",
    "nedegrevatului": "nedegrevat",
    "nedegustată": "nedegustat",
    "nedegustate": "nedegustat",
    "nedegustați": "nedegustat",
    "nedei": "nedeie",
    "nedeia": "nedeie",
    "nedeii": "nedeie",
    "nedeile": "nedeie",
    "nedeilor": "nedeie",
    "nedeificată": "nedeificat",
    "nedeificate": "nedeificat",
    "nedeificați": "nedeificat",
    "nedejugată": "nedejugat",
    "nedejugate": "nedejugat",
    "nedejugați": "nedejugat",
    "nedejunată": "nedejunat",
    "nedejunate": "nedejunat",
    "nedejunați": "nedejunat",
    "nedelapidată": "nedelapidat",
    "nedelapidate": "nedelapidat",
    "nedelapidați": "nedelapidat",
    "nedelăsată": "nedelăsat",
    "nedelăsate": "nedelăsat",
    "nedelăsați": "nedelăsat",
    "nedelectată": "nedelectat",
    "nedelectate": "nedelectat",
    "nedelectați": "nedelectat",
    "nedelegată": "nedelegat",
    "nedelegate": "nedelegat",
    "nedelegați": "nedelegat",
    "nedeliberata": "nedeliberat",
    "nedeliberată": "nedeliberat",
    "nedeliberate": "nedeliberat",
    "nedeliberatei": "nedeliberat",
    "nedeliberatele": "nedeliberat",
    "nedeliberatelor": "nedeliberat",
    "nedeliberați": "nedeliberat",
    "nedeliberații": "nedeliberat",
    "nedeliberaților": "nedeliberat",
    "nedeliberatul": "nedeliberat",
    "nedeliberatului": "nedeliberat",
    "nedelicatețea": "nedelicatețe",
    "nedelicateți": "nedelicatețe",
    "nedelicateții": "nedelicatețe",
    "nedelicatețile": "nedelicatețe",
    "nedelicateților": "nedelicatețe",
    "nedelimitată": "nedelimitat",
    "nedelimitate": "nedelimitat",
    "nedelimitați": "nedelimitat",
    "nedelirată": "nedelirat",
    "nedelirate": "nedelirat",
    "nedelirați": "nedelirat",
    "nedemagnetizată": "nedemagnetizat",
    "nedemagnetizate": "nedemagnetizat",
    "nedemagnetizați": "nedemagnetizat",
    "nedemarată": "nedemarat",
    "nedemarate": "nedemarat",
    "nedemarați": "nedemarat",
    "nedemarcată": "nedemarcat",
    "nedemarcate": "nedemarcat",
    "nedemarcați": "nedemarcat",
    "nedemascată": "nedemascat",
    "nedemascate": "nedemascat",
    "nedemascați": "nedemascat",
    "nedemilitarizata": "nedemilitarizat",
    "nedemilitarizată": "nedemilitarizat",
    "nedemilitarizate": "nedemilitarizat",
    "nedemilitarizatei": "nedemilitarizat",
    "nedemilitarizatele": "nedemilitarizat",
    "nedemilitarizatelor": "nedemilitarizat",
    "nedemilitarizați": "nedemilitarizat",
    "nedemilitarizații": "nedemilitarizat",
    "nedemilitarizaților": "nedemilitarizat",
    "nedemilitarizatul": "nedemilitarizat",
    "nedemilitarizatului": "nedemilitarizat",
    "nedemineralizată": "nedemineralizat",
    "nedemineralizate": "nedemineralizat",
    "nedemineralizați": "nedemineralizat",
    "nedemisă": "nedemis",
    "nedemise": "nedemis",
    "nedemiși": "nedemis",
    "nedemisionată": "nedemisionat",
    "nedemisionate": "nedemisionat",
    "nedemisionați": "nedemisionat",
    "nedemna": "nedemn",
    "nedemnă": "nedemn",
    "nedemne": "nedemn",
    "nedemnei": "nedemn",
    "nedemnele": "nedemn",
    "nedemnelor": "nedemn",
    "nedemni": "nedemn",
    "nedemnii": "nedemn",
    "nedemnilor": "nedemn",
    "nedemnul": "nedemn",
    "nedemnului": "nedemn",
    "nedemobilizata": "nedemobilizat",
    "nedemobilizată": "nedemobilizat",
    "nedemobilizate": "nedemobilizat",
    "nedemobilizatei": "nedemobilizat",
    "nedemobilizatele": "nedemobilizat",
    "nedemobilizatelor": "nedemobilizat",
    "nedemobilizați": "nedemobilizat",
    "nedemobilizații": "nedemobilizat",
    "nedemobilizaților": "nedemobilizat",
    "nedemobilizatul": "nedemobilizat",
    "nedemobilizatului": "nedemobilizat",
    "nedemocratizată": "nedemocratizat",
    "nedemocratizate": "nedemocratizat",
    "nedemocratizați": "nedemocratizat",
    "nedemodata": "nedemodat",
    "nedemodată": "nedemodat",
    "nedemodate": "nedemodat",
    "nedemodatei": "nedemodat",
    "nedemodatele": "nedemodat",
    "nedemodatelor": "nedemodat",
    "nedemodați": "nedemodat",
    "nedemodații": "nedemodat",
    "nedemodaților": "nedemodat",
    "nedemodatul": "nedemodat",
    "nedemodatului": "nedemodat",
    "nedemolată": "nedemolat",
    "nedemolate": "nedemolat",
    "nedemolați": "nedemolat",
    "nedemonetizată": "nedemonetizat",
    "nedemonetizate": "nedemonetizat",
    "nedemonetizați": "nedemonetizat",
    "nedemonstrată": "nedemonstrat",
    "nedemonstrate": "nedemonstrat",
    "nedemonstrați": "nedemonstrat",
    "nedemontată": "nedemontat",
    "nedemontate": "nedemontat",
    "nedemontați": "nedemontat",
    "nedemoralizata": "nedemoralizat",
    "nedemoralizată": "nedemoralizat",
    "nedemoralizate": "nedemoralizat",
    "nedemoralizatei": "nedemoralizat",
    "nedemoralizatele": "nedemoralizat",
    "nedemoralizatelor": "nedemoralizat",
    "nedemoralizați": "nedemoralizat",
    "nedemoralizații": "nedemoralizat",
    "nedemoralizaților": "nedemoralizat",
    "nedemoralizatul": "nedemoralizat",
    "nedemoralizatului": "nedemoralizat",
    "nedemultiplicată": "nedemultiplicat",
    "nedemultiplicate": "nedemultiplicat",
    "nedemultiplicați": "nedemultiplicat",
    "nedenaturata": "nedenaturat",
    "nedenaturată": "nedenaturat",
    "nedenaturate": "nedenaturat",
    "nedenaturatei": "nedenaturat",
    "nedenaturatele": "nedenaturat",
    "nedenaturatelor": "nedenaturat",
    "nedenaturați": "nedenaturat",
    "nedenaturații": "nedenaturat",
    "nedenaturaților": "nedenaturat",
    "nedenaturatul": "nedenaturat",
    "nedenaturatului": "nedenaturat",
    "nedenicotinizata": "nedenicotinizat",
    "nedenicotinizată": "nedenicotinizat",
    "nedenicotinizate": "nedenicotinizat",
    "nedenicotinizatei": "nedenicotinizat",
    "nedenicotinizatele": "nedenicotinizat",
    "nedenicotinizatelor": "nedenicotinizat",
    "nedenicotinizați": "nedenicotinizat",
    "nedenicotinizații": "nedenicotinizat",
    "nedenicotinizaților": "nedenicotinizat",
    "nedenicotinizatul": "nedenicotinizat",
    "nedenicotinizatului": "nedenicotinizat",
    "nedenigrată": "nedenigrat",
    "nedenigrate": "nedenigrat",
    "nedenigrați": "nedenigrat",
    "nedenivelată": "nedenivelat",
    "nedenivelate": "nedenivelat",
    "nedenivelați": "nedenivelat",
    "nedenotată": "nedenotat",
    "nedenotate": "nedenotat",
    "nedenotați": "nedenotat",
    "nedenumita": "nedenumit",
    "nedenumită": "nedenumit",
    "nedenumite": "nedenumit",
    "nedenumitei": "nedenumit",
    "nedenumitele": "nedenumit",
    "nedenumitelor": "nedenumit",
    "nedenumiți": "nedenumit",
    "nedenumiții": "nedenumit",
    "nedenumiților": "nedenumit",
    "nedenumitul": "nedenumit",
    "nedenumitului": "nedenumit",
    "nedenunțată": "nedenunțat",
    "nedenunțate": "nedenunțat",
    "nedenunțați": "nedenunțat",
    "nedeocheata": "nedeocheat",
    "nedeocheată": "nedeocheat",
    "nedeocheate": "nedeocheat",
    "nedeocheatei": "nedeocheat",
    "nedeocheatele": "nedeocheat",
    "nedeocheatelor": "nedeocheat",
    "nedeocheați": "nedeocheat",
    "nedeocheații": "nedeocheat",
    "nedeocheaților": "nedeocheat",
    "nedeocheatul": "nedeocheat",
    "nedeocheatului": "nedeocheat",
    "nedeosebita": "nedeosebit",
    "nedeosebită": "nedeosebit",
    "nedeosebite": "nedeosebit",
    "nedeosebitei": "nedeosebit",
    "nedeosebitele": "nedeosebit",
    "nedeosebitelor": "nedeosebit",
    "nedeosebiți": "nedeosebit",
    "nedeosebiții": "nedeosebit",
    "nedeosebiților": "nedeosebit",
    "nedeosebitul": "nedeosebit",
    "nedeosebitului": "nedeosebit",
    "nedepanată": "nedepanat",
    "nedepanate": "nedepanat",
    "nedepanați": "nedepanat",
    "nedepănata": "nedepănat",
    "nedepănată": "nedepănat",
    "nedepănate": "nedepănat",
    "nedepănatei": "nedepănat",
    "nedepănatele": "nedepănat",
    "nedepănatelor": "nedepănat",
    "nedepănați": "nedepănat",
    "nedepănații": "nedepănat",
    "nedepănaților": "nedepănat",
    "nedepănatul": "nedepănat",
    "nedepănatului": "nedepănat",
    "nedeparafinata": "nedeparafinat",
    "nedeparafinată": "nedeparafinat",
    "nedeparafinate": "nedeparafinat",
    "nedeparafinatei": "nedeparafinat",
    "nedeparafinatele": "nedeparafinat",
    "nedeparafinatelor": "nedeparafinat",
    "nedeparafinați": "nedeparafinat",
    "nedeparafinații": "nedeparafinat",
    "nedeparafinaților": "nedeparafinat",
    "nedeparafinatul": "nedeparafinat",
    "nedeparafinatului": "nedeparafinat",
    "nedeparazitată": "nedeparazitat",
    "nedeparazitate": "nedeparazitat",
    "nedeparazitați": "nedeparazitat",
    "nedepărtata": "nedepărtat",
    "nedepărtată": "nedepărtat",
    "nedepărtate": "nedepărtat",
    "nedepărtatei": "nedepărtat",
    "nedepărtatele": "nedepărtat",
    "nedepărtatelor": "nedepărtat",
    "nedepărtați": "nedepărtat",
    "nedepărtații": "nedepărtat",
    "nedepărtaților": "nedepărtat",
    "nedepărtatul": "nedepărtat",
    "nedepărtatului": "nedepărtat",
    "nedepășita": "nedepășit",
    "nedepășită": "nedepășit",
    "nedepășite": "nedepășit",
    "nedepășitei": "nedepășit",
    "nedepășitele": "nedepășit",
    "nedepășitelor": "nedepășit",
    "nedepășiți": "nedepășit",
    "nedepășiții": "nedepășit",
    "nedepășiților": "nedepășit",
    "nedepășitul": "nedepășit",
    "nedepășitului": "nedepășit",
    "nedepilată": "nedepilat",
    "nedepilate": "nedepilat",
    "nedepilați": "nedepilat",
    "nedepinsă": "nedepins",
    "nedepinse": "nedepins",
    "nedepinși": "nedepins",
    "nedepistată": "nedepistat",
    "nedepistate": "nedepistat",
    "nedepistați": "nedepistat",
    "nedeplasata": "nedeplasat",
    "nedeplasată": "nedeplasat",
    "nedeplasate": "nedeplasat",
    "nedeplasatei": "nedeplasat",
    "nedeplasatele": "nedeplasat",
    "nedeplasatelor": "nedeplasat",
    "nedeplasați": "nedeplasat",
    "nedeplasații": "nedeplasat",
    "nedeplasaților": "nedeplasat",
    "nedeplasatul": "nedeplasat",
    "nedeplasatului": "nedeplasat",
    "nedeplorată": "nedeplorat",
    "nedeplorate": "nedeplorat",
    "nedeplorați": "nedeplorat",
    "nedepolarizată": "nedepolarizat",
    "nedepolarizate": "nedepolarizat",
    "nedepolarizați": "nedepolarizat",
    "nedepopulată": "nedepopulat",
    "nedepopulate": "nedepopulat",
    "nedepopulați": "nedepopulat",
    "nedeportata": "nedeportat",
    "nedeportată": "nedeportat",
    "nedeportate": "nedeportat",
    "nedeportatei": "nedeportat",
    "nedeportatele": "nedeportat",
    "nedeportatelor": "nedeportat",
    "nedeportați": "nedeportat",
    "nedeportații": "nedeportat",
    "nedeportaților": "nedeportat",
    "nedeportatul": "nedeportat",
    "nedeportatului": "nedeportat",
    "nedeposedată": "nedeposedat",
    "nedeposedate": "nedeposedat",
    "nedeposedați": "nedeposedat",
    "nedepozitată": "nedepozitat",
    "nedepozitate": "nedepozitat",
    "nedepozitați": "nedepozitat",
    "nedepravata": "nedepravat",
    "nedepravată": "nedepravat",
    "nedepravate": "nedepravat",
    "nedepravatei": "nedepravat",
    "nedepravatele": "nedepravat",
    "nedepravatelor": "nedepravat",
    "nedepravați": "nedepravat",
    "nedepravații": "nedepravat",
    "nedepravaților": "nedepravat",
    "nedepravatul": "nedepravat",
    "nedepravatului": "nedepravat",
    "nedepreciată": "nedepreciat",
    "nedepreciate": "nedepreciat",
    "nedepreciați": "nedepreciat",
    "nedepresată": "nedepresat",
    "nedepresate": "nedepresat",
    "nedepresați": "nedepresat",
    "nedeprimata": "nedeprimat",
    "nedeprimată": "nedeprimat",
    "nedeprimate": "nedeprimat",
    "nedeprimatei": "nedeprimat",
    "nedeprimatele": "nedeprimat",
    "nedeprimatelor": "nedeprimat",
    "nedeprimați": "nedeprimat",
    "nedeprimații": "nedeprimat",
    "nedeprimaților": "nedeprimat",
    "nedeprimatul": "nedeprimat",
    "nedeprimatului": "nedeprimat",
    "nedeprinsa": "nedeprins",
    "nedeprinsă": "nedeprins",
    "nedeprinse": "nedeprins",
    "nedeprinsei": "nedeprins",
    "nedeprinsele": "nedeprins",
    "nedeprinselor": "nedeprins",
    "nedeprinși": "nedeprins",
    "nedeprinșii": "nedeprins",
    "nedeprinșilor": "nedeprins",
    "nedeprinsul": "nedeprins",
    "nedeprinsului": "nedeprins",
    "nedepusă": "nedepus",
    "nedepuse": "nedepus",
    "nedepuși": "nedepus",
    "nederaiată": "nederaiat",
    "nederaiate": "nederaiat",
    "nederaiați": "nederaiat",
    "nederanjată": "nederanjat",
    "nederanjate": "nederanjat",
    "nederanjați": "nederanjat",
    "nederapată": "nederapat",
    "nederapate": "nederapat",
    "nederapați": "nederapat",
    "nederatizată": "nederatizat",
    "nederatizate": "nederatizat",
    "nederatizați": "nederatizat",
    "nedereticată": "nedereticat",
    "nedereticate": "nedereticat",
    "nedereticați": "nedereticat",
    "nederivata": "nederivat",
    "nederivată": "nederivat",
    "nederivate": "nederivat",
    "nederivatei": "nederivat",
    "nederivatele": "nederivat",
    "nederivatelor": "nederivat",
    "nederivați": "nederivat",
    "nederivații": "nederivat",
    "nederivaților": "nederivat",
    "nederivatul": "nederivat",
    "nederivatului": "nederivat",
    "nederogată": "nederogat",
    "nederogate": "nederogat",
    "nederogați": "nederogat",
    "nederulată": "nederulat",
    "nederulate": "nederulat",
    "nederulați": "nederulat",
    "nederutata": "nederutat",
    "nederutată": "nederutat",
    "nederutate": "nederutat",
    "nederutatei": "nederutat",
    "nederutatele": "nederutat",
    "nederutatelor": "nederutat",
    "nederutați": "nederutat",
    "nederutații": "nederutat",
    "nederutaților": "nederutat",
    "nederutatul": "nederutat",
    "nederutatului": "nederutat",
    "nedeșănțata": "nedeșănțat",
    "nedeșănțată": "nedeșănțat",
    "nedeșănțate": "nedeșănțat",
    "nedeșănțatei": "nedeșănțat",
    "nedeșănțatele": "nedeșănțat",
    "nedeșănțatelor": "nedeșănțat",
    "nedeșănțați": "nedeșănțat",
    "nedeșănțații": "nedeșănțat",
    "nedeșănțaților": "nedeșănțat",
    "nedeșănțatul": "nedeșănțat",
    "nedeșănțatului": "nedeșănțat",
    "nedesărcinată": "nedesărcinat",
    "nedesărcinate": "nedesărcinat",
    "nedesărcinați": "nedesărcinat",
    "nedesăvârșirea": "nedesăvârșire",
    "nedesăvârșiri": "nedesăvârșire",
    "nedesăvârșirii": "nedesăvârșire",
    "nedesăvârșirile": "nedesăvârșire",
    "nedesăvârșirilor": "nedesăvârșire",
    "nedesăvârșită": "nedesăvârșit",
    "nedesăvârșite": "nedesăvârșit",
    "nedesăvârșiți": "nedesăvârșit",
    "nedesăvârșitul": "nedesăvârșit",
    "nedesăvârșitului": "nedesăvârșit",
    "nedescâlcită": "nedescâlcit",
    "nedescâlcite": "nedescâlcit",
    "nedescâlciți": "nedescâlcit",
    "nedescălecată": "nedescălecat",
    "nedescălecate": "nedescălecat",
    "nedescălecați": "nedescălecat",
    "nedescălțata": "nedescălțat",
    "nedescălțată": "nedescălțat",
    "nedescălțate": "nedescălțat",
    "nedescălțatei": "nedescălțat",
    "nedescălțatele": "nedescălțat",
    "nedescălțatelor": "nedescălțat",
    "nedescălțați": "nedescălțat",
    "nedescălțații": "nedescălțat",
    "nedescălțaților": "nedescălțat",
    "nedescălțatul": "nedescălțat",
    "nedescălțatului": "nedescălțat",
    "nedescărcată": "nedescărcat",
    "nedescărcate": "nedescărcat",
    "nedescărcați": "nedescărcat",
    "nedescărnata": "nedescărnat",
    "nedescărnată": "nedescărnat",
    "nedescărnate": "nedescărnat",
    "nedescărnatei": "nedescărnat",
    "nedescărnatele": "nedescărnat",
    "nedescărnatelor": "nedescărnat",
    "nedescărnați": "nedescărnat",
    "nedescărnații": "nedescărnat",
    "nedescărnaților": "nedescărnat",
    "nedescărnatul": "nedescărnat",
    "nedescărnatului": "nedescărnat",
    "nedescătărămată": "nedescătărămat",
    "nedescătărămate": "nedescătărămat",
    "nedescătărămați": "nedescătărămat",
    "nedescătușată": "nedescătușat",
    "nedescătușate": "nedescătușat",
    "nedescătușați": "nedescătușat",
    "nedescentralizată": "nedescentralizat",
    "nedescentralizate": "nedescentralizat",
    "nedescentralizați": "nedescentralizat",
    "nedescentrată": "nedescentrat",
    "nedescentrate": "nedescentrat",
    "nedescentrați": "nedescentrat",
    "nedescheiata": "nedescheiat",
    "nedescheiată": "nedescheiat",
    "nedescheiate": "nedescheiat",
    "nedescheiatei": "nedescheiat",
    "nedescheiatele": "nedescheiat",
    "nedescheiatelor": "nedescheiat",
    "nedescheiați": "nedescheiat",
    "nedescheiații": "nedescheiat",
    "nedescheiaților": "nedescheiat",
    "nedescheiatul": "nedescheiat",
    "nedescheiatului": "nedescheiat",
    "nedeschingată": "nedeschingat",
    "nedeschingate": "nedeschingat",
    "nedeschingați": "nedeschingat",
    "nedeschisa": "nedeschis",
    "nedeschisă": "nedeschis",
    "nedeschise": "nedeschis",
    "nedeschisei": "nedeschis",
    "nedeschisele": "nedeschis",
    "nedeschiselor": "nedeschis",
    "nedeschiși": "nedeschis",
    "nedeschișii": "nedeschis",
    "nedeschișilor": "nedeschis",
    "nedeschisul": "nedeschis",
    "nedeschisului": "nedeschis",
    "nedescifrată": "nedescifrat",
    "nedescifrate": "nedescifrat",
    "nedescifrați": "nedescifrat",
    "nedescinsa": "nedescins",
    "nedescinsă": "nedescins",
    "nedescinse": "nedescins",
    "nedescinsei": "nedescins",
    "nedescinsele": "nedescins",
    "nedescinselor": "nedescins",
    "nedescinși": "nedescins",
    "nedescinșii": "nedescins",
    "nedescinșilor": "nedescins",
    "nedescinsul": "nedescins",
    "nedescinsului": "nedescins",
    "nedescleiată": "nedescleiat",
    "nedescleiate": "nedescleiat",
    "nedescleiați": "nedescleiat",
    "nedescleștată": "nedescleștat",
    "nedescleștate": "nedescleștat",
    "nedescleștați": "nedescleștat",
    "nedescolăcită": "nedescolăcit",
    "nedescolăcite": "nedescolăcit",
    "nedescolăciți": "nedescolăcit",
    "nedescoperita": "nedescoperit",
    "nedescoperită": "nedescoperit",
    "nedescoperite": "nedescoperit",
    "nedescoperitei": "nedescoperit",
    "nedescoperitele": "nedescoperit",
    "nedescoperitelor": "nedescoperit",
    "nedescoperiți": "nedescoperit",
    "nedescoperiții": "nedescoperit",
    "nedescoperiților": "nedescoperit",
    "nedescoperitul": "nedescoperit",
    "nedescoperitului": "nedescoperit",
    "nedescotorosită": "nedescotorosit",
    "nedescotorosite": "nedescotorosit",
    "nedescotorosiți": "nedescotorosit",
    "nedescotoșmănită": "nedescotoșmănit",
    "nedescotoșmănite": "nedescotoșmănit",
    "nedescotoșmăniți": "nedescotoșmănit",
    "nedescovoiată": "nedescovoiat",
    "nedescovoiate": "nedescovoiat",
    "nedescovoiați": "nedescovoiat",
    "nedescrețita": "nedescrețit",
    "nedescrețită": "nedescrețit",
    "nedescrețite": "nedescrețit",
    "nedescrețitei": "nedescrețit",
    "nedescrețitele": "nedescrețit",
    "nedescrețitelor": "nedescrețit",
    "nedescrețiți": "nedescrețit",
    "nedescrețiții": "nedescrețit",
    "nedescrețiților": "nedescrețit",
    "nedescrețitul": "nedescrețit",
    "nedescrețitului": "nedescrețit",
    "nedescrisa": "nedescris",
    "nedescrisă": "nedescris",
    "nedescrise": "nedescris",
    "nedescrisei": "nedescris",
    "nedescrisele": "nedescris",
    "nedescriselor": "nedescris",
    "nedescriși": "nedescris",
    "nedescrișii": "nedescris",
    "nedescrișilor": "nedescris",
    "nedescrisul": "nedescris",
    "nedescrisului": "nedescris",
    "nedescrucișată": "nedescrucișat",
    "nedescrucișate": "nedescrucișat",
    "nedescrucișați": "nedescrucișat",
    "nedescruntată": "nedescruntat",
    "nedescruntate": "nedescruntat",
    "nedescruntați": "nedescruntat",
    "nedescuiata": "nedescuiat",
    "nedescuiată": "nedescuiat",
    "nedescuiate": "nedescuiat",
    "nedescuiatei": "nedescuiat",
    "nedescuiatele": "nedescuiat",
    "nedescuiatelor": "nedescuiat",
    "nedescuiați": "nedescuiat",
    "nedescuiații": "nedescuiat",
    "nedescuiaților": "nedescuiat",
    "nedescuiatul": "nedescuiat",
    "nedescuiatului": "nedescuiat",
    "nedescurajata": "nedescurajat",
    "nedescurajată": "nedescurajat",
    "nedescurajate": "nedescurajat",
    "nedescurajatei": "nedescurajat",
    "nedescurajatele": "nedescurajat",
    "nedescurajatelor": "nedescurajat",
    "nedescurajați": "nedescurajat",
    "nedescurajații": "nedescurajat",
    "nedescurajaților": "nedescurajat",
    "nedescurajatul": "nedescurajat",
    "nedescurajatului": "nedescurajat",
    "nedescurcată": "nedescurcat",
    "nedescurcate": "nedescurcat",
    "nedescurcați": "nedescurcat",
    "nedeșelata": "nedeșelat",
    "nedeșelată": "nedeșelat",
    "nedeșelate": "nedeșelat",
    "nedeșelatei": "nedeșelat",
    "nedeșelatele": "nedeșelat",
    "nedeșelatelor": "nedeșelat",
    "nedeșelați": "nedeșelat",
    "nedeșelații": "nedeșelat",
    "nedeșelaților": "nedeșelat",
    "nedeșelatul": "nedeșelat",
    "nedeșelatului": "nedeșelat",
    "nedesemnată": "nedesemnat",
    "nedesemnate": "nedesemnat",
    "nedesemnați": "nedesemnat",
    "nedesenată": "nedesenat",
    "nedesenate": "nedesenat",
    "nedesenați": "nedesenat",
    "nedeșertata": "nedeșertat",
    "nedeșertată": "nedeșertat",
    "nedeșertate": "nedeșertat",
    "nedeșertatei": "nedeșertat",
    "nedeșertatele": "nedeșertat",
    "nedeșertatelor": "nedeșertat",
    "nedeșertați": "nedeșertat",
    "nedeșertații": "nedeșertat",
    "nedeșertaților": "nedeșertat",
    "nedeșertatul": "nedeșertat",
    "nedeșertatului": "nedeșertat",
    "nedeservită": "nedeservit",
    "nedeservite": "nedeservit",
    "nedeserviți": "nedeservit",
    "nedesesizată": "nedesesizat",
    "nedesesizate": "nedesesizat",
    "nedesesizați": "nedesesizat",
    "nedeșeuata": "nedeșeuat",
    "nedeșeuată": "nedeșeuat",
    "nedeșeuate": "nedeșeuat",
    "nedeșeuatei": "nedeșeuat",
    "nedeșeuatele": "nedeșeuat",
    "nedeșeuatelor": "nedeșeuat",
    "nedeșeuați": "nedeșeuat",
    "nedeșeuații": "nedeșeuat",
    "nedeșeuaților": "nedeșeuat",
    "nedeșeuatul": "nedeșeuat",
    "nedeșeuatului": "nedeșeuat",
    "nedesfăcută": "nedesfăcut",
    "nedesfăcute": "nedesfăcut",
    "nedesfăcuți": "nedesfăcut",
    "nedesfășata": "nedesfășat",
    "nedesfășată": "nedesfășat",
    "nedesfășate": "nedesfășat",
    "nedesfășatei": "nedesfășat",
    "nedesfășatele": "nedesfășat",
    "nedesfășatelor": "nedesfășat",
    "nedesfășați": "nedesfășat",
    "nedesfășații": "nedesfășat",
    "nedesfășaților": "nedesfășat",
    "nedesfășatul": "nedesfășat",
    "nedesfășatului": "nedesfășat",
    "nedesfășurata": "nedesfășurat",
    "nedesfășurată": "nedesfășurat",
    "nedesfășurate": "nedesfășurat",
    "nedesfășuratei": "nedesfășurat",
    "nedesfășuratele": "nedesfășurat",
    "nedesfășuratelor": "nedesfășurat",
    "nedesfășurați": "nedesfășurat",
    "nedesfășurații": "nedesfășurat",
    "nedesfășuraților": "nedesfășurat",
    "nedesfășuratul": "nedesfășurat",
    "nedesfășuratului": "nedesfășurat",
    "nedesfătată": "nedesfătat",
    "nedesfătate": "nedesfătat",
    "nedesfătați": "nedesfătat",
    "nedesfățata": "nedesfățat",
    "nedesfățată": "nedesfățat",
    "nedesfățate": "nedesfățat",
    "nedesfățatei": "nedesfățat",
    "nedesfățatele": "nedesfățat",
    "nedesfățatelor": "nedesfățat",
    "nedesfățați": "nedesfățat",
    "nedesfățații": "nedesfățat",
    "nedesfățaților": "nedesfățat",
    "nedesfățatul": "nedesfățat",
    "nedesfățatului": "nedesfățat",
    "nedesfigurata": "nedesfigurat",
    "nedesfigurată": "nedesfigurat",
    "nedesfigurate": "nedesfigurat",
    "nedesfiguratei": "nedesfigurat",
    "nedesfiguratele": "nedesfigurat",
    "nedesfiguratelor": "nedesfigurat",
    "nedesfigurați": "nedesfigurat",
    "nedesfigurații": "nedesfigurat",
    "nedesfiguraților": "nedesfigurat",
    "nedesfiguratul": "nedesfigurat",
    "nedesfiguratului": "nedesfigurat",
    "nedesființata": "nedesființat",
    "nedesființată": "nedesființat",
    "nedesființate": "nedesființat",
    "nedesființatei": "nedesființat",
    "nedesființatele": "nedesființat",
    "nedesființatelor": "nedesființat",
    "nedesființați": "nedesființat",
    "nedesființații": "nedesființat",
    "nedesființaților": "nedesființat",
    "nedesființatul": "nedesființat",
    "nedesființatului": "nedesființat",
    "nedesfoiata": "nedesfoiat",
    "nedesfoiată": "nedesfoiat",
    "nedesfoiate": "nedesfoiat",
    "nedesfoiatei": "nedesfoiat",
    "nedesfoiatele": "nedesfoiat",
    "nedesfoiatelor": "nedesfoiat",
    "nedesfoiați": "nedesfoiat",
    "nedesfoiații": "nedesfoiat",
    "nedesfoiaților": "nedesfoiat",
    "nedesfoiatul": "nedesfoiat",
    "nedesfoiatului": "nedesfoiat",
    "nedesfrânata": "nedesfrânat",
    "nedesfrânată": "nedesfrânat",
    "nedesfrânate": "nedesfrânat",
    "nedesfrânatei": "nedesfrânat",
    "nedesfrânatele": "nedesfrânat",
    "nedesfrânatelor": "nedesfrânat",
    "nedesfrânați": "nedesfrânat",
    "nedesfrânații": "nedesfrânat",
    "nedesfrânaților": "nedesfrânat",
    "nedesfrânatul": "nedesfrânat",
    "nedesfrânatului": "nedesfrânat",
    "nedesfrunzita": "nedesfrunzit",
    "nedesfrunzită": "nedesfrunzit",
    "nedesfrunzite": "nedesfrunzit",
    "nedesfrunzitei": "nedesfrunzit",
    "nedesfrunzitele": "nedesfrunzit",
    "nedesfrunzitelor": "nedesfrunzit",
    "nedesfrunziți": "nedesfrunzit",
    "nedesfrunziții": "nedesfrunzit",
    "nedesfrunziților": "nedesfrunzit",
    "nedesfrunzitul": "nedesfrunzit",
    "nedesfrunzitului": "nedesfrunzit",
    "nedesfundata": "nedesfundat",
    "nedesfundată": "nedesfundat",
    "nedesfundate": "nedesfundat",
    "nedesfundatei": "nedesfundat",
    "nedesfundatele": "nedesfundat",
    "nedesfundatelor": "nedesfundat",
    "nedesfundați": "nedesfundat",
    "nedesfundații": "nedesfundat",
    "nedesfundaților": "nedesfundat",
    "nedesfundatul": "nedesfundat",
    "nedesfundatului": "nedesfundat",
    "nedeshămată": "nedeshămat",
    "nedeshămate": "nedeshămat",
    "nedeshămați": "nedeshămat",
    "nedeshidratată": "nedeshidratat",
    "nedeshidratate": "nedeshidratat",
    "nedeshidratați": "nedeshidratat",
    "nedeshumată": "nedeshumat",
    "nedeshumate": "nedeshumat",
    "nedeshumați": "nedeshumat",
    "nedeșirata": "nedeșirat",
    "nedeșirată": "nedeșirat",
    "nedeșirate": "nedeșirat",
    "nedeșiratei": "nedeșirat",
    "nedeșiratele": "nedeșirat",
    "nedeșiratelor": "nedeșirat",
    "nedeșirați": "nedeșirat",
    "nedeșirații": "nedeșirat",
    "nedeșiraților": "nedeșirat",
    "nedeșiratul": "nedeșirat",
    "nedeșiratului": "nedeșirat",
    "nedeslușita": "nedeslușit",
    "nedeslușită": "nedeslușit",
    "nedeslușite": "nedeslușit",
    "nedeslușitei": "nedeslușit",
    "nedeslușitele": "nedeslușit",
    "nedeslușitelor": "nedeslușit",
    "nedeslușiți": "nedeslușit",
    "nedeslușiții": "nedeslușit",
    "nedeslușiților": "nedeslușit",
    "nedeslușitul": "nedeslușit",
    "nedeslușitului": "nedeslușit",
    "nedesolidarizată": "nedesolidarizat",
    "nedesolidarizate": "nedesolidarizat",
    "nedesolidarizați": "nedesolidarizat",
    "nedespachetată": "nedespachetat",
    "nedespachetate": "nedespachetat",
    "nedespachetați": "nedespachetat",
    "nedespăducheată": "nedespăducheat",
    "nedespăducheate": "nedespăducheat",
    "nedespăducheați": "nedespăducheat",
    "nedespădurita": "nedespădurit",
    "nedespădurită": "nedespădurit",
    "nedespădurite": "nedespădurit",
    "nedespăduritei": "nedespădurit",
    "nedespăduritele": "nedespădurit",
    "nedespăduritelor": "nedespădurit",
    "nedespăduriți": "nedespădurit",
    "nedespăduriții": "nedespădurit",
    "nedespăduriților": "nedespădurit",
    "nedespăduritul": "nedespădurit",
    "nedespăduritului": "nedespădurit",
    "nedespăienjenită": "nedespăienjenit",
    "nedespăienjenite": "nedespăienjenit",
    "nedespăienjeniți": "nedespăienjenit",
    "nedespărțita": "nedespărțit",
    "nedespărțită": "nedespărțit",
    "nedespărțite": "nedespărțit",
    "nedespărțitei": "nedespărțit",
    "nedespărțitele": "nedespărțit",
    "nedespărțitelor": "nedespărțit",
    "nedespărțiți": "nedespărțit",
    "nedespărțiții": "nedespărțit",
    "nedespărțiților": "nedespărțit",
    "nedespărțitul": "nedespărțit",
    "nedespărțitului": "nedespărțit",
    "nedespăturită": "nedespăturit",
    "nedespăturite": "nedespăturit",
    "nedespăturiți": "nedespăturit",
    "nedesperata": "nedesperat",
    "nedesperată": "nedesperat",
    "nedesperate": "nedesperat",
    "nedesperatei": "nedesperat",
    "nedesperatele": "nedesperat",
    "nedesperatelor": "nedesperat",
    "nedesperați": "nedesperat",
    "nedesperații": "nedesperat",
    "nedesperaților": "nedesperat",
    "nedesperatul": "nedesperat",
    "nedesperatului": "nedesperat",
    "nedesperecheata": "nedesperecheat",
    "nedesperecheată": "nedesperecheat",
    "nedesperecheate": "nedesperecheat",
    "nedesperecheatei": "nedesperecheat",
    "nedesperecheatele": "nedesperecheat",
    "nedesperecheatelor": "nedesperecheat",
    "nedesperecheați": "nedesperecheat",
    "nedesperecheații": "nedesperecheat",
    "nedesperecheaților": "nedesperecheat",
    "nedesperecheatul": "nedesperecheat",
    "nedesperecheatului": "nedesperecheat",
    "nedespicata": "nedespicat",
    "nedespicată": "nedespicat",
    "nedespicate": "nedespicat",
    "nedespicatei": "nedespicat",
    "nedespicatele": "nedespicat",
    "nedespicatelor": "nedespicat",
    "nedespicați": "nedespicat",
    "nedespicații": "nedespicat",
    "nedespicaților": "nedespicat",
    "nedespicatul": "nedespicat",
    "nedespicatului": "nedespicat",
    "nedespiedicată": "nedespiedicat",
    "nedespiedicate": "nedespiedicat",
    "nedespiedicați": "nedespiedicat",
    "nedespletita": "nedespletit",
    "nedespletită": "nedespletit",
    "nedespletite": "nedespletit",
    "nedespletitei": "nedespletit",
    "nedespletitele": "nedespletit",
    "nedespletitelor": "nedespletit",
    "nedespletiți": "nedespletit",
    "nedespletiții": "nedespletit",
    "nedespletiților": "nedespletit",
    "nedespletitul": "nedespletit",
    "nedespletitului": "nedespletit",
    "nedespodobită": "nedespodobit",
    "nedespodobite": "nedespodobit",
    "nedespodobiți": "nedespodobit",
    "nedespotmolită": "nedespotmolit",
    "nedespotmolite": "nedespotmolit",
    "nedespotmoliți": "nedespotmolit",
    "nedespovărată": "nedespovărat",
    "nedespovărate": "nedespovărat",
    "nedespovărați": "nedespovărat",
    "nedesprejmuită": "nedesprejmuit",
    "nedesprejmuite": "nedesprejmuit",
    "nedesprejmuiți": "nedesprejmuit",
    "nedespresurată": "nedespresurat",
    "nedespresurate": "nedespresurat",
    "nedespresurați": "nedespresurat",
    "nedesprimăvărată": "nedesprimăvărat",
    "nedesprimăvărate": "nedesprimăvărat",
    "nedesprimăvărați": "nedesprimăvărat",
    "nedesprinsă": "nedesprins",
    "nedesprinse": "nedesprins",
    "nedesprinși": "nedesprins",
    "nedespuiata": "nedespuiat",
    "nedespuiată": "nedespuiat",
    "nedespuiate": "nedespuiat",
    "nedespuiatei": "nedespuiat",
    "nedespuiatele": "nedespuiat",
    "nedespuiatelor": "nedespuiat",
    "nedespuiați": "nedespuiat",
    "nedespuiații": "nedespuiat",
    "nedespuiaților": "nedespuiat",
    "nedespuiatul": "nedespuiat",
    "nedespuiatului": "nedespuiat",
    "nedesțelenită": "nedesțelenit",
    "nedesțelenite": "nedesțelenit",
    "nedesțeleniți": "nedesțelenit",
    "nedesțepenită": "nedesțepenit",
    "nedesțepenite": "nedesțepenit",
    "nedesțepeniți": "nedesțepenit",
    "nedeșteptată": "nedeșteptat",
    "nedeșteptate": "nedeșteptat",
    "nedeșteptați": "nedeșteptat",
    "nedestinată": "nedestinat",
    "nedestinate": "nedestinat",
    "nedestinați": "nedestinat",
    "nedestinsa": "nedestins",
    "nedestinsă": "nedestins",
    "nedestinse": "nedestins",
    "nedestinsei": "nedestins",
    "nedestinsele": "nedestins",
    "nedestinselor": "nedestins",
    "nedestinși": "nedestins",
    "nedestinșii": "nedestins",
    "nedestinșilor": "nedestins",
    "nedestinsul": "nedestins",
    "nedestinsului": "nedestins",
    "nedestituită": "nedestituit",
    "nedestituite": "nedestituit",
    "nedestituiți": "nedestituit",
    "nedestrăbălata": "nedestrăbălat",
    "nedestrăbălată": "nedestrăbălat",
    "nedestrăbălate": "nedestrăbălat",
    "nedestrăbălatei": "nedestrăbălat",
    "nedestrăbălatele": "nedestrăbălat",
    "nedestrăbălatelor": "nedestrăbălat",
    "nedestrăbălați": "nedestrăbălat",
    "nedestrăbălații": "nedestrăbălat",
    "nedestrăbălaților": "nedestrăbălat",
    "nedestrăbălatul": "nedestrăbălat",
    "nedestrăbălatului": "nedestrăbălat",
    "nedestrămata": "nedestrămat",
    "nedestrămată": "nedestrămat",
    "nedestrămate": "nedestrămat",
    "nedestrămatei": "nedestrămat",
    "nedestrămatele": "nedestrămat",
    "nedestrămatelor": "nedestrămat",
    "nedestrămați": "nedestrămat",
    "nedestrămații": "nedestrămat",
    "nedestrămaților": "nedestrămat",
    "nedestrămatul": "nedestrămat",
    "nedestrămatului": "nedestrămat",
    "nedestroienita": "nedestroienit",
    "nedestroienită": "nedestroienit",
    "nedestroienite": "nedestroienit",
    "nedestroienitei": "nedestroienit",
    "nedestroienitele": "nedestroienit",
    "nedestroienitelor": "nedestroienit",
    "nedestroieniți": "nedestroienit",
    "nedestroieniții": "nedestroienit",
    "nedestroieniților": "nedestroienit",
    "nedestroienitul": "nedestroienit",
    "nedestroienitului": "nedestroienit",
    "nedestupată": "nedestupat",
    "nedestupate": "nedestupat",
    "nedestupați": "nedestupat",
    "nedeșurubata": "nedeșurubat",
    "nedeșurubată": "nedeșurubat",
    "nedeșurubate": "nedeșurubat",
    "nedeșurubatei": "nedeșurubat",
    "nedeșurubatele": "nedeșurubat",
    "nedeșurubatelor": "nedeșurubat",
    "nedeșurubați": "nedeșurubat",
    "nedeșurubații": "nedeșurubat",
    "nedeșurubaților": "nedeșurubat",
    "nedeșurubatul": "nedeșurubat",
    "nedeșurubatului": "nedeșurubat",
    "nedeszăpezita": "nedeszăpezit",
    "nedeszăpezită": "nedeszăpezit",
    "nedeszăpezite": "nedeszăpezit",
    "nedeszăpezitei": "nedeszăpezit",
    "nedeszăpezitele": "nedeszăpezit",
    "nedeszăpezitelor": "nedeszăpezit",
    "nedeszăpeziți": "nedeszăpezit",
    "nedeszăpeziții": "nedeszăpezit",
    "nedeszăpeziților": "nedeszăpezit",
    "nedeszăpezitul": "nedeszăpezit",
    "nedeszăpezitului": "nedeszăpezit",
    "nedetaliata": "nedetaliat",
    "nedetaliată": "nedetaliat",
    "nedetaliate": "nedetaliat",
    "nedetaliatei": "nedetaliat",
    "nedetaliatele": "nedetaliat",
    "nedetaliatelor": "nedetaliat",
    "nedetaliați": "nedetaliat",
    "nedetaliații": "nedetaliat",
    "nedetaliaților": "nedetaliat",
    "nedetaliatul": "nedetaliat",
    "nedetaliatului": "nedetaliat",
    "nedetașata": "nedetașat",
    "nedetașată": "nedetașat",
    "nedetașate": "nedetașat",
    "nedetașatei": "nedetașat",
    "nedetașatele": "nedetașat",
    "nedetașatelor": "nedetașat",
    "nedetașați": "nedetașat",
    "nedetașații": "nedetașat",
    "nedetașaților": "nedetașat",
    "nedetașatul": "nedetașat",
    "nedetașatului": "nedetașat",
    "nedetectată": "nedetectat",
    "nedetectate": "nedetectat",
    "nedetectați": "nedetectat",
    "nedeteriorata": "nedeteriorat",
    "nedeteriorată": "nedeteriorat",
    "nedeteriorate": "nedeteriorat",
    "nedeterioratei": "nedeteriorat",
    "nedeterioratele": "nedeteriorat",
    "nedeterioratelor": "nedeteriorat",
    "nedeteriorați": "nedeteriorat",
    "nedeteriorații": "nedeteriorat",
    "nedeterioraților": "nedeteriorat",
    "nedeterioratul": "nedeteriorat",
    "nedeterioratului": "nedeteriorat",
    "nedeterminarea": "nedeterminare",
    "nedeterminări": "nedeterminare",
    "nedeterminării": "nedeterminare",
    "nedeterminările": "nedeterminare",
    "nedeterminărilor": "nedeterminare",
    "nedeterminata": "nedeterminat",
    "nedeterminată": "nedeterminat",
    "nedeterminate": "nedeterminat",
    "nedeterminatei": "nedeterminat",
    "nedeterminatele": "nedeterminat",
    "nedeterminatelor": "nedeterminat",
    "nedeterminați": "nedeterminat",
    "nedeterminații": "nedeterminat",
    "nedeterminaților": "nedeterminat",
    "nedeterminatul": "nedeterminat",
    "nedeterminatului": "nedeterminat",
    "nedetestată": "nedetestat",
    "nedetestate": "nedetestat",
    "nedetestați": "nedetestat",
    "nedeținută": "nedeținut",
    "nedeținute": "nedeținut",
    "nedeținuți": "nedeținut",
    "nedetractată": "nedetractat",
    "nedetractate": "nedetractat",
    "nedetractați": "nedetractat",
    "nedetronata": "nedetronat",
    "nedetronată": "nedetronat",
    "nedetronate": "nedetronat",
    "nedetronatei": "nedetronat",
    "nedetronatele": "nedetronat",
    "nedetronatelor": "nedetronat",
    "nedetronați": "nedetronat",
    "nedetronații": "nedetronat",
    "nedetronaților": "nedetronat",
    "nedetronatul": "nedetronat",
    "nedetronatului": "nedetronat",
    "nedetunata": "nedetunat",
    "nedetunată": "nedetunat",
    "nedetunate": "nedetunat",
    "nedetunatei": "nedetunat",
    "nedetunatele": "nedetunat",
    "nedetunatelor": "nedetunat",
    "nedetunați": "nedetunat",
    "nedetunații": "nedetunat",
    "nedetunaților": "nedetunat",
    "nedetunatul": "nedetunat",
    "nedetunatului": "nedetunat",
    "nedeturnată": "nedeturnat",
    "nedeturnate": "nedeturnat",
    "nedeturnați": "nedeturnat",
    "nedevalizată": "nedevalizat",
    "nedevalizate": "nedevalizat",
    "nedevalizați": "nedevalizat",
    "nedevalorizata": "nedevalorizat",
    "nedevalorizată": "nedevalorizat",
    "nedevalorizate": "nedevalorizat",
    "nedevalorizatei": "nedevalorizat",
    "nedevalorizatele": "nedevalorizat",
    "nedevalorizatelor": "nedevalorizat",
    "nedevalorizați": "nedevalorizat",
    "nedevalorizații": "nedevalorizat",
    "nedevalorizaților": "nedevalorizat",
    "nedevalorizatul": "nedevalorizat",
    "nedevalorizatului": "nedevalorizat",
    "nedevansată": "nedevansat",
    "nedevansate": "nedevansat",
    "nedevansați": "nedevansat",
    "nedevastata": "nedevastat",
    "nedevastată": "nedevastat",
    "nedevastate": "nedevastat",
    "nedevastatei": "nedevastat",
    "nedevastatele": "nedevastat",
    "nedevastatelor": "nedevastat",
    "nedevastați": "nedevastat",
    "nedevastații": "nedevastat",
    "nedevastaților": "nedevastat",
    "nedevastatul": "nedevastat",
    "nedevastatului": "nedevastat",
    "nedevelopata": "nedevelopat",
    "nedevelopată": "nedevelopat",
    "nedevelopate": "nedevelopat",
    "nedevelopatei": "nedevelopat",
    "nedevelopatele": "nedevelopat",
    "nedevelopatelor": "nedevelopat",
    "nedevelopați": "nedevelopat",
    "nedevelopații": "nedevelopat",
    "nedevelopaților": "nedevelopat",
    "nedevelopatul": "nedevelopat",
    "nedevelopatului": "nedevelopat",
    "nedevenită": "nedevenit",
    "nedevenite": "nedevenit",
    "nedeveniți": "nedevenit",
    "nedeviată": "nedeviat",
    "nedeviate": "nedeviat",
    "nedeviați": "nedeviat",
    "nedevorată": "nedevorat",
    "nedevorate": "nedevorat",
    "nedevorați": "nedevorat",
    "nedevotata": "nedevotat",
    "nedevotată": "nedevotat",
    "nedevotate": "nedevotat",
    "nedevotatei": "nedevotat",
    "nedevotatele": "nedevotat",
    "nedevotatelor": "nedevotat",
    "nedevotați": "nedevotat",
    "nedevotații": "nedevotat",
    "nedevotaților": "nedevotat",
    "nedevotatul": "nedevotat",
    "nedevotatului": "nedevotat",
    "nedezacordata": "nedezacordat",
    "nedezacordată": "nedezacordat",
    "nedezacordate": "nedezacordat",
    "nedezacordatei": "nedezacordat",
    "nedezacordatele": "nedezacordat",
    "nedezacordatelor": "nedezacordat",
    "nedezacordați": "nedezacordat",
    "nedezacordații": "nedezacordat",
    "nedezacordaților": "nedezacordat",
    "nedezacordatul": "nedezacordat",
    "nedezacordatului": "nedezacordat",
    "nedezagregata": "nedezagregat",
    "nedezagregată": "nedezagregat",
    "nedezagregate": "nedezagregat",
    "nedezagregatei": "nedezagregat",
    "nedezagregatele": "nedezagregat",
    "nedezagregatelor": "nedezagregat",
    "nedezagregați": "nedezagregat",
    "nedezagregații": "nedezagregat",
    "nedezagregaților": "nedezagregat",
    "nedezagregatul": "nedezagregat",
    "nedezagregatului": "nedezagregat",
    "nedezamăgită": "nedezamăgit",
    "nedezamăgite": "nedezamăgit",
    "nedezamăgiți": "nedezamăgit",
    "nedezaprobată": "nedezaprobat",
    "nedezaprobate": "nedezaprobat",
    "nedezaprobați": "nedezaprobat",
    "nedezarmata": "nedezarmat",
    "nedezarmată": "nedezarmat",
    "nedezarmate": "nedezarmat",
    "nedezarmatei": "nedezarmat",
    "nedezarmatele": "nedezarmat",
    "nedezarmatelor": "nedezarmat",
    "nedezarmați": "nedezarmat",
    "nedezarmații": "nedezarmat",
    "nedezarmaților": "nedezarmat",
    "nedezarmatul": "nedezarmat",
    "nedezarmatului": "nedezarmat",
    "nedezarticulata": "nedezarticulat",
    "nedezarticulată": "nedezarticulat",
    "nedezarticulate": "nedezarticulat",
    "nedezarticulatei": "nedezarticulat",
    "nedezarticulatele": "nedezarticulat",
    "nedezarticulatelor": "nedezarticulat",
    "nedezarticulați": "nedezarticulat",
    "nedezarticulații": "nedezarticulat",
    "nedezarticulaților": "nedezarticulat",
    "nedezarticulatul": "nedezarticulat",
    "nedezarticulatului": "nedezarticulat",
    "nedezavantajată": "nedezavantajat",
    "nedezavantajate": "nedezavantajat",
    "nedezavantajați": "nedezavantajat",
    "nedezavuată": "nedezavuat",
    "nedezavuate": "nedezavuat",
    "nedezavuați": "nedezavuat",
    "nedezaxata": "nedezaxat",
    "nedezaxată": "nedezaxat",
    "nedezaxate": "nedezaxat",
    "nedezaxatei": "nedezaxat",
    "nedezaxatele": "nedezaxat",
    "nedezaxatelor": "nedezaxat",
    "nedezaxați": "nedezaxat",
    "nedezaxații": "nedezaxat",
    "nedezaxaților": "nedezaxat",
    "nedezaxatul": "nedezaxat",
    "nedezaxatului": "nedezaxat",
    "nedezbărată": "nedezbărat",
    "nedezbărate": "nedezbărat",
    "nedezbărați": "nedezbărat",
    "nedezbătută": "nedezbătut",
    "nedezbătute": "nedezbătut",
    "nedezbătuți": "nedezbătut",
    "nedezbinata": "nedezbinat",
    "nedezbinată": "nedezbinat",
    "nedezbinate": "nedezbinat",
    "nedezbinatei": "nedezbinat",
    "nedezbinatele": "nedezbinat",
    "nedezbinatelor": "nedezbinat",
    "nedezbinați": "nedezbinat",
    "nedezbinații": "nedezbinat",
    "nedezbinaților": "nedezbinat",
    "nedezbinatul": "nedezbinat",
    "nedezbinatului": "nedezbinat",
    "nedezbrăcata": "nedezbrăcat",
    "nedezbrăcată": "nedezbrăcat",
    "nedezbrăcate": "nedezbrăcat",
    "nedezbrăcatei": "nedezbrăcat",
    "nedezbrăcatele": "nedezbrăcat",
    "nedezbrăcatelor": "nedezbrăcat",
    "nedezbrăcați": "nedezbrăcat",
    "nedezbrăcații": "nedezbrăcat",
    "nedezbrăcaților": "nedezbrăcat",
    "nedezbrăcatul": "nedezbrăcat",
    "nedezbrăcatului": "nedezbrăcat",
    "nedezbrobodita": "nedezbrobodit",
    "nedezbrobodită": "nedezbrobodit",
    "nedezbrobodite": "nedezbrobodit",
    "nedezbroboditei": "nedezbrobodit",
    "nedezbroboditele": "nedezbrobodit",
    "nedezbroboditelor": "nedezbrobodit",
    "nedezbrobodiți": "nedezbrobodit",
    "nedezbrobodiții": "nedezbrobodit",
    "nedezbrobodiților": "nedezbrobodit",
    "nedezbroboditul": "nedezbrobodit",
    "nedezbroboditului": "nedezbrobodit",
    "nedezdoită": "nedezdoit",
    "nedezdoite": "nedezdoit",
    "nedezdoiți": "nedezdoit",
    "nedezechilibrata": "nedezechilibrat",
    "nedezechilibrată": "nedezechilibrat",
    "nedezechilibrate": "nedezechilibrat",
    "nedezechilibratei": "nedezechilibrat",
    "nedezechilibratele": "nedezechilibrat",
    "nedezechilibratelor": "nedezechilibrat",
    "nedezechilibrați": "nedezechilibrat",
    "nedezechilibrații": "nedezechilibrat",
    "nedezechilibraților": "nedezechilibrat",
    "nedezechilibratul": "nedezechilibrat",
    "nedezechilibratului": "nedezechilibrat",
    "nedezechipata": "nedezechipat",
    "nedezechipată": "nedezechipat",
    "nedezechipate": "nedezechipat",
    "nedezechipatei": "nedezechipat",
    "nedezechipatele": "nedezechipat",
    "nedezechipatelor": "nedezechipat",
    "nedezechipați": "nedezechipat",
    "nedezechipații": "nedezechipat",
    "nedezechipaților": "nedezechipat",
    "nedezechipatul": "nedezechipat",
    "nedezechipatului": "nedezechipat",
    "nedezertată": "nedezertat",
    "nedezertate": "nedezertat",
    "nedezertați": "nedezertat",
    "nedezghețata": "nedezghețat",
    "nedezghețată": "nedezghețat",
    "nedezghețate": "nedezghețat",
    "nedezghețatei": "nedezghețat",
    "nedezghețatele": "nedezghețat",
    "nedezghețatelor": "nedezghețat",
    "nedezghețați": "nedezghețat",
    "nedezghețații": "nedezghețat",
    "nedezghețaților": "nedezghețat",
    "nedezghețatul": "nedezghețat",
    "nedezghețatului": "nedezghețat",
    "nedezghiocata": "nedezghiocat",
    "nedezghiocată": "nedezghiocat",
    "nedezghiocate": "nedezghiocat",
    "nedezghiocatei": "nedezghiocat",
    "nedezghiocatele": "nedezghiocat",
    "nedezghiocatelor": "nedezghiocat",
    "nedezghiocați": "nedezghiocat",
    "nedezghiocații": "nedezghiocat",
    "nedezghiocaților": "nedezghiocat",
    "nedezghiocatul": "nedezghiocat",
    "nedezghiocatului": "nedezghiocat",
    "nedezgrădită": "nedezgrădit",
    "nedezgrădite": "nedezgrădit",
    "nedezgrădiți": "nedezgrădit",
    "nedezgropată": "nedezgropat",
    "nedezgropate": "nedezgropat",
    "nedezgropați": "nedezgropat",
    "nedezgustata": "nedezgustat",
    "nedezgustată": "nedezgustat",
    "nedezgustate": "nedezgustat",
    "nedezgustatei": "nedezgustat",
    "nedezgustatele": "nedezgustat",
    "nedezgustatelor": "nedezgustat",
    "nedezgustați": "nedezgustat",
    "nedezgustații": "nedezgustat",
    "nedezgustaților": "nedezgustat",
    "nedezgustatul": "nedezgustat",
    "nedezgustatului": "nedezgustat",
    "nedeziluzionata": "nedeziluzionat",
    "nedeziluzionată": "nedeziluzionat",
    "nedeziluzionate": "nedeziluzionat",
    "nedeziluzionatei": "nedeziluzionat",
    "nedeziluzionatele": "nedeziluzionat",
    "nedeziluzionatelor": "nedeziluzionat",
    "nedeziluzionați": "nedeziluzionat",
    "nedeziluzionații": "nedeziluzionat",
    "nedeziluzionaților": "nedeziluzionat",
    "nedeziluzionatul": "nedeziluzionat",
    "nedeziluzionatului": "nedeziluzionat",
    "nedezincrustată": "nedezincrustat",
    "nedezincrustate": "nedezincrustat",
    "nedezincrustați": "nedezincrustat",
    "nedezinfectată": "nedezinfectat",
    "nedezinfectate": "nedezinfectat",
    "nedezinfectați": "nedezinfectat",
    "nedezintegrata": "nedezintegrat",
    "nedezintegrată": "nedezintegrat",
    "nedezintegrate": "nedezintegrat",
    "nedezintegratei": "nedezintegrat",
    "nedezintegratele": "nedezintegrat",
    "nedezintegratelor": "nedezintegrat",
    "nedezintegrați": "nedezintegrat",
    "nedezintegrații": "nedezintegrat",
    "nedezintegraților": "nedezintegrat",
    "nedezintegratul": "nedezintegrat",
    "nedezintegratului": "nedezintegrat",
    "nedezinteresata": "nedezinteresat",
    "nedezinteresată": "nedezinteresat",
    "nedezinteresate": "nedezinteresat",
    "nedezinteresatei": "nedezinteresat",
    "nedezinteresatele": "nedezinteresat",
    "nedezinteresatelor": "nedezinteresat",
    "nedezinteresați": "nedezinteresat",
    "nedezinteresații": "nedezinteresat",
    "nedezinteresaților": "nedezinteresat",
    "nedezinteresatul": "nedezinteresat",
    "nedezinteresatului": "nedezinteresat",
    "nedezintoxicată": "nedezintoxicat",
    "nedezintoxicate": "nedezintoxicat",
    "nedezintoxicați": "nedezintoxicat",
    "nedezlânata": "nedezlânat",
    "nedezlânată": "nedezlânat",
    "nedezlânate": "nedezlânat",
    "nedezlânatei": "nedezlânat",
    "nedezlânatele": "nedezlânat",
    "nedezlânatelor": "nedezlânat",
    "nedezlânați": "nedezlânat",
    "nedezlânații": "nedezlânat",
    "nedezlânaților": "nedezlânat",
    "nedezlânatul": "nedezlânat",
    "nedezlânatului": "nedezlânat",
    "nedezlănțuita": "nedezlănțuit",
    "nedezlănțuită": "nedezlănțuit",
    "nedezlănțuite": "nedezlănțuit",
    "nedezlănțuitei": "nedezlănțuit",
    "nedezlănțuitele": "nedezlănțuit",
    "nedezlănțuitelor": "nedezlănțuit",
    "nedezlănțuiți": "nedezlănțuit",
    "nedezlănțuiții": "nedezlănțuit",
    "nedezlănțuiților": "nedezlănțuit",
    "nedezlănțuitul": "nedezlănțuit",
    "nedezlănțuitului": "nedezlănțuit",
    "nedezlegata": "nedezlegat",
    "nedezlegată": "nedezlegat",
    "nedezlegate": "nedezlegat",
    "nedezlegatei": "nedezlegat",
    "nedezlegatele": "nedezlegat",
    "nedezlegatelor": "nedezlegat",
    "nedezlegați": "nedezlegat",
    "nedezlegații": "nedezlegat",
    "nedezlegaților": "nedezlegat",
    "nedezlegatul": "nedezlegat",
    "nedezlegatului": "nedezlegat",
    "nedezlipita": "nedezlipit",
    "nedezlipită": "nedezlipit",
    "nedezlipite": "nedezlipit",
    "nedezlipitei": "nedezlipit",
    "nedezlipitele": "nedezlipit",
    "nedezlipitelor": "nedezlipit",
    "nedezlipiți": "nedezlipit",
    "nedezlipiții": "nedezlipit",
    "nedezlipiților": "nedezlipit",
    "nedezlipitul": "nedezlipit",
    "nedezlipitului": "nedezlipit",
    "nedezmățata": "nedezmățat",
    "nedezmățată": "nedezmățat",
    "nedezmățate": "nedezmățat",
    "nedezmățatei": "nedezmățat",
    "nedezmățatele": "nedezmățat",
    "nedezmățatelor": "nedezmățat",
    "nedezmățați": "nedezmățat",
    "nedezmățații": "nedezmățat",
    "nedezmățaților": "nedezmățat",
    "nedezmățatul": "nedezmățat",
    "nedezmățatului": "nedezmățat",
    "nedezmembrată": "nedezmembrat",
    "nedezmembrate": "nedezmembrat",
    "nedezmembrați": "nedezmembrat",
    "nedezmeticita": "nedezmeticit",
    "nedezmeticită": "nedezmeticit",
    "nedezmeticite": "nedezmeticit",
    "nedezmeticitei": "nedezmeticit",
    "nedezmeticitele": "nedezmeticit",
    "nedezmeticitelor": "nedezmeticit",
    "nedezmeticiți": "nedezmeticit",
    "nedezmeticiții": "nedezmeticit",
    "nedezmeticiților": "nedezmeticit",
    "nedezmeticitul": "nedezmeticit",
    "nedezmeticitului": "nedezmeticit",
    "nedezmierdata": "nedezmierdat",
    "nedezmierdată": "nedezmierdat",
    "nedezmierdate": "nedezmierdat",
    "nedezmierdatei": "nedezmierdat",
    "nedezmierdatele": "nedezmierdat",
    "nedezmierdatelor": "nedezmierdat",
    "nedezmierdați": "nedezmierdat",
    "nedezmierdații": "nedezmierdat",
    "nedezmierdaților": "nedezmierdat",
    "nedezmierdatul": "nedezmierdat",
    "nedezmierdatului": "nedezmierdat",
    "nedezmințita": "nedezmințit",
    "nedezmințită": "nedezmințit",
    "nedezmințite": "nedezmințit",
    "nedezmințitei": "nedezmințit",
    "nedezmințitele": "nedezmințit",
    "nedezmințitelor": "nedezmințit",
    "nedezmințiți": "nedezmințit",
    "nedezmințiții": "nedezmințit",
    "nedezmințiților": "nedezmințit",
    "nedezmințitul": "nedezmințit",
    "nedezmințitului": "nedezmințit",
    "nedezmiriștită": "nedezmiriștit",
    "nedezmiriștite": "nedezmiriștit",
    "nedezmiriștiți": "nedezmiriștit",
    "nedezmorțita": "nedezmorțit",
    "nedezmorțită": "nedezmorțit",
    "nedezmorțite": "nedezmorțit",
    "nedezmorțitei": "nedezmorțit",
    "nedezmorțitele": "nedezmorțit",
    "nedezmorțitelor": "nedezmorțit",
    "nedezmorțiți": "nedezmorțit",
    "nedezmorțiții": "nedezmorțit",
    "nedezmorțiților": "nedezmorțit",
    "nedezmorțitul": "nedezmorțit",
    "nedezmorțitului": "nedezmorțit",
    "nedeznaționalizata": "nedeznaționalizat",
    "nedeznaționalizată": "nedeznaționalizat",
    "nedeznaționalizate": "nedeznaționalizat",
    "nedeznaționalizatei": "nedeznaționalizat",
    "nedeznaționalizatele": "nedeznaționalizat",
    "nedeznaționalizatelor": "nedeznaționalizat",
    "nedeznaționalizați": "nedeznaționalizat",
    "nedeznaționalizații": "nedeznaționalizat",
    "nedeznaționalizaților": "nedeznaționalizat",
    "nedeznaționalizatul": "nedeznaționalizat",
    "nedeznaționalizatului": "nedeznaționalizat",
    "nedeznodata": "nedeznodat",
    "nedeznodată": "nedeznodat",
    "nedeznodate": "nedeznodat",
    "nedeznodatei": "nedeznodat",
    "nedeznodatele": "nedeznodat",
    "nedeznodatelor": "nedeznodat",
    "nedeznodați": "nedeznodat",
    "nedeznodații": "nedeznodat",
    "nedeznodaților": "nedeznodat",
    "nedeznodatul": "nedeznodat",
    "nedeznodatului": "nedeznodat",
    "nedezodorizată": "nedezodorizat",
    "nedezodorizate": "nedezodorizat",
    "nedezodorizați": "nedezodorizat",
    "nedezolata": "nedezolat",
    "nedezolată": "nedezolat",
    "nedezolate": "nedezolat",
    "nedezolatei": "nedezolat",
    "nedezolatele": "nedezolat",
    "nedezolatelor": "nedezolat",
    "nedezolați": "nedezolat",
    "nedezolații": "nedezolat",
    "nedezolaților": "nedezolat",
    "nedezolatul": "nedezolat",
    "nedezolatului": "nedezolat",
    "nedezonorata": "nedezonorat",
    "nedezonorată": "nedezonorat",
    "nedezonorate": "nedezonorat",
    "nedezonoratei": "nedezonorat",
    "nedezonoratele": "nedezonorat",
    "nedezonoratelor": "nedezonorat",
    "nedezonorați": "nedezonorat",
    "nedezonorații": "nedezonorat",
    "nedezonoraților": "nedezonorat",
    "nedezonoratul": "nedezonorat",
    "nedezonoratului": "nedezonorat",
    "nedezorganizata": "nedezorganizat",
    "nedezorganizată": "nedezorganizat",
    "nedezorganizate": "nedezorganizat",
    "nedezorganizatei": "nedezorganizat",
    "nedezorganizatele": "nedezorganizat",
    "nedezorganizatelor": "nedezorganizat",
    "nedezorganizați": "nedezorganizat",
    "nedezorganizații": "nedezorganizat",
    "nedezorganizaților": "nedezorganizat",
    "nedezorganizatul": "nedezorganizat",
    "nedezorganizatului": "nedezorganizat",
    "nedezorientata": "nedezorientat",
    "nedezorientată": "nedezorientat",
    "nedezorientate": "nedezorientat",
    "nedezorientatei": "nedezorientat",
    "nedezorientatele": "nedezorientat",
    "nedezorientatelor": "nedezorientat",
    "nedezorientați": "nedezorientat",
    "nedezorientații": "nedezorientat",
    "nedezorientaților": "nedezorientat",
    "nedezorientatul": "nedezorientat",
    "nedezorientatului": "nedezorientat",
    "nedezoxidată": "nedezoxidat",
    "nedezoxidate": "nedezoxidat",
    "nedezoxidați": "nedezoxidat",
    "nedezrădăcinata": "nedezrădăcinat",
    "nedezrădăcinată": "nedezrădăcinat",
    "nedezrădăcinate": "nedezrădăcinat",
    "nedezrădăcinatei": "nedezrădăcinat",
    "nedezrădăcinatele": "nedezrădăcinat",
    "nedezrădăcinatelor": "nedezrădăcinat",
    "nedezrădăcinați": "nedezrădăcinat",
    "nedezrădăcinații": "nedezrădăcinat",
    "nedezrădăcinaților": "nedezrădăcinat",
    "nedezrădăcinatul": "nedezrădăcinat",
    "nedezrădăcinatului": "nedezrădăcinat",
    "nedezumanizată": "nedezumanizat",
    "nedezumanizate": "nedezumanizat",
    "nedezumanizați": "nedezumanizat",
    "nedezvăluită": "nedezvăluit",
    "nedezvăluite": "nedezvăluit",
    "nedezvăluiți": "nedezvăluit",
    "nedezvățată": "nedezvățat",
    "nedezvățate": "nedezvățat",
    "nedezvățați": "nedezvățat",
    "nedezvelită": "nedezvelit",
    "nedezvelite": "nedezvelit",
    "nedezveliți": "nedezvelit",
    "nedezvinovățită": "nedezvinovățit",
    "nedezvinovățite": "nedezvinovățit",
    "nedezvinovățiți": "nedezvinovățit",
    "nedezvinuită": "nedezvinuit",
    "nedezvinuite": "nedezvinuit",
    "nedezvinuiți": "nedezvinuit",
    "nedezvoltata": "nedezvoltat",
    "nedezvoltată": "nedezvoltat",
    "nedezvoltate": "nedezvoltat",
    "nedezvoltatei": "nedezvoltat",
    "nedezvoltatele": "nedezvoltat",
    "nedezvoltatelor": "nedezvoltat",
    "nedezvoltați": "nedezvoltat",
    "nedezvoltații": "nedezvoltat",
    "nedezvoltaților": "nedezvoltat",
    "nedezvoltatul": "nedezvoltat",
    "nedezvoltatului": "nedezvoltat",
    "nediafanizată": "nediafanizat",
    "nediafanizate": "nediafanizat",
    "nediafanizați": "nediafanizat",
    "nediagnosticată": "nediagnosticat",
    "nediagnosticate": "nediagnosticat",
    "nediagnosticați": "nediagnosticat",
    "nedialogata": "nedialogat",
    "nedialogată": "nedialogat",
    "nedialogate": "nedialogat",
    "nedialogatei": "nedialogat",
    "nedialogatele": "nedialogat",
    "nedialogatelor": "nedialogat",
    "nedialogați": "nedialogat",
    "nedialogații": "nedialogat",
    "nedialogaților": "nedialogat",
    "nedialogatul": "nedialogat",
    "nedialogatului": "nedialogat",
    "nedibăcită": "nedibăcit",
    "nedibăcite": "nedibăcit",
    "nedibăciți": "nedibăcit",
    "nedibuită": "nedibuit",
    "nedibuite": "nedibuit",
    "nedibuiți": "nedibuit",
    "nedichisita": "nedichisit",
    "nedichisită": "nedichisit",
    "nedichisite": "nedichisit",
    "nedichisitei": "nedichisit",
    "nedichisitele": "nedichisit",
    "nedichisitelor": "nedichisit",
    "nedichisiți": "nedichisit",
    "nedichisiții": "nedichisit",
    "nedichisiților": "nedichisit",
    "nedichisitul": "nedichisit",
    "nedichisitului": "nedichisit",
    "nedictată": "nedictat",
    "nedictate": "nedictat",
    "nedictați": "nedictat",
    "nedidactica": "nedidactic",
    "nedidactică": "nedidactic",
    "nedidactice": "nedidactic",
    "nedidacticei": "nedidactic",
    "nedidacticele": "nedidactic",
    "nedidacticelor": "nedidactic",
    "nedidactici": "nedidactic",
    "nedidacticii": "nedidactic",
    "nedidacticilor": "nedidactic",
    "nedidacticul": "nedidactic",
    "nedidacticului": "nedidactic",
    "nediferențiata": "nediferențiat",
    "nediferențiată": "nediferențiat",
    "nediferențiate": "nediferențiat",
    "nediferențiatei": "nediferențiat",
    "nediferențiatele": "nediferențiat",
    "nediferențiatelor": "nediferențiat",
    "nediferențiați": "nediferențiat",
    "nediferențiații": "nediferențiat",
    "nediferențiaților": "nediferențiat",
    "nediferențiatul": "nediferențiat",
    "nediferențiatului": "nediferențiat",
    "nediferita": "nediferit",
    "nediferită": "nediferit",
    "nediferite": "nediferit",
    "nediferitei": "nediferit",
    "nediferitele": "nediferit",
    "nediferitelor": "nediferit",
    "nediferiți": "nediferit",
    "nediferiții": "nediferit",
    "nediferiților": "nediferit",
    "nediferitul": "nediferit",
    "nediferitului": "nediferit",
    "nedifractată": "nedifractat",
    "nedifractate": "nedifractat",
    "nedifractați": "nedifractat",
    "nediftongata": "nediftongat",
    "nediftongată": "nediftongat",
    "nediftongate": "nediftongat",
    "nediftongatei": "nediftongat",
    "nediftongatele": "nediftongat",
    "nediftongatelor": "nediftongat",
    "nediftongați": "nediftongat",
    "nediftongații": "nediftongat",
    "nediftongaților": "nediftongat",
    "nediftongatul": "nediftongat",
    "nediftongatului": "nediftongat",
    "nedifuzată": "nedifuzat",
    "nedifuzate": "nedifuzat",
    "nedifuzați": "nedifuzat",
    "nedigerata": "nedigerat",
    "nedigerată": "nedigerat",
    "nedigerate": "nedigerat",
    "nedigeratei": "nedigerat",
    "nedigeratele": "nedigerat",
    "nedigeratelor": "nedigerat",
    "nedigerați": "nedigerat",
    "nedigerații": "nedigerat",
    "nedigeraților": "nedigerat",
    "nedigeratul": "nedigerat",
    "nedigeratului": "nedigerat",
    "nedijmuită": "nedijmuit",
    "nedijmuite": "nedijmuit",
    "nedijmuiți": "nedijmuit",
    "nedilatata": "nedilatat",
    "nedilatată": "nedilatat",
    "nedilatate": "nedilatat",
    "nedilatatei": "nedilatat",
    "nedilatatele": "nedilatat",
    "nedilatatelor": "nedilatat",
    "nedilatați": "nedilatat",
    "nedilatații": "nedilatat",
    "nedilataților": "nedilatat",
    "nedilatatul": "nedilatat",
    "nedilatatului": "nedilatat",
    "nediluata": "nediluat",
    "nediluată": "nediluat",
    "nediluate": "nediluat",
    "nediluatei": "nediluat",
    "nediluatele": "nediluat",
    "nediluatelor": "nediluat",
    "nediluați": "nediluat",
    "nediluații": "nediluat",
    "nediluaților": "nediluat",
    "nediluatul": "nediluat",
    "nediluatului": "nediluat",
    "nedimensionată": "nedimensionat",
    "nedimensionate": "nedimensionat",
    "nedimensionați": "nedimensionat",
    "nediminuată": "nediminuat",
    "nediminuate": "nediminuat",
    "nediminuați": "nediminuat",
    "nedinamitată": "nedinamitat",
    "nedinamitate": "nedinamitat",
    "nedinamitați": "nedinamitat",
    "nedinamizată": "nedinamizat",
    "nedinamizate": "nedinamizat",
    "nedinamizați": "nedinamizat",
    "nedințata": "nedințat",
    "nedințată": "nedințat",
    "nedințate": "nedințat",
    "nedințatei": "nedințat",
    "nedințatele": "nedințat",
    "nedințatelor": "nedințat",
    "nedințați": "nedințat",
    "nedințații": "nedințat",
    "nedințaților": "nedințat",
    "nedințatul": "nedințat",
    "nedințatului": "nedințat",
    "nediriguită": "nediriguit",
    "nediriguite": "nediriguit",
    "nediriguiți": "nediriguit",
    "nedirijata": "nedirijat",
    "nedirijată": "nedirijat",
    "nedirijate": "nedirijat",
    "nedirijatei": "nedirijat",
    "nedirijatele": "nedirijat",
    "nedirijatelor": "nedirijat",
    "nedirijați": "nedirijat",
    "nedirijații": "nedirijat",
    "nedirijaților": "nedirijat",
    "nedirijatul": "nedirijat",
    "nedirijatului": "nedirijat",
    "nediscernută": "nediscernut",
    "nediscernute": "nediscernut",
    "nediscernuți": "nediscernut",
    "nedisciplinata": "nedisciplinat",
    "nedisciplinată": "nedisciplinat",
    "nedisciplinate": "nedisciplinat",
    "nedisciplinatei": "nedisciplinat",
    "nedisciplinatele": "nedisciplinat",
    "nedisciplinatelor": "nedisciplinat",
    "nedisciplinați": "nedisciplinat",
    "nedisciplinații": "nedisciplinat",
    "nedisciplinaților": "nedisciplinat",
    "nedisciplinatul": "nedisciplinat",
    "nedisciplinatului": "nedisciplinat",
    "nediscordata": "nediscordat",
    "nediscordată": "nediscordat",
    "nediscordate": "nediscordat",
    "nediscordatei": "nediscordat",
    "nediscordatele": "nediscordat",
    "nediscordatelor": "nediscordat",
    "nediscordați": "nediscordat",
    "nediscordații": "nediscordat",
    "nediscordaților": "nediscordat",
    "nediscordatul": "nediscordat",
    "nediscordatului": "nediscordat",
    "nediscreditata": "nediscreditat",
    "nediscreditată": "nediscreditat",
    "nediscreditate": "nediscreditat",
    "nediscreditatei": "nediscreditat",
    "nediscreditatele": "nediscreditat",
    "nediscreditatelor": "nediscreditat",
    "nediscreditați": "nediscreditat",
    "nediscreditații": "nediscreditat",
    "nediscreditaților": "nediscreditat",
    "nediscreditatul": "nediscreditat",
    "nediscreditatului": "nediscreditat",
    "nediscriminatoria": "nediscriminatoriu",
    "nediscriminatorie": "nediscriminatoriu",
    "nediscriminatoriei": "nediscriminatoriu",
    "nediscriminatorii": "nediscriminatoriu",
    "nediscriminatoriii": "nediscriminatoriu",
    "nediscriminatoriile": "nediscriminatoriu",
    "nediscriminatoriilor": "nediscriminatoriu",
    "nediscriminatoriul": "nediscriminatoriu",
    "nediscriminatoriului": "nediscriminatoriu",
    "nedisculpată": "nedisculpat",
    "nedisculpate": "nedisculpat",
    "nedisculpați": "nedisculpat",
    "nediscutata": "nediscutat",
    "nediscutată": "nediscutat",
    "nediscutate": "nediscutat",
    "nediscutatei": "nediscutat",
    "nediscutatele": "nediscutat",
    "nediscutatelor": "nediscutat",
    "nediscutați": "nediscutat",
    "nediscutații": "nediscutat",
    "nediscutaților": "nediscutat",
    "nediscutatul": "nediscutat",
    "nediscutatului": "nediscutat",
    "nedisecată": "nedisecat",
    "nedisecate": "nedisecat",
    "nedisecați": "nedisecat",
    "nediseminarea": "nediseminare",
    "nediseminări": "nediseminare",
    "nediseminării": "nediseminare",
    "nediseminările": "nediseminare",
    "nediseminărilor": "nediseminare",
    "nedisertată": "nedisertat",
    "nedisertate": "nedisertat",
    "nedisertați": "nedisertat",
    "nedisimilată": "nedisimilat",
    "nedisimilate": "nedisimilat",
    "nedisimilați": "nedisimilat",
    "nedisimulata": "nedisimulat",
    "nedisimulată": "nedisimulat",
    "nedisimulate": "nedisimulat",
    "nedisimulatei": "nedisimulat",
    "nedisimulatele": "nedisimulat",
    "nedisimulatelor": "nedisimulat",
    "nedisimulați": "nedisimulat",
    "nedisimulații": "nedisimulat",
    "nedisimulaților": "nedisimulat",
    "nedisimulatul": "nedisimulat",
    "nedisimulatului": "nedisimulat",
    "nedisjunsă": "nedisjuns",
    "nedisjunse": "nedisjuns",
    "nedisjunși": "nedisjuns",
    "nedislocata": "nedislocat",
    "nedislocată": "nedislocat",
    "nedislocate": "nedislocat",
    "nedislocatei": "nedislocat",
    "nedislocatele": "nedislocat",
    "nedislocatelor": "nedislocat",
    "nedislocați": "nedislocat",
    "nedislocații": "nedislocat",
    "nedislocaților": "nedislocat",
    "nedislocatul": "nedislocat",
    "nedislocatului": "nedislocat",
    "nedisociata": "nedisociat",
    "nedisociată": "nedisociat",
    "nedisociate": "nedisociat",
    "nedisociatei": "nedisociat",
    "nedisociatele": "nedisociat",
    "nedisociatelor": "nedisociat",
    "nedisociați": "nedisociat",
    "nedisociații": "nedisociat",
    "nedisociaților": "nedisociat",
    "nedisociatul": "nedisociat",
    "nedisociatului": "nedisociat",
    "nedispăruta": "nedispărut",
    "nedispărută": "nedispărut",
    "nedispărute": "nedispărut",
    "nedispărutei": "nedispărut",
    "nedispărutele": "nedispărut",
    "nedispărutelor": "nedispărut",
    "nedispăruți": "nedispărut",
    "nedispăruții": "nedispărut",
    "nedispăruților": "nedispărut",
    "nedispărutul": "nedispărut",
    "nedispărutului": "nedispărut",
    "nedispensata": "nedispensat",
    "nedispensată": "nedispensat",
    "nedispensate": "nedispensat",
    "nedispensatei": "nedispensat",
    "nedispensatele": "nedispensat",
    "nedispensatelor": "nedispensat",
    "nedispensați": "nedispensat",
    "nedispensații": "nedispensat",
    "nedispensaților": "nedispensat",
    "nedispensatul": "nedispensat",
    "nedispensatului": "nedispensat",
    "nedisperata": "nedisperat",
    "nedisperată": "nedisperat",
    "nedisperate": "nedisperat",
    "nedisperatei": "nedisperat",
    "nedisperatele": "nedisperat",
    "nedisperatelor": "nedisperat",
    "nedisperați": "nedisperat",
    "nedisperații": "nedisperat",
    "nedisperaților": "nedisperat",
    "nedisperatul": "nedisperat",
    "nedisperatului": "nedisperat",
    "nedispersata": "nedispersat",
    "nedispersată": "nedispersat",
    "nedispersate": "nedispersat",
    "nedispersatei": "nedispersat",
    "nedispersatele": "nedispersat",
    "nedispersatelor": "nedispersat",
    "nedispersați": "nedispersat",
    "nedispersații": "nedispersat",
    "nedispersaților": "nedispersat",
    "nedispersatul": "nedispersat",
    "nedispersatului": "nedispersat",
    "nedisplăcută": "nedisplăcut",
    "nedisplăcute": "nedisplăcut",
    "nedisplăcuți": "nedisplăcut",
    "nedisprețuită": "nedisprețuit",
    "nedisprețuite": "nedisprețuit",
    "nedisprețuiți": "nedisprețuit",
    "nedispusa": "nedispus",
    "nedispusă": "nedispus",
    "nedispuse": "nedispus",
    "nedispusei": "nedispus",
    "nedispusele": "nedispus",
    "nedispuselor": "nedispus",
    "nedispuși": "nedispus",
    "nedispușii": "nedispus",
    "nedispușilor": "nedispus",
    "nedispusul": "nedispus",
    "nedispusului": "nedispus",
    "nedisputată": "nedisputat",
    "nedisputate": "nedisputat",
    "nedisputați": "nedisputat",
    "nedistanțată": "nedistanțat",
    "nedistanțate": "nedistanțat",
    "nedistanțați": "nedistanțat",
    "nedistilata": "nedistilat",
    "nedistilată": "nedistilat",
    "nedistilate": "nedistilat",
    "nedistilatei": "nedistilat",
    "nedistilatele": "nedistilat",
    "nedistilatelor": "nedistilat",
    "nedistilați": "nedistilat",
    "nedistilații": "nedistilat",
    "nedistilaților": "nedistilat",
    "nedistilatul": "nedistilat",
    "nedistilatului": "nedistilat",
    "nedistinsa": "nedistins",
    "nedistinsă": "nedistins",
    "nedistinse": "nedistins",
    "nedistinsei": "nedistins",
    "nedistinsele": "nedistins",
    "nedistinselor": "nedistins",
    "nedistinși": "nedistins",
    "nedistinșii": "nedistins",
    "nedistinșilor": "nedistins",
    "nedistinsul": "nedistins",
    "nedistinsului": "nedistins",
    "nedistonată": "nedistonat",
    "nedistonate": "nedistonat",
    "nedistonați": "nedistonat",
    "nedistorsionata": "nedistorsionat",
    "nedistorsionată": "nedistorsionat",
    "nedistorsionate": "nedistorsionat",
    "nedistorsionatei": "nedistorsionat",
    "nedistorsionatele": "nedistorsionat",
    "nedistorsionatelor": "nedistorsionat",
    "nedistorsionați": "nedistorsionat",
    "nedistorsionații": "nedistorsionat",
    "nedistorsionaților": "nedistorsionat",
    "nedistorsionatul": "nedistorsionat",
    "nedistorsionatului": "nedistorsionat",
    "nedistrasa": "nedistras",
    "nedistrasă": "nedistras",
    "nedistrase": "nedistras",
    "nedistrasei": "nedistras",
    "nedistrasele": "nedistras",
    "nedistraselor": "nedistras",
    "nedistrași": "nedistras",
    "nedistrașii": "nedistras",
    "nedistrașilor": "nedistras",
    "nedistrasul": "nedistras",
    "nedistrasului": "nedistras",
    "nedistrata": "nedistrat",
    "nedistrată": "nedistrat",
    "nedistrate": "nedistrat",
    "nedistratei": "nedistrat",
    "nedistratele": "nedistrat",
    "nedistratelor": "nedistrat",
    "nedistrați": "nedistrat",
    "nedistrații": "nedistrat",
    "nedistraților": "nedistrat",
    "nedistratul": "nedistrat",
    "nedistratului": "nedistrat",
    "nedistribuită": "nedistribuit",
    "nedistribuite": "nedistribuit",
    "nedistribuiți": "nedistribuit",
    "nedistrusa": "nedistrus",
    "nedistrusă": "nedistrus",
    "nedistruse": "nedistrus",
    "nedistrusei": "nedistrus",
    "nedistrusele": "nedistrus",
    "nedistruselor": "nedistrus",
    "nedistruși": "nedistrus",
    "nedistrușii": "nedistrus",
    "nedistrușilor": "nedistrus",
    "nedistrusul": "nedistrus",
    "nedistrusului": "nedistrus",
    "nedivagată": "nedivagat",
    "nedivagate": "nedivagat",
    "nedivagați": "nedivagat",
    "nediversificată": "nediversificat",
    "nediversificate": "nediversificat",
    "nediversificați": "nediversificat",
    "nedivizata": "nedivizat",
    "nedivizată": "nedivizat",
    "nedivizate": "nedivizat",
    "nedivizatei": "nedivizat",
    "nedivizatele": "nedivizat",
    "nedivizatelor": "nedivizat",
    "nedivizați": "nedivizat",
    "nedivizații": "nedivizat",
    "nedivizaților": "nedivizat",
    "nedivizatul": "nedivizat",
    "nedivizatului": "nedivizat",
    "nedivorțata": "nedivorțat",
    "nedivorțată": "nedivorțat",
    "nedivorțate": "nedivorțat",
    "nedivorțatei": "nedivorțat",
    "nedivorțatele": "nedivorțat",
    "nedivorțatelor": "nedivorțat",
    "nedivorțați": "nedivorțat",
    "nedivorțații": "nedivorțat",
    "nedivorțaților": "nedivorțat",
    "nedivorțatul": "nedivorțat",
    "nedivorțatului": "nedivorțat",
    "nedivulgată": "nedivulgat",
    "nedivulgate": "nedivulgat",
    "nedivulgați": "nedivulgat",
    "nedizgrațiata": "nedizgrațiat",
    "nedizgrațiată": "nedizgrațiat",
    "nedizgrațiate": "nedizgrațiat",
    "nedizgrațiatei": "nedizgrațiat",
    "nedizgrațiatele": "nedizgrațiat",
    "nedizgrațiatelor": "nedizgrațiat",
    "nedizgrațiați": "nedizgrațiat",
    "nedizgrațiații": "nedizgrațiat",
    "nedizgrațiaților": "nedizgrațiat",
    "nedizgrațiatul": "nedizgrațiat",
    "nedizgrațiatului": "nedizgrațiat",
    "nedizolvata": "nedizolvat",
    "nedizolvată": "nedizolvat",
    "nedizolvate": "nedizolvat",
    "nedizolvatei": "nedizolvat",
    "nedizolvatele": "nedizolvat",
    "nedizolvatelor": "nedizolvat",
    "nedizolvați": "nedizolvat",
    "nedizolvații": "nedizolvat",
    "nedizolvaților": "nedizolvat",
    "nedizolvatul": "nedizolvat",
    "nedizolvatului": "nedizolvat",
    "nedobândită": "nedobândit",
    "nedobândite": "nedobândit",
    "nedobândiți": "nedobândit",
    "nedoborâta": "nedoborât",
    "nedoborâtă": "nedoborât",
    "nedoborâte": "nedoborât",
    "nedoborâtei": "nedoborât",
    "nedoborâtele": "nedoborât",
    "nedoborâtelor": "nedoborât",
    "nedoborâți": "nedoborât",
    "nedoborâții": "nedoborât",
    "nedoborâților": "nedoborât",
    "nedoborâtul": "nedoborât",
    "nedoborâtului": "nedoborât",
    "nedoctoricită": "nedoctoricit",
    "nedoctoricite": "nedoctoricit",
    "nedoctoriciți": "nedoctoricit",
    "nedocumentata": "nedocumentat",
    "nedocumentată": "nedocumentat",
    "nedocumentate": "nedocumentat",
    "nedocumentatei": "nedocumentat",
    "nedocumentatele": "nedocumentat",
    "nedocumentatelor": "nedocumentat",
    "nedocumentați": "nedocumentat",
    "nedocumentații": "nedocumentat",
    "nedocumentaților": "nedocumentat",
    "nedocumentatul": "nedocumentat",
    "nedocumentatului": "nedocumentat",
    "nedogita": "nedogit",
    "nedogită": "nedogit",
    "nedogite": "nedogit",
    "nedogitei": "nedogit",
    "nedogitele": "nedogit",
    "nedogitelor": "nedogit",
    "nedogiți": "nedogit",
    "nedogiții": "nedogit",
    "nedogiților": "nedogit",
    "nedogitul": "nedogit",
    "nedogitului": "nedogit",
    "nedogorita": "nedogorit",
    "nedogorită": "nedogorit",
    "nedogorite": "nedogorit",
    "nedogoritei": "nedogorit",
    "nedogoritele": "nedogorit",
    "nedogoritelor": "nedogorit",
    "nedogoriți": "nedogorit",
    "nedogoriții": "nedogorit",
    "nedogoriților": "nedogorit",
    "nedogoritul": "nedogorit",
    "nedogoritului": "nedogorit",
    "nedoinită": "nedoinit",
    "nedoinite": "nedoinit",
    "nedoiniți": "nedoinit",
    "nedojenită": "nedojenit",
    "nedojenite": "nedojenit",
    "nedojeniți": "nedojenit",
    "nedomesticita": "nedomesticit",
    "nedomesticită": "nedomesticit",
    "nedomesticite": "nedomesticit",
    "nedomesticitei": "nedomesticit",
    "nedomesticitele": "nedomesticit",
    "nedomesticitelor": "nedomesticit",
    "nedomesticiți": "nedomesticit",
    "nedomesticiții": "nedomesticit",
    "nedomesticiților": "nedomesticit",
    "nedomesticitul": "nedomesticit",
    "nedomesticitului": "nedomesticit",
    "nedomiciliată": "nedomiciliat",
    "nedomiciliate": "nedomiciliat",
    "nedomiciliați": "nedomiciliat",
    "nedominată": "nedominat",
    "nedominate": "nedominat",
    "nedominați": "nedominat",
    "nedomnită": "nedomnit",
    "nedomnite": "nedomnit",
    "nedomniți": "nedomnit",
    "nedomolita": "nedomolit",
    "nedomolită": "nedomolit",
    "nedomolite": "nedomolit",
    "nedomolitei": "nedomolit",
    "nedomolitele": "nedomolit",
    "nedomolitelor": "nedomolit",
    "nedomoliți": "nedomolit",
    "nedomoliții": "nedomolit",
    "nedomoliților": "nedomolit",
    "nedomolitul": "nedomolit",
    "nedomolitului": "nedomolit",
    "nedonată": "nedonat",
    "nedonate": "nedonat",
    "nedonați": "nedonat",
    "nedondănită": "nedondănit",
    "nedondănite": "nedondănit",
    "nedondăniți": "nedondănit",
    "nedopată": "nedopat",
    "nedopate": "nedopat",
    "nedopați": "nedopat",
    "nedorita": "nedorit",
    "nedorită": "nedorit",
    "nedorite": "nedorit",
    "nedoritei": "nedorit",
    "nedoritele": "nedorit",
    "nedoritelor": "nedorit",
    "nedoriți": "nedorit",
    "nedoriții": "nedorit",
    "nedoriților": "nedorit",
    "nedoritul": "nedorit",
    "nedoritului": "nedorit",
    "nedormirea": "nedormire",
    "nedormiri": "nedormire",
    "nedormirii": "nedormire",
    "nedormirile": "nedormire",
    "nedormirilor": "nedormire",
    "nedormita": "nedormit",
    "nedormită": "nedormit",
    "nedormite": "nedormit",
    "nedormitei": "nedormit",
    "nedormitele": "nedormit",
    "nedormitelor": "nedormit",
    "nedormiți": "nedormit",
    "nedormiții": "nedormit",
    "nedormiților": "nedormit",
    "nedormitul": "nedormit",
    "nedormitului": "nedormit",
    "nedormitată": "nedormitat",
    "nedormitate": "nedormitat",
    "nedormitați": "nedormitat",
    "nedosita": "nedosit",
    "nedosită": "nedosit",
    "nedosite": "nedosit",
    "nedositei": "nedosit",
    "nedositele": "nedosit",
    "nedositelor": "nedosit",
    "nedosiți": "nedosit",
    "nedosiții": "nedosit",
    "nedosiților": "nedosit",
    "nedositul": "nedosit",
    "nedositului": "nedosit",
    "nedospita": "nedospit",
    "nedospită": "nedospit",
    "nedospite": "nedospit",
    "nedospitei": "nedospit",
    "nedospitele": "nedospit",
    "nedospitelor": "nedospit",
    "nedospiți": "nedospit",
    "nedospiții": "nedospit",
    "nedospiților": "nedospit",
    "nedospitul": "nedospit",
    "nedospitului": "nedospit",
    "nedotata": "nedotat",
    "nedotată": "nedotat",
    "nedotate": "nedotat",
    "nedotatei": "nedotat",
    "nedotatele": "nedotat",
    "nedotatelor": "nedotat",
    "nedotați": "nedotat",
    "nedotații": "nedotat",
    "nedotaților": "nedotat",
    "nedotatul": "nedotat",
    "nedotatului": "nedotat",
    "nedovedită": "nedovedit",
    "nedovedite": "nedovedit",
    "nedovediți": "nedovedit",
    "nedozată": "nedozat",
    "nedozate": "nedozat",
    "nedozați": "nedozat",
    "nedrăcuită": "nedrăcuit",
    "nedrăcuite": "nedrăcuit",
    "nedrăcuiți": "nedrăcuit",
    "nedragată": "nedragat",
    "nedragate": "nedragat",
    "nedragați": "nedragat",
    "nedrăgostită": "nedrăgostit",
    "nedrăgostite": "nedrăgostit",
    "nedrăgostiți": "nedrăgostit",
    "nedrămăluită": "nedrămăluit",
    "nedrămăluite": "nedrămăluit",
    "nedrămăluiți": "nedrămăluit",
    "nedramatizată": "nedramatizat",
    "nedramatizate": "nedramatizat",
    "nedramatizați": "nedramatizat",
    "nedrămuită": "nedrămuit",
    "nedrămuite": "nedrămuit",
    "nedrămuiți": "nedrămuit",
    "nedrapată": "nedrapat",
    "nedrapate": "nedrapat",
    "nedrapați": "nedrapat",
    "nedrenată": "nedrenat",
    "nedrenate": "nedrenat",
    "nedrenați": "nedrenat",
    "nedreapta": "nedrept",
    "nedreaptă": "nedrept",
    "nedrepte": "nedrept",
    "nedreptei": "nedrept",
    "nedreptele": "nedrept",
    "nedreptelor": "nedrept",
    "nedrepți": "nedrept",
    "nedrepții": "nedrept",
    "nedrepților": "nedrept",
    "nedreptul": "nedrept",
    "nedreptule": "nedrept",
    "nedreptului": "nedrept",
    "nedreptatea": "nedreptate",
    "nedreptăți": "nedreptate",
    "nedreptății": "nedreptate",
    "nedreptățile": "nedreptate",
    "nedreptăților": "nedreptate",
    "nedreptățea": "nedreptăți",
    "nedreptățeai": "nedreptăți",
    "nedreptățeam": "nedreptăți",
    "nedreptățească": "nedreptăți",
    "nedreptățeați": "nedreptăți",
    "nedreptățeau": "nedreptăți",
    "nedreptățesc": "nedreptăți",
    "nedreptățește": "nedreptăți",
    "nedreptățești": "nedreptăți",
    "nedreptății": "nedreptăți",
    "nedreptățim": "nedreptăți",
    "nedreptățind": "nedreptăți",
    "nedreptățindu": "nedreptăți",
    "nedreptățiră": "nedreptăți",
    "nedreptățirăm": "nedreptăți",
    "nedreptățirăți": "nedreptăți",
    "nedreptățise": "nedreptăți",
    "nedreptățisem": "nedreptăți",
    "nedreptățiseră": "nedreptăți",
    "nedreptățiserăm": "nedreptăți",
    "nedreptățiserăți": "nedreptăți",
    "nedreptățiseși": "nedreptăți",
    "nedreptățiși": "nedreptăți",
    "nedreptățit": "nedreptăți",
    "nedreptățiți": "nedreptăți",
    "nemainedreptățindu": "nedreptăți",
    "nenedreptățindu": "nedreptăți",
    "nedreptățită": "nedreptățit",
    "nedreptățite": "nedreptățit",
    "nedreptățiți": "nedreptățit",
    "nedreasă": "nedres",
    "nedrese": "nedres",
    "nedreși": "nedres",
    "nedreșii": "nedres",
    "nedreșilor": "nedres",
    "nedresul": "nedres",
    "nedresului": "nedres",
    "nedresata": "nedresat",
    "nedresată": "nedresat",
    "nedresate": "nedresat",
    "nedresatei": "nedresat",
    "nedresatele": "nedresat",
    "nedresatelor": "nedresat",
    "nedresați": "nedresat",
    "nedresații": "nedresat",
    "nedresaților": "nedresat",
    "nedresatul": "nedresat",
    "nedresatului": "nedresat",
    "nedriblată": "nedriblat",
    "nedriblate": "nedriblat",
    "nedriblați": "nedriblat",
    "nedrișcuită": "nedrișcuit",
    "nedrișcuite": "nedrișcuit",
    "nedrișcuiți": "nedrișcuit",
    "nedrumuită": "nedrumuit",
    "nedrumuite": "nedrumuit",
    "nedrumuiți": "nedrumuit",
    "nedublată": "nedublat",
    "nedublate": "nedublat",
    "nedublați": "nedublat",
    "neduduită": "neduduit",
    "neduduite": "neduduit",
    "neduduiți": "neduduit",
    "neduelată": "neduelat",
    "neduelate": "neduelat",
    "neduelați": "neduelat",
    "neduhnită": "neduhnit",
    "neduhnite": "neduhnit",
    "neduhniți": "neduhnit",
    "neduhorită": "neduhorit",
    "neduhorite": "neduhorit",
    "neduhoriți": "neduhorit",
    "neduhovnicită": "neduhovnicit",
    "neduhovnicite": "neduhovnicit",
    "neduhovniciți": "neduhovnicit",
    "nedumerirea": "nedumerire",
    "nedumeriri": "nedumerire",
    "nedumeririi": "nedumerire",
    "nedumeririle": "nedumerire",
    "nedumeririlor": "nedumerire",
    "nedumerită": "nedumerit",
    "nedumerite": "nedumerit",
    "nedumeriți": "nedumerit",
    "nedumicată": "nedumicat",
    "nedumicate": "nedumicat",
    "nedumicați": "nedumicat",
    "nedumirită": "nedumirit",
    "nedumirite": "nedumirit",
    "nedumiriți": "nedumirit",
    "neduplicată": "neduplicat",
    "neduplicate": "neduplicat",
    "neduplicați": "neduplicat",
    "nedurăită": "nedurăit",
    "nedurăite": "nedurăit",
    "nedurăiți": "nedurăit",
    "nedurată": "nedurat",
    "nedurate": "nedurat",
    "nedurați": "nedurat",
    "nedurduită": "nedurduit",
    "nedurduite": "nedurduit",
    "nedurduiți": "nedurduit",
    "nedureroasa": "nedureros",
    "nedureroasă": "nedureros",
    "nedureroase": "nedureros",
    "nedureroasei": "nedureros",
    "nedureroasele": "nedureros",
    "nedureroaselor": "nedureros",
    "nedureroși": "nedureros",
    "nedureroșii": "nedureros",
    "nedureroșilor": "nedureros",
    "nedurerosul": "nedureros",
    "nedurerosului": "nedureros",
    "neduruită": "neduruit",
    "neduruite": "neduruit",
    "neduruiți": "neduruit",
    "nedurută": "nedurut",
    "nedurute": "nedurut",
    "neduruți": "nedurut",
    "nedusa": "nedus",
    "nedusă": "nedus",
    "neduse": "nedus",
    "nedusei": "nedus",
    "nedusele": "nedus",
    "neduselor": "nedus",
    "neduși": "nedus",
    "nedușii": "nedus",
    "nedușilor": "nedus",
    "nedusul": "nedus",
    "nedusului": "nedus",
    "nedușmănită": "nedușmănit",
    "nedușmănite": "nedușmănit",
    "nedușmăniți": "nedușmănit",
    "neeboșată": "neeboșat",
    "neeboșate": "neeboșat",
    "neeboșați": "neeboșat",
    "neechilibrata": "neechilibrat",
    "neechilibrată": "neechilibrat",
    "neechilibrate": "neechilibrat",
    "neechilibratei": "neechilibrat",
    "neechilibratele": "neechilibrat",
    "neechilibratelor": "neechilibrat",
    "neechilibrați": "neechilibrat",
    "neechilibrații": "neechilibrat",
    "neechilibraților": "neechilibrat",
    "neechilibratul": "neechilibrat",
    "neechilibratului": "neechilibrat",
    "neechipata": "neechipat",
    "neechipată": "neechipat",
    "neechipate": "neechipat",
    "neechipatei": "neechipat",
    "neechipatele": "neechipat",
    "neechipatelor": "neechipat",
    "neechipați": "neechipat",
    "neechipații": "neechipat",
    "neechipaților": "neechipat",
    "neechipatul": "neechipat",
    "neechipatului": "neechipat",
    "neechivalată": "neechivalat",
    "neechivalate": "neechivalat",
    "neechivalați": "neechivalat",
    "neeclipsată": "neeclipsat",
    "neeclipsate": "neeclipsat",
    "neeclipsați": "neeclipsat",
    "neeconomica": "neeconomic",
    "neeconomică": "neeconomic",
    "neeconomice": "neeconomic",
    "neeconomicei": "neeconomic",
    "neeconomicele": "neeconomic",
    "neeconomicelor": "neeconomic",
    "neeconomici": "neeconomic",
    "neeconomicii": "neeconomic",
    "neeconomicilor": "neeconomic",
    "neeconomisită": "neeconomisit",
    "neeconomisite": "neeconomisit",
    "neeconomisiți": "neeconomisit",
    "needificată": "needificat",
    "needificate": "needificat",
    "needificați": "needificat",
    "needitată": "needitat",
    "needitate": "needitat",
    "needitați": "needitat",
    "needucată": "needucat",
    "needucate": "needucat",
    "needucați": "needucat",
    "neefectuată": "neefectuat",
    "neefectuate": "neefectuat",
    "neefectuați": "neefectuat",
    "neeficienta": "neeficient",
    "neeficientă": "neeficient",
    "neeficiente": "neeficient",
    "neeficientei": "neeficient",
    "neeficientele": "neeficient",
    "neeficientelor": "neeficient",
    "neeficienți": "neeficient",
    "neeficienții": "neeficient",
    "neeficienților": "neeficient",
    "neeficientul": "neeficient",
    "neeficientului": "neeficient",
    "neeficiența": "neeficiență",
    "neeficiențe": "neeficiență",
    "neeficienței": "neeficiență",
    "neeficiențele": "neeficiență",
    "neeficiențelor": "neeficiență",
    "neegalata": "neegalat",
    "neegalată": "neegalat",
    "neegalate": "neegalat",
    "neegalatei": "neegalat",
    "neegalatele": "neegalat",
    "neegalatelor": "neegalat",
    "neegalați": "neegalat",
    "neegalații": "neegalat",
    "neegalaților": "neegalat",
    "neegalatul": "neegalat",
    "neegalatului": "neegalat",
    "neegalizată": "neegalizat",
    "neegalizate": "neegalizat",
    "neegalizați": "neegalizat",
    "neegrenată": "neegrenat",
    "neegrenate": "neegrenat",
    "neegrenați": "neegrenat",
    "neegumenită": "neegumenit",
    "neegumenite": "neegumenit",
    "neegumeniți": "neegumenit",
    "neelaborată": "neelaborat",
    "neelaborate": "neelaborat",
    "neelaborați": "neelaborat",
    "neelectrificată": "neelectrificat",
    "neelectrificate": "neelectrificat",
    "neelectrificați": "neelectrificat",
    "neelectrizata": "neelectrizat",
    "neelectrizată": "neelectrizat",
    "neelectrizate": "neelectrizat",
    "neelectrizatei": "neelectrizat",
    "neelectrizatele": "neelectrizat",
    "neelectrizatelor": "neelectrizat",
    "neelectrizați": "neelectrizat",
    "neelectrizații": "neelectrizat",
    "neelectrizaților": "neelectrizat",
    "neelectrizatul": "neelectrizat",
    "neelectrizatului": "neelectrizat",
    "neelectrocutată": "neelectrocutat",
    "neelectrocutate": "neelectrocutat",
    "neelectrocutați": "neelectrocutat",
    "neeliberată": "neeliberat",
    "neeliberate": "neeliberat",
    "neeliberați": "neeliberat",
    "neelidată": "neelidat",
    "neelidate": "neelidat",
    "neelidați": "neelidat",
    "neeliminată": "neeliminat",
    "neeliminate": "neeliminat",
    "neeliminați": "neeliminat",
    "neelogiată": "neelogiat",
    "neelogiate": "neelogiat",
    "neelogiați": "neelogiat",
    "neelucidată": "neelucidat",
    "neelucidate": "neelucidat",
    "neelucidați": "neelucidat",
    "neeludată": "neeludat",
    "neeludate": "neeludat",
    "neeludați": "neeludat",
    "neemailata": "neemailat",
    "neemailată": "neemailat",
    "neemailate": "neemailat",
    "neemailatei": "neemailat",
    "neemailatele": "neemailat",
    "neemailatelor": "neemailat",
    "neemailați": "neemailat",
    "neemailații": "neemailat",
    "neemailaților": "neemailat",
    "neemailatul": "neemailat",
    "neemailatului": "neemailat",
    "neemanată": "neemanat",
    "neemanate": "neemanat",
    "neemanați": "neemanat",
    "neemancipata": "neemancipat",
    "neemancipată": "neemancipat",
    "neemancipate": "neemancipat",
    "neemancipatei": "neemancipat",
    "neemancipatele": "neemancipat",
    "neemancipatelor": "neemancipat",
    "neemancipați": "neemancipat",
    "neemancipații": "neemancipat",
    "neemancipaților": "neemancipat",
    "neemancipatul": "neemancipat",
    "neemancipatului": "neemancipat",
    "neemigrată": "neemigrat",
    "neemigrate": "neemigrat",
    "neemigrați": "neemigrat",
    "neemisă": "neemis",
    "neemise": "neemis",
    "neemiși": "neemis",
    "neemoționata": "neemoționat",
    "neemoționată": "neemoționat",
    "neemoționate": "neemoționat",
    "neemoționatei": "neemoționat",
    "neemoționatele": "neemoționat",
    "neemoționatelor": "neemoționat",
    "neemoționați": "neemoționat",
    "neemoționații": "neemoționat",
    "neemoționaților": "neemoționat",
    "neemoționatul": "neemoționat",
    "neemoționatului": "neemoționat",
    "neemulsionată": "neemulsionat",
    "neemulsionate": "neemulsionat",
    "neemulsionați": "neemulsionat",
    "neenervata": "neenervat",
    "neenervată": "neenervat",
    "neenervate": "neenervat",
    "neenervatei": "neenervat",
    "neenervatele": "neenervat",
    "neenervatelor": "neenervat",
    "neenervați": "neenervat",
    "neenervații": "neenervat",
    "neenervaților": "neenervat",
    "neenervatul": "neenervat",
    "neenervatului": "neenervat",
    "neentuziasmata": "neentuziasmat",
    "neentuziasmată": "neentuziasmat",
    "neentuziasmate": "neentuziasmat",
    "neentuziasmatei": "neentuziasmat",
    "neentuziasmatele": "neentuziasmat",
    "neentuziasmatelor": "neentuziasmat",
    "neentuziasmați": "neentuziasmat",
    "neentuziasmații": "neentuziasmat",
    "neentuziasmaților": "neentuziasmat",
    "neentuziasmatul": "neentuziasmat",
    "neentuziasmatului": "neentuziasmat",
    "neenumerată": "neenumerat",
    "neenumerate": "neenumerat",
    "neenumerați": "neenumerat",
    "neenunțată": "neenunțat",
    "neenunțate": "neenunțat",
    "neenunțați": "neenunțat",
    "neepatată": "neepatat",
    "neepatate": "neepatat",
    "neepatați": "neepatat",
    "neepilogată": "neepilogat",
    "neepilogate": "neepilogat",
    "neepilogați": "neepilogat",
    "neepuizata": "neepuizat",
    "neepuizată": "neepuizat",
    "neepuizate": "neepuizat",
    "neepuizatei": "neepuizat",
    "neepuizatele": "neepuizat",
    "neepuizatelor": "neepuizat",
    "neepuizați": "neepuizat",
    "neepuizații": "neepuizat",
    "neepuizaților": "neepuizat",
    "neepuizatul": "neepuizat",
    "neepuizatului": "neepuizat",
    "neepurată": "neepurat",
    "neepurate": "neepurat",
    "neepurați": "neepurat",
    "neeradicata": "neeradicat",
    "neeradicată": "neeradicat",
    "neeradicate": "neeradicat",
    "neeradicatei": "neeradicat",
    "neeradicatele": "neeradicat",
    "neeradicatelor": "neeradicat",
    "neeradicați": "neeradicat",
    "neeradicații": "neeradicat",
    "neeradicaților": "neeradicat",
    "neeradicatul": "neeradicat",
    "neeradicatului": "neeradicat",
    "neerijată": "neerijat",
    "neerijate": "neerijat",
    "neerijați": "neerijat",
    "neeruptă": "neerupt",
    "neerupte": "neerupt",
    "neerupți": "neerupt",
    "neeșalonată": "neeșalonat",
    "neeșalonate": "neeșalonat",
    "neeșalonați": "neeșalonat",
    "neescaladată": "neescaladat",
    "neescaladate": "neescaladat",
    "neescaladați": "neescaladat",
    "neescamotată": "neescamotat",
    "neescamotate": "neescamotat",
    "neescamotați": "neescamotat",
    "neeschivată": "neeschivat",
    "neeschivate": "neeschivat",
    "neeschivați": "neeschivat",
    "neescortată": "neescortat",
    "neescortate": "neescortat",
    "neescortați": "neescortat",
    "neescrocată": "neescrocat",
    "neescrocate": "neescrocat",
    "neescrocați": "neescrocat",
    "neesențiala": "neesențial",
    "neesențială": "neesențial",
    "neesențiale": "neesențial",
    "neesențialei": "neesențial",
    "neesențialele": "neesențial",
    "neesențialelor": "neesențial",
    "neesențiali": "neesențial",
    "neesențialii": "neesențial",
    "neesențialilor": "neesențial",
    "neesențialul": "neesențial",
    "neesențialului": "neesențial",
    "neestimată": "neestimat",
    "neestimate": "neestimat",
    "neestimați": "neestimat",
    "neestompata": "neestompat",
    "neestompată": "neestompat",
    "neestompate": "neestompat",
    "neestompatei": "neestompat",
    "neestompatele": "neestompat",
    "neestompatelor": "neestompat",
    "neestompați": "neestompat",
    "neestompații": "neestompat",
    "neestompaților": "neestompat",
    "neestompatul": "neestompat",
    "neestompatului": "neestompat",
    "neestorcată": "neestorcat",
    "neestorcate": "neestorcat",
    "neestorcați": "neestorcat",
    "neeșuată": "neeșuat",
    "neeșuate": "neeșuat",
    "neeșuați": "neeșuat",
    "neetajată": "neetajat",
    "neetajate": "neetajat",
    "neetajați": "neetajat",
    "neetalată": "neetalat",
    "neetalate": "neetalat",
    "neetalați": "neetalat",
    "neetalonată": "neetalonat",
    "neetalonate": "neetalonat",
    "neetalonați": "neetalonat",
    "neetanșată": "neetanșat",
    "neetanșate": "neetanșat",
    "neetanșați": "neetanșat",
    "neetatizată": "neetatizat",
    "neetatizate": "neetatizat",
    "neetatizați": "neetatizat",
    "neeternizată": "neeternizat",
    "neeternizate": "neeternizat",
    "neeternizați": "neeternizat",
    "neetichetata": "neetichetat",
    "neetichetată": "neetichetat",
    "neetichetate": "neetichetat",
    "neetichetatei": "neetichetat",
    "neetichetatele": "neetichetat",
    "neetichetatelor": "neetichetat",
    "neetichetați": "neetichetat",
    "neetichetații": "neetichetat",
    "neetichetaților": "neetichetat",
    "neetichetatul": "neetichetat",
    "neetichetatului": "neetichetat",
    "neeuclidiana": "neeuclidian",
    "neeuclidiană": "neeuclidian",
    "neeuclidianul": "neeuclidian",
    "neeuclidianului": "neeuclidian",
    "neeuclidiene": "neeuclidian",
    "neeuclidienei": "neeuclidian",
    "neeuclidienele": "neeuclidian",
    "neeuclidienelor": "neeuclidian",
    "neeuclidieni": "neeuclidian",
    "neeuclidienii": "neeuclidian",
    "neeuclidienilor": "neeuclidian",
    "neevacuată": "neevacuat",
    "neevacuate": "neevacuat",
    "neevacuați": "neevacuat",
    "neevadata": "neevadat",
    "neevadată": "neevadat",
    "neevadate": "neevadat",
    "neevadatei": "neevadat",
    "neevadatele": "neevadat",
    "neevadatelor": "neevadat",
    "neevadați": "neevadat",
    "neevadații": "neevadat",
    "neevadaților": "neevadat",
    "neevadatul": "neevadat",
    "neevadatului": "neevadat",
    "neevaluată": "neevaluat",
    "neevaluate": "neevaluat",
    "neevaluați": "neevaluat",
    "neevanghelizată": "neevanghelizat",
    "neevanghelizate": "neevanghelizat",
    "neevanghelizați": "neevanghelizat",
    "neevaporată": "neevaporat",
    "neevaporate": "neevaporat",
    "neevaporați": "neevaporat",
    "neevidențiata": "neevidențiat",
    "neevidențiată": "neevidențiat",
    "neevidențiate": "neevidențiat",
    "neevidențiatei": "neevidențiat",
    "neevidențiatele": "neevidențiat",
    "neevidențiatelor": "neevidențiat",
    "neevidențiați": "neevidențiat",
    "neevidențiații": "neevidențiat",
    "neevidențiaților": "neevidențiat",
    "neevidențiatul": "neevidențiat",
    "neevidențiatului": "neevidențiat",
    "neevidențierea": "neevidențiere",
    "neevidențieri": "neevidențiere",
    "neevidențierii": "neevidențiere",
    "neevidențierile": "neevidențiere",
    "neevidențierilor": "neevidențiere",
    "neevitata": "neevitat",
    "neevitată": "neevitat",
    "neevitate": "neevitat",
    "neevitatei": "neevitat",
    "neevitatele": "neevitat",
    "neevitatelor": "neevitat",
    "neevitați": "neevitat",
    "neevitații": "neevitat",
    "neevitaților": "neevitat",
    "neevitatul": "neevitat",
    "neevitatului": "neevitat",
    "neevocată": "neevocat",
    "neevocate": "neevocat",
    "neevocați": "neevocat",
    "neevoluata": "neevoluat",
    "neevoluată": "neevoluat",
    "neevoluate": "neevoluat",
    "neevoluatei": "neevoluat",
    "neevoluatele": "neevoluat",
    "neevoluatelor": "neevoluat",
    "neevoluați": "neevoluat",
    "neevoluații": "neevoluat",
    "neevoluaților": "neevoluat",
    "neevoluatul": "neevoluat",
    "neevoluatului": "neevoluat",
    "neexacerbata": "neexacerbat",
    "neexacerbată": "neexacerbat",
    "neexacerbate": "neexacerbat",
    "neexacerbatei": "neexacerbat",
    "neexacerbatele": "neexacerbat",
    "neexacerbatelor": "neexacerbat",
    "neexacerbați": "neexacerbat",
    "neexacerbații": "neexacerbat",
    "neexacerbaților": "neexacerbat",
    "neexacerbatul": "neexacerbat",
    "neexacerbatului": "neexacerbat",
    "neexagerata": "neexagerat",
    "neexagerată": "neexagerat",
    "neexagerate": "neexagerat",
    "neexageratei": "neexagerat",
    "neexageratele": "neexagerat",
    "neexageratelor": "neexagerat",
    "neexagerați": "neexagerat",
    "neexagerații": "neexagerat",
    "neexageraților": "neexagerat",
    "neexageratul": "neexagerat",
    "neexageratului": "neexagerat",
    "neexalată": "neexalat",
    "neexalate": "neexalat",
    "neexalați": "neexalat",
    "neexaltata": "neexaltat",
    "neexaltată": "neexaltat",
    "neexaltate": "neexaltat",
    "neexaltatei": "neexaltat",
    "neexaltatele": "neexaltat",
    "neexaltatelor": "neexaltat",
    "neexaltați": "neexaltat",
    "neexaltații": "neexaltat",
    "neexaltaților": "neexaltat",
    "neexaltatul": "neexaltat",
    "neexaltatului": "neexaltat",
    "neexaminată": "neexaminat",
    "neexaminate": "neexaminat",
    "neexaminați": "neexaminat",
    "neexasperata": "neexasperat",
    "neexasperată": "neexasperat",
    "neexasperate": "neexasperat",
    "neexasperatei": "neexasperat",
    "neexasperatele": "neexasperat",
    "neexasperatelor": "neexasperat",
    "neexasperați": "neexasperat",
    "neexasperații": "neexasperat",
    "neexasperaților": "neexasperat",
    "neexasperatul": "neexasperat",
    "neexasperatului": "neexasperat",
    "neexcavată": "neexcavat",
    "neexcavate": "neexcavat",
    "neexcavați": "neexcavat",
    "neexcelată": "neexcelat",
    "neexcelate": "neexcelat",
    "neexcelați": "neexcelat",
    "neexceptată": "neexceptat",
    "neexceptate": "neexceptat",
    "neexceptați": "neexceptat",
    "neexcitata": "neexcitat",
    "neexcitată": "neexcitat",
    "neexcitate": "neexcitat",
    "neexcitatei": "neexcitat",
    "neexcitatele": "neexcitat",
    "neexcitatelor": "neexcitat",
    "neexcitați": "neexcitat",
    "neexcitații": "neexcitat",
    "neexcitaților": "neexcitat",
    "neexcitatul": "neexcitat",
    "neexcitatului": "neexcitat",
    "neexclamată": "neexclamat",
    "neexclamate": "neexclamat",
    "neexclamați": "neexclamat",
    "neexclusa": "neexclus",
    "neexclusă": "neexclus",
    "neexcluse": "neexclus",
    "neexclusei": "neexclus",
    "neexclusele": "neexclus",
    "neexcluselor": "neexclus",
    "neexcluși": "neexclus",
    "neexclușii": "neexclus",
    "neexclușilor": "neexclus",
    "neexclusul": "neexclus",
    "neexclusului": "neexclus",
    "neexcomunicată": "neexcomunicat",
    "neexcomunicate": "neexcomunicat",
    "neexcomunicați": "neexcomunicat",
    "neexcretată": "neexcretat",
    "neexcretate": "neexcretat",
    "neexcretați": "neexcretat",
    "neexecutată": "neexecutat",
    "neexecutate": "neexecutat",
    "neexecutați": "neexecutat",
    "neexemplificată": "neexemplificat",
    "neexemplificate": "neexemplificat",
    "neexemplificați": "neexemplificat",
    "neexercitată": "neexercitat",
    "neexercitate": "neexercitat",
    "neexercitați": "neexercitat",
    "neexersarea": "neexersare",
    "neexersari": "neexersare",
    "neexersarii": "neexersare",
    "neexersarile": "neexersare",
    "neexersarilor": "neexersare",
    "neexersată": "neexersat",
    "neexersate": "neexersat",
    "neexersați": "neexersat",
    "neexhibată": "neexhibat",
    "neexhibate": "neexhibat",
    "neexhibați": "neexhibat",
    "neexhumată": "neexhumat",
    "neexhumate": "neexhumat",
    "neexhumați": "neexhumat",
    "neexilata": "neexilat",
    "neexilată": "neexilat",
    "neexilate": "neexilat",
    "neexilatei": "neexilat",
    "neexilatele": "neexilat",
    "neexilatelor": "neexilat",
    "neexilați": "neexilat",
    "neexilații": "neexilat",
    "neexilaților": "neexilat",
    "neexilatul": "neexilat",
    "neexilatului": "neexilat",
    "neexistată": "neexistat",
    "neexistate": "neexistat",
    "neexistați": "neexistat",
    "neexmatriculată": "neexmatriculat",
    "neexmatriculate": "neexmatriculat",
    "neexmatriculați": "neexmatriculat",
    "neexonerată": "neexonerat",
    "neexonerate": "neexonerat",
    "neexonerați": "neexonerat",
    "neexpatriata": "neexpatriat",
    "neexpatriată": "neexpatriat",
    "neexpatriate": "neexpatriat",
    "neexpatriatei": "neexpatriat",
    "neexpatriatele": "neexpatriat",
    "neexpatriatelor": "neexpatriat",
    "neexpatriați": "neexpatriat",
    "neexpatriații": "neexpatriat",
    "neexpatriaților": "neexpatriat",
    "neexpatriatul": "neexpatriat",
    "neexpatriatului": "neexpatriat",
    "neexpectorată": "neexpectorat",
    "neexpectorate": "neexpectorat",
    "neexpectorați": "neexpectorat",
    "neexpediată": "neexpediat",
    "neexpediate": "neexpediat",
    "neexpediați": "neexpediat",
    "neexperimentata": "neexperimentat",
    "neexperimentată": "neexperimentat",
    "neexperimentate": "neexperimentat",
    "neexperimentatei": "neexperimentat",
    "neexperimentatele": "neexperimentat",
    "neexperimentatelor": "neexperimentat",
    "neexperimentați": "neexperimentat",
    "neexperimentații": "neexperimentat",
    "neexperimentaților": "neexperimentat",
    "neexperimentatul": "neexperimentat",
    "neexperimentatului": "neexperimentat",
    "neexpertizată": "neexpertizat",
    "neexpertizate": "neexpertizat",
    "neexpertizați": "neexpertizat",
    "neexpirată": "neexpirat",
    "neexpirate": "neexpirat",
    "neexpirați": "neexpirat",
    "neexplicată": "neexplicat",
    "neexplicate": "neexplicat",
    "neexplicați": "neexplicat",
    "neexploatata": "neexploatat",
    "neexploatată": "neexploatat",
    "neexploatate": "neexploatat",
    "neexploatatei": "neexploatat",
    "neexploatatele": "neexploatat",
    "neexploatatelor": "neexploatat",
    "neexploatați": "neexploatat",
    "neexploatații": "neexploatat",
    "neexploataților": "neexploatat",
    "neexploatatul": "neexploatat",
    "neexploatatului": "neexploatat",
    "neexplodată": "neexplodat",
    "neexplodate": "neexplodat",
    "neexplodați": "neexplodat",
    "neexplorata": "neexplorat",
    "neexplorată": "neexplorat",
    "neexplorate": "neexplorat",
    "neexploratei": "neexplorat",
    "neexploratele": "neexplorat",
    "neexploratelor": "neexplorat",
    "neexplorați": "neexplorat",
    "neexplorații": "neexplorat",
    "neexploraților": "neexplorat",
    "neexploratul": "neexplorat",
    "neexploratului": "neexplorat",
    "neexportată": "neexportat",
    "neexportate": "neexportat",
    "neexportați": "neexportat",
    "neexprimata": "neexprimat",
    "neexprimată": "neexprimat",
    "neexprimate": "neexprimat",
    "neexprimatei": "neexprimat",
    "neexprimatele": "neexprimat",
    "neexprimatelor": "neexprimat",
    "neexprimați": "neexprimat",
    "neexprimații": "neexprimat",
    "neexprimaților": "neexprimat",
    "neexprimatul": "neexprimat",
    "neexprimatului": "neexprimat",
    "neexpropriata": "neexpropriat",
    "neexpropriată": "neexpropriat",
    "neexpropriate": "neexpropriat",
    "neexpropriatei": "neexpropriat",
    "neexpropriatele": "neexpropriat",
    "neexpropriatelor": "neexpropriat",
    "neexpropriați": "neexpropriat",
    "neexpropriații": "neexpropriat",
    "neexpropriaților": "neexpropriat",
    "neexpropriatul": "neexpropriat",
    "neexpropriatului": "neexpropriat",
    "neexpulzată": "neexpulzat",
    "neexpulzate": "neexpulzat",
    "neexpulzați": "neexpulzat",
    "neexpusă": "neexpus",
    "neexpuse": "neexpus",
    "neexpuși": "neexpus",
    "neextaziata": "neextaziat",
    "neextaziată": "neextaziat",
    "neextaziate": "neextaziat",
    "neextaziatei": "neextaziat",
    "neextaziatele": "neextaziat",
    "neextaziatelor": "neextaziat",
    "neextaziați": "neextaziat",
    "neextaziații": "neextaziat",
    "neextaziaților": "neextaziat",
    "neextaziatul": "neextaziat",
    "neextaziatului": "neextaziat",
    "neextenuata": "neextenuat",
    "neextenuată": "neextenuat",
    "neextenuate": "neextenuat",
    "neextenuatei": "neextenuat",
    "neextenuatele": "neextenuat",
    "neextenuatelor": "neextenuat",
    "neextenuați": "neextenuat",
    "neextenuații": "neextenuat",
    "neextenuaților": "neextenuat",
    "neextenuatul": "neextenuat",
    "neextenuatului": "neextenuat",
    "neexteriorizată": "neexteriorizat",
    "neexteriorizate": "neexteriorizat",
    "neexteriorizați": "neexteriorizat",
    "neexterminata": "neexterminat",
    "neexterminată": "neexterminat",
    "neexterminate": "neexterminat",
    "neexterminatei": "neexterminat",
    "neexterminatele": "neexterminat",
    "neexterminatelor": "neexterminat",
    "neexterminați": "neexterminat",
    "neexterminații": "neexterminat",
    "neexterminaților": "neexterminat",
    "neexterminatul": "neexterminat",
    "neexterminatului": "neexterminat",
    "neextinsă": "neextins",
    "neextinse": "neextins",
    "neextinși": "neextins",
    "neextirpată": "neextirpat",
    "neextirpate": "neextirpat",
    "neextirpați": "neextirpat",
    "neextorcată": "neextorcat",
    "neextorcate": "neextorcat",
    "neextorcați": "neextorcat",
    "neextrădată": "neextrădat",
    "neextrădate": "neextrădat",
    "neextrădați": "neextrădat",
    "neextrasă": "neextras",
    "neextrase": "neextras",
    "neextrași": "neextras",
    "neexultată": "neexultat",
    "neexultate": "neexultat",
    "neexultați": "neexultat",
    "neezitată": "neezitat",
    "neezitate": "neezitat",
    "neezitați": "neezitat",
    "nefabricată": "nefabricat",
    "nefabricate": "nefabricat",
    "nefabricați": "nefabricat",
    "nefăcăluită": "nefăcăluit",
    "nefăcăluite": "nefăcăluit",
    "nefăcăluiți": "nefăcăluit",
    "nefacilitată": "nefacilitat",
    "nefacilitate": "nefacilitat",
    "nefacilitați": "nefacilitat",
    "nefacturată": "nefacturat",
    "nefacturate": "nefacturat",
    "nefacturați": "nefacturat",
    "nefăcuta": "nefăcut",
    "nefăcută": "nefăcut",
    "nefăcute": "nefăcut",
    "nefăcutei": "nefăcut",
    "nefăcutele": "nefăcut",
    "nefăcutelor": "nefăcut",
    "nefăcuți": "nefăcut",
    "nefăcuții": "nefăcut",
    "nefăcuților": "nefăcut",
    "nefăcutul": "nefăcut",
    "nefăcutului": "nefăcut",
    "nefăgăduită": "nefăgăduit",
    "nefăgăduite": "nefăgăduit",
    "nefăgăduiți": "nefăgăduit",
    "nefaianțată": "nefaianțat",
    "nefaianțate": "nefaianțat",
    "nefaianțați": "nefaianțat",
    "nefălălăită": "nefălălăit",
    "nefălălăite": "nefălălăit",
    "nefălălăiți": "nefălălăit",
    "nefâlfâită": "nefâlfâit",
    "nefâlfâite": "nefâlfâit",
    "nefâlfâiți": "nefâlfâit",
    "nefaliată": "nefaliat",
    "nefaliate": "nefaliat",
    "nefaliați": "nefaliat",
    "nefălită": "nefălit",
    "nefălite": "nefălit",
    "nefăliți": "nefălit",
    "nefăloșită": "nefăloșit",
    "nefăloșite": "nefăloșit",
    "nefăloșiți": "nefăloșit",
    "nefalsificată": "nefalsificat",
    "nefalsificate": "nefalsificat",
    "nefalsificați": "nefalsificat",
    "nefălțuită": "nefălțuit",
    "nefălțuite": "nefălțuit",
    "nefălțuiți": "nefălțuit",
    "nefamiliarizata": "nefamiliarizat",
    "nefamiliarizată": "nefamiliarizat",
    "nefamiliarizate": "nefamiliarizat",
    "nefamiliarizatei": "nefamiliarizat",
    "nefamiliarizatele": "nefamiliarizat",
    "nefamiliarizatelor": "nefamiliarizat",
    "nefamiliarizați": "nefamiliarizat",
    "nefamiliarizații": "nefamiliarizat",
    "nefamiliarizaților": "nefamiliarizat",
    "nefamiliarizatul": "nefamiliarizat",
    "nefamiliarizatului": "nefamiliarizat",
    "nefanariotizată": "nefanariotizat",
    "nefanariotizate": "nefanariotizat",
    "nefanariotizați": "nefanariotizat",
    "nefanată": "nefanat",
    "nefanate": "nefanat",
    "nefanați": "nefanat",
    "nefandată": "nefandat",
    "nefandate": "nefandat",
    "nefandați": "nefandat",
    "nefandosită": "nefandosit",
    "nefandosite": "nefandosit",
    "nefandosiți": "nefandosit",
    "nefăptuită": "nefăptuit",
    "nefăptuite": "nefăptuit",
    "nefăptuiți": "nefăptuit",
    "nefărâmată": "nefărâmat",
    "nefărâmate": "nefărâmat",
    "nefărâmați": "nefărâmat",
    "nefărâmițată": "nefărâmițat",
    "nefărâmițate": "nefărâmițat",
    "nefărâmițați": "nefărâmițat",
    "nefardată": "nefardat",
    "nefardate": "nefardat",
    "nefardați": "nefardat",
    "nefârnâită": "nefârnâit",
    "nefârnâite": "nefârnâit",
    "nefârnâiți": "nefârnâit",
    "nefâsâită": "nefâsâit",
    "nefâsâite": "nefâsâit",
    "nefâsâiți": "nefâsâit",
    "nefâșâită": "nefâșâit",
    "nefâșâite": "nefâșâit",
    "nefâșâiți": "nefâșâit",
    "nefascinată": "nefascinat",
    "nefascinate": "nefascinat",
    "nefascinați": "nefascinat",
    "nefascizată": "nefascizat",
    "nefascizate": "nefascizat",
    "nefascizați": "nefascizat",
    "nefasolită": "nefasolit",
    "nefasolite": "nefasolit",
    "nefasoliți": "nefasolit",
    "nefasonată": "nefasonat",
    "nefasonate": "nefasonat",
    "nefasonați": "nefasonat",
    "nefasta": "nefast",
    "nefastă": "nefast",
    "nefaste": "nefast",
    "nefastei": "nefast",
    "nefastele": "nefast",
    "nefastelor": "nefast",
    "nefaști": "nefast",
    "nefaștii": "nefast",
    "nefaștilor": "nefast",
    "nefastul": "nefast",
    "nefastului": "nefast",
    "nefâstâcită": "nefâstâcit",
    "nefâstâcite": "nefâstâcit",
    "nefâstâciți": "nefâstâcit",
    "nefâțâită": "nefâțâit",
    "nefâțâite": "nefâțâit",
    "nefâțâiți": "nefâțâit",
    "nefățărită": "nefățărit",
    "nefățărite": "nefățărit",
    "nefățăriți": "nefățărit",
    "nefățărnicită": "nefățărnicit",
    "nefățărnicite": "nefățărnicit",
    "nefățărniciți": "nefățărnicit",
    "nefătată": "nefătat",
    "nefătate": "nefătat",
    "nefătați": "nefătat",
    "nefățuită": "nefățuit",
    "nefățuite": "nefățuit",
    "nefățuiți": "nefățuit",
    "nefaultată": "nefaultat",
    "nefaultate": "nefaultat",
    "nefaultați": "nefaultat",
    "nefăurită": "nefăurit",
    "nefăurite": "nefăurit",
    "nefăuriți": "nefăurit",
    "nefavorabila": "nefavorabil",
    "nefavorabilă": "nefavorabil",
    "nefavorabile": "nefavorabil",
    "nefavorabilei": "nefavorabil",
    "nefavorabilele": "nefavorabil",
    "nefavorabilelor": "nefavorabil",
    "nefavorabili": "nefavorabil",
    "nefavorabilii": "nefavorabil",
    "nefavorabililor": "nefavorabil",
    "nefavorabilul": "nefavorabil",
    "nefavorabilului": "nefavorabil",
    "nefavorizată": "nefavorizat",
    "nefavorizate": "nefavorizat",
    "nefavorizați": "nefavorizat",
    "nefebricitată": "nefebricitat",
    "nefebricitate": "nefebricitat",
    "nefebricitați": "nefebricitat",
    "nefecundată": "nefecundat",
    "nefecundate": "nefecundat",
    "nefecundați": "nefecundat",
    "nefederalizată": "nefederalizat",
    "nefederalizate": "nefederalizat",
    "nefederalizați": "nefederalizat",
    "nefelicitată": "nefelicitat",
    "nefelicitate": "nefelicitat",
    "nefelicitați": "nefelicitat",
    "nefelurita": "nefelurit",
    "nefelurită": "nefelurit",
    "nefelurite": "nefelurit",
    "nefeluritei": "nefelurit",
    "nefeluritele": "nefelurit",
    "nefeluritelor": "nefelurit",
    "nefeluriți": "nefelurit",
    "nefeluriții": "nefelurit",
    "nefeluriților": "nefelurit",
    "nefeluritul": "nefelurit",
    "nefeluritului": "nefelurit",
    "nefeminizată": "nefeminizat",
    "nefeminizate": "nefeminizat",
    "nefeminizați": "nefeminizat",
    "neferchezuită": "neferchezuit",
    "neferchezuite": "neferchezuit",
    "neferchezuiți": "neferchezuit",
    "neferecată": "neferecat",
    "neferecate": "neferecat",
    "neferecați": "neferecat",
    "nefereduită": "nefereduit",
    "nefereduite": "nefereduit",
    "nefereduiți": "nefereduit",
    "neferestruită": "neferestruit",
    "neferestruite": "neferestruit",
    "neferestruiți": "neferestruit",
    "neferfenițită": "neferfenițit",
    "neferfenițite": "neferfenițit",
    "neferfenițiți": "neferfenițit",
    "nefericirea": "nefericire",
    "nefericiri": "nefericire",
    "nefericirii": "nefericire",
    "nefericirile": "nefericire",
    "nefericirilor": "nefericire",
    "nefericita": "nefericit",
    "nefericită": "nefericit",
    "nefericite": "nefericit",
    "nefericitei": "nefericit",
    "nefericitele": "nefericit",
    "nefericitelor": "nefericit",
    "nefericiți": "nefericit",
    "nefericiții": "nefericit",
    "nefericiților": "nefericit",
    "nefericitul": "nefericit",
    "nefericitule": "nefericit",
    "nefericitului": "nefericit",
    "neferita": "neferit",
    "neferită": "neferit",
    "neferite": "neferit",
    "neferitei": "neferit",
    "neferitele": "neferit",
    "neferitelor": "neferit",
    "neferiți": "neferit",
    "neferiții": "neferit",
    "neferiților": "neferit",
    "neferitul": "neferit",
    "neferitului": "neferit",
    "nefermecata": "nefermecat",
    "nefermecată": "nefermecat",
    "nefermecate": "nefermecat",
    "nefermecatei": "nefermecat",
    "nefermecatele": "nefermecat",
    "nefermecatelor": "nefermecat",
    "nefermecați": "nefermecat",
    "nefermecații": "nefermecat",
    "nefermecaților": "nefermecat",
    "nefermecatul": "nefermecat",
    "nefermecatului": "nefermecat",
    "nefermentată": "nefermentat",
    "nefermentate": "nefermentat",
    "nefermentați": "nefermentat",
    "nefer.": "neferoase",
    "neferoasa": "neferos",
    "neferoasă": "neferos",
    "neferoase": "neferos",
    "neferoasei": "neferos",
    "neferoasele": "neferos",
    "neferoaselor": "neferos",
    "neferoși": "neferos",
    "neferoșii": "neferos",
    "neferoșilor": "neferos",
    "neferosul": "neferos",
    "neferosului": "neferos",
    "nefertilizată": "nefertilizat",
    "nefertilizate": "nefertilizat",
    "nefertilizați": "nefertilizat",
    "nefeștelită": "nefeștelit",
    "nefeștelite": "nefeștelit",
    "nefeșteliți": "nefeștelit",
    "nefestonată": "nefestonat",
    "nefestonate": "nefestonat",
    "nefestonați": "nefestonat",
    "nefetișizată": "nefetișizat",
    "nefetișizate": "nefetișizat",
    "nefetișizați": "nefetișizat",
    "nefetită": "nefetit",
    "nefetite": "nefetit",
    "nefetiți": "nefetit",
    "nefezandată": "nefezandat",
    "nefezandate": "nefezandat",
    "nefezandați": "nefezandat",
    "nefiarta": "nefiert",
    "nefiartă": "nefiert",
    "nefiertă": "nefiert",
    "nefierte": "nefiert",
    "nefiertei": "nefiert",
    "nefiertele": "nefiert",
    "nefiertelor": "nefiert",
    "nefierți": "nefiert",
    "nefierții": "nefiert",
    "nefierților": "nefiert",
    "nefiertul": "nefiert",
    "nefiertului": "nefiert",
    "nefigurata": "nefigurat",
    "nefigurată": "nefigurat",
    "nefigurate": "nefigurat",
    "nefiguratei": "nefigurat",
    "nefiguratele": "nefigurat",
    "nefiguratelor": "nefigurat",
    "nefigurați": "nefigurat",
    "nefigurații": "nefigurat",
    "nefiguraților": "nefigurat",
    "nefiguratul": "nefigurat",
    "nefiguratului": "nefigurat",
    "neființa": "neființă",
    "neființe": "neființă",
    "neființei": "neființă",
    "neființele": "neființă",
    "neființelor": "neființă",
    "neființată": "neființat",
    "neființate": "neființat",
    "neființați": "neființat",
    "nefilată": "nefilat",
    "nefilate": "nefilat",
    "nefilați": "nefilat",
    "nefiletată": "nefiletat",
    "nefiletate": "nefiletat",
    "nefiletați": "nefiletat",
    "nefiligranată": "nefiligranat",
    "nefiligranate": "nefiligranat",
    "nefiligranați": "nefiligranat",
    "nefilmată": "nefilmat",
    "nefilmate": "nefilmat",
    "nefilmați": "nefilmat",
    "nefilosofica": "nefilosofic",
    "nefilosofică": "nefilosofic",
    "nefilosofice": "nefilosofic",
    "nefilosoficei": "nefilosofic",
    "nefilosoficele": "nefilosofic",
    "nefilosoficelor": "nefilosofic",
    "nefilosofici": "nefilosofic",
    "nefilosoficii": "nefilosofic",
    "nefilosoficilor": "nefilosofic",
    "nefilosoficul": "nefilosofic",
    "nefilosoficului": "nefilosofic",
    "nefilozofată": "nefilozofat",
    "nefilozofate": "nefilozofat",
    "nefilozofați": "nefilozofat",
    "nefiltrată": "nefiltrat",
    "nefiltrate": "nefiltrat",
    "nefiltrați": "nefiltrat",
    "nefinalizată": "nefinalizat",
    "nefinalizate": "nefinalizat",
    "nefinalizați": "nefinalizat",
    "nefinanțată": "nefinanțat",
    "nefinanțate": "nefinanțat",
    "nefinanțați": "nefinanțat",
    "nefinisată": "nefinisat",
    "nefinisate": "nefinisat",
    "nefinisați": "nefinisat",
    "nefinita": "nefinit",
    "nefinită": "nefinit",
    "nefinite": "nefinit",
    "nefinitei": "nefinit",
    "nefinitele": "nefinit",
    "nefinitelor": "nefinit",
    "nefiniți": "nefinit",
    "nefiniții": "nefinit",
    "nefiniților": "nefinit",
    "nefinitul": "nefinit",
    "nefinitului": "nefinit",
    "nefireasca": "nefiresc",
    "nefirească": "nefiresc",
    "nefirescul": "nefiresc",
    "nefirescului": "nefiresc",
    "nefirești": "nefiresc",
    "nefireștii": "nefiresc",
    "nefireștile": "nefiresc",
    "nefireștilor": "nefiresc",
    "nefișată": "nefișat",
    "nefișate": "nefișat",
    "nefișați": "nefișat",
    "nefisionată": "nefisionat",
    "nefisionate": "nefisionat",
    "nefisionați": "nefisionat",
    "nefisurată": "nefisurat",
    "nefisurate": "nefisurat",
    "nefisurați": "nefisurat",
    "nefituită": "nefituit",
    "nefituite": "nefituit",
    "nefituiți": "nefituit",
    "nefixată": "nefixat",
    "nefixate": "nefixat",
    "nefixați": "nefixat",
    "nefla": "neflă",
    "nefle": "neflă",
    "neflei": "neflă",
    "neflele": "neflă",
    "neflelor": "neflă",
    "neflăcăită": "neflăcăit",
    "neflăcăite": "neflăcăit",
    "neflăcăiți": "neflăcăit",
    "neflagelată": "neflagelat",
    "neflagelate": "neflagelat",
    "neflagelați": "neflagelat",
    "neflămânzită": "neflămânzit",
    "neflămânzite": "neflămânzit",
    "neflămânziți": "neflămânzit",
    "neflambată": "neflambat",
    "neflambate": "neflambat",
    "neflambați": "neflambat",
    "neflanată": "neflanat",
    "neflanate": "neflanat",
    "neflanați": "neflanat",
    "neflancată": "neflancat",
    "neflancate": "neflancat",
    "neflancați": "neflancat",
    "neflatată": "neflatat",
    "neflatate": "neflatat",
    "neflatați": "neflatat",
    "neflecărită": "neflecărit",
    "neflecărite": "neflecărit",
    "neflecăriți": "neflecărit",
    "neflecuită": "neflecuit",
    "neflecuite": "neflecuit",
    "neflecuiți": "neflecuit",
    "neflencănită": "neflencănit",
    "neflencănite": "neflencănit",
    "neflencăniți": "neflencănit",
    "nefleșcăita": "nefleșcăit",
    "nefleșcăită": "nefleșcăit",
    "nefleșcăite": "nefleșcăit",
    "nefleșcăitei": "nefleșcăit",
    "nefleșcăitele": "nefleșcăit",
    "nefleșcăitelor": "nefleșcăit",
    "nefleșcăiți": "nefleșcăit",
    "nefleșcăiții": "nefleșcăit",
    "nefleșcăiților": "nefleșcăit",
    "nefleșcăitul": "nefleșcăit",
    "nefleșcăitului": "nefleșcăit",
    "neflexibila": "neflexibil",
    "neflexibilă": "neflexibil",
    "neflexibile": "neflexibil",
    "neflexibilei": "neflexibil",
    "neflexibilele": "neflexibil",
    "neflexibilelor": "neflexibil",
    "neflexibili": "neflexibil",
    "neflexibilii": "neflexibil",
    "neflexibililor": "neflexibil",
    "neflexibilul": "neflexibil",
    "neflexibilului": "neflexibil",
    "neflexionată": "neflexionat",
    "neflexionate": "neflexionat",
    "neflexionați": "neflexionat",
    "neflirtată": "neflirtat",
    "neflirtate": "neflirtat",
    "neflirtați": "neflirtat",
    "neflocăită": "neflocăit",
    "neflocăite": "neflocăit",
    "neflocăiți": "neflocăit",
    "neflotată": "neflotat",
    "neflotate": "neflotat",
    "neflotați": "neflotat",
    "nefluctuată": "nefluctuat",
    "nefluctuate": "nefluctuat",
    "nefluctuați": "nefluctuat",
    "nefluidificată": "nefluidificat",
    "nefluidificate": "nefluidificat",
    "nefluidificați": "nefluidificat",
    "nefluidizată": "nefluidizat",
    "nefluidizate": "nefluidizat",
    "nefluidizați": "nefluidizat",
    "nefluierată": "nefluierat",
    "nefluierate": "nefluierat",
    "nefluierați": "nefluierat",
    "nefluorizată": "nefluorizat",
    "nefluorizate": "nefluorizat",
    "nefluorizați": "nefluorizat",
    "neflușturată": "neflușturat",
    "neflușturate": "neflușturat",
    "neflușturați": "neflușturat",
    "nefluturată": "nefluturat",
    "nefluturate": "nefluturat",
    "nefluturați": "nefluturat",
    "nefocalizată": "nefocalizat",
    "nefocalizate": "nefocalizat",
    "nefocalizați": "nefocalizat",
    "nefofilată": "nefofilat",
    "nefofilate": "nefofilat",
    "nefofilați": "nefofilat",
    "nefoiletată": "nefoiletat",
    "nefoiletate": "nefoiletat",
    "nefoiletați": "nefoiletat",
    "nefoită": "nefoit",
    "nefoite": "nefoit",
    "nefoiți": "nefoit",
    "nefojgăită": "nefojgăit",
    "nefojgăite": "nefojgăit",
    "nefojgăiți": "nefojgăit",
    "nefolfăită": "nefolfăit",
    "nefolfăite": "nefolfăit",
    "nefolfăiți": "nefolfăit",
    "nefolosirea": "nefolosire",
    "nefolosiri": "nefolosire",
    "nefolosirii": "nefolosire",
    "nefolosita": "nefolosit",
    "nefolosită": "nefolosit",
    "nefolosite": "nefolosit",
    "nefolositei": "nefolosit",
    "nefolositele": "nefolosit",
    "nefolositelor": "nefolosit",
    "nefolosiți": "nefolosit",
    "nefolosiții": "nefolosit",
    "nefolosiților": "nefolosit",
    "nefolositul": "nefolosit",
    "nefolositului": "nefolosit",
    "nefolositoare": "nefolositor",
    "nefolositoarea": "nefolositor",
    "nefolositoarei": "nefolositor",
    "nefolositoarele": "nefolositor",
    "nefolositoarelor": "nefolositor",
    "nefolositori": "nefolositor",
    "nefolositorii": "nefolositor",
    "nefolositorilor": "nefolositor",
    "nefolositorul": "nefolositor",
    "nefolositorului": "nefolositor",
    "nefondata": "nefondat",
    "nefondată": "nefondat",
    "nefondate": "nefondat",
    "nefondatei": "nefondat",
    "nefondatele": "nefondat",
    "nefondatelor": "nefondat",
    "nefondați": "nefondat",
    "nefondații": "nefondat",
    "nefondaților": "nefondat",
    "nefondatul": "nefondat",
    "nefondatului": "nefondat",
    "nefonfăită": "nefonfăit",
    "nefonfăite": "nefonfăit",
    "nefonfăiți": "nefonfăit",
    "neforăită": "neforăit",
    "neforăite": "neforăit",
    "neforăiți": "neforăit",
    "neforată": "neforat",
    "neforate": "neforat",
    "neforați": "neforat",
    "neforfăită": "neforfăit",
    "neforfăite": "neforfăit",
    "neforfăiți": "neforfăit",
    "neforfecată": "neforfecat",
    "neforfecate": "neforfecat",
    "neforfecați": "neforfecat",
    "neforfotită": "neforfotit",
    "neforfotite": "neforfotit",
    "neforfotiți": "neforfotit",
    "neforjată": "neforjat",
    "neforjate": "neforjat",
    "neforjați": "neforjat",
    "neformalizată": "neformalizat",
    "neformalizate": "neformalizat",
    "neformalizați": "neformalizat",
    "neformata": "neformat",
    "neformată": "neformat",
    "neformate": "neformat",
    "neformatei": "neformat",
    "neformatele": "neformat",
    "neformatelor": "neformat",
    "neformați": "neformat",
    "neformații": "neformat",
    "neformaților": "neformat",
    "neformatul": "neformat",
    "neformatului": "neformat",
    "neformulata": "neformulat",
    "neformulată": "neformulat",
    "neformulate": "neformulat",
    "neformulatei": "neformulat",
    "neformulatele": "neformulat",
    "neformulatelor": "neformulat",
    "neformulați": "neformulat",
    "neformulații": "neformulat",
    "neformulaților": "neformulat",
    "neformulatul": "neformulat",
    "neformulatului": "neformulat",
    "nefornăită": "nefornăit",
    "nefornăite": "nefornăit",
    "nefornăiți": "nefornăit",
    "neforțata": "neforțat",
    "neforțată": "neforțat",
    "neforțate": "neforțat",
    "neforțatei": "neforțat",
    "neforțatele": "neforțat",
    "neforțatelor": "neforțat",
    "neforțați": "neforțat",
    "neforțații": "neforțat",
    "neforțaților": "neforțat",
    "neforțatul": "neforțat",
    "neforțatului": "neforțat",
    "nefortificată": "nefortificat",
    "nefortificate": "nefortificat",
    "nefortificați": "nefortificat",
    "nefoșăită": "nefoșăit",
    "nefoșăite": "nefoșăit",
    "nefoșăiți": "nefoșăit",
    "nefosfatată": "nefosfatat",
    "nefosfatate": "nefosfatat",
    "nefosfatați": "nefosfatat",
    "nefosilizată": "nefosilizat",
    "nefosilizate": "nefosilizat",
    "nefosilizați": "nefosilizat",
    "nefoșnită": "nefoșnit",
    "nefoșnite": "nefoșnit",
    "nefoșniți": "nefoșnit",
    "nefosta": "nefost",
    "nefostă": "nefost",
    "nefoste": "nefost",
    "nefostei": "nefost",
    "nefostele": "nefost",
    "nefostelor": "nefost",
    "nefoști": "nefost",
    "nefoștii": "nefost",
    "nefoștilor": "nefost",
    "nefostul": "nefost",
    "nefostului": "nefost",
    "nefotografiată": "nefotografiat",
    "nefotografiate": "nefotografiat",
    "nefotografiați": "nefotografiat",
    "nefracționată": "nefracționat",
    "nefracționate": "nefracționat",
    "nefracționați": "nefracționat",
    "nefracturată": "nefracturat",
    "nefracturate": "nefracturat",
    "nefracturați": "nefracturat",
    "nefrăgezită": "nefrăgezit",
    "nefrăgezite": "nefrăgezit",
    "nefrăgeziți": "nefrăgezit",
    "nefragmentată": "nefragmentat",
    "nefragmentate": "nefragmentat",
    "nefragmentați": "nefragmentat",
    "nefraierită": "nefraierit",
    "nefraierite": "nefraierit",
    "nefraieriți": "nefraierit",
    "nefrământată": "nefrământat",
    "nefrământate": "nefrământat",
    "nefrământați": "nefrământat",
    "nefrânată": "nefrânat",
    "nefrânate": "nefrânat",
    "nefrânați": "nefrânat",
    "nefrancată": "nefrancat",
    "nefrancate": "nefrancat",
    "nefrancați": "nefrancat",
    "nefrânta": "nefrânt",
    "nefrântă": "nefrânt",
    "nefrânte": "nefrânt",
    "nefrântei": "nefrânt",
    "nefrântele": "nefrânt",
    "nefrântelor": "nefrânt",
    "nefrânți": "nefrânt",
    "nefrânții": "nefrânt",
    "nefrânților": "nefrânt",
    "nefrântul": "nefrânt",
    "nefrântului": "nefrânt",
    "nefranțuzită": "nefranțuzit",
    "nefranțuzite": "nefranțuzit",
    "nefranțuziți": "nefranțuzit",
    "nefrapată": "nefrapat",
    "nefrapate": "nefrapat",
    "nefrapați": "nefrapat",
    "nefrăsuită": "nefrăsuit",
    "nefrăsuite": "nefrăsuit",
    "nefrăsuiți": "nefrăsuit",
    "nefraternizată": "nefraternizat",
    "nefraternizate": "nefraternizat",
    "nefraternizați": "nefraternizat",
    "nefraudată": "nefraudat",
    "nefraudate": "nefraudat",
    "nefraudați": "nefraudat",
    "nefrazată": "nefrazat",
    "nefrazate": "nefrazat",
    "nefrazați": "nefrazat",
    "nefrecată": "nefrecat",
    "nefrecate": "nefrecat",
    "nefrecați": "nefrecat",
    "nefrectomiea": "nefrectomie",
    "nefrectomii": "nefrectomie",
    "nefrectomiii": "nefrectomie",
    "nefrectomiile": "nefrectomie",
    "nefrectomiilor": "nefrectomie",
    "nefrecventată": "nefrecventat",
    "nefrecventate": "nefrecventat",
    "nefrecventați": "nefrecventat",
    "nefredonată": "nefredonat",
    "nefredonate": "nefredonat",
    "nefredonați": "nefredonat",
    "nefremătată": "nefremătat",
    "nefremătate": "nefremătat",
    "nefremătați": "nefremătat",
    "nefretată": "nefretat",
    "nefretate": "nefretat",
    "nefretați": "nefretat",
    "nefrezată": "nefrezat",
    "nefrezate": "nefrezat",
    "nefrezați": "nefrezat",
    "nefrichinită": "nefrichinit",
    "nefrichinite": "nefrichinit",
    "nefrichiniți": "nefrichinit",
    "nefricționată": "nefricționat",
    "nefricționate": "nefricționat",
    "nefricționați": "nefricționat",
    "nefridiea": "nefridie",
    "nefridii": "nefridie",
    "nefridiii": "nefridie",
    "nefridiile": "nefridie",
    "nefridiilor": "nefridie",
    "nefripta": "nefript",
    "nefriptă": "nefript",
    "nefripte": "nefript",
    "nefriptei": "nefript",
    "nefriptele": "nefript",
    "nefriptelor": "nefript",
    "nefripți": "nefript",
    "nefripții": "nefript",
    "nefripților": "nefript",
    "nefriptul": "nefript",
    "nefriptului": "nefript",
    "nefritul": "nefrit",
    "nefritului": "nefrit",
    "nefrita": "nefrită",
    "nefrite": "nefrită",
    "nefritei": "nefrită",
    "nefritele": "nefrită",
    "nefritelor": "nefrită",
    "nefritica": "nefritic",
    "nefritică": "nefritic",
    "nefritice": "nefritic",
    "nefriticei": "nefritic",
    "nefriticele": "nefritic",
    "nefriticelor": "nefritic",
    "nefritici": "nefritic",
    "nefriticii": "nefritic",
    "nefriticilor": "nefritic",
    "nefriticul": "nefritic",
    "nefriticului": "nefritic",
    "nefrizată": "nefrizat",
    "nefrizate": "nefrizat",
    "nefrizați": "nefrizat",
    "nefrotată": "nefrotat",
    "nefrotate": "nefrotat",
    "nefrotați": "nefrotat",
    "nefructificată": "nefructificat",
    "nefructificate": "nefructificat",
    "nefructificați": "nefructificat",
    "nefrunzărită": "nefrunzărit",
    "nefrunzărite": "nefrunzărit",
    "nefrunzăriți": "nefrunzărit",
    "nefrustrată": "nefrustrat",
    "nefrustrate": "nefrustrat",
    "nefrustrați": "nefrustrat",
    "nefudulită": "nefudulit",
    "nefudulite": "nefudulit",
    "nefuduliți": "nefudulit",
    "nefugărită": "nefugărit",
    "nefugărite": "nefugărit",
    "nefugăriți": "nefugărit",
    "nefugită": "nefugit",
    "nefugite": "nefugit",
    "nefugiți": "nefugit",
    "nefuguită": "nefuguit",
    "nefuguite": "nefuguit",
    "nefuguiți": "nefuguit",
    "nefulardată": "nefulardat",
    "nefulardate": "nefulardat",
    "nefulardați": "nefulardat",
    "nefulată": "nefulat",
    "nefulate": "nefulat",
    "nefulați": "nefulat",
    "nefulgerată": "nefulgerat",
    "nefulgerate": "nefulgerat",
    "nefulgerați": "nefulgerat",
    "nefulguită": "nefulguit",
    "nefulguite": "nefulguit",
    "nefulguiți": "nefulguit",
    "nefumată": "nefumat",
    "nefumate": "nefumat",
    "nefumați": "nefumat",
    "nefumătoare": "nefumător",
    "nefumătoarea": "nefumător",
    "nefumătoarei": "nefumător",
    "nefumătoarele": "nefumător",
    "nefumătoarelor": "nefumător",
    "nefumători": "nefumător",
    "nefumătorii": "nefumător",
    "nefumătorilor": "nefumător",
    "nefumătorul": "nefumător",
    "nefumătorului": "nefumător",
    "nefumegată": "nefumegat",
    "nefumegate": "nefumegat",
    "nefumegați": "nefumegat",
    "nefumizată": "nefumizat",
    "nefumizate": "nefumizat",
    "nefumizați": "nefumizat",
    "nefumuită": "nefumuit",
    "nefumuite": "nefumuit",
    "nefumuiți": "nefumuit",
    "nefuncționată": "nefuncționat",
    "nefuncționate": "nefuncționat",
    "nefuncționați": "nefuncționat",
    "nefundamentată": "nefundamentat",
    "nefundamentate": "nefundamentat",
    "nefundamentați": "nefundamentat",
    "nefundarisită": "nefundarisit",
    "nefundarisite": "nefundarisit",
    "nefundarisiți": "nefundarisit",
    "nefundată": "nefundat",
    "nefundate": "nefundat",
    "nefundați": "nefundat",
    "nefurată": "nefurat",
    "nefurate": "nefurat",
    "nefurați": "nefurat",
    "nefurișată": "nefurișat",
    "nefurișate": "nefurișat",
    "nefurișați": "nefurișat",
    "nefurlandisită": "nefurlandisit",
    "nefurlandisite": "nefurlandisit",
    "nefurlandisiți": "nefurlandisit",
    "nefurnicată": "nefurnicat",
    "nefurnicate": "nefurnicat",
    "nefurnicați": "nefurnicat",
    "nefurniruită": "nefurniruit",
    "nefurniruite": "nefurniruit",
    "nefurniruiți": "nefurniruit",
    "nefurnizată": "nefurnizat",
    "nefurnizate": "nefurnizat",
    "nefurnizați": "nefurnizat",
    "nefuzionată": "nefuzionat",
    "nefuzionate": "nefuzionat",
    "nefuzionați": "nefuzionat",
    "negi": "neg",
    "negii": "neg",
    "negilor": "neg",
    "negul": "neg",
    "negului": "neg",
    "neagă": "nega",
    "neg": "nega",
    "negă": "nega",
    "negai": "nega",
    "negam": "nega",
    "negăm": "nega",
    "negând": "nega",
    "negându": "nega",
    "negară": "nega",
    "negarăm": "nega",
    "negarăți": "nega",
    "negase": "nega",
    "negasem": "nega",
    "negaseră": "nega",
    "negaserăm": "nega",
    "negaserăți": "nega",
    "negaseși": "nega",
    "negași": "nega",
    "negat": "nega",
    "negați": "nega",
    "negau": "nega",
    "nege": "nega",
    "negi": "nega",
    "nemainegându": "nega",
    "nenegându": "nega",
    "negăbjită": "negăbjit",
    "negăbjite": "negăbjit",
    "negăbjiți": "negăbjit",
    "negăbuită": "negăbuit",
    "negăbuite": "negăbuit",
    "negăbuiți": "negăbuit",
    "negâdilată": "negâdilat",
    "negâdilate": "negâdilat",
    "negâdilați": "negâdilat",
    "negâfâită": "negâfâit",
    "negâfâite": "negâfâit",
    "negâfâiți": "negâfâit",
    "negâgâită": "negâgâit",
    "negâgâite": "negâgâit",
    "negâgâiți": "negâgâit",
    "negăgăită": "negăgăit",
    "negăgăite": "negăgăit",
    "negăgăiți": "negăgăit",
    "negăinată": "negăinat",
    "negăinate": "negăinat",
    "negăinați": "negăinat",
    "negăinățată": "negăinățat",
    "negăinățate": "negăinățat",
    "negăinățați": "negăinățat",
    "negăitănită": "negăitănit",
    "negăitănite": "negăitănit",
    "negăităniți": "negăitănit",
    "negâjâită": "negâjâit",
    "negâjâite": "negâjâit",
    "negâjâiți": "negâjâit",
    "negălbejita": "negălbejit",
    "negălbejită": "negălbejit",
    "negălbejite": "negălbejit",
    "negălbejitei": "negălbejit",
    "negălbejitele": "negălbejit",
    "negălbejitelor": "negălbejit",
    "negălbejiți": "negălbejit",
    "negălbejiții": "negălbejit",
    "negălbejiților": "negălbejit",
    "negălbejitul": "negălbejit",
    "negălbejitului": "negălbejit",
    "negălbenită": "negălbenit",
    "negălbenite": "negălbenit",
    "negălbeniți": "negălbenit",
    "negâlcevită": "negâlcevit",
    "negâlcevite": "negâlcevit",
    "negâlceviți": "negâlcevit",
    "negâlgâită": "negâlgâit",
    "negâlgâite": "negâlgâit",
    "negâlgâiți": "negâlgâit",
    "negalopată": "negalopat",
    "negalopate": "negalopat",
    "negalopați": "negalopat",
    "negalvanizată": "negalvanizat",
    "negalvanizate": "negalvanizat",
    "negalvanizați": "negalvanizat",
    "negândita": "negândit",
    "negândită": "negândit",
    "negândite": "negândit",
    "negânditei": "negândit",
    "negânditele": "negândit",
    "negânditelor": "negândit",
    "negândiți": "negândit",
    "negândiții": "negândit",
    "negândiților": "negândit",
    "negânditul": "negândit",
    "negânditului": "negândit",
    "negângăvită": "negângăvit",
    "negângăvite": "negângăvit",
    "negângăviți": "negângăvit",
    "negângurită": "negângurit",
    "negângurite": "negângurit",
    "negânguriți": "negângurit",
    "negarantată": "negarantat",
    "negarantate": "negarantat",
    "negarantați": "negarantat",
    "negarată": "negarat",
    "negarate": "negarat",
    "negarați": "negarat",
    "negârbovită": "negârbovit",
    "negârbovite": "negârbovit",
    "negârboviți": "negârbovit",
    "negărduită": "negărduit",
    "negărduite": "negărduit",
    "negărduiți": "negărduit",
    "negarea": "negare",
    "negari": "negare",
    "negarii": "negare",
    "negarile": "negare",
    "negarilor": "negare",
    "negargarisită": "negargarisit",
    "negargarisite": "negargarisit",
    "negargarisiți": "negargarisit",
    "negargarizată": "negargarizat",
    "negargarizate": "negargarizat",
    "negargarizați": "negargarizat",
    "negarnisită": "negarnisit",
    "negarnisite": "negarnisit",
    "negarnisiți": "negarnisit",
    "negăsită": "negăsit",
    "negăsite": "negăsit",
    "negăsiți": "negăsit",
    "negată": "negat",
    "negate": "negat",
    "negați": "negat",
    "negația": "negație",
    "negației": "negație",
    "negații": "negație",
    "negațiile": "negație",
    "negațiilor": "negație",
    "negătită": "negătit",
    "negătite": "negătit",
    "negătiți": "negătit",
    "neg.": "negativ",
    "negativa": "negativ",
    "negativă": "negativ",
    "negative": "negativ",
    "negativei": "negativ",
    "negativele": "negativ",
    "negativelor": "negativ",
    "negativi": "negativ",
    "negativii": "negativ",
    "negativilor": "negativ",
    "negativul": "negativ",
    "negativului": "negativ",
    "negativismul": "negativism",
    "negativismului": "negativism",
    "negativista": "negativist",
    "negativistă": "negativist",
    "negativiste": "negativist",
    "negativistei": "negativist",
    "negativistele": "negativist",
    "negativistelor": "negativist",
    "negativiști": "negativist",
    "negativiștii": "negativist",
    "negativiștilor": "negativist",
    "negativistul": "negativist",
    "negativistului": "negativist",
    "negativista": "negativistă",
    "negativiste": "negativistă",
    "negativistei": "negativistă",
    "negativistele": "negativistă",
    "negativistelor": "negativistă",
    "negatoare": "negator",
    "negatoarea": "negator",
    "negatoarei": "negator",
    "negatoarele": "negator",
    "negatoarelor": "negator",
    "negatori": "negator",
    "negatorii": "negator",
    "negatorilor": "negator",
    "negatorul": "negator",
    "negatorului": "negator",
    "negatoscoape": "negatoscop",
    "negatoscoapele": "negatoscop",
    "negatoscoapelor": "negatoscop",
    "negatoscopul": "negatoscop",
    "negatoscopului": "negatoscop",
    "negâtuită": "negâtuit",
    "negâtuite": "negâtuit",
    "negâtuiți": "negâtuit",
    "negăunoșită": "negăunoșit",
    "negăunoșite": "negăunoșit",
    "negăunoșiți": "negăunoșit",
    "negăurită": "negăurit",
    "negăurite": "negăurit",
    "negăuriți": "negăurit",
    "negăvozdită": "negăvozdit",
    "negăvozdite": "negăvozdit",
    "negăvozdiți": "negăvozdit",
    "negazată": "negazat",
    "negazate": "negazat",
    "negazați": "negazat",
    "negăzduită": "negăzduit",
    "negăzduite": "negăzduit",
    "negăzduiți": "negăzduit",
    "negazificată": "negazificat",
    "negazificate": "negazificat",
    "negazificați": "negazificat",
    "negazonată": "negazonat",
    "negazonate": "negazonat",
    "negazonați": "negazonat",
    "negelarița": "negelariță",
    "negelarițe": "negelariță",
    "negelariței": "negelariță",
    "negelarițele": "negelariță",
    "negelarițelor": "negelariță",
    "negelatinizată": "negelatinizat",
    "negelatinizate": "negelatinizat",
    "negelatinizați": "negelatinizat",
    "negelificată": "negelificat",
    "negelificate": "negelificat",
    "negelificați": "negelificat",
    "negeluită": "negeluit",
    "negeluite": "negeluit",
    "negeluiți": "negeluit",
    "negemută": "negemut",
    "negemute": "negemut",
    "negemuți": "negemut",
    "negeneralizată": "negeneralizat",
    "negeneralizate": "negeneralizat",
    "negeneralizați": "negeneralizat",
    "negenerată": "negenerat",
    "negenerate": "negenerat",
    "negenerați": "negenerat",
    "negermanizată": "negermanizat",
    "negermanizate": "negermanizat",
    "negermanizați": "negermanizat",
    "negerminată": "negerminat",
    "negerminate": "negerminat",
    "negerminați": "negerminat",
    "negeruită": "negeruit",
    "negeruite": "negeruit",
    "negeruiți": "negeruit",
    "negesticulată": "negesticulat",
    "negesticulate": "negesticulat",
    "negesticulați": "negesticulat",
    "negheboșată": "negheboșat",
    "negheboșate": "negheboșat",
    "negheboșați": "negheboșat",
    "neghemuită": "neghemuit",
    "neghemuite": "neghemuit",
    "neghemuiți": "neghemuit",
    "neghicită": "neghicit",
    "neghicite": "neghicit",
    "neghiciți": "neghicit",
    "neghidată": "neghidat",
    "neghidate": "neghidat",
    "neghidați": "neghidat",
    "neghiftuită": "neghiftuit",
    "neghiftuite": "neghiftuit",
    "neghiftuiți": "neghiftuit",
    "neghigosită": "neghigosit",
    "neghigosite": "neghigosit",
    "neghigosiți": "neghigosit",
    "neghilită": "neghilit",
    "neghilite": "neghilit",
    "neghiliți": "neghilit",
    "neghilosită": "neghilosit",
    "neghilosite": "neghilosit",
    "neghilosiți": "neghilosit",
    "neghilotinată": "neghilotinat",
    "neghilotinate": "neghilotinat",
    "neghilotinați": "neghilotinat",
    "neghina": "neghină",
    "neghine": "neghină",
    "neghinei": "neghină",
    "neghinele": "neghină",
    "neghinelor": "neghină",
    "neghinița": "neghiniță",
    "neghinițe": "neghiniță",
    "neghiniței": "neghiniță",
    "neghinițele": "neghiniță",
    "neghinițelor": "neghiniță",
    "neghintuită": "neghintuit",
    "neghintuite": "neghintuit",
    "neghintuiți": "neghintuit",
    "neghinuța": "neghinuță",
    "neghinuțe": "neghinuță",
    "neghinuței": "neghinuță",
    "neghinuțele": "neghinuță",
    "neghinuțelor": "neghinuță",
    "neghioaba": "neghioabă",
    "neghioabe": "neghioabă",
    "neghioabei": "neghioabă",
    "neghioabele": "neghioabă",
    "neghioabelor": "neghioabă",
    "neghioaba": "neghiob",
    "neghioabă": "neghiob",
    "neghioabe": "neghiob",
    "neghioabei": "neghiob",
    "neghioabele": "neghiob",
    "neghioabelor": "neghiob",
    "neghiobi": "neghiob",
    "neghiobii": "neghiob",
    "neghiobilor": "neghiob",
    "neghiobul": "neghiob",
    "neghiobului": "neghiob",
    "neghiobeasca": "neghiobesc",
    "neghiobească": "neghiobesc",
    "neghiobescul": "neghiobesc",
    "neghiobescului": "neghiobesc",
    "neghiobești": "neghiobesc",
    "neghiobeștii": "neghiobesc",
    "neghiobeștile": "neghiobesc",
    "neghiobeștilor": "neghiobesc",
    "neghiobia": "neghiobie",
    "neghiobiei": "neghiobie",
    "neghiobii": "neghiobie",
    "neghiobiile": "neghiobie",
    "neghiobiilor": "neghiobie",
    "neghiontită": "neghiontit",
    "neghiontite": "neghiontit",
    "neghiontiți": "neghiontit",
    "neghiorțăită": "neghiorțăit",
    "neghiorțăite": "neghiorțăit",
    "neghiorțăiți": "neghiorțăit",
    "neghioșată": "neghioșat",
    "neghioșate": "neghioșat",
    "neghioșați": "neghioșat",
    "neghizduită": "neghizduit",
    "neghizduite": "neghizduit",
    "neghizduiți": "neghizduit",
    "neginerită": "neginerit",
    "neginerite": "neginerit",
    "negineriți": "neginerit",
    "neginită": "neginit",
    "neginite": "neginit",
    "neginiți": "neginit",
    "negirată": "negirat",
    "negirate": "negirat",
    "negirați": "negirat",
    "negiugiulită": "negiugiulit",
    "negiugiulite": "negiugiulit",
    "negiugiuliți": "negiugiulit",
    "neglasată": "neglasat",
    "neglasate": "neglasat",
    "neglasați": "neglasat",
    "neglăsuită": "neglăsuit",
    "neglăsuite": "neglăsuit",
    "neglăsuiți": "neglăsuit",
    "neglazurată": "neglazurat",
    "neglazurate": "neglazurat",
    "neglazurați": "neglazurat",
    "neglijă": "neglija",
    "neglijai": "neglija",
    "neglijam": "neglija",
    "neglijăm": "neglija",
    "neglijând": "neglija",
    "neglijându": "neglija",
    "neglijară": "neglija",
    "neglijarăm": "neglija",
    "neglijarăți": "neglija",
    "neglijase": "neglija",
    "neglijasem": "neglija",
    "neglijaseră": "neglija",
    "neglijaserăm": "neglija",
    "neglijaserăți": "neglija",
    "neglijaseși": "neglija",
    "neglijași": "neglija",
    "neglijat": "neglija",
    "neglijați": "neglija",
    "neglijau": "neglija",
    "neglijează": "neglija",
    "neglijez": "neglija",
    "neglijeze": "neglija",
    "neglijezi": "neglija",
    "nemaineglijând": "neglija",
    "nemaineglijându": "neglija",
    "neneglijând": "neglija",
    "neneglijându": "neglija",
    "neglijabila": "neglijabil",
    "neglijabilă": "neglijabil",
    "neglijabile": "neglijabil",
    "neglijabilei": "neglijabil",
    "neglijabilele": "neglijabil",
    "neglijabilelor": "neglijabil",
    "neglijabili": "neglijabil",
    "neglijabilii": "neglijabil",
    "neglijabililor": "neglijabil",
    "neglijabilul": "neglijabil",
    "neglijabilului": "neglijabil",
    "neglijarea": "neglijare",
    "neglijări": "neglijare",
    "neglijării": "neglijare",
    "neglijările": "neglijare",
    "neglijărilor": "neglijare",
    "neglijată": "neglijat",
    "neglijate": "neglijat",
    "neglijați": "neglijat",
    "neglijenta": "neglijent",
    "neglijentă": "neglijent",
    "neglijente": "neglijent",
    "neglijentei": "neglijent",
    "neglijentele": "neglijent",
    "neglijentelor": "neglijent",
    "neglijenți": "neglijent",
    "neglijenții": "neglijent",
    "neglijenților": "neglijent",
    "neglijentul": "neglijent",
    "neglijentului": "neglijent",
    "neglijența": "neglijență",
    "neglijențe": "neglijență",
    "neglijenței": "neglijență",
    "neglijențele": "neglijență",
    "neglijențelor": "neglijență",
    "neglijeul": "neglijeu",
    "neglijeului": "neglijeu",
    "neglijeuri": "neglijeu",
    "neglijeurile": "neglijeu",
    "neglijeurilor": "neglijeu",
    "neglisată": "neglisat",
    "neglisate": "neglisat",
    "neglisați": "neglisat",
    "neglobită": "neglobit",
    "neglobite": "neglobit",
    "neglobiți": "neglobit",
    "neglodită": "neglodit",
    "neglodite": "neglodit",
    "neglodiți": "neglodit",
    "neglorificată": "neglorificat",
    "neglorificate": "neglorificat",
    "neglorificați": "neglorificat",
    "neglosată": "neglosat",
    "neglosate": "neglosat",
    "neglosați": "neglosat",
    "neglumită": "neglumit",
    "neglumite": "neglumit",
    "neglumiți": "neglumit",
    "negociai": "negocia",
    "negociam": "negocia",
    "negociară": "negocia",
    "negociarăm": "negocia",
    "negociarăți": "negocia",
    "negociase": "negocia",
    "negociasem": "negocia",
    "negociaseră": "negocia",
    "negociaserăm": "negocia",
    "negociaserăți": "negocia",
    "negociaseși": "negocia",
    "negociași": "negocia",
    "negociat": "negocia",
    "negociați": "negocia",
    "negociau": "negocia",
    "negociază": "negocia",
    "negocie": "negocia",
    "negociem": "negocia",
    "negociez": "negocia",
    "negocieze": "negocia",
    "negociezi": "negocia",
    "negociind": "negocia",
    "negociindu": "negocia",
    "nemainegociind": "negocia",
    "nemainegociindu": "negocia",
    "nenegociind": "negocia",
    "nenegociindu": "negocia",
    "negociabila": "negociabil",
    "negociabilă": "negociabil",
    "negociabile": "negociabil",
    "negociabilei": "negociabil",
    "negociabilele": "negociabil",
    "negociabilelor": "negociabil",
    "negociabili": "negociabil",
    "negociabilii": "negociabil",
    "negociabililor": "negociabil",
    "negociabilul": "negociabil",
    "negociabilului": "negociabil",
    "negociată": "negociat",
    "negociate": "negociat",
    "negociați": "negociat",
    "negociatoarea": "negociatoare",
    "negociatoarei": "negociatoare",
    "negociatoarele": "negociatoare",
    "negociatoarelor": "negociatoare",
    "negociatori": "negociator",
    "negociatorii": "negociator",
    "negociatorilor": "negociator",
    "negociatorul": "negociator",
    "negociatorului": "negociator",
    "negociatorul-șef": "negociator-șef",
    "negociatorului-șef": "negociator-șef",
    "negocierea": "negociere",
    "negocieri": "negociere",
    "negocierii": "negociere",
    "negocierile": "negociere",
    "negocierilor": "negociere",
    "negofrată": "negofrat",
    "negofrate": "negofrat",
    "negofrați": "negofrat",
    "negogită": "negogit",
    "negogite": "negogit",
    "negogiți": "negogit",
    "negolită": "negolit",
    "negolite": "negolit",
    "negoliți": "negolit",
    "negologănită": "negologănit",
    "negologănite": "negologănit",
    "negologăniți": "negologănit",
    "negonflată": "negonflat",
    "negonflate": "negonflat",
    "negonflați": "negonflat",
    "negonită": "negonit",
    "negonite": "negonit",
    "negoniți": "negonit",
    "negoasa": "negos",
    "negoasă": "negos",
    "negoase": "negos",
    "negoasei": "negos",
    "negoasele": "negos",
    "negoaselor": "negos",
    "negoși": "negos",
    "negoșii": "negos",
    "negoșilor": "negos",
    "negosul": "negos",
    "negosului": "negos",
    "negospodărită": "negospodărit",
    "negospodărite": "negospodărit",
    "negospodăriți": "negospodărit",
    "negoțul": "negoț",
    "negoțului": "negoț",
    "negoțuri": "negoț",
    "negoțurile": "negoț",
    "negoțurilor": "negoț",
    "negrăbită": "negrăbit",
    "negrăbite": "negrăbit",
    "negrăbiți": "negrăbit",
    "negradata": "negradat",
    "negradată": "negradat",
    "negradate": "negradat",
    "negradatei": "negradat",
    "negradatele": "negradat",
    "negradatelor": "negradat",
    "negradați": "negradat",
    "negradații": "negradat",
    "negradaților": "negradat",
    "negradatul": "negradat",
    "negradatului": "negradat",
    "negrădinărită": "negrădinărit",
    "negrădinărite": "negrădinărit",
    "negrădinăriți": "negrădinărit",
    "negrafitizată": "negrafitizat",
    "negrafitizate": "negrafitizat",
    "negrafitizați": "negrafitizat",
    "negrăita": "negrăit",
    "negrăită": "negrăit",
    "negrăite": "negrăit",
    "negrăitei": "negrăit",
    "negrăitele": "negrăit",
    "negrăitelor": "negrăit",
    "negrăiți": "negrăit",
    "negrăiții": "negrăit",
    "negrăiților": "negrăit",
    "negrăitul": "negrăit",
    "negrăitului": "negrăit",
    "negrămădită": "negrămădit",
    "negrămădite": "negrămădit",
    "negrămădiți": "negrămădit",
    "negramaticalizată": "negramaticalizat",
    "negramaticalizate": "negramaticalizat",
    "negramaticalizați": "negramaticalizat",
    "negranulată": "negranulat",
    "negranulate": "negranulat",
    "negranulați": "negranulat",
    "negrăpată": "negrăpat",
    "negrăpate": "negrăpat",
    "negrăpați": "negrăpat",
    "negraseiată": "negraseiat",
    "negraseiate": "negraseiat",
    "negraseiați": "negraseiat",
    "negrațiată": "negrațiat",
    "negrațiate": "negrațiat",
    "negrațiați": "negrațiat",
    "negratificată": "negratificat",
    "negratificate": "negratificat",
    "negratificați": "negratificat",
    "negratinată": "negratinat",
    "negratinate": "negratinat",
    "negratinați": "negratinat",
    "negravată": "negravat",
    "negravate": "negravat",
    "negravați": "negravat",
    "negravitată": "negravitat",
    "negravitate": "negravitat",
    "negravitați": "negravitat",
    "negreala": "negreală",
    "negreli": "negreală",
    "negrelii": "negreală",
    "negrelile": "negreală",
    "negrelilor": "negreală",
    "negreața": "negreață",
    "negreați": "negreață",
    "negreații": "negreață",
    "negreațile": "negreață",
    "negreaților": "negreață",
    "negreblată": "negreblat",
    "negreblate": "negreblat",
    "negreblați": "negreblat",
    "negrecizată": "negrecizat",
    "negrecizate": "negrecizat",
    "negrecizați": "negrecizat",
    "negrefată": "negrefat",
    "negrefate": "negrefat",
    "negrefați": "negrefat",
    "negresa": "negresă",
    "negrese": "negresă",
    "negresei": "negresă",
    "negresele": "negresă",
    "negreselor": "negresă",
    "negresată": "negresat",
    "negresate": "negresat",
    "negresați": "negresat",
    "negreșita": "negreșit",
    "negreșită": "negreșit",
    "negreșite": "negreșit",
    "negreșitei": "negreșit",
    "negreșitele": "negreșit",
    "negreșitelor": "negreșit",
    "negreșiți": "negreșit",
    "negreșiții": "negreșit",
    "negreșiților": "negreșit",
    "negreșitul": "negreșit",
    "negreșitului": "negreșit",
    "negrevată": "negrevat",
    "negrevate": "negrevat",
    "negrevați": "negrevat",
    "negricioasa": "negricios",
    "negricioasă": "negricios",
    "negricioase": "negricios",
    "negricioasei": "negricios",
    "negricioasele": "negricios",
    "negricioaselor": "negricios",
    "negricioși": "negricios",
    "negricioșii": "negricios",
    "negricioșilor": "negricios",
    "negriciosul": "negricios",
    "negriciosului": "negricios",
    "negrijită": "negrijit",
    "negrijite": "negrijit",
    "negrijiți": "negrijit",
    "negrilica": "negrilică",
    "negrilici": "negrilică",
    "negrilicii": "negrilică",
    "negrilicile": "negrilică",
    "negrilicilor": "negrilică",
    "negrimată": "negrimat",
    "negrimate": "negrimat",
    "negrimați": "negrimat",
    "negrindinată": "negrindinat",
    "negrindinate": "negrindinat",
    "negrindinați": "negrindinat",
    "negripată": "negripat",
    "negripate": "negripat",
    "negripați": "negripat",
    "negrișoara": "negrișor",
    "negrișoară": "negrișor",
    "negrișoare": "negrișor",
    "negrișoarei": "negrișor",
    "negrișoarele": "negrișor",
    "negrișoarelor": "negrișor",
    "negrișori": "negrișor",
    "negrișorii": "negrișor",
    "negrișorilor": "negrișor",
    "negrișorul": "negrișor",
    "negrișorului": "negrișor",
    "negria": "negriu",
    "negrie": "negriu",
    "negriei": "negriu",
    "negrii": "negriu",
    "negriii": "negriu",
    "negriile": "negriu",
    "negriilor": "negriu",
    "negriul": "negriu",
    "negriului": "negriu",
    "negrizată": "negrizat",
    "negrizate": "negrizat",
    "negrizați": "negrizat",
    "negrohăită": "negrohăit",
    "negrohăite": "negrohăit",
    "negrohăiți": "negrohăit",
    "negrohotită": "negrohotit",
    "negrohotite": "negrohotit",
    "negrohotiți": "negrohotit",
    "negroidul": "negroid",
    "negroidului": "negroid",
    "negroizi": "negroid",
    "negroizii": "negroid",
    "negroizilor": "negroid",
    "negroida": "negroidă",
    "negroide": "negroidă",
    "negroidei": "negroidă",
    "negroidele": "negroidă",
    "negroidelor": "negroidă",
    "negrozăvită": "negrozăvit",
    "negrozăvite": "negrozăvit",
    "negrozăviți": "negrozăvit",
    "neagra": "negru",
    "neagră": "negru",
    "negre": "negru",
    "negrei": "negru",
    "negrele": "negru",
    "negrelor": "negru",
    "negri": "negru",
    "negrii": "negru",
    "negrilor": "negru",
    "negrul": "negru",
    "negrului": "negru",
    "negrunduită": "negrunduit",
    "negrunduite": "negrunduit",
    "negrunduiți": "negrunduit",
    "negrupată": "negrupat",
    "negrupate": "negrupat",
    "negrupați": "negrupat",
    "negrușca": "negrușcă",
    "negruște": "negrușcă",
    "negruștei": "negrușcă",
    "negruștele": "negrușcă",
    "negruștelor": "negrușcă",
    "negruța": "negruț",
    "negruță": "negruț",
    "negruțe": "negruț",
    "negruței": "negruț",
    "negruțele": "negruț",
    "negruțelor": "negruț",
    "negruți": "negruț",
    "negruții": "negruț",
    "negruților": "negruț",
    "negruțul": "negruț",
    "negruțului": "negruț",
    "negudronata": "negudronat",
    "negudronată": "negudronat",
    "negudronate": "negudronat",
    "negudronatei": "negudronat",
    "negudronatele": "negudronat",
    "negudronatelor": "negudronat",
    "negudronați": "negudronat",
    "negudronații": "negudronat",
    "negudronaților": "negudronat",
    "negudronatul": "negudronat",
    "negudronatului": "negudronat",
    "negudurată": "negudurat",
    "negudurate": "negudurat",
    "negudurați": "negudurat",
    "neguițată": "neguițat",
    "neguițate": "neguițat",
    "neguițați": "neguițat",
    "negumată": "negumat",
    "negumate": "negumat",
    "negumați": "negumat",
    "negunoită": "negunoit",
    "negunoite": "negunoit",
    "negunoiți": "negunoit",
    "negura": "negură",
    "neguri": "negură",
    "negurii": "negură",
    "negurile": "negură",
    "negurilor": "negură",
    "negurăită": "negurăit",
    "negurăite": "negurăit",
    "negurăiți": "negurăit",
    "negurata": "negurat",
    "negurată": "negurat",
    "negurate": "negurat",
    "neguratei": "negurat",
    "neguratele": "negurat",
    "neguratelor": "negurat",
    "negurați": "negurat",
    "negurații": "negurat",
    "neguraților": "negurat",
    "neguratul": "negurat",
    "neguratului": "negurat",
    "negureala": "negureală",
    "negureali": "negureală",
    "negureli": "negureală",
    "negurelii": "negureală",
    "negurelilor": "negureală",
    "negurguiată": "negurguiat",
    "negurguiate": "negurguiat",
    "negurguiați": "negurguiat",
    "neguria": "neguriu",
    "negurie": "neguriu",
    "neguriei": "neguriu",
    "negurii": "neguriu",
    "neguriii": "neguriu",
    "neguriile": "neguriu",
    "neguriilor": "neguriu",
    "neguriul": "neguriu",
    "neguriului": "neguriu",
    "negurluită": "negurluit",
    "negurluite": "negurluit",
    "negurluiți": "negurluit",
    "neguroasa": "neguros",
    "neguroasă": "neguros",
    "neguroase": "neguros",
    "neguroasei": "neguros",
    "neguroasele": "neguros",
    "neguroaselor": "neguros",
    "neguroși": "neguros",
    "neguroșii": "neguros",
    "neguroșilor": "neguros",
    "negurosul": "neguros",
    "negurosului": "neguros",
    "negustată": "negustat",
    "negustate": "negustat",
    "negustați": "negustat",
    "negustori": "negustor",
    "negustorii": "negustor",
    "negustorilor": "negustor",
    "negustorul": "negustor",
    "negustorului": "negustor",
    "negustorași": "negustoraș",
    "negustorașii": "negustoraș",
    "negustorașilor": "negustoraș",
    "negustorașul": "negustoraș",
    "negustorașului": "negustoraș",
    "negustoreasa": "negustoreasă",
    "negustorese": "negustoreasă",
    "negustoresei": "negustoreasă",
    "negustoresele": "negustoreasă",
    "negustoreselor": "negustoreasă",
    "negustoreasca": "negustoresc",
    "negustorească": "negustoresc",
    "negustorescul": "negustoresc",
    "negustorescului": "negustoresc",
    "negustorești": "negustoresc",
    "negustoreștii": "negustoresc",
    "negustoreștile": "negustoresc",
    "negustoreștilor": "negustoresc",
    "negustoria": "negustorie",
    "negustoriei": "negustorie",
    "negustorii": "negustorie",
    "negustoriile": "negustorie",
    "negustoriilor": "negustorie",
    "negustorimea": "negustorime",
    "negustorimi": "negustorime",
    "negustorimii": "negustorime",
    "negustorimile": "negustorime",
    "negustorimilor": "negustorime",
    "negustoroasa": "negustoros",
    "negustoroasă": "negustoros",
    "negustoroase": "negustoros",
    "negustoroasei": "negustoros",
    "negustoroasele": "negustoros",
    "negustoroaselor": "negustoros",
    "negustoroși": "negustoros",
    "negustoroșii": "negustoros",
    "negustoroșilor": "negustoros",
    "negustorosul": "negustoros",
    "negustorosului": "negustoros",
    "neguțători": "neguțător",
    "neguțătorii": "neguțător",
    "neguțătorilor": "neguțător",
    "neguțătorul": "neguțător",
    "neguțătorului": "neguțător",
    "neguțătoreasa": "neguțătoreasă",
    "neguțătorese": "neguțătoreasă",
    "neguțătoresei": "neguțătoreasă",
    "neguțătoresele": "neguțătoreasă",
    "neguțătoreselor": "neguțătoreasă",
    "neguțătoria": "neguțătorie",
    "neguțătoriei": "neguțătorie",
    "neguțătorii": "neguțătorie",
    "neguțătoriile": "neguțătorie",
    "neguțătoriilor": "neguțătorie",
    "neguvernamentală": "neguvernamental",
    "neguvernamentale": "neguvernamental",
    "neguvernamentali": "neguvernamental",
    "neguvernată": "neguvernat",
    "neguvernate": "neguvernat",
    "neguvernați": "neguvernat",
    "nehăbăucită": "nehăbăucit",
    "nehăbăucite": "nehăbăucit",
    "nehăbăuciți": "nehăbăucit",
    "nehăbucită": "nehăbucit",
    "nehăbucite": "nehăbucit",
    "nehăbuciți": "nehăbucit",
    "nehâcâită": "nehâcâit",
    "nehâcâite": "nehâcâit",
    "nehâcâiți": "nehâcâit",
    "nehăcuită": "nehăcuit",
    "nehăcuite": "nehăcuit",
    "nehăcuiți": "nehăcuit",
    "nehaiducită": "nehaiducit",
    "nehaiducite": "nehaiducit",
    "nehaiduciți": "nehaiducit",
    "nehăimănită": "nehăimănit",
    "nehăimănite": "nehăimănit",
    "nehăimăniți": "nehăimănit",
    "nehainită": "nehainit",
    "nehainite": "nehainit",
    "nehainiți": "nehainit",
    "nehâită": "nehâit",
    "nehâite": "nehâit",
    "nehâiți": "nehâit",
    "nehăită": "nehăit",
    "nehăite": "nehăit",
    "nehăiți": "nehăit",
    "nehăituită": "nehăituit",
    "nehăituite": "nehăituit",
    "nehăituiți": "nehăituit",
    "nehălăduită": "nehălăduit",
    "nehălăduite": "nehălăduit",
    "nehălăduiți": "nehălăduit",
    "nehălălăită": "nehălălăit",
    "nehălălăite": "nehălălăit",
    "nehălălăiți": "nehălălăit",
    "nehalită": "nehalit",
    "nehalite": "nehalit",
    "nehaliți": "nehalit",
    "nehălpăită": "nehălpăit",
    "nehălpăite": "nehălpăit",
    "nehălpăiți": "nehălpăit",
    "nehalucinată": "nehalucinat",
    "nehalucinate": "nehalucinat",
    "nehalucinați": "nehalucinat",
    "nehămăită": "nehămăit",
    "nehămăite": "nehămăit",
    "nehămăiți": "nehămăit",
    "nehămesita": "nehămesit",
    "nehămesită": "nehămesit",
    "nehămesite": "nehămesit",
    "nehămesitei": "nehămesit",
    "nehămesitele": "nehămesit",
    "nehămesitelor": "nehămesit",
    "nehămesiți": "nehămesit",
    "nehămesiții": "nehămesit",
    "nehămesiților": "nehămesit",
    "nehămesitul": "nehămesit",
    "nehămesitului": "nehămesit",
    "nehămuită": "nehămuit",
    "nehămuite": "nehămuit",
    "nehămuiți": "nehămuit",
    "nehandicapată": "nehandicapat",
    "nehandicapate": "nehandicapat",
    "nehandicapați": "nehandicapat",
    "nehăpăită": "nehăpăit",
    "nehăpăite": "nehăpăit",
    "nehăpăiți": "nehăpăit",
    "nehărățită": "nehărățit",
    "nehărățite": "nehărățit",
    "nehărățiți": "nehărățit",
    "nehărăzită": "nehărăzit",
    "nehărăzite": "nehărăzit",
    "nehărăziți": "nehărăzit",
    "nehârbuită": "nehârbuit",
    "nehârbuite": "nehârbuit",
    "nehârbuiți": "nehârbuit",
    "nehârcâită": "nehârcâit",
    "nehârcâite": "nehârcâit",
    "nehârcâiți": "nehârcâit",
    "nehărhătită": "nehărhătit",
    "nehărhătite": "nehărhătit",
    "nehărhătiți": "nehărhătit",
    "nehârjonită": "nehârjonit",
    "nehârjonite": "nehârjonit",
    "nehârjoniți": "nehârjonit",
    "neharnașată": "neharnașat",
    "neharnașate": "neharnașat",
    "neharnașați": "neharnașat",
    "nehărnicită": "nehărnicit",
    "nehărnicite": "nehărnicit",
    "nehărniciți": "nehărnicit",
    "nehârșâită": "nehârșâit",
    "nehârșâite": "nehârșâit",
    "nehârșâiți": "nehârșâit",
    "nehârsită": "nehârsit",
    "nehârsite": "nehârsit",
    "nehârsiți": "nehârsit",
    "nehărșnită": "nehărșnit",
    "nehărșnite": "nehărșnit",
    "nehărșniți": "nehărșnit",
    "nehărtănită": "nehărtănit",
    "nehărtănite": "nehărtănit",
    "nehărtăniți": "nehărtănit",
    "nehartoită": "nehartoit",
    "nehartoite": "nehartoit",
    "nehartoiți": "nehartoit",
    "nehărțuită": "nehărțuit",
    "nehărțuite": "nehărțuit",
    "nehărțuiți": "nehărțuit",
    "nehâșâită": "nehâșâit",
    "nehâșâite": "nehâșâit",
    "nehâșâiți": "nehâșâit",
    "nehașurată": "nehașurat",
    "nehașurate": "nehașurat",
    "nehașurați": "nehașurat",
    "nehâțâită": "nehâțâit",
    "nehâțâite": "nehâțâit",
    "nehâțâiți": "nehâțâit",
    "nehâțânată": "nehâțânat",
    "nehâțânate": "nehâțânat",
    "nehâțânați": "nehâțânat",
    "nehătcăită": "nehătcăit",
    "nehătcăite": "nehătcăit",
    "nehătcăiți": "nehătcăit",
    "nehătită": "nehătit",
    "nehătite": "nehătit",
    "nehătiți": "nehătit",
    "nehățită": "nehățit",
    "nehățite": "nehățit",
    "nehățiți": "nehățit",
    "nehățuită": "nehățuit",
    "nehățuite": "nehățuit",
    "nehățuiți": "nehățuit",
    "nehăulită": "nehăulit",
    "nehăulite": "nehăulit",
    "nehăuliți": "nehăulit",
    "nehavată": "nehavat",
    "nehavate": "nehavat",
    "nehavați": "nehavat",
    "nehazardata": "nehazardat",
    "nehazardată": "nehazardat",
    "nehazardate": "nehazardat",
    "nehazardatei": "nehazardat",
    "nehazardatele": "nehazardat",
    "nehazardatelor": "nehazardat",
    "nehazardați": "nehazardat",
    "nehazardații": "nehazardat",
    "nehazardaților": "nehazardat",
    "nehazardatul": "nehazardat",
    "nehazardatului": "nehazardat",
    "nehâzită": "nehâzit",
    "nehâzite": "nehâzit",
    "nehâziți": "nehâzit",
    "nehibernată": "nehibernat",
    "nehibernate": "nehibernat",
    "nehibernați": "nehibernat",
    "nehibridată": "nehibridat",
    "nehibridate": "nehibridat",
    "nehibridați": "nehibridat",
    "nehibridizată": "nehibridizat",
    "nehibridizate": "nehibridizat",
    "nehibridizați": "nehibridizat",
    "nehicăită": "nehicăit",
    "nehicăite": "nehicăit",
    "nehicăiți": "nehicăit",
    "nehidratată": "nehidratat",
    "nehidratate": "nehidratat",
    "nehidratați": "nehidratat",
    "nehidrogenată": "nehidrogenat",
    "nehidrogenate": "nehidrogenat",
    "nehidrogenați": "nehidrogenat",
    "nehipertrofiată": "nehipertrofiat",
    "nehipertrofiate": "nehipertrofiat",
    "nehipertrofiați": "nehipertrofiat",
    "nehipnotizată": "nehipnotizat",
    "nehipnotizate": "nehipnotizat",
    "nehipnotizați": "nehipnotizat",
    "nehiritisită": "nehiritisit",
    "nehiritisite": "nehiritisit",
    "nehiritisiți": "nehiritisit",
    "nehirotonisită": "nehirotonisit",
    "nehirotonisite": "nehirotonisit",
    "nehirotonisiți": "nehirotonisit",
    "nehirotonită": "nehirotonit",
    "nehirotonite": "nehirotonit",
    "nehirotoniți": "nehirotonit",
    "nehlizită": "nehlizit",
    "nehlizite": "nehlizit",
    "nehliziți": "nehlizit",
    "nehodorogita": "nehodorogit",
    "nehodorogită": "nehodorogit",
    "nehodorogite": "nehodorogit",
    "nehodorogitei": "nehodorogit",
    "nehodorogitele": "nehodorogit",
    "nehodorogitelor": "nehodorogit",
    "nehodorogiți": "nehodorogit",
    "nehodorogiții": "nehodorogit",
    "nehodorogiților": "nehodorogit",
    "nehodorogitul": "nehodorogit",
    "nehodorogitului": "nehodorogit",
    "nehohotită": "nehohotit",
    "nehohotite": "nehohotit",
    "nehohotiți": "nehohotit",
    "nehoinărită": "nehoinărit",
    "nehoinărite": "nehoinărit",
    "nehoinăriți": "nehoinărit",
    "nehojbăită": "nehojbăit",
    "nehojbăite": "nehojbăit",
    "nehojbăiți": "nehojbăit",
    "neholbata": "neholbat",
    "neholbată": "neholbat",
    "neholbate": "neholbat",
    "neholbatei": "neholbat",
    "neholbatele": "neholbat",
    "neholbatelor": "neholbat",
    "neholbați": "neholbat",
    "neholbații": "neholbat",
    "neholbaților": "neholbat",
    "neholbatul": "neholbat",
    "neholbatului": "neholbat",
    "neholteită": "neholteit",
    "neholteite": "neholteit",
    "neholteiți": "neholteit",
    "nehondrănită": "nehondrănit",
    "nehondrănite": "nehondrănit",
    "nehondrăniți": "nehondrănit",
    "nehonipsită": "nehonipsit",
    "nehonipsite": "nehonipsit",
    "nehonipsiți": "nehonipsit",
    "nehonuită": "nehonuit",
    "nehonuite": "nehonuit",
    "nehonuiți": "nehonuit",
    "nehopăită": "nehopăit",
    "nehopăite": "nehopăit",
    "nehopăiți": "nehopăit",
    "nehorăită": "nehorăit",
    "nehorăite": "nehorăit",
    "nehorăiți": "nehorăit",
    "nehorcăită": "nehorcăit",
    "nehorcăite": "nehorcăit",
    "nehorcăiți": "nehorcăit",
    "nehorită": "nehorit",
    "nehorite": "nehorit",
    "nehoriți": "nehorit",
    "nehorpăită": "nehorpăit",
    "nehorpăite": "nehorpăit",
    "nehorpăiți": "nehorpăit",
    "nehotărârea": "nehotărâre",
    "nehotărâri": "nehotărâre",
    "nehotărârii": "nehotărâre",
    "nehotărârile": "nehotărâre",
    "nehotărârilor": "nehotărâre",
    "nehot.": "nehotărât",
    "nehotărâta": "nehotărât",
    "nehotărâtă": "nehotărât",
    "nehotărâte": "nehotărât",
    "nehotărâtei": "nehotărât",
    "nehotărâtele": "nehotărât",
    "nehotărâtelor": "nehotărât",
    "nehotărâți": "nehotărât",
    "nehotărâții": "nehotărât",
    "nehotărâților": "nehotărât",
    "nehotărâtul": "nehotărât",
    "nehotărâtului": "nehotărât",
    "nehotărnicită": "nehotărnicit",
    "nehotărnicite": "nehotărnicit",
    "nehotărniciți": "nehotărnicit",
    "nehoțită": "nehoțit",
    "nehoțite": "nehoțit",
    "nehoțiți": "nehoțit",
    "nehrănirea": "nehrănire",
    "nehrăniri": "nehrănire",
    "nehrănirii": "nehrănire",
    "nehrănirile": "nehrănire",
    "nehrănirilor": "nehrănire",
    "nehrănita": "nehrănit",
    "nehrănită": "nehrănit",
    "nehrănite": "nehrănit",
    "nehrănitei": "nehrănit",
    "nehrănitele": "nehrănit",
    "nehrănitelor": "nehrănit",
    "nehrăniți": "nehrănit",
    "nehrăniții": "nehrănit",
    "nehrăniților": "nehrănit",
    "nehrănitul": "nehrănit",
    "nehrănitului": "nehrănit",
    "nehrentuită": "nehrentuit",
    "nehrentuite": "nehrentuit",
    "nehrentuiți": "nehrentuit",
    "nehrepcuită": "nehrepcuit",
    "nehrepcuite": "nehrepcuit",
    "nehrepcuiți": "nehrepcuit",
    "nehuciuită": "nehuciuit",
    "nehuciuite": "nehuciuit",
    "nehuciuiți": "nehuciuit",
    "nehuhurată": "nehuhurat",
    "nehuhurate": "nehuhurat",
    "nehuhurați": "nehuhurat",
    "nehuiduită": "nehuiduit",
    "nehuiduite": "nehuiduit",
    "nehuiduiți": "nehuiduit",
    "nehuită": "nehuit",
    "nehuite": "nehuit",
    "nehuiți": "nehuit",
    "nehuițată": "nehuițat",
    "nehuițate": "nehuițat",
    "nehuițați": "nehuițat",
    "nehulită": "nehulit",
    "nehulite": "nehulit",
    "nehuliți": "nehulit",
    "nehumuită": "nehumuit",
    "nehumuite": "nehumuit",
    "nehumuiți": "nehumuit",
    "nehurducăită": "nehurducăit",
    "nehurducăite": "nehurducăit",
    "nehurducăiți": "nehurducăit",
    "nehurducată": "nehurducat",
    "nehurducate": "nehurducat",
    "nehurducați": "nehurducat",
    "nehurduită": "nehurduit",
    "nehurduite": "nehurduit",
    "nehurduiți": "nehurduit",
    "nehuruită": "nehuruit",
    "nehuruite": "nehuruit",
    "nehuruiți": "nehuruit",
    "nehutupită": "nehutupit",
    "nehutupite": "nehutupit",
    "nehutupiți": "nehutupit",
    "nehuțuțată": "nehuțuțat",
    "nehuțuțate": "nehuțuțat",
    "nehuțuțați": "nehuțuțat",
    "nehuzdupată": "nehuzdupat",
    "nehuzdupate": "nehuzdupat",
    "nehuzdupați": "nehuzdupat",
    "nehuzurită": "nehuzurit",
    "nehuzurite": "nehuzurit",
    "nehuzuriți": "nehuzurit",
    "neica": "neică",
    "neicha": "neică",
    "neichă": "neică",
    "neichii": "neică",
    "neicii": "neică",
    "neicnită": "neicnit",
    "neicnite": "neicnit",
    "neicniți": "neicnit",
    "neiculița": "neiculiță",
    "neiculițăl": "neiculiță",
    "neiculițălui": "neiculiță",
    "neiculiței": "neiculiță",
    "neiculiții": "neiculiță",
    "neicușori": "neicușor",
    "neicușorii": "neicușor",
    "neicușorilor": "neicușor",
    "neicușorul": "neicușor",
    "neicușorului": "neicușor",
    "neicuța": "neicuță",
    "neicuțăl": "neicuță",
    "neicuțălui": "neicuță",
    "neicuței": "neicuță",
    "neicuții": "neicuță",
    "neidealizată": "neidealizat",
    "neidealizate": "neidealizat",
    "neidealizați": "neidealizat",
    "neidentica": "neidentic",
    "neidentică": "neidentic",
    "neidentice": "neidentic",
    "neidenticei": "neidentic",
    "neidenticele": "neidentic",
    "neidenticelor": "neidentic",
    "neidentici": "neidentic",
    "neidenticii": "neidentic",
    "neidenticilor": "neidentic",
    "neidenticul": "neidentic",
    "neidenticului": "neidentic",
    "neidentificabila": "neidentificabil",
    "neidentificabilă": "neidentificabil",
    "neidentificabile": "neidentificabil",
    "neidentificabilei": "neidentificabil",
    "neidentificabilele": "neidentificabil",
    "neidentificabilelor": "neidentificabil",
    "neidentificabili": "neidentificabil",
    "neidentificabilii": "neidentificabil",
    "neidentificabililor": "neidentificabil",
    "neidentificabilul": "neidentificabil",
    "neidentificabilului": "neidentificabil",
    "neidentificată": "neidentificat",
    "neidentificate": "neidentificat",
    "neidentificați": "neidentificat",
    "neidilizată": "neidilizat",
    "neidilizate": "neidilizat",
    "neidilizați": "neidilizat",
    "neidiotizată": "neidiotizat",
    "neidiotizate": "neidiotizat",
    "neidiotizați": "neidiotizat",
    "neidolatrizată": "neidolatrizat",
    "neidolatrizate": "neidolatrizat",
    "neidolatrizați": "neidolatrizat",
    "neieftinită": "neieftinit",
    "neieftinite": "neieftinit",
    "neieftiniți": "neieftinit",
    "neierarhizată": "neierarhizat",
    "neierarhizate": "neierarhizat",
    "neierarhizați": "neierarhizat",
    "neiernată": "neiernat",
    "neiernate": "neiernat",
    "neiernați": "neiernat",
    "neiertata": "neiertat",
    "neiertată": "neiertat",
    "neiertate": "neiertat",
    "neiertatei": "neiertat",
    "neiertatele": "neiertat",
    "neiertatelor": "neiertat",
    "neiertați": "neiertat",
    "neiertații": "neiertat",
    "neiertaților": "neiertat",
    "neiertatul": "neiertat",
    "neiertatului": "neiertat",
    "neiertătoare": "neiertător",
    "neiertătoarea": "neiertător",
    "neiertătoarei": "neiertător",
    "neiertătoarele": "neiertător",
    "neiertătoarelor": "neiertător",
    "neiertători": "neiertător",
    "neiertătorii": "neiertător",
    "neiertătorilor": "neiertător",
    "neiertătorul": "neiertător",
    "neiertătorului": "neiertător",
    "neieșită": "neieșit",
    "neieșite": "neieșit",
    "neieșiți": "neieșit",
    "neiezită": "neiezit",
    "neiezite": "neiezit",
    "neieziți": "neiezit",
    "neignorată": "neignorat",
    "neignorate": "neignorat",
    "neignorați": "neignorat",
    "neilegalizată": "neilegalizat",
    "neilegalizate": "neilegalizat",
    "neilegalizați": "neilegalizat",
    "neiluminată": "neiluminat",
    "neiluminate": "neiluminat",
    "neiluminați": "neiluminat",
    "neilustrata": "neilustrat",
    "neilustrată": "neilustrat",
    "neilustrate": "neilustrat",
    "neilustratei": "neilustrat",
    "neilustratele": "neilustrat",
    "neilustratelor": "neilustrat",
    "neilustrați": "neilustrat",
    "neilustrații": "neilustrat",
    "neilustraților": "neilustrat",
    "neilustratul": "neilustrat",
    "neilustratului": "neilustrat",
    "neiluzionată": "neiluzionat",
    "neiluzionate": "neiluzionat",
    "neiluzionați": "neiluzionat",
    "neimaginata": "neimaginat",
    "neimaginată": "neimaginat",
    "neimaginate": "neimaginat",
    "neimaginatei": "neimaginat",
    "neimaginatele": "neimaginat",
    "neimaginatelor": "neimaginat",
    "neimaginați": "neimaginat",
    "neimaginații": "neimaginat",
    "neimaginaților": "neimaginat",
    "neimaginatul": "neimaginat",
    "neimaginatului": "neimaginat",
    "neîmbâcsită": "neîmbâcsit",
    "neîmbâcsite": "neîmbâcsit",
    "neîmbâcsiți": "neîmbâcsit",
    "neîmbăiată": "neîmbăiat",
    "neîmbăiate": "neîmbăiat",
    "neîmbăiați": "neîmbăiat",
    "neîmbălată": "neîmbălat",
    "neîmbălate": "neîmbălat",
    "neîmbălați": "neîmbălat",
    "neîmbăloșată": "neîmbăloșat",
    "neîmbăloșate": "neîmbăloșat",
    "neîmbăloșați": "neîmbăloșat",
    "neîmbălsămată": "neîmbălsămat",
    "neîmbălsămate": "neîmbălsămat",
    "neîmbălsămați": "neîmbălsămat",
    "neîmbărbătată": "neîmbărbătat",
    "neîmbărbătate": "neîmbărbătat",
    "neîmbărbătați": "neîmbărbătat",
    "neîmbarcată": "neîmbarcat",
    "neîmbarcate": "neîmbarcat",
    "neîmbarcați": "neîmbarcat",
    "neîmbârligată": "neîmbârligat",
    "neîmbârligate": "neîmbârligat",
    "neîmbârligați": "neîmbârligat",
    "neîmbătată": "neîmbătat",
    "neîmbătate": "neîmbătat",
    "neîmbătați": "neîmbătat",
    "neîmbățoșată": "neîmbățoșat",
    "neîmbățoșate": "neîmbățoșat",
    "neîmbățoșați": "neîmbățoșat",
    "neîmbătrânită": "neîmbătrânit",
    "neîmbătrânite": "neîmbătrânit",
    "neîmbătrâniți": "neîmbătrânit",
    "neimbecilizată": "neimbecilizat",
    "neimbecilizate": "neimbecilizat",
    "neimbecilizați": "neimbecilizat",
    "neîmbelșugata": "neîmbelșugat",
    "neîmbelșugată": "neîmbelșugat",
    "neîmbelșugate": "neîmbelșugat",
    "neîmbelșugatei": "neîmbelșugat",
    "neîmbelșugatele": "neîmbelșugat",
    "neîmbelșugatelor": "neîmbelșugat",
    "neîmbelșugați": "neîmbelșugat",
    "neîmbelșugații": "neîmbelșugat",
    "neîmbelșugaților": "neîmbelșugat",
    "neîmbelșugatul": "neîmbelșugat",
    "neîmbelșugatului": "neîmbelșugat",
    "neîmbiată": "neîmbiat",
    "neîmbiate": "neîmbiat",
    "neîmbiați": "neîmbiat",
    "neîmbibată": "neîmbibat",
    "neîmbibate": "neîmbibat",
    "neîmbibați": "neîmbibat",
    "neîmbinată": "neîmbinat",
    "neîmbinate": "neîmbinat",
    "neîmbinați": "neîmbinat",
    "neîmblănita": "neîmblănit",
    "neîmblănită": "neîmblănit",
    "neîmblănite": "neîmblănit",
    "neîmblănitei": "neîmblănit",
    "neîmblănitele": "neîmblănit",
    "neîmblănitelor": "neîmblănit",
    "neîmblăniți": "neîmblănit",
    "neîmblăniții": "neîmblănit",
    "neîmblăniților": "neîmblănit",
    "neîmblănitul": "neîmblănit",
    "neîmblănitului": "neîmblănit",
    "neîmblânzita": "neîmblânzit",
    "neîmblânzită": "neîmblânzit",
    "neîmblânzite": "neîmblânzit",
    "neîmblânzitei": "neîmblânzit",
    "neîmblânzitele": "neîmblânzit",
    "neîmblânzitelor": "neîmblânzit",
    "neîmblânziți": "neîmblânzit",
    "neîmblânziții": "neîmblânzit",
    "neîmblânziților": "neîmblânzit",
    "neîmblânzitul": "neîmblânzit",
    "neîmblânzitului": "neîmblânzit",
    "neîmbobocită": "neîmbobocit",
    "neîmbobocite": "neîmbobocit",
    "neîmbobociți": "neîmbobocit",
    "neîmbogățită": "neîmbogățit",
    "neîmbogățite": "neîmbogățit",
    "neîmbogățiți": "neîmbogățit",
    "neîmbolbojită": "neîmbolbojit",
    "neîmbolbojite": "neîmbolbojit",
    "neîmbolbojiți": "neîmbolbojit",
    "neîmboldită": "neîmboldit",
    "neîmboldite": "neîmboldit",
    "neîmboldiți": "neîmboldit",
    "neîmbolnăvită": "neîmbolnăvit",
    "neîmbolnăvite": "neîmbolnăvit",
    "neîmbolnăviți": "neîmbolnăvit",
    "neîmbrăcată": "neîmbrăcat",
    "neîmbrăcate": "neîmbrăcat",
    "neîmbrăcați": "neîmbrăcat",
    "neîmbrâncită": "neîmbrâncit",
    "neîmbrâncite": "neîmbrâncit",
    "neîmbrânciți": "neîmbrâncit",
    "neîmbrățișată": "neîmbrățișat",
    "neîmbrățișate": "neîmbrățișat",
    "neîmbrățișați": "neîmbrățișat",
    "neîmbrobodită": "neîmbrobodit",
    "neîmbrobodite": "neîmbrobodit",
    "neîmbrobodiți": "neîmbrobodit",
    "neîmbucată": "neîmbucat",
    "neîmbucate": "neîmbucat",
    "neîmbucați": "neîmbucat",
    "neîmbucătățită": "neîmbucătățit",
    "neîmbucătățite": "neîmbucătățit",
    "neîmbucătățiți": "neîmbucătățit",
    "neîmbucățită": "neîmbucățit",
    "neîmbucățite": "neîmbucățit",
    "neîmbucățiți": "neîmbucățit",
    "neîmbucurată": "neîmbucurat",
    "neîmbucurate": "neîmbucurat",
    "neîmbucurați": "neîmbucurat",
    "neîmbufnata": "neîmbufnat",
    "neîmbufnată": "neîmbufnat",
    "neîmbufnate": "neîmbufnat",
    "neîmbufnatei": "neîmbufnat",
    "neîmbufnatele": "neîmbufnat",
    "neîmbufnatelor": "neîmbufnat",
    "neîmbufnați": "neîmbufnat",
    "neîmbufnații": "neîmbufnat",
    "neîmbufnaților": "neîmbufnat",
    "neîmbufnatul": "neîmbufnat",
    "neîmbufnatului": "neîmbufnat",
    "neîmbuibată": "neîmbuibat",
    "neîmbuibate": "neîmbuibat",
    "neîmbuibați": "neîmbuibat",
    "neîmbujorată": "neîmbujorat",
    "neîmbujorate": "neîmbujorat",
    "neîmbujorați": "neîmbujorat",
    "neîmbulzită": "neîmbulzit",
    "neîmbulzite": "neîmbulzit",
    "neîmbulziți": "neîmbulzit",
    "neîmbunată": "neîmbunat",
    "neîmbunate": "neîmbunat",
    "neîmbunați": "neîmbunat",
    "neîmbunătățită": "neîmbunătățit",
    "neîmbunătățite": "neîmbunătățit",
    "neîmbunătățiți": "neîmbunătățit",
    "neîmburghezită": "neîmburghezit",
    "neîmburghezite": "neîmburghezit",
    "neîmburgheziți": "neîmburghezit",
    "neîmbuteliată": "neîmbuteliat",
    "neîmbuteliate": "neîmbuteliat",
    "neîmbuteliați": "neîmbuteliat",
    "neimigrată": "neimigrat",
    "neimigrate": "neimigrat",
    "neimigrați": "neimigrat",
    "neimitabila": "neimitabil",
    "neimitabilă": "neimitabil",
    "neimitabile": "neimitabil",
    "neimitabilei": "neimitabil",
    "neimitabilele": "neimitabil",
    "neimitabilelor": "neimitabil",
    "neimitabili": "neimitabil",
    "neimitabilii": "neimitabil",
    "neimitabililor": "neimitabil",
    "neimitabilul": "neimitabil",
    "neimitabilului": "neimitabil",
    "neimitată": "neimitat",
    "neimitate": "neimitat",
    "neimitați": "neimitat",
    "neimobilizată": "neimobilizat",
    "neimobilizate": "neimobilizat",
    "neimobilizați": "neimobilizat",
    "neimolată": "neimolat",
    "neimolate": "neimolat",
    "neimolați": "neimolat",
    "neimortalizată": "neimortalizat",
    "neimortalizate": "neimortalizat",
    "neimortalizați": "neimortalizat",
    "neîmpăcata": "neîmpăcat",
    "neîmpăcată": "neîmpăcat",
    "neîmpăcate": "neîmpăcat",
    "neîmpăcatei": "neîmpăcat",
    "neîmpăcatele": "neîmpăcat",
    "neîmpăcatelor": "neîmpăcat",
    "neîmpăcați": "neîmpăcat",
    "neîmpăcații": "neîmpăcat",
    "neîmpăcaților": "neîmpăcat",
    "neîmpăcatul": "neîmpăcat",
    "neîmpăcatului": "neîmpăcat",
    "neîmpachetată": "neîmpachetat",
    "neîmpachetate": "neîmpachetat",
    "neîmpachetați": "neîmpachetat",
    "neimpacientată": "neimpacientat",
    "neimpacientate": "neimpacientat",
    "neimpacientați": "neimpacientat",
    "neîmpăciuită": "neîmpăciuit",
    "neîmpăciuite": "neîmpăciuit",
    "neîmpăciuiți": "neîmpăciuit",
    "neîmpădurită": "neîmpădurit",
    "neîmpădurite": "neîmpădurit",
    "neîmpăduriți": "neîmpădurit",
    "neîmpăiata": "neîmpăiat",
    "neîmpăiată": "neîmpăiat",
    "neîmpăiate": "neîmpăiat",
    "neîmpăiatei": "neîmpăiat",
    "neîmpăiatele": "neîmpăiat",
    "neîmpăiatelor": "neîmpăiat",
    "neîmpăiați": "neîmpăiat",
    "neîmpăiații": "neîmpăiat",
    "neîmpăiaților": "neîmpăiat",
    "neîmpăiatul": "neîmpăiat",
    "neîmpăiatului": "neîmpăiat",
    "neîmpăienjenită": "neîmpăienjenit",
    "neîmpăienjenite": "neîmpăienjenit",
    "neîmpăienjeniți": "neîmpăienjenit",
    "neîmpământenită": "neîmpământenit",
    "neîmpământenite": "neîmpământenit",
    "neîmpământeniți": "neîmpământenit",
    "neîmpănată": "neîmpănat",
    "neîmpănate": "neîmpănat",
    "neîmpănați": "neîmpănat",
    "neîmpânzită": "neîmpânzit",
    "neîmpânzite": "neîmpânzit",
    "neîmpânziți": "neîmpânzit",
    "neîmpărățită": "neîmpărățit",
    "neîmpărățite": "neîmpărățit",
    "neîmpărățiți": "neîmpărățit",
    "neîmpăroșată": "neîmpăroșat",
    "neîmpăroșate": "neîmpăroșat",
    "neîmpăroșați": "neîmpăroșat",
    "neîmpărtășită": "neîmpărtășit",
    "neîmpărtășite": "neîmpărtășit",
    "neîmpărtășiți": "neîmpărtășit",
    "neîmpărțită": "neîmpărțit",
    "neîmpărțite": "neîmpărțit",
    "neîmpărțiți": "neîmpărțit",
    "neîmpătimită": "neîmpătimit",
    "neîmpătimite": "neîmpătimit",
    "neîmpătimiți": "neîmpătimit",
    "neîmpătrită": "neîmpătrit",
    "neîmpătrite": "neîmpătrit",
    "neîmpătriți": "neîmpătrit",
    "neîmpăturită": "neîmpăturit",
    "neîmpăturite": "neîmpăturit",
    "neîmpăturiți": "neîmpăturit",
    "neîmpăunată": "neîmpăunat",
    "neîmpăunate": "neîmpăunat",
    "neîmpăunați": "neîmpăunat",
    "neîmpelițată": "neîmpelițat",
    "neîmpelițate": "neîmpelițat",
    "neîmpelițați": "neîmpelițat",
    "neimpermeabilizată": "neimpermeabilizat",
    "neimpermeabilizate": "neimpermeabilizat",
    "neimpermeabilizați": "neimpermeabilizat",
    "neimpestată": "neimpestat",
    "neimpestate": "neimpestat",
    "neimpestați": "neimpestat",
    "neîmpestrițată": "neîmpestrițat",
    "neîmpestrițate": "neîmpestrițat",
    "neîmpestrițați": "neîmpestrițat",
    "neîmpețită": "neîmpețit",
    "neîmpețite": "neîmpețit",
    "neîmpețiți": "neîmpețit",
    "neîmpiciorogată": "neîmpiciorogat",
    "neîmpiciorogate": "neîmpiciorogat",
    "neîmpiciorogați": "neîmpiciorogat",
    "neîmpiedicată": "neîmpiedicat",
    "neîmpiedicate": "neîmpiedicat",
    "neîmpiedicați": "neîmpiedicat",
    "neîmpieptoșată": "neîmpieptoșat",
    "neîmpieptoșate": "neîmpieptoșat",
    "neîmpieptoșați": "neîmpieptoșat",
    "neimpietată": "neimpietat",
    "neimpietate": "neimpietat",
    "neimpietați": "neimpietat",
    "neîmpietrita": "neîmpietrit",
    "neîmpietrită": "neîmpietrit",
    "neîmpietrite": "neîmpietrit",
    "neîmpietritei": "neîmpietrit",
    "neîmpietritele": "neîmpietrit",
    "neîmpietritelor": "neîmpietrit",
    "neîmpietriți": "neîmpietrit",
    "neîmpietriții": "neîmpietrit",
    "neîmpietriților": "neîmpietrit",
    "neîmpietritul": "neîmpietrit",
    "neîmpietritului": "neîmpietrit",
    "neîmpilată": "neîmpilat",
    "neîmpilate": "neîmpilat",
    "neîmpilați": "neîmpilat",
    "neîmpinsă": "neîmpins",
    "neîmpinse": "neîmpins",
    "neîmpinși": "neîmpins",
    "neimplantată": "neimplantat",
    "neimplantate": "neimplantat",
    "neimplantați": "neimplantat",
    "neîmplântată": "neîmplântat",
    "neîmplântate": "neîmplântat",
    "neîmplântați": "neîmplântat",
    "neîmpleticită": "neîmpleticit",
    "neîmpleticite": "neîmpleticit",
    "neîmpleticiți": "neîmpleticit",
    "neîmpletită": "neîmpletit",
    "neîmpletite": "neîmpletit",
    "neîmpletiți": "neîmpletit",
    "neimplicarea": "neimplicare",
    "neimplicari": "neimplicare",
    "neimplicarii": "neimplicare",
    "neimplicarile": "neimplicare",
    "neimplicarilor": "neimplicare",
    "neimplicată": "neimplicat",
    "neimplicate": "neimplicat",
    "neimplicați": "neimplicat",
    "neîmplinirea": "neîmplinire",
    "neîmpliniri": "neîmplinire",
    "neîmplinirii": "neîmplinire",
    "neîmplinirile": "neîmplinire",
    "neîmplinirilor": "neîmplinire",
    "neîmplinita": "neîmplinit",
    "neîmplinită": "neîmplinit",
    "neîmplinite": "neîmplinit",
    "neîmplinitei": "neîmplinit",
    "neîmplinitele": "neîmplinit",
    "neîmplinitelor": "neîmplinit",
    "neîmpliniți": "neîmplinit",
    "neîmpliniții": "neîmplinit",
    "neîmpliniților": "neîmplinit",
    "neîmplinitul": "neîmplinit",
    "neîmplinitului": "neîmplinit",
    "neimplorată": "neimplorat",
    "neimplorate": "neimplorat",
    "neimplorați": "neimplorat",
    "neîmpodobită": "neîmpodobit",
    "neîmpodobite": "neîmpodobit",
    "neîmpodobiți": "neîmpodobit",
    "neîmpopoțonată": "neîmpopoțonat",
    "neîmpopoțonate": "neîmpopoțonat",
    "neîmpopoțonați": "neîmpopoțonat",
    "neimportanta": "neimportant",
    "neimportantă": "neimportant",
    "neimportante": "neimportant",
    "neimportantei": "neimportant",
    "neimportantele": "neimportant",
    "neimportantelor": "neimportant",
    "neimportanți": "neimportant",
    "neimportanții": "neimportant",
    "neimportanților": "neimportant",
    "neimportantul": "neimportant",
    "neimportantului": "neimportant",
    "neimportată": "neimportat",
    "neimportate": "neimportat",
    "neimportați": "neimportat",
    "neimportunată": "neimportunat",
    "neimportunate": "neimportunat",
    "neimportunați": "neimportunat",
    "neîmpotmolită": "neîmpotmolit",
    "neîmpotmolite": "neîmpotmolit",
    "neîmpotmoliți": "neîmpotmolit",
    "neîmpotrivită": "neîmpotrivit",
    "neîmpotrivite": "neîmpotrivit",
    "neîmpotriviți": "neîmpotrivit",
    "neîmpovărată": "neîmpovărat",
    "neîmpovărate": "neîmpovărat",
    "neîmpovărați": "neîmpovărat",
    "neimpozabila": "neimpozabil",
    "neimpozabilă": "neimpozabil",
    "neimpozabile": "neimpozabil",
    "neimpozabilei": "neimpozabil",
    "neimpozabilele": "neimpozabil",
    "neimpozabilelor": "neimpozabil",
    "neimpozabili": "neimpozabil",
    "neimpozabilii": "neimpozabil",
    "neimpozabililor": "neimpozabil",
    "neimpozabilul": "neimpozabil",
    "neimpozabilului": "neimpozabil",
    "neîmprăștiată": "neîmprăștiat",
    "neîmprăștiate": "neîmprăștiat",
    "neîmprăștiați": "neîmprăștiat",
    "neimpregnată": "neimpregnat",
    "neimpregnate": "neimpregnat",
    "neimpregnați": "neimpregnat",
    "neîmprejmuită": "neîmprejmuit",
    "neîmprejmuite": "neîmprejmuit",
    "neîmprejmuiți": "neîmprejmuit",
    "neîmprejurată": "neîmprejurat",
    "neîmprejurate": "neîmprejurat",
    "neîmprejurați": "neîmprejurat",
    "neimpresionată": "neimpresionat",
    "neimpresionate": "neimpresionat",
    "neimpresionați": "neimpresionat",
    "neîmpresurată": "neîmpresurat",
    "neîmpresurate": "neîmpresurat",
    "neîmpresurați": "neîmpresurat",
    "neîmpreunată": "neîmpreunat",
    "neîmpreunate": "neîmpreunat",
    "neîmpreunați": "neîmpreunat",
    "neîmpricinată": "neîmpricinat",
    "neîmpricinate": "neîmpricinat",
    "neîmpricinați": "neîmpricinat",
    "neîmprietenită": "neîmprietenit",
    "neîmprietenite": "neîmprietenit",
    "neîmprieteniți": "neîmprietenit",
    "neimprimata": "neimprimat",
    "neimprimată": "neimprimat",
    "neimprimate": "neimprimat",
    "neimprimatei": "neimprimat",
    "neimprimatele": "neimprimat",
    "neimprimatelor": "neimprimat",
    "neimprimați": "neimprimat",
    "neimprimații": "neimprimat",
    "neimprimaților": "neimprimat",
    "neimprimatul": "neimprimat",
    "neimprimatului": "neimprimat",
    "neîmprimăvărată": "neîmprimăvărat",
    "neîmprimăvărate": "neîmprimăvărat",
    "neîmprimăvărați": "neîmprimăvărat",
    "neîmproprietărită": "neîmproprietărit",
    "neîmproprietărite": "neîmproprietărit",
    "neîmproprietăriți": "neîmproprietărit",
    "neîmproșcată": "neîmproșcat",
    "neîmproșcate": "neîmproșcat",
    "neîmproșcați": "neîmproșcat",
    "neîmprospătată": "neîmprospătat",
    "neîmprospătate": "neîmprospătat",
    "neîmprospătați": "neîmprospătat",
    "neimprovizată": "neimprovizat",
    "neimprovizate": "neimprovizat",
    "neimprovizați": "neimprovizat",
    "neîmprumutată": "neîmprumutat",
    "neîmprumutate": "neîmprumutat",
    "neîmprumutați": "neîmprumutat",
    "neîmpuiată": "neîmpuiat",
    "neîmpuiate": "neîmpuiat",
    "neîmpuiați": "neîmpuiat",
    "neimpulsionată": "neimpulsionat",
    "neimpulsionate": "neimpulsionat",
    "neimpulsionați": "neimpulsionat",
    "neîmpunsă": "neîmpuns",
    "neîmpunse": "neîmpuns",
    "neîmpunși": "neîmpuns",
    "neîmpurpurată": "neîmpurpurat",
    "neîmpurpurate": "neîmpurpurat",
    "neîmpurpurați": "neîmpurpurat",
    "neimpusă": "neimpus",
    "neimpuse": "neimpus",
    "neimpuși": "neimpus",
    "neîmpușcată": "neîmpușcat",
    "neîmpușcate": "neîmpușcat",
    "neîmpușcați": "neîmpușcat",
    "neimputată": "neimputat",
    "neimputate": "neimputat",
    "neimputați": "neimputat",
    "neîmputernicită": "neîmputernicit",
    "neîmputernicite": "neîmputernicit",
    "neîmputerniciți": "neîmputernicit",
    "neîmpuținată": "neîmpuținat",
    "neîmpuținate": "neîmpuținat",
    "neîmpuținați": "neîmpuținat",
    "neîmpuțita": "neîmpuțit",
    "neîmpuțită": "neîmpuțit",
    "neîmpuțite": "neîmpuțit",
    "neîmpuțitei": "neîmpuțit",
    "neîmpuțitele": "neîmpuțit",
    "neîmpuțitelor": "neîmpuțit",
    "neîmpuțiți": "neîmpuțit",
    "neîmpuțiții": "neîmpuțit",
    "neîmpuțiților": "neîmpuțit",
    "neîmpuțitul": "neîmpuțit",
    "neîmpuțitului": "neîmpuțit",
    "neimunizată": "neimunizat",
    "neimunizate": "neimunizat",
    "neimunizați": "neimunizat",
    "neînăbușită": "neînăbușit",
    "neînăbușite": "neînăbușit",
    "neînăbușiți": "neînăbușit",
    "neînăclăită": "neînăclăit",
    "neînăclăite": "neînăclăit",
    "neînăclăiți": "neînăclăit",
    "neînăcrită": "neînăcrit",
    "neînăcrite": "neînăcrit",
    "neînăcriți": "neînăcrit",
    "neînădușită": "neînădușit",
    "neînădușite": "neînădușit",
    "neînădușiți": "neînădușit",
    "neînaintata": "neînaintat",
    "neînaintată": "neînaintat",
    "neînaintate": "neînaintat",
    "neînaintatei": "neînaintat",
    "neînaintatele": "neînaintat",
    "neînaintatelor": "neînaintat",
    "neînaintați": "neînaintat",
    "neînaintații": "neînaintat",
    "neînaintaților": "neînaintat",
    "neînaintatul": "neînaintat",
    "neînaintatului": "neînaintat",
    "neînălbăstrită": "neînălbăstrit",
    "neînălbăstrite": "neînălbăstrit",
    "neînălbăstriți": "neînălbăstrit",
    "neînălbită": "neînălbit",
    "neînălbite": "neînălbit",
    "neînălbiți": "neînălbit",
    "neînălțată": "neînălțat",
    "neînălțate": "neînălțat",
    "neînălțați": "neînălțat",
    "neînamorată": "neînamorat",
    "neînamorate": "neînamorat",
    "neînamorați": "neînamorat",
    "neînapoiata": "neînapoiat",
    "neînapoiată": "neînapoiat",
    "neînapoiate": "neînapoiat",
    "neînapoiatei": "neînapoiat",
    "neînapoiatele": "neînapoiat",
    "neînapoiatelor": "neînapoiat",
    "neînapoiați": "neînapoiat",
    "neînapoiații": "neînapoiat",
    "neînapoiaților": "neînapoiat",
    "neînapoiatul": "neînapoiat",
    "neînapoiatului": "neînapoiat",
    "neînaripată": "neînaripat",
    "neînaripate": "neînaripat",
    "neînaripați": "neînaripat",
    "neînarmată": "neînarmat",
    "neînarmate": "neînarmat",
    "neînarmați": "neînarmat",
    "neînăsprită": "neînăsprit",
    "neînăsprite": "neînăsprit",
    "neînăspriți": "neînăsprit",
    "neinaugurată": "neinaugurat",
    "neinaugurate": "neinaugurat",
    "neinaugurați": "neinaugurat",
    "neînavuțită": "neînavuțit",
    "neînavuțite": "neînavuțit",
    "neînavuțiți": "neînavuțit",
    "neîncadrată": "neîncadrat",
    "neîncadrate": "neîncadrat",
    "neîncadrați": "neîncadrat",
    "neîncăierată": "neîncăierat",
    "neîncăierate": "neîncăierat",
    "neîncăierați": "neîncăierat",
    "neîncâinată": "neîncâinat",
    "neîncâinate": "neîncâinat",
    "neîncâinați": "neîncâinat",
    "neîncălcată": "neîncălcat",
    "neîncălcate": "neîncălcat",
    "neîncălcați": "neîncălcat",
    "neîncâlcita": "neîncâlcit",
    "neîncâlcită": "neîncâlcit",
    "neîncâlcite": "neîncâlcit",
    "neîncâlcitei": "neîncâlcit",
    "neîncâlcitele": "neîncâlcit",
    "neîncâlcitelor": "neîncâlcit",
    "neîncâlciți": "neîncâlcit",
    "neîncâlciții": "neîncâlcit",
    "neîncâlciților": "neîncâlcit",
    "neîncâlcitul": "neîncâlcit",
    "neîncâlcitului": "neîncâlcit",
    "neîncălecată": "neîncălecat",
    "neîncălecate": "neîncălecat",
    "neîncălecați": "neîncălecat",
    "neîncălțată": "neîncălțat",
    "neîncălțate": "neîncălțat",
    "neîncălțați": "neîncălțat",
    "neîncălușată": "neîncălușat",
    "neîncălușate": "neîncălușat",
    "neîncălușați": "neîncălușat",
    "neîncălzita": "neîncălzit",
    "neîncălzită": "neîncălzit",
    "neîncălzite": "neîncălzit",
    "neîncălzitei": "neîncălzit",
    "neîncălzitele": "neîncălzit",
    "neîncălzitelor": "neîncălzit",
    "neîncălziți": "neîncălzit",
    "neîncălziții": "neîncălzit",
    "neîncălziților": "neîncălzit",
    "neîncălzitul": "neîncălzit",
    "neîncălzitului": "neîncălzit",
    "neîncântata": "neîncântat",
    "neîncântată": "neîncântat",
    "neîncântate": "neîncântat",
    "neîncântatei": "neîncântat",
    "neîncântatele": "neîncântat",
    "neîncântatelor": "neîncântat",
    "neîncântați": "neîncântat",
    "neîncântații": "neîncântat",
    "neîncântaților": "neîncântat",
    "neîncântatul": "neîncântat",
    "neîncântatului": "neîncântat",
    "neîncăpățânata": "neîncăpățânat",
    "neîncăpățânată": "neîncăpățânat",
    "neîncăpățânate": "neîncăpățânat",
    "neîncăpățânatei": "neîncăpățânat",
    "neîncăpățânatele": "neîncăpățânat",
    "neîncăpățânatelor": "neîncăpățânat",
    "neîncăpățânați": "neîncăpățânat",
    "neîncăpățânații": "neîncăpățânat",
    "neîncăpățânatul": "neîncăpățânat",
    "neîncăpățânatului": "neîncăpățânat",
    "neîncapsulată": "neîncapsulat",
    "neîncapsulate": "neîncapsulat",
    "neîncapsulați": "neîncapsulat",
    "neîncăpuită": "neîncăpuit",
    "neîncăpuite": "neîncăpuit",
    "neîncăpuiți": "neîncăpuit",
    "neîncăpușită": "neîncăpușit",
    "neîncăpușite": "neîncăpușit",
    "neîncăpușiți": "neîncăpușit",
    "neîncăpută": "neîncăput",
    "neîncăpute": "neîncăput",
    "neîncăpuți": "neîncăput",
    "neîncăputată": "neîncăputat",
    "neîncăputate": "neîncăputat",
    "neîncăputați": "neîncăputat",
    "neîncărcata": "neîncărcat",
    "neîncărcată": "neîncărcat",
    "neîncărcate": "neîncărcat",
    "neîncărcatei": "neîncărcat",
    "neîncărcatele": "neîncărcat",
    "neîncărcatelor": "neîncărcat",
    "neîncărcați": "neîncărcat",
    "neîncărcații": "neîncărcat",
    "neîncărcaților": "neîncărcat",
    "neîncărcatul": "neîncărcat",
    "neîncărcatului": "neîncărcat",
    "neîncarcerată": "neîncarcerat",
    "neîncarcerate": "neîncarcerat",
    "neîncarcerați": "neîncarcerat",
    "neîncârdoșată": "neîncârdoșat",
    "neîncârdoșate": "neîncârdoșat",
    "neîncârdoșați": "neîncârdoșat",
    "neîncârduită": "neîncârduit",
    "neîncârduite": "neîncârduit",
    "neîncârduiți": "neîncârduit",
    "neîncârligată": "neîncârligat",
    "neîncârligate": "neîncârligat",
    "neîncârligați": "neîncârligat",
    "neîncârlionțată": "neîncârlionțat",
    "neîncârlionțate": "neîncârlionțat",
    "neîncârlionțați": "neîncârlionțat",
    "neincarnată": "neincarnat",
    "neincarnate": "neincarnat",
    "neincarnați": "neincarnat",
    "neîncărnată": "neîncărnat",
    "neîncărnate": "neîncărnat",
    "neîncărnați": "neîncărnat",
    "neîncartiruită": "neîncartiruit",
    "neîncartiruite": "neîncartiruit",
    "neîncartiruiți": "neîncartiruit",
    "neîncărunțita": "neîncărunțit",
    "neîncărunțită": "neîncărunțit",
    "neîncărunțite": "neîncărunțit",
    "neîncărunțitei": "neîncărunțit",
    "neîncărunțitele": "neîncărunțit",
    "neîncărunțitelor": "neîncărunțit",
    "neîncărunțiți": "neîncărunțit",
    "neîncărunțiții": "neîncărunțit",
    "neîncărunțiților": "neîncărunțit",
    "neîncărunțitul": "neîncărunțit",
    "neîncărunțitului": "neîncărunțit",
    "neîncasată": "neîncasat",
    "neîncasate": "neîncasat",
    "neîncasați": "neîncasat",
    "neîncastrată": "neîncastrat",
    "neîncastrate": "neîncastrat",
    "neîncastrați": "neîncastrat",
    "neîncătărămată": "neîncătărămat",
    "neîncătărămate": "neîncătărămat",
    "neîncătărămați": "neîncătărămat",
    "neîncătușată": "neîncătușat",
    "neîncătușate": "neîncătușat",
    "neîncătușați": "neîncătușat",
    "neîncazarmată": "neîncazarmat",
    "neîncazarmate": "neîncazarmat",
    "neîncazarmați": "neîncazarmat",
    "neincendiată": "neincendiat",
    "neincendiate": "neincendiat",
    "neincendiați": "neincendiat",
    "neînceperea": "neîncepere",
    "neînceperi": "neîncepere",
    "neînceperii": "neîncepere",
    "neînceperile": "neîncepere",
    "neînceperilor": "neîncepere",
    "neînceputa": "neînceput",
    "neîncepută": "neînceput",
    "neîncepute": "neînceput",
    "neînceputei": "neînceput",
    "neînceputele": "neînceput",
    "neînceputelor": "neînceput",
    "neîncepuți": "neînceput",
    "neîncepuții": "neînceput",
    "neîncepuților": "neînceput",
    "neînceputul": "neînceput",
    "neînceputului": "neînceput",
    "neîncercănată": "neîncercănat",
    "neîncercănate": "neîncercănat",
    "neîncercănați": "neîncercănat",
    "neîncercată": "neîncercat",
    "neîncercate": "neîncercat",
    "neîncercați": "neîncercat",
    "neîncercuită": "neîncercuit",
    "neîncercuite": "neîncercuit",
    "neîncercuiți": "neîncercuit",
    "neîncetata": "neîncetat",
    "neîncetată": "neîncetat",
    "neîncetate": "neîncetat",
    "neîncetatei": "neîncetat",
    "neîncetatele": "neîncetat",
    "neîncetatelor": "neîncetat",
    "neîncetați": "neîncetat",
    "neîncetații": "neîncetat",
    "neîncetaților": "neîncetat",
    "neîncetatul": "neîncetat",
    "neîncetatului": "neîncetat",
    "neîncetățenită": "neîncetățenit",
    "neîncetățenite": "neîncetățenit",
    "neîncetățeniți": "neîncetățenit",
    "neîncetinită": "neîncetinit",
    "neîncetinite": "neîncetinit",
    "neîncetiniți": "neîncetinit",
    "neîncețoșată": "neîncețoșat",
    "neînchegată": "neînchegat",
    "neînchegate": "neînchegat",
    "neînchegați": "neînchegat",
    "neîncheiată": "neîncheiat",
    "neîncheiate": "neîncheiat",
    "neîncheiați": "neîncheiat",
    "neînchiaburită": "neînchiaburit",
    "neînchiaburite": "neînchiaburit",
    "neînchiaburiți": "neînchiaburit",
    "neînchinată": "neînchinat",
    "neînchinate": "neînchinat",
    "neînchinați": "neînchinat",
    "neînchipuita": "neînchipuit",
    "neînchipuită": "neînchipuit",
    "neînchipuite": "neînchipuit",
    "neînchipuitei": "neînchipuit",
    "neînchipuitele": "neînchipuit",
    "neînchipuitelor": "neînchipuit",
    "neînchipuiți": "neînchipuit",
    "neînchipuiții": "neînchipuit",
    "neînchipuiților": "neînchipuit",
    "neînchipuitul": "neînchipuit",
    "neînchipuitului": "neînchipuit",
    "neînchircită": "neînchircit",
    "neînchircite": "neînchircit",
    "neînchirciți": "neînchircit",
    "neînchiriată": "neînchiriat",
    "neînchiriate": "neînchiriat",
    "neînchiriați": "neînchiriat",
    "neînchisa": "neînchis",
    "neînchisă": "neînchis",
    "neînchise": "neînchis",
    "neînchisei": "neînchis",
    "neînchisele": "neînchis",
    "neînchiselor": "neînchis",
    "neînchiși": "neînchis",
    "neînchișii": "neînchis",
    "neînchișilor": "neînchis",
    "neînchisul": "neînchis",
    "neînchisului": "neînchis",
    "neînchistată": "neînchistat",
    "neînchistate": "neînchistat",
    "neînchistați": "neînchistat",
    "neincinerată": "neincinerat",
    "neincinerate": "neincinerat",
    "neincinerați": "neincinerat",
    "neîncinsa": "neîncins",
    "neîncinsă": "neîncins",
    "neîncinse": "neîncins",
    "neîncinsei": "neîncins",
    "neîncinsele": "neîncins",
    "neîncinselor": "neîncins",
    "neîncinși": "neîncins",
    "neîncinșii": "neîncins",
    "neîncinșilor": "neîncins",
    "neîncinsul": "neîncins",
    "neîncinsului": "neîncins",
    "neincitată": "neincitat",
    "neincitate": "neincitat",
    "neincitați": "neincitat",
    "neînciudata": "neînciudat",
    "neînciudată": "neînciudat",
    "neînciudate": "neînciudat",
    "neînciudatei": "neînciudat",
    "neînciudatele": "neînciudat",
    "neînciudatelor": "neînciudat",
    "neînciudați": "neînciudat",
    "neînciudații": "neînciudat",
    "neînciudaților": "neînciudat",
    "neînciudatul": "neînciudat",
    "neînciudatului": "neînciudat",
    "neincizată": "neincizat",
    "neincizate": "neincizat",
    "neincizați": "neincizat",
    "neîncleiată": "neîncleiat",
    "neîncleiate": "neîncleiat",
    "neîncleiați": "neîncleiat",
    "neîncleștată": "neîncleștat",
    "neîncleștate": "neîncleștat",
    "neîncleștați": "neîncleștat",
    "neînclinata": "neînclinat",
    "neînclinată": "neînclinat",
    "neînclinate": "neînclinat",
    "neînclinatei": "neînclinat",
    "neînclinatele": "neînclinat",
    "neînclinatelor": "neînclinat",
    "neînclinați": "neînclinat",
    "neînclinații": "neînclinat",
    "neînclinaților": "neînclinat",
    "neînclinatul": "neînclinat",
    "neînclinatului": "neînclinat",
    "neinclusă": "neinclus",
    "neincluse": "neinclus",
    "neincluși": "neinclus",
    "neîncolăcită": "neîncolăcit",
    "neîncolăcite": "neîncolăcit",
    "neîncolăciți": "neîncolăcit",
    "neîncolonată": "neîncolonat",
    "neîncolonate": "neîncolonat",
    "neîncolonați": "neîncolonat",
    "neîncolțită": "neîncolțit",
    "neîncolțite": "neîncolțit",
    "neîncolțiți": "neîncolțit",
    "neincomodată": "neincomodat",
    "neincomodate": "neincomodat",
    "neincomodați": "neincomodat",
    "neîncondeiată": "neîncondeiat",
    "neîncondeiate": "neîncondeiat",
    "neîncondeiați": "neîncondeiat",
    "neînconjurată": "neînconjurat",
    "neînconjurate": "neînconjurat",
    "neînconjurați": "neînconjurat",
    "neîncontrată": "neîncontrat",
    "neîncontrate": "neîncontrat",
    "neîncontrați": "neîncontrat",
    "neîncopciată": "neîncopciat",
    "neîncopciate": "neîncopciat",
    "neîncopciați": "neîncopciat",
    "neîncordata": "neîncordat",
    "neîncordată": "neîncordat",
    "neîncordate": "neîncordat",
    "neîncordatei": "neîncordat",
    "neîncordatele": "neîncordat",
    "neîncordatelor": "neîncordat",
    "neîncordați": "neîncordat",
    "neîncordații": "neîncordat",
    "neîncordaților": "neîncordat",
    "neîncordatul": "neîncordat",
    "neîncordatului": "neîncordat",
    "neîncoronată": "neîncoronat",
    "neîncoronate": "neîncoronat",
    "neîncoronați": "neîncoronat",
    "neîncorporată": "neîncorporat",
    "neîncorporate": "neîncorporat",
    "neîncorporați": "neîncorporat",
    "neîncorsetată": "neîncorsetat",
    "neîncorsetate": "neîncorsetat",
    "neîncorsetați": "neîncorsetat",
    "neîncotoșmănată": "neîncotoșmănat",
    "neîncotoșmănate": "neîncotoșmănat",
    "neîncotoșmănați": "neîncotoșmănat",
    "neîncovoiata": "neîncovoiat",
    "neîncovoiată": "neîncovoiat",
    "neîncovoiate": "neîncovoiat",
    "neîncovoiatei": "neîncovoiat",
    "neîncovoiatele": "neîncovoiat",
    "neîncovoiatelor": "neîncovoiat",
    "neîncovoiați": "neîncovoiat",
    "neîncovoiații": "neîncovoiat",
    "neîncovoiaților": "neîncovoiat",
    "neîncovoiatul": "neîncovoiat",
    "neîncovoiatului": "neîncovoiat",
    "neîncovrigată": "neîncovrigat",
    "neîncovrigate": "neîncovrigat",
    "neîncovrigați": "neîncovrigat",
    "neîncrâncenată": "neîncrâncenat",
    "neîncrâncenate": "neîncrâncenat",
    "neîncrâncenați": "neîncrâncenat",
    "neîncrederea": "neîncredere",
    "neîncrederi": "neîncredere",
    "neîncrederii": "neîncredere",
    "neîncrederile": "neîncredere",
    "neîncrederilor": "neîncredere",
    "neîncredințată": "neîncredințat",
    "neîncredințate": "neîncredințat",
    "neîncredințați": "neîncredințat",
    "neîncremenită": "neîncremenit",
    "neîncremenite": "neîncremenit",
    "neîncremeniți": "neîncremenit",
    "neîncrestată": "neîncrestat",
    "neîncrestate": "neîncrestat",
    "neîncrestați": "neîncrestat",
    "neîncrețita": "neîncrețit",
    "neîncrețită": "neîncrețit",
    "neîncrețite": "neîncrețit",
    "neîncrețitei": "neîncrețit",
    "neîncrețitele": "neîncrețit",
    "neîncrețitelor": "neîncrețit",
    "neîncrețiți": "neîncrețit",
    "neîncrețiții": "neîncrețit",
    "neîncrețiților": "neîncrețit",
    "neîncrețitul": "neîncrețit",
    "neîncrețitului": "neîncrețit",
    "neîncrezătoare": "neîncrezător",
    "neîncrezătoarea": "neîncrezător",
    "neîncrezătoarei": "neîncrezător",
    "neîncrezătoarele": "neîncrezător",
    "neîncrezătoarelor": "neîncrezător",
    "neîncrezători": "neîncrezător",
    "neîncrezătorii": "neîncrezător",
    "neîncrezătorilor": "neîncrezător",
    "neîncrezătorul": "neîncrezător",
    "neîncrezătorului": "neîncrezător",
    "neîncrezuta": "neîncrezut",
    "neîncrezută": "neîncrezut",
    "neîncrezute": "neîncrezut",
    "neîncrezutei": "neîncrezut",
    "neîncrezutele": "neîncrezut",
    "neîncrezutelor": "neîncrezut",
    "neîncrezuți": "neîncrezut",
    "neîncrezuții": "neîncrezut",
    "neîncrezuților": "neîncrezut",
    "neîncrezutul": "neîncrezut",
    "neîncrezutului": "neîncrezut",
    "neincriminată": "neincriminat",
    "neincriminate": "neincriminat",
    "neincriminați": "neincriminat",
    "neîncropită": "neîncropit",
    "neîncropite": "neîncropit",
    "neîncropiți": "neîncropit",
    "neîncrucișată": "neîncrucișat",
    "neîncrucișate": "neîncrucișat",
    "neîncrucișați": "neîncrucișat",
    "neîncrucită": "neîncrucit",
    "neîncrucite": "neîncrucit",
    "neîncruciți": "neîncrucit",
    "neîncruntată": "neîncruntat",
    "neîncruntate": "neîncruntat",
    "neîncruntați": "neîncruntat",
    "neincrustată": "neincrustat",
    "neincrustate": "neincrustat",
    "neincrustați": "neincrustat",
    "neîncuiată": "neîncuiat",
    "neîncuiate": "neîncuiat",
    "neîncuiați": "neîncuiat",
    "neîncuibată": "neîncuibat",
    "neîncuibate": "neîncuibat",
    "neîncuibați": "neîncuibat",
    "neinculcată": "neinculcat",
    "neinculcate": "neinculcat",
    "neinculcați": "neinculcat",
    "neinculpată": "neinculpat",
    "neinculpate": "neinculpat",
    "neinculpați": "neinculpat",
    "neincumbată": "neincumbat",
    "neincumbate": "neincumbat",
    "neincumbați": "neincumbat",
    "neîncumetată": "neîncumetat",
    "neîncumetate": "neîncumetat",
    "neîncumetați": "neîncumetat",
    "neîncumetrită": "neîncumetrit",
    "neîncumetrite": "neîncumetrit",
    "neîncumetriți": "neîncumetrit",
    "neîncunoștințată": "neîncunoștințat",
    "neîncunoștințate": "neîncunoștințat",
    "neîncunoștințați": "neîncunoștințat",
    "neîncununată": "neîncununat",
    "neîncununate": "neîncununat",
    "neîncununați": "neîncununat",
    "neîncurajată": "neîncurajat",
    "neîncurajate": "neîncurajat",
    "neîncurajați": "neîncurajat",
    "neîncurată": "neîncurat",
    "neîncurate": "neîncurat",
    "neîncurați": "neîncurat",
    "neîncurcata": "neîncurcat",
    "neîncurcată": "neîncurcat",
    "neîncurcate": "neîncurcat",
    "neîncurcatei": "neîncurcat",
    "neîncurcatele": "neîncurcat",
    "neîncurcatelor": "neîncurcat",
    "neîncurcați": "neîncurcat",
    "neîncurcații": "neîncurcat",
    "neîncurcaților": "neîncurcat",
    "neîncurcatul": "neîncurcat",
    "neîncurcatului": "neîncurcat",
    "neîncurelată": "neîncurelat",
    "neîncurelate": "neîncurelat",
    "neîncurelați": "neîncurelat",
    "neîncuscrită": "neîncuscrit",
    "neîncuscrite": "neîncuscrit",
    "neîncuscriți": "neîncuscrit",
    "neîncuviințată": "neîncuviințat",
    "neîncuviințate": "neîncuviințat",
    "neîncuviințați": "neîncuviințat",
    "neîndărătnicită": "neîndărătnicit",
    "neîndărătnicite": "neîndărătnicit",
    "neîndărătniciți": "neîndărătnicit",
    "neîndârjita": "neîndârjit",
    "neîndârjită": "neîndârjit",
    "neîndârjite": "neîndârjit",
    "neîndârjitei": "neîndârjit",
    "neîndârjitele": "neîndârjit",
    "neîndârjitelor": "neîndârjit",
    "neîndârjiți": "neîndârjit",
    "neîndârjiții": "neîndârjit",
    "neîndârjiților": "neîndârjit",
    "neîndârjitul": "neîndârjit",
    "neîndârjitului": "neîndârjit",
    "neîndătinată": "neîndătinat",
    "neîndătinate": "neîndătinat",
    "neîndătinați": "neîndătinat",
    "neîndatorată": "neîndatorat",
    "neîndatorate": "neîndatorat",
    "neîndatorați": "neîndatorat",
    "neîndeletnicită": "neîndeletnicit",
    "neîndeletnicite": "neîndeletnicit",
    "neîndeletniciți": "neîndeletnicit",
    "neîndelungata": "neîndelungat",
    "neîndelungată": "neîndelungat",
    "neîndelungate": "neîndelungat",
    "neîndelungatei": "neîndelungat",
    "neîndelungatele": "neîndelungat",
    "neîndelungatelor": "neîndelungat",
    "neîndelungați": "neîndelungat",
    "neîndelungații": "neîndelungat",
    "neîndelungaților": "neîndelungat",
    "neîndelungatul": "neîndelungat",
    "neîndelungatului": "neîndelungat",
    "neîndemânarea": "neîndemânare",
    "neîndemânări": "neîndemânare",
    "neîndemânării": "neîndemânare",
    "neîndemânată": "neîndemânat",
    "neîndemânate": "neîndemânat",
    "neîndemânați": "neîndemânat",
    "neîndemânatica": "neîndemânatic",
    "neîndemânatică": "neîndemânatic",
    "neîndemânatice": "neîndemânatic",
    "neîndemânaticei": "neîndemânatic",
    "neîndemânaticele": "neîndemânatic",
    "neîndemânaticelor": "neîndemânatic",
    "neîndemânatici": "neîndemânatic",
    "neîndemânaticii": "neîndemânatic",
    "neîndemânaticilor": "neîndemânatic",
    "neîndemânaticul": "neîndemânatic",
    "neîndemânaticului": "neîndemânatic",
    "neîndemnată": "neîndemnat",
    "neîndemnate": "neîndemnat",
    "neîndemnați": "neîndemnat",
    "neindemnizată": "neindemnizat",
    "neindemnizate": "neindemnizat",
    "neindemnizați": "neindemnizat",
    "neîndepărtata": "neîndepărtat",
    "neîndepărtată": "neîndepărtat",
    "neîndepărtate": "neîndepărtat",
    "neîndepărtatei": "neîndepărtat",
    "neîndepărtatele": "neîndepărtat",
    "neîndepărtatelor": "neîndepărtat",
    "neîndepărtați": "neîndepărtat",
    "neîndepărtații": "neîndepărtat",
    "neîndepărtaților": "neîndepărtat",
    "neîndepărtatul": "neîndepărtat",
    "neîndepărtatului": "neîndepărtat",
    "neîndeplinirea": "neîndeplinire",
    "neîndepliniri": "neîndeplinire",
    "neîndeplinirii": "neîndeplinire",
    "neîndeplinirile": "neîndeplinire",
    "neîndeplinirilor": "neîndeplinire",
    "neîndeplinită": "neîndeplinit",
    "neîndeplinite": "neîndeplinit",
    "neîndepliniți": "neîndeplinit",
    "neîndesata": "neîndesat",
    "neîndesată": "neîndesat",
    "neîndesate": "neîndesat",
    "neîndesatei": "neîndesat",
    "neîndesatele": "neîndesat",
    "neîndesatelor": "neîndesat",
    "neîndesați": "neîndesat",
    "neîndesații": "neîndesat",
    "neîndesaților": "neîndesat",
    "neîndesatul": "neîndesat",
    "neîndesatului": "neîndesat",
    "neîndesită": "neîndesit",
    "neîndesite": "neîndesit",
    "neîndesiți": "neîndesit",
    "neîndestularea": "neîndestulare",
    "neîndestulări": "neîndestulare",
    "neîndestulării": "neîndestulare",
    "neîndestulările": "neîndestulare",
    "neîndestulărilor": "neîndestulare",
    "neîndestulată": "neîndestulat",
    "neîndestulate": "neîndestulat",
    "neîndestulați": "neîndestulat",
    "neîndestulătoare": "neîndestulător",
    "neîndestulătoarea": "neîndestulător",
    "neîndestulătoarei": "neîndestulător",
    "neîndestulătoarele": "neîndestulător",
    "neîndestulătoarelor": "neîndestulător",
    "neîndestulători": "neîndestulător",
    "neîndestulătorii": "neîndestulător",
    "neîndestulătorilor": "neîndestulător",
    "neîndestulătorul": "neîndestulător",
    "neîndestulătorului": "neîndestulător",
    "neindicata": "neindicat",
    "neindicată": "neindicat",
    "neindicate": "neindicat",
    "neindicatei": "neindicat",
    "neindicatele": "neindicat",
    "neindicatelor": "neindicat",
    "neindicați": "neindicat",
    "neindicații": "neindicat",
    "neindicaților": "neindicat",
    "neindicatul": "neindicat",
    "neindicatului": "neindicat",
    "neindigenată": "neindigenat",
    "neindigenate": "neindigenat",
    "neindigenați": "neindigenat",
    "neindignata": "neindignat",
    "neindignată": "neindignat",
    "neindignate": "neindignat",
    "neindignatei": "neindignat",
    "neindignatele": "neindignat",
    "neindignatelor": "neindignat",
    "neindignați": "neindignat",
    "neindignații": "neindignat",
    "neindignaților": "neindignat",
    "neindignatul": "neindignat",
    "neindignatului": "neindignat",
    "neîndiguită": "neîndiguit",
    "neîndiguite": "neîndiguit",
    "neîndiguiți": "neîndiguit",
    "neindispusa": "neindispus",
    "neindispusă": "neindispus",
    "neindispuse": "neindispus",
    "neindispusei": "neindispus",
    "neindispusele": "neindispus",
    "neindispuselor": "neindispus",
    "neindispuși": "neindispus",
    "neindispușii": "neindispus",
    "neindispușilor": "neindispus",
    "neindispusul": "neindispus",
    "neindispusului": "neindispus",
    "neindividualizată": "neindividualizat",
    "neindividualizate": "neindividualizat",
    "neindividualizați": "neindividualizat",
    "neîndobitocită": "neîndobitocit",
    "neîndobitocite": "neîndobitocit",
    "neîndobitociți": "neîndobitocit",
    "neîndoctrinată": "neîndoctrinat",
    "neîndoctrinate": "neîndoctrinat",
    "neîndoctrinați": "neîndoctrinat",
    "neîndoielnica": "neîndoielnic",
    "neîndoielnică": "neîndoielnic",
    "neîndoielnice": "neîndoielnic",
    "neîndoielnicei": "neîndoielnic",
    "neîndoielnicele": "neîndoielnic",
    "neîndoielnicelor": "neîndoielnic",
    "neîndoielnici": "neîndoielnic",
    "neîndoielnicii": "neîndoielnic",
    "neîndoielnicilor": "neîndoielnic",
    "neîndoielnicul": "neîndoielnic",
    "neîndoielnicului": "neîndoielnic",
    "neîndoioasa": "neîndoios",
    "neîndoioasă": "neîndoios",
    "neîndoioase": "neîndoios",
    "neîndoioasei": "neîndoios",
    "neîndoioasele": "neîndoios",
    "neîndoioaselor": "neîndoios",
    "neîndoioși": "neîndoios",
    "neîndoioșii": "neîndoios",
    "neîndoioșilor": "neîndoios",
    "neîndoiosul": "neîndoios",
    "neîndoiosului": "neîndoios",
    "neîndoită": "neîndoit",
    "neîndoite": "neîndoit",
    "neîndoiți": "neîndoit",
    "neîndoliata": "neîndoliat",
    "neîndoliată": "neîndoliat",
    "neîndoliate": "neîndoliat",
    "neîndoliatei": "neîndoliat",
    "neîndoliatele": "neîndoliat",
    "neîndoliatelor": "neîndoliat",
    "neîndoliați": "neîndoliat",
    "neîndoliații": "neîndoliat",
    "neîndoliaților": "neîndoliat",
    "neîndoliatul": "neîndoliat",
    "neîndoliatului": "neîndoliat",
    "neîndopată": "neîndopat",
    "neîndopate": "neîndopat",
    "neîndopați": "neîndopat",
    "neîndosită": "neîndosit",
    "neîndosite": "neîndosit",
    "neîndosiți": "neîndosit",
    "neîndrăcită": "neîndrăcit",
    "neîndrăcite": "neîndrăcit",
    "neîndrăciți": "neîndrăcit",
    "neîndrăgită": "neîndrăgit",
    "neîndrăgite": "neîndrăgit",
    "neîndrăgiți": "neîndrăgit",
    "neîndrăgostita": "neîndrăgostit",
    "neîndrăgostită": "neîndrăgostit",
    "neîndrăgostite": "neîndrăgostit",
    "neîndrăgostitei": "neîndrăgostit",
    "neîndrăgostitele": "neîndrăgostit",
    "neîndrăgostitelor": "neîndrăgostit",
    "neîndrăgostiți": "neîndrăgostit",
    "neîndrăgostiții": "neîndrăgostit",
    "neîndrăgostiților": "neîndrăgostit",
    "neîndrăgostitul": "neîndrăgostit",
    "neîndrăgostitului": "neîndrăgostit",
    "neîndrăznită": "neîndrăznit",
    "neîndrăznite": "neîndrăznit",
    "neîndrăzniți": "neîndrăznit",
    "neîndreptată": "neîndreptat",
    "neîndreptate": "neîndreptat",
    "neîndreptați": "neîndreptat",
    "neîndreptățită": "neîndreptățit",
    "neîndreptățite": "neîndreptățit",
    "neîndreptățiți": "neîndreptățit",
    "neîndreptuită": "neîndreptuit",
    "neîndreptuite": "neîndreptuit",
    "neîndreptuiți": "neîndreptuit",
    "neîndrituită": "neîndrituit",
    "neîndrituite": "neîndrituit",
    "neîndrituiți": "neîndrituit",
    "neîndrugată": "neîndrugat",
    "neîndrugate": "neîndrugat",
    "neîndrugați": "neîndrugat",
    "neîndrumată": "neîndrumat",
    "neîndrumate": "neîndrumat",
    "neîndrumați": "neîndrumat",
    "neînduioșată": "neînduioșat",
    "neînduioșate": "neînduioșat",
    "neînduioșați": "neînduioșat",
    "neîndulcită": "neîndulcit",
    "neîndulcite": "neîndulcit",
    "neîndulciți": "neîndulcit",
    "neîndumnezeită": "neîndumnezeit",
    "neîndumnezeite": "neîndumnezeit",
    "neîndumnezeiți": "neîndumnezeit",
    "neînduplecarea": "neînduplecare",
    "neînduplecări": "neînduplecare",
    "neînduplecării": "neînduplecare",
    "neînduplecările": "neînduplecare",
    "neînduplecărilor": "neînduplecare",
    "neînduplecata": "neînduplecat",
    "neînduplecată": "neînduplecat",
    "neînduplecate": "neînduplecat",
    "neînduplecatei": "neînduplecat",
    "neînduplecatele": "neînduplecat",
    "neînduplecatelor": "neînduplecat",
    "neînduplecați": "neînduplecat",
    "neînduplecații": "neînduplecat",
    "neînduplecaților": "neînduplecat",
    "neînduplecatul": "neînduplecat",
    "neînduplecatului": "neînduplecat",
    "neîndurarea": "neîndurare",
    "neîndurari": "neîndurare",
    "neîndurarii": "neîndurare",
    "neîndurarile": "neîndurare",
    "neîndurarilor": "neîndurare",
    "neindurată": "neindurat",
    "neindurate": "neindurat",
    "neindurați": "neindurat",
    "neîndurata": "neîndurat",
    "neîndurată": "neîndurat",
    "neîndurate": "neîndurat",
    "neînduratei": "neîndurat",
    "neînduratele": "neîndurat",
    "neînduratelor": "neîndurat",
    "neîndurați": "neîndurat",
    "neîndurații": "neîndurat",
    "neînduraților": "neîndurat",
    "neînduratul": "neîndurat",
    "neînduratului": "neîndurat",
    "neîndurătoare": "neîndurător",
    "neîndurătoarea": "neîndurător",
    "neîndurătoarei": "neîndurător",
    "neîndurătoarele": "neîndurător",
    "neîndurătoarelor": "neîndurător",
    "neîndurători": "neîndurător",
    "neîndurătorii": "neîndurător",
    "neîndurătorilor": "neîndurător",
    "neîndurătorul": "neîndurător",
    "neîndurătorului": "neîndurător",
    "neîndurerata": "neîndurerat",
    "neîndurerată": "neîndurerat",
    "neîndurerate": "neîndurerat",
    "neîndureratei": "neîndurerat",
    "neîndureratele": "neîndurerat",
    "neîndureratelor": "neîndurerat",
    "neîndurerați": "neîndurerat",
    "neîndurerații": "neîndurerat",
    "neîndureraților": "neîndurerat",
    "neîndureratul": "neîndurerat",
    "neîndureratului": "neîndurerat",
    "neindusă": "neindus",
    "neinduse": "neindus",
    "neinduși": "neindus",
    "neîndușmănită": "neîndușmănit",
    "neîndușmănite": "neîndușmănit",
    "neîndușmăniți": "neîndușmănit",
    "neindustrializată": "neindustrializat",
    "neindustrializate": "neindustrializat",
    "neindustrializați": "neindustrializat",
    "neînecată": "neînecat",
    "neînecate": "neînecat",
    "neînecați": "neînecat",
    "neinervată": "neinervat",
    "neinervate": "neinervat",
    "neinervați": "neinervat",
    "neînfăptuită": "neînfăptuit",
    "neînfăptuite": "neînfăptuit",
    "neînfăptuiți": "neînfăptuit",
    "neînfășată": "neînfășat",
    "neînfășate": "neînfășat",
    "neînfășați": "neînfășat",
    "neînfășurată": "neînfășurat",
    "neînfășurate": "neînfășurat",
    "neînfășurați": "neînfășurat",
    "neînfățată": "neînfățat",
    "neînfățate": "neînfățat",
    "neînfățați": "neînfățat",
    "neînfățișată": "neînfățișat",
    "neînfățișate": "neînfățișat",
    "neînfățișați": "neînfățișat",
    "neinfatuata": "neinfatuat",
    "neinfatuată": "neinfatuat",
    "neinfatuate": "neinfatuat",
    "neinfatuatei": "neinfatuat",
    "neinfatuatele": "neinfatuat",
    "neinfatuatelor": "neinfatuat",
    "neinfatuați": "neinfatuat",
    "neinfatuații": "neinfatuat",
    "neinfatuaților": "neinfatuat",
    "neinfatuatul": "neinfatuat",
    "neinfatuatului": "neinfatuat",
    "neinfectată": "neinfectat",
    "neinfectate": "neinfectat",
    "neinfectați": "neinfectat",
    "neinferată": "neinferat",
    "neinferate": "neinferat",
    "neinferați": "neinferat",
    "neinfestată": "neinfestat",
    "neinfestate": "neinfestat",
    "neinfestați": "neinfestat",
    "neînfeudată": "neînfeudat",
    "neînfeudate": "neînfeudat",
    "neînfeudați": "neînfeudat",
    "neînfiată": "neînfiat",
    "neînfiate": "neînfiat",
    "neînfiați": "neînfiat",
    "neînfierată": "neînfierat",
    "neînfierate": "neînfierat",
    "neînfierați": "neînfierat",
    "neînfierbântată": "neînfierbântat",
    "neînfierbântate": "neînfierbântat",
    "neînfierbântați": "neînfierbântat",
    "neînființată": "neînființat",
    "neînființate": "neînființat",
    "neînființați": "neînființat",
    "neinfiltrată": "neinfiltrat",
    "neinfiltrate": "neinfiltrat",
    "neinfiltrați": "neinfiltrat",
    "neînfiorată": "neînfiorat",
    "neînfiorate": "neînfiorat",
    "neînfiorați": "neînfiorat",
    "neînfiptă": "neînfipt",
    "neînfipte": "neînfipt",
    "neînfipți": "neînfipt",
    "neînfiripată": "neînfiripat",
    "neînfiripate": "neînfiripat",
    "neînfiripați": "neînfiripat",
    "neinfirmată": "neinfirmat",
    "neinfirmate": "neinfirmat",
    "neinfirmați": "neinfirmat",
    "neînflăcărata": "neînflăcărat",
    "neînflăcărată": "neînflăcărat",
    "neînflăcărate": "neînflăcărat",
    "neînflăcăratei": "neînflăcărat",
    "neînflăcăratele": "neînflăcărat",
    "neînflăcăratelor": "neînflăcărat",
    "neînflăcărați": "neînflăcărat",
    "neînflăcărații": "neînflăcărat",
    "neînflăcăraților": "neînflăcărat",
    "neînflăcăratul": "neînflăcărat",
    "neînflăcăratului": "neînflăcărat",
    "neinflamată": "neinflamat",
    "neinflamate": "neinflamat",
    "neinflamați": "neinflamat",
    "neînflorata": "neînflorat",
    "neînflorată": "neînflorat",
    "neînflorate": "neînflorat",
    "neînfloratei": "neînflorat",
    "neînfloratele": "neînflorat",
    "neînfloratelor": "neînflorat",
    "neînflorați": "neînflorat",
    "neînflorații": "neînflorat",
    "neînfloraților": "neînflorat",
    "neînfloratul": "neînflorat",
    "neînfloratului": "neînflorat",
    "neînflorita": "neînflorit",
    "neînflorită": "neînflorit",
    "neînflorite": "neînflorit",
    "neînfloritei": "neînflorit",
    "neînfloritele": "neînflorit",
    "neînfloritelor": "neînflorit",
    "neînfloriți": "neînflorit",
    "neînfloriții": "neînflorit",
    "neînfloriților": "neînflorit",
    "neînfloritul": "neînflorit",
    "neînfloritului": "neînflorit",
    "neinfluențată": "neinfluențat",
    "neinfluențate": "neinfluențat",
    "neinfluențați": "neinfluențat",
    "neînfocata": "neînfocat",
    "neînfocată": "neînfocat",
    "neînfocate": "neînfocat",
    "neînfocatei": "neînfocat",
    "neînfocatele": "neînfocat",
    "neînfocatelor": "neînfocat",
    "neînfocați": "neînfocat",
    "neînfocații": "neînfocat",
    "neînfocaților": "neînfocat",
    "neînfocatul": "neînfocat",
    "neînfocatului": "neînfocat",
    "neînfofolită": "neînfofolit",
    "neînfofolite": "neînfofolit",
    "neînfofoliți": "neînfofolit",
    "neînfoiată": "neînfoiat",
    "neînfoiate": "neînfoiat",
    "neînfoiați": "neînfoiat",
    "neînfometată": "neînfometat",
    "neînfometate": "neînfometat",
    "neînfometați": "neînfometat",
    "neinformata": "neinformat",
    "neinformată": "neinformat",
    "neinformate": "neinformat",
    "neinformatei": "neinformat",
    "neinformatele": "neinformat",
    "neinformatelor": "neinformat",
    "neinformați": "neinformat",
    "neinformații": "neinformat",
    "neinformaților": "neinformat",
    "neinformatul": "neinformat",
    "neinformatului": "neinformat",
    "neînfrânarea": "neînfrânare",
    "neînfrânări": "neînfrânare",
    "neînfrânării": "neînfrânare",
    "neînfrânările": "neînfrânare",
    "neînfrânărilor": "neînfrânare",
    "neînfrânată": "neînfrânat",
    "neînfrânate": "neînfrânat",
    "neînfrânați": "neînfrânat",
    "neînfrânta": "neînfrânt",
    "neînfrântă": "neînfrânt",
    "neînfrânte": "neînfrânt",
    "neînfrântei": "neînfrânt",
    "neînfrântele": "neînfrânt",
    "neînfrântelor": "neînfrânt",
    "neînfrânți": "neînfrânt",
    "neînfrânții": "neînfrânt",
    "neînfrânților": "neînfrânt",
    "neînfrântul": "neînfrânt",
    "neînfrântului": "neînfrânt",
    "neînfrățită": "neînfrățit",
    "neînfrățite": "neînfrățit",
    "neînfrățiți": "neînfrățit",
    "neînfricarea": "neînfricare",
    "neînfricări": "neînfricare",
    "neînfricării": "neînfricare",
    "neînfricările": "neînfricare",
    "neînfricărilor": "neînfricare",
    "neînfricata": "neînfricat",
    "neînfricată": "neînfricat",
    "neînfricate": "neînfricat",
    "neînfricatei": "neînfricat",
    "neînfricatele": "neînfricat",
    "neînfricatelor": "neînfricat",
    "neînfricați": "neînfricat",
    "neînfricații": "neînfricat",
    "neînfricaților": "neînfricat",
    "neînfricatul": "neînfricat",
    "neînfricatului": "neînfricat",
    "neînfricoșata": "neînfricoșat",
    "neînfricoșată": "neînfricoșat",
    "neînfricoșate": "neînfricoșat",
    "neînfricoșatei": "neînfricoșat",
    "neînfricoșatele": "neînfricoșat",
    "neînfricoșatelor": "neînfricoșat",
    "neînfricoșați": "neînfricoșat",
    "neînfricoșații": "neînfricoșat",
    "neînfricoșaților": "neînfricoșat",
    "neînfricoșatul": "neînfricoșat",
    "neînfricoșatului": "neînfricoșat",
    "neînfrumoșată": "neînfrumoșat",
    "neînfrumoșate": "neînfrumoșat",
    "neînfrumoșați": "neînfrumoșat",
    "neînfrumusețată": "neînfrumusețat",
    "neînfrumusețate": "neînfrumusețat",
    "neînfrumusețați": "neînfrumusețat",
    "neînfruntată": "neînfruntat",
    "neînfruntate": "neînfruntat",
    "neînfruntați": "neînfruntat",
    "neînfrunzita": "neînfrunzit",
    "neînfrunzită": "neînfrunzit",
    "neînfrunzite": "neînfrunzit",
    "neînfrunzitei": "neînfrunzit",
    "neînfrunzitele": "neînfrunzit",
    "neînfrunzitelor": "neînfrunzit",
    "neînfrunziți": "neînfrunzit",
    "neînfrunziții": "neînfrunzit",
    "neînfrunziților": "neînfrunzit",
    "neînfrunzitul": "neînfrunzit",
    "neînfrunzitului": "neînfrunzit",
    "neînfruptată": "neînfruptat",
    "neînfruptate": "neînfruptat",
    "neînfruptați": "neînfruptat",
    "neînfulecată": "neînfulecat",
    "neînfulecate": "neînfulecat",
    "neînfulecați": "neînfulecat",
    "neînfumurata": "neînfumurat",
    "neînfumurată": "neînfumurat",
    "neînfumurate": "neînfumurat",
    "neînfumuratei": "neînfumurat",
    "neînfumuratele": "neînfumurat",
    "neînfumuratelor": "neînfumurat",
    "neînfumurați": "neînfumurat",
    "neînfumurații": "neînfumurat",
    "neînfumuraților": "neînfumurat",
    "neînfumuratul": "neînfumurat",
    "neînfumuratului": "neînfumurat",
    "neînfundata": "neînfundat",
    "neînfundată": "neînfundat",
    "neînfundate": "neînfundat",
    "neînfundatei": "neînfundat",
    "neînfundatele": "neînfundat",
    "neînfundatelor": "neînfundat",
    "neînfundați": "neînfundat",
    "neînfundații": "neînfundat",
    "neînfundaților": "neînfundat",
    "neînfundatul": "neînfundat",
    "neînfundatului": "neînfundat",
    "neînfuriata": "neînfuriat",
    "neînfuriată": "neînfuriat",
    "neînfuriate": "neînfuriat",
    "neînfuriatei": "neînfuriat",
    "neînfuriatele": "neînfuriat",
    "neînfuriatelor": "neînfuriat",
    "neînfuriați": "neînfuriat",
    "neînfuriații": "neînfuriat",
    "neînfuriaților": "neînfuriat",
    "neînfuriatul": "neînfuriat",
    "neînfuriatului": "neînfuriat",
    "neinfuzată": "neinfuzat",
    "neinfuzate": "neinfuzat",
    "neinfuzați": "neinfuzat",
    "neîngăduită": "neîngăduit",
    "neîngăduite": "neîngăduit",
    "neîngăduiți": "neîngăduit",
    "neîngăimată": "neîngăimat",
    "neîngăimate": "neîngăimat",
    "neîngăimați": "neîngăimat",
    "neîngălată": "neîngălat",
    "neîngălate": "neîngălat",
    "neîngălați": "neîngălat",
    "neîngălbenită": "neîngălbenit",
    "neîngălbenite": "neîngălbenit",
    "neîngălbeniți": "neîngălbenit",
    "neîngâmfata": "neîngâmfat",
    "neîngâmfată": "neîngâmfat",
    "neîngâmfate": "neîngâmfat",
    "neîngâmfatei": "neîngâmfat",
    "neîngâmfatele": "neîngâmfat",
    "neîngâmfatelor": "neîngâmfat",
    "neîngâmfați": "neîngâmfat",
    "neîngâmfații": "neîngâmfat",
    "neîngâmfaților": "neîngâmfat",
    "neîngâmfatul": "neîngâmfat",
    "neîngâmfatului": "neîngâmfat",
    "neîngânată": "neîngânat",
    "neîngânate": "neîngânat",
    "neîngânați": "neîngânat",
    "neîngândurata": "neîngândurat",
    "neîngândurată": "neîngândurat",
    "neîngândurate": "neîngândurat",
    "neîngânduratei": "neîngândurat",
    "neîngânduratele": "neîngândurat",
    "neîngânduratelor": "neîngândurat",
    "neîngândurați": "neîngândurat",
    "neîngândurații": "neîngândurat",
    "neîngânduraților": "neîngândurat",
    "neîngânduratul": "neîngândurat",
    "neîngânduratului": "neîngândurat",
    "neîngemănată": "neîngemănat",
    "neîngemănate": "neîngemănat",
    "neîngemănați": "neîngemănat",
    "neîngenuncheată": "neîngenuncheat",
    "neîngenuncheate": "neîngenuncheat",
    "neîngenuncheați": "neîngenuncheat",
    "neingerată": "neingerat",
    "neingerate": "neingerat",
    "neingerați": "neingerat",
    "neînghemuită": "neînghemuit",
    "neînghemuite": "neînghemuit",
    "neînghemuiți": "neînghemuit",
    "neînghesuită": "neînghesuit",
    "neînghesuite": "neînghesuit",
    "neînghesuiți": "neînghesuit",
    "neînghețată": "neînghețat",
    "neînghețate": "neînghețat",
    "neînghețați": "neînghețat",
    "neînghimpată": "neînghimpat",
    "neînghimpate": "neînghimpat",
    "neînghimpați": "neînghimpat",
    "neînghioldită": "neînghioldit",
    "neînghioldite": "neînghioldit",
    "neînghioldiți": "neînghioldit",
    "neînghiontită": "neînghiontit",
    "neînghiontite": "neînghiontit",
    "neînghiontiți": "neînghiontit",
    "neînghițită": "neînghițit",
    "neînghițite": "neînghițit",
    "neînghițiți": "neînghițit",
    "neînglobată": "neînglobat",
    "neînglobate": "neînglobat",
    "neînglobați": "neînglobat",
    "neînglodată": "neînglodat",
    "neînglodate": "neînglodat",
    "neînglodați": "neînglodat",
    "neînglotită": "neînglotit",
    "neînglotite": "neînglotit",
    "neînglotiți": "neînglotit",
    "neîngrădita": "neîngrădit",
    "neîngrădită": "neîngrădit",
    "neîngrădite": "neîngrădit",
    "neîngrăditei": "neîngrădit",
    "neîngrăditele": "neîngrădit",
    "neîngrăditelor": "neîngrădit",
    "neîngrădiți": "neîngrădit",
    "neîngrădiții": "neîngrădit",
    "neîngrădiților": "neîngrădit",
    "neîngrăditul": "neîngrădit",
    "neîngrăditului": "neîngrădit",
    "neîngrămădită": "neîngrămădit",
    "neîngrămădite": "neîngrămădit",
    "neîngrămădiți": "neîngrămădit",
    "neîngrășată": "neîngrășat",
    "neîngrășate": "neîngrășat",
    "neîngrășați": "neîngrășat",
    "neîngrețoșată": "neîngrețoșat",
    "neîngrețoșate": "neîngrețoșat",
    "neîngrețoșați": "neîngrețoșat",
    "neîngreuiată": "neîngreuiat",
    "neîngreuiate": "neîngreuiat",
    "neîngreuiați": "neîngreuiat",
    "neîngreunată": "neîngreunat",
    "neîngreunate": "neîngreunat",
    "neîngreunați": "neîngreunat",
    "neîngrijirea": "neîngrijire",
    "neîngrijiri": "neîngrijire",
    "neîngrijirii": "neîngrijire",
    "neîngrijirile": "neîngrijire",
    "neîngrijirilor": "neîngrijire",
    "neîngrijita": "neîngrijit",
    "neîngrijită": "neîngrijit",
    "neîngrijite": "neîngrijit",
    "neîngrijitei": "neîngrijit",
    "neîngrijitele": "neîngrijit",
    "neîngrijitelor": "neîngrijit",
    "neîngrijiți": "neîngrijit",
    "neîngrijiții": "neîngrijit",
    "neîngrijiților": "neîngrijit",
    "neîngrijitul": "neîngrijit",
    "neîngrijitului": "neîngrijit",
    "neîngrijorata": "neîngrijorat",
    "neîngrijorată": "neîngrijorat",
    "neîngrijorate": "neîngrijorat",
    "neîngrijoratei": "neîngrijorat",
    "neîngrijoratele": "neîngrijorat",
    "neîngrijoratelor": "neîngrijorat",
    "neîngrijorați": "neîngrijorat",
    "neîngrijorații": "neîngrijorat",
    "neîngrijoraților": "neîngrijorat",
    "neîngrijoratul": "neîngrijorat",
    "neîngrijoratului": "neîngrijorat",
    "neîngropată": "neîngropat",
    "neîngropate": "neîngropat",
    "neîngropați": "neîngropat",
    "neîngroșată": "neîngroșat",
    "neîngroșate": "neîngroșat",
    "neîngroșați": "neîngroșat",
    "neîngrozita": "neîngrozit",
    "neîngrozită": "neîngrozit",
    "neîngrozite": "neîngrozit",
    "neîngrozitei": "neîngrozit",
    "neîngrozitele": "neîngrozit",
    "neîngrozitelor": "neîngrozit",
    "neîngroziți": "neîngrozit",
    "neîngroziții": "neîngrozit",
    "neîngroziților": "neîngrozit",
    "neîngrozitul": "neîngrozit",
    "neîngrozitului": "neîngrozit",
    "neingurgitată": "neingurgitat",
    "neingurgitate": "neingurgitat",
    "neingurgitați": "neingurgitat",
    "neîngustată": "neîngustat",
    "neîngustate": "neîngustat",
    "neîngustați": "neîngustat",
    "neînhăitată": "neînhăitat",
    "neînhăitate": "neînhăitat",
    "neînhăitați": "neînhăitat",
    "neinhalată": "neinhalat",
    "neinhalate": "neinhalat",
    "neinhalați": "neinhalat",
    "neînhămată": "neînhămat",
    "neînhămate": "neînhămat",
    "neînhămați": "neînhămat",
    "neînhățată": "neînhățat",
    "neînhățate": "neînhățat",
    "neînhățați": "neînhățat",
    "neinhibată": "neinhibat",
    "neinhibate": "neinhibat",
    "neinhibați": "neinhibat",
    "neînhumată": "neînhumat",
    "neînhumate": "neînhumat",
    "neînhumați": "neînhumat",
    "neînierbată": "neînierbat",
    "neînierbate": "neînierbat",
    "neînierbați": "neînierbat",
    "neinițiată": "neinițiat",
    "neinițiate": "neinițiat",
    "neinițiați": "neinițiat",
    "neinjectata": "neinjectat",
    "neinjectată": "neinjectat",
    "neinjectate": "neinjectat",
    "neinjectatei": "neinjectat",
    "neinjectatele": "neinjectat",
    "neinjectatelor": "neinjectat",
    "neinjectați": "neinjectat",
    "neinjectații": "neinjectat",
    "neinjectaților": "neinjectat",
    "neinjectatul": "neinjectat",
    "neinjectatului": "neinjectat",
    "neînjghebată": "neînjghebat",
    "neînjghebate": "neînjghebat",
    "neînjghebați": "neînjghebat",
    "neînjosită": "neînjosit",
    "neînjosite": "neînjosit",
    "neînjosiți": "neînjosit",
    "neînjugată": "neînjugat",
    "neînjugate": "neînjugat",
    "neînjugați": "neînjugat",
    "neînjumătățită": "neînjumătățit",
    "neînjumătățite": "neînjumătățit",
    "neînjumătățiți": "neînjumătățit",
    "neînjunghiată": "neînjunghiat",
    "neînjunghiate": "neînjunghiat",
    "neînjunghiați": "neînjunghiat",
    "neînjurată": "neînjurat",
    "neînjurate": "neînjurat",
    "neînjurați": "neînjurat",
    "neînlăcrimată": "neînlăcrimat",
    "neînlăcrimate": "neînlăcrimat",
    "neînlăcrimați": "neînlăcrimat",
    "neînlănțuită": "neînlănțuit",
    "neînlănțuite": "neînlănțuit",
    "neînlănțuiți": "neînlănțuit",
    "neînlăturată": "neînlăturat",
    "neînlăturate": "neînlăturat",
    "neînlăturați": "neînlăturat",
    "neînlemnită": "neînlemnit",
    "neînlemnite": "neînlemnit",
    "neînlemniți": "neînlemnit",
    "neînlesnită": "neînlesnit",
    "neînlesnite": "neînlesnit",
    "neînlesniți": "neînlesnit",
    "neînlocuită": "neînlocuit",
    "neînlocuite": "neînlocuit",
    "neînlocuiți": "neînlocuit",
    "neînluminată": "neînluminat",
    "neînluminate": "neînluminat",
    "neînluminați": "neînluminat",
    "neînmagazinată": "neînmagazinat",
    "neînmagazinate": "neînmagazinat",
    "neînmagazinați": "neînmagazinat",
    "neînmânată": "neînmânat",
    "neînmânate": "neînmânat",
    "neînmânați": "neînmânat",
    "neînmănuncheată": "neînmănuncheat",
    "neînmănuncheate": "neînmănuncheat",
    "neînmănuncheați": "neînmănuncheat",
    "neînmărmurita": "neînmărmurit",
    "neînmărmurită": "neînmărmurit",
    "neînmărmurite": "neînmărmurit",
    "neînmărmuritei": "neînmărmurit",
    "neînmărmuritele": "neînmărmurit",
    "neînmărmuritelor": "neînmărmurit",
    "neînmărmuriți": "neînmărmurit",
    "neînmărmuriții": "neînmărmurit",
    "neînmărmuriților": "neînmărmurit",
    "neînmărmuritul": "neînmărmurit",
    "neînmărmuritului": "neînmărmurit",
    "neînmatriculată": "neînmatriculat",
    "neînmatriculate": "neînmatriculat",
    "neînmatriculați": "neînmatriculat",
    "neînmiită": "neînmiit",
    "neînmiite": "neînmiit",
    "neînmiiți": "neînmiit",
    "neînmiresmata": "neînmiresmat",
    "neînmiresmată": "neînmiresmat",
    "neînmiresmate": "neînmiresmat",
    "neînmiresmatei": "neînmiresmat",
    "neînmiresmatele": "neînmiresmat",
    "neînmiresmatelor": "neînmiresmat",
    "neînmiresmați": "neînmiresmat",
    "neînmiresmații": "neînmiresmat",
    "neînmiresmaților": "neînmiresmat",
    "neînmiresmatul": "neînmiresmat",
    "neînmiresmatului": "neînmiresmat",
    "neînmlădiată": "neînmlădiat",
    "neînmlădiate": "neînmlădiat",
    "neînmlădiați": "neînmlădiat",
    "neînmoinată": "neînmoinat",
    "neînmormântată": "neînmormântat",
    "neînmormântate": "neînmormântat",
    "neînmormântați": "neînmormântat",
    "neînmugurită": "neînmugurit",
    "neînmugurite": "neînmugurit",
    "neînmuguriți": "neînmugurit",
    "neînmuiată": "neînmuiat",
    "neînmuiate": "neînmuiat",
    "neînmuiați": "neînmuiat",
    "neînmulțită": "neînmulțit",
    "neînmulțite": "neînmulțit",
    "neînmulțiți": "neînmulțit",
    "neînmurgită": "neînmurgit",
    "neînmurgite": "neînmurgit",
    "neînmurgiți": "neînmurgit",
    "neînnădită": "neînnădit",
    "neînnădite": "neînnădit",
    "neînnădiți": "neînnădit",
    "neînnămolită": "neînnămolit",
    "neînnămolite": "neînnămolit",
    "neînnămoliți": "neînnămolit",
    "neînnărăvită": "neînnărăvit",
    "neînnărăvite": "neînnărăvit",
    "neînnărăviți": "neînnărăvit",
    "neînnebunita": "neînnebunit",
    "neînnebunită": "neînnebunit",
    "neînnebunite": "neînnebunit",
    "neînnebunitei": "neînnebunit",
    "neînnebunitele": "neînnebunit",
    "neînnebunitelor": "neînnebunit",
    "neînnebuniți": "neînnebunit",
    "neînnebuniții": "neînnebunit",
    "neînnebuniților": "neînnebunit",
    "neînnebunitul": "neînnebunit",
    "neînnebunitului": "neînnebunit",
    "neînnegrită": "neînnegrit",
    "neînnegrite": "neînnegrit",
    "neînnegriți": "neînnegrit",
    "neînnegurată": "neînnegurat",
    "neînnemurită": "neînnemurit",
    "neînnemurite": "neînnemurit",
    "neînnemuriți": "neînnemurit",
    "neînnisipată": "neînnisipat",
    "neînnisipate": "neînnisipat",
    "neînnisipați": "neînnisipat",
    "neînnobilată": "neînnobilat",
    "neînnobilate": "neînnobilat",
    "neînnobilați": "neînnobilat",
    "neînnodată": "neînnodat",
    "neînnodate": "neînnodat",
    "neînnodați": "neînnodat",
    "neînnoită": "neînnoit",
    "neînnoite": "neînnoit",
    "neînnoiți": "neînnoit",
    "neînnoptată": "neînnoptat",
    "neînnoptate": "neînnoptat",
    "neînnoptați": "neînnoptat",
    "neînnorata": "neînnorat",
    "neînnorată": "neînnorat",
    "neînnoratei": "neînnorat",
    "neînnoratele": "neînnorat",
    "neînnoratelor": "neînnorat",
    "neînnorații": "neînnorat",
    "neînnoraților": "neînnorat",
    "neînnoratul": "neînnorat",
    "neînnoratului": "neînnorat",
    "neînnoroită": "neînnoroit",
    "neînnoroite": "neînnoroit",
    "neînnoroiți": "neînnoroit",
    "neinoculată": "neinoculat",
    "neinoculate": "neinoculat",
    "neinoculați": "neinoculat",
    "neînotată": "neînotat",
    "neînotate": "neînotat",
    "neînotați": "neînotat",
    "neinovată": "neinovat",
    "neinovate": "neinovat",
    "neinovați": "neinovat",
    "neînrădăcinata": "neînrădăcinat",
    "neînrădăcinată": "neînrădăcinat",
    "neînrădăcinate": "neînrădăcinat",
    "neînrădăcinatei": "neînrădăcinat",
    "neînrădăcinatele": "neînrădăcinat",
    "neînrădăcinatelor": "neînrădăcinat",
    "neînrădăcinați": "neînrădăcinat",
    "neînrădăcinații": "neînrădăcinat",
    "neînrădăcinaților": "neînrădăcinat",
    "neînrădăcinatul": "neînrădăcinat",
    "neînrădăcinatului": "neînrădăcinat",
    "neînrăita": "neînrăit",
    "neînrăită": "neînrăit",
    "neînrăite": "neînrăit",
    "neînrăitei": "neînrăit",
    "neînrăitele": "neînrăit",
    "neînrăitelor": "neînrăit",
    "neînrăiți": "neînrăit",
    "neînrăiții": "neînrăit",
    "neînrăiților": "neînrăit",
    "neînrăitul": "neînrăit",
    "neînrăitului": "neînrăit",
    "neînrămată": "neînrămat",
    "neînrămate": "neînrămat",
    "neînrămați": "neînrămat",
    "neînrâurită": "neînrâurit",
    "neînrâurite": "neînrâurit",
    "neînrâuriți": "neînrâurit",
    "neînrăutățită": "neînrăutățit",
    "neînrăutățite": "neînrăutățit",
    "neînrăutățiți": "neînrăutățit",
    "neînregimentată": "neînregimentat",
    "neînregimentate": "neînregimentat",
    "neînregimentați": "neînregimentat",
    "neînregistrarea": "neînregistrare",
    "neînregistrări": "neînregistrare",
    "neînregistrării": "neînregistrare",
    "neînregistrările": "neînregistrare",
    "neînregistrărilor": "neînregistrare",
    "neînregistrată": "neînregistrat",
    "neînregistrate": "neînregistrat",
    "neînregistrați": "neînregistrat",
    "neînrobită": "neînrobit",
    "neînrobite": "neînrobit",
    "neînrobiți": "neînrobit",
    "neînrolată": "neînrolat",
    "neînrolate": "neînrolat",
    "neînrolați": "neînrolat",
    "neînroșită": "neînroșit",
    "neînroșite": "neînroșit",
    "neînroșiți": "neînroșit",
    "neînrourata": "neînrourat",
    "neînrourată": "neînrourat",
    "neînrouratei": "neînrourat",
    "neînrouratele": "neînrourat",
    "neînrouratelor": "neînrourat",
    "neînrourații": "neînrourat",
    "neînrouraților": "neînrourat",
    "neînrouratul": "neînrourat",
    "neînrouratului": "neînrourat",
    "neînrudita": "neînrudit",
    "neînrudită": "neînrudit",
    "neînrudite": "neînrudit",
    "neînruditei": "neînrudit",
    "neînruditele": "neînrudit",
    "neînruditelor": "neînrudit",
    "neînrudiți": "neînrudit",
    "neînrudiții": "neînrudit",
    "neînrudiților": "neînrudit",
    "neînruditul": "neînrudit",
    "neînruditului": "neînrudit",
    "neînsăilată": "neînsăilat",
    "neînsăilate": "neînsăilat",
    "neînsăilați": "neînsăilat",
    "neînsămânțată": "neînsămânțat",
    "neînsămânțate": "neînsămânțat",
    "neînsămânțați": "neînsămânțat",
    "neînsănătoșită": "neînsănătoșit",
    "neînsănătoșite": "neînsănătoșit",
    "neînsănătoșiți": "neînsănătoșit",
    "neînsărcinată": "neînsărcinat",
    "neînsărcinate": "neînsărcinat",
    "neînsărcinați": "neînsărcinat",
    "neînscăunată": "neînscăunat",
    "neînscăunate": "neînscăunat",
    "neînscăunați": "neînscăunat",
    "neinsculpată": "neinsculpat",
    "neinsculpate": "neinsculpat",
    "neinsculpați": "neinsculpat",
    "neînșelată": "neînșelat",
    "neînșelate": "neînșelat",
    "neînșelați": "neînșelat",
    "neînsemnata": "neînsemnat",
    "neînsemnată": "neînsemnat",
    "neînsemnate": "neînsemnat",
    "neînsemnatei": "neînsemnat",
    "neînsemnatele": "neînsemnat",
    "neînsemnatelor": "neînsemnat",
    "neînsemnați": "neînsemnat",
    "neînsemnații": "neînsemnat",
    "neînsemnaților": "neînsemnat",
    "neînsemnatul": "neînsemnat",
    "neînsemnatului": "neînsemnat",
    "neinsensibilizată": "neinsensibilizat",
    "neinsensibilizate": "neinsensibilizat",
    "neinsensibilizați": "neinsensibilizat",
    "neinserată": "neinserat",
    "neinserate": "neinserat",
    "neinserați": "neinserat",
    "neînșeuată": "neînșeuat",
    "neînșeuate": "neînșeuat",
    "neînșeuați": "neînșeuat",
    "neînșfăcată": "neînșfăcat",
    "neînșfăcate": "neînșfăcat",
    "neînșfăcați": "neînșfăcat",
    "neinsinuată": "neinsinuat",
    "neinsinuate": "neinsinuat",
    "neinsinuați": "neinsinuat",
    "neînșirată": "neînșirat",
    "neînșirate": "neînșirat",
    "neînșirați": "neînșirat",
    "neînșiruită": "neînșiruit",
    "neînșiruite": "neînșiruit",
    "neînșiruiți": "neînșiruit",
    "neinsistată": "neinsistat",
    "neinsistate": "neinsistat",
    "neinsistați": "neinsistat",
    "neinsolubilizată": "neinsolubilizat",
    "neinsolubilizate": "neinsolubilizat",
    "neinsolubilizați": "neinsolubilizat",
    "neînșomoltocită": "neînșomoltocit",
    "neînșomoltocite": "neînșomoltocit",
    "neînșomoltociți": "neînșomoltocit",
    "neinspectată": "neinspectat",
    "neinspectate": "neinspectat",
    "neinspectați": "neinspectat",
    "neinspirata": "neinspirat",
    "neinspirată": "neinspirat",
    "neinspirate": "neinspirat",
    "neinspiratei": "neinspirat",
    "neinspiratele": "neinspirat",
    "neinspiratelor": "neinspirat",
    "neinspirați": "neinspirat",
    "neinspirații": "neinspirat",
    "neinspiraților": "neinspirat",
    "neinspiratul": "neinspirat",
    "neinspiratului": "neinspirat",
    "neînspumata": "neînspumat",
    "neînspumată": "neînspumat",
    "neînspumate": "neînspumat",
    "neînspumatei": "neînspumat",
    "neînspumatele": "neînspumat",
    "neînspumatelor": "neînspumat",
    "neînspumați": "neînspumat",
    "neînspumații": "neînspumat",
    "neînspumaților": "neînspumat",
    "neînspumatul": "neînspumat",
    "neînspumatului": "neînspumat",
    "neînspumegată": "neînspumegat",
    "neînspumegate": "neînspumegat",
    "neînspumegați": "neînspumegat",
    "neinstalată": "neinstalat",
    "neinstalate": "neinstalat",
    "neinstalați": "neinstalat",
    "neînstăpânită": "neînstăpânit",
    "neînstăpânite": "neînstăpânit",
    "neînstăpâniți": "neînstăpânit",
    "neînstărita": "neînstărit",
    "neînstărită": "neînstărit",
    "neînstărite": "neînstărit",
    "neînstăritei": "neînstărit",
    "neînstăritele": "neînstărit",
    "neînstăritelor": "neînstărit",
    "neînstăriți": "neînstărit",
    "neînstăriții": "neînstărit",
    "neînstăriților": "neînstărit",
    "neînstăritul": "neînstărit",
    "neînstăritului": "neînstărit",
    "neinstaurată": "neinstaurat",
    "neinstaurate": "neinstaurat",
    "neinstaurați": "neinstaurat",
    "neînstelata": "neînstelat",
    "neînstelată": "neînstelat",
    "neînstelate": "neînstelat",
    "neînstelatei": "neînstelat",
    "neînstelatele": "neînstelat",
    "neînstelatelor": "neînstelat",
    "neînstelați": "neînstelat",
    "neînstelații": "neînstelat",
    "neînstelaților": "neînstelat",
    "neînstelatul": "neînstelat",
    "neînstelatului": "neînstelat",
    "neinstigată": "neinstigat",
    "neinstigate": "neinstigat",
    "neinstigați": "neinstigat",
    "neînștiințată": "neînștiințat",
    "neînștiințate": "neînștiințat",
    "neînștiințați": "neînștiințat",
    "neinstilată": "neinstilat",
    "neinstilate": "neinstilat",
    "neinstilați": "neinstilat",
    "neinstituită": "neinstituit",
    "neinstituite": "neinstituit",
    "neinstituiți": "neinstituit",
    "neînstrăinată": "neînstrăinat",
    "neînstrăinate": "neînstrăinat",
    "neînstrăinați": "neînstrăinat",
    "neinstruita": "neinstruit",
    "neinstruită": "neinstruit",
    "neinstruite": "neinstruit",
    "neinstruitei": "neinstruit",
    "neinstruitele": "neinstruit",
    "neinstruitelor": "neinstruit",
    "neinstruiți": "neinstruit",
    "neinstruiții": "neinstruit",
    "neinstruiților": "neinstruit",
    "neinstruitul": "neinstruit",
    "neinstruitului": "neinstruit",
    "neinstrumentată": "neinstrumentat",
    "neinstrumentate": "neinstrumentat",
    "neinstrumentați": "neinstrumentat",
    "neînstrunată": "neînstrunat",
    "neînstrunate": "neînstrunat",
    "neînstrunați": "neînstrunat",
    "neinsuflată": "neinsuflat",
    "neinsuflate": "neinsuflat",
    "neinsuflați": "neinsuflat",
    "neînsuflețita": "neînsuflețit",
    "neînsuflețită": "neînsuflețit",
    "neînsuflețite": "neînsuflețit",
    "neînsuflețitei": "neînsuflețit",
    "neînsuflețitele": "neînsuflețit",
    "neînsuflețitelor": "neînsuflețit",
    "neînsuflețiți": "neînsuflețit",
    "neînsuflețiții": "neînsuflețit",
    "neînsuflețiților": "neînsuflețit",
    "neînsuflețitul": "neînsuflețit",
    "neînsuflețitului": "neînsuflețit",
    "neinsultată": "neinsultat",
    "neinsultate": "neinsultat",
    "neinsultați": "neinsultat",
    "neînsumată": "neînsumat",
    "neînsumate": "neînsumat",
    "neînsumați": "neînsumat",
    "neînsurata": "neînsurat",
    "neînsurată": "neînsurat",
    "neînsurate": "neînsurat",
    "neînsuratei": "neînsurat",
    "neînsuratele": "neînsurat",
    "neînsuratelor": "neînsurat",
    "neînsurați": "neînsurat",
    "neînsurații": "neînsurat",
    "neînsuraților": "neînsurat",
    "neînsuratul": "neînsurat",
    "neînsuratului": "neînsurat",
    "neînșurubată": "neînșurubat",
    "neînșurubate": "neînșurubat",
    "neînșurubați": "neînșurubat",
    "neînsușită": "neînsușit",
    "neînsușite": "neînsușit",
    "neînsușiți": "neînsușit",
    "neînsutită": "neînsutit",
    "neînsutite": "neînsutit",
    "neînsutiți": "neînsutit",
    "neintabulată": "neintabulat",
    "neintabulate": "neintabulat",
    "neintabulați": "neintabulat",
    "neîntâlnită": "neîntâlnit",
    "neîntâlnite": "neîntâlnit",
    "neîntâlniți": "neîntâlnit",
    "neîntâmpinată": "neîntâmpinat",
    "neîntâmpinate": "neîntâmpinat",
    "neîntâmpinați": "neîntâmpinat",
    "neîntâmplată": "neîntâmplat",
    "neîntâmplate": "neîntâmplat",
    "neîntâmplați": "neîntâmplat",
    "neîntărâtată": "neîntărâtat",
    "neîntărâtate": "neîntărâtat",
    "neîntărâtați": "neîntărâtat",
    "neînțărcată": "neînțărcat",
    "neînțărcate": "neînțărcat",
    "neînțărcați": "neînțărcat",
    "neînțărcuită": "neînțărcuit",
    "neînțărcuite": "neînțărcuit",
    "neînțărcuiți": "neînțărcuit",
    "neîntărită": "neîntărit",
    "neîntărite": "neîntărit",
    "neîntăriți": "neîntărit",
    "neîntârziata": "neîntârziat",
    "neîntârziată": "neîntârziat",
    "neîntârziate": "neîntârziat",
    "neîntârziatei": "neîntârziat",
    "neîntârziatele": "neîntârziat",
    "neîntârziatelor": "neîntârziat",
    "neîntârziați": "neîntârziat",
    "neîntârziații": "neîntârziat",
    "neîntârziaților": "neîntârziat",
    "neîntârziatul": "neîntârziat",
    "neîntârziatului": "neîntârziat",
    "neintegrată": "neintegrat",
    "neintegrate": "neintegrat",
    "neintegrați": "neintegrat",
    "neînțelegătoare": "neînțelegător",
    "neînțelegătoarea": "neînțelegător",
    "neînțelegătoarei": "neînțelegător",
    "neînțelegătoarele": "neînțelegător",
    "neînțelegătoarelor": "neînțelegător",
    "neînțelegători": "neînțelegător",
    "neînțelegătorii": "neînțelegător",
    "neînțelegătorilor": "neînțelegător",
    "neînțelegătorul": "neînțelegător",
    "neînțelegătorului": "neînțelegător",
    "neînțelegerea": "neînțelegere",
    "neînțelegeri": "neînțelegere",
    "neînțelegerii": "neînțelegere",
    "neînțelegerile": "neînțelegere",
    "neînțelegerilor": "neînțelegere",
    "neînțelenită": "neînțelenit",
    "neînțelenite": "neînțelenit",
    "neînțeleniți": "neînțelenit",
    "neînțeleapta": "neînțelept",
    "neînțeleaptă": "neînțelept",
    "neînțelepte": "neînțelept",
    "neînțeleptei": "neînțelept",
    "neînțeleptele": "neînțelept",
    "neînțeleptelor": "neînțelept",
    "neînțelepți": "neînțelept",
    "neînțelepții": "neînțelept",
    "neînțelepților": "neînțelept",
    "neînțeleptul": "neînțelept",
    "neînțeleptului": "neînțelept",
    "neînțeleasa": "neînțeles",
    "neînțeleasă": "neînțeles",
    "neînțelese": "neînțeles",
    "neînțelesei": "neînțeles",
    "neînțelesele": "neînțeles",
    "neînțeleselor": "neînțeles",
    "neînțeleși": "neînțeles",
    "neînțeleșii": "neînțeles",
    "neînțeleșilor": "neînțeles",
    "neînțelesul": "neînțeles",
    "neînțelesului": "neînțeles",
    "neinteligenta": "neinteligent",
    "neinteligentă": "neinteligent",
    "neinteligente": "neinteligent",
    "neinteligentei": "neinteligent",
    "neinteligentele": "neinteligent",
    "neinteligentelor": "neinteligent",
    "neinteligenți": "neinteligent",
    "neinteligenții": "neinteligent",
    "neinteligenților": "neinteligent",
    "neinteligentul": "neinteligent",
    "neinteligentului": "neinteligent",
    "neîntemeiata": "neîntemeiat",
    "neîntemeiată": "neîntemeiat",
    "neîntemeiate": "neîntemeiat",
    "neîntemeiatei": "neîntemeiat",
    "neîntemeiatele": "neîntemeiat",
    "neîntemeiatelor": "neîntemeiat",
    "neîntemeiați": "neîntemeiat",
    "neîntemeiații": "neîntemeiat",
    "neîntemeiaților": "neîntemeiat",
    "neîntemeiatul": "neîntemeiat",
    "neîntemeiatului": "neîntemeiat",
    "neîntemnițată": "neîntemnițat",
    "neîntemnițate": "neîntemnițat",
    "neîntemnițați": "neîntemnițat",
    "neintensificată": "neintensificat",
    "neintensificate": "neintensificat",
    "neintensificați": "neintensificat",
    "neintentată": "neintentat",
    "neintentate": "neintentat",
    "neintentați": "neintentat",
    "neintenționata": "neintenționat",
    "neintenționată": "neintenționat",
    "neintenționate": "neintenționat",
    "neintenționatei": "neintenționat",
    "neintenționatele": "neintenționat",
    "neintenționatelor": "neintenționat",
    "neintenționați": "neintenționat",
    "neintenționații": "neintenționat",
    "neintenționaților": "neintenționat",
    "neintenționatul": "neintenționat",
    "neintenționatului": "neintenționat",
    "neînțepată": "neînțepat",
    "neînțepate": "neînțepat",
    "neînțepați": "neînțepat",
    "neînțepenită": "neînțepenit",
    "neînțepenite": "neînțepenit",
    "neînțepeniți": "neînțepenit",
    "neînțepușată": "neînțepușat",
    "neînțepușate": "neînțepușat",
    "neînțepușați": "neînțepușat",
    "neintercalată": "neintercalat",
    "neintercalate": "neintercalat",
    "neintercalați": "neintercalat",
    "neinterceptată": "neinterceptat",
    "neinterceptate": "neinterceptat",
    "neinterceptați": "neinterceptat",
    "neinterconectată": "neinterconectat",
    "neinterconectate": "neinterconectat",
    "neinterconectați": "neinterconectat",
    "neinteresanta": "neinteresant",
    "neinteresantă": "neinteresant",
    "neinteresante": "neinteresant",
    "neinteresantei": "neinteresant",
    "neinteresantele": "neinteresant",
    "neinteresantelor": "neinteresant",
    "neinteresanți": "neinteresant",
    "neinteresanții": "neinteresant",
    "neinteresanților": "neinteresant",
    "neinteresantul": "neinteresant",
    "neinteresantului": "neinteresant",
    "neinteresată": "neinteresat",
    "neinteresate": "neinteresat",
    "neinteresați": "neinteresat",
    "neinterferată": "neinterferat",
    "neinterferate": "neinterferat",
    "neinterferați": "neinterferat",
    "neinterfoliată": "neinterfoliat",
    "neinterfoliate": "neinterfoliat",
    "neinterfoliați": "neinterfoliat",
    "neinterliniată": "neinterliniat",
    "neinterliniate": "neinterliniat",
    "neinterliniați": "neinterliniat",
    "neintermediată": "neintermediat",
    "neintermediate": "neintermediat",
    "neintermediați": "neintermediat",
    "neinternată": "neinternat",
    "neinternate": "neinternat",
    "neinternați": "neinternat",
    "neinterogată": "neinterogat",
    "neinterogate": "neinterogat",
    "neinterogați": "neinterogat",
    "neinterpelată": "neinterpelat",
    "neinterpelate": "neinterpelat",
    "neinterpelați": "neinterpelat",
    "neinterpolată": "neinterpolat",
    "neinterpolate": "neinterpolat",
    "neinterpolați": "neinterpolat",
    "neinterpretată": "neinterpretat",
    "neinterpretate": "neinterpretat",
    "neinterpretați": "neinterpretat",
    "neinterpusă": "neinterpus",
    "neinterpuse": "neinterpus",
    "neinterpuși": "neinterpus",
    "neintersectată": "neintersectat",
    "neintersectate": "neintersectat",
    "neintersectați": "neintersectat",
    "neintervenită": "neintervenit",
    "neintervenite": "neintervenit",
    "neinterveniți": "neintervenit",
    "neintervenția": "neintervenție",
    "neintervenției": "neintervenție",
    "neintervenții": "neintervenție",
    "neintervențiile": "neintervenție",
    "neintervențiilor": "neintervenție",
    "neintervertită": "neintervertit",
    "neintervertite": "neintervertit",
    "neintervertiți": "neintervertit",
    "neintervievată": "neintervievat",
    "neintervievate": "neintervievat",
    "neintervievați": "neintervievat",
    "neinterzisa": "neinterzis",
    "neinterzisă": "neinterzis",
    "neinterzise": "neinterzis",
    "neinterzisei": "neinterzis",
    "neinterzisele": "neinterzis",
    "neinterziselor": "neinterzis",
    "neinterziși": "neinterzis",
    "neinterzișii": "neinterzis",
    "neinterzișilor": "neinterzis",
    "neinterzisul": "neinterzis",
    "neinterzisului": "neinterzis",
    "neînțesată": "neînțesat",
    "neînțesate": "neînțesat",
    "neînțesați": "neînțesat",
    "neîntețită": "neîntețit",
    "neîntețite": "neîntețit",
    "neîntețiți": "neîntețit",
    "neintimată": "neintimat",
    "neintimate": "neintimat",
    "neintimați": "neintimat",
    "neintimidată": "neintimidat",
    "neintimidate": "neintimidat",
    "neintimidați": "neintimidat",
    "neîntinata": "neîntinat",
    "neîntinată": "neîntinat",
    "neîntinate": "neîntinat",
    "neîntinatei": "neîntinat",
    "neîntinatele": "neîntinat",
    "neîntinatelor": "neîntinat",
    "neîntinați": "neîntinat",
    "neîntinații": "neîntinat",
    "neîntinaților": "neîntinat",
    "neîntinatul": "neîntinat",
    "neîntinatului": "neîntinat",
    "neîntinerită": "neîntinerit",
    "neîntinerite": "neîntinerit",
    "neîntineriți": "neîntinerit",
    "neîntinsa": "neîntins",
    "neîntinsă": "neîntins",
    "neîntinse": "neîntins",
    "neîntinsei": "neîntins",
    "neîntinsele": "neîntins",
    "neîntinselor": "neîntins",
    "neîntinși": "neîntins",
    "neîntinșii": "neîntins",
    "neîntinșilor": "neîntins",
    "neîntinsul": "neîntins",
    "neîntinsului": "neîntins",
    "neîntipărită": "neîntipărit",
    "neîntipărite": "neîntipărit",
    "neîntipăriți": "neîntipărit",
    "neintitulata": "neintitulat",
    "neintitulată": "neintitulat",
    "neintitulate": "neintitulat",
    "neintitulatei": "neintitulat",
    "neintitulatele": "neintitulat",
    "neintitulatelor": "neintitulat",
    "neintitulați": "neintitulat",
    "neintitulații": "neintitulat",
    "neintitulaților": "neintitulat",
    "neintitulatul": "neintitulat",
    "neintitulatului": "neintitulat",
    "neîntocmită": "neîntocmit",
    "neîntocmite": "neîntocmit",
    "neîntocmiți": "neîntocmit",
    "neînțolită": "neînțolit",
    "neînțolite": "neînțolit",
    "neînțoliți": "neînțolit",
    "neîntomnată": "neîntomnat",
    "neintonată": "neintonat",
    "neintonate": "neintonat",
    "neintonați": "neintonat",
    "neîntoarsa": "neîntors",
    "neîntoarsă": "neîntors",
    "neîntoarsei": "neîntors",
    "neîntoarsele": "neîntors",
    "neîntoarselor": "neîntors",
    "neîntorse": "neîntors",
    "neîntorși": "neîntors",
    "neîntorșii": "neîntors",
    "neîntorșilor": "neîntors",
    "neîntorsul": "neîntors",
    "neîntorsului": "neîntors",
    "neîntortocheata": "neîntortocheat",
    "neîntortocheată": "neîntortocheat",
    "neîntortocheate": "neîntortocheat",
    "neîntortocheatei": "neîntortocheat",
    "neîntortocheatele": "neîntortocheat",
    "neîntortocheatelor": "neîntortocheat",
    "neîntortocheați": "neîntortocheat",
    "neîntortocheații": "neîntortocheat",
    "neîntortocheaților": "neîntortocheat",
    "neîntortocheatul": "neîntortocheat",
    "neîntortocheatului": "neîntortocheat",
    "neîntovărășită": "neîntovărășit",
    "neîntovărășite": "neîntovărășit",
    "neîntovărășiți": "neîntovărășit",
    "neintoxicată": "neintoxicat",
    "neintoxicate": "neintoxicat",
    "neintoxicați": "neintoxicat",
    "neîntrajutorată": "neîntrajutorat",
    "neîntrajutorate": "neîntrajutorat",
    "neîntrajutorați": "neîntrajutorat",
    "neîntraripată": "neîntraripat",
    "neîntraripate": "neîntraripat",
    "neîntraripați": "neîntraripat",
    "neîntrarmată": "neîntrarmat",
    "neîntrarmate": "neîntrarmat",
    "neîntrarmați": "neîntrarmat",
    "neintrată": "neintrat",
    "neintrate": "neintrat",
    "neintrați": "neintrat",
    "neîntraurită": "neîntraurit",
    "neîntraurite": "neîntraurit",
    "neîntrauriți": "neîntraurit",
    "neîntrebată": "neîntrebat",
    "neîntrebate": "neîntrebat",
    "neîntrebați": "neîntrebat",
    "neîntrebuințată": "neîntrebuințat",
    "neîntrebuințate": "neîntrebuințat",
    "neîntrebuințați": "neîntrebuințat",
    "neîntrecuta": "neîntrecut",
    "neîntrecută": "neîntrecut",
    "neîntrecute": "neîntrecut",
    "neîntrecutei": "neîntrecut",
    "neîntrecutele": "neîntrecut",
    "neîntrecutelor": "neîntrecut",
    "neîntrecuți": "neîntrecut",
    "neîntrecuții": "neîntrecut",
    "neîntrecuților": "neîntrecut",
    "neîntrecutul": "neîntrecut",
    "neîntrecutului": "neîntrecut",
    "neîntredeschisa": "neîntredeschis",
    "neîntredeschisă": "neîntredeschis",
    "neîntredeschise": "neîntredeschis",
    "neîntredeschisei": "neîntredeschis",
    "neîntredeschisele": "neîntredeschis",
    "neîntredeschiselor": "neîntredeschis",
    "neîntredeschiși": "neîntredeschis",
    "neîntredeschișii": "neîntredeschis",
    "neîntredeschișilor": "neîntredeschis",
    "neîntredeschisul": "neîntredeschis",
    "neîntredeschisului": "neîntredeschis",
    "neîntregită": "neîntregit",
    "neîntregite": "neîntregit",
    "neîntregiți": "neîntregit",
    "neîntreită": "neîntreit",
    "neîntreite": "neîntreit",
    "neîntreiți": "neîntreit",
    "neîntremată": "neîntremat",
    "neîntremate": "neîntremat",
    "neîntremați": "neîntremat",
    "neîntrepătrunsă": "neîntrepătruns",
    "neîntrepătrunse": "neîntrepătruns",
    "neîntrepătrunși": "neîntrepătruns",
    "neîntreprinsă": "neîntreprins",
    "neîntreprinse": "neîntreprins",
    "neîntreprinși": "neîntreprins",
    "neîntrerupta": "neîntrerupt",
    "neîntreruptă": "neîntrerupt",
    "neîntrerupte": "neîntrerupt",
    "neîntreruptei": "neîntrerupt",
    "neîntreruptele": "neîntrerupt",
    "neîntreruptelor": "neîntrerupt",
    "neîntrerupți": "neîntrerupt",
    "neîntrerupții": "neîntrerupt",
    "neîntrerupților": "neîntrerupt",
    "neîntreruptul": "neîntrerupt",
    "neîntreruptului": "neîntrerupt",
    "neîntretăiată": "neîntretăiat",
    "neîntretăiate": "neîntretăiat",
    "neîntretăiați": "neîntretăiat",
    "neîntrețesută": "neîntrețesut",
    "neîntrețesute": "neîntrețesut",
    "neîntrețesuți": "neîntrețesut",
    "neîntreținută": "neîntreținut",
    "neîntreținute": "neîntreținut",
    "neîntreținuți": "neîntreținut",
    "neîntrevăzută": "neîntrevăzut",
    "neîntrevăzute": "neîntrevăzut",
    "neîntrevăzuți": "neîntrevăzut",
    "neîntrezărită": "neîntrezărit",
    "neîntrezărite": "neîntrezărit",
    "neîntrezăriți": "neîntrezărit",
    "neintrigată": "neintrigat",
    "neintrigate": "neintrigat",
    "neintrigați": "neintrigat",
    "neîntristata": "neîntristat",
    "neîntristată": "neîntristat",
    "neîntristate": "neîntristat",
    "neîntristatei": "neîntristat",
    "neîntristatele": "neîntristat",
    "neîntristatelor": "neîntristat",
    "neîntristați": "neîntristat",
    "neîntristații": "neîntristat",
    "neîntristaților": "neîntristat",
    "neîntristatul": "neîntristat",
    "neîntristatului": "neîntristat",
    "neintrodusă": "neintrodus",
    "neintroduse": "neintrodus",
    "neintroduși": "neintrodus",
    "neîntroienită": "neîntroienit",
    "neîntroienite": "neîntroienit",
    "neîntroieniți": "neîntroienit",
    "neîntronată": "neîntronat",
    "neîntronate": "neîntronat",
    "neîntronați": "neîntronat",
    "neîntruchipată": "neîntruchipat",
    "neîntruchipate": "neîntruchipat",
    "neîntruchipați": "neîntruchipat",
    "neîntrunită": "neîntrunit",
    "neîntrunite": "neîntrunit",
    "neîntruniți": "neîntrunit",
    "neîntrupată": "neîntrupat",
    "neîntrupate": "neîntrupat",
    "neîntrupați": "neîntrupat",
    "neintuită": "neintuit",
    "neintuite": "neintuit",
    "neintuiți": "neintuit",
    "neîntunecata": "neîntunecat",
    "neîntunecată": "neîntunecat",
    "neîntunecate": "neîntunecat",
    "neîntunecatei": "neîntunecat",
    "neîntunecatele": "neîntunecat",
    "neîntunecatelor": "neîntunecat",
    "neîntunecați": "neîntunecat",
    "neîntunecații": "neîntunecat",
    "neîntunecaților": "neîntunecat",
    "neîntunecatul": "neîntunecat",
    "neîntunecatului": "neîntunecat",
    "neinundată": "neinundat",
    "neinundate": "neinundat",
    "neinundați": "neinundat",
    "neinvadată": "neinvadat",
    "neinvadate": "neinvadat",
    "neinvadați": "neinvadat",
    "neînvălătucită": "neînvălătucit",
    "neînvălătucite": "neînvălătucit",
    "neînvălătuciți": "neînvălătucit",
    "neinvalidată": "neinvalidat",
    "neinvalidate": "neinvalidat",
    "neinvalidați": "neinvalidat",
    "neînvălmășită": "neînvălmășit",
    "neînvălmășite": "neînvălmășit",
    "neînvălmășiți": "neînvălmășit",
    "neînvăluită": "neînvăluit",
    "neînvăluite": "neînvăluit",
    "neînvăluiți": "neînvăluit",
    "neînvăpăiată": "neînvăpăiat",
    "neînvăpăiate": "neînvăpăiat",
    "neînvăpăiați": "neînvăpăiat",
    "neînvârtejită": "neînvârtejit",
    "neînvârtejite": "neînvârtejit",
    "neînvârtejiți": "neînvârtejit",
    "neînvârtită": "neînvârtit",
    "neînvârtite": "neînvârtit",
    "neînvârtiți": "neînvârtit",
    "neînvârtoșată": "neînvârtoșat",
    "neînvârtoșate": "neînvârtoșat",
    "neînvârtoșați": "neînvârtoșat",
    "neînvățată": "neînvățat",
    "neînvățate": "neînvățat",
    "neînvățați": "neînvățat",
    "neînvechita": "neînvechit",
    "neînvechită": "neînvechit",
    "neînvechite": "neînvechit",
    "neînvechitei": "neînvechit",
    "neînvechitele": "neînvechit",
    "neînvechitelor": "neînvechit",
    "neînvechiți": "neînvechit",
    "neînvechiții": "neînvechit",
    "neînvechiților": "neînvechit",
    "neînvechitul": "neînvechit",
    "neînvechitului": "neînvechit",
    "neînvecinata": "neînvecinat",
    "neînvecinată": "neînvecinat",
    "neînvecinate": "neînvecinat",
    "neînvecinatei": "neînvecinat",
    "neînvecinatele": "neînvecinat",
    "neînvecinatelor": "neînvecinat",
    "neînvecinați": "neînvecinat",
    "neînvecinații": "neînvecinat",
    "neînvecinaților": "neînvecinat",
    "neînvecinatul": "neînvecinat",
    "neînvecinatului": "neînvecinat",
    "neinvectivată": "neinvectivat",
    "neinvectivate": "neinvectivat",
    "neinvectivați": "neinvectivat",
    "neînvederată": "neînvederat",
    "neînvederate": "neînvederat",
    "neînvederați": "neînvederat",
    "neînvelită": "neînvelit",
    "neînvelite": "neînvelit",
    "neînveliți": "neînvelit",
    "neînveninată": "neînveninat",
    "neînveninate": "neînveninat",
    "neînveninați": "neînveninat",
    "neinventariată": "neinventariat",
    "neinventariate": "neinventariat",
    "neinventariați": "neinventariat",
    "neinventată": "neinventat",
    "neinventate": "neinventat",
    "neinventați": "neinventat",
    "neinversată": "neinversat",
    "neinversate": "neinversat",
    "neinversați": "neinversat",
    "neînverșunată": "neînverșunat",
    "neînverșunate": "neînverșunat",
    "neînverșunați": "neînverșunat",
    "neinvertită": "neinvertit",
    "neinvertite": "neinvertit",
    "neinvertiți": "neinvertit",
    "neînverzita": "neînverzit",
    "neînverzită": "neînverzit",
    "neînverzite": "neînverzit",
    "neînverzitei": "neînverzit",
    "neînverzitele": "neînverzit",
    "neînverzitelor": "neînverzit",
    "neînverziți": "neînverzit",
    "neînverziții": "neînverzit",
    "neînverziților": "neînverzit",
    "neînverzitul": "neînverzit",
    "neînverzitului": "neînverzit",
    "neînveselită": "neînveselit",
    "neînveselite": "neînveselit",
    "neînveseliți": "neînveselit",
    "neînveșmântată": "neînveșmântat",
    "neînveșmântate": "neînveșmântat",
    "neînveșmântați": "neînveșmântat",
    "neînveșnicită": "neînveșnicit",
    "neînveșnicite": "neînveșnicit",
    "neînveșniciți": "neînveșnicit",
    "neinvestigată": "neinvestigat",
    "neinvestigate": "neinvestigat",
    "neinvestigați": "neinvestigat",
    "neinvestită": "neinvestit",
    "neinvestite": "neinvestit",
    "neinvestiți": "neinvestit",
    "neînvestită": "neînvestit",
    "neînvestite": "neînvestit",
    "neînvestiți": "neînvestit",
    "neînviată": "neînviat",
    "neînviate": "neînviat",
    "neînviați": "neînviat",
    "neinvidiată": "neinvidiat",
    "neinvidiate": "neinvidiat",
    "neinvidiați": "neinvidiat",
    "neînviforată": "neînviforat",
    "neînvinețită": "neînvinețit",
    "neînvinețite": "neînvinețit",
    "neînvinețiți": "neînvinețit",
    "neînvinovățită": "neînvinovățit",
    "neînvinovățite": "neînvinovățit",
    "neînvinovățiți": "neînvinovățit",
    "neînvinsa": "neînvins",
    "neînvinsă": "neînvins",
    "neînvinse": "neînvins",
    "neînvinsei": "neînvins",
    "neînvinsele": "neînvins",
    "neînvinselor": "neînvins",
    "neînvinși": "neînvins",
    "neînvinșii": "neînvins",
    "neînvinșilor": "neînvins",
    "neînvinsul": "neînvins",
    "neînvinsului": "neînvins",
    "neînvinuită": "neînvinuit",
    "neînvinuite": "neînvinuit",
    "neînvinuiți": "neînvinuit",
    "neînviorată": "neînviorat",
    "neînviorate": "neînviorat",
    "neînviorați": "neînviorat",
    "neinvitarea": "neinvitare",
    "neinvitări": "neinvitare",
    "neinvitării": "neinvitare",
    "neinvitările": "neinvitare",
    "neinvitărilor": "neinvitare",
    "neinvitată": "neinvitat",
    "neinvitate": "neinvitat",
    "neinvitați": "neinvitat",
    "neînvoită": "neînvoit",
    "neînvoite": "neînvoit",
    "neînvoiți": "neînvoit",
    "neînvolburata": "neînvolburat",
    "neînvolburată": "neînvolburat",
    "neînvolburate": "neînvolburat",
    "neînvolburatei": "neînvolburat",
    "neînvolburatele": "neînvolburat",
    "neînvolburatelor": "neînvolburat",
    "neînvolburați": "neînvolburat",
    "neînvolburații": "neînvolburat",
    "neînvolburaților": "neînvolburat",
    "neînvolburatul": "neînvolburat",
    "neînvolburatului": "neînvolburat",
    "neînvrăjbită": "neînvrăjbit",
    "neînvrăjbite": "neînvrăjbit",
    "neînvrăjbiți": "neînvrăjbit",
    "neînvrăjmășită": "neînvrăjmășit",
    "neînvrăjmășite": "neînvrăjmășit",
    "neînvrăjmășiți": "neînvrăjmășit",
    "neînvrednicită": "neînvrednicit",
    "neînvrednicite": "neînvrednicit",
    "neînvredniciți": "neînvrednicit",
    "neînzăpezita": "neînzăpezit",
    "neînzăpezită": "neînzăpezit",
    "neînzăpezite": "neînzăpezit",
    "neînzăpezitei": "neînzăpezit",
    "neînzăpezitele": "neînzăpezit",
    "neînzăpezitelor": "neînzăpezit",
    "neînzăpeziți": "neînzăpezit",
    "neînzăpeziții": "neînzăpezit",
    "neînzăpeziților": "neînzăpezit",
    "neînzăpezitul": "neînzăpezit",
    "neînzăpezitului": "neînzăpezit",
    "neînzdrăvenită": "neînzdrăvenit",
    "neînzdrăvenite": "neînzdrăvenit",
    "neînzdrăveniți": "neînzdrăvenit",
    "neînzecită": "neînzecit",
    "neînzecite": "neînzecit",
    "neînzeciți": "neînzecit",
    "neînzestrata": "neînzestrat",
    "neînzestrată": "neînzestrat",
    "neînzestrate": "neînzestrat",
    "neînzestratei": "neînzestrat",
    "neînzestratele": "neînzestrat",
    "neînzestratelor": "neînzestrat",
    "neînzestrați": "neînzestrat",
    "neînzestrații": "neînzestrat",
    "neînzestraților": "neînzestrat",
    "neînzestratul": "neînzestrat",
    "neînzestratului": "neînzestrat",
    "neînzidită": "neînzidit",
    "neînzidite": "neînzidit",
    "neînzidiți": "neînzidit",
    "neînzorzonata": "neînzorzonat",
    "neînzorzonată": "neînzorzonat",
    "neînzorzonate": "neînzorzonat",
    "neînzorzonatei": "neînzorzonat",
    "neînzorzonatele": "neînzorzonat",
    "neînzorzonatelor": "neînzorzonat",
    "neînzorzonați": "neînzorzonat",
    "neînzorzonații": "neînzorzonat",
    "neînzorzonaților": "neînzorzonat",
    "neînzorzonatul": "neînzorzonat",
    "neînzorzonatului": "neînzorzonat",
    "neiobăgită": "neiobăgit",
    "neiobăgite": "neiobăgit",
    "neiobăgiți": "neiobăgit",
    "neionizată": "neionizat",
    "neionizate": "neionizat",
    "neionizați": "neionizat",
    "neiotacizată": "neiotacizat",
    "neiotacizate": "neiotacizat",
    "neiotacizați": "neiotacizat",
    "neipotecată": "neipotecat",
    "neipotecate": "neipotecat",
    "neipotecați": "neipotecat",
    "neiradiată": "neiradiat",
    "neiradiate": "neiradiat",
    "neiradiați": "neiradiat",
    "neirigată": "neirigat",
    "neirigate": "neirigat",
    "neirigați": "neirigat",
    "neiritată": "neiritat",
    "neiritate": "neiritat",
    "neiritați": "neiritat",
    "neirizată": "neirizat",
    "neirizate": "neirizat",
    "neirizați": "neirizat",
    "neironizată": "neironizat",
    "neironizate": "neironizat",
    "neironizați": "neironizat",
    "neirosită": "neirosit",
    "neirosite": "neirosit",
    "neirosiți": "neirosit",
    "neiscălită": "neiscălit",
    "neiscălite": "neiscălit",
    "neiscăliți": "neiscălit",
    "neiscată": "neiscat",
    "neiscate": "neiscat",
    "neiscați": "neiscat",
    "neiscodită": "neiscodit",
    "neiscodite": "neiscodit",
    "neiscodiți": "neiscodit",
    "neiscusita": "neiscusit",
    "neiscusită": "neiscusit",
    "neiscusite": "neiscusit",
    "neiscusitei": "neiscusit",
    "neiscusitele": "neiscusit",
    "neiscusitelor": "neiscusit",
    "neiscusiți": "neiscusit",
    "neiscusiții": "neiscusit",
    "neiscusiților": "neiscusit",
    "neiscusitul": "neiscusit",
    "neiscusitului": "neiscusit",
    "neispășită": "neispășit",
    "neispășite": "neispășit",
    "neispășiți": "neispășit",
    "neispitită": "neispitit",
    "neispitite": "neispitit",
    "neispitiți": "neispitit",
    "neisprăvita": "neisprăvit",
    "neisprăvită": "neisprăvit",
    "neisprăvite": "neisprăvit",
    "neisprăvitei": "neisprăvit",
    "neisprăvitele": "neisprăvit",
    "neisprăvitelor": "neisprăvit",
    "neisprăviți": "neisprăvit",
    "neisprăviții": "neisprăvit",
    "neisprăviților": "neisprăvit",
    "neisprăvitul": "neisprăvit",
    "neisprăvitului": "neisprăvit",
    "neisprăvita": "neisprăvită",
    "neisprăvite": "neisprăvită",
    "neisprăvitei": "neisprăvită",
    "neisprăvitele": "neisprăvită",
    "neisprăvitelor": "neisprăvită",
    "neistorisită": "neistorisit",
    "neistorisite": "neistorisit",
    "neistorisiți": "neistorisit",
    "neistovita": "neistovit",
    "neistovită": "neistovit",
    "neistovite": "neistovit",
    "neistovitei": "neistovit",
    "neistovitele": "neistovit",
    "neistovitelor": "neistovit",
    "neistoviți": "neistovit",
    "neistoviții": "neistovit",
    "neistoviților": "neistovit",
    "neistovitul": "neistovit",
    "neistovitului": "neistovit",
    "neitalienizată": "neitalienizat",
    "neitalienizate": "neitalienizat",
    "neitalienizați": "neitalienizat",
    "neiubită": "neiubit",
    "neiubite": "neiubit",
    "neiubiți": "neiubit",
    "neiuțită": "neiuțit",
    "neiuțite": "neiuțit",
    "neiuțiți": "neiuțit",
    "neivită": "neivit",
    "neivite": "neivit",
    "neiviți": "neivit",
    "neizbânda": "neizbândă",
    "neizbândi": "neizbândă",
    "neizbândii": "neizbândă",
    "neizbândită": "neizbândit",
    "neizbândite": "neizbândit",
    "neizbândiți": "neizbândit",
    "neizbăvită": "neizbăvit",
    "neizbăvite": "neizbăvit",
    "neizbăviți": "neizbăvit",
    "neizbită": "neizbit",
    "neizbite": "neizbit",
    "neizbiți": "neizbit",
    "neizbucnită": "neizbucnit",
    "neizbucnite": "neizbucnit",
    "neizbucniți": "neizbucnit",
    "neizbutita": "neizbutit",
    "neizbutită": "neizbutit",
    "neizbutite": "neizbutit",
    "neizbutitei": "neizbutit",
    "neizbutitele": "neizbutit",
    "neizbutitelor": "neizbutit",
    "neizbutiți": "neizbutit",
    "neizbutiții": "neizbutit",
    "neizbutiților": "neizbutit",
    "neizbutitul": "neizbutit",
    "neizbutitului": "neizbutit",
    "neizgonită": "neizgonit",
    "neizgonite": "neizgonit",
    "neizgoniți": "neizgonit",
    "neizmenită": "neizmenit",
    "neizmenite": "neizmenit",
    "neizmeniți": "neizmenit",
    "neizolata": "neizolat",
    "neizolată": "neizolat",
    "neizolate": "neizolat",
    "neizolatei": "neizolat",
    "neizolatele": "neizolat",
    "neizolatelor": "neizolat",
    "neizolați": "neizolat",
    "neizolații": "neizolat",
    "neizolaților": "neizolat",
    "neizolatul": "neizolat",
    "neizolatului": "neizolat",
    "neizvodită": "neizvodit",
    "neizvodite": "neizvodit",
    "neizvodiți": "neizvodit",
    "neizvorâtă": "neizvorât",
    "neizvorâte": "neizvorât",
    "neizvorâți": "neizvorât",
    "nejalonată": "nejalonat",
    "nejalonate": "nejalonat",
    "nejalonați": "nejalonat",
    "nejăruită": "nejăruit",
    "nejăruite": "nejăruit",
    "nejăruiți": "nejăruit",
    "nejecmănită": "nejecmănit",
    "nejecmănite": "nejecmănit",
    "nejecmăniți": "nejecmănit",
    "nejefuită": "nejefuit",
    "nejefuite": "nejefuit",
    "nejefuiți": "nejefuit",
    "nejelită": "nejelit",
    "nejelite": "nejelit",
    "nejeliți": "nejelit",
    "nejeluită": "nejeluit",
    "nejeluite": "nejeluit",
    "nejeluiți": "nejeluit",
    "nejenata": "nejenat",
    "nejenată": "nejenat",
    "nejenate": "nejenat",
    "nejenatei": "nejenat",
    "nejenatele": "nejenat",
    "nejenatelor": "nejenat",
    "nejenați": "nejenat",
    "nejenații": "nejenat",
    "nejenaților": "nejenat",
    "nejenatul": "nejenat",
    "nejenatului": "nejenat",
    "nejerpelita": "nejerpelit",
    "nejerpelită": "nejerpelit",
    "nejerpelite": "nejerpelit",
    "nejerpelitei": "nejerpelit",
    "nejerpelitele": "nejerpelit",
    "nejerpelitelor": "nejerpelit",
    "nejerpeliți": "nejerpelit",
    "nejerpeliții": "nejerpelit",
    "nejerpeliților": "nejerpelit",
    "nejerpelitul": "nejerpelit",
    "nejerpelitului": "nejerpelit",
    "nejertfită": "nejertfit",
    "nejertfite": "nejertfit",
    "nejertfiți": "nejertfit",
    "nejigărita": "nejigărit",
    "nejigărită": "nejigărit",
    "nejigărite": "nejigărit",
    "nejigăritei": "nejigărit",
    "nejigăritele": "nejigărit",
    "nejigăritelor": "nejigărit",
    "nejigăriți": "nejigărit",
    "nejigăriții": "nejigărit",
    "nejigăriților": "nejigărit",
    "nejigăritul": "nejigărit",
    "nejigăritului": "nejigărit",
    "nejignită": "nejignit",
    "nejignite": "nejignit",
    "nejigniți": "nejignit",
    "nejilăvită": "nejilăvit",
    "nejilăvite": "nejilăvit",
    "nejilăviți": "nejilăvit",
    "nejinduită": "nejinduit",
    "nejinduite": "nejinduit",
    "nejinduiți": "nejinduit",
    "nejintuită": "nejintuit",
    "nejintuite": "nejintuit",
    "nejintuiți": "nejintuit",
    "nejonglată": "nejonglat",
    "nejonglate": "nejonglat",
    "nejonglați": "nejonglat",
    "nejubilată": "nejubilat",
    "nejubilate": "nejubilat",
    "nejubilați": "nejubilat",
    "nejucată": "nejucat",
    "nejucate": "nejucat",
    "nejucați": "nejucat",
    "nejudecată": "nejudecat",
    "nejudecate": "nejudecat",
    "nejudecați": "nejudecat",
    "nejugulată": "nejugulat",
    "nejugulate": "nejugulat",
    "nejugulați": "nejugulat",
    "nejuisată": "nejuisat",
    "nejuisate": "nejuisat",
    "nejuisați": "nejuisat",
    "nejulită": "nejulit",
    "nejulite": "nejulit",
    "nejuliți": "nejulit",
    "nejumătățită": "nejumătățit",
    "nejumătățite": "nejumătățit",
    "nejumătățiți": "nejumătățit",
    "nejumulită": "nejumulit",
    "nejumulite": "nejumulit",
    "nejumuliți": "nejumulit",
    "nejunghiată": "nejunghiat",
    "nejunghiate": "nejunghiat",
    "nejunghiați": "nejunghiat",
    "nejupuită": "nejupuit",
    "nejupuite": "nejupuit",
    "nejupuiți": "nejupuit",
    "nejurată": "nejurat",
    "nejurate": "nejurat",
    "nejurați": "nejurat",
    "nejuruită": "nejuruit",
    "nejuruite": "nejuruit",
    "nejuruiți": "nejuruit",
    "nejustificată": "nejustificat",
    "nejustificate": "nejustificat",
    "nejustificați": "nejustificat",
    "nejuxtapusă": "nejuxtapus",
    "nejuxtapuse": "nejuxtapus",
    "nejuxtapuși": "nejuxtapus",
    "nekilometrată": "nekilometrat",
    "nekilometrate": "nekilometrat",
    "nekilometrați": "nekilometrat",
    "nelăbărțată": "nelăbărțat",
    "nelăbărțate": "nelăbărțat",
    "nelăbărțați": "nelăbărțat",
    "nelabializată": "nelabializat",
    "nelabializate": "nelabializat",
    "nelabializați": "nelabializat",
    "nelăcomită": "nelăcomit",
    "nelăcomite": "nelăcomit",
    "nelăcomiți": "nelăcomit",
    "nelăcrimată": "nelăcrimat",
    "nelăcrimate": "nelăcrimat",
    "nelăcrimați": "nelăcrimat",
    "nelăcuită": "nelăcuit",
    "nelăcuite": "nelăcuit",
    "nelăcuiți": "nelăcuit",
    "nelăfăită": "nelăfăit",
    "nelăfăite": "nelăfăit",
    "nelăfăiți": "nelăfăit",
    "nelaicizată": "nelaicizat",
    "nelaicizate": "nelaicizat",
    "nelaicizați": "nelaicizat",
    "nelălăită": "nelălăit",
    "nelălăite": "nelălăit",
    "nelălăiți": "nelălăit",
    "nelambrisată": "nelambrisat",
    "nelambrisate": "nelambrisat",
    "nelambrisați": "nelambrisat",
    "nelamentată": "nelamentat",
    "nelamentate": "nelamentat",
    "nelamentați": "nelamentat",
    "nelaminată": "nelaminat",
    "nelaminate": "nelaminat",
    "nelaminați": "nelaminat",
    "nelămurirea": "nelămurire",
    "nelămuriri": "nelămurire",
    "nelămuririi": "nelămurire",
    "nelămuririle": "nelămurire",
    "nelămuririlor": "nelămurire",
    "nelămurita": "nelămurit",
    "nelămurită": "nelămurit",
    "nelămurite": "nelămurit",
    "nelămuritei": "nelămurit",
    "nelămuritele": "nelămurit",
    "nelămuritelor": "nelămurit",
    "nelămuriți": "nelămurit",
    "nelămuriții": "nelămurit",
    "nelămuriților": "nelămurit",
    "nelămuritul": "nelămurit",
    "nelămuritului": "nelămurit",
    "nelâncezită": "nelâncezit",
    "nelâncezite": "nelâncezit",
    "nelânceziți": "nelâncezit",
    "nelansată": "nelansat",
    "nelansate": "nelansat",
    "nelansați": "nelansat",
    "nelapidată": "nelapidat",
    "nelapidate": "nelapidat",
    "nelapidați": "nelapidat",
    "nelărgită": "nelărgit",
    "nelărgite": "nelărgit",
    "nelărgiți": "nelărgit",
    "nelăsată": "nelăsat",
    "nelăsate": "nelăsat",
    "nelăsați": "nelăsat",
    "nelatinizată": "nelatinizat",
    "nelatinizate": "nelatinizat",
    "nelatinizați": "nelatinizat",
    "nelățită": "nelățit",
    "nelățite": "nelățit",
    "nelățiți": "nelățit",
    "nelătrată": "nelătrat",
    "nelătrate": "nelătrat",
    "nelătrați": "nelătrat",
    "nelăudată": "nelăudat",
    "nelăudate": "nelăudat",
    "nelăudați": "nelăudat",
    "nelăuzită": "nelăuzit",
    "nelăuzite": "nelăuzit",
    "nelăuziți": "nelăuzit",
    "nelecturată": "nelecturat",
    "nelecturate": "nelecturat",
    "nelecturați": "nelecturat",
    "nelecuită": "nelecuit",
    "nelecuite": "nelecuit",
    "nelecuiți": "nelecuit",
    "nelefterită": "nelefterit",
    "nelefterite": "nelefterit",
    "nelefteriți": "nelefterit",
    "nelegalizată": "nelegalizat",
    "nelegalizate": "nelegalizat",
    "nelegalizați": "nelegalizat",
    "nelegănata": "nelegănat",
    "nelegănată": "nelegănat",
    "nelegănate": "nelegănat",
    "nelegănatei": "nelegănat",
    "nelegănatele": "nelegănat",
    "nelegănatelor": "nelegănat",
    "nelegănați": "nelegănat",
    "nelegănații": "nelegănat",
    "nelegănaților": "nelegănat",
    "nelegănatul": "nelegănat",
    "nelegănatului": "nelegănat",
    "nelegată": "nelegat",
    "nelegate": "nelegat",
    "nelegați": "nelegat",
    "nelegiferată": "nelegiferat",
    "nelegiferate": "nelegiferat",
    "nelegiferați": "nelegiferat",
    "nelegislată": "nelegislat",
    "nelegislate": "nelegislat",
    "nelegislați": "nelegislat",
    "nelegitima": "nelegitim",
    "nelegitimă": "nelegitim",
    "nelegitime": "nelegitim",
    "nelegitimei": "nelegitim",
    "nelegitimele": "nelegitim",
    "nelegitimelor": "nelegitim",
    "nelegitimi": "nelegitim",
    "nelegitimii": "nelegitim",
    "nelegitimilor": "nelegitim",
    "nelegitimul": "nelegitim",
    "nelegitimului": "nelegitim",
    "nelegitimată": "nelegitimat",
    "nelegitimate": "nelegitimat",
    "nelegitimați": "nelegitimat",
    "nelegiuirea": "nelegiuire",
    "nelegiuiri": "nelegiuire",
    "nelegiuirii": "nelegiuire",
    "nelegiuirile": "nelegiuire",
    "nelegiuirilor": "nelegiuire",
    "nelegiuita": "nelegiuit",
    "nelegiuită": "nelegiuit",
    "nelegiuite": "nelegiuit",
    "nelegiuitei": "nelegiuit",
    "nelegiuitele": "nelegiuit",
    "nelegiuitelor": "nelegiuit",
    "nelegiuiți": "nelegiuit",
    "nelegiuiții": "nelegiuit",
    "nelegiuiților": "nelegiuit",
    "nelegiuitul": "nelegiuit",
    "nelegiuitului": "nelegiuit",
    "nelehămetisită": "nelehămetisit",
    "nelehămetisite": "nelehămetisit",
    "nelehămetisiți": "nelehămetisit",
    "nelehămețită": "nelehămețit",
    "nelehămețite": "nelehămețit",
    "nelehămețiți": "nelehămețit",
    "nelenevită": "nelenevit",
    "nelenevite": "nelenevit",
    "neleneviți": "nelenevit",
    "neleorcăită": "neleorcăit",
    "neleorcăite": "neleorcăit",
    "neleorcăiți": "neleorcăit",
    "nelepădată": "nelepădat",
    "nelepădate": "nelepădat",
    "nelepădați": "nelepădat",
    "neleșinată": "neleșinat",
    "neleșinate": "neleșinat",
    "neleșinați": "neleșinat",
    "nelezată": "nelezat",
    "nelezate": "nelezat",
    "nelezați": "nelezat",
    "nelibera": "neliber",
    "neliberă": "neliber",
    "nelibere": "neliber",
    "neliberei": "neliber",
    "neliberele": "neliber",
    "neliberelor": "neliber",
    "neliberi": "neliber",
    "neliberii": "neliber",
    "neliberilor": "neliber",
    "neliberul": "neliber",
    "neliberului": "neliber",
    "neliberată": "neliberat",
    "neliberate": "neliberat",
    "neliberați": "neliberat",
    "nelibertatea": "nelibertate",
    "nelibertăți": "nelibertate",
    "nelibertății": "nelibertate",
    "nelibertățile": "nelibertate",
    "nelibertăților": "nelibertate",
    "nelicărită": "nelicărit",
    "nelicărite": "nelicărit",
    "nelicăriți": "nelicărit",
    "nelicențiată": "nelicențiat",
    "nelicențiate": "nelicențiat",
    "nelicențiați": "nelicențiat",
    "nelichidată": "nelichidat",
    "nelichidate": "nelichidat",
    "nelichidați": "nelichidat",
    "nelicitată": "nelicitat",
    "nelicitate": "nelicitat",
    "nelicitați": "nelicitat",
    "nelimitata": "nelimitat",
    "nelimitată": "nelimitat",
    "nelimitate": "nelimitat",
    "nelimitatei": "nelimitat",
    "nelimitatele": "nelimitat",
    "nelimitatelor": "nelimitat",
    "nelimitați": "nelimitat",
    "nelimitații": "nelimitat",
    "nelimitaților": "nelimitat",
    "nelimitatul": "nelimitat",
    "nelimitatului": "nelimitat",
    "nelimpezită": "nelimpezit",
    "nelimpezite": "nelimpezit",
    "nelimpeziți": "nelimpezit",
    "nelingușită": "nelingușit",
    "nelingușite": "nelingușit",
    "nelingușiți": "nelingușit",
    "neliniată": "neliniat",
    "neliniate": "neliniat",
    "neliniați": "neliniat",
    "neliniștea": "neliniște",
    "neliniști": "neliniște",
    "neliniștii": "neliniște",
    "neliniștile": "neliniște",
    "neliniștilor": "neliniște",
    "neliniștea": "neliniști",
    "nelinișteai": "neliniști",
    "nelinișteam": "neliniști",
    "neliniștească": "neliniști",
    "nelinișteați": "neliniști",
    "nelinișteau": "neliniști",
    "neliniștesc": "neliniști",
    "neliniștește": "neliniști",
    "neliniștești": "neliniști",
    "neliniștii": "neliniști",
    "neliniștim": "neliniști",
    "neliniștind": "neliniști",
    "neliniștindu": "neliniști",
    "neliniștiră": "neliniști",
    "neliniștirăm": "neliniști",
    "neliniștirăți": "neliniști",
    "neliniștise": "neliniști",
    "neliniștisem": "neliniști",
    "neliniștiseră": "neliniști",
    "neliniștiserăm": "neliniști",
    "neliniștiserăți": "neliniști",
    "neliniștiseși": "neliniști",
    "neliniștiși": "neliniști",
    "neliniștit": "neliniști",
    "neliniștiți": "neliniști",
    "nemaineliniștindu": "neliniști",
    "neneliniștindu": "neliniști",
    "neliniștita": "neliniștit",
    "neliniștită": "neliniștit",
    "neliniștite": "neliniștit",
    "neliniștitei": "neliniștit",
    "neliniștitele": "neliniștit",
    "neliniștitelor": "neliniștit",
    "neliniștiți": "neliniștit",
    "neliniștiții": "neliniștit",
    "neliniștiților": "neliniștit",
    "neliniștitul": "neliniștit",
    "neliniștitului": "neliniștit",
    "neliniștitoare": "neliniștitor",
    "neliniștitoarea": "neliniștitor",
    "neliniștitoarei": "neliniștitor",
    "neliniștitoarele": "neliniștitor",
    "neliniștitoarelor": "neliniștitor",
    "neliniștitori": "neliniștitor",
    "neliniștitorii": "neliniștitor",
    "neliniștitorilor": "neliniștitor",
    "neliniștitorul": "neliniștitor",
    "neliniștitorului": "neliniștitor",
    "nelinsă": "nelins",
    "nelinse": "nelins",
    "nelinși": "nelins",
    "nelinșată": "nelinșat",
    "nelinșate": "nelinșat",
    "nelinșați": "nelinșat",
    "nelipăită": "nelipăit",
    "nelipăite": "nelipăit",
    "nelipăiți": "nelipăit",
    "nelipită": "nelipit",
    "nelipite": "nelipit",
    "nelipiți": "nelipit",
    "nelipsita": "nelipsit",
    "nelipsită": "nelipsit",
    "nelipsite": "nelipsit",
    "nelipsitei": "nelipsit",
    "nelipsitele": "nelipsit",
    "nelipsitelor": "nelipsit",
    "nelipsiți": "nelipsit",
    "nelipsiții": "nelipsit",
    "nelipsiților": "nelipsit",
    "nelipsitul": "nelipsit",
    "nelipsitului": "nelipsit",
    "neliterarizată": "neliterarizat",
    "neliterarizate": "neliterarizat",
    "neliterarizați": "neliterarizat",
    "neliteraturizată": "neliteraturizat",
    "neliteraturizate": "neliteraturizat",
    "neliteraturizați": "neliteraturizat",
    "nelitografiată": "nelitografiat",
    "nelitografiate": "nelitografiat",
    "nelitografiați": "nelitografiat",
    "nelivrarea": "nelivrare",
    "nelivrari": "nelivrare",
    "nelivrarii": "nelivrare",
    "nelivrarile": "nelivrare",
    "nelivrarilor": "nelivrare",
    "nelivrată": "nelivrat",
    "nelivrate": "nelivrat",
    "nelivrați": "nelivrat",
    "nelocalizată": "nelocalizat",
    "nelocalizate": "nelocalizat",
    "nelocalizați": "nelocalizat",
    "nelocuita": "nelocuit",
    "nelocuită": "nelocuit",
    "nelocuite": "nelocuit",
    "nelocuitei": "nelocuit",
    "nelocuitele": "nelocuit",
    "nelocuitelor": "nelocuit",
    "nelocuiți": "nelocuit",
    "nelocuiții": "nelocuit",
    "nelocuiților": "nelocuit",
    "nelocuitul": "nelocuit",
    "nelocuitului": "nelocuit",
    "nelogaritmată": "nelogaritmat",
    "nelogaritmate": "nelogaritmat",
    "nelogaritmați": "nelogaritmat",
    "nelogodită": "nelogodit",
    "nelogodite": "nelogodit",
    "nelogodiți": "nelogodit",
    "neloiala": "neloial",
    "neloială": "neloial",
    "neloiale": "neloial",
    "neloialei": "neloial",
    "neloialele": "neloial",
    "neloialelor": "neloial",
    "neloiali": "neloial",
    "neloialii": "neloial",
    "neloialilor": "neloial",
    "nelovită": "nelovit",
    "nelovite": "nelovit",
    "neloviți": "nelovit",
    "Nelule": "Nelu",
    "neluată": "neluat",
    "neluate": "neluat",
    "neluați": "neluat",
    "nelucită": "nelucit",
    "nelucite": "nelucit",
    "neluciți": "nelucit",
    "nelucrată": "nelucrat",
    "nelucrate": "nelucrat",
    "nelucrați": "nelucrat",
    "nelumeasca": "nelumesc",
    "nelumească": "nelumesc",
    "nelumescul": "nelumesc",
    "nelumescului": "nelumesc",
    "nelumești": "nelumesc",
    "nelumeștii": "nelumesc",
    "nelumeștile": "nelumesc",
    "nelumeștilor": "nelumesc",
    "neluminata": "neluminat",
    "neluminată": "neluminat",
    "neluminate": "neluminat",
    "neluminatei": "neluminat",
    "neluminatele": "neluminat",
    "neluminatelor": "neluminat",
    "neluminați": "neluminat",
    "neluminații": "neluminat",
    "neluminaților": "neluminat",
    "neluminatul": "neluminat",
    "neluminatului": "neluminat",
    "nelunecată": "nelunecat",
    "nelunecate": "nelunecat",
    "nelunecați": "nelunecat",
    "neluptată": "neluptat",
    "neluptate": "neluptat",
    "neluptați": "neluptat",
    "nelustruită": "nelustruit",
    "nelustruite": "nelustruit",
    "nelustruiți": "nelustruit",
    "neluxată": "neluxat",
    "neluxate": "neluxat",
    "neluxați": "neluxat",
    "nemăcelărită": "nemăcelărit",
    "nemăcelărite": "nemăcelărit",
    "nemăcelăriți": "nemăcelărit",
    "nemacerată": "nemacerat",
    "nemacerate": "nemacerat",
    "nemacerați": "nemacerat",
    "nemachiată": "nemachiat",
    "nemachiate": "nemachiat",
    "nemachiați": "nemachiat",
    "nemăcinată": "nemăcinat",
    "nemăcinate": "nemăcinat",
    "nemăcinați": "nemăcinat",
    "nemăgulită": "nemăgulit",
    "nemăgulite": "nemăgulit",
    "nemăguliți": "nemăgulit",
    "nemâhnita": "nemâhnit",
    "nemâhnită": "nemâhnit",
    "nemâhnite": "nemâhnit",
    "nemâhnitei": "nemâhnit",
    "nemâhnitele": "nemâhnit",
    "nemâhnitelor": "nemâhnit",
    "nemâhniți": "nemâhnit",
    "nemâhniții": "nemâhnit",
    "nemâhniților": "nemâhnit",
    "nemâhnitul": "nemâhnit",
    "nemâhnitului": "nemâhnit",
    "nemaiatinsa": "nemaiatins",
    "nemaiatinsă": "nemaiatins",
    "nemaiatinse": "nemaiatins",
    "nemaiatinsei": "nemaiatins",
    "nemaiatinsele": "nemaiatins",
    "nemaiatinselor": "nemaiatins",
    "nemaiatinși": "nemaiatins",
    "nemaiatinșii": "nemaiatins",
    "nemaiatinșilor": "nemaiatins",
    "nemaiatinsul": "nemaiatins",
    "nemaiatinsului": "nemaiatins",
    "nemaiauzita": "nemaiauzit",
    "nemaiauzită": "nemaiauzit",
    "nemaiauzite": "nemaiauzit",
    "nemaiauzitei": "nemaiauzit",
    "nemaiauzitele": "nemaiauzit",
    "nemaiauzitelor": "nemaiauzit",
    "nemaiauziți": "nemaiauzit",
    "nemaiauziții": "nemaiauzit",
    "nemaiauziților": "nemaiauzit",
    "nemaiauzitul": "nemaiauzit",
    "nemaiauzitului": "nemaiauzit",
    "nemaibănuiși": "nemaibănuit",
    "nemaibănuișii": "nemaibănuit",
    "nemaibănuișilor": "nemaibănuit",
    "nemaibănuita": "nemaibănuit",
    "nemaibănuită": "nemaibănuit",
    "nemaibănuite": "nemaibănuit",
    "nemaibănuitei": "nemaibănuit",
    "nemaibănuitele": "nemaibănuit",
    "nemaibănuitelor": "nemaibănuit",
    "nemaibănuitul": "nemaibănuit",
    "nemaibănuitului": "nemaibănuit",
    "nemaicunoscuta": "nemaicunoscut",
    "nemaicunoscută": "nemaicunoscut",
    "nemaicunoscute": "nemaicunoscut",
    "nemaicunoscutei": "nemaicunoscut",
    "nemaicunoscutele": "nemaicunoscut",
    "nemaicunoscutelor": "nemaicunoscut",
    "nemaicunoscuți": "nemaicunoscut",
    "nemaicunoscuții": "nemaicunoscut",
    "nemaicunoscuților": "nemaicunoscut",
    "nemaicunoscutul": "nemaicunoscut",
    "nemaicunoscutului": "nemaicunoscut",
    "nemaiîncercata": "nemaiîncercat",
    "nemaiîncercată": "nemaiîncercat",
    "nemaiîncercate": "nemaiîncercat",
    "nemaiîncercatei": "nemaiîncercat",
    "nemaiîncercatele": "nemaiîncercat",
    "nemaiîncercatelor": "nemaiîncercat",
    "nemaiîncercați": "nemaiîncercat",
    "nemaiîncercații": "nemaiîncercat",
    "nemaiîncercaților": "nemaiîncercat",
    "nemaiîncercatul": "nemaiîncercat",
    "nemaiîncercatului": "nemaiîncercat",
    "nemaiîntâlnita": "nemaiîntâlnit",
    "nemaiîntâlnită": "nemaiîntâlnit",
    "nemaiîntâlnite": "nemaiîntâlnit",
    "nemaiîntâlnitei": "nemaiîntâlnit",
    "nemaiîntâlnitele": "nemaiîntâlnit",
    "nemaiîntâlnitelor": "nemaiîntâlnit",
    "nemaiîntâlniți": "nemaiîntâlnit",
    "nemaiîntâlniții": "nemaiîntâlnit",
    "nemaiîntâlniților": "nemaiîntâlnit",
    "nemaiîntâlnitul": "nemaiîntâlnit",
    "nemaiîntâlnitului": "nemaiîntâlnit",
    "nemaimanifestata": "nemaimanifestat",
    "nemaimanifestată": "nemaimanifestat",
    "nemaimanifestate": "nemaimanifestat",
    "nemaimanifestatei": "nemaimanifestat",
    "nemaimanifestatele": "nemaimanifestat",
    "nemaimanifestatelor": "nemaimanifestat",
    "nemaimanifestați": "nemaimanifestat",
    "nemaimanifestații": "nemaimanifestat",
    "nemaimanifestaților": "nemaimanifestat",
    "nemaimanifestatul": "nemaimanifestat",
    "nemaimanifestatului": "nemaimanifestat",
    "nemaimuțărită": "nemaimuțărit",
    "nemaimuțărite": "nemaimuțărit",
    "nemaimuțăriți": "nemaimuțărit",
    "nemaipomenita": "nemaipomenit",
    "nemaipomenită": "nemaipomenit",
    "nemaipomenite": "nemaipomenit",
    "nemaipomenitei": "nemaipomenit",
    "nemaipomenitele": "nemaipomenit",
    "nemaipomenitelor": "nemaipomenit",
    "nemaipomeniți": "nemaipomenit",
    "nemaipomeniții": "nemaipomenit",
    "nemaipomeniților": "nemaipomenit",
    "nemaipomenitul": "nemaipomenit",
    "nemaipomenitului": "nemaipomenit",
    "nemaivăzuta": "nemaivăzut",
    "nemaivăzută": "nemaivăzut",
    "nemaivăzute": "nemaivăzut",
    "nemaivăzutei": "nemaivăzut",
    "nemaivăzutele": "nemaivăzut",
    "nemaivăzutelor": "nemaivăzut",
    "nemaivăzuți": "nemaivăzut",
    "nemaivăzuții": "nemaivăzut",
    "nemaivăzuților": "nemaivăzut",
    "nemaivăzutul": "nemaivăzut",
    "nemaivăzutului": "nemaivăzut",
    "nemajorată": "nemajorat",
    "nemajorate": "nemajorat",
    "nemajorați": "nemajorat",
    "nemâlita": "nemâlit",
    "nemâlită": "nemâlit",
    "nemâlite": "nemâlit",
    "nemâlitei": "nemâlit",
    "nemâlitele": "nemâlit",
    "nemâlitelor": "nemâlit",
    "nemâliți": "nemâlit",
    "nemâliții": "nemâlit",
    "nemâliților": "nemâlit",
    "nemâlitul": "nemâlit",
    "nemâlitului": "nemâlit",
    "nemaltratată": "nemaltratat",
    "nemaltratate": "nemaltratat",
    "nemaltratați": "nemaltratat",
    "nemânată": "nemânat",
    "nemânate": "nemânat",
    "nemânați": "nemânat",
    "nemâncarea": "nemâncare",
    "nemâncari": "nemâncare",
    "nemâncarii": "nemâncare",
    "nemâncarile": "nemâncare",
    "nemâncarilor": "nemâncare",
    "nemâncata": "nemâncat",
    "nemâncată": "nemâncat",
    "nemâncate": "nemâncat",
    "nemâncatei": "nemâncat",
    "nemâncatele": "nemâncat",
    "nemâncatelor": "nemâncat",
    "nemâncați": "nemâncat",
    "nemâncații": "nemâncat",
    "nemâncaților": "nemâncat",
    "nemâncatul": "nemâncat",
    "nemâncatului": "nemâncat",
    "nemândrită": "nemândrit",
    "nemândrite": "nemândrit",
    "nemândriți": "nemândrit",
    "nemanevrată": "nemanevrat",
    "nemanevrate": "nemanevrat",
    "nemanevrați": "nemanevrat",
    "nemângâiata": "nemângâiat",
    "nemângâiată": "nemângâiat",
    "nemângâiate": "nemângâiat",
    "nemângâiatei": "nemângâiat",
    "nemângâiatele": "nemângâiat",
    "nemângâiatelor": "nemângâiat",
    "nemângâiați": "nemângâiat",
    "nemângâiații": "nemângâiat",
    "nemângâiaților": "nemângâiat",
    "nemângâiatul": "nemângâiat",
    "nemângâiatului": "nemângâiat",
    "nemâniată": "nemâniat",
    "nemâniate": "nemâniat",
    "nemâniați": "nemâniat",
    "nemanifestata": "nemanifestat",
    "nemanifestată": "nemanifestat",
    "nemanifestate": "nemanifestat",
    "nemanifestatele": "nemanifestat",
    "nemanifestați": "nemanifestat",
    "nemanifestații": "nemanifestat",
    "nemanifestatul": "nemanifestat",
    "nemanipulată": "nemanipulat",
    "nemanipulate": "nemanipulat",
    "nemanipulați": "nemanipulat",
    "nemânjită": "nemânjit",
    "nemânjite": "nemânjit",
    "nemânjiți": "nemânjit",
    "nemântuită": "nemântuit",
    "nemântuite": "nemântuit",
    "nemântuiți": "nemântuit",
    "nemânuită": "nemânuit",
    "nemânuite": "nemânuit",
    "nemânuiți": "nemânuit",
    "nemârâită": "nemârâit",
    "nemârâite": "nemârâit",
    "nemârâiți": "nemârâit",
    "nemarcata": "nemarcat",
    "nemarcată": "nemarcat",
    "nemarcate": "nemarcat",
    "nemarcatei": "nemarcat",
    "nemarcatele": "nemarcat",
    "nemarcatelor": "nemarcat",
    "nemarcați": "nemarcat",
    "nemarcații": "nemarcat",
    "nemarcaților": "nemarcat",
    "nemarcatul": "nemarcat",
    "nemarcatului": "nemarcat",
    "nemărginirea": "nemărginire",
    "nemărginiri": "nemărginire",
    "nemărginirii": "nemărginire",
    "nemărginirile": "nemărginire",
    "nemărginirilor": "nemărginire",
    "nemărginita": "nemărginit",
    "nemărginită": "nemărginit",
    "nemărginite": "nemărginit",
    "nemărginitei": "nemărginit",
    "nemărginitele": "nemărginit",
    "nemărginitelor": "nemărginit",
    "nemărginiți": "nemărginit",
    "nemărginiții": "nemărginit",
    "nemărginiților": "nemărginit",
    "nemărginitul": "nemărginit",
    "nemărginitului": "nemărginit",
    "nemarinata": "nemarinat",
    "nemarinată": "nemarinat",
    "nemarinate": "nemarinat",
    "nemarinatei": "nemarinat",
    "nemarinatele": "nemarinat",
    "nemarinatelor": "nemarinat",
    "nemarinați": "nemarinat",
    "nemarinații": "nemarinat",
    "nemarinaților": "nemarinat",
    "nemarinatul": "nemarinat",
    "nemarinatului": "nemarinat",
    "nemărita": "nemărit",
    "nemărită": "nemărit",
    "nemărite": "nemărit",
    "nemăritei": "nemărit",
    "nemăritele": "nemărit",
    "nemăritelor": "nemărit",
    "nemăriți": "nemărit",
    "nemăriții": "nemărit",
    "nemăriților": "nemărit",
    "nemăritul": "nemărit",
    "nemăritului": "nemărit",
    "nemăritată": "nemăritat",
    "nemăritate": "nemăritat",
    "nemăritați": "nemăritat",
    "nemartirizată": "nemartirizat",
    "nemartirizate": "nemartirizat",
    "nemartirizați": "nemartirizat",
    "nemărturisibila": "nemărturisibil",
    "nemărturisibilă": "nemărturisibil",
    "nemărturisibile": "nemărturisibil",
    "nemărturisibilei": "nemărturisibil",
    "nemărturisibilele": "nemărturisibil",
    "nemărturisibilelor": "nemărturisibil",
    "nemărturisibili": "nemărturisibil",
    "nemărturisibilii": "nemărturisibil",
    "nemărturisibililor": "nemărturisibil",
    "nemărturisibilul": "nemărturisibil",
    "nemărturisibilului": "nemărturisibil",
    "nemărturisită": "nemărturisit",
    "nemărturisite": "nemărturisit",
    "nemărturisiți": "nemărturisit",
    "nemărunțită": "nemărunțit",
    "nemărunțite": "nemărunțit",
    "nemărunțiți": "nemărunțit",
    "nemasacrată": "nemasacrat",
    "nemasacrate": "nemasacrat",
    "nemasacrați": "nemasacrat",
    "nemasată": "nemasat",
    "nemasate": "nemasat",
    "nemasați": "nemasat",
    "nemascata": "nemascat",
    "nemascată": "nemascat",
    "nemascate": "nemascat",
    "nemascatei": "nemascat",
    "nemascatele": "nemascat",
    "nemascatelor": "nemascat",
    "nemascați": "nemascat",
    "nemascații": "nemascat",
    "nemascaților": "nemascat",
    "nemascatul": "nemascat",
    "nemascatului": "nemascat",
    "nemăsluită": "nemăsluit",
    "nemăsluite": "nemăsluit",
    "nemăsluiți": "nemăsluit",
    "nemăsurata": "nemăsurat",
    "nemăsurată": "nemăsurat",
    "nemăsurate": "nemăsurat",
    "nemăsuratei": "nemăsurat",
    "nemăsuratele": "nemăsurat",
    "nemăsuratelor": "nemăsurat",
    "nemăsurați": "nemăsurat",
    "nemăsurații": "nemăsurat",
    "nemăsuraților": "nemăsurat",
    "nemăsuratul": "nemăsurat",
    "nemăsuratului": "nemăsurat",
    "nematelminți": "nematelmint",
    "nematelminții": "nematelmint",
    "nematelminților": "nematelmint",
    "nematelmintul": "nematelmint",
    "nematelmintului": "nematelmint",
    "nematerializată": "nematerializat",
    "nematerializate": "nematerializat",
    "nematerializați": "nematerializat",
    "nematlasată": "nematlasat",
    "nematlasate": "nematlasat",
    "nematlasați": "nematlasat",
    "nematode": "nematod",
    "nematodele": "nematod",
    "nematodelor": "nematod",
    "nematodul": "nematod",
    "nematodului": "nematod",
    "nemătrășită": "nemătrășit",
    "nemătrășite": "nemătrășit",
    "nemătrășiți": "nemătrășit",
    "nemăturată": "nemăturat",
    "nemăturate": "nemăturat",
    "nemăturați": "nemăturat",
    "nematurizată": "nematurizat",
    "nematurizate": "nematurizat",
    "nematurizați": "nematurizat",
    "nemâzgălită": "nemâzgălit",
    "nemâzgălite": "nemâzgălit",
    "nemâzgăliți": "nemâzgălit",
    "nemazilită": "nemazilit",
    "nemazilite": "nemazilit",
    "nemaziliți": "nemazilit",
    "nemecanizata": "nemecanizat",
    "nemecanizată": "nemecanizat",
    "nemecanizate": "nemecanizat",
    "nemecanizatei": "nemecanizat",
    "nemecanizatele": "nemecanizat",
    "nemecanizatelor": "nemecanizat",
    "nemecanizați": "nemecanizat",
    "nemecanizații": "nemecanizat",
    "nemecanizaților": "nemecanizat",
    "nemecanizatul": "nemecanizat",
    "nemecanizatului": "nemecanizat",
    "nemedaliata": "nemedaliat",
    "nemedaliată": "nemedaliat",
    "nemedaliate": "nemedaliat",
    "nemedaliatei": "nemedaliat",
    "nemedaliatele": "nemedaliat",
    "nemedaliatelor": "nemedaliat",
    "nemedaliați": "nemedaliat",
    "nemedaliații": "nemedaliat",
    "nemedaliaților": "nemedaliat",
    "nemedaliatul": "nemedaliat",
    "nemedaliatului": "nemedaliat",
    "nemediată": "nemediat",
    "nemediate": "nemediat",
    "nemediați": "nemediat",
    "nemeditată": "nemeditat",
    "nemeditate": "nemeditat",
    "nemeditați": "nemeditat",
    "nemelițată": "nemelițat",
    "nemelițate": "nemelițat",
    "nemelițați": "nemelițat",
    "nememorată": "nememorat",
    "nememorate": "nememorat",
    "nememorați": "nememorat",
    "nememorizată": "nememorizat",
    "nememorizate": "nememorizat",
    "nememorizați": "nememorizat",
    "nemenajată": "nemenajat",
    "nemenajate": "nemenajat",
    "nemenajați": "nemenajat",
    "nemenită": "nemenit",
    "nemenite": "nemenit",
    "nemeniți": "nemenit",
    "nemenționată": "nemenționat",
    "nemenționate": "nemenționat",
    "nemenționați": "nemenționat",
    "nemercerizată": "nemercerizat",
    "nemercerizate": "nemercerizat",
    "nemercerizați": "nemercerizat",
    "nemeritată": "nemeritat",
    "nemeritate": "nemeritat",
    "nemeritați": "nemeritat",
    "nemernica": "nemernic",
    "nemernică": "nemernic",
    "nemernice": "nemernic",
    "nemernicei": "nemernic",
    "nemernicele": "nemernic",
    "nemernicelor": "nemernic",
    "nemernici": "nemernic",
    "nemernicii": "nemernic",
    "nemernicilor": "nemernic",
    "nemernicul": "nemernic",
    "nemernicului": "nemernic",
    "nemernica": "nemernică",
    "nemernice": "nemernică",
    "nemernicei": "nemernică",
    "nemernicele": "nemernică",
    "nemernicelor": "nemernică",
    "nemernicia": "nemernicie",
    "nemerniciei": "nemernicie",
    "nemernicii": "nemernicie",
    "nemerniciile": "nemernicie",
    "nemerniciilor": "nemernicie",
    "nemeși": "nemeș",
    "nemeșii": "nemeș",
    "nemeșilor": "nemeș",
    "nemeșul": "nemeș",
    "nemeșului": "nemeș",
    "nemeșeasca": "nemeșesc",
    "nemeșească": "nemeșesc",
    "nemeșescul": "nemeșesc",
    "nemeșescului": "nemeșesc",
    "nemeșești": "nemeșesc",
    "nemeșeștii": "nemeșesc",
    "nemeșeștile": "nemeșesc",
    "nemeșeștilor": "nemeșesc",
    "nemeșia": "nemeșie",
    "nemeșiei": "nemeșie",
    "nemeșii": "nemeșie",
    "nemeșiile": "nemeșie",
    "nemeșiilor": "nemeșie",
    "nemestecată": "nemestecat",
    "nemestecate": "nemestecat",
    "nemestecați": "nemestecat",
    "nemeșterită": "nemeșterit",
    "nemeșterite": "nemeșterit",
    "nemeșteriți": "nemeșterit",
    "nemeșteșugită": "nemeșteșugit",
    "nemeșteșugite": "nemeșteșugit",
    "nemeșteșugiți": "nemeșteșugit",
    "nemetale": "nemetal",
    "nemetalele": "nemetal",
    "nemetalelor": "nemetal",
    "nemetalul": "nemetal",
    "nemetalului": "nemetal",
    "nemetalizată": "nemetalizat",
    "nemetalizate": "nemetalizat",
    "nemetalizați": "nemetalizat",
    "nemetamorfozată": "nemetamorfozat",
    "nemetamorfozate": "nemetamorfozat",
    "nemetamorfozați": "nemetamorfozat",
    "nemicșorată": "nemicșorat",
    "nemicșorate": "nemicșorat",
    "nemicșorați": "nemicșorat",
    "nemigălită": "nemigălit",
    "nemigălite": "nemigălit",
    "nemigăliți": "nemigălit",
    "nemigrată": "nemigrat",
    "nemigrate": "nemigrat",
    "nemigrați": "nemigrat",
    "nemijită": "nemijit",
    "nemijite": "nemijit",
    "nemijiți": "nemijit",
    "nemijlocita": "nemijlocit",
    "nemijlocită": "nemijlocit",
    "nemijlocite": "nemijlocit",
    "nemijlocitei": "nemijlocit",
    "nemijlocitele": "nemijlocit",
    "nemijlocitelor": "nemijlocit",
    "nemijlociți": "nemijlocit",
    "nemijlociții": "nemijlocit",
    "nemijlociților": "nemijlocit",
    "nemijlocitul": "nemijlocit",
    "nemijlocitului": "nemijlocit",
    "nemilitarizată": "nemilitarizat",
    "nemilitarizate": "nemilitarizat",
    "nemilitarizați": "nemilitarizat",
    "nemilitată": "nemilitat",
    "nemilitate": "nemilitat",
    "nemilitați": "nemilitat",
    "nemiloasa": "nemilos",
    "nemiloasă": "nemilos",
    "nemiloase": "nemilos",
    "nemiloasei": "nemilos",
    "nemiloasele": "nemilos",
    "nemiloaselor": "nemilos",
    "nemiloși": "nemilos",
    "nemiloșii": "nemilos",
    "nemiloșilor": "nemilos",
    "nemilosul": "nemilos",
    "nemilosului": "nemilos",
    "nemilostiva": "nemilostiv",
    "nemilostivă": "nemilostiv",
    "nemilostive": "nemilostiv",
    "nemilostivei": "nemilostiv",
    "nemilostivele": "nemilostiv",
    "nemilostivelor": "nemilostiv",
    "nemilostivi": "nemilostiv",
    "nemilostivii": "nemilostiv",
    "nemilostivilor": "nemilostiv",
    "nemilostivul": "nemilostiv",
    "nemilostivului": "nemilostiv",
    "nemiluita": "nemiluit",
    "nemiluită": "nemiluit",
    "nemiluite": "nemiluit",
    "nemiluitei": "nemiluit",
    "nemiluitele": "nemiluit",
    "nemiluitelor": "nemiluit",
    "nemiluiți": "nemiluit",
    "nemiluiții": "nemiluit",
    "nemiluiților": "nemiluit",
    "nemiluitul": "nemiluit",
    "nemiluitului": "nemiluit",
    "nemimată": "nemimat",
    "nemimate": "nemimat",
    "nemimați": "nemimat",
    "neminata": "neminat",
    "neminată": "neminat",
    "neminate": "neminat",
    "neminatei": "neminat",
    "neminatele": "neminat",
    "neminatelor": "neminat",
    "neminați": "neminat",
    "neminații": "neminat",
    "neminaților": "neminat",
    "neminatul": "neminat",
    "neminatului": "neminat",
    "nemineralizată": "nemineralizat",
    "nemineralizate": "nemineralizat",
    "nemineralizați": "nemineralizat",
    "neminimalizată": "neminimalizat",
    "neminimalizate": "neminimalizat",
    "neminimalizați": "neminimalizat",
    "nemințită": "nemințit",
    "nemințite": "nemințit",
    "nemințiți": "nemințit",
    "neminunata": "neminunat",
    "neminunată": "neminunat",
    "neminunate": "neminunat",
    "neminunatei": "neminunat",
    "neminunatele": "neminunat",
    "neminunatelor": "neminunat",
    "neminunați": "neminunat",
    "neminunații": "neminunat",
    "neminunaților": "neminunat",
    "neminunatul": "neminunat",
    "neminunatului": "neminunat",
    "nemirată": "nemirat",
    "nemirate": "nemirat",
    "nemirați": "nemirat",
    "nemirosită": "nemirosit",
    "nemirosite": "nemirosit",
    "nemirosiți": "nemirosit",
    "nemiruită": "nemiruit",
    "nemiruite": "nemiruit",
    "nemiruiți": "nemiruit",
    "nemișcarea": "nemișcare",
    "nemișcari": "nemișcare",
    "nemișcarii": "nemișcare",
    "nemișcarile": "nemișcare",
    "nemișcarilor": "nemișcare",
    "nemișcata": "nemișcat",
    "nemișcată": "nemișcat",
    "nemișcate": "nemișcat",
    "nemișcatei": "nemișcat",
    "nemișcatele": "nemișcat",
    "nemișcatelor": "nemișcat",
    "nemișcați": "nemișcat",
    "nemișcații": "nemișcat",
    "nemișcaților": "nemișcat",
    "nemișcatul": "nemișcat",
    "nemișcatului": "nemișcat",
    "nemișcătoare": "nemișcător",
    "nemișcătoarea": "nemișcător",
    "nemișcătoarei": "nemișcător",
    "nemișcătoarele": "nemișcător",
    "nemișcătoarelor": "nemișcător",
    "nemișcători": "nemișcător",
    "nemișcătorii": "nemișcător",
    "nemișcătorilor": "nemișcător",
    "nemișcătorul": "nemișcător",
    "nemișcătorului": "nemișcător",
    "nemistificată": "nemistificat",
    "nemistificate": "nemistificat",
    "nemistificați": "nemistificat",
    "nemistuită": "nemistuit",
    "nemistuite": "nemistuit",
    "nemistuiți": "nemistuit",
    "nemișunată": "nemișunat",
    "nemișunate": "nemișunat",
    "nemișunați": "nemișunat",
    "nemitraliată": "nemitraliat",
    "nemitraliate": "nemitraliat",
    "nemitraliați": "nemitraliat",
    "nemituită": "nemituit",
    "nemituite": "nemituit",
    "nemituiți": "nemituit",
    "nemizată": "nemizat",
    "nemizate": "nemizat",
    "nemizați": "nemizat",
    "nemlădiată": "nemlădiat",
    "nemlădiate": "nemlădiat",
    "nemlădiați": "nemlădiat",
    "nemobilată": "nemobilat",
    "nemobilate": "nemobilat",
    "nemobilați": "nemobilat",
    "nemobilizată": "nemobilizat",
    "nemobilizate": "nemobilizat",
    "nemobilizați": "nemobilizat",
    "nemocăita": "nemocăit",
    "nemocăită": "nemocăit",
    "nemocăite": "nemocăit",
    "nemocăitei": "nemocăit",
    "nemocăitele": "nemocăit",
    "nemocăitelor": "nemocăit",
    "nemocăiți": "nemocăit",
    "nemocăiții": "nemocăit",
    "nemocăiților": "nemocăit",
    "nemocăitul": "nemocăit",
    "nemocăitului": "nemocăit",
    "nemocnită": "nemocnit",
    "nemocnite": "nemocnit",
    "nemocniți": "nemocnit",
    "nemocoșita": "nemocoșit",
    "nemocoșită": "nemocoșit",
    "nemocoșite": "nemocoșit",
    "nemocoșitei": "nemocoșit",
    "nemocoșitele": "nemocoșit",
    "nemocoșitelor": "nemocoșit",
    "nemocoșiți": "nemocoșit",
    "nemocoșiții": "nemocoșit",
    "nemocoșiților": "nemocoșit",
    "nemocoșitul": "nemocoșit",
    "nemocoșitului": "nemocoșit",
    "nemodelată": "nemodelat",
    "nemodelate": "nemodelat",
    "nemodelați": "nemodelat",
    "nemoderată": "nemoderat",
    "nemoderate": "nemoderat",
    "nemoderați": "nemoderat",
    "nemodernizată": "nemodernizat",
    "nemodernizate": "nemodernizat",
    "nemodernizați": "nemodernizat",
    "nemodificată": "nemodificat",
    "nemodificate": "nemodificat",
    "nemodificați": "nemodificat",
    "nemodulată": "nemodulat",
    "nemodulate": "nemodulat",
    "nemodulați": "nemodulat",
    "nemolcomită": "nemolcomit",
    "nemolcomite": "nemolcomit",
    "nemolcomiți": "nemolcomit",
    "nemoleșită": "nemoleșit",
    "nemoleșite": "nemoleșit",
    "nemoleșiți": "nemoleșit",
    "nemolestată": "nemolestat",
    "nemolestate": "nemolestat",
    "nemolestați": "nemolestat",
    "nemolfăită": "nemolfăit",
    "nemolfăite": "nemolfăit",
    "nemolfăiți": "nemolfăit",
    "nemolipsită": "nemolipsit",
    "nemolipsite": "nemolipsit",
    "nemolipsiți": "nemolipsit",
    "nemomită": "nemomit",
    "nemomite": "nemomit",
    "nemomiți": "nemomit",
    "nemonologată": "nemonologat",
    "nemonologate": "nemonologat",
    "nemonologați": "nemonologat",
    "nemonopolizată": "nemonopolizat",
    "nemonopolizate": "nemonopolizat",
    "nemonopolizați": "nemonopolizat",
    "nemontată": "nemontat",
    "nemontate": "nemontat",
    "nemontați": "nemontat",
    "nemorfolită": "nemorfolit",
    "nemorfolite": "nemorfolit",
    "nemorfoliți": "nemorfolit",
    "nemorită": "nemorit",
    "nemorite": "nemorit",
    "nemoriți": "nemorit",
    "nemormăită": "nemormăit",
    "nemormăite": "nemormăit",
    "nemormăiți": "nemormăit",
    "nemortezată": "nemortezat",
    "nemortezate": "nemortezat",
    "nemortezați": "nemortezat",
    "nemoșită": "nemoșit",
    "nemoșite": "nemoșit",
    "nemoșiți": "nemoșit",
    "nemoșmonită": "nemoșmonit",
    "nemoșmonite": "nemoșmonit",
    "nemoșmoniți": "nemoșmonit",
    "nemoștenită": "nemoștenit",
    "nemoștenite": "nemoștenit",
    "nemoșteniți": "nemoștenit",
    "nemoțăită": "nemoțăit",
    "nemoțăite": "nemoțăit",
    "nemoțăiți": "nemoțăit",
    "nemotivată": "nemotivat",
    "nemotivate": "nemotivat",
    "nemotivați": "nemotivat",
    "nemotorizată": "nemotorizat",
    "nemotorizate": "nemotorizat",
    "nemotorizați": "nemotorizat",
    "nemototolită": "nemototolit",
    "nemototolite": "nemototolit",
    "nemototoliți": "nemototolit",
    "nemovilită": "nemovilit",
    "nemovilite": "nemovilit",
    "nemoviliți": "nemovilit",
    "nemozolită": "nemozolit",
    "nemozolite": "nemozolit",
    "nemozoliți": "nemozolit",
    "nemțeasca": "nemțesc",
    "nemțească": "nemțesc",
    "nemțescul": "nemțesc",
    "nemțescului": "nemțesc",
    "nemțești": "nemțesc",
    "nemțeștii": "nemțesc",
    "nemțeștile": "nemțesc",
    "nemțeștilor": "nemțesc",
    "nemțișori": "nemțișor",
    "nemțișorii": "nemțișor",
    "nemțișorilor": "nemțișor",
    "nemțișorul": "nemțișor",
    "nemțișorului": "nemțișor",
    "nemțoaica": "nemțoaică",
    "nemțoaice": "nemțoaică",
    "nemțoaicei": "nemțoaică",
    "nemțoaicele": "nemțoaică",
    "nemțoaicelor": "nemțoaică",
    "nemțofila": "nemțofil",
    "nemțofilă": "nemțofil",
    "nemțofile": "nemțofil",
    "nemțofilei": "nemțofil",
    "nemțofilele": "nemțofil",
    "nemțofilelor": "nemțofil",
    "nemțofili": "nemțofil",
    "nemțofilii": "nemțofil",
    "nemțofililor": "nemțofil",
    "nemțofilul": "nemțofil",
    "nemțofilului": "nemțofil",
    "nemțofila": "nemțofilă",
    "nemțofile": "nemțofilă",
    "nemțofilei": "nemțofilă",
    "nemțofilele": "nemțofilă",
    "nemțofilelor": "nemțofilă",
    "nemțoicuța": "nemțoicuță",
    "nemțoicuțe": "nemțoicuță",
    "nemțoicuței": "nemțoicuță",
    "nemțoicuțele": "nemțoicuță",
    "nemțoicuțelor": "nemțoicuță",
    "nemucezită": "nemucezit",
    "nemucezite": "nemucezit",
    "nemuceziți": "nemucezit",
    "nemuiată": "nemuiat",
    "nemuiate": "nemuiat",
    "nemuiați": "nemuiat",
    "nemulată": "nemulat",
    "nemulate": "nemulat",
    "nemulați": "nemulat",
    "nemulsă": "nemuls",
    "nemulse": "nemuls",
    "nemulși": "nemuls",
    "nemultiplicată": "nemultiplicat",
    "nemultiplicate": "nemultiplicat",
    "nemultiplicați": "nemultiplicat",
    "nemulțumirea": "nemulțumire",
    "nemulțumiri": "nemulțumire",
    "nemulțumirii": "nemulțumire",
    "nemulțumirile": "nemulțumire",
    "nemulțumirilor": "nemulțumire",
    "nemulțumita": "nemulțumit",
    "nemulțumită": "nemulțumit",
    "nemulțumite": "nemulțumit",
    "nemulțumitei": "nemulțumit",
    "nemulțumitele": "nemulțumit",
    "nemulțumitelor": "nemulțumit",
    "nemulțumiți": "nemulțumit",
    "nemulțumiții": "nemulțumit",
    "nemulțumiților": "nemulțumit",
    "nemulțumitul": "nemulțumit",
    "nemulțumitului": "nemulțumit",
    "nemulțumitoare": "nemulțumitor",
    "nemulțumitoarea": "nemulțumitor",
    "nemulțumitoarei": "nemulțumitor",
    "nemulțumitoarele": "nemulțumitor",
    "nemulțumitoarelor": "nemulțumitor",
    "nemulțumitori": "nemulțumitor",
    "nemulțumitorii": "nemulțumitor",
    "nemulțumitorilor": "nemulțumitor",
    "nemulțumitorul": "nemulțumitor",
    "nemulțumitorului": "nemulțumitor",
    "nemumificată": "nemumificat",
    "nemumificate": "nemumificat",
    "nemumificați": "nemumificat",
    "nemuncită": "nemuncit",
    "nemuncite": "nemuncit",
    "nemunciți": "nemuncit",
    "nemurată": "nemurat",
    "nemurate": "nemurat",
    "nemurați": "nemurat",
    "nemurdărită": "nemurdărit",
    "nemurdărite": "nemurdărit",
    "nemurdăriți": "nemurdărit",
    "nemainemurindu": "nemuri",
    "nemurea": "nemuri",
    "nemureai": "nemuri",
    "nemuream": "nemuri",
    "nemurească": "nemuri",
    "nemureați": "nemuri",
    "nemureau": "nemuri",
    "nemuresc": "nemuri",
    "nemurește": "nemuri",
    "nemurești": "nemuri",
    "nemurii": "nemuri",
    "nemurim": "nemuri",
    "nemurind": "nemuri",
    "nemurindu": "nemuri",
    "nemuriră": "nemuri",
    "nemurirăm": "nemuri",
    "nemurirăți": "nemuri",
    "nemurise": "nemuri",
    "nemurisem": "nemuri",
    "nemuriseră": "nemuri",
    "nemuriserăm": "nemuri",
    "nemuriserăți": "nemuri",
    "nemuriseși": "nemuri",
    "nemuriși": "nemuri",
    "nemurit": "nemuri",
    "nemuriți": "nemuri",
    "nemurirea": "nemurire",
    "nemuriri": "nemurire",
    "nemuririi": "nemurire",
    "nemuririle": "nemurire",
    "nemuririlor": "nemurire",
    "nemurită": "nemurit",
    "nemurite": "nemurit",
    "nemuriți": "nemurit",
    "nemuritoare": "nemuritor",
    "nemuritoarea": "nemuritor",
    "nemuritoarei": "nemuritor",
    "nemuritoarele": "nemuritor",
    "nemuritoarelor": "nemuritor",
    "nemuritori": "nemuritor",
    "nemuritorii": "nemuritor",
    "nemuritorilor": "nemuritor",
    "nemuritorul": "nemuritor",
    "nemuritorului": "nemuritor",
    "nemurmurată": "nemurmurat",
    "nemurmurate": "nemurmurat",
    "nemurmurați": "nemurmurat",
    "nemușamalizată": "nemușamalizat",
    "nemușamalizate": "nemușamalizat",
    "nemușamalizați": "nemușamalizat",
    "nemușcată": "nemușcat",
    "nemușcate": "nemușcat",
    "nemușcați": "nemușcat",
    "nemustrată": "nemustrat",
    "nemustrate": "nemustrat",
    "nemustrați": "nemustrat",
    "nemustuită": "nemustuit",
    "nemustuite": "nemustuit",
    "nemustuiți": "nemustuit",
    "nemutată": "nemutat",
    "nemutate": "nemutat",
    "nemutați": "nemutat",
    "nemutilată": "nemutilat",
    "nemutilate": "nemutilat",
    "nemutilați": "nemutilat",
    "nenăbușită": "nenăbușit",
    "nenăbușite": "nenăbușit",
    "nenăbușiți": "nenăbușit",
    "nenăclăită": "nenăclăit",
    "nenăclăite": "nenăclăit",
    "nenăclăiți": "nenăclăit",
    "nenădăjduită": "nenădăjduit",
    "nenădăjduite": "nenădăjduit",
    "nenădăjduiți": "nenădăjduit",
    "nenădușită": "nenădușit",
    "nenădușite": "nenădușit",
    "nenădușiți": "nenădușit",
    "nenăimită": "nenăimit",
    "nenăimite": "nenăimit",
    "nenăimiți": "nenăimit",
    "nenălbită": "nenălbit",
    "nenălbite": "nenălbit",
    "nenălbiți": "nenălbit",
    "nenălucită": "nenălucit",
    "nenălucite": "nenălucit",
    "nenăluciți": "nenălucit",
    "nenămețita": "nenămețit",
    "nenămețită": "nenămețit",
    "nenămețite": "nenămețit",
    "nenămețitei": "nenămețit",
    "nenămețitele": "nenămețit",
    "nenămețitelor": "nenămețit",
    "nenămețiți": "nenămețit",
    "nenămețiții": "nenămețit",
    "nenămețiților": "nenămețit",
    "nenămețitul": "nenămețit",
    "nenămețitului": "nenămețit",
    "nenămolită": "nenămolit",
    "nenămolite": "nenămolit",
    "nenămoliți": "nenămolit",
    "nenăpădită": "nenăpădit",
    "nenăpădite": "nenăpădit",
    "nenăpădiți": "nenăpădit",
    "nenăpârlită": "nenăpârlit",
    "nenăpârlite": "nenăpârlit",
    "nenăpârliți": "nenăpârlit",
    "nenăpăstuită": "nenăpăstuit",
    "nenăpăstuite": "nenăpăstuit",
    "nenăpăstuiți": "nenăpăstuit",
    "nenăpustită": "nenăpustit",
    "nenăpustite": "nenăpustit",
    "nenăpustiți": "nenăpustit",
    "nenarată": "nenarat",
    "nenarate": "nenarat",
    "nenarați": "nenarat",
    "nenărăvită": "nenărăvit",
    "nenărăvite": "nenărăvit",
    "nenărăviți": "nenărăvit",
    "nenarcotizată": "nenarcotizat",
    "nenarcotizate": "nenarcotizat",
    "nenarcotizați": "nenarcotizat",
    "nenăruită": "nenăruit",
    "nenăruite": "nenăruit",
    "nenăruiți": "nenăruit",
    "nenăsădită": "nenăsădit",
    "nenăsădite": "nenăsădit",
    "nenăsădiți": "nenăsădit",
    "nenăscocită": "nenăscocit",
    "nenăscocite": "nenăscocit",
    "nenăscociți": "nenăscocit",
    "nenăscuta": "nenăscut",
    "nenăscută": "nenăscut",
    "nenăscute": "nenăscut",
    "nenăscutei": "nenăscut",
    "nenăscutele": "nenăscut",
    "nenăscutelor": "nenăscut",
    "nenăscuți": "nenăscut",
    "nenăscuții": "nenăscut",
    "nenăscuților": "nenăscut",
    "nenăscutul": "nenăscut",
    "nenăscutului": "nenăscut",
    "nenășită": "nenășit",
    "nenășite": "nenășit",
    "nenășiți": "nenășit",
    "nenaționalizată": "nenaționalizat",
    "nenaționalizate": "nenaționalizat",
    "nenaționalizați": "nenaționalizat",
    "nenaturala": "nenatural",
    "nenaturală": "nenatural",
    "nenaturale": "nenatural",
    "nenaturalei": "nenatural",
    "nenaturalele": "nenatural",
    "nenaturalelor": "nenatural",
    "nenaturali": "nenatural",
    "nenaturalii": "nenatural",
    "nenaturalilor": "nenatural",
    "nenaturalul": "nenatural",
    "nenaturalului": "nenatural",
    "nenaturalizată": "nenaturalizat",
    "nenaturalizate": "nenaturalizat",
    "nenaturalizați": "nenaturalizat",
    "nenăucită": "nenăucit",
    "nenăucite": "nenăucit",
    "nenăuciți": "nenăucit",
    "nenaufragiată": "nenaufragiat",
    "nenaufragiate": "nenaufragiat",
    "nenaufragiați": "nenaufragiat",
    "nenăvădită": "nenăvădit",
    "nenăvădite": "nenăvădit",
    "nenăvădiți": "nenăvădit",
    "nenăvălită": "nenăvălit",
    "nenăvălite": "nenăvălit",
    "nenăvăliți": "nenăvălit",
    "nenavigată": "nenavigat",
    "nenavigate": "nenavigat",
    "nenavigați": "nenavigat",
    "nenavlosită": "nenavlosit",
    "nenavlosite": "nenavlosit",
    "nenavlosiți": "nenavlosit",
    "nenazalizată": "nenazalizat",
    "nenazalizate": "nenazalizat",
    "nenazalizați": "nenazalizat",
    "nenăzărită": "nenăzărit",
    "nenăzărite": "nenăzărit",
    "nenăzăriți": "nenăzărit",
    "nenăzuită": "nenăzuit",
    "nenăzuite": "nenăzuit",
    "nenăzuiți": "nenăzuit",
    "nenecesara": "nenecesar",
    "nenecesară": "nenecesar",
    "nenecesare": "nenecesar",
    "nenecesarei": "nenecesar",
    "nenecesarele": "nenecesar",
    "nenecesarelor": "nenecesar",
    "nenecesari": "nenecesar",
    "nenecesarii": "nenecesar",
    "nenecesarilor": "nenecesar",
    "nenecesarul": "nenecesar",
    "nenecesarului": "nenecesar",
    "neneglijată": "neneglijat",
    "neneglijate": "neneglijat",
    "neneglijați": "neneglijat",
    "nenegociată": "nenegociat",
    "nenegociate": "nenegociat",
    "nenegociați": "nenegociat",
    "nenetezită": "nenetezit",
    "nenetezite": "nenetezit",
    "neneteziți": "nenetezit",
    "neneurastenizată": "neneurastenizat",
    "neneurastenizate": "neneurastenizat",
    "neneurastenizați": "neneurastenizat",
    "nenichelată": "nenichelat",
    "nenichelate": "nenichelat",
    "nenichelați": "nenichelat",
    "nenimerită": "nenimerit",
    "nenimerite": "nenimerit",
    "nenimeriți": "nenimerit",
    "nenimicită": "nenimicit",
    "nenimicite": "nenimicit",
    "nenimiciți": "nenimicit",
    "nenituită": "nenituit",
    "nenituite": "nenituit",
    "nenituiți": "nenituit",
    "nenivelată": "nenivelat",
    "nenivelate": "nenivelat",
    "nenivelați": "nenivelat",
    "nenominalizată": "nenominalizat",
    "nenominalizate": "nenominalizat",
    "nenominalizați": "nenominalizat",
    "nenormalizată": "nenormalizat",
    "nenormalizate": "nenormalizat",
    "nenormalizați": "nenormalizat",
    "nenormata": "nenormat",
    "nenormată": "nenormat",
    "nenormate": "nenormat",
    "nenormatei": "nenormat",
    "nenormatele": "nenormat",
    "nenormatelor": "nenormat",
    "nenormați": "nenormat",
    "nenormații": "nenormat",
    "nenormaților": "nenormat",
    "nenormatul": "nenormat",
    "nenormatului": "nenormat",
    "nenorocul": "nenoroc",
    "nenorocului": "nenoroc",
    "nemainenorocindu": "nenoroci",
    "nenenorocindu": "nenoroci",
    "nenorocea": "nenoroci",
    "nenoroceai": "nenoroci",
    "nenoroceam": "nenoroci",
    "nenorocească": "nenoroci",
    "nenoroceați": "nenoroci",
    "nenoroceau": "nenoroci",
    "nenorocesc": "nenoroci",
    "nenorocește": "nenoroci",
    "nenorocești": "nenoroci",
    "nenorocii": "nenoroci",
    "nenorocim": "nenoroci",
    "nenorocind": "nenoroci",
    "nenorocindu": "nenoroci",
    "nenorociră": "nenoroci",
    "nenorocirăm": "nenoroci",
    "nenorocirăți": "nenoroci",
    "nenorocise": "nenoroci",
    "nenorocisem": "nenoroci",
    "nenorociseră": "nenoroci",
    "nenorociserăm": "nenoroci",
    "nenorociserăți": "nenoroci",
    "nenorociseși": "nenoroci",
    "nenorociși": "nenoroci",
    "nenorocit": "nenoroci",
    "nenorociți": "nenoroci",
    "nenorocirea": "nenorocire",
    "nenorociri": "nenorocire",
    "nenorocirii": "nenorocire",
    "nenorocirile": "nenorocire",
    "nenorocirilor": "nenorocire",
    "nenorocita": "nenorocit",
    "nenorocită": "nenorocit",
    "nenorocite": "nenorocit",
    "nenorocitei": "nenorocit",
    "nenorocitele": "nenorocit",
    "nenorocitelor": "nenorocit",
    "nenorociți": "nenorocit",
    "nenorociții": "nenorocit",
    "nenorociților": "nenorocit",
    "nenorocitul": "nenorocit",
    "nenorocitule": "nenorocit",
    "nenorocitului": "nenorocit",
    "nenorocita": "nenorocită",
    "nenorocite": "nenorocită",
    "nenorocitei": "nenorocită",
    "nenorocitele": "nenorocită",
    "nenorocitelor": "nenorocită",
    "nenorocoasa": "nenorocos",
    "nenorocoasă": "nenorocos",
    "nenorocoase": "nenorocos",
    "nenorocoasei": "nenorocos",
    "nenorocoasele": "nenorocos",
    "nenorocoaselor": "nenorocos",
    "nenorocoși": "nenorocos",
    "nenorocoșii": "nenorocos",
    "nenorocoșilor": "nenorocos",
    "nenorocosul": "nenorocos",
    "nenorocosului": "nenorocos",
    "nenotată": "nenotat",
    "nenotate": "nenotat",
    "nenotați": "nenotat",
    "nenotificată": "nenotificat",
    "nenotificate": "nenotificat",
    "nenotificați": "nenotificat",
    "nenuanțată": "nenuanțat",
    "nenuanțate": "nenuanțat",
    "nenuanțați": "nenuanțat",
    "nenumărata": "nenumărat",
    "nenumărată": "nenumărat",
    "nenumărate": "nenumărat",
    "nenumăratei": "nenumărat",
    "nenumăratele": "nenumărat",
    "nenumăratelor": "nenumărat",
    "nenumărați": "nenumărat",
    "nenumărații": "nenumărat",
    "nenumăraților": "nenumărat",
    "nenumăratul": "nenumărat",
    "nenumăratului": "nenumărat",
    "nenumerotată": "nenumerotat",
    "nenumerotate": "nenumerotat",
    "nenumerotați": "nenumerotat",
    "nenumită": "nenumit",
    "nenumite": "nenumit",
    "nenumiți": "nenumit",
    "nenuntită": "nenuntit",
    "nenuntite": "nenuntit",
    "nenuntiți": "nenuntit",
    "nenutrită": "nenutrit",
    "nenutrite": "nenutrit",
    "nenutriți": "nenutrit",
    "neobiectată": "neobiectat",
    "neobiectate": "neobiectat",
    "neobiectați": "neobiectat",
    "neobișnuința": "neobișnuință",
    "neobișnuințe": "neobișnuință",
    "neobișnuinței": "neobișnuință",
    "neobișnuita": "neobișnuit",
    "neobișnuită": "neobișnuit",
    "neobișnuite": "neobișnuit",
    "neobișnuitei": "neobișnuit",
    "neobișnuitele": "neobișnuit",
    "neobișnuitelor": "neobișnuit",
    "neobișnuiți": "neobișnuit",
    "neobișnuiții": "neobișnuit",
    "neobișnuiților": "neobișnuit",
    "neobișnuitul": "neobișnuit",
    "neobișnuitului": "neobișnuit",
    "neoblăduită": "neoblăduit",
    "neoblăduite": "neoblăduit",
    "neoblăduiți": "neoblăduit",
    "neobligată": "neobligat",
    "neobligate": "neobligat",
    "neobligați": "neobligat",
    "neoblojită": "neoblojit",
    "neoblojite": "neoblojit",
    "neoblojiți": "neoblojit",
    "Neo-Bolșevismul": "Neo-Bolșevism",
    "neobosita": "neobosit",
    "neobosită": "neobosit",
    "neobosite": "neobosit",
    "neobositei": "neobosit",
    "neobositele": "neobosit",
    "neobositelor": "neobosit",
    "neobosiți": "neobosit",
    "neobosiții": "neobosit",
    "neobosiților": "neobosit",
    "neobositul": "neobosit",
    "neobositului": "neobosit",
    "neobrăzarea": "neobrăzare",
    "neobrăzări": "neobrăzare",
    "neobrăzării": "neobrăzare",
    "neobrăzările": "neobrăzare",
    "neobrăzărilor": "neobrăzare",
    "neobrăzata": "neobrăzat",
    "neobrăzată": "neobrăzat",
    "neobrăzate": "neobrăzat",
    "neobrăzatei": "neobrăzat",
    "neobrăzatele": "neobrăzat",
    "neobrăzatelor": "neobrăzat",
    "neobrăzați": "neobrăzat",
    "neobrăzații": "neobrăzat",
    "neobrăzaților": "neobrăzat",
    "neobrăzatul": "neobrăzat",
    "neobrăzatului": "neobrăzat",
    "neobrăznicită": "neobrăznicit",
    "neobrăznicite": "neobrăznicit",
    "neobrăzniciți": "neobrăznicit",
    "neobsedata": "neobsedat",
    "neobsedată": "neobsedat",
    "neobsedate": "neobsedat",
    "neobsedatei": "neobsedat",
    "neobsedatele": "neobsedat",
    "neobsedatelor": "neobsedat",
    "neobsedați": "neobsedat",
    "neobsedații": "neobsedat",
    "neobsedaților": "neobsedat",
    "neobsedatul": "neobsedat",
    "neobsedatului": "neobsedat",
    "neobservata": "neobservat",
    "neobservată": "neobservat",
    "neobservate": "neobservat",
    "neobservatei": "neobservat",
    "neobservatele": "neobservat",
    "neobservatelor": "neobservat",
    "neobservați": "neobservat",
    "neobservații": "neobservat",
    "neobservaților": "neobservat",
    "neobservatul": "neobservat",
    "neobservatului": "neobservat",
    "neobstinată": "neobstinat",
    "neobstinate": "neobstinat",
    "neobstinați": "neobstinat",
    "neobținută": "neobținut",
    "neobținute": "neobținut",
    "neobținuți": "neobținut",
    "neobturată": "neobturat",
    "neobturate": "neobturat",
    "neobturați": "neobturat",
    "neocărâtă": "neocărât",
    "neocărâte": "neocărât",
    "neocărâți": "neocărât",
    "neocârmuită": "neocârmuit",
    "neocârmuite": "neocârmuit",
    "neocârmuiți": "neocârmuit",
    "neocazionată": "neocazionat",
    "neocazionate": "neocazionat",
    "neocazionați": "neocazionat",
    "neochită": "neochit",
    "neochite": "neochit",
    "neochiți": "neochit",
    "neoclasica": "neoclasic",
    "neoclasică": "neoclasic",
    "neoclasice": "neoclasic",
    "neoclasicei": "neoclasic",
    "neoclasicele": "neoclasic",
    "neoclasicelor": "neoclasic",
    "neoclasici": "neoclasic",
    "neoclasicii": "neoclasic",
    "neoclasicilor": "neoclasic",
    "neoclasicul": "neoclasic",
    "neoclasicului": "neoclasic",
    "neocolită": "neocolit",
    "neocolite": "neocolit",
    "neocoliți": "neocolit",
    "neocolonialista": "neocolonialist",
    "neocolonialistă": "neocolonialist",
    "neocolonialiste": "neocolonialist",
    "neocolonialistei": "neocolonialist",
    "neocolonialistele": "neocolonialist",
    "neocolonialistelor": "neocolonialist",
    "neocolonialiști": "neocolonialist",
    "neocolonialiștii": "neocolonialist",
    "neocolonialiștilor": "neocolonialist",
    "neocolonialistul": "neocolonialist",
    "neocolonialistului": "neocolonialist",
    "neocrotită": "neocrotit",
    "neocrotite": "neocrotit",
    "neocrotiți": "neocrotit",
    "neocupată": "neocupat",
    "neocupate": "neocupat",
    "neocupați": "neocupat",
    "neodihna": "neodihnă",
    "neodihne": "neodihnă",
    "neodihnei": "neodihnă",
    "neodihnele": "neodihnă",
    "neodihnelor": "neodihnă",
    "neodihnita": "neodihnit",
    "neodihnită": "neodihnit",
    "neodihnite": "neodihnit",
    "neodihnitei": "neodihnit",
    "neodihnitele": "neodihnit",
    "neodihnitelor": "neodihnit",
    "neodihniți": "neodihnit",
    "neodihniții": "neodihnit",
    "neodihniților": "neodihnit",
    "neodihnitul": "neodihnit",
    "neodihnitului": "neodihnit",
    "Nd": "neodim",
    "neodimul": "neodim",
    "neodimului": "neodim",
    "neodorizată": "neodorizat",
    "neodorizate": "neodorizat",
    "neodorizați": "neodorizat",
    "neodrăslită": "neodrăslit",
    "neodrăslite": "neodrăslit",
    "neodrăsliți": "neodrăslit",
    "neofalina": "neofalină",
    "neofaline": "neofalină",
    "neofalinei": "neofalină",
    "neofascismul": "neofascism",
    "neofascismului": "neofascism",
    "neofascista": "neofascist",
    "neofascistă": "neofascist",
    "neofasciste": "neofascist",
    "neofascistei": "neofascist",
    "neofascistele": "neofascist",
    "neofascistelor": "neofascist",
    "neofasciști": "neofascist",
    "neofasciștii": "neofascist",
    "neofasciștilor": "neofascist",
    "neofascistul": "neofascist",
    "neofascistului": "neofascist",
    "neofensată": "neofensat",
    "neofensate": "neofensat",
    "neofensați": "neofensat",
    "neoferită": "neoferit",
    "neoferite": "neoferit",
    "neoferiți": "neoferit",
    "neoficiala": "neoficial",
    "neoficială": "neoficial",
    "neoficiale": "neoficial",
    "neoficialei": "neoficial",
    "neoficialele": "neoficial",
    "neoficialelor": "neoficial",
    "neoficiali": "neoficial",
    "neoficialii": "neoficial",
    "neoficialilor": "neoficial",
    "neoficialul": "neoficial",
    "neoficialului": "neoficial",
    "neoficializată": "neoficializat",
    "neoficializate": "neoficializat",
    "neoficializați": "neoficializat",
    "neoficiată": "neoficiat",
    "neoficiate": "neoficiat",
    "neoficiați": "neoficiat",
    "neofilita": "neofilit",
    "neofilită": "neofilit",
    "neofilite": "neofilit",
    "neofilitei": "neofilit",
    "neofilitele": "neofilit",
    "neofilitelor": "neofilit",
    "neofiliți": "neofilit",
    "neofiliții": "neofilit",
    "neofiliților": "neofilit",
    "neofilitul": "neofilit",
    "neofilitului": "neofilit",
    "neofiți": "neofit",
    "neofiții": "neofit",
    "neofiților": "neofit",
    "neofitul": "neofit",
    "neofitului": "neofit",
    "neofita": "neofită",
    "neofite": "neofită",
    "neofitei": "neofită",
    "neofitele": "neofită",
    "neofitelor": "neofită",
    "neoftată": "neoftat",
    "neoftate": "neoftat",
    "neoftați": "neoftat",
    "neofticată": "neofticat",
    "neofticate": "neofticat",
    "neofticați": "neofticat",
    "neogena": "neogen",
    "neogenă": "neogen",
    "neogene": "neogen",
    "neogenei": "neogen",
    "neogenele": "neogen",
    "neogenelor": "neogen",
    "neogeni": "neogen",
    "neogenii": "neogen",
    "neogenilor": "neogen",
    "neogenul": "neogen",
    "neogenului": "neogen",
    "neoglindită": "neoglindit",
    "neoglindite": "neoglindit",
    "neoglindiți": "neoglindit",
    "neogoită": "neogoit",
    "neogoite": "neogoit",
    "neogoiți": "neogoit",
    "neogorâtă": "neogorât",
    "neogorâte": "neogorât",
    "neogorâți": "neogorât",
    "neogotica": "neogotic",
    "neogotică": "neogotic",
    "neogotice": "neogotic",
    "neogoticei": "neogotic",
    "neogoticele": "neogotic",
    "neogoticelor": "neogotic",
    "neogotici": "neogotic",
    "neogoticii": "neogotic",
    "neogoticilor": "neogotic",
    "neogoticul": "neogotic",
    "neogoticului": "neogotic",
    "neogramatica": "neogramatic",
    "neogramatică": "neogramatic",
    "neogramatice": "neogramatic",
    "neogramaticei": "neogramatic",
    "neogramaticele": "neogramatic",
    "neogramaticelor": "neogramatic",
    "neogramatici": "neogramatic",
    "neogramaticii": "neogramatic",
    "neogramaticilor": "neogramatic",
    "neogramaticul": "neogramatic",
    "neogramaticului": "neogramatic",
    "neogreaca": "neogreacă",
    "ngr.": "neogreacă",
    "neogreca": "neogrec",
    "neogrecă": "neogrec",
    "neogrece": "neogrec",
    "neogrecei": "neogrec",
    "neogrecele": "neogrec",
    "neogrecelor": "neogrec",
    "neogreci": "neogrec",
    "neogrecii": "neogrec",
    "neogrecilor": "neogrec",
    "neogrecul": "neogrec",
    "neogrecului": "neogrec",
    "neogreceasca": "neogrecesc",
    "neogrecească": "neogrecesc",
    "neogrecescul": "neogrecesc",
    "neogrecescului": "neogrecesc",
    "neogrecești": "neogrecesc",
    "neogreceștii": "neogrecesc",
    "neogreceștile": "neogrecesc",
    "neogreceștilor": "neogrecesc",
    "neohegeliana": "neohegelian",
    "neohegeliană": "neohegelian",
    "neohegelianul": "neohegelian",
    "neohegelianului": "neohegelian",
    "neohegeliene": "neohegelian",
    "neohegelienei": "neohegelian",
    "neohegelienele": "neohegelian",
    "neohegelienelor": "neohegelian",
    "neohegelieni": "neohegelian",
    "neohegelienii": "neohegelian",
    "neohegelienilor": "neohegelian",
    "neoimpresionista": "neoimpresionist",
    "neoimpresionistă": "neoimpresionist",
    "neoimpresioniste": "neoimpresionist",
    "neoimpresionistei": "neoimpresionist",
    "neoimpresionistele": "neoimpresionist",
    "neoimpresionistelor": "neoimpresionist",
    "neoimpresioniști": "neoimpresionist",
    "neoimpresioniștii": "neoimpresionist",
    "neoimpresioniștilor": "neoimpresionist",
    "neoimpresionistul": "neoimpresionist",
    "neoimpresionistului": "neoimpresionist",
    "neokantiana": "neokantian",
    "neokantiană": "neokantian",
    "neokantianul": "neokantian",
    "neokantianului": "neokantian",
    "neokantiene": "neokantian",
    "neokantienei": "neokantian",
    "neokantienele": "neokantian",
    "neokantienelor": "neokantian",
    "neokantieni": "neokantian",
    "neokantienii": "neokantian",
    "neokantienilor": "neokantian",
    "neolatina": "neolatin",
    "neolatină": "neolatin",
    "neolatine": "neolatin",
    "neolatinei": "neolatin",
    "neolatinele": "neolatin",
    "neolatinelor": "neolatin",
    "neolatini": "neolatin",
    "neolatinii": "neolatin",
    "neolatinilor": "neolatin",
    "neolatinul": "neolatin",
    "neolatinului": "neolatin",
    "neoliberala": "neoliberal",
    "neoliberală": "neoliberal",
    "neoliberale": "neoliberal",
    "neoliberalei": "neoliberal",
    "neoliberalele": "neoliberal",
    "neoliberalelor": "neoliberal",
    "neoliberali": "neoliberal",
    "neoliberalii": "neoliberal",
    "neoliberalilor": "neoliberal",
    "neoliberalul": "neoliberal",
    "neoliberalului": "neoliberal",
    "neolitica": "neolitic",
    "neolitică": "neolitic",
    "neolitice": "neolitic",
    "neoliticei": "neolitic",
    "neoliticele": "neolitic",
    "neoliticelor": "neolitic",
    "neolitici": "neolitic",
    "neoliticii": "neolitic",
    "neoliticilor": "neolitic",
    "neoliticul": "neolitic",
    "neoliticului": "neolitic",
    "neologica": "neologic",
    "neologică": "neologic",
    "neologice": "neologic",
    "neologicei": "neologic",
    "neologicele": "neologic",
    "neologicelor": "neologic",
    "neologici": "neologic",
    "neologicii": "neologic",
    "neologicilor": "neologic",
    "neologicul": "neologic",
    "neologicului": "neologic",
    "neologisme": "neologism",
    "neologismele": "neologism",
    "neologismelor": "neologism",
    "neologismul": "neologism",
    "neologismului": "neologism",
    "neologistica": "neologistic",
    "neologistică": "neologistic",
    "neologistice": "neologistic",
    "neologisticei": "neologistic",
    "neologisticele": "neologistic",
    "neologisticelor": "neologistic",
    "neologistici": "neologistic",
    "neologisticii": "neologistic",
    "neologisticilor": "neologistic",
    "neologisticul": "neologistic",
    "neologisticului": "neologistic",
    "neologită": "neologit",
    "neologite": "neologit",
    "neologiți": "neologit",
    "neoameni": "neom",
    "neoamenii": "neom",
    "neoamenilor": "neom",
    "neomul": "neom",
    "neomului": "neom",
    "neomagiată": "neomagiat",
    "neomagiate": "neomagiat",
    "neomagiați": "neomagiat",
    "neomeneasca": "neomenesc",
    "neomenească": "neomenesc",
    "neomenescul": "neomenesc",
    "neomenescului": "neomenesc",
    "neomenești": "neomenesc",
    "neomeneștii": "neomenesc",
    "neomeneștile": "neomenesc",
    "neomeneștilor": "neomenesc",
    "neomenia": "neomenie",
    "neomeniei": "neomenie",
    "neomenii": "neomenie",
    "neomeniile": "neomenie",
    "neomeniilor": "neomenie",
    "neomenita": "neomenit",
    "neomenită": "neomenit",
    "neomenite": "neomenit",
    "neomenitei": "neomenit",
    "neomenitele": "neomenit",
    "neomenitelor": "neomenit",
    "neomeniți": "neomenit",
    "neomeniții": "neomenit",
    "neomeniților": "neomenit",
    "neomenitul": "neomenit",
    "neomenitului": "neomenit",
    "neomenoasa": "neomenos",
    "neomenoasă": "neomenos",
    "neomenoase": "neomenos",
    "neomenoasei": "neomenos",
    "neomenoasele": "neomenos",
    "neomenoaselor": "neomenos",
    "neomenoși": "neomenos",
    "neomenoșii": "neomenos",
    "neomenoșilor": "neomenos",
    "neomenosul": "neomenos",
    "neomenosului": "neomenos",
    "neomisa": "neomis",
    "neomisă": "neomis",
    "neomise": "neomis",
    "neomisei": "neomis",
    "neomisele": "neomis",
    "neomiselor": "neomis",
    "neomiși": "neomis",
    "neomișii": "neomis",
    "neomișilor": "neomis",
    "neomisul": "neomis",
    "neomisului": "neomis",
    "neomogenizată": "neomogenizat",
    "neomogenizate": "neomogenizat",
    "neomogenizați": "neomogenizat",
    "neomologata": "neomologat",
    "neomologată": "neomologat",
    "neomologate": "neomologat",
    "neomologatei": "neomologat",
    "neomologatele": "neomologat",
    "neomologatelor": "neomologat",
    "neomologați": "neomologat",
    "neomologații": "neomologat",
    "neomologaților": "neomologat",
    "neomologatul": "neomologat",
    "neomologatului": "neomologat",
    "neomorâtă": "neomorât",
    "neomorâte": "neomorât",
    "neomorâți": "neomorât",
    "Ne": "neon",
    "neoane": "neon",
    "neoanele": "neon",
    "neoanelor": "neon",
    "neonul": "neon",
    "neonului": "neon",
    "neonazista": "neonazist",
    "neonazistă": "neonazist",
    "neonaziste": "neonazist",
    "neonazistei": "neonazist",
    "neonazistele": "neonazist",
    "neonazistelor": "neonazist",
    "neonaziști": "neonazist",
    "neonaziștii": "neonazist",
    "neonaziștilor": "neonazist",
    "neonazistul": "neonazist",
    "neonazistului": "neonazist",
    "neondulată": "neondulat",
    "neondulate": "neondulat",
    "neondulați": "neondulat",
    "neonorată": "neonorat",
    "neonorate": "neonorat",
    "neonorați": "neonorat",
    "neopacifiată": "neopacifiat",
    "neopacifiate": "neopacifiat",
    "neopacifiați": "neopacifiat",
    "neopărită": "neopărit",
    "neopărite": "neopărit",
    "neopăriți": "neopărit",
    "neoperata": "neoperat",
    "neoperată": "neoperat",
    "neoperate": "neoperat",
    "neoperatei": "neoperat",
    "neoperatele": "neoperat",
    "neoperatelor": "neoperat",
    "neoperați": "neoperat",
    "neoperații": "neoperat",
    "neoperaților": "neoperat",
    "neoperatul": "neoperat",
    "neoperatului": "neoperat",
    "neopinată": "neopinat",
    "neopinate": "neopinat",
    "neopinați": "neopinat",
    "neopintită": "neopintit",
    "neopintite": "neopintit",
    "neopintiți": "neopintit",
    "neoplasmul": "neoplasm",
    "neoplasmului": "neoplasm",
    "neoplatonica": "neoplatonic",
    "neoplatonică": "neoplatonic",
    "neoplatonice": "neoplatonic",
    "neoplatonicei": "neoplatonic",
    "neoplatonicele": "neoplatonic",
    "neoplatonicelor": "neoplatonic",
    "neoplatonici": "neoplatonic",
    "neoplatonicii": "neoplatonic",
    "neoplatonicilor": "neoplatonic",
    "neoplatonicul": "neoplatonic",
    "neoplatonicului": "neoplatonic",
    "neoplatoniciana": "neoplatonician",
    "neoplatoniciană": "neoplatonician",
    "neoplatonicianul": "neoplatonician",
    "neoplatonicianului": "neoplatonician",
    "neoplatoniciene": "neoplatonician",
    "neoplatonicienei": "neoplatonician",
    "neoplatonicienele": "neoplatonician",
    "neoplatonicienelor": "neoplatonician",
    "neoplatonicieni": "neoplatonician",
    "neoplatonicienii": "neoplatonician",
    "neoplatonicienilor": "neoplatonician",
    "neoploșită": "neoploșit",
    "neoploșite": "neoploșit",
    "neoploșiți": "neoploșit",
    "neopozitivista": "neopozitivist",
    "neopozitivistă": "neopozitivist",
    "neopozitiviste": "neopozitivist",
    "neopozitivistei": "neopozitivist",
    "neopozitivistele": "neopozitivist",
    "neopozitivistelor": "neopozitivist",
    "neopozitiviști": "neopozitivist",
    "neopozitiviștii": "neopozitivist",
    "neopozitiviștilor": "neopozitivist",
    "neopozitivistul": "neopozitivist",
    "neopozitivistului": "neopozitivist",
    "neoprimată": "neoprimat",
    "neoprimate": "neoprimat",
    "neoprimați": "neoprimat",
    "neoprită": "neoprit",
    "neoprite": "neoprit",
    "neopriți": "neoprit",
    "neoprotestanta": "neoprotestant",
    "neoprotestantă": "neoprotestant",
    "neoprotestante": "neoprotestant",
    "neoprotestantei": "neoprotestant",
    "neoprotestantele": "neoprotestant",
    "neoprotestantelor": "neoprotestant",
    "neoprotestanti": "neoprotestant",
    "neoprotestanți": "neoprotestant",
    "neoprotestantii": "neoprotestant",
    "neoprotestanții": "neoprotestant",
    "neoprotestantilor": "neoprotestant",
    "neoprotestanților": "neoprotestant",
    "neoprotestantul": "neoprotestant",
    "neoprotestantului": "neoprotestant",
    "neoptată": "neoptat",
    "neoptate": "neoptat",
    "neoptați": "neoptat",
    "neopusa": "neopus",
    "neopusă": "neopus",
    "neopuse": "neopus",
    "neopusei": "neopus",
    "neopusele": "neopus",
    "neopuselor": "neopus",
    "neopuși": "neopus",
    "neopușii": "neopus",
    "neopușilor": "neopus",
    "neopusul": "neopus",
    "neopusului": "neopus",
    "neorăcăită": "neorăcăit",
    "neorăcăite": "neorăcăit",
    "neorăcăiți": "neorăcăit",
    "neorânduiala": "neorânduială",
    "neorânduieli": "neorânduială",
    "neorânduielii": "neorânduială",
    "neorânduielile": "neorânduială",
    "neorânduielilor": "neorânduială",
    "neorânduita": "neorânduit",
    "neorânduită": "neorânduit",
    "neorânduite": "neorânduit",
    "neorânduitei": "neorânduit",
    "neorânduitele": "neorânduit",
    "neorânduitelor": "neorânduit",
    "neorânduiți": "neorânduit",
    "neorânduiții": "neorânduit",
    "neorânduiților": "neorânduit",
    "neorânduitul": "neorânduit",
    "neorânduitului": "neorânduit",
    "neorbecăită": "neorbecăit",
    "neorbecăite": "neorbecăit",
    "neorbecăiți": "neorbecăit",
    "neorbită": "neorbit",
    "neorbite": "neorbit",
    "neorbiți": "neorbit",
    "neorchestrată": "neorchestrat",
    "neorchestrate": "neorchestrat",
    "neorchestrați": "neorchestrat",
    "neordonata": "neordonat",
    "neordonată": "neordonat",
    "neordonate": "neordonat",
    "neordonatei": "neordonat",
    "neordonatele": "neordonat",
    "neordonatelor": "neordonat",
    "neordonați": "neordonat",
    "neordonații": "neordonat",
    "neordonaților": "neordonat",
    "neordonatul": "neordonat",
    "neordonatului": "neordonat",
    "neorealista": "neorealist",
    "neorealistă": "neorealist",
    "neorealiste": "neorealist",
    "neorealistei": "neorealist",
    "neorealistele": "neorealist",
    "neorealistelor": "neorealist",
    "neorealiști": "neorealist",
    "neorealiștii": "neorealist",
    "neorealiștilor": "neorealist",
    "neorealistul": "neorealist",
    "neorealistului": "neorealist",
    "neorganica": "neorganic",
    "neorganică": "neorganic",
    "neorganice": "neorganic",
    "neorganicei": "neorganic",
    "neorganicele": "neorganic",
    "neorganicelor": "neorganic",
    "neorganici": "neorganic",
    "neorganicii": "neorganic",
    "neorganicilor": "neorganic",
    "neorganicul": "neorganic",
    "neorganicului": "neorganic",
    "neorganizată": "neorganizat",
    "neorganizate": "neorganizat",
    "neorganizați": "neorganizat",
    "neorientată": "neorientat",
    "neorientate": "neorientat",
    "neorientați": "neorientat",
    "neoripilată": "neoripilat",
    "neoripilate": "neoripilat",
    "neoripilați": "neoripilat",
    "neornamentată": "neornamentat",
    "neornamentate": "neornamentat",
    "neornamentați": "neornamentat",
    "neornată": "neornat",
    "neornate": "neornat",
    "neornați": "neornat",
    "neoromantica": "neoromantic",
    "neoromantică": "neoromantic",
    "neoromantice": "neoromantic",
    "neoromanticei": "neoromantic",
    "neoromanticele": "neoromantic",
    "neoromanticelor": "neoromantic",
    "neoromantici": "neoromantic",
    "neoromanticii": "neoromantic",
    "neoromanticilor": "neoromantic",
    "neoromanticul": "neoromantic",
    "neoromanticului": "neoromantic",
    "neoropsită": "neoropsit",
    "neoropsite": "neoropsit",
    "neoropsiți": "neoropsit",
    "neortodoxă": "neortodox",
    "neortodoxe": "neortodox",
    "neortodoxia": "neortodoxie",
    "neosândită": "neosândit",
    "neosândite": "neosândit",
    "neosândiți": "neosândit",
    "neoscilată": "neoscilat",
    "neoscilate": "neoscilat",
    "neoscilați": "neoscilat",
    "neosificata": "neosificat",
    "neosificată": "neosificat",
    "neosificate": "neosificat",
    "neosificatei": "neosificat",
    "neosificatele": "neosificat",
    "neosificatelor": "neosificat",
    "neosificați": "neosificat",
    "neosificații": "neosificat",
    "neosificaților": "neosificat",
    "neosificatul": "neosificat",
    "neosificatului": "neosificat",
    "neospătată": "neospătat",
    "neospătate": "neospătat",
    "neospătați": "neospătat",
    "neostenita": "neostenit",
    "neostenită": "neostenit",
    "neostenite": "neostenit",
    "neostenitei": "neostenit",
    "neostenitele": "neostenit",
    "neostenitelor": "neostenit",
    "neosteniți": "neostenit",
    "neosteniții": "neostenit",
    "neosteniților": "neostenit",
    "neostenitul": "neostenit",
    "neostenitului": "neostenit",
    "neostoita": "neostoit",
    "neostoită": "neostoit",
    "neostoite": "neostoit",
    "neostoitei": "neostoit",
    "neostoitele": "neostoit",
    "neostoitelor": "neostoit",
    "neostoiți": "neostoit",
    "neostoiții": "neostoit",
    "neostoiților": "neostoit",
    "neostoitul": "neostoit",
    "neostoitului": "neostoit",
    "neostracizată": "neostracizat",
    "neostracizate": "neostracizat",
    "neostracizați": "neostracizat",
    "neoțărâtă": "neoțărât",
    "neoțărâte": "neoțărât",
    "neoțărâți": "neoțărât",
    "neotectonica": "neotectonic",
    "neotectonică": "neotectonic",
    "neotectonice": "neotectonic",
    "neotectonicei": "neotectonic",
    "neotectonicele": "neotectonic",
    "neotectonicelor": "neotectonic",
    "neotectonici": "neotectonic",
    "neotectonicii": "neotectonic",
    "neotectonicilor": "neotectonic",
    "neotectonicul": "neotectonic",
    "neotectonicului": "neotectonic",
    "neoțelită": "neoțelit",
    "neoțelite": "neoțelit",
    "neoțeliți": "neoțelit",
    "neoțetită": "neoțetit",
    "neoțetite": "neoțetit",
    "neoțetiți": "neoțetit",
    "neotrăvită": "neotrăvit",
    "neotrăvite": "neotrăvit",
    "neotrăviți": "neotrăvit",
    "neouată": "neouat",
    "neouate": "neouat",
    "neouați": "neouat",
    "neovaționată": "neovaționat",
    "neovaționate": "neovaționat",
    "neovaționați": "neovaționat",
    "neoxidată": "neoxidat",
    "neoxidate": "neoxidat",
    "neoxidați": "neoxidat",
    "neoxigenată": "neoxigenat",
    "neoxigenate": "neoxigenat",
    "neoxigenați": "neoxigenat",
    "neozeelandeza": "neozeelandez",
    "neozeelandeză": "neozeelandez",
    "neozeelandeze": "neozeelandez",
    "neozeelandezei": "neozeelandez",
    "neozeelandezele": "neozeelandez",
    "neozeelandezelor": "neozeelandez",
    "neozeelandezi": "neozeelandez",
    "neozeelandezii": "neozeelandez",
    "neozeelandezilor": "neozeelandez",
    "neozeelandezul": "neozeelandez",
    "neozeelandezului": "neozeelandez",
    "neozoica": "neozoic",
    "neozoică": "neozoic",
    "neozoice": "neozoic",
    "neozoicei": "neozoic",
    "neozoicele": "neozoic",
    "neozoicelor": "neozoic",
    "neozoici": "neozoic",
    "neozoicii": "neozoic",
    "neozoicilor": "neozoic",
    "neozoicul": "neozoic",
    "neozoicului": "neozoic",
    "neozonizată": "neozonizat",
    "neozonizate": "neozonizat",
    "neozonizați": "neozonizat",
    "nepâcâită": "nepâcâit",
    "nepâcâite": "nepâcâit",
    "nepâcâiți": "nepâcâit",
    "nepăcălita": "nepăcălit",
    "nepăcălită": "nepăcălit",
    "nepăcălite": "nepăcălit",
    "nepăcălitei": "nepăcălit",
    "nepăcălitele": "nepăcălit",
    "nepăcălitelor": "nepăcălit",
    "nepăcăliți": "nepăcălit",
    "nepăcăliții": "nepăcălit",
    "nepăcăliților": "nepăcălit",
    "nepăcălitul": "nepăcălit",
    "nepăcălitului": "nepăcălit",
    "nepăcănită": "nepăcănit",
    "nepăcănite": "nepăcănit",
    "nepăcăniți": "nepăcănit",
    "nepăcătuită": "nepăcătuit",
    "nepăcătuite": "nepăcătuit",
    "nepăcătuiți": "nepăcătuit",
    "nepacificată": "nepacificat",
    "nepacificate": "nepacificat",
    "nepacificați": "nepacificat",
    "nepactizată": "nepactizat",
    "nepactizate": "nepactizat",
    "nepactizați": "nepactizat",
    "nepaginată": "nepaginat",
    "nepaginate": "nepaginat",
    "nepaginați": "nepaginat",
    "nepăgubita": "nepăgubit",
    "nepăgubită": "nepăgubit",
    "nepăgubite": "nepăgubit",
    "nepăgubitei": "nepăgubit",
    "nepăgubitele": "nepăgubit",
    "nepăgubitelor": "nepăgubit",
    "nepăgubiți": "nepăgubit",
    "nepăgubiții": "nepăgubit",
    "nepăgubiților": "nepăgubit",
    "nepăgubitul": "nepăgubit",
    "nepăgubitului": "nepăgubit",
    "nepălălăită": "nepălălăit",
    "nepălălăite": "nepălălăit",
    "nepălălăiți": "nepălălăit",
    "nepălăvrăgită": "nepălăvrăgit",
    "nepălăvrăgite": "nepălăvrăgit",
    "nepălăvrăgiți": "nepălăvrăgit",
    "nepaleza": "nepalez",
    "nepaleză": "nepalez",
    "nepaleze": "nepalez",
    "nepalezei": "nepalez",
    "nepalezele": "nepalez",
    "nepalezelor": "nepalez",
    "nepalezi": "nepalez",
    "nepalezii": "nepalez",
    "nepalezilor": "nepalez",
    "nepalezul": "nepalez",
    "nepalezului": "nepalez",
    "nepălita": "nepălit",
    "nepălită": "nepălit",
    "nepălite": "nepălit",
    "nepălitei": "nepălit",
    "nepălitele": "nepălit",
    "nepălitelor": "nepălit",
    "nepăliți": "nepălit",
    "nepăliții": "nepălit",
    "nepăliților": "nepălit",
    "nepălitul": "nepălit",
    "nepălitului": "nepălit",
    "nepălmuita": "nepălmuit",
    "nepălmuită": "nepălmuit",
    "nepălmuite": "nepălmuit",
    "nepălmuitei": "nepălmuit",
    "nepălmuitele": "nepălmuit",
    "nepălmuitelor": "nepălmuit",
    "nepălmuiți": "nepălmuit",
    "nepălmuiții": "nepălmuit",
    "nepălmuiților": "nepălmuit",
    "nepălmuitul": "nepălmuit",
    "nepălmuitului": "nepălmuit",
    "nepâlpâită": "nepâlpâit",
    "nepâlpâite": "nepâlpâit",
    "nepâlpâiți": "nepâlpâit",
    "nepalpitanta": "nepalpitant",
    "nepalpitantă": "nepalpitant",
    "nepalpitante": "nepalpitant",
    "nepalpitantei": "nepalpitant",
    "nepalpitantele": "nepalpitant",
    "nepalpitantelor": "nepalpitant",
    "nepalpitanți": "nepalpitant",
    "nepalpitanții": "nepalpitant",
    "nepalpitanților": "nepalpitant",
    "nepalpitantul": "nepalpitant",
    "nepalpitantului": "nepalpitant",
    "nepalpitată": "nepalpitat",
    "nepalpitate": "nepalpitat",
    "nepalpitați": "nepalpitat",
    "nepământeana": "nepământean",
    "nepământeană": "nepământean",
    "nepământeanul": "nepământean",
    "nepământeanului": "nepământean",
    "nepământene": "nepământean",
    "nepământenei": "nepământean",
    "nepământenele": "nepământean",
    "nepământenelor": "nepământean",
    "nepământeni": "nepământean",
    "nepământenii": "nepământean",
    "nepământenilor": "nepământean",
    "nepământeasca": "nepământesc",
    "nepământească": "nepământesc",
    "nepământescul": "nepământesc",
    "nepământescului": "nepământesc",
    "nepământești": "nepământesc",
    "nepământeștii": "nepământesc",
    "nepământeștile": "nepământesc",
    "nepământeștilor": "nepământesc",
    "nepândită": "nepândit",
    "nepândite": "nepândit",
    "nepândiți": "nepândit",
    "nepângărită": "nepângărit",
    "nepângărite": "nepângărit",
    "nepângăriți": "nepângărit",
    "nepanificată": "nepanificat",
    "nepanificate": "nepanificat",
    "nepanificați": "nepanificat",
    "nepansată": "nepansat",
    "nepansate": "nepansat",
    "nepansați": "nepansat",
    "nepăpată": "nepăpat",
    "nepăpate": "nepăpat",
    "nepăpați": "nepăpat",
    "neparafată": "neparafat",
    "neparafate": "neparafat",
    "neparafați": "neparafat",
    "neparafrazată": "neparafrazat",
    "neparafrazate": "neparafrazat",
    "neparafrazați": "neparafrazat",
    "nepărăginita": "nepărăginit",
    "nepărăginită": "nepărăginit",
    "nepărăginite": "nepărăginit",
    "nepărăginitei": "nepărăginit",
    "nepărăginitele": "nepărăginit",
    "nepărăginitelor": "nepărăginit",
    "nepărăginiți": "nepărăginit",
    "nepărăginiții": "nepărăginit",
    "nepărăginiților": "nepărăginit",
    "nepărăginitul": "nepărăginit",
    "nepărăginitului": "nepărăginit",
    "nepârâita": "nepârâit",
    "nepârâită": "nepârâit",
    "nepârâite": "nepârâit",
    "nepârâitei": "nepârâit",
    "nepârâitele": "nepârâit",
    "nepârâitelor": "nepârâit",
    "nepârâiți": "nepârâit",
    "nepârâiții": "nepârâit",
    "nepârâiților": "nepârâit",
    "nepârâitul": "nepârâit",
    "nepârâitului": "nepârâit",
    "neparalelizată": "neparalelizat",
    "neparalelizate": "neparalelizat",
    "neparalelizați": "neparalelizat",
    "neparalizată": "neparalizat",
    "neparalizate": "neparalizat",
    "neparalizați": "neparalizat",
    "nepărăsita": "nepărăsit",
    "nepărăsită": "nepărăsit",
    "nepărăsite": "nepărăsit",
    "nepărăsitei": "nepărăsit",
    "nepărăsitele": "nepărăsit",
    "nepărăsitelor": "nepărăsit",
    "nepărăsiți": "nepărăsit",
    "nepărăsiții": "nepărăsit",
    "nepărăsiților": "nepărăsit",
    "nepărăsitul": "nepărăsit",
    "nepărăsitului": "nepărăsit",
    "neparașutată": "neparașutat",
    "neparașutate": "neparașutat",
    "neparașutați": "neparașutat",
    "nepârâtă": "nepârât",
    "nepârâte": "nepârât",
    "nepârâți": "nepârât",
    "neparazitată": "neparazitat",
    "neparazitate": "neparazitat",
    "neparazitați": "neparazitat",
    "neparcată": "neparcat",
    "neparcate": "neparcat",
    "neparcați": "neparcat",
    "neparcelata": "neparcelat",
    "neparcelată": "neparcelat",
    "neparcelate": "neparcelat",
    "neparcelatei": "neparcelat",
    "neparcelatele": "neparcelat",
    "neparcelatelor": "neparcelat",
    "neparcelați": "neparcelat",
    "neparcelații": "neparcelat",
    "neparcelaților": "neparcelat",
    "neparcelatul": "neparcelat",
    "neparcelatului": "neparcelat",
    "neparchetata": "neparchetat",
    "neparchetată": "neparchetat",
    "neparchetate": "neparchetat",
    "neparchetatei": "neparchetat",
    "neparchetatele": "neparchetat",
    "neparchetatelor": "neparchetat",
    "neparchetați": "neparchetat",
    "neparchetații": "neparchetat",
    "neparchetaților": "neparchetat",
    "neparchetatul": "neparchetat",
    "neparchetatului": "neparchetat",
    "neparcursă": "neparcurs",
    "neparcurse": "neparcurs",
    "neparcurși": "neparcurs",
    "nepardosita": "nepardosit",
    "nepardosită": "nepardosit",
    "nepardosite": "nepardosit",
    "nepardositei": "nepardosit",
    "nepardositele": "nepardosit",
    "nepardositelor": "nepardosit",
    "nepardosiți": "nepardosit",
    "nepardosiții": "nepardosit",
    "nepardosiților": "nepardosit",
    "nepardositul": "nepardosit",
    "nepardositului": "nepardosit",
    "neparfumata": "neparfumat",
    "neparfumată": "neparfumat",
    "neparfumate": "neparfumat",
    "neparfumatei": "neparfumat",
    "neparfumatele": "neparfumat",
    "neparfumatelor": "neparfumat",
    "neparfumați": "neparfumat",
    "neparfumații": "neparfumat",
    "neparfumaților": "neparfumat",
    "neparfumatul": "neparfumat",
    "neparfumatului": "neparfumat",
    "nepârguită": "nepârguit",
    "nepârguite": "nepârguit",
    "nepârguiți": "nepârguit",
    "nepariată": "nepariat",
    "nepariate": "nepariat",
    "nepariați": "nepariat",
    "nepârjolită": "nepârjolit",
    "nepârjolite": "nepârjolit",
    "nepârjoliți": "nepârjolit",
    "neparlamentată": "neparlamentat",
    "neparlamentate": "neparlamentat",
    "neparlamentați": "neparlamentat",
    "nepârlită": "nepârlit",
    "nepârlite": "nepârlit",
    "nepârliți": "nepârlit",
    "neparodiată": "neparodiat",
    "neparodiate": "neparodiat",
    "neparodiați": "neparodiat",
    "neparticiparea": "neparticipare",
    "neparticipari": "neparticipare",
    "neparticiparii": "neparticipare",
    "neparticiparile": "neparticipare",
    "neparticiparilor": "neparticipare",
    "neparticipată": "neparticipat",
    "neparticipate": "neparticipat",
    "neparticipați": "neparticipat",
    "nepărtinirea": "nepărtinire",
    "nepărtiniri": "nepărtinire",
    "nepărtinirii": "nepărtinire",
    "nepărtinirile": "nepărtinire",
    "nepărtinirilor": "nepărtinire",
    "nepărtinită": "nepărtinit",
    "nepărtinite": "nepărtinit",
    "nepărtiniți": "nepărtinit",
    "nepărtinitoare": "nepărtinitor",
    "nepărtinitoarea": "nepărtinitor",
    "nepărtinitoarei": "nepărtinitor",
    "nepărtinitoarele": "nepărtinitor",
    "nepărtinitoarelor": "nepărtinitor",
    "nepărtinitori": "nepărtinitor",
    "nepărtinitorii": "nepărtinitor",
    "nepărtinitorilor": "nepărtinitor",
    "nepărtinitorul": "nepărtinitor",
    "nepărtinitorului": "nepărtinitor",
    "nepăruită": "nepăruit",
    "nepăruite": "nepăruit",
    "nepăruiți": "nepăruit",
    "nepărută": "nepărut",
    "nepărute": "nepărut",
    "nepăruți": "nepărut",
    "neparvenită": "neparvenit",
    "neparvenite": "neparvenit",
    "neparveniți": "neparvenit",
    "nepăsarea": "nepăsare",
    "nepăsări": "nepăsare",
    "nepăsării": "nepăsare",
    "nepăsările": "nepăsare",
    "nepăsărilor": "nepăsare",
    "nepasată": "nepasat",
    "nepasate": "nepasat",
    "nepasați": "nepasat",
    "nepăsătoare": "nepăsător",
    "nepăsătoarea": "nepăsător",
    "nepăsătoarei": "nepăsător",
    "nepăsătoarele": "nepăsător",
    "nepăsătoarelor": "nepăsător",
    "nepăsători": "nepăsător",
    "nepăsătorii": "nepăsător",
    "nepăsătorilor": "nepăsător",
    "nepăsătorul": "nepăsător",
    "nepăsătorului": "nepăsător",
    "nepascută": "nepascut",
    "nepascute": "nepascut",
    "nepascuți": "nepascut",
    "nepasionata": "nepasionat",
    "nepasionată": "nepasionat",
    "nepasionate": "nepasionat",
    "nepasionatei": "nepasionat",
    "nepasionatele": "nepasionat",
    "nepasionatelor": "nepasionat",
    "nepasionați": "nepasionat",
    "nepasionații": "nepasionat",
    "nepasionaților": "nepasionat",
    "nepasionatul": "nepasionat",
    "nepasionatului": "nepasionat",
    "nepășită": "nepășit",
    "nepășite": "nepășit",
    "nepășiți": "nepășit",
    "nepasteurizata": "nepasteurizat",
    "nepasteurizată": "nepasteurizat",
    "nepasteurizate": "nepasteurizat",
    "nepasteurizatei": "nepasteurizat",
    "nepasteurizatele": "nepasteurizat",
    "nepasteurizatelor": "nepasteurizat",
    "nepasteurizați": "nepasteurizat",
    "nepasteurizații": "nepasteurizat",
    "nepasteurizaților": "nepasteurizat",
    "nepasteurizatul": "nepasteurizat",
    "nepasteurizatului": "nepasteurizat",
    "nepăstorită": "nepăstorit",
    "nepăstorite": "nepăstorit",
    "nepăstoriți": "nepăstorit",
    "nepăstrată": "nepăstrat",
    "nepăstrate": "nepăstrat",
    "nepăstrați": "nepăstrat",
    "nepaștută": "nepaștut",
    "nepaștute": "nepaștut",
    "nepaștuți": "nepaștut",
    "nepăștută": "nepăștut",
    "nepăștute": "nepăștut",
    "nepăștuți": "nepăștut",
    "nepăsuita": "nepăsuit",
    "nepăsuită": "nepăsuit",
    "nepăsuite": "nepăsuit",
    "nepăsuitei": "nepăsuit",
    "nepăsuitele": "nepăsuit",
    "nepăsuitelor": "nepăsuit",
    "nepăsuiți": "nepăsuit",
    "nepăsuiții": "nepăsuit",
    "nepăsuiților": "nepăsuit",
    "nepăsuitul": "nepăsuit",
    "nepăsuitului": "nepăsuit",
    "nepășunată": "nepășunat",
    "nepășunate": "nepășunat",
    "nepășunați": "nepășunat",
    "nepătata": "nepătat",
    "nepătată": "nepătat",
    "nepătate": "nepătat",
    "nepătatei": "nepătat",
    "nepătatele": "nepătat",
    "nepătatelor": "nepătat",
    "nepătați": "nepătat",
    "nepătații": "nepătat",
    "nepătaților": "nepătat",
    "nepătatul": "nepătat",
    "nepătatului": "nepătat",
    "nepatentata": "nepatentat",
    "nepatentată": "nepatentat",
    "nepatentate": "nepatentat",
    "nepatentatei": "nepatentat",
    "nepatentatele": "nepatentat",
    "nepatentatelor": "nepatentat",
    "nepatentați": "nepatentat",
    "nepatentații": "nepatentat",
    "nepatentaților": "nepatentat",
    "nepatentatul": "nepatentat",
    "nepatentatului": "nepatentat",
    "nepătimită": "nepătimit",
    "nepătimite": "nepătimit",
    "nepătimiți": "nepătimit",
    "nepatinată": "nepatinat",
    "nepatinate": "nepatinat",
    "nepatinați": "nepatinat",
    "nepățita": "nepățit",
    "nepățită": "nepățit",
    "nepățite": "nepățit",
    "nepățitei": "nepățit",
    "nepățitele": "nepățit",
    "nepățitelor": "nepățit",
    "nepățiți": "nepățit",
    "nepățiții": "nepățit",
    "nepățiților": "nepățit",
    "nepățitul": "nepățit",
    "nepățitului": "nepățit",
    "nepatrulată": "nepatrulat",
    "nepatrulate": "nepatrulat",
    "nepatrulați": "nepatrulat",
    "nepătrunsa": "nepătruns",
    "nepătrunsă": "nepătruns",
    "nepătrunse": "nepătruns",
    "nepătrunsei": "nepătruns",
    "nepătrunsele": "nepătruns",
    "nepătrunselor": "nepătruns",
    "nepătrunsi": "nepătruns",
    "nepătrunși": "nepătruns",
    "nepătrunsii": "nepătruns",
    "nepătrunsilor": "nepătruns",
    "nepătrunsul": "nepătruns",
    "nepătrunsului": "nepătruns",
    "nepauperizata": "nepauperizat",
    "nepauperizată": "nepauperizat",
    "nepauperizate": "nepauperizat",
    "nepauperizatei": "nepauperizat",
    "nepauperizatele": "nepauperizat",
    "nepauperizatelor": "nepauperizat",
    "nepauperizați": "nepauperizat",
    "nepauperizații": "nepauperizat",
    "nepauperizaților": "nepauperizat",
    "nepauperizatul": "nepauperizat",
    "nepauperizatului": "nepauperizat",
    "nepavată": "nepavat",
    "nepavate": "nepavat",
    "nepavați": "nepavat",
    "nepavoazată": "nepavoazat",
    "nepavoazate": "nepavoazat",
    "nepavoazați": "nepavoazat",
    "nepăzita": "nepăzit",
    "nepăzită": "nepăzit",
    "nepăzite": "nepăzit",
    "nepăzitei": "nepăzit",
    "nepăzitele": "nepăzit",
    "nepăzitelor": "nepăzit",
    "nepăziți": "nepăzit",
    "nepăziții": "nepăzit",
    "nepăziților": "nepăzit",
    "nepăzitul": "nepăzit",
    "nepăzitului": "nepăzit",
    "nepecetluita": "nepecetluit",
    "nepecetluită": "nepecetluit",
    "nepecetluite": "nepecetluit",
    "nepecetluitei": "nepecetluit",
    "nepecetluitele": "nepecetluit",
    "nepecetluitelor": "nepecetluit",
    "nepecetluiți": "nepecetluit",
    "nepecetluiții": "nepecetluit",
    "nepecetluiților": "nepecetluit",
    "nepecetluitul": "nepecetluit",
    "nepecetluitului": "nepecetluit",
    "nepedalată": "nepedalat",
    "nepedalate": "nepedalat",
    "nepedalați": "nepedalat",
    "nepedepsita": "nepedepsit",
    "nepedepsită": "nepedepsit",
    "nepedepsite": "nepedepsit",
    "nepedepsitei": "nepedepsit",
    "nepedepsitele": "nepedepsit",
    "nepedepsitelor": "nepedepsit",
    "nepedepsiți": "nepedepsit",
    "nepedepsiții": "nepedepsit",
    "nepedepsiților": "nepedepsit",
    "nepedepsitul": "nepedepsit",
    "nepedepsitului": "nepedepsit",
    "nepenalizată": "nepenalizat",
    "nepenalizate": "nepenalizat",
    "nepenalizați": "nepenalizat",
    "nependulată": "nependulat",
    "nependulate": "nependulat",
    "nependulați": "nependulat",
    "nepenetrată": "nepenetrat",
    "nepenetrate": "nepenetrat",
    "nepenetrați": "nepenetrat",
    "nepercepută": "neperceput",
    "nepercepute": "neperceput",
    "nepercepuți": "neperceput",
    "nepercheziționată": "nepercheziționat",
    "nepercheziționate": "nepercheziționat",
    "nepercheziționați": "nepercheziționat",
    "nepercutată": "nepercutat",
    "nepercutate": "nepercutat",
    "nepercutați": "nepercutat",
    "neperegrinată": "neperegrinat",
    "neperegrinate": "neperegrinat",
    "neperegrinați": "neperegrinat",
    "neperfectată": "neperfectat",
    "neperfectate": "neperfectat",
    "neperfectați": "neperfectat",
    "neperfecționată": "neperfecționat",
    "neperfecționate": "neperfecționat",
    "neperfecționați": "neperfecționat",
    "neperforata": "neperforat",
    "neperforată": "neperforat",
    "neperforate": "neperforat",
    "neperforatei": "neperforat",
    "neperforatele": "neperforat",
    "neperforatelor": "neperforat",
    "neperforați": "neperforat",
    "neperforații": "neperforat",
    "neperforaților": "neperforat",
    "neperforatul": "neperforat",
    "neperforatului": "neperforat",
    "neperformantă": "neperformant",
    "neperformante": "neperformant",
    "neperformanți": "neperformant",
    "neperiata": "neperiat",
    "neperiată": "neperiat",
    "neperiate": "neperiat",
    "neperiatei": "neperiat",
    "neperiatele": "neperiat",
    "neperiatelor": "neperiat",
    "neperiați": "neperiat",
    "neperiații": "neperiat",
    "neperiaților": "neperiat",
    "neperiatul": "neperiat",
    "neperiatului": "neperiat",
    "nepericlitată": "nepericlitat",
    "nepericlitate": "nepericlitat",
    "nepericlitați": "nepericlitat",
    "nepericuloasa": "nepericulos",
    "nepericuloasă": "nepericulos",
    "nepericuloase": "nepericulos",
    "nepericuloasei": "nepericulos",
    "nepericuloasele": "nepericulos",
    "nepericuloaselor": "nepericulos",
    "nepericuloși": "nepericulos",
    "nepericuloșii": "nepericulos",
    "nepericuloșilor": "nepericulos",
    "nepericulosul": "nepericulos",
    "nepericulosului": "nepericulos",
    "neperimata": "neperimat",
    "neperimată": "neperimat",
    "neperimate": "neperimat",
    "neperimatei": "neperimat",
    "neperimatele": "neperimat",
    "neperimatelor": "neperimat",
    "neperimați": "neperimat",
    "neperimații": "neperimat",
    "neperimaților": "neperimat",
    "neperimatul": "neperimat",
    "neperimatului": "neperimat",
    "neperindată": "neperindat",
    "neperindate": "neperindat",
    "neperindați": "neperindat",
    "neperiodica": "neperiodic",
    "neperiodică": "neperiodic",
    "neperiodice": "neperiodic",
    "neperiodicei": "neperiodic",
    "neperiodicele": "neperiodic",
    "neperiodicelor": "neperiodic",
    "neperiodici": "neperiodic",
    "neperiodicii": "neperiodic",
    "neperiodicilor": "neperiodic",
    "neperiodicul": "neperiodic",
    "neperiodicului": "neperiodic",
    "neperiodizată": "neperiodizat",
    "neperiodizate": "neperiodizat",
    "neperiodizați": "neperiodizat",
    "nepermanentizată": "nepermanentizat",
    "nepermanentizate": "nepermanentizat",
    "nepermanentizați": "nepermanentizat",
    "nepermisa": "nepermis",
    "nepermisă": "nepermis",
    "nepermise": "nepermis",
    "nepermisei": "nepermis",
    "nepermisele": "nepermis",
    "nepermiselor": "nepermis",
    "nepermiși": "nepermis",
    "nepermisii": "nepermis",
    "nepermisilor": "nepermis",
    "nepermisul": "nepermis",
    "nepermisului": "nepermis",
    "nepermutată": "nepermutat",
    "nepermutate": "nepermutat",
    "nepermutați": "nepermutat",
    "neperorată": "neperorat",
    "neperorate": "neperorat",
    "neperorați": "neperorat",
    "neperpelita": "neperpelit",
    "neperpelită": "neperpelit",
    "neperpelite": "neperpelit",
    "neperpelitei": "neperpelit",
    "neperpelitele": "neperpelit",
    "neperpelitelor": "neperpelit",
    "neperpeliți": "neperpelit",
    "neperpeliții": "neperpelit",
    "neperpeliților": "neperpelit",
    "neperpelitul": "neperpelit",
    "neperpelitului": "neperpelit",
    "neperpetuată": "neperpetuat",
    "neperpetuate": "neperpetuat",
    "neperpetuați": "neperpetuat",
    "nepersecutată": "nepersecutat",
    "nepersecutate": "nepersecutat",
    "nepersecutați": "nepersecutat",
    "neperseverată": "neperseverat",
    "neperseverate": "neperseverat",
    "neperseverați": "neperseverat",
    "nepersiflată": "nepersiflat",
    "nepersiflate": "nepersiflat",
    "nepersiflați": "nepersiflat",
    "nepersistată": "nepersistat",
    "nepersistate": "nepersistat",
    "nepersistați": "nepersistat",
    "nepersoane": "nepersoană",
    "nepersonificată": "nepersonificat",
    "nepersonificate": "nepersonificat",
    "nepersonificați": "nepersonificat",
    "nepertractată": "nepertractat",
    "nepertractate": "nepertractat",
    "nepertractați": "nepertractat",
    "neperturbată": "neperturbat",
    "neperturbate": "neperturbat",
    "neperturbați": "neperturbat",
    "nepervertită": "nepervertit",
    "nepervertite": "nepervertit",
    "nepervertiți": "nepervertit",
    "nepescuită": "nepescuit",
    "nepescuite": "nepescuit",
    "nepescuiți": "nepescuit",
    "nepeticită": "nepeticit",
    "nepeticite": "nepeticit",
    "nepeticiți": "nepeticit",
    "nepețită": "nepețit",
    "nepețite": "nepețit",
    "nepețiți": "nepețit",
    "nepetrecută": "nepetrecut",
    "nepetrecute": "nepetrecut",
    "nepetrecuți": "nepetrecut",
    "nepicată": "nepicat",
    "nepicate": "nepicat",
    "nepicați": "nepicat",
    "nepichetată": "nepichetat",
    "nepichetate": "nepichetat",
    "nepichetați": "nepichetat",
    "nepicnită": "nepicnit",
    "nepicnite": "nepicnit",
    "nepicniți": "nepicnit",
    "nepicotită": "nepicotit",
    "nepicotite": "nepicotit",
    "nepicotiți": "nepicotit",
    "nepictata": "nepictat",
    "nepictată": "nepictat",
    "nepictate": "nepictat",
    "nepictatei": "nepictat",
    "nepictatele": "nepictat",
    "nepictatelor": "nepictat",
    "nepictați": "nepictat",
    "nepictații": "nepictat",
    "nepictaților": "nepictat",
    "nepictatul": "nepictat",
    "nepictatului": "nepictat",
    "nepicurată": "nepicurat",
    "nepicurate": "nepicurat",
    "nepicurați": "nepicurat",
    "nepieptănată": "nepieptănat",
    "nepieptănate": "nepieptănat",
    "nepieptănați": "nepieptănat",
    "nepierdută": "nepierdut",
    "nepierdute": "nepierdut",
    "nepierduți": "nepierdut",
    "nepierită": "nepierit",
    "nepierite": "nepierit",
    "nepieriți": "nepierit",
    "nepieritoare": "nepieritor",
    "nepieritoarea": "nepieritor",
    "nepieritoarei": "nepieritor",
    "nepieritoarele": "nepieritor",
    "nepieritoarelor": "nepieritor",
    "nepieritori": "nepieritor",
    "nepieritorii": "nepieritor",
    "nepieritorilor": "nepieritor",
    "nepieritorul": "nepieritor",
    "nepieritorului": "nepieritor",
    "nepietruita": "nepietruit",
    "nepietruită": "nepietruit",
    "nepietruite": "nepietruit",
    "nepietruitei": "nepietruit",
    "nepietruitele": "nepietruit",
    "nepietruitelor": "nepietruit",
    "nepietruiți": "nepietruit",
    "nepietruiții": "nepietruit",
    "nepietruiților": "nepietruit",
    "nepietruitul": "nepietruit",
    "nepietruitului": "nepietruit",
    "nepigmentată": "nepigmentat",
    "nepigmentate": "nepigmentat",
    "nepigmentați": "nepigmentat",
    "nepigulită": "nepigulit",
    "nepigulite": "nepigulit",
    "nepiguliți": "nepigulit",
    "nepilduita": "nepilduit",
    "nepilduită": "nepilduit",
    "nepilduite": "nepilduit",
    "nepilduitei": "nepilduit",
    "nepilduitele": "nepilduit",
    "nepilduitelor": "nepilduit",
    "nepilduiți": "nepilduit",
    "nepilduiții": "nepilduit",
    "nepilduiților": "nepilduit",
    "nepilduitul": "nepilduit",
    "nepilduitului": "nepilduit",
    "nepilită": "nepilit",
    "nepilite": "nepilit",
    "nepiliți": "nepilit",
    "nepilotată": "nepilotat",
    "nepilotate": "nepilotat",
    "nepilotați": "nepilotat",
    "nepingelită": "nepingelit",
    "nepingelite": "nepingelit",
    "nepingeliți": "nepingelit",
    "nepipăita": "nepipăit",
    "nepipăită": "nepipăit",
    "nepipăite": "nepipăit",
    "nepipăitei": "nepipăit",
    "nepipăitele": "nepipăit",
    "nepipăitelor": "nepipăit",
    "nepipăiți": "nepipăit",
    "nepipăiții": "nepipăit",
    "nepipăiților": "nepipăit",
    "nepipăitul": "nepipăit",
    "nepipăitului": "nepipăit",
    "nepiperată": "nepiperat",
    "nepiperate": "nepiperat",
    "nepiperați": "nepiperat",
    "nepironită": "nepironit",
    "nepironite": "nepironit",
    "nepironiți": "nepironit",
    "nepirotită": "nepirotit",
    "nepirotite": "nepirotit",
    "nepirotiți": "nepirotit",
    "nepisălogită": "nepisălogit",
    "nepisălogite": "nepisălogit",
    "nepisălogiți": "nepisălogit",
    "nepisată": "nepisat",
    "nepisate": "nepisat",
    "nepisați": "nepisat",
    "nepișcată": "nepișcat",
    "nepișcate": "nepișcat",
    "nepișcați": "nepișcat",
    "nepistonată": "nepistonat",
    "nepistonate": "nepistonat",
    "nepistonați": "nepistonat",
    "nepitită": "nepitit",
    "nepitite": "nepitit",
    "nepitiți": "nepitit",
    "nepitulată": "nepitulat",
    "nepitulate": "nepitulat",
    "nepitulați": "nepitulat",
    "nepiuită": "nepiuit",
    "nepiuite": "nepiuit",
    "nepiuiți": "nepiuit",
    "nepivotată": "nepivotat",
    "nepivotate": "nepivotat",
    "nepivotați": "nepivotat",
    "nepizmuită": "nepizmuit",
    "nepizmuite": "nepizmuit",
    "nepizmuiți": "nepizmuit",
    "neplacată": "neplacat",
    "neplacate": "neplacat",
    "neplacați": "neplacat",
    "neplăcerea": "neplăcere",
    "neplăceri": "neplăcere",
    "neplăcerii": "neplăcere",
    "neplăcerile": "neplăcere",
    "neplăcerilor": "neplăcere",
    "neplăcuta": "neplăcut",
    "neplăcută": "neplăcut",
    "neplăcute": "neplăcut",
    "neplăcutei": "neplăcut",
    "neplăcutele": "neplăcut",
    "neplăcutelor": "neplăcut",
    "neplăcuți": "neplăcut",
    "neplăcuții": "neplăcut",
    "neplăcuților": "neplăcut",
    "neplăcutul": "neplăcut",
    "neplăcutului": "neplăcut",
    "neplafonată": "neplafonat",
    "neplafonate": "neplafonat",
    "neplafonați": "neplafonat",
    "neplagiată": "neplagiat",
    "neplagiate": "neplagiat",
    "neplagiați": "neplagiat",
    "neplămădită": "neplămădit",
    "neplămădite": "neplămădit",
    "neplămădiți": "neplămădit",
    "neplanată": "neplanat",
    "neplanate": "neplanat",
    "neplanați": "neplanat",
    "neplanificată": "neplanificat",
    "neplanificate": "neplanificat",
    "neplanificați": "neplanificat",
    "neplânsă": "neplâns",
    "neplânse": "neplâns",
    "neplânși": "neplâns",
    "neplantată": "neplantat",
    "neplantate": "neplantat",
    "neplantați": "neplantat",
    "neplănuită": "neplănuit",
    "neplănuite": "neplănuit",
    "neplănuiți": "neplănuit",
    "neplasată": "neplasat",
    "neplasate": "neplasat",
    "neplasați": "neplasat",
    "neplăsmuită": "neplăsmuit",
    "neplăsmuite": "neplăsmuit",
    "neplăsmuiți": "neplăsmuit",
    "neplasticizată": "neplasticizat",
    "neplasticizate": "neplasticizat",
    "neplasticizați": "neplasticizat",
    "neplastografiată": "neplastografiat",
    "neplastografiate": "neplastografiat",
    "neplastografiați": "neplastografiat",
    "neplata": "neplată",
    "neplati": "neplată",
    "neplatii": "neplată",
    "neplatile": "neplată",
    "neplatilor": "neplată",
    "neplatinată": "neplatinat",
    "neplatinate": "neplatinat",
    "neplatinați": "neplatinat",
    "neplătită": "neplătit",
    "neplătite": "neplătit",
    "neplătiți": "neplătit",
    "neplauzibilă": "neplauzibil",
    "neplauzibile": "neplauzibil",
    "neplauzibili": "neplauzibil",
    "neplecată": "neplecat",
    "neplecate": "neplecat",
    "neplecați": "neplecat",
    "nepledată": "nepledat",
    "nepledate": "nepledat",
    "nepledați": "nepledat",
    "nepleoscăită": "nepleoscăit",
    "nepleoscăite": "nepleoscăit",
    "nepleoscăiți": "nepleoscăit",
    "nepleoștită": "nepleoștit",
    "nepleoștite": "nepleoștit",
    "nepleoștiți": "nepleoștit",
    "neplescăită": "neplescăit",
    "neplescăite": "neplescăit",
    "neplescăiți": "neplescăit",
    "neplesnită": "neplesnit",
    "neplesnite": "neplesnit",
    "neplesniți": "neplesnit",
    "nepleșuvită": "nepleșuvit",
    "nepleșuvite": "nepleșuvit",
    "nepleșuviți": "nepleșuvit",
    "nepliată": "nepliat",
    "nepliate": "nepliat",
    "nepliați": "nepliat",
    "neplictisită": "neplictisit",
    "neplictisite": "neplictisit",
    "neplictisiți": "neplictisit",
    "neplimbată": "neplimbat",
    "neplimbate": "neplimbat",
    "neplimbați": "neplimbat",
    "neplisată": "neplisat",
    "neplisate": "neplisat",
    "neplisați": "neplisat",
    "neplivită": "neplivit",
    "neplivite": "neplivit",
    "nepliviți": "neplivit",
    "neplombată": "neplombat",
    "neplombate": "neplombat",
    "neplombați": "neplombat",
    "neplonjată": "neplonjat",
    "neplonjate": "neplonjat",
    "neplonjați": "neplonjat",
    "neplugărită": "neplugărit",
    "neplugărite": "neplugărit",
    "neplugăriți": "neplugărit",
    "neplumbuită": "neplumbuit",
    "neplumbuite": "neplumbuit",
    "neplumbuiți": "neplumbuit",
    "neplutărită": "neplutărit",
    "neplutărite": "neplutărit",
    "neplutăriți": "neplutărit",
    "neplutită": "neplutit",
    "neplutite": "neplutit",
    "neplutiți": "neplutit",
    "neplutuită": "neplutuit",
    "neplutuite": "neplutuit",
    "neplutuiți": "neplutuit",
    "nepoata": "nepoată",
    "nepoate": "nepoată",
    "nepoatei": "nepoată",
    "nepoatele": "nepoată",
    "nepoatelor": "nepoată",
    "nepocăita": "nepocăit",
    "nepocăită": "nepocăit",
    "nepocăite": "nepocăit",
    "nepocăitei": "nepocăit",
    "nepocăitele": "nepocăit",
    "nepocăitelor": "nepocăit",
    "nepocăiți": "nepocăit",
    "nepocăiții": "nepocăit",
    "nepocăiților": "nepocăit",
    "nepocăitul": "nepocăit",
    "nepocăitului": "nepocăit",
    "nepocită": "nepocit",
    "nepocite": "nepocit",
    "nepociți": "nepocit",
    "nepocnită": "nepocnit",
    "nepocnite": "nepocnit",
    "nepocniți": "nepocnit",
    "nepodidită": "nepodidit",
    "nepodidite": "nepodidit",
    "nepodidiți": "nepodidit",
    "nepodită": "nepodit",
    "nepodite": "nepodit",
    "nepodiți": "nepodit",
    "nepoetizată": "nepoetizat",
    "nepoetizate": "nepoetizat",
    "nepoetizați": "nepoetizat",
    "nepoftita": "nepoftit",
    "nepoftită": "nepoftit",
    "nepoftite": "nepoftit",
    "nepoftitei": "nepoftit",
    "nepoftitele": "nepoftit",
    "nepoftitelor": "nepoftit",
    "nepoftiți": "nepoftit",
    "nepoftiții": "nepoftit",
    "nepoftiților": "nepoftit",
    "nepoftitul": "nepoftit",
    "nepoftitului": "nepoftit",
    "nepogorâtă": "nepogorât",
    "nepogorâte": "nepogorât",
    "nepogorâți": "nepogorât",
    "nepolara": "nepolar",
    "nepolară": "nepolar",
    "nepolare": "nepolar",
    "nepolarei": "nepolar",
    "nepolarele": "nepolar",
    "nepolarelor": "nepolar",
    "nepolari": "nepolar",
    "nepolarii": "nepolar",
    "nepolarilor": "nepolar",
    "nepolarul": "nepolar",
    "nepolarului": "nepolar",
    "nepolarizată": "nepolarizat",
    "nepolarizate": "nepolarizat",
    "nepolarizați": "nepolarizat",
    "nepoleită": "nepoleit",
    "nepoleite": "nepoleit",
    "nepoleiți": "nepoleit",
    "nepolemizată": "nepolemizat",
    "nepolemizate": "nepolemizat",
    "nepolemizați": "nepolemizat",
    "nepolenizată": "nepolenizat",
    "nepolenizate": "nepolenizat",
    "nepolenizați": "nepolenizat",
    "nepolimerizată": "nepolimerizat",
    "nepolimerizate": "nepolimerizat",
    "nepolimerizați": "nepolimerizat",
    "nepolitică": "nepolitic",
    "nepolitice": "nepolitic",
    "nepolitici": "nepolitic",
    "nepoliticoasa": "nepoliticos",
    "nepoliticoasă": "nepoliticos",
    "nepoliticoase": "nepoliticos",
    "nepoliticoasei": "nepoliticos",
    "nepoliticoasele": "nepoliticos",
    "nepoliticoaselor": "nepoliticos",
    "nepoliticoși": "nepoliticos",
    "nepoliticoșii": "nepoliticos",
    "nepoliticoșilor": "nepoliticos",
    "nepoliticosul": "nepoliticos",
    "nepoliticosului": "nepoliticos",
    "nepolitizată": "nepolitizat",
    "nepolitizate": "nepolitizat",
    "nepolitizați": "nepolitizat",
    "nepoluată": "nepoluat",
    "nepoluate": "nepoluat",
    "nepoluați": "nepoluat",
    "nepomenita": "nepomenit",
    "nepomenită": "nepomenit",
    "nepomenite": "nepomenit",
    "nepomenitei": "nepomenit",
    "nepomenitele": "nepomenit",
    "nepomenitelor": "nepomenit",
    "nepomeniți": "nepomenit",
    "nepomeniții": "nepomenit",
    "nepomeniților": "nepomenit",
    "nepomenitul": "nepomenit",
    "nepomenitului": "nepomenit",
    "nepompată": "nepompat",
    "nepompate": "nepompat",
    "nepompați": "nepompat",
    "neponegrită": "neponegrit",
    "neponegrite": "neponegrit",
    "neponegriți": "neponegrit",
    "neponosită": "neponosit",
    "neponosite": "neponosit",
    "neponosiți": "neponosit",
    "nepontată": "nepontat",
    "nepontate": "nepontat",
    "nepontați": "nepontat",
    "nepopită": "nepopit",
    "nepopite": "nepopit",
    "nepopiți": "nepopit",
    "nepoposită": "nepoposit",
    "nepoposite": "nepoposit",
    "nepoposiți": "nepoposit",
    "nepopularizată": "nepopularizat",
    "nepopularizate": "nepopularizat",
    "nepopularizați": "nepopularizat",
    "nepopulata": "nepopulat",
    "nepopulată": "nepopulat",
    "nepopulate": "nepopulat",
    "nepopulatei": "nepopulat",
    "nepopulatele": "nepopulat",
    "nepopulatelor": "nepopulat",
    "nepopulați": "nepopulat",
    "nepopulații": "nepopulat",
    "nepopulaților": "nepopulat",
    "nepopulatul": "nepopulat",
    "nepopulatului": "nepopulat",
    "neporeclită": "neporeclit",
    "neporeclite": "neporeclit",
    "neporecliți": "neporeclit",
    "nepornită": "nepornit",
    "nepornite": "nepornit",
    "neporniți": "nepornit",
    "neportretizată": "neportretizat",
    "neportretizate": "neportretizat",
    "neportretizați": "neportretizat",
    "neporuncită": "neporuncit",
    "neporuncite": "neporuncit",
    "neporunciți": "neporuncit",
    "neposedată": "neposedat",
    "neposedate": "neposedat",
    "neposedați": "neposedat",
    "neposomorâtă": "neposomorât",
    "neposomorâte": "neposomorât",
    "neposomorâți": "neposomorât",
    "nepostată": "nepostat",
    "nepostate": "nepostat",
    "nepostați": "nepostat",
    "nepostită": "nepostit",
    "nepostite": "nepostit",
    "nepostiți": "nepostit",
    "nepostulată": "nepostulat",
    "nepostulate": "nepostulat",
    "nepostulați": "nepostulat",
    "nepoți": "nepot",
    "nepoții": "nepot",
    "nepoților": "nepot",
    "nepotul": "nepot",
    "nepotului": "nepot",
    "nepotcovită": "nepotcovit",
    "nepotcovite": "nepotcovit",
    "nepotcoviți": "nepotcovit",
    "nepoței": "nepoțel",
    "nepoțeii": "nepoțel",
    "nepoțeilor": "nepoțel",
    "nepoțelul": "nepoțel",
    "nepoțelului": "nepoțel",
    "nepoțele": "nepoțică",
    "nepoțelei": "nepoțică",
    "nepoțelele": "nepoțică",
    "nepoțelelor": "nepoțică",
    "nepoțica": "nepoțică",
    "nepoticnită": "nepoticnit",
    "nepoticnite": "nepoticnit",
    "nepoticniți": "nepoticnit",
    "nepotisme": "nepotism",
    "nepotismele": "nepotism",
    "nepotismelor": "nepotism",
    "nepotismul": "nepotism",
    "nepotismului": "nepotism",
    "nepotolita": "nepotolit",
    "nepotolită": "nepotolit",
    "nepotolite": "nepotolit",
    "nepotolitei": "nepotolit",
    "nepotolitele": "nepotolit",
    "nepotolitelor": "nepotolit",
    "nepotoliți": "nepotolit",
    "nepotoliții": "nepotolit",
    "nepotoliților": "nepotolit",
    "nepotolitul": "nepotolit",
    "nepotolitului": "nepotolit",
    "nepotopită": "nepotopit",
    "nepotopite": "nepotopit",
    "nepotopiți": "nepotopit",
    "nepotrivirea": "nepotrivire",
    "nepotriviri": "nepotrivire",
    "nepotrivirii": "nepotrivire",
    "nepotrivirile": "nepotrivire",
    "nepotrivirilor": "nepotrivire",
    "nepotrivita": "nepotrivit",
    "nepotrivită": "nepotrivit",
    "nepotrivite": "nepotrivit",
    "nepotrivitei": "nepotrivit",
    "nepotrivitele": "nepotrivit",
    "nepotrivitelor": "nepotrivit",
    "nepotriviți": "nepotrivit",
    "nepotriviții": "nepotrivit",
    "nepotriviților": "nepotrivit",
    "nepotrivitul": "nepotrivit",
    "nepotrivitului": "nepotrivit",
    "nepovârnită": "nepovârnit",
    "nepovârnite": "nepovârnit",
    "nepovârniți": "nepovârnit",
    "nepovățuită": "nepovățuit",
    "nepovățuite": "nepovățuit",
    "nepovățuiți": "nepovățuit",
    "nepovestita": "nepovestit",
    "nepovestită": "nepovestit",
    "nepovestite": "nepovestit",
    "nepovestitei": "nepovestit",
    "nepovestitele": "nepovestit",
    "nepovestitelor": "nepovestit",
    "nepovestiți": "nepovestit",
    "nepovestiții": "nepovestit",
    "nepovestiților": "nepovestit",
    "nepovestitul": "nepovestit",
    "nepovestitului": "nepovestit",
    "nepozată": "nepozat",
    "nepozate": "nepozat",
    "nepozați": "nepozat",
    "neprăbușită": "neprăbușit",
    "neprăbușite": "neprăbușit",
    "neprăbușiți": "neprăbușit",
    "nepracticată": "nepracticat",
    "nepracticate": "nepracticat",
    "nepracticați": "nepracticat",
    "neprădată": "neprădat",
    "neprădate": "neprădat",
    "neprădați": "neprădat",
    "neprăfuita": "neprăfuit",
    "neprăfuită": "neprăfuit",
    "neprăfuite": "neprăfuit",
    "neprăfuitei": "neprăfuit",
    "neprăfuitele": "neprăfuit",
    "neprăfuitelor": "neprăfuit",
    "neprăfuiți": "neprăfuit",
    "neprăfuiții": "neprăfuit",
    "neprăfuiților": "neprăfuit",
    "neprăfuitul": "neprăfuit",
    "neprăfuitului": "neprăfuit",
    "neprăjită": "neprăjit",
    "neprăjite": "neprăjit",
    "neprăjiți": "neprăjit",
    "neprânzită": "neprânzit",
    "neprânzite": "neprânzit",
    "neprânziți": "neprânzit",
    "neprăpădită": "neprăpădit",
    "neprăpădite": "neprăpădit",
    "neprăpădiți": "neprăpădit",
    "neprăsită": "neprăsit",
    "neprăsite": "neprăsit",
    "neprăsiți": "neprăsit",
    "neprășită": "neprășit",
    "neprășite": "neprășit",
    "neprășiți": "neprășit",
    "neprăvălită": "neprăvălit",
    "neprăvălite": "neprăvălit",
    "neprăvăliți": "neprăvălit",
    "neprăznuită": "neprăznuit",
    "neprăznuite": "neprăznuit",
    "neprăznuiți": "neprăznuit",
    "nepreamărită": "nepreamărit",
    "nepreamărite": "nepreamărit",
    "nepreamăriți": "nepreamărit",
    "neprecedată": "neprecedat",
    "neprecedate": "neprecedat",
    "neprecedați": "neprecedat",
    "neprecipitată": "neprecipitat",
    "neprecipitate": "neprecipitat",
    "neprecipitați": "neprecipitat",
    "neprecizată": "neprecizat",
    "neprecizate": "neprecizat",
    "neprecizați": "neprecizat",
    "nepreconizată": "nepreconizat",
    "nepreconizate": "nepreconizat",
    "nepreconizați": "nepreconizat",
    "neprecugetata": "neprecugetat",
    "neprecugetată": "neprecugetat",
    "neprecugetate": "neprecugetat",
    "neprecugetatei": "neprecugetat",
    "neprecugetatele": "neprecugetat",
    "neprecugetatelor": "neprecugetat",
    "neprecugetați": "neprecugetat",
    "neprecugetații": "neprecugetat",
    "neprecugetaților": "neprecugetat",
    "neprecugetatul": "neprecugetat",
    "neprecugetatului": "neprecugetat",
    "neprecumpănită": "neprecumpănit",
    "neprecumpănite": "neprecumpănit",
    "neprecumpăniți": "neprecumpănit",
    "neprecupețita": "neprecupețit",
    "neprecupețită": "neprecupețit",
    "neprecupețite": "neprecupețit",
    "neprecupețitei": "neprecupețit",
    "neprecupețitele": "neprecupețit",
    "neprecupețitelor": "neprecupețit",
    "neprecupețiți": "neprecupețit",
    "neprecupețiții": "neprecupețit",
    "neprecupețiților": "neprecupețit",
    "neprecupețitul": "neprecupețit",
    "neprecupețitului": "neprecupețit",
    "nepredată": "nepredat",
    "nepredate": "nepredat",
    "nepredați": "nepredat",
    "nepredicată": "nepredicat",
    "nepredicate": "nepredicat",
    "nepredicați": "nepredicat",
    "nepredicativa": "nepredicativ",
    "nepredicativă": "nepredicativ",
    "nepredicative": "nepredicativ",
    "nepredicativei": "nepredicativ",
    "nepredicativele": "nepredicativ",
    "nepredicativelor": "nepredicativ",
    "nepredicativi": "nepredicativ",
    "nepredicativii": "nepredicativ",
    "nepredicativilor": "nepredicativ",
    "nepredicativul": "nepredicativ",
    "nepredicativului": "nepredicativ",
    "nepredispusa": "nepredispus",
    "nepredispusă": "nepredispus",
    "nepredispuse": "nepredispus",
    "nepredispusei": "nepredispus",
    "nepredispusele": "nepredispus",
    "nepredispuselor": "nepredispus",
    "nepredispuși": "nepredispus",
    "nepredispusii": "nepredispus",
    "nepredispusilor": "nepredispus",
    "nepredispusul": "nepredispus",
    "nepredispusului": "nepredispus",
    "nepredominată": "nepredominat",
    "nepredominate": "nepredominat",
    "nepredominați": "nepredominat",
    "neprefabricată": "neprefabricat",
    "neprefabricate": "neprefabricat",
    "neprefabricați": "neprefabricat",
    "neprefăcută": "neprefăcut",
    "neprefăcute": "neprefăcut",
    "neprefăcuți": "neprefăcut",
    "neprefațată": "neprefațat",
    "neprefațate": "neprefațat",
    "neprefațați": "neprefațat",
    "nepreferată": "nepreferat",
    "nepreferate": "nepreferat",
    "nepreferați": "nepreferat",
    "neprefigurată": "neprefigurat",
    "neprefigurate": "neprefigurat",
    "neprefigurați": "neprefigurat",
    "neprefirată": "neprefirat",
    "neprefirate": "neprefirat",
    "neprefirați": "neprefirat",
    "neprefixată": "neprefixat",
    "neprefixate": "neprefixat",
    "neprefixați": "neprefixat",
    "nepregătirea": "nepregătire",
    "nepregătiri": "nepregătire",
    "nepregătirii": "nepregătire",
    "nepregătirile": "nepregătire",
    "nepregătirilor": "nepregătire",
    "nepregătita": "nepregătit",
    "nepregătită": "nepregătit",
    "nepregătite": "nepregătit",
    "nepregătitei": "nepregătit",
    "nepregătitele": "nepregătit",
    "nepregătitelor": "nepregătit",
    "nepregătiți": "nepregătit",
    "nepregătiții": "nepregătit",
    "nepregătiților": "nepregătit",
    "nepregătitul": "nepregătit",
    "nepregătitului": "nepregătit",
    "nepregetata": "nepregetat",
    "nepregetată": "nepregetat",
    "nepregetate": "nepregetat",
    "nepregetatei": "nepregetat",
    "nepregetatele": "nepregetat",
    "nepregetatelor": "nepregetat",
    "nepregetați": "nepregetat",
    "nepregetații": "nepregetat",
    "nepregetaților": "nepregetat",
    "nepregetatul": "nepregetat",
    "nepregetatului": "nepregetat",
    "neprejudiciată": "neprejudiciat",
    "neprejudiciate": "neprejudiciat",
    "neprejudiciați": "neprejudiciat",
    "neprelevată": "neprelevat",
    "neprelevate": "neprelevat",
    "neprelevați": "neprelevat",
    "neprelinsă": "neprelins",
    "neprelinse": "neprelins",
    "neprelinși": "neprelins",
    "nepreluată": "nepreluat",
    "nepreluate": "nepreluat",
    "nepreluați": "nepreluat",
    "neprelucrată": "neprelucrat",
    "neprelucrate": "neprelucrat",
    "neprelucrați": "neprelucrat",
    "neprelungită": "neprelungit",
    "neprelungite": "neprelungit",
    "neprelungiți": "neprelungit",
    "nepremeditată": "nepremeditat",
    "nepremeditate": "nepremeditat",
    "nepremeditați": "nepremeditat",
    "nepremiată": "nepremiat",
    "nepremiate": "nepremiat",
    "nepremiați": "nepremiat",
    "nepreocupată": "nepreocupat",
    "nepreocupate": "nepreocupat",
    "nepreocupați": "nepreocupat",
    "nepreparată": "nepreparat",
    "nepreparate": "nepreparat",
    "nepreparați": "nepreparat",
    "nepresărată": "nepresărat",
    "nepresărate": "nepresărat",
    "nepresărați": "nepresărat",
    "nepresată": "nepresat",
    "nepresate": "nepresat",
    "nepresați": "nepresat",
    "nepreschimbată": "nepreschimbat",
    "nepreschimbate": "nepreschimbat",
    "nepreschimbați": "nepreschimbat",
    "neprescrisă": "neprescris",
    "neprescrise": "neprescris",
    "neprescriși": "neprescris",
    "neprescurtată": "neprescurtat",
    "neprescurtate": "neprescurtat",
    "neprescurtați": "neprescurtat",
    "nepresimțită": "nepresimțit",
    "nepresimțite": "nepresimțit",
    "nepresimțiți": "nepresimțit",
    "neprestată": "neprestat",
    "neprestate": "neprestat",
    "neprestați": "neprestat",
    "nepresupusă": "nepresupus",
    "nepresupuse": "nepresupus",
    "nepresupuși": "nepresupus",
    "nepresurizată": "nepresurizat",
    "nepresurizate": "nepresurizat",
    "nepresurizați": "nepresurizat",
    "nepretată": "nepretat",
    "nepretate": "nepretat",
    "nepretați": "nepretat",
    "nepretențioasa": "nepretențios",
    "nepretențioasă": "nepretențios",
    "nepretențioase": "nepretențios",
    "nepretențioasei": "nepretențios",
    "nepretențioasele": "nepretențios",
    "nepretențioaselor": "nepretențios",
    "nepretențioși": "nepretențios",
    "nepretențioșii": "nepretențios",
    "nepretențioșilor": "nepretențios",
    "nepretențiosul": "nepretențios",
    "nepretențiosului": "nepretențios",
    "nepretextată": "nepretextat",
    "nepretextate": "nepretextat",
    "nepretextați": "nepretextat",
    "nepretinsă": "nepretins",
    "nepretinse": "nepretins",
    "nepretinși": "nepretins",
    "neprețuita": "neprețuit",
    "neprețuită": "neprețuit",
    "neprețuite": "neprețuit",
    "neprețuitei": "neprețuit",
    "neprețuitele": "neprețuit",
    "neprețuitelor": "neprețuit",
    "neprețuiți": "neprețuit",
    "neprețuiții": "neprețuit",
    "neprețuiților": "neprețuit",
    "neprețuitul": "neprețuit",
    "neprețuitului": "neprețuit",
    "neprevalată": "neprevalat",
    "neprevalate": "neprevalat",
    "neprevalați": "neprevalat",
    "neprevăzătoare": "neprevăzător",
    "neprevăzătoarea": "neprevăzător",
    "neprevăzătoarei": "neprevăzător",
    "neprevăzătoarele": "neprevăzător",
    "neprevăzătoarelor": "neprevăzător",
    "neprevăzători": "neprevăzător",
    "neprevăzătorii": "neprevăzător",
    "neprevăzătorilor": "neprevăzător",
    "neprevăzătorul": "neprevăzător",
    "neprevăzătorului": "neprevăzător",
    "neprevăzuta": "neprevăzut",
    "neprevăzută": "neprevăzut",
    "neprevăzute": "neprevăzut",
    "neprevăzutei": "neprevăzut",
    "neprevăzutele": "neprevăzut",
    "neprevăzutelor": "neprevăzut",
    "neprevăzuți": "neprevăzut",
    "neprevăzuții": "neprevăzut",
    "neprevăzuților": "neprevăzut",
    "neprevăzutul": "neprevăzut",
    "neprevăzutului": "neprevăzut",
    "neprevenită": "neprevenit",
    "neprevenite": "neprevenit",
    "nepreveniți": "neprevenit",
    "neprevestită": "neprevestit",
    "neprevestite": "neprevestit",
    "neprevestiți": "neprevestit",
    "neprezentarea": "neprezentare",
    "neprezentari": "neprezentare",
    "neprezentarii": "neprezentare",
    "neprezentarile": "neprezentare",
    "neprezentarilor": "neprezentare",
    "neprezentată": "neprezentat",
    "neprezentate": "neprezentat",
    "neprezentați": "neprezentat",
    "neprezervată": "neprezervat",
    "neprezervate": "neprezervat",
    "neprezervați": "neprezervat",
    "neprezidată": "neprezidat",
    "neprezidate": "neprezidat",
    "neprezidați": "neprezidat",
    "neprezisă": "neprezis",
    "neprezise": "neprezis",
    "nepreziși": "neprezis",
    "nepribegită": "nepribegit",
    "nepribegite": "nepribegit",
    "nepribegiți": "nepribegit",
    "nepriceperea": "nepricepere",
    "nepriceperi": "nepricepere",
    "nepriceperii": "nepricepere",
    "nepriceperile": "nepricepere",
    "nepriceperilor": "nepricepere",
    "nepriceputa": "nepriceput",
    "nepricepută": "nepriceput",
    "nepricepute": "nepriceput",
    "nepriceputei": "nepriceput",
    "nepriceputele": "nepriceput",
    "nepriceputelor": "nepriceput",
    "nepricepuți": "nepriceput",
    "nepricepuții": "nepriceput",
    "nepricepuților": "nepriceput",
    "nepriceputul": "nepriceput",
    "nepriceputului": "nepriceput",
    "nepriceputa": "nepricepută",
    "nepricepute": "nepricepută",
    "nepriceputei": "nepricepută",
    "nepriceputele": "nepricepută",
    "nepriceputelor": "nepricepută",
    "nepricinuită": "nepricinuit",
    "nepricinuite": "nepricinuit",
    "nepricinuiți": "nepricinuit",
    "nepricopsita": "nepricopsit",
    "nepricopsită": "nepricopsit",
    "nepricopsite": "nepricopsit",
    "nepricopsitei": "nepricopsit",
    "nepricopsitele": "nepricopsit",
    "nepricopsitelor": "nepricopsit",
    "nepricopsiți": "nepricopsit",
    "nepricopsiții": "nepricopsit",
    "nepricopsiților": "nepricopsit",
    "nepricopsitul": "nepricopsit",
    "nepricopsitului": "nepricopsit",
    "neprididită": "neprididit",
    "neprididite": "neprididit",
    "neprididiți": "neprididit",
    "neprielnica": "neprielnic",
    "neprielnică": "neprielnic",
    "neprielnice": "neprielnic",
    "neprielnicei": "neprielnic",
    "neprielnicele": "neprielnic",
    "neprielnicelor": "neprielnic",
    "neprielnici": "neprielnic",
    "neprielnicii": "neprielnic",
    "neprielnicilor": "neprielnic",
    "neprielnicul": "neprielnic",
    "neprielnicului": "neprielnic",
    "neprieteneasca": "neprietenesc",
    "neprietenească": "neprietenesc",
    "neprietenescul": "neprietenesc",
    "neprietenescului": "neprietenesc",
    "neprietenești": "neprietenesc",
    "neprieteneștii": "neprietenesc",
    "neprieteneștile": "neprietenesc",
    "neprieteneștilor": "neprietenesc",
    "neprietenoasa": "neprietenos",
    "neprietenoasă": "neprietenos",
    "neprietenoase": "neprietenos",
    "neprietenoasei": "neprietenos",
    "neprietenoasele": "neprietenos",
    "neprietenoaselor": "neprietenos",
    "neprietenoși": "neprietenos",
    "neprietenoșii": "neprietenos",
    "neprietenoșilor": "neprietenos",
    "neprietenosul": "neprietenos",
    "neprietenosului": "neprietenos",
    "neprigonită": "neprigonit",
    "neprigonite": "neprigonit",
    "neprigoniți": "neprigonit",
    "neprihănita": "neprihănit",
    "neprihănită": "neprihănit",
    "neprihănite": "neprihănit",
    "neprihănitei": "neprihănit",
    "neprihănitele": "neprihănit",
    "neprihănitelor": "neprihănit",
    "neprihăniți": "neprihănit",
    "neprihăniții": "neprihănit",
    "neprihăniților": "neprihănit",
    "neprihănitul": "neprihănit",
    "neprihănitului": "neprihănit",
    "nepriincioasa": "nepriincios",
    "nepriincioasă": "nepriincios",
    "nepriincioase": "nepriincios",
    "nepriincioasei": "nepriincios",
    "nepriincioasele": "nepriincios",
    "nepriincioaselor": "nepriincios",
    "nepriincioși": "nepriincios",
    "nepriincioșii": "nepriincios",
    "nepriincioșilor": "nepriincios",
    "nepriinciosul": "nepriincios",
    "nepriinciosului": "nepriincios",
    "neprilejuită": "neprilejuit",
    "neprilejuite": "neprilejuit",
    "neprilejuiți": "neprilejuit",
    "neprimata": "neprimat",
    "neprimată": "neprimat",
    "neprimate": "neprimat",
    "neprimatei": "neprimat",
    "neprimatele": "neprimat",
    "neprimatelor": "neprimat",
    "neprimați": "neprimat",
    "neprimații": "neprimat",
    "neprimaților": "neprimat",
    "neprimatul": "neprimat",
    "neprimatului": "neprimat",
    "neprimejdioasa": "neprimejdios",
    "neprimejdioasă": "neprimejdios",
    "neprimejdioase": "neprimejdios",
    "neprimejdioasei": "neprimejdios",
    "neprimejdioasele": "neprimejdios",
    "neprimejdioaselor": "neprimejdios",
    "neprimejdioși": "neprimejdios",
    "neprimejdioșii": "neprimejdios",
    "neprimejdioșilor": "neprimejdios",
    "neprimejdiosul": "neprimejdios",
    "neprimejdiosului": "neprimejdios",
    "neprimejduită": "neprimejduit",
    "neprimejduite": "neprimejduit",
    "neprimejduiți": "neprimejduit",
    "neprimenită": "neprimenit",
    "neprimenite": "neprimenit",
    "neprimeniți": "neprimenit",
    "neprimită": "neprimit",
    "neprimite": "neprimit",
    "neprimiți": "neprimit",
    "neprimitoare": "neprimitor",
    "neprimitoarea": "neprimitor",
    "neprimitoarei": "neprimitor",
    "neprimitoarele": "neprimitor",
    "neprimitoarelor": "neprimitor",
    "neprimitori": "neprimitor",
    "neprimitorii": "neprimitor",
    "neprimitorilor": "neprimitor",
    "neprimitorul": "neprimitor",
    "neprimitorului": "neprimitor",
    "neprincipiala": "neprincipial",
    "neprincipială": "neprincipial",
    "neprincipiale": "neprincipial",
    "neprincipialei": "neprincipial",
    "neprincipialele": "neprincipial",
    "neprincipialelor": "neprincipial",
    "neprincipiali": "neprincipial",
    "neprincipialii": "neprincipial",
    "neprincipialilor": "neprincipial",
    "neprincipialul": "neprincipial",
    "neprincipialului": "neprincipial",
    "neprinsa": "neprins",
    "neprinsă": "neprins",
    "neprinse": "neprins",
    "neprinsei": "neprins",
    "neprinsele": "neprins",
    "neprinselor": "neprins",
    "neprinși": "neprins",
    "neprinșii": "neprins",
    "neprinșilor": "neprins",
    "neprinsul": "neprins",
    "neprinsului": "neprins",
    "nepripășită": "nepripășit",
    "nepripășite": "nepripășit",
    "nepripășiți": "nepripășit",
    "nepripită": "nepripit",
    "nepripite": "nepripit",
    "nepripiți": "nepripit",
    "nepriponită": "nepriponit",
    "nepriponite": "nepriponit",
    "nepriponiți": "nepriponit",
    "neprisosită": "neprisosit",
    "neprisosite": "neprisosit",
    "neprisosiți": "neprisosit",
    "nepritocită": "nepritocit",
    "nepritocite": "nepritocit",
    "nepritociți": "nepritocit",
    "neprivata": "neprivat",
    "neprivată": "neprivat",
    "neprivate": "neprivat",
    "neprivatei": "neprivat",
    "neprivatele": "neprivat",
    "neprivatelor": "neprivat",
    "neprivați": "neprivat",
    "neprivații": "neprivat",
    "neprivaților": "neprivat",
    "neprivatul": "neprivat",
    "neprivatului": "neprivat",
    "neprivilegiata": "neprivilegiat",
    "neprivilegiată": "neprivilegiat",
    "neprivilegiate": "neprivilegiat",
    "neprivilegiatei": "neprivilegiat",
    "neprivilegiatele": "neprivilegiat",
    "neprivilegiatelor": "neprivilegiat",
    "neprivilegiați": "neprivilegiat",
    "neprivilegiații": "neprivilegiat",
    "neprivilegiaților": "neprivilegiat",
    "neprivilegiatul": "neprivilegiat",
    "neprivilegiatului": "neprivilegiat",
    "neprivită": "neprivit",
    "neprivite": "neprivit",
    "nepriviți": "neprivit",
    "neprizata": "neprizat",
    "neprizată": "neprizat",
    "neprizate": "neprizat",
    "neprizatei": "neprizat",
    "neprizatele": "neprizat",
    "neprizatelor": "neprizat",
    "neprizați": "neprizat",
    "neprizații": "neprizat",
    "neprizaților": "neprizat",
    "neprizatul": "neprizat",
    "neprizatului": "neprizat",
    "neprobată": "neprobat",
    "neprobate": "neprobat",
    "neprobați": "neprobat",
    "neprocedată": "neprocedat",
    "neprocedate": "neprocedat",
    "neprocedați": "neprocedat",
    "neproclamată": "neproclamat",
    "neproclamate": "neproclamat",
    "neproclamați": "neproclamat",
    "neprocreată": "neprocreat",
    "neprocreate": "neprocreat",
    "neprocreați": "neprocreat",
    "neprocurata": "neprocurat",
    "neprocurată": "neprocurat",
    "neprocurate": "neprocurat",
    "neprocuratei": "neprocurat",
    "neprocuratele": "neprocurat",
    "neprocuratelor": "neprocurat",
    "neprocurați": "neprocurat",
    "neprocurații": "neprocurat",
    "neprocuraților": "neprocurat",
    "neprocuratul": "neprocurat",
    "neprocuratului": "neprocurat",
    "neproductiva": "neproductiv",
    "neproductivă": "neproductiv",
    "neproductive": "neproductiv",
    "neproductivei": "neproductiv",
    "neproductivele": "neproductiv",
    "neproductivelor": "neproductiv",
    "neproductivi": "neproductiv",
    "neproductivii": "neproductiv",
    "neproductivilor": "neproductiv",
    "neproductivul": "neproductiv",
    "neproductivului": "neproductiv",
    "neprofanată": "neprofanat",
    "neprofanate": "neprofanat",
    "neprofanați": "neprofanat",
    "neproferată": "neproferat",
    "neproferate": "neproferat",
    "neproferați": "neproferat",
    "neprofesată": "neprofesat",
    "neprofesate": "neprofesat",
    "neprofesați": "neprofesat",
    "neprofețită": "neprofețit",
    "neprofețite": "neprofețit",
    "neprofețiți": "neprofețit",
    "neprofetizată": "neprofetizat",
    "neprofetizate": "neprofetizat",
    "neprofetizați": "neprofetizat",
    "neprofilată": "neprofilat",
    "neprofilate": "neprofilat",
    "neprofilați": "neprofilat",
    "neprofitabilă": "neprofitabil",
    "neprofitabile": "neprofitabil",
    "neprofitabili": "neprofitabil",
    "neprofitată": "neprofitat",
    "neprofitate": "neprofitat",
    "neprofitați": "neprofitat",
    "neprogramată": "neprogramat",
    "neprogramate": "neprogramat",
    "neprogramați": "neprogramat",
    "neprogresată": "neprogresat",
    "neprogresate": "neprogresat",
    "neprogresați": "neprogresat",
    "neprohibită": "neprohibit",
    "neprohibite": "neprohibit",
    "neprohibiți": "neprohibit",
    "neprohodită": "neprohodit",
    "neprohodite": "neprohodit",
    "neprohodiți": "neprohodit",
    "neproiectată": "neproiectat",
    "neproiectate": "neproiectat",
    "neproiectați": "neproiectat",
    "neproletarizată": "neproletarizat",
    "neproletarizate": "neproletarizat",
    "neproletarizați": "neproletarizat",
    "neproliferată": "neproliferat",
    "neproliferate": "neproliferat",
    "neproliferați": "neproliferat",
    "nepromisă": "nepromis",
    "nepromise": "nepromis",
    "nepromiși": "nepromis",
    "nepromovată": "nepromovat",
    "nepromovate": "nepromovat",
    "nepromovați": "nepromovat",
    "nepromulgată": "nepromulgat",
    "nepromulgate": "nepromulgat",
    "nepromulgați": "nepromulgat",
    "nepronosticată": "nepronosticat",
    "nepronosticate": "nepronosticat",
    "nepronosticați": "nepronosticat",
    "nepronunțată": "nepronunțat",
    "nepronunțate": "nepronunțat",
    "nepronunțați": "nepronunțat",
    "nepropagată": "nepropagat",
    "nepropagate": "nepropagat",
    "nepropagați": "nepropagat",
    "nepropășită": "nepropășit",
    "nepropășite": "nepropășit",
    "nepropășiți": "nepropășit",
    "neproporționată": "neproporționat",
    "neproporționate": "neproporționat",
    "neproporționați": "neproporționat",
    "nepropovăduită": "nepropovăduit",
    "nepropovăduite": "nepropovăduit",
    "nepropovăduiți": "nepropovăduit",
    "neproptită": "neproptit",
    "neproptite": "neproptit",
    "neproptiți": "neproptit",
    "nepropulsată": "nepropulsat",
    "nepropulsate": "nepropulsat",
    "nepropulsați": "nepropulsat",
    "nepropusă": "nepropus",
    "nepropuse": "nepropus",
    "nepropuși": "nepropus",
    "neprorocită": "neprorocit",
    "neprorocite": "neprorocit",
    "neprorociți": "neprorocit",
    "neproscrisa": "neproscris",
    "neproscrisă": "neproscris",
    "neproscrise": "neproscris",
    "neproscrisei": "neproscris",
    "neproscrisele": "neproscris",
    "neproscriselor": "neproscris",
    "neproscriși": "neproscris",
    "neproscrisii": "neproscris",
    "neproscrisilor": "neproscris",
    "neproscrisul": "neproscris",
    "neproscrisului": "neproscris",
    "neproslăvită": "neproslăvit",
    "neproslăvite": "neproslăvit",
    "neproslăviți": "neproslăvit",
    "neprospectată": "neprospectat",
    "neprospectate": "neprospectat",
    "neprospectați": "neprospectat",
    "neprosperată": "neprosperat",
    "neprosperate": "neprosperat",
    "neprosperați": "neprosperat",
    "neprosternată": "neprosternat",
    "neprosternate": "neprosternat",
    "neprosternați": "neprosternat",
    "neprostită": "neprostit",
    "neprostite": "neprostit",
    "neprostiți": "neprostit",
    "neprostituată": "neprostituat",
    "neprostituate": "neprostituat",
    "neprostituați": "neprostituat",
    "neproțăpită": "neproțăpit",
    "neproțăpite": "neproțăpit",
    "neproțăpiți": "neproțăpit",
    "neprotejată": "neprotejat",
    "neprotejate": "neprotejat",
    "neprotejați": "neprotejat",
    "neprotestată": "neprotestat",
    "neprotestate": "neprotestat",
    "neprotestați": "neprotestat",
    "neprovenită": "neprovenit",
    "neprovenite": "neprovenit",
    "neproveniți": "neprovenit",
    "neprovocată": "neprovocat",
    "neprovocate": "neprovocat",
    "neprovocați": "neprovocat",
    "neprunduită": "neprunduit",
    "neprunduite": "neprunduit",
    "neprunduiți": "neprunduit",
    "nepsalmodiată": "nepsalmodiat",
    "nepsalmodiate": "nepsalmodiat",
    "nepsalmodiați": "nepsalmodiat",
    "neptuniul": "neptuniu",
    "neptuniului": "neptuniu",
    "Np": "neptuniu",
    "nepublicată": "nepublicat",
    "nepublicate": "nepublicat",
    "nepublicați": "nepublicat",
    "nepudrată": "nepudrat",
    "nepudrate": "nepudrat",
    "nepudrați": "nepudrat",
    "nepufăită": "nepufăit",
    "nepufăite": "nepufăit",
    "nepufăiți": "nepufăit",
    "nepufnită": "nepufnit",
    "nepufnite": "nepufnit",
    "nepufniți": "nepufnit",
    "nepuhăvită": "nepuhăvit",
    "nepuhăvite": "nepuhăvit",
    "nepuhăviți": "nepuhăvit",
    "nepulsată": "nepulsat",
    "nepulsate": "nepulsat",
    "nepulsați": "nepulsat",
    "nepulverizată": "nepulverizat",
    "nepulverizate": "nepulverizat",
    "nepulverizați": "nepulverizat",
    "nepunctată": "nepunctat",
    "nepunctate": "nepunctat",
    "nepunctați": "nepunctat",
    "nepungălită": "nepungălit",
    "nepungălite": "nepungălit",
    "nepungăliți": "nepungălit",
    "nepungășită": "nepungășit",
    "nepungășite": "nepungășit",
    "nepungășiți": "nepungășit",
    "nepupată": "nepupat",
    "nepupate": "nepupat",
    "nepupați": "nepupat",
    "nepurificată": "nepurificat",
    "nepurificate": "nepurificat",
    "nepurificați": "nepurificat",
    "nepuroiată": "nepuroiat",
    "nepuroiate": "nepuroiat",
    "nepuroiați": "nepuroiat",
    "nepurtată": "nepurtat",
    "nepurtate": "nepurtat",
    "nepurtați": "nepurtat",
    "nepusa": "nepus",
    "nepusă": "nepus",
    "nepuse": "nepus",
    "nepusei": "nepus",
    "nepusele": "nepus",
    "nepuselor": "nepus",
    "nepusi": "nepus",
    "nepuși": "nepus",
    "nepusii": "nepus",
    "nepusilor": "nepus",
    "nepusul": "nepus",
    "nepusului": "nepus",
    "nepustiită": "nepustiit",
    "nepustiite": "nepustiit",
    "nepustiiți": "nepustiit",
    "neputincioasa": "neputincios",
    "neputincioasă": "neputincios",
    "neputincioase": "neputincios",
    "neputincioasei": "neputincios",
    "neputincioasele": "neputincios",
    "neputincioaselor": "neputincios",
    "neputincioși": "neputincios",
    "neputincioșii": "neputincios",
    "neputincioșilor": "neputincios",
    "neputinciosul": "neputincios",
    "neputinciosului": "neputincios",
    "neputința": "neputință",
    "neputințe": "neputință",
    "neputinței": "neputință",
    "neputințele": "neputință",
    "neputințelor": "neputință",
    "nepuțită": "nepuțit",
    "nepuțite": "nepuțit",
    "nepuțiți": "nepuțit",
    "neputrezită": "neputrezit",
    "neputrezite": "neputrezit",
    "neputreziți": "neputrezit",
    "neputută": "neputut",
    "neputute": "neputut",
    "neputuți": "neputut",
    "nerăbdarea": "nerăbdare",
    "nerăbdări": "nerăbdare",
    "nerăbdării": "nerăbdare",
    "nerăbdările": "nerăbdare",
    "nerăbdărilor": "nerăbdare",
    "nerăbdată": "nerăbdat",
    "nerăbdate": "nerăbdat",
    "nerăbdați": "nerăbdat",
    "nerăbdătoare": "nerăbdător",
    "nerăbdătoarea": "nerăbdător",
    "nerăbdătoarei": "nerăbdător",
    "nerăbdătoarele": "nerăbdător",
    "nerăbdătoarelor": "nerăbdător",
    "nerăbdători": "nerăbdător",
    "nerăbdătorii": "nerăbdător",
    "nerăbdătorilor": "nerăbdător",
    "nerăbdătorul": "nerăbdător",
    "nerăbdătorului": "nerăbdător",
    "nerablagita": "nerablagit",
    "nerablagită": "nerablagit",
    "nerablagite": "nerablagit",
    "nerablagitei": "nerablagit",
    "nerablagitele": "nerablagit",
    "nerablagitelor": "nerablagit",
    "nerablagiți": "nerablagit",
    "nerablagiții": "nerablagit",
    "nerablagiților": "nerablagit",
    "nerablagitul": "nerablagit",
    "nerablagitului": "nerablagit",
    "nerabotată": "nerabotat",
    "nerabotate": "nerabotat",
    "nerabotați": "nerabotat",
    "nerăbufnită": "nerăbufnit",
    "nerăbufnite": "nerăbufnit",
    "nerăbufniți": "nerăbufnit",
    "nerâcâită": "nerâcâit",
    "nerâcâite": "nerâcâit",
    "nerâcâiți": "nerâcâit",
    "nerăcita": "nerăcit",
    "nerăcită": "nerăcit",
    "nerăcite": "nerăcit",
    "nerăcitei": "nerăcit",
    "nerăcitele": "nerăcit",
    "nerăcitelor": "nerăcit",
    "nerăciți": "nerăcit",
    "nerăciții": "nerăcit",
    "nerăciților": "nerăcit",
    "nerăcitul": "nerăcit",
    "nerăcitului": "nerăcit",
    "nerăcnită": "nerăcnit",
    "nerăcnite": "nerăcnit",
    "nerăcniți": "nerăcnit",
    "neracordată": "neracordat",
    "neracordate": "neracordat",
    "neracordați": "neracordat",
    "nerăcorită": "nerăcorit",
    "nerăcorite": "nerăcorit",
    "nerăcoriți": "nerăcorit",
    "neradiată": "neradiat",
    "neradiate": "neradiat",
    "neradiați": "neradiat",
    "nerafinata": "nerafinat",
    "nerafinată": "nerafinat",
    "nerafinate": "nerafinat",
    "nerafinatei": "nerafinat",
    "nerafinatele": "nerafinat",
    "nerafinatelor": "nerafinat",
    "nerafinați": "nerafinat",
    "nerafinații": "nerafinat",
    "nerafinaților": "nerafinat",
    "nerafinatul": "nerafinat",
    "nerafinatului": "nerafinat",
    "nerăfuită": "nerăfuit",
    "nerăfuite": "nerăfuit",
    "nerăfuiți": "nerăfuit",
    "nerâgâită": "nerâgâit",
    "nerâgâite": "nerâgâit",
    "nerâgâiți": "nerâgâit",
    "nerăgușita": "nerăgușit",
    "nerăgușită": "nerăgușit",
    "nerăgușite": "nerăgușit",
    "nerăgușitei": "nerăgușit",
    "nerăgușitele": "nerăgușit",
    "nerăgușitelor": "nerăgușit",
    "nerăgușiți": "nerăgușit",
    "nerăgușiții": "nerăgușit",
    "nerăgușiților": "nerăgușit",
    "nerăgușitul": "nerăgușit",
    "nerăgușitului": "nerăgușit",
    "nerăgută": "nerăgut",
    "nerăgute": "nerăgut",
    "nerăguți": "nerăgut",
    "neraliată": "neraliat",
    "neraliate": "neraliat",
    "neraliați": "neraliat",
    "nerâmată": "nerâmat",
    "nerâmate": "nerâmat",
    "nerâmați": "nerâmat",
    "nerambleiată": "nerambleiat",
    "nerambleiate": "nerambleiat",
    "nerambleiați": "nerambleiat",
    "nerambursată": "nerambursat",
    "nerambursate": "nerambursat",
    "nerambursați": "nerambursat",
    "neramificată": "neramificat",
    "neramificate": "neramificat",
    "neramificați": "neramificat",
    "neramolita": "neramolit",
    "neramolită": "neramolit",
    "neramolite": "neramolit",
    "neramolitei": "neramolit",
    "neramolitele": "neramolit",
    "neramolitelor": "neramolit",
    "neramoliți": "neramolit",
    "neramoliții": "neramolit",
    "neramoliților": "neramolit",
    "neramolitul": "neramolit",
    "neramolitului": "neramolit",
    "nerâncezită": "nerâncezit",
    "nerâncezite": "nerâncezit",
    "nerânceziți": "nerâncezit",
    "nerânduită": "nerânduit",
    "nerânduite": "nerânduit",
    "nerânduiți": "nerânduit",
    "nerânită": "nerânit",
    "nerânite": "nerânit",
    "nerâniți": "nerânit",
    "nerănită": "nerănit",
    "nerănite": "nerănit",
    "nerăniți": "nerănit",
    "nerânjită": "nerânjit",
    "nerânjite": "nerânjit",
    "nerânjiți": "nerânjit",
    "nerăpită": "nerăpit",
    "nerăpite": "nerăpit",
    "nerăpiți": "nerăpit",
    "neraportată": "neraportat",
    "neraportate": "neraportat",
    "neraportați": "neraportat",
    "nerăposata": "nerăposat",
    "nerăposată": "nerăposat",
    "nerăposate": "nerăposat",
    "nerăposatei": "nerăposat",
    "nerăposatele": "nerăposat",
    "nerăposatelor": "nerăposat",
    "nerăposați": "nerăposat",
    "nerăposații": "nerăposat",
    "nerăposaților": "nerăposat",
    "nerăposatul": "nerăposat",
    "nerăposatului": "nerăposat",
    "nerăpusa": "nerăpus",
    "nerăpusă": "nerăpus",
    "nerăpuse": "nerăpus",
    "nerăpusei": "nerăpus",
    "nerăpusele": "nerăpus",
    "nerăpuselor": "nerăpus",
    "nerăpuși": "nerăpus",
    "nerăpușii": "nerăpus",
    "nerăpușilor": "nerăpus",
    "nerăpusul": "nerăpus",
    "nerăpusului": "nerăpus",
    "nerarefiata": "nerarefiat",
    "nerarefiată": "nerarefiat",
    "nerarefiate": "nerarefiat",
    "nerarefiatei": "nerarefiat",
    "nerarefiatele": "nerarefiat",
    "nerarefiatelor": "nerarefiat",
    "nerarefiați": "nerarefiat",
    "nerarefiații": "nerarefiat",
    "nerarefiaților": "nerarefiat",
    "nerarefiatul": "nerarefiat",
    "nerarefiatului": "nerarefiat",
    "nerărită": "nerărit",
    "nerărite": "nerărit",
    "nerăriți": "nerărit",
    "nerărițată": "nerărițat",
    "nerărițate": "nerărițat",
    "nerărițați": "nerărițat",
    "nerase": "neras",
    "nerasi": "neras",
    "nerași": "neras",
    "nerasii": "neras",
    "nerașii": "neras",
    "nerasilor": "neras",
    "nerașilor": "neras",
    "nerasul": "neras",
    "nerasului": "neras",
    "nerâsă": "nerâs",
    "nerâse": "nerâs",
    "nerâși": "nerâs",
    "nerăsădită": "nerăsădit",
    "nerăsădite": "nerăsădit",
    "nerăsădiți": "nerăsădit",
    "nerăsărita": "nerăsărit",
    "nerăsărită": "nerăsărit",
    "nerăsărite": "nerăsărit",
    "nerăsăritei": "nerăsărit",
    "nerăsăritele": "nerăsărit",
    "nerăsăritelor": "nerăsărit",
    "nerăsăriți": "nerăsărit",
    "nerăsăriții": "nerăsărit",
    "nerăsăriților": "nerăsărit",
    "nerăsăritul": "nerăsărit",
    "nerăsăritului": "nerăsărit",
    "nerăscoaptă": "nerăsărit",
    "nerăscoapte": "nerăsărit",
    "nerașchetata": "nerașchetat",
    "nerașchetată": "nerașchetat",
    "nerașchetate": "nerașchetat",
    "nerașchetatele": "nerașchetat",
    "nerașchetatelor": "nerașchetat",
    "nerașchetați": "nerașchetat",
    "nerașchetații": "nerașchetat",
    "nerașchetaților": "nerașchetat",
    "nerașchetatul": "nerașchetat",
    "nerașchetatului": "nerașchetat",
    "nerășchiata": "nerășchiat",
    "nerășchiată": "nerășchiat",
    "nerășchiate": "nerășchiat",
    "nerășchiatei": "nerășchiat",
    "nerășchiatele": "nerășchiat",
    "nerășchiatelor": "nerășchiat",
    "nerășchiați": "nerășchiat",
    "nerășchiații": "nerășchiat",
    "nerășchiaților": "nerășchiat",
    "nerășchiatul": "nerășchiat",
    "nerășchiatului": "nerășchiat",
    "nerăscolită": "nerăscolit",
    "nerăscolite": "nerăscolit",
    "nerăscoliți": "nerăscolit",
    "nerăscoapta": "nerăscopt",
    "nerăscoaptei": "nerăscopt",
    "nerăscoaptele": "nerăscopt",
    "nerăscoaptelor": "nerăscopt",
    "nerăscopți": "nerăscopt",
    "nerăscopții": "nerăscopt",
    "nerăscopților": "nerăscopt",
    "nerăscoptul": "nerăscopt",
    "nerăscoptului": "nerăscopt",
    "nerăscroita": "nerăscroit",
    "nerăscroită": "nerăscroit",
    "nerăscroite": "nerăscroit",
    "nerăscroitei": "nerăscroit",
    "nerăscroitele": "nerăscroit",
    "nerăscroitelor": "nerăscroit",
    "nerăscroiți": "nerăscroit",
    "nerăscroiții": "nerăscroit",
    "nerăscroiților": "nerăscroit",
    "nerăscroitul": "nerăscroit",
    "nerăscroitului": "nerăscroit",
    "nerăsculată": "nerăsculat",
    "nerăsculate": "nerăsculat",
    "nerăsculați": "nerăsculat",
    "nerăscumpărată": "nerăscumpărat",
    "nerăscumpărate": "nerăscumpărat",
    "nerăscumpărați": "nerăscumpărat",
    "nerăsfățată": "nerăsfățat",
    "nerăsfățate": "nerăsfățat",
    "nerăsfățați": "nerăsfățat",
    "nerăsfirata": "nerăsfirat",
    "nerăsfirată": "nerăsfirat",
    "nerăsfirate": "nerăsfirat",
    "nerăsfiratei": "nerăsfirat",
    "nerăsfiratele": "nerăsfirat",
    "nerăsfiratelor": "nerăsfirat",
    "nerăsfirați": "nerăsfirat",
    "nerăsfirații": "nerăsfirat",
    "nerăsfiraților": "nerăsfirat",
    "nerăsfiratul": "nerăsfirat",
    "nerăsfiratului": "nerăsfirat",
    "nerăsfoita": "nerăsfoit",
    "nerăsfoită": "nerăsfoit",
    "nerăsfoite": "nerăsfoit",
    "nerăsfoitei": "nerăsfoit",
    "nerăsfoitele": "nerăsfoit",
    "nerăsfoitelor": "nerăsfoit",
    "nerăsfoiți": "nerăsfoit",
    "nerăsfoiții": "nerăsfoit",
    "nerăsfoitul": "nerăsfoit",
    "nerăsfoitului": "nerăsfoit",
    "nerăsfrânta": "nerăsfrânt",
    "nerăsfrântă": "nerăsfrânt",
    "nerăsfrânte": "nerăsfrânt",
    "nerăsfrântei": "nerăsfrânt",
    "nerăsfrântele": "nerăsfrânt",
    "nerăsfrântelor": "nerăsfrânt",
    "nerăsfrânți": "nerăsfrânt",
    "nerăsfrânții": "nerăsfrânt",
    "nerăsfrânților": "nerăsfrânt",
    "nerăsfrântul": "nerăsfrânt",
    "nerăsfrântului": "nerăsfrânt",
    "nerâșnită": "nerâșnit",
    "nerâșnite": "nerâșnit",
    "nerâșniți": "nerâșnit",
    "nerasolita": "nerasolit",
    "nerasolită": "nerasolit",
    "nerasolite": "nerasolit",
    "nerasolitei": "nerasolit",
    "nerasolitele": "nerasolit",
    "nerasolitelor": "nerasolit",
    "nerasoliți": "nerasolit",
    "nerasoliții": "nerasolit",
    "nerasoliților": "nerasolit",
    "nerasolitul": "nerasolit",
    "nerasolitului": "nerasolit",
    "nerășpăluită": "nerășpăluit",
    "nerășpăluite": "nerășpăluit",
    "nerășpăluiți": "nerășpăluit",
    "nerăspândita": "nerăspândit",
    "nerăspândită": "nerăspândit",
    "nerăspândite": "nerăspândit",
    "nerăspânditei": "nerăspândit",
    "nerăspânditele": "nerăspândit",
    "nerăspânditelor": "nerăspândit",
    "nerăspândiți": "nerăspândit",
    "nerăspândiții": "nerăspândit",
    "nerăspândiților": "nerăspândit",
    "nerăspânditul": "nerăspândit",
    "nerăspânditului": "nerăspândit",
    "nerăspicata": "nerăspicat",
    "nerăspicată": "nerăspicat",
    "nerăspicate": "nerăspicat",
    "nerăspicatei": "nerăspicat",
    "nerăspicatele": "nerăspicat",
    "nerăspicatelor": "nerăspicat",
    "nerăspicați": "nerăspicat",
    "nerăspicații": "nerăspicat",
    "nerăspicaților": "nerăspicat",
    "nerăspicatul": "nerăspicat",
    "nerăspicatului": "nerăspicat",
    "nerăsplătită": "nerăsplătit",
    "nerăsplătite": "nerăsplătit",
    "nerăsplătiți": "nerăsplătit",
    "nerăspopita": "nerăspopit",
    "nerăspopită": "nerăspopit",
    "nerăspopite": "nerăspopit",
    "nerăspopitei": "nerăspopit",
    "nerăspopitele": "nerăspopit",
    "nerăspopitelor": "nerăspopit",
    "nerăspopiți": "nerăspopit",
    "nerăspopiții": "nerăspopit",
    "nerăspopiților": "nerăspopit",
    "nerăspopitul": "nerăspopit",
    "nerăspopitului": "nerăspopit",
    "nerăspunsă": "nerăspuns",
    "nerăspunse": "nerăspuns",
    "nerăspunși": "nerăspuns",
    "nerăstălmăcită": "nerăstălmăcit",
    "nerăstălmăcite": "nerăstălmăcit",
    "nerăstălmăciți": "nerăstălmăcit",
    "nerastenica": "nerastenic",
    "nerastenică": "nerastenic",
    "nerastenice": "nerastenic",
    "nerastenicei": "nerastenic",
    "nerastenicele": "nerastenic",
    "nerastenicelor": "nerastenic",
    "nerastenici": "nerastenic",
    "nerastenicii": "nerastenic",
    "nerastenicilor": "nerastenic",
    "nerastenicul": "nerastenic",
    "nerastenicului": "nerastenic",
    "nerăstignită": "nerăstignit",
    "nerăstignite": "nerăstignit",
    "nerăstigniți": "nerăstignit",
    "nerăstită": "nerăstit",
    "nerăstite": "nerăstit",
    "nerăstiți": "nerăstit",
    "nerăstocită": "nerăstocit",
    "nerăstocite": "nerăstocit",
    "nerăstociți": "nerăstocit",
    "nerăsturnată": "nerăsturnat",
    "nerăsturnate": "nerăsturnat",
    "nerăsturnați": "nerăsturnat",
    "nerăsucită": "nerăsucit",
    "nerăsucite": "nerăsucit",
    "nerăsuciți": "nerăsucit",
    "nerăsuflata": "nerăsuflat",
    "nerăsuflată": "nerăsuflat",
    "nerăsuflate": "nerăsuflat",
    "nerăsuflatei": "nerăsuflat",
    "nerăsuflatele": "nerăsuflat",
    "nerăsuflatelor": "nerăsuflat",
    "nerăsuflați": "nerăsuflat",
    "nerăsuflatul": "nerăsuflat",
    "nerăsuflatului": "nerăsuflat",
    "nerăsunată": "nerăsunat",
    "nerăsunate": "nerăsunat",
    "nerăsunați": "nerăsunat",
    "nerătăcită": "nerătăcit",
    "nerătăcite": "nerătăcit",
    "nerătăciți": "nerătăcit",
    "neratata": "neratat",
    "neratată": "neratat",
    "neratate": "neratat",
    "neratatei": "neratat",
    "neratatele": "neratat",
    "neratatelor": "neratat",
    "neratați": "neratat",
    "neratații": "neratat",
    "neratatul": "neratat",
    "neratatului": "neratat",
    "neratificata": "neratificat",
    "neratificată": "neratificat",
    "neratificate": "neratificat",
    "neratificatei": "neratificat",
    "neratificatele": "neratificat",
    "neratificatelor": "neratificat",
    "neratificați": "neratificat",
    "neratificații": "neratificat",
    "neratificaților": "neratificat",
    "neratificatul": "neratificat",
    "neratificatului": "neratificat",
    "neraționalizata": "neraționalizat",
    "neraționalizată": "neraționalizat",
    "neraționalizate": "neraționalizat",
    "neraționalizatei": "neraționalizat",
    "neraționalizatele": "neraționalizat",
    "neraționalizatelor": "neraționalizat",
    "neraționalizați": "neraționalizat",
    "neraționalizații": "neraționalizat",
    "neraționalizatul": "neraționalizat",
    "neraționalizatului": "neraționalizat",
    "nerăvășită": "nerăvășit",
    "nerăvășite": "nerăvășit",
    "nerăvășiți": "nerăvășit",
    "nerâvnită": "nerâvnit",
    "nerâvnite": "nerâvnit",
    "nerâvniți": "nerâvnit",
    "nerăzbătuta": "nerăzbătut",
    "nerăzbătută": "nerăzbătut",
    "nerăzbătute": "nerăzbătut",
    "nerăzbătutei": "nerăzbătut",
    "nerăzbătutele": "nerăzbătut",
    "nerăzbătutelor": "nerăzbătut",
    "nerăzbătuți": "nerăzbătut",
    "nerăzbătuții": "nerăzbătut",
    "nerăzbătuților": "nerăzbătut",
    "nerăzbătutul": "nerăzbătut",
    "nerăzbătutului": "nerăzbătut",
    "nerăzbita": "nerăzbit",
    "nerăzbită": "nerăzbit",
    "nerăzbite": "nerăzbit",
    "nerăzbitei": "nerăzbit",
    "nerăzbitele": "nerăzbit",
    "nerăzbitelor": "nerăzbit",
    "nerăzbiți": "nerăzbit",
    "nerăzbiții": "nerăzbit",
    "nerăzbiților": "nerăzbit",
    "nerăzbitul": "nerăzbit",
    "nerăzbitului": "nerăzbit",
    "nerăzboită": "nerăzboit",
    "nerăzboite": "nerăzboit",
    "nerăzboiți": "nerăzboit",
    "nerăzbunata": "nerăzbunat",
    "nerăzbunată": "nerăzbunat",
    "nerăzbunate": "nerăzbunat",
    "nerăzbunatei": "nerăzbunat",
    "nerăzbunatele": "nerăzbunat",
    "nerăzbunatelor": "nerăzbunat",
    "nerăzbunați": "nerăzbunat",
    "nerăzbunații": "nerăzbunat",
    "nerăzbunaților": "nerăzbunat",
    "nerăzbunatul": "nerăzbunat",
    "nerăzbunatului": "nerăzbunat",
    "nerăzgâiata": "nerăzgâiat",
    "nerăzgâiată": "nerăzgâiat",
    "nerăzgâiate": "nerăzgâiat",
    "nerăzgâiatei": "nerăzgâiat",
    "nerăzgâiatele": "nerăzgâiat",
    "nerăzgâiatelor": "nerăzgâiat",
    "nerăzgâiați": "nerăzgâiat",
    "nerăzgâiații": "nerăzgâiat",
    "nerăzgâiaților": "nerăzgâiat",
    "nerăzgâiatul": "nerăzgâiat",
    "nerăzgâiatului": "nerăzgâiat",
    "nerăzgândită": "nerăzgândit",
    "nerăzgândite": "nerăzgândit",
    "nerăzgândiți": "nerăzgândit",
    "nerăzlețită": "nerăzlețit",
    "nerăzlețite": "nerăzlețit",
    "nerăzlețiți": "nerăzlețit",
    "nerăzuita": "nerăzuit",
    "nerăzuită": "nerăzuit",
    "nerăzuite": "nerăzuit",
    "nerăzuitei": "nerăzuit",
    "nerăzuitele": "nerăzuit",
    "nerăzuitelor": "nerăzuit",
    "nerăzuiți": "nerăzuit",
    "nerăzuiții": "nerăzuit",
    "nerăzuitul": "nerăzuit",
    "nerăzuitului": "nerăzuit",
    "nerăzvrătită": "nerăzvrătit",
    "nerăzvrătite": "nerăzvrătit",
    "nerăzvrătiți": "nerăzvrătit",
    "nereabilitata": "nereabilitat",
    "nereabilitată": "nereabilitat",
    "nereabilitate": "nereabilitat",
    "nereabilitatei": "nereabilitat",
    "nereabilitatele": "nereabilitat",
    "nereabilitatelor": "nereabilitat",
    "nereabilitați": "nereabilitat",
    "nereabilitații": "nereabilitat",
    "nereabilitaților": "nereabilitat",
    "nereabilitatul": "nereabilitat",
    "nereabilitatului": "nereabilitat",
    "nereacționată": "nereacționat",
    "nereacționate": "nereacționat",
    "nereacționați": "nereacționat",
    "nereactivată": "nereactivat",
    "nereactivate": "nereactivat",
    "nereactivați": "nereactivat",
    "nereactualizată": "nereactualizat",
    "nereactualizate": "nereactualizat",
    "nereactualizați": "nereactualizat",
    "nereadusă": "nereadus",
    "nereaduse": "nereadus",
    "nereaduși": "nereadus",
    "nereafirmată": "nereafirmat",
    "nereafirmate": "nereafirmat",
    "nereafirmați": "nereafirmat",
    "nerealiniată": "nerealiniat",
    "nerealiniate": "nerealiniat",
    "nerealiniați": "nerealiniat",
    "nerealipită": "nerealipit",
    "nerealipite": "nerealipit",
    "nerealipiți": "nerealipit",
    "nerealista": "nerealist",
    "nerealistă": "nerealist",
    "nerealiste": "nerealist",
    "nerealistei": "nerealist",
    "nerealistele": "nerealist",
    "nerealistelor": "nerealist",
    "nerealiști": "nerealist",
    "nerealiștii": "nerealist",
    "nerealiștilor": "nerealist",
    "nerealistul": "nerealist",
    "nerealistului": "nerealist",
    "nerealista": "nerealistă",
    "nerealiste": "nerealistă",
    "nerealistei": "nerealistă",
    "nerealistele": "nerealistă",
    "nerealistelor": "nerealistă",
    "nerealizarea": "nerealizare",
    "nerealizari": "nerealizare",
    "nerealizarii": "nerealizare",
    "nerealizarile": "nerealizare",
    "nerealizarilor": "nerealizare",
    "nerealizată": "nerealizat",
    "nerealizate": "nerealizat",
    "nerealizați": "nerealizat",
    "nereamintită": "nereamintit",
    "nereamintite": "nereamintit",
    "nereamintiți": "nereamintit",
    "nereangajată": "nereangajat",
    "nereangajate": "nereangajat",
    "nereangajați": "nereangajat",
    "nereanimată": "nereanimat",
    "nereanimate": "nereanimat",
    "nereanimați": "nereanimat",
    "nereapărută": "nereapărut",
    "nereapărute": "nereapărut",
    "nereapăruți": "nereapărut",
    "nereașezată": "nereașezat",
    "nereașezate": "nereașezat",
    "nereașezați": "nereașezat",
    "nerebegită": "nerebegit",
    "nerebegite": "nerebegit",
    "nerebegiți": "nerebegit",
    "nerebutata": "nerebutat",
    "nerebutată": "nerebutat",
    "nerebutate": "nerebutat",
    "nerebutatei": "nerebutat",
    "nerebutatele": "nerebutat",
    "nerebutatelor": "nerebutat",
    "nerebutați": "nerebutat",
    "nerebutații": "nerebutat",
    "nerebutaților": "nerebutat",
    "nerebutatul": "nerebutat",
    "nerebutatului": "nerebutat",
    "nerecalculată": "nerecalculat",
    "nerecalculate": "nerecalculat",
    "nerecalculați": "nerecalculat",
    "nerecalificată": "nerecalificat",
    "nerecalificate": "nerecalificat",
    "nerecalificați": "nerecalificat",
    "nerecăpătată": "nerecăpătat",
    "nerecăpătate": "nerecăpătat",
    "nerecăpătați": "nerecăpătat",
    "nerecapitulată": "nerecapitulat",
    "nerecapitulate": "nerecapitulat",
    "nerecapitulați": "nerecapitulat",
    "nerecăsătorita": "nerecăsătorit",
    "nerecăsătorită": "nerecăsătorit",
    "nerecăsătorite": "nerecăsătorit",
    "nerecăsătoritei": "nerecăsătorit",
    "nerecăsătoritele": "nerecăsătorit",
    "nerecăsătoritelor": "nerecăsătorit",
    "nerecăsătoriți": "nerecăsătorit",
    "nerecăsătoriții": "nerecăsătorit",
    "nerecăsătoriților": "nerecăsătorit",
    "nerecăsătoritul": "nerecăsătorit",
    "nerecăsătoritului": "nerecăsătorit",
    "nerecâștigată": "nerecâștigat",
    "nerecâștigate": "nerecâștigat",
    "nerecâștigați": "nerecâștigat",
    "nerecenzată": "nerecenzat",
    "nerecenzate": "nerecenzat",
    "nerecenzați": "nerecenzat",
    "nereceptată": "nereceptat",
    "nereceptate": "nereceptat",
    "nereceptați": "nereceptat",
    "nerecepționată": "nerecepționat",
    "nerecepționate": "nerecepționat",
    "nerecepționați": "nerecepționat",
    "nerechemata": "nerechemat",
    "nerechemată": "nerechemat",
    "nerechemate": "nerechemat",
    "nerechematei": "nerechemat",
    "nerechematele": "nerechemat",
    "nerechematelor": "nerechemat",
    "nerechemați": "nerechemat",
    "nerechemații": "nerechemat",
    "nerechemaților": "nerechemat",
    "nerechematul": "nerechemat",
    "nerechematului": "nerechemat",
    "nerechiziționată": "nerechiziționat",
    "nerechiziționate": "nerechiziționat",
    "nerechiziționați": "nerechiziționat",
    "nereciclată": "nereciclat",
    "nereciclate": "nereciclat",
    "nereciclați": "nereciclat",
    "nerecidivată": "nerecidivat",
    "nerecidivate": "nerecidivat",
    "nerecidivați": "nerecidivat",
    "nerecitată": "nerecitat",
    "nerecitate": "nerecitat",
    "nerecitați": "nerecitat",
    "nerecitită": "nerecitit",
    "nerecitite": "nerecitit",
    "nerecitiți": "nerecitit",
    "nereclădită": "nereclădit",
    "nereclădite": "nereclădit",
    "nereclădiți": "nereclădit",
    "nereclamată": "nereclamat",
    "nereclamate": "nereclamat",
    "nereclamați": "nereclamat",
    "nerecoltata": "nerecoltat",
    "nerecoltată": "nerecoltat",
    "nerecoltate": "nerecoltat",
    "nerecoltatei": "nerecoltat",
    "nerecoltatele": "nerecoltat",
    "nerecoltatelor": "nerecoltat",
    "nerecoltați": "nerecoltat",
    "nerecoltații": "nerecoltat",
    "nerecoltaților": "nerecoltat",
    "nerecoltatul": "nerecoltat",
    "nerecoltatului": "nerecoltat",
    "nerecomandată": "nerecomandat",
    "nerecomandate": "nerecomandat",
    "nerecomandați": "nerecomandat",
    "nerecompensată": "nerecompensat",
    "nerecompensate": "nerecompensat",
    "nerecompensați": "nerecompensat",
    "nerecompunsă": "nerecompuns",
    "nerecompunse": "nerecompuns",
    "nerecompunși": "nerecompuns",
    "nereconciliată": "nereconciliat",
    "nereconciliate": "nereconciliat",
    "nereconciliați": "nereconciliat",
    "nerecondiționată": "nerecondiționat",
    "nerecondiționate": "nerecondiționat",
    "nerecondiționați": "nerecondiționat",
    "nereconfirmată": "nereconfirmat",
    "nereconfirmate": "nereconfirmat",
    "nereconfirmați": "nereconfirmat",
    "nereconfortată": "nereconfortat",
    "nereconfortate": "nereconfortat",
    "nereconfortați": "nereconfortat",
    "nereconsiderată": "nereconsiderat",
    "nereconsiderate": "nereconsiderat",
    "nereconsiderați": "nereconsiderat",
    "nereconstituită": "nereconstituit",
    "nereconstituite": "nereconstituit",
    "nereconstituiți": "nereconstituit",
    "nereconstruită": "nereconstruit",
    "nereconstruite": "nereconstruit",
    "nereconstruiți": "nereconstruit",
    "nerecoptă": "nerecopt",
    "nerecopte": "nerecopt",
    "nerecopți": "nerecopt",
    "nerecreata": "nerecreat",
    "nerecreată": "nerecreat",
    "nerecreate": "nerecreat",
    "nerecreatei": "nerecreat",
    "nerecreatele": "nerecreat",
    "nerecreatelor": "nerecreat",
    "nerecreați": "nerecreat",
    "nerecreații": "nerecreat",
    "nerecreaților": "nerecreat",
    "nerecreatul": "nerecreat",
    "nerecreatului": "nerecreat",
    "nerecrutată": "nerecrutat",
    "nerecrutate": "nerecrutat",
    "nerecrutați": "nerecrutat",
    "nerectificată": "nerectificat",
    "nerectificate": "nerectificat",
    "nerectificați": "nerectificat",
    "nerecucerita": "nerecucerit",
    "nerecucerită": "nerecucerit",
    "nerecucerite": "nerecucerit",
    "nerecuceritei": "nerecucerit",
    "nerecuceritele": "nerecucerit",
    "nerecuceritelor": "nerecucerit",
    "nerecuceriți": "nerecucerit",
    "nerecuceriții": "nerecucerit",
    "nerecuceriților": "nerecucerit",
    "nerecuceritul": "nerecucerit",
    "nerecuceritului": "nerecucerit",
    "nerecunoașterea": "nerecunoaștere",
    "nerecunoașteri": "nerecunoaștere",
    "nerecunoașterii": "nerecunoaștere",
    "nerecunoașterile": "nerecunoaștere",
    "nerecunoașterilor": "nerecunoaștere",
    "nerecunoscătoarea": "nerecunoscătoare",
    "nerecunoscătoarei": "nerecunoscătoare",
    "nerecunoscătoarele": "nerecunoscătoare",
    "nerecunoscătoarelor": "nerecunoscătoare",
    "nerecunoscătoare": "nerecunoscător",
    "nerecunoscătoarea": "nerecunoscător",
    "nerecunoscătoarei": "nerecunoscător",
    "nerecunoscătoarele": "nerecunoscător",
    "nerecunoscătoarelor": "nerecunoscător",
    "nerecunoscători": "nerecunoscător",
    "nerecunoscătorii": "nerecunoscător",
    "nerecunoscătorilor": "nerecunoscător",
    "nerecunoscătorul": "nerecunoscător",
    "nerecunoscătorului": "nerecunoscător",
    "nerecunoscuta": "nerecunoscut",
    "nerecunoscută": "nerecunoscut",
    "nerecunoscute": "nerecunoscut",
    "nerecunoscutei": "nerecunoscut",
    "nerecunoscutele": "nerecunoscut",
    "nerecunoscutelor": "nerecunoscut",
    "nerecunoscuți": "nerecunoscut",
    "nerecunoscuții": "nerecunoscut",
    "nerecunoscuților": "nerecunoscut",
    "nerecunoscutul": "nerecunoscut",
    "nerecunoscutului": "nerecunoscut",
    "nerecunoștința": "nerecunoștință",
    "nerecunoștințe": "nerecunoștință",
    "nerecunoștinței": "nerecunoștință",
    "nerecunoștințele": "nerecunoștință",
    "nerecunoștințelor": "nerecunoștință",
    "nerecuperată": "nerecuperat",
    "nerecuperate": "nerecuperat",
    "nerecuperați": "nerecuperat",
    "nerecursă": "nerecurs",
    "nerecurse": "nerecurs",
    "nerecurși": "nerecurs",
    "nerecuzată": "nerecuzat",
    "nerecuzate": "nerecuzat",
    "nerecuzați": "nerecuzat",
    "neredactată": "neredactat",
    "neredactate": "neredactat",
    "neredactați": "neredactat",
    "neredată": "neredat",
    "neredate": "neredat",
    "neredați": "neredat",
    "neredeschisa": "neredeschis",
    "neredeschisă": "neredeschis",
    "neredeschise": "neredeschis",
    "neredeschisei": "neredeschis",
    "neredeschisele": "neredeschis",
    "neredeschiselor": "neredeschis",
    "neredeschiși": "neredeschis",
    "neredeschisii": "neredeschis",
    "neredeschisilor": "neredeschis",
    "neredeschisul": "neredeschis",
    "neredeschisului": "neredeschis",
    "neredescoperită": "neredescoperit",
    "neredescoperite": "neredescoperit",
    "neredescoperiți": "neredescoperit",
    "neredeșteptată": "neredeșteptat",
    "neredeșteptate": "neredeșteptat",
    "neredeșteptați": "neredeșteptat",
    "neredevenită": "neredevenit",
    "neredevenite": "neredevenit",
    "neredeveniți": "neredevenit",
    "nerediscutată": "nerediscutat",
    "nerediscutate": "nerediscutat",
    "nerediscutați": "nerediscutat",
    "neredistribuită": "neredistribuit",
    "neredistribuite": "neredistribuit",
    "neredistribuiți": "neredistribuit",
    "neredobândită": "neredobândit",
    "neredobândite": "neredobândit",
    "neredobândiți": "neredobândit",
    "neredresată": "neredresat",
    "neredresate": "neredresat",
    "neredresați": "neredresat",
    "neredusa": "neredus",
    "neredusă": "neredus",
    "nereduse": "neredus",
    "neredusei": "neredus",
    "neredusele": "neredus",
    "nereduselor": "neredus",
    "nereduși": "neredus",
    "neredușii": "neredus",
    "neredușilor": "neredus",
    "neredusul": "neredus",
    "neredusului": "neredus",
    "nereeditata": "nereeditat",
    "nereeditată": "nereeditat",
    "nereeditate": "nereeditat",
    "nereeditatei": "nereeditat",
    "nereeditatele": "nereeditat",
    "nereeditatelor": "nereeditat",
    "nereeditați": "nereeditat",
    "nereeditații": "nereeditat",
    "nereeditaților": "nereeditat",
    "nereeditatul": "nereeditat",
    "nereeditatului": "nereeditat",
    "nereeducată": "nereeducat",
    "nereeducate": "nereeducat",
    "nereeducați": "nereeducat",
    "nereexaminată": "nereexaminat",
    "nereexaminate": "nereexaminat",
    "nereexaminați": "nereexaminat",
    "nerefăcută": "nerefăcut",
    "nerefăcute": "nerefăcut",
    "nerefăcuți": "nerefăcut",
    "nereferită": "nereferit",
    "nereferite": "nereferit",
    "nereferiți": "nereferit",
    "nereformată": "nereformat",
    "nereformate": "nereformat",
    "nereformați": "nereformat",
    "nerefrigerată": "nerefrigerat",
    "nerefrigerate": "nerefrigerat",
    "nerefrigerați": "nerefrigerat",
    "nerefugiată": "nerefugiat",
    "nerefugiate": "nerefugiat",
    "nerefugiați": "nerefugiat",
    "nerefulată": "nerefulat",
    "nerefulate": "nerefulat",
    "nerefulați": "nerefulat",
    "nerefuzată": "nerefuzat",
    "nerefuzate": "nerefuzat",
    "nerefuzați": "nerefuzat",
    "neregăsită": "neregăsit",
    "neregăsite": "neregăsit",
    "neregăsiți": "neregăsit",
    "neregenerată": "neregenerat",
    "neregenerate": "neregenerat",
    "neregenerați": "neregenerat",
    "neregizată": "neregizat",
    "neregizate": "neregizat",
    "neregizați": "neregizat",
    "nereglată": "nereglat",
    "nereglate": "nereglat",
    "nereglați": "nereglat",
    "nereglementată": "nereglementat",
    "nereglementate": "nereglementat",
    "nereglementați": "nereglementat",
    "neregresată": "neregresat",
    "neregresate": "neregresat",
    "neregresați": "neregresat",
    "neregretată": "neregretat",
    "neregretate": "neregretat",
    "neregretați": "neregretat",
    "neregrupată": "neregrupat",
    "neregrupate": "neregrupat",
    "neregrupați": "neregrupat",
    "neregula": "neregulă",
    "nereguli": "neregulă",
    "neregulii": "neregulă",
    "neregulile": "neregulă",
    "neregulilor": "neregulă",
    "neregularitatea": "neregularitate",
    "neregularități": "neregularitate",
    "neregularității": "neregularitate",
    "neregularitățile": "neregularitate",
    "neregularităților": "neregularitate",
    "neregularizată": "neregularizat",
    "neregularizate": "neregularizat",
    "neregularizați": "neregularizat",
    "neregulata": "neregulat",
    "neregulată": "neregulat",
    "neregulate": "neregulat",
    "neregulatei": "neregulat",
    "neregulatele": "neregulat",
    "neregulatelor": "neregulat",
    "neregulați": "neregulat",
    "neregulații": "neregulat",
    "neregulaților": "neregulat",
    "neregulatul": "neregulat",
    "neregulatului": "neregulat",
    "nereieșită": "nereieșit",
    "nereieșite": "nereieșit",
    "nereieșiți": "nereieșit",
    "nereîmpădurită": "nereîmpădurit",
    "nereîmpădurite": "nereîmpădurit",
    "nereîmpăduriți": "nereîmpădurit",
    "nereîmpărțită": "nereîmpărțit",
    "nereîmpărțite": "nereîmpărțit",
    "nereîmpărțiți": "nereîmpărțit",
    "nereîmprospătată": "nereîmprospătat",
    "nereîmprospătate": "nereîmprospătat",
    "nereîmprospătați": "nereîmprospătat",
    "nereînarmată": "nereînarmat",
    "nereînarmate": "nereînarmat",
    "nereînarmați": "nereînarmat",
    "nereîncadrată": "nereîncadrat",
    "nereîncadrate": "nereîncadrat",
    "nereîncadrați": "nereîncadrat",
    "nereincarnată": "nereincarnat",
    "nereincarnate": "nereincarnat",
    "nereincarnați": "nereincarnat",
    "nereîncepută": "nereînceput",
    "nereîncepute": "nereînceput",
    "nereîncepuți": "nereînceput",
    "nereînființată": "nereînființat",
    "nereînființate": "nereînființat",
    "nereînființați": "nereînființat",
    "nereînnoita": "nereînnoit",
    "nereînnoită": "nereînnoit",
    "nereînnoite": "nereînnoit",
    "nereînnoitei": "nereînnoit",
    "nereînnoitele": "nereînnoit",
    "nereînnoitelor": "nereînnoit",
    "nereînnoiți": "nereînnoit",
    "nereînnoiții": "nereînnoit",
    "nereînnoiților": "nereînnoit",
    "nereînnoitul": "nereînnoit",
    "nereînnoitului": "nereînnoit",
    "nereînsuflețită": "nereînsuflețit",
    "nereînsuflețite": "nereînsuflețit",
    "nereînsuflețiți": "nereînsuflețit",
    "nereîntâlnită": "nereîntâlnit",
    "nereîntâlnite": "nereîntâlnit",
    "nereîntâlniți": "nereîntâlnit",
    "nereintegrată": "nereintegrat",
    "nereintegrate": "nereintegrat",
    "nereintegrați": "nereintegrat",
    "nereîntinerita": "nereîntinerit",
    "nereîntinerită": "nereîntinerit",
    "nereîntinerite": "nereîntinerit",
    "nereîntineritei": "nereîntinerit",
    "nereîntineritele": "nereîntinerit",
    "nereîntineritelor": "nereîntinerit",
    "nereîntineriți": "nereîntinerit",
    "nereîntineriții": "nereîntinerit",
    "nereîntineriților": "nereîntinerit",
    "nereîntineritul": "nereîntinerit",
    "nereîntineritului": "nereîntinerit",
    "nereintrodusă": "nereintrodus",
    "nereintroduse": "nereintrodus",
    "nereintroduși": "nereintrodus",
    "nereînviata": "nereînviat",
    "nereînviată": "nereînviat",
    "nereînviate": "nereînviat",
    "nereînviatei": "nereînviat",
    "nereînviatele": "nereînviat",
    "nereînviatelor": "nereînviat",
    "nereînviați": "nereînviat",
    "nereînviații": "nereînviat",
    "nereînviaților": "nereînviat",
    "nereînviatul": "nereînviat",
    "nereînviatului": "nereînviat",
    "nerelansată": "nerelansat",
    "nerelansate": "nerelansat",
    "nerelansați": "nerelansat",
    "nerelatată": "nerelatat",
    "nerelatate": "nerelatat",
    "nerelatați": "nerelatat",
    "nerelaxată": "nerelaxat",
    "nerelaxate": "nerelaxat",
    "nerelaxați": "nerelaxat",
    "nerelevată": "nerelevat",
    "nerelevate": "nerelevat",
    "nerelevați": "nerelevat",
    "nereliefata": "nereliefat",
    "nereliefată": "nereliefat",
    "nereliefate": "nereliefat",
    "nereliefatei": "nereliefat",
    "nereliefatele": "nereliefat",
    "nereliefatelor": "nereliefat",
    "nereliefați": "nereliefat",
    "nereliefații": "nereliefat",
    "nereliefaților": "nereliefat",
    "nereliefatul": "nereliefat",
    "nereliefatului": "nereliefat",
    "nereluată": "nereluat",
    "nereluate": "nereluat",
    "nereluați": "nereluat",
    "neremaiată": "neremaiat",
    "neremaiate": "neremaiat",
    "neremaiați": "neremaiat",
    "neremaniată": "neremaniat",
    "neremaniate": "neremaniat",
    "neremaniați": "neremaniat",
    "neremarcată": "neremarcat",
    "neremarcate": "neremarcat",
    "neremarcați": "neremarcat",
    "neremediată": "neremediat",
    "neremediate": "neremediat",
    "neremediați": "neremediat",
    "nerememorată": "nerememorat",
    "nerememorate": "nerememorat",
    "nerememorați": "nerememorat",
    "neremisă": "neremis",
    "neremise": "neremis",
    "neremiși": "neremis",
    "neremizată": "neremizat",
    "neremizate": "neremizat",
    "neremizați": "neremizat",
    "neremodelată": "neremodelat",
    "neremodelate": "neremodelat",
    "neremodelați": "neremodelat",
    "neremontată": "neremontat",
    "neremontate": "neremontat",
    "neremontați": "neremontat",
    "neremorcată": "neremorcat",
    "neremorcate": "neremorcat",
    "neremorcați": "neremorcat",
    "neremunerată": "neremunerat",
    "neremunerate": "neremunerat",
    "neremunerați": "neremunerat",
    "nerenăscuta": "nerenăscut",
    "nerenăscută": "nerenăscut",
    "nerenăscute": "nerenăscut",
    "nerenăscutei": "nerenăscut",
    "nerenăscutele": "nerenăscut",
    "nerenăscutelor": "nerenăscut",
    "nerenăscuți": "nerenăscut",
    "nerenăscuții": "nerenăscut",
    "nerenăscuților": "nerenăscut",
    "nerenăscutul": "nerenăscut",
    "nerenăscutului": "nerenăscut",
    "nerenegata": "nerenegat",
    "nerenegată": "nerenegat",
    "nerenegate": "nerenegat",
    "nerenegatei": "nerenegat",
    "nerenegatele": "nerenegat",
    "nerenegatelor": "nerenegat",
    "nerenegați": "nerenegat",
    "nerenegații": "nerenegat",
    "nerenegaților": "nerenegat",
    "nerenegatul": "nerenegat",
    "nerenegatului": "nerenegat",
    "nerenovată": "nerenovat",
    "nerenovate": "nerenovat",
    "nerenovați": "nerenovat",
    "nerentabilă": "nerentabil",
    "nerentabile": "nerentabil",
    "nerentabili": "nerentabil",
    "nerentată": "nerentat",
    "nerentate": "nerentat",
    "nerentați": "nerentat",
    "nerenumită": "nerenumit",
    "nerenumite": "nerenumit",
    "nerenumiți": "nerenumit",
    "nerenunțată": "nerenunțat",
    "nerenunțate": "nerenunțat",
    "nerenunțați": "nerenunțat",
    "nereocupată": "nereocupat",
    "nereocupate": "nereocupat",
    "nereocupați": "nereocupat",
    "nereorganizată": "nereorganizat",
    "nereorganizate": "nereorganizat",
    "nereorganizați": "nereorganizat",
    "nereparată": "nereparat",
    "nereparate": "nereparat",
    "nereparați": "nereparat",
    "nerepartizată": "nerepartizat",
    "nerepartizate": "nerepartizat",
    "nerepartizați": "nerepartizat",
    "nerepatriată": "nerepatriat",
    "nerepatriate": "nerepatriat",
    "nerepatriați": "nerepatriat",
    "nerepauzată": "nerepauzat",
    "nerepauzate": "nerepauzat",
    "nerepauzați": "nerepauzat",
    "nereperată": "nereperat",
    "nereperate": "nereperat",
    "nereperați": "nereperat",
    "nerepetata": "nerepetat",
    "nerepetată": "nerepetat",
    "nerepetate": "nerepetat",
    "nerepetatei": "nerepetat",
    "nerepetatele": "nerepetat",
    "nerepetatelor": "nerepetat",
    "nerepetați": "nerepetat",
    "nerepetații": "nerepetat",
    "nerepetaților": "nerepetat",
    "nerepetatul": "nerepetat",
    "nerepetatului": "nerepetat",
    "nerepezită": "nerepezit",
    "nerepezite": "nerepezit",
    "nerepeziți": "nerepezit",
    "nereplantată": "nereplantat",
    "nereplantate": "nereplantat",
    "nereplantați": "nereplantat",
    "nerepliată": "nerepliat",
    "nerepliate": "nerepliat",
    "nerepliați": "nerepliat",
    "nereplicată": "nereplicat",
    "nereplicate": "nereplicat",
    "nereplicați": "nereplicat",
    "nerepopulată": "nerepopulat",
    "nerepopulate": "nerepopulat",
    "nerepopulați": "nerepopulat",
    "nereportată": "nereportat",
    "nereportate": "nereportat",
    "nereportați": "nereportat",
    "nereprezentată": "nereprezentat",
    "nereprezentate": "nereprezentat",
    "nereprezentați": "nereprezentat",
    "nereprimată": "nereprimat",
    "nereprimate": "nereprimat",
    "nereprimați": "nereprimat",
    "nereprimită": "nereprimit",
    "nereprimite": "nereprimit",
    "nereprimiți": "nereprimit",
    "nereprobată": "nereprobat",
    "nereprobate": "nereprobat",
    "nereprobați": "nereprobat",
    "nereprodusă": "nereprodus",
    "nereproduse": "nereprodus",
    "nereproduși": "nereprodus",
    "nereprofilată": "nereprofilat",
    "nereprofilate": "nereprofilat",
    "nereprofilați": "nereprofilat",
    "nereproșată": "nereproșat",
    "nereproșate": "nereproșat",
    "nereproșați": "nereproșat",
    "nerepublicată": "nerepublicat",
    "nerepublicate": "nerepublicat",
    "nerepublicați": "nerepublicat",
    "nerepudiată": "nerepudiat",
    "nerepudiate": "nerepudiat",
    "nerepudiați": "nerepudiat",
    "nerepurtată": "nerepurtat",
    "nerepurtate": "nerepurtat",
    "nerepurtați": "nerepurtat",
    "nerescrisă": "nerescries",
    "nerescrise": "nerescries",
    "nerescriși": "nerescries",
    "neresemnata": "neresemnat",
    "neresemnată": "neresemnat",
    "neresemnate": "neresemnat",
    "neresemnatei": "neresemnat",
    "neresemnatele": "neresemnat",
    "neresemnatelor": "neresemnat",
    "neresemnați": "neresemnat",
    "neresemnații": "neresemnat",
    "neresemnaților": "neresemnat",
    "neresemnatul": "neresemnat",
    "neresemnatului": "neresemnat",
    "neresimțită": "neresimțit",
    "neresimțite": "neresimțit",
    "neresimțiți": "neresimțit",
    "neresorbită": "neresorbit",
    "neresorbite": "neresorbit",
    "neresorbiți": "neresorbit",
    "nerespectata": "nerespectat",
    "nerespectată": "nerespectat",
    "nerespectate": "nerespectat",
    "nerespectatei": "nerespectat",
    "nerespectatele": "nerespectat",
    "nerespectatelor": "nerespectat",
    "nerespectați": "nerespectat",
    "nerespectații": "nerespectat",
    "nerespectaților": "nerespectat",
    "nerespectatul": "nerespectat",
    "nerespectatului": "nerespectat",
    "nerespinsă": "nerespins",
    "nerespinse": "nerespins",
    "nerespinși": "nerespins",
    "nerespirată": "nerespirat",
    "nerespirate": "nerespirat",
    "nerespirați": "nerespirat",
    "nerestabilită": "nerestabilit",
    "nerestabilite": "nerestabilit",
    "nerestabiliți": "nerestabilit",
    "nerestatornicită": "nerestatornicit",
    "nerestatornicite": "nerestatornicit",
    "nerestatorniciți": "nerestatornicit",
    "nerestaurată": "nerestaurat",
    "nerestaurate": "nerestaurat",
    "nerestaurați": "nerestaurat",
    "nerestituită": "nerestituit",
    "nerestituite": "nerestituit",
    "nerestituiți": "nerestituit",
    "nerestrânsa": "nerestrâns",
    "nerestrânsă": "nerestrâns",
    "nerestrânse": "nerestrâns",
    "nerestrânsei": "nerestrâns",
    "nerestrânsele": "nerestrâns",
    "nerestrânselor": "nerestrâns",
    "nerestrânși": "nerestrâns",
    "nerestrânsii": "nerestrâns",
    "nerestrânsilor": "nerestrâns",
    "nerestrânsul": "nerestrâns",
    "nerestrânsului": "nerestrâns",
    "nerestructurată": "nerestructurat",
    "nerestructurate": "nerestructurat",
    "nerestructurați": "nerestructurat",
    "neretezata": "neretezat",
    "neretezată": "neretezat",
    "neretezate": "neretezat",
    "neretezatei": "neretezat",
    "neretezatele": "neretezat",
    "neretezatelor": "neretezat",
    "neretezați": "neretezat",
    "neretezații": "neretezat",
    "neretezaților": "neretezat",
    "neretezatul": "neretezat",
    "neretezatului": "neretezat",
    "nereținută": "nereținut",
    "nereținute": "nereținut",
    "nereținuți": "nereținut",
    "neretipărită": "neretipărit",
    "neretipărite": "neretipărit",
    "neretipăriți": "neretipărit",
    "neretractată": "neretractat",
    "neretractate": "neretractat",
    "neretractați": "neretractat",
    "neretrăită": "neretrăit",
    "neretrăite": "neretrăit",
    "neretrăiți": "neretrăit",
    "neretrasă": "neretras",
    "neretrase": "neretras",
    "neretrași": "neretras",
    "neretribuită": "neretribuit",
    "neretribuite": "neretribuit",
    "neretribuiți": "neretribuit",
    "neretrocedată": "neretrocedat",
    "neretrocedate": "neretrocedat",
    "neretrocedați": "neretrocedat",
    "neretrogradată": "neretrogradat",
    "neretrogradate": "neretrogradat",
    "neretrogradați": "neretrogradat",
    "neretușată": "neretușat",
    "neretușate": "neretușat",
    "neretușați": "neretușat",
    "nereunită": "nereunit",
    "nereunite": "nereunit",
    "nereuniți": "nereunit",
    "nereușita": "nereușit",
    "nereușită": "nereușit",
    "nereușite": "nereușit",
    "nereușitei": "nereușit",
    "nereușitele": "nereușit",
    "nereușitelor": "nereușit",
    "nereușiți": "nereușit",
    "nereușiții": "nereușit",
    "nereușiților": "nereușit",
    "nereușitul": "nereușit",
    "nereușitului": "nereușit",
    "nereutilată": "nereutilat",
    "nereutilate": "nereutilat",
    "nereutilați": "nereutilat",
    "nerevaccinată": "nerevaccinat",
    "nerevaccinate": "nerevaccinat",
    "nerevaccinați": "nerevaccinat",
    "nerevalorificată": "nerevalorificat",
    "nerevalorificate": "nerevalorificat",
    "nerevalorificați": "nerevalorificat",
    "nerevalorizată": "nerevalorizat",
    "nerevalorizate": "nerevalorizat",
    "nerevalorizați": "nerevalorizat",
    "nerevanșată": "nerevanșat",
    "nerevanșate": "nerevanșat",
    "nerevanșați": "nerevanșat",
    "nerevărsata": "nerevărsat",
    "nerevărsată": "nerevărsat",
    "nerevărsate": "nerevărsat",
    "nerevărsatei": "nerevărsat",
    "nerevărsatele": "nerevărsat",
    "nerevărsatelor": "nerevărsat",
    "nerevărsați": "nerevărsat",
    "nerevărsații": "nerevărsat",
    "nerevărsaților": "nerevărsat",
    "nerevărsatul": "nerevărsat",
    "nerevărsatului": "nerevărsat",
    "nerevăzută": "nerevăzut",
    "nerevăzute": "nerevăzut",
    "nerevăzuți": "nerevăzut",
    "nerevelată": "nerevelat",
    "nerevelate": "nerevelat",
    "nerevelați": "nerevelat",
    "nerevendicată": "nerevendicat",
    "nerevendicate": "nerevendicat",
    "nerevendicați": "nerevendicat",
    "nerevenită": "nerevenit",
    "nerevenite": "nerevenit",
    "nereveniți": "nerevenit",
    "nerevizuită": "nerevizuit",
    "nerevizuite": "nerevizuit",
    "nerevizuiți": "nerevizuit",
    "nerevocată": "nerevocat",
    "nerevocate": "nerevocat",
    "nerevocați": "nerevocat",
    "nerevoltată": "nerevoltat",
    "nerevoltate": "nerevoltat",
    "nerevoltați": "nerevoltat",
    "nerevoluționată": "nerevoluționat",
    "nerevoluționate": "nerevoluționat",
    "nerevoluționați": "nerevoluționat",
    "nerezemată": "nerezemat",
    "nerezemate": "nerezemat",
    "nerezemați": "nerezemat",
    "nerezervata": "nerezervat",
    "nerezervată": "nerezervat",
    "nerezervate": "nerezervat",
    "nerezervatei": "nerezervat",
    "nerezervatele": "nerezervat",
    "nerezervatelor": "nerezervat",
    "nerezervați": "nerezervat",
    "nerezervații": "nerezervat",
    "nerezervaților": "nerezervat",
    "nerezervatul": "nerezervat",
    "nerezervatului": "nerezervat",
    "nereziliată": "nereziliat",
    "nereziliate": "nereziliat",
    "nereziliați": "nereziliat",
    "nerezistată": "nerezistat",
    "nerezistate": "nerezistat",
    "nerezistați": "nerezistat",
    "nerezolvata": "nerezolvat",
    "nerezolvată": "nerezolvat",
    "nerezolvate": "nerezolvat",
    "nerezolvatei": "nerezolvat",
    "nerezolvatele": "nerezolvat",
    "nerezolvatelor": "nerezolvat",
    "nerezolvați": "nerezolvat",
    "nerezolvații": "nerezolvat",
    "nerezolvaților": "nerezolvat",
    "nerezolvatul": "nerezolvat",
    "nerezolvatului": "nerezolvat",
    "nerezultată": "nerezultat",
    "nerezultate": "nerezultat",
    "nerezultați": "nerezultat",
    "nerezumată": "nerezumat",
    "nerezumate": "nerezumat",
    "nerezumați": "nerezumat",
    "nericoșată": "nericoșat",
    "nericoșate": "nericoșat",
    "nericoșați": "nericoșat",
    "neridicată": "neridicat",
    "neridicate": "neridicat",
    "neridicați": "neridicat",
    "neridiculizată": "neridiculizat",
    "neridiculizate": "neridiculizat",
    "neridiculizați": "neridiculizat",
    "nerihtuită": "nerihtuit",
    "nerihtuite": "nerihtuit",
    "nerihtuiți": "nerihtuit",
    "nerimată": "nerimat",
    "nerimate": "nerimat",
    "nerimați": "nerimat",
    "nerindeluită": "nerindeluit",
    "nerindeluite": "nerindeluit",
    "nerindeluiți": "nerindeluit",
    "neripostată": "neripostat",
    "neripostate": "neripostat",
    "neripostați": "neripostat",
    "neriscata": "neriscat",
    "neriscată": "neriscat",
    "neriscate": "neriscat",
    "neriscatei": "neriscat",
    "neriscatele": "neriscat",
    "neriscatelor": "neriscat",
    "neriscați": "neriscat",
    "neriscații": "neriscat",
    "neriscaților": "neriscat",
    "neriscatul": "neriscat",
    "neriscatului": "neriscat",
    "nerisipita": "nerisipit",
    "nerisipită": "nerisipit",
    "nerisipite": "nerisipit",
    "nerisipitei": "nerisipit",
    "nerisipitele": "nerisipit",
    "nerisipitelor": "nerisipit",
    "nerisipiți": "nerisipit",
    "nerisipiții": "nerisipit",
    "nerisipiților": "nerisipit",
    "nerisipitul": "nerisipit",
    "nerisipitului": "nerisipit",
    "neritmată": "neritmat",
    "neritmate": "neritmat",
    "neritmați": "neritmat",
    "nerivalizată": "nerivalizat",
    "nerivalizate": "nerivalizat",
    "nerivalizați": "nerivalizat",
    "nerobită": "nerobit",
    "nerobite": "nerobit",
    "nerobiți": "nerobit",
    "nerobotită": "nerobotit",
    "nerobotite": "nerobotit",
    "nerobotiți": "nerobotit",
    "neroada": "nerod",
    "neroadă": "nerod",
    "neroade": "nerod",
    "neroadei": "nerod",
    "neroadele": "nerod",
    "neroadelor": "nerod",
    "nerodul": "nerod",
    "nerodului": "nerod",
    "nerozi": "nerod",
    "nerozii": "nerod",
    "nerozilor": "nerod",
    "nerodată": "nerodat",
    "nerodate": "nerodat",
    "nerodați": "nerodat",
    "nerodirea": "nerodire",
    "nerodiri": "nerodire",
    "nerodirii": "nerodire",
    "nerodirile": "nerodire",
    "nerodirilor": "nerodire",
    "nerodită": "nerodit",
    "nerodite": "nerodit",
    "nerodiți": "nerodit",
    "neroditoare": "neroditor",
    "neroditoarea": "neroditor",
    "neroditoarei": "neroditor",
    "neroditoarele": "neroditor",
    "neroditoarelor": "neroditor",
    "neroditori": "neroditor",
    "neroditorii": "neroditor",
    "neroditorilor": "neroditor",
    "neroditorul": "neroditor",
    "neroditorului": "neroditor",
    "neroită": "neroit",
    "neroite": "neroit",
    "neroiți": "neroit",
    "neromâneasca": "neromânesc",
    "neromânească": "neromânesc",
    "neromânescul": "neromânesc",
    "neromânescului": "neromânesc",
    "neromânești": "neromânesc",
    "neromâneștii": "neromânesc",
    "neromâneștile": "neromânesc",
    "neromâneștilor": "neromânesc",
    "neromanizată": "neromanizat",
    "neromanizate": "neromanizat",
    "neromanizați": "neromanizat",
    "neromânizată": "neromânizat",
    "neromânizate": "neromânizat",
    "neromânizați": "neromânizat",
    "neromanțată": "neromanțat",
    "neromanțate": "neromanțat",
    "neromanțați": "neromanțat",
    "neronțăită": "neronțăit",
    "neronțăite": "neronțăit",
    "neronțăiți": "neronțăit",
    "neropotită": "neropotit",
    "neropotite": "neropotit",
    "neropotiți": "neropotit",
    "neroșită": "neroșit",
    "neroșite": "neroșit",
    "neroșiți": "neroșit",
    "nerostita": "nerostit",
    "nerostită": "nerostit",
    "nerostite": "nerostit",
    "nerostitei": "nerostit",
    "nerostitele": "nerostit",
    "nerostitelor": "nerostit",
    "nerostiți": "nerostit",
    "nerostiții": "nerostit",
    "nerostiților": "nerostit",
    "nerostitul": "nerostit",
    "nerostitului": "nerostit",
    "nerostogolită": "nerostogolit",
    "nerostogolite": "nerostogolit",
    "nerostogoliți": "nerostogolit",
    "nerostuită": "nerostuit",
    "nerostuite": "nerostuit",
    "nerostuiți": "nerostuit",
    "nerotacizată": "nerotacizat",
    "nerotacizate": "nerotacizat",
    "nerotacizați": "nerotacizat",
    "nerotită": "nerotit",
    "nerotite": "nerotit",
    "nerotiți": "nerotit",
    "nerotunjita": "nerotunjit",
    "nerotunjită": "nerotunjit",
    "nerotunjite": "nerotunjit",
    "nerotunjitei": "nerotunjit",
    "nerotunjitele": "nerotunjit",
    "nerotunjitelor": "nerotunjit",
    "nerotunjiți": "nerotunjit",
    "nerotunjiții": "nerotunjit",
    "nerotunjiților": "nerotunjit",
    "nerotunjitul": "nerotunjit",
    "nerotunjitului": "nerotunjit",
    "nerozeasca": "nerozesc",
    "nerozească": "nerozesc",
    "nerozescul": "nerozesc",
    "nerozescului": "nerozesc",
    "nerozești": "nerozesc",
    "nerozeștii": "nerozesc",
    "nerozeștile": "nerozesc",
    "nerozeștilor": "nerozesc",
    "nerozia": "nerozie",
    "neroziei": "nerozie",
    "nerozii": "nerozie",
    "neroziile": "nerozie",
    "neroziilor": "nerozie",
    "nerugată": "nerugat",
    "nerugate": "nerugat",
    "nerugați": "nerugat",
    "neruginită": "neruginit",
    "neruginite": "neruginit",
    "neruginiți": "neruginit",
    "neruinată": "neruinat",
    "neruinate": "neruinat",
    "neruinați": "neruinat",
    "nerujată": "nerujat",
    "nerujate": "nerujat",
    "nerujați": "nerujat",
    "nerulată": "nerulat",
    "nerulate": "nerulat",
    "nerulați": "nerulat",
    "nerumegata": "nerumegat",
    "nerumegată": "nerumegat",
    "nerumegate": "nerumegat",
    "nerumegatei": "nerumegat",
    "nerumegatele": "nerumegat",
    "nerumegatelor": "nerumegat",
    "nerumegați": "nerumegat",
    "nerumegații": "nerumegat",
    "nerumegaților": "nerumegat",
    "nerumegatul": "nerumegat",
    "nerumegatului": "nerumegat",
    "nerumenită": "nerumenit",
    "nerumenite": "nerumenit",
    "nerumeniți": "nerumenit",
    "neruptă": "nerupt",
    "nerupte": "nerupt",
    "nerupți": "nerupt",
    "nerușinarea": "nerușinare",
    "nerușinări": "nerușinare",
    "nerușinării": "nerușinare",
    "nerușinările": "nerușinare",
    "nerușinărilor": "nerușinare",
    "nerușinata": "nerușinat",
    "nerușinată": "nerușinat",
    "nerușinate": "nerușinat",
    "nerușinatei": "nerușinat",
    "nerușinatele": "nerușinat",
    "nerușinatelor": "nerușinat",
    "nerușinați": "nerușinat",
    "nerușinații": "nerușinat",
    "nerușinaților": "nerușinat",
    "nerușinatul": "nerușinat",
    "nerușinatului": "nerușinat",
    "nerușinata": "nerușinată",
    "nerușinate": "nerușinată",
    "nerușinatei": "nerușinată",
    "nerușinatele": "nerușinată",
    "nerușinatelor": "nerușinată",
    "nervi": "nerv",
    "nervii": "nerv",
    "nervilor": "nerv",
    "nervul": "nerv",
    "nervului": "nerv",
    "nervoasa": "nervos",
    "nervoasă": "nervos",
    "nervoase": "nervos",
    "nervoasei": "nervos",
    "nervoasele": "nervos",
    "nervoaselor": "nervos",
    "nervoși": "nervos",
    "nervoșii": "nervos",
    "nervoșilor": "nervos",
    "nervosul": "nervos",
    "nervosului": "nervos",
    "nervozitatea": "nervozitate",
    "nervozități": "nervozitate",
    "nervozității": "nervozitate",
    "nervozitățile": "nervozitate",
    "nervozităților": "nervozitate",
    "nervura": "nervură",
    "nervuri": "nervură",
    "nervurii": "nervură",
    "nervurile": "nervură",
    "nervurilor": "nervură",
    "nervurata": "nervurat",
    "nervurată": "nervurat",
    "nervurate": "nervurat",
    "nervuratei": "nervurat",
    "nervuratele": "nervurat",
    "nervuratelor": "nervurat",
    "nervurați": "nervurat",
    "nervurații": "nervurat",
    "nervuraților": "nervurat",
    "nervuratul": "nervurat",
    "nervuratului": "nervurat",
    "nesablată": "nesablat",
    "nesablate": "nesablat",
    "nesablați": "nesablat",
    "neșablonată": "neșablonat",
    "neșablonate": "neșablonat",
    "neșablonați": "neșablonat",
    "nesabordată": "nesabordat",
    "nesabordate": "nesabordat",
    "nesabordați": "nesabordat",
    "nesabotată": "nesabotat",
    "nesabotate": "nesabotat",
    "nesabotați": "nesabotat",
    "nesăbuința": "nesăbuință",
    "nesăbuințe": "nesăbuință",
    "nesăbuinței": "nesăbuință",
    "nesăbuita": "nesăbuit",
    "nesăbuită": "nesăbuit",
    "nesăbuite": "nesăbuit",
    "nesăbuitei": "nesăbuit",
    "nesăbuitele": "nesăbuit",
    "nesăbuitelor": "nesăbuit",
    "nesăbuiți": "nesăbuit",
    "nesăbuiții": "nesăbuit",
    "nesăbuiților": "nesăbuit",
    "nesăbuitul": "nesăbuit",
    "nesăbuitului": "nesăbuit",
    "nesacadata": "nesacadat",
    "nesacadată": "nesacadat",
    "nesacadate": "nesacadat",
    "nesacadatei": "nesacadat",
    "nesacadatele": "nesacadat",
    "nesacadatelor": "nesacadat",
    "nesacadați": "nesacadat",
    "nesacadații": "nesacadat",
    "nesacadaților": "nesacadat",
    "nesacadatul": "nesacadat",
    "nesacadatului": "nesacadat",
    "nesâcâită": "nesâcâit",
    "nesâcâite": "nesâcâit",
    "nesâcâiți": "nesâcâit",
    "nesacrificată": "nesacrificat",
    "nesacrificate": "nesacrificat",
    "nesacrificați": "nesacrificat",
    "nesădită": "nesădit",
    "nesădite": "nesădit",
    "nesădiți": "nesădit",
    "nesăgetată": "nesăgetat",
    "nesăgetate": "nesăgetat",
    "nesăgetați": "nesăgetat",
    "neșagrinată": "neșagrinat",
    "neșagrinate": "neșagrinat",
    "neșagrinați": "neșagrinat",
    "nesalahorită": "nesalahorit",
    "nesalahorite": "nesalahorit",
    "nesalahoriți": "nesalahorit",
    "nesalariata": "nesalariat",
    "nesalariată": "nesalariat",
    "nesalariate": "nesalariat",
    "nesalariatei": "nesalariat",
    "nesalariatele": "nesalariat",
    "nesalariatelor": "nesalariat",
    "nesalariați": "nesalariat",
    "nesalariații": "nesalariat",
    "nesalariaților": "nesalariat",
    "nesalariatul": "nesalariat",
    "nesalariatului": "nesalariat",
    "nesalarizată": "nesalarizat",
    "nesalarizate": "nesalarizat",
    "nesalarizați": "nesalarizat",
    "nesălășluită": "nesălășluit",
    "nesălășluite": "nesălășluit",
    "nesălășluiți": "nesălășluit",
    "nesălbăticită": "nesălbăticit",
    "nesălbăticite": "nesălbăticit",
    "nesălbăticiți": "nesălbăticit",
    "nesalivată": "nesalivat",
    "nesalivate": "nesalivat",
    "nesalivați": "nesalivat",
    "nesăltata": "nesăltat",
    "nesăltată": "nesăltat",
    "nesăltate": "nesăltat",
    "nesăltatei": "nesăltat",
    "nesăltatele": "nesăltat",
    "nesăltatelor": "nesăltat",
    "nesăltați": "nesăltat",
    "nesăltații": "nesăltat",
    "nesăltaților": "nesăltat",
    "nesăltatul": "nesăltat",
    "nesăltatului": "nesăltat",
    "nesalutată": "nesalutat",
    "nesalutate": "nesalutat",
    "nesalutați": "nesalutat",
    "nesalvaaților": "nesalvat",
    "nesalvata": "nesalvat",
    "nesalvată": "nesalvat",
    "nesalvate": "nesalvat",
    "nesalvatei": "nesalvat",
    "nesalvatele": "nesalvat",
    "nesalvatelor": "nesalvat",
    "nesalvați": "nesalvat",
    "nesalvații": "nesalvat",
    "nesalvatul": "nesalvat",
    "nesalvatului": "nesalvat",
    "neșampanizată": "neșampanizat",
    "neșampanizate": "neșampanizat",
    "neșampanizați": "neșampanizat",
    "nesănătoasa": "nesănătos",
    "nesănătoasă": "nesănătos",
    "nesănătoase": "nesănătos",
    "nesănătoasei": "nesănătos",
    "nesănătoasele": "nesănătos",
    "nesănătoaselor": "nesănătos",
    "nesănătoși": "nesănătos",
    "nesănătoșii": "nesănătos",
    "nesănătoșilor": "nesănătos",
    "nesănătosul": "nesănătos",
    "nesănătosului": "nesănătos",
    "nesanctificată": "nesanctificat",
    "nesanctificate": "nesanctificat",
    "nesanctificați": "nesanctificat",
    "nesancționată": "nesancționat",
    "nesancționate": "nesancționat",
    "nesancționați": "nesancționat",
    "nesângerată": "nesângerat",
    "nesângerate": "nesângerat",
    "nesângerați": "nesângerat",
    "neșansa": "neșansă",
    "neșanse": "neșansă",
    "neșansei": "neșansă",
    "neșansele": "neșansă",
    "neșanselor": "neșansă",
    "neșantajată": "neșantajat",
    "neșantajate": "neșantajat",
    "neșantajați": "neșantajat",
    "nesăpată": "nesăpat",
    "nesăpate": "nesăpat",
    "nesăpați": "nesăpat",
    "nesăpunită": "nesăpunit",
    "nesăpunite": "nesăpunit",
    "nesăpuniți": "nesăpunit",
    "nesărăcită": "nesărăcit",
    "nesărăcite": "nesărăcit",
    "nesărăciți": "nesărăcit",
    "nesaramurată": "nesaramurat",
    "nesaramurate": "nesaramurat",
    "nesaramurați": "nesaramurat",
    "nesărata": "nesărat",
    "nesărată": "nesărat",
    "nesărate": "nesărat",
    "nesăratei": "nesărat",
    "nesăratele": "nesărat",
    "nesăratelor": "nesărat",
    "nesărați": "nesărat",
    "nesărații": "nesărat",
    "nesăraților": "nesărat",
    "nesăratul": "nesărat",
    "nesăratului": "nesărat",
    "nesărbătorită": "nesărbătorit",
    "nesărbătorite": "nesărbătorit",
    "nesărbătoriți": "nesărbătorit",
    "nesârguită": "nesârguit",
    "nesârguite": "nesârguit",
    "nesârguiți": "nesârguit",
    "nesărită": "nesărit",
    "nesărite": "nesărit",
    "nesăriți": "nesărit",
    "neșarjată": "neșarjat",
    "neșarjate": "neșarjat",
    "neșarjați": "neșarjat",
    "nesărutată": "nesărutat",
    "nesărutate": "nesărutat",
    "nesărutați": "nesărutat",
    "nesâsâită": "nesâsâit",
    "nesâsâite": "nesâsâit",
    "nesâsâiți": "nesâsâit",
    "nesațul": "nesaț",
    "nesațului": "nesaț",
    "nesatinată": "nesatinat",
    "nesatinate": "nesatinat",
    "nesatinați": "nesatinat",
    "nesățioasa": "nesățios",
    "nesățioasă": "nesățios",
    "nesățioase": "nesățios",
    "nesățioasei": "nesățios",
    "nesățioasele": "nesățios",
    "nesățioaselor": "nesățios",
    "nesățioși": "nesățios",
    "nesățioșii": "nesățios",
    "nesățioșilor": "nesățios",
    "nesățiosul": "nesățios",
    "nesățiosului": "nesățios",
    "nesatirizată": "nesatirizat",
    "nesatirizate": "nesatirizat",
    "nesatirizați": "nesatirizat",
    "nesatisfăcătoare": "nesatisfăcător",
    "nesatisfăcătoarea": "nesatisfăcător",
    "nesatisfăcătoarei": "nesatisfăcător",
    "nesatisfăcătoarele": "nesatisfăcător",
    "nesatisfăcătoarelor": "nesatisfăcător",
    "nesatisfăcători": "nesatisfăcător",
    "nesatisfăcătorii": "nesatisfăcător",
    "nesatisfăcătorilor": "nesatisfăcător",
    "nesatisfăcătorul": "nesatisfăcător",
    "nesatisfăcătorului": "nesatisfăcător",
    "nesatisfăcută": "nesatisfăcut",
    "nesatisfăcute": "nesatisfăcut",
    "nesatisfăcuți": "nesatisfăcut",
    "nesătui": "nesătul",
    "nesătuii": "nesătul",
    "nesătuilor": "nesătul",
    "nesătula": "nesătul",
    "nesătulă": "nesătul",
    "nesătule": "nesătul",
    "nesătulei": "nesătul",
    "nesătulele": "nesătul",
    "nesătulelor": "nesătul",
    "nesătulul": "nesătul",
    "nesătulului": "nesătul",
    "nesaturata": "nesaturat",
    "nesaturată": "nesaturat",
    "nesaturate": "nesaturat",
    "nesaturatei": "nesaturat",
    "nesaturatele": "nesaturat",
    "nesaturatelor": "nesaturat",
    "nesaturați": "nesaturat",
    "nesaturații": "nesaturat",
    "nesaturaților": "nesaturat",
    "nesaturatul": "nesaturat",
    "nesaturatului": "nesaturat",
    "nesăturată": "nesăturat",
    "nesăturate": "nesăturat",
    "nesăturați": "nesăturat",
    "nesăvârșită": "nesăvârșit",
    "nesăvârșite": "nesăvârșit",
    "nesăvârșiți": "nesăvârșit",
    "nesavurată": "nesavurat",
    "nesavurate": "nesavurat",
    "nesavurați": "nesavurat",
    "nescălâmbăiată": "nescălâmbăiat",
    "nescălâmbăiate": "nescălâmbăiat",
    "nescălâmbăiați": "nescălâmbăiat",
    "nescăldată": "nescăldat",
    "nescăldate": "nescăldat",
    "nescăldați": "nescăldat",
    "nescalpată": "nescalpat",
    "nescalpate": "nescalpat",
    "nescalpați": "nescalpat",
    "nescămoșată": "nescămoșat",
    "nescămoșate": "nescămoșat",
    "nescămoșați": "nescămoșat",
    "nescâncită": "nescâncit",
    "nescâncite": "nescâncit",
    "nescânciți": "nescâncit",
    "nescandalizata": "nescandalizat",
    "nescandalizată": "nescandalizat",
    "nescandalizate": "nescandalizat",
    "nescandalizatei": "nescandalizat",
    "nescandalizatele": "nescandalizat",
    "nescandalizatelor": "nescandalizat",
    "nescandalizați": "nescandalizat",
    "nescandalizații": "nescandalizat",
    "nescandalizaților": "nescandalizat",
    "nescandalizatul": "nescandalizat",
    "nescandalizatului": "nescandalizat",
    "nescandată": "nescandat",
    "nescandate": "nescandat",
    "nescandați": "nescandat",
    "nescânteiată": "nescânteiat",
    "nescânteiate": "nescânteiat",
    "nescânteiați": "nescânteiat",
    "nescăpărată": "nescăpărat",
    "nescăpărate": "nescăpărat",
    "nescăpărați": "nescăpărat",
    "nescăpată": "nescăpat",
    "nescăpate": "nescăpat",
    "nescăpați": "nescăpat",
    "nescăpătată": "nescăpătat",
    "nescăpătate": "nescăpătat",
    "nescăpătați": "nescăpătat",
    "nescârbită": "nescârbit",
    "nescârbite": "nescârbit",
    "nescârbiți": "nescârbit",
    "nescărmănată": "nescărmănat",
    "nescărmănate": "nescărmănat",
    "nescărmănați": "nescărmănat",
    "nescârnăvită": "nescârnăvit",
    "nescârnăvite": "nescârnăvit",
    "nescârnăviți": "nescârnăvit",
    "nescărpinata": "nescărpinat",
    "nescărpinată": "nescărpinat",
    "nescărpinate": "nescărpinat",
    "nescărpinatei": "nescărpinat",
    "nescărpinatele": "nescărpinat",
    "nescărpinatelor": "nescărpinat",
    "nescărpinați": "nescărpinat",
    "nescărpinații": "nescărpinat",
    "nescărpinaților": "nescărpinat",
    "nescărpinatul": "nescărpinat",
    "nescărpinatului": "nescărpinat",
    "nescârțâită": "nescârțâit",
    "nescârțâite": "nescârțâit",
    "nescârțâiți": "nescârțâit",
    "nescăzută": "nescăzut",
    "nescăzute": "nescăzut",
    "nescăzuți": "nescăzut",
    "nescheunată": "nescheunat",
    "nescheunate": "nescheunat",
    "nescheunați": "nescheunat",
    "neschiată": "neschiat",
    "neschiate": "neschiat",
    "neschiați": "neschiat",
    "neschilodită": "neschilodit",
    "neschilodite": "neschilodit",
    "neschilodiți": "neschilodit",
    "neschimbarea": "neschimbare",
    "neschimbari": "neschimbare",
    "neschimbarii": "neschimbare",
    "neschimbarile": "neschimbare",
    "neschimbarilor": "neschimbare",
    "neschimbata": "neschimbat",
    "neschimbată": "neschimbat",
    "neschimbate": "neschimbat",
    "neschimbatei": "neschimbat",
    "neschimbatele": "neschimbat",
    "neschimbatelor": "neschimbat",
    "neschimbați": "neschimbat",
    "neschimbații": "neschimbat",
    "neschimbaților": "neschimbat",
    "neschimbatul": "neschimbat",
    "neschimbatului": "neschimbat",
    "neschimbătoare": "neschimbător",
    "neschimbătoarea": "neschimbător",
    "neschimbătoarei": "neschimbător",
    "neschimbătoarele": "neschimbător",
    "neschimbătoarelor": "neschimbător",
    "neschimbători": "neschimbător",
    "neschimbătorii": "neschimbător",
    "neschimbătorilor": "neschimbător",
    "neschimbătorul": "neschimbător",
    "neschimbătorului": "neschimbător",
    "neschimonosita": "neschimonosit",
    "neschimonosită": "neschimonosit",
    "neschimonosite": "neschimonosit",
    "neschimonositei": "neschimonosit",
    "neschimonositele": "neschimonosit",
    "neschimonositelor": "neschimonosit",
    "neschimonosiți": "neschimonosit",
    "neschimonosiții": "neschimonosit",
    "neschimonosiților": "neschimonosit",
    "neschimonositul": "neschimonosit",
    "neschimonositului": "neschimonosit",
    "neschingiuită": "neschingiuit",
    "neschingiuite": "neschingiuit",
    "neschingiuiți": "neschingiuit",
    "neșchiopată": "neșchiopat",
    "neșchiopate": "neșchiopat",
    "neșchiopați": "neșchiopat",
    "neșchiopătată": "neșchiopătat",
    "neșchiopătate": "neșchiopătat",
    "neșchiopătați": "neșchiopătat",
    "neschițată": "neschițat",
    "neschițate": "neschițat",
    "neschițați": "neschițat",
    "nescindată": "nescindat",
    "nescindate": "nescindat",
    "nescindați": "nescindat",
    "nescizionată": "nescizionat",
    "nescizionate": "nescizionat",
    "nescizionați": "nescizionat",
    "nesclerozată": "nesclerozat",
    "nesclerozate": "nesclerozat",
    "nesclerozați": "nesclerozat",
    "nesclifosită": "nesclifosit",
    "nesclifosite": "nesclifosit",
    "nesclifosiți": "nesclifosit",
    "nesclipită": "nesclipit",
    "nesclipite": "nesclipit",
    "nesclipiți": "nesclipit",
    "nescoasă": "nesclipit",
    "nescoase": "nesclipit",
    "nescobită": "nescobit",
    "nescobite": "nescobit",
    "nescobiți": "nescobit",
    "nescofâlcită": "nescofâlcit",
    "nescofâlcite": "nescofâlcit",
    "nescofâlciți": "nescofâlcit",
    "neșcolărită": "neșcolărit",
    "neșcolărite": "neșcolărit",
    "neșcolăriți": "neșcolărit",
    "neșcolarizată": "neșcolarizat",
    "neșcolarizate": "neșcolarizat",
    "neșcolarizați": "neșcolarizat",
    "nescontată": "nescontat",
    "nescontate": "nescontat",
    "nescontați": "nescontat",
    "nescormonită": "nescormonit",
    "nescormonite": "nescormonit",
    "nescormoniți": "nescormonit",
    "nescornită": "nescornit",
    "nescornite": "nescornit",
    "nescorniți": "nescornit",
    "nescorojită": "nescorojit",
    "nescorojite": "nescorojit",
    "nescorojiți": "nescorojit",
    "nescoși": "nescos",
    "nescotocită": "nescotocit",
    "nescotocite": "nescotocit",
    "nescotociți": "nescotocit",
    "nescrântită": "nescrântit",
    "nescrântite": "nescrântit",
    "nescrântiți": "nescrântit",
    "nescrâșnita": "nescrâșnit",
    "nescrâșnită": "nescrâșnit",
    "nescrâșnite": "nescrâșnit",
    "nescrâșnitei": "nescrâșnit",
    "nescrâșnitele": "nescrâșnit",
    "nescrâșnitelor": "nescrâșnit",
    "nescrâșniți": "nescrâșnit",
    "nescrâșniții": "nescrâșnit",
    "nescrâșniților": "nescrâșnit",
    "nescrâșnitul": "nescrâșnit",
    "nescrâșnitului": "nescrâșnit",
    "nescrijelita": "nescrijelit",
    "nescrijelită": "nescrijelit",
    "nescrijelite": "nescrijelit",
    "nescrijelitei": "nescrijelit",
    "nescrijelitele": "nescrijelit",
    "nescrijelitelor": "nescrijelit",
    "nescrijeliți": "nescrijelit",
    "nescrijeliții": "nescrijelit",
    "nescrijeliților": "nescrijelit",
    "nescrijelitul": "nescrijelit",
    "nescrijelitului": "nescrijelit",
    "nescriptica": "nescriptic",
    "nescriptică": "nescriptic",
    "nescriptice": "nescriptic",
    "nescripticei": "nescriptic",
    "nescripticele": "nescriptic",
    "nescripticelor": "nescriptic",
    "nescriptici": "nescriptic",
    "nescripticii": "nescriptic",
    "nescripticilor": "nescriptic",
    "nescripticul": "nescriptic",
    "nescripticului": "nescriptic",
    "nescrisa": "nescris",
    "nescrisă": "nescris",
    "nescrise": "nescris",
    "nescrisei": "nescris",
    "nescrisele": "nescris",
    "nescriselor": "nescris",
    "nescrisi": "nescris",
    "nescriși": "nescris",
    "nescrisii": "nescris",
    "nescrisilor": "nescris",
    "nescrisul": "nescris",
    "nescrisului": "nescris",
    "nescrobită": "nescrobit",
    "nescrobite": "nescrobit",
    "nescrobiți": "nescrobit",
    "nescrutată": "nescrutat",
    "nescrutate": "nescrutat",
    "nescrutați": "nescrutat",
    "nescufundata": "nescufundat",
    "nescufundată": "nescufundat",
    "nescufundate": "nescufundat",
    "nescufundatei": "nescufundat",
    "nescufundatele": "nescufundat",
    "nescufundatelor": "nescufundat",
    "nescufundați": "nescufundat",
    "nescufundații": "nescufundat",
    "nescufundaților": "nescufundat",
    "nescufundatul": "nescufundat",
    "nescufundatului": "nescufundat",
    "nescuipata": "nescuipat",
    "nescuipată": "nescuipat",
    "nescuipate": "nescuipat",
    "nescuipatei": "nescuipat",
    "nescuipatele": "nescuipat",
    "nescuipatelor": "nescuipat",
    "nescuipați": "nescuipat",
    "nescuipații": "nescuipat",
    "nescuipaților": "nescuipat",
    "nescuipatul": "nescuipat",
    "nescuipatului": "nescuipat",
    "nesculata": "nesculat",
    "nesculată": "nesculat",
    "nesculate": "nesculat",
    "nesculatei": "nesculat",
    "nesculatele": "nesculat",
    "nesculatelor": "nesculat",
    "nesculați": "nesculat",
    "nesculații": "nesculat",
    "nesculaților": "nesculat",
    "nesculatul": "nesculat",
    "nesculatului": "nesculat",
    "nesculptată": "nesculptat",
    "nesculptate": "nesculptat",
    "nesculptați": "nesculptat",
    "nescumpită": "nescumpit",
    "nescumpite": "nescumpit",
    "nescumpiți": "nescumpit",
    "nescurmată": "nescurmat",
    "nescurmate": "nescurmat",
    "nescurmați": "nescurmat",
    "nescursă": "nescurs",
    "nescurse": "nescurs",
    "nescurși": "nescurs",
    "nescurtată": "nescurtat",
    "nescurtate": "nescurtat",
    "nescurtați": "nescurtat",
    "nescutită": "nescutit",
    "nescutite": "nescutit",
    "nescutiți": "nescutit",
    "nescuturata": "nescuturat",
    "nescuturată": "nescuturat",
    "nescuturate": "nescuturat",
    "nescuturatei": "nescuturat",
    "nescuturatele": "nescuturat",
    "nescuturatelor": "nescuturat",
    "nescuturați": "nescuturat",
    "nescuturații": "nescuturat",
    "nescuturaților": "nescuturat",
    "nescuturatul": "nescuturat",
    "nescuturatului": "nescuturat",
    "nescuzabila": "nescuzabil",
    "nescuzabilă": "nescuzabil",
    "nescuzabile": "nescuzabil",
    "nescuzabilei": "nescuzabil",
    "nescuzabilele": "nescuzabil",
    "nescuzabilelor": "nescuzabil",
    "nescuzabili": "nescuzabil",
    "nescuzabilii": "nescuzabil",
    "nescuzabililor": "nescuzabil",
    "nescuzabilul": "nescuzabil",
    "nescuzabilului": "nescuzabil",
    "nescuzată": "nescuzat",
    "nescuzate": "nescuzat",
    "nescuzați": "nescuzat",
    "nesecata": "nesecat",
    "nesecată": "nesecat",
    "nesecate": "nesecat",
    "nesecatei": "nesecat",
    "nesecatele": "nesecat",
    "nesecatelor": "nesecat",
    "nesecați": "nesecat",
    "nesecații": "nesecat",
    "nesecaților": "nesecat",
    "nesecatul": "nesecat",
    "nesecatului": "nesecat",
    "nesecătuita": "nesecătuit",
    "nesecătuită": "nesecătuit",
    "nesecătuite": "nesecătuit",
    "nesecătuitei": "nesecătuit",
    "nesecătuitele": "nesecătuit",
    "nesecătuitelor": "nesecătuit",
    "nesecătuiți": "nesecătuit",
    "nesecătuiții": "nesecătuit",
    "nesecătuiților": "nesecătuit",
    "nesecătuitul": "nesecătuit",
    "nesecătuitului": "nesecătuit",
    "nesecerată": "nesecerat",
    "nesecerate": "nesecerat",
    "nesecerați": "nesecerat",
    "nesechestrată": "nesechestrat",
    "nesechestrate": "nesechestrat",
    "nesechestrați": "nesechestrat",
    "nesecretată": "nesecretat",
    "nesecretate": "nesecretat",
    "nesecretați": "nesecretat",
    "nesecționată": "nesecționat",
    "nesecționate": "nesecționat",
    "nesecționați": "nesecționat",
    "nesecularizată": "nesecularizat",
    "nesecularizate": "nesecularizat",
    "nesecularizați": "nesecularizat",
    "nesecundată": "nesecundat",
    "nesecundate": "nesecundat",
    "nesecundați": "nesecundat",
    "nesedimentată": "nesedimentat",
    "nesedimentate": "nesedimentat",
    "nesedimentați": "nesedimentat",
    "nesedusă": "nesedus",
    "neseduse": "nesedus",
    "neseduși": "nesedus",
    "nesegmentată": "nesegmentat",
    "nesegmentate": "nesegmentat",
    "nesegmentați": "nesegmentat",
    "neselectată": "neselectat",
    "neselectate": "neselectat",
    "neselectați": "neselectat",
    "neselecționata": "neselecționat",
    "neselecționată": "neselecționat",
    "neselecționate": "neselecționat",
    "neselecționatei": "neselecționat",
    "neselecționatele": "neselecționat",
    "neselecționatelor": "neselecționat",
    "neselecționați": "neselecționat",
    "neselecționații": "neselecționat",
    "neselecționaților": "neselecționat",
    "neselecționatul": "neselecționat",
    "neselecționatului": "neselecționat",
    "nesemănată": "nesemănat",
    "nesemănate": "nesemănat",
    "nesemănați": "nesemănat",
    "nesemețită": "nesemețit",
    "nesemețite": "nesemețit",
    "nesemețiți": "nesemețit",
    "nesemnalată": "nesemnalat",
    "nesemnalate": "nesemnalat",
    "nesemnalați": "nesemnalat",
    "nesemnalizată": "nesemnalizat",
    "nesemnalizate": "nesemnalizat",
    "nesemnalizați": "nesemnalizat",
    "nesemnată": "nesemnat",
    "nesemnate": "nesemnat",
    "nesemnați": "nesemnat",
    "nesemnificativa": "nesemnificativ",
    "nesemnificativă": "nesemnificativ",
    "nesemnificative": "nesemnificativ",
    "nesemnificativei": "nesemnificativ",
    "nesemnificativele": "nesemnificativ",
    "nesemnificativelor": "nesemnificativ",
    "nesemnificativi": "nesemnificativ",
    "nesemnificativii": "nesemnificativ",
    "nesemnificativilor": "nesemnificativ",
    "nesemnificativul": "nesemnificativ",
    "nesemnificativului": "nesemnificativ",
    "nesensibilizată": "nesensibilizat",
    "nesensibilizate": "nesensibilizat",
    "nesensibilizați": "nesensibilizat",
    "neseparata": "neseparat",
    "neseparată": "neseparat",
    "neseparate": "neseparat",
    "neseparatei": "neseparat",
    "neseparatele": "neseparat",
    "neseparatelor": "neseparat",
    "neseparați": "neseparat",
    "neseparații": "neseparat",
    "neseparaților": "neseparat",
    "neseparatul": "neseparat",
    "neseparatului": "neseparat",
    "neserbată": "neserbat",
    "neserbate": "neserbat",
    "neserbați": "neserbat",
    "neseriată": "neseriat",
    "neseriate": "neseriat",
    "neseriați": "neseriat",
    "neserioasa": "neserios",
    "neserioasă": "neserios",
    "neserioase": "neserios",
    "neserioasei": "neserios",
    "neserioasele": "neserios",
    "neserioaselor": "neserios",
    "neserioși": "neserios",
    "neserioșii": "neserios",
    "neserioșilor": "neserios",
    "neseriosul": "neserios",
    "neseriosului": "neserios",
    "neșerpuită": "neșerpuit",
    "neșerpuite": "neșerpuit",
    "neșerpuiți": "neșerpuit",
    "neservită": "neservit",
    "neservite": "neservit",
    "neserviți": "neservit",
    "nesesizată": "nesesizat",
    "nesesizate": "nesesizat",
    "nesesizați": "nesesizat",
    "neșezută": "neșezut",
    "neșezute": "neșezut",
    "neșezuți": "neșezut",
    "nesfădită": "nesfădit",
    "nesfădite": "nesfădit",
    "nesfădiți": "nesfădit",
    "nesfârâită": "nesfârâit",
    "nesfârâite": "nesfârâit",
    "nesfârâiți": "nesfârâit",
    "nesfărâmată": "nesfărâmat",
    "nesfărâmate": "nesfărâmat",
    "nesfărâmați": "nesfărâmat",
    "nesfărmată": "nesfărmat",
    "nesfărmate": "nesfărmat",
    "nesfărmați": "nesfărmat",
    "nesfârșita": "nesfârșit",
    "nesfârșită": "nesfârșit",
    "nesfârșite": "nesfârșit",
    "nesfârșitei": "nesfârșit",
    "nesfârșitele": "nesfârșit",
    "nesfârșitelor": "nesfârșit",
    "nesfârșiți": "nesfârșit",
    "nesfârșiții": "nesfârșit",
    "nesfârșiților": "nesfârșit",
    "nesfârșitul": "nesfârșit",
    "nesfârșitului": "nesfârșit",
    "nesfârtecată": "nesfârtecat",
    "nesfârtecate": "nesfârtecat",
    "nesfârtecați": "nesfârtecat",
    "nesfârticată": "nesfârticat",
    "nesfârticate": "nesfârticat",
    "nesfârticați": "nesfârticat",
    "nesfâșiata": "nesfâșiat",
    "nesfâșiată": "nesfâșiat",
    "nesfâșiate": "nesfâșiat",
    "nesfâșiatei": "nesfâșiat",
    "nesfâșiatele": "nesfâșiat",
    "nesfâșiatelor": "nesfâșiat",
    "nesfâșiați": "nesfâșiat",
    "nesfâșiații": "nesfâșiat",
    "nesfâșiaților": "nesfâșiat",
    "nesfâșiatul": "nesfâșiat",
    "nesfâșiatului": "nesfâșiat",
    "nesfătuită": "nesfătuit",
    "nesfătuite": "nesfătuit",
    "nesfătuiți": "nesfătuit",
    "nesfeclită": "nesfeclit",
    "nesfeclite": "nesfeclit",
    "nesfecliți": "nesfeclit",
    "nesfetită": "nesfetit",
    "nesfetite": "nesfetit",
    "nesfetiți": "nesfetit",
    "neșfichiuită": "neșfichiuit",
    "neșfichiuite": "neșfichiuit",
    "neșfichiuiți": "neșfichiuit",
    "nesfidată": "nesfidat",
    "nesfidate": "nesfidat",
    "nesfidați": "nesfidat",
    "nesfielnica": "nesfielnic",
    "nesfielnică": "nesfielnic",
    "nesfielnice": "nesfielnic",
    "nesfielnicei": "nesfielnic",
    "nesfielnicele": "nesfielnic",
    "nesfielnicelor": "nesfielnic",
    "nesfielnici": "nesfielnic",
    "nesfielnicii": "nesfielnic",
    "nesfielnicilor": "nesfielnic",
    "nesfielnicul": "nesfielnic",
    "nesfielnicului": "nesfielnic",
    "nesfiită": "nesfiit",
    "nesfiite": "nesfiit",
    "nesfiiți": "nesfiit",
    "nesfințită": "nesfințit",
    "nesfințite": "nesfințit",
    "nesfințiți": "nesfințit",
    "nesfoiegita": "nesfoiegit",
    "nesfoiegită": "nesfoiegit",
    "nesfoiegite": "nesfoiegit",
    "nesfoiegitei": "nesfoiegit",
    "nesfoiegitele": "nesfoiegit",
    "nesfoiegitelor": "nesfoiegit",
    "nesfoiegiți": "nesfoiegit",
    "nesfoiegiții": "nesfoiegit",
    "nesfoiegiților": "nesfoiegit",
    "nesfoiegitul": "nesfoiegit",
    "nesfoiegitului": "nesfoiegit",
    "nesforăită": "nesforăit",
    "nesforăite": "nesforăit",
    "nesforăiți": "nesforăit",
    "nesforțată": "nesforțat",
    "nesforțate": "nesforțat",
    "nesforțați": "nesforțat",
    "nesfredelită": "nesfredelit",
    "nesfredelite": "nesfredelit",
    "nesfredeliți": "nesfredelit",
    "nesfrijită": "nesfrijit",
    "nesfrijite": "nesfrijit",
    "nesfrijiți": "nesfrijit",
    "nesfruntată": "nesfruntat",
    "nesfruntate": "nesfruntat",
    "nesfruntați": "nesfruntat",
    "neșicanata": "neșicanat",
    "neșicanată": "neșicanat",
    "neșicanate": "neșicanat",
    "neșicanatei": "neșicanat",
    "neșicanatele": "neșicanat",
    "neșicanatelor": "neșicanat",
    "neșicanați": "neșicanat",
    "neșicanații": "neșicanat",
    "neșicanaților": "neșicanat",
    "neșicanatul": "neșicanat",
    "neșicanatului": "neșicanat",
    "nesictirită": "nesictirit",
    "nesictirite": "nesictirit",
    "nesictiriți": "nesictirit",
    "neșifonabila": "neșifonabil",
    "neșifonabilă": "neșifonabil",
    "neșifonabile": "neșifonabil",
    "neșifonabilei": "neșifonabil",
    "neșifonabilele": "neșifonabil",
    "neșifonabilelor": "neșifonabil",
    "neșifonabili": "neșifonabil",
    "neșifonabilii": "neșifonabil",
    "neșifonabililor": "neșifonabil",
    "neșifonabilul": "neșifonabil",
    "neșifonabilului": "neșifonabil",
    "neșifonata": "neșifonat",
    "neșifonată": "neșifonat",
    "neșifonate": "neșifonat",
    "neșifonatei": "neșifonat",
    "neșifonatele": "neșifonat",
    "neșifonatelor": "neșifonat",
    "neșifonați": "neșifonat",
    "neșifonații": "neșifonat",
    "neșifonaților": "neșifonat",
    "neșifonatul": "neșifonat",
    "neșifonatului": "neșifonat",
    "nesigilata": "nesigilat",
    "nesigilată": "nesigilat",
    "nesigilate": "nesigilat",
    "nesigilatei": "nesigilat",
    "nesigilatele": "nesigilat",
    "nesigilatelor": "nesigilat",
    "nesigilați": "nesigilat",
    "nesigilații": "nesigilat",
    "nesigilaților": "nesigilat",
    "nesigilatul": "nesigilat",
    "nesigilatului": "nesigilat",
    "nesigura": "nesigur",
    "nesigură": "nesigur",
    "nesigure": "nesigur",
    "nesigurei": "nesigur",
    "nesigurele": "nesigur",
    "nesigurelor": "nesigur",
    "nesiguri": "nesigur",
    "nesigurii": "nesigur",
    "nesigurilor": "nesigur",
    "nesigurul": "nesigur",
    "nesigurului": "nesigur",
    "nesiguranța": "nesiguranță",
    "nesiguranțe": "nesiguranță",
    "nesiguranței": "nesiguranță",
    "nesiguranțele": "nesiguranță",
    "nesiguranțelor": "nesiguranță",
    "nesihăstrită": "nesihăstrit",
    "nesihăstrite": "nesihăstrit",
    "nesihăstriți": "nesihăstrit",
    "nesilabisită": "nesilabisit",
    "nesilabisite": "nesilabisit",
    "nesilabisiți": "nesilabisit",
    "nesilita": "nesilit",
    "nesilită": "nesilit",
    "nesilite": "nesilit",
    "nesilitei": "nesilit",
    "nesilitele": "nesilit",
    "nesilitelor": "nesilit",
    "nesiliți": "nesilit",
    "nesiliții": "nesilit",
    "nesiliților": "nesilit",
    "nesilitul": "nesilit",
    "nesilitului": "nesilit",
    "nesilnicită": "nesilnicit",
    "nesilnicite": "nesilnicit",
    "nesilniciți": "nesilnicit",
    "nesilogistica": "nesilogistic",
    "nesilogistică": "nesilogistic",
    "nesilogistice": "nesilogistic",
    "nesilogisticei": "nesilogistic",
    "nesilogisticele": "nesilogistic",
    "nesilogisticelor": "nesilogistic",
    "nesilogistici": "nesilogistic",
    "nesilogisticii": "nesilogistic",
    "nesilogisticilor": "nesilogistic",
    "nesilogisticul": "nesilogistic",
    "nesilogisticului": "nesilogistic",
    "nesiluită": "nesiluit",
    "nesiluite": "nesiluit",
    "nesiluiți": "nesiluit",
    "nesimbolizată": "nesimbolizat",
    "nesimbolizate": "nesimbolizat",
    "nesimbolizați": "nesimbolizat",
    "nesimpatizată": "nesimpatizat",
    "nesimpatizate": "nesimpatizat",
    "nesimpatizați": "nesimpatizat",
    "nesimplificată": "nesimplificat",
    "nesimplificate": "nesimplificat",
    "nesimplificați": "nesimplificat",
    "nesimțirea": "nesimțire",
    "nesimțiri": "nesimțire",
    "nesimțirii": "nesimțire",
    "nesimțirile": "nesimțire",
    "nesimțirilor": "nesimțire",
    "nesimțita": "nesimțit",
    "nesimțită": "nesimțit",
    "nesimțite": "nesimțit",
    "nesimțitei": "nesimțit",
    "nesimțitele": "nesimțit",
    "nesimțitelor": "nesimțit",
    "nesimțiți": "nesimțit",
    "nesimțiții": "nesimțit",
    "nesimțiților": "nesimțit",
    "nesimțitul": "nesimțit",
    "nesimțitului": "nesimțit",
    "nesimțitoare": "nesimțitor",
    "nesimțitoarea": "nesimțitor",
    "nesimțitoarei": "nesimțitor",
    "nesimțitoarele": "nesimțitor",
    "nesimțitoarelor": "nesimțitor",
    "nesimțitori": "nesimțitor",
    "nesimțitorii": "nesimțitor",
    "nesimțitorilor": "nesimțitor",
    "nesimțitorul": "nesimțitor",
    "nesimțitorului": "nesimțitor",
    "nesimulată": "nesimulat",
    "nesimulate": "nesimulat",
    "nesimulați": "nesimulat",
    "nesinchisită": "nesinchisit",
    "nesinchisite": "nesinchisit",
    "nesinchisiți": "nesinchisit",
    "nesincronizată": "nesincronizat",
    "nesincronizate": "nesincronizat",
    "nesincronizați": "nesincronizat",
    "nesindicalizată": "nesindicalizat",
    "nesindicalizate": "nesindicalizat",
    "nesindicalizați": "nesindicalizat",
    "neșindrilită": "neșindrilit",
    "neșindrilite": "neșindrilit",
    "neșindriliți": "neșindrilit",
    "neșindruita": "neșindruit",
    "neșindruită": "neșindruit",
    "neșindruite": "neșindruit",
    "neșindruitei": "neșindruit",
    "neșindruitele": "neșindruit",
    "neșindruitelor": "neșindruit",
    "neșindruiți": "neșindruit",
    "neșindruiții": "neșindruit",
    "neșindruiților": "neșindruit",
    "neșindruitul": "neșindruit",
    "neșindruitului": "neșindruit",
    "nesingularizată": "nesingularizat",
    "nesingularizate": "nesingularizat",
    "nesingularizați": "nesingularizat",
    "nesintetizată": "nesintetizat",
    "nesintetizate": "nesintetizat",
    "nesintetizați": "nesintetizat",
    "nesinucisă": "nesinucis",
    "nesinucise": "nesinucis",
    "nesinuciși": "nesinucis",
    "neșiroită": "neșiroit",
    "neșiroite": "neșiroit",
    "neșiroiți": "neșiroit",
    "nesistată": "nesistat",
    "nesistate": "nesistat",
    "nesistați": "nesistat",
    "nesistematizată": "nesistematizat",
    "nesistematizate": "nesistematizat",
    "nesistematizați": "nesistematizat",
    "nesituata": "nesituat",
    "nesituată": "nesituat",
    "nesituate": "nesituat",
    "nesituatei": "nesituat",
    "nesituatele": "nesituat",
    "nesituatelor": "nesituat",
    "nesituați": "nesituat",
    "nesituații": "nesituat",
    "nesituaților": "nesituat",
    "nesituatul": "nesituat",
    "nesituatului": "nesituat",
    "neslăbănogită": "neslăbănogit",
    "neslăbănogite": "neslăbănogit",
    "neslăbănogiți": "neslăbănogit",
    "neslăbita": "neslăbit",
    "neslăbită": "neslăbit",
    "neslăbite": "neslăbit",
    "neslăbitei": "neslăbit",
    "neslăbitele": "neslăbit",
    "neslăbitelor": "neslăbit",
    "neslăbiți": "neslăbit",
    "neslăbiții": "neslăbit",
    "neslăbiților": "neslăbit",
    "neslăbitul": "neslăbit",
    "neslăbitului": "neslăbit",
    "neslăvita": "neslăvit",
    "neslăvită": "neslăvit",
    "neslăvite": "neslăvit",
    "neslăvitei": "neslăvit",
    "neslăvitele": "neslăvit",
    "neslăvitelor": "neslăvit",
    "neslăviți": "neslăvit",
    "neslăviții": "neslăvit",
    "neslăviților": "neslăvit",
    "neslăvitul": "neslăvit",
    "neslăvitului": "neslăvit",
    "neslavizată": "neslavizat",
    "neslavizate": "neslavizat",
    "neslavizați": "neslavizat",
    "neșlefuită": "neșlefuit",
    "neșlefuite": "neșlefuit",
    "neșlefuiți": "neșlefuit",
    "nesleită": "nesleit",
    "nesleite": "nesleit",
    "nesleiți": "nesleit",
    "neslobozită": "neslobozit",
    "neslobozite": "neslobozit",
    "nesloboziți": "neslobozit",
    "neslugărită": "neslugărit",
    "neslugărite": "neslugărit",
    "neslugăriți": "neslugărit",
    "neslugărnicită": "neslugărnicit",
    "neslugărnicite": "neslugărnicit",
    "neslugărniciți": "neslugărnicit",
    "neslujită": "neslujit",
    "neslujite": "neslujit",
    "neslujiți": "neslujit",
    "nesluțită": "nesluțit",
    "nesluțite": "nesluțit",
    "nesluțiți": "nesluțit",
    "nesmălțuită": "nesmălțuit",
    "nesmălțuite": "nesmălțuit",
    "nesmălțuiți": "nesmălțuit",
    "nesmântânită": "nesmântânit",
    "nesmântânite": "nesmântânit",
    "nesmântâniți": "nesmântânit",
    "nesmârcâită": "nesmârcâit",
    "nesmârcâite": "nesmârcâit",
    "nesmârcâiți": "nesmârcâit",
    "neșmecherită": "neșmecherit",
    "neșmecherite": "neșmecherit",
    "neșmecheriți": "neșmecherit",
    "nesmerită": "nesmerit",
    "nesmerite": "nesmerit",
    "nesmeriți": "nesmerit",
    "nesmintita": "nesmintit",
    "nesmintită": "nesmintit",
    "nesmintite": "nesmintit",
    "nesmintitei": "nesmintit",
    "nesmintitele": "nesmintit",
    "nesmintitelor": "nesmintit",
    "nesmintiți": "nesmintit",
    "nesmintiții": "nesmintit",
    "nesmintiților": "nesmintit",
    "nesmintitul": "nesmintit",
    "nesmintitului": "nesmintit",
    "nesmiorcăita": "nesmiorcăit",
    "nesmiorcăită": "nesmiorcăit",
    "nesmiorcăite": "nesmiorcăit",
    "nesmiorcăitei": "nesmiorcăit",
    "nesmiorcăitele": "nesmiorcăit",
    "nesmiorcăitelor": "nesmiorcăit",
    "nesmiorcăiți": "nesmiorcăit",
    "nesmiorcăiții": "nesmiorcăit",
    "nesmiorcăiților": "nesmiorcăit",
    "nesmiorcăitul": "nesmiorcăit",
    "nesmiorcăitului": "nesmiorcăit",
    "nesmochinită": "nesmochinit",
    "nesmochinite": "nesmochinit",
    "nesmochiniți": "nesmochinit",
    "nesmolită": "nesmolit",
    "nesmolite": "nesmolit",
    "nesmoliți": "nesmolit",
    "neșmotrită": "neșmotrit",
    "neșmotrite": "neșmotrit",
    "neșmotriți": "neșmotrit",
    "nesmucita": "nesmucit",
    "nesmucită": "nesmucit",
    "nesmucite": "nesmucit",
    "nesmucitei": "nesmucit",
    "nesmucitele": "nesmucit",
    "nesmucitelor": "nesmucit",
    "nesmuciți": "nesmucit",
    "nesmuciții": "nesmucit",
    "nesmuciților": "nesmucit",
    "nesmucitul": "nesmucit",
    "nesmucitului": "nesmucit",
    "nesmulsă": "nesmuls",
    "nesmulse": "nesmuls",
    "nesmulși": "nesmuls",
    "nesnopită": "nesnopit",
    "nesnopite": "nesnopit",
    "nesnopiți": "nesnopit",
    "neșnuruita": "neșnuruit",
    "neșnuruită": "neșnuruit",
    "neșnuruite": "neșnuruit",
    "neșnuruitei": "neșnuruit",
    "neșnuruitele": "neșnuruit",
    "neșnuruitelor": "neșnuruit",
    "neșnuruiți": "neșnuruit",
    "neșnuruiții": "neșnuruit",
    "neșnuruiților": "neșnuruit",
    "neșnuruitul": "neșnuruit",
    "neșnuruitului": "neșnuruit",
    "neșocată": "neșocat",
    "neșocate": "neșocat",
    "neșocați": "neșocat",
    "nesociabila": "nesociabil",
    "nesociabilă": "nesociabil",
    "nesociabile": "nesociabil",
    "nesociabilei": "nesociabil",
    "nesociabilele": "nesociabil",
    "nesociabilelor": "nesociabil",
    "nesociabili": "nesociabil",
    "nesociabilii": "nesociabil",
    "nesociabililor": "nesociabil",
    "nesociabilul": "nesociabil",
    "nesociabilului": "nesociabil",
    "nesociabilitatea": "nesociabilitate",
    "nesociabilități": "nesociabilitate",
    "nesociabilității": "nesociabilitate",
    "nesociabilitățile": "nesociabilitate",
    "nesociabilităților": "nesociabilitate",
    "nesocializată": "nesocializat",
    "nesocializate": "nesocializat",
    "nesocializați": "nesocializat",
    "nemainesocotindu": "nesocoti",
    "nenesocotindu": "nesocoti",
    "nesocotea": "nesocoti",
    "nesocoteai": "nesocoti",
    "nesocoteam": "nesocoti",
    "nesocotească": "nesocoti",
    "nesocoteați": "nesocoti",
    "nesocoteau": "nesocoti",
    "nesocotesc": "nesocoti",
    "nesocotește": "nesocoti",
    "nesocotești": "nesocoti",
    "nesocotii": "nesocoti",
    "nesocotim": "nesocoti",
    "nesocotind": "nesocoti",
    "nesocotindu": "nesocoti",
    "nesocotiră": "nesocoti",
    "nesocotirăm": "nesocoti",
    "nesocotirăți": "nesocoti",
    "nesocotise": "nesocoti",
    "nesocotisem": "nesocoti",
    "nesocotiseră": "nesocoti",
    "nesocotiserăm": "nesocoti",
    "nesocotiserăți": "nesocoti",
    "nesocotiseși": "nesocoti",
    "nesocotiși": "nesocoti",
    "nesocotit": "nesocoti",
    "nesocotiți": "nesocoti",
    "nesocotința": "nesocotință",
    "nesocotințe": "nesocotință",
    "nesocotinței": "nesocotință",
    "nesocotințele": "nesocotință",
    "nesocotințelor": "nesocotință",
    "nesocotirea": "nesocotire",
    "nesocotiri": "nesocotire",
    "nesocotirii": "nesocotire",
    "nesocotirile": "nesocotire",
    "nesocotirilor": "nesocotire",
    "nesocotita": "nesocotit",
    "nesocotită": "nesocotit",
    "nesocotite": "nesocotit",
    "nesocotitei": "nesocotit",
    "nesocotitele": "nesocotit",
    "nesocotitelor": "nesocotit",
    "nesocotiți": "nesocotit",
    "nesocotiții": "nesocotit",
    "nesocotiților": "nesocotit",
    "nesocotitul": "nesocotit",
    "nesocotitului": "nesocotit",
    "nesodomită": "nesodomit",
    "nesodomite": "nesodomit",
    "nesodomiți": "nesodomit",
    "neșofată": "neșofat",
    "neșofate": "neșofat",
    "neșofați": "neșofat",
    "nesofisticata": "nesofisticat",
    "nesofisticată": "nesofisticat",
    "nesofisticate": "nesofisticat",
    "nesofisticatei": "nesofisticat",
    "nesofisticatele": "nesofisticat",
    "nesofisticatelor": "nesofisticat",
    "nesofisticați": "nesofisticat",
    "nesofisticații": "nesofisticat",
    "nesofisticaților": "nesofisticat",
    "nesofisticatul": "nesofisticat",
    "nesofisticatului": "nesofisticat",
    "nesoldată": "nesoldat",
    "nesoldate": "nesoldat",
    "nesoldați": "nesoldat",
    "nesolfegiată": "nesolfegiat",
    "nesolfegiate": "nesolfegiat",
    "nesolfegiați": "nesolfegiat",
    "nesolicitată": "nesolicitat",
    "nesolicitate": "nesolicitat",
    "nesolicitați": "nesolicitat",
    "nesolidarizată": "nesolidarizat",
    "nesolidarizate": "nesolidarizat",
    "nesolidarizați": "nesolidarizat",
    "nesolidificată": "nesolidificat",
    "nesolidificate": "nesolidificat",
    "nesolidificați": "nesolidificat",
    "nesolubilizată": "nesolubilizat",
    "nesolubilizate": "nesolubilizat",
    "nesolubilizați": "nesolubilizat",
    "nesoluționată": "nesoluționat",
    "nesoluționate": "nesoluționat",
    "nesoluționați": "nesoluționat",
    "nesolvită": "nesolvit",
    "nesolvite": "nesolvit",
    "nesolviți": "nesolvit",
    "nesomată": "nesomat",
    "nesomate": "nesomat",
    "nesomați": "nesomat",
    "neșomată": "neșomat",
    "neșomate": "neșomat",
    "neșomați": "neșomat",
    "nesomnul": "nesomn",
    "nesomnului": "nesomn",
    "nesondată": "nesondat",
    "nesondate": "nesondat",
    "nesondați": "nesondat",
    "nesonorizată": "nesonorizat",
    "nesonorizate": "nesonorizat",
    "nesonorizați": "nesonorizat",
    "neșopăită": "neșopăit",
    "neșopăite": "neșopăit",
    "neșopăiți": "neșopăit",
    "neșopotita": "neșopotit",
    "neșopotită": "neșopotit",
    "neșopotite": "neșopotit",
    "neșopotitei": "neșopotit",
    "neșopotitele": "neșopotit",
    "neșopotitelor": "neșopotit",
    "neșopotiți": "neșopotit",
    "neșopotiții": "neșopotit",
    "neșopotitul": "neșopotit",
    "neșopotitului": "neșopotit",
    "neșoptită": "neșoptit",
    "neșoptite": "neșoptit",
    "neșoptiți": "neșoptit",
    "nesorbită": "nesorbit",
    "nesorbite": "nesorbit",
    "nesorbiți": "nesorbit",
    "nesorcovită": "nesorcovit",
    "nesorcovite": "nesorcovit",
    "nesorcoviți": "nesorcovit",
    "nesorocita": "nesorocit",
    "nesorocită": "nesorocit",
    "nesorocite": "nesorocit",
    "nesorocitei": "nesorocit",
    "nesorocitele": "nesorocit",
    "nesorocitelor": "nesorocit",
    "nesorociți": "nesorocit",
    "nesorociții": "nesorocit",
    "nesorociților": "nesorocit",
    "nesorocitul": "nesorocit",
    "nesorocitului": "nesorocit",
    "nesortată": "nesortat",
    "nesortate": "nesortat",
    "nesortați": "nesortat",
    "nesortita": "nesortit",
    "nesortită": "nesortit",
    "nesortite": "nesortit",
    "nesortitei": "nesortit",
    "nesortitele": "nesortit",
    "nesortitelor": "nesortit",
    "nesortiți": "nesortit",
    "nesortiții": "nesortit",
    "nesortiților": "nesortit",
    "nesortitul": "nesortit",
    "nesortitului": "nesortit",
    "nesosita": "nesosit",
    "nesosită": "nesosit",
    "nesosite": "nesosit",
    "nesositei": "nesosit",
    "nesositele": "nesosit",
    "nesositelor": "nesosit",
    "nesosiți": "nesosit",
    "nesosiții": "nesosit",
    "nesositul": "nesosit",
    "nesositului": "nesosit",
    "neșovăita": "neșovăit",
    "neșovăită": "neșovăit",
    "neșovăite": "neșovăit",
    "neșovăitei": "neșovăit",
    "neșovăitele": "neșovăit",
    "neșovăitelor": "neșovăit",
    "neșovăiți": "neșovăit",
    "neșovăiții": "neșovăit",
    "neșovăitul": "neșovăit",
    "neșovăitului": "neșovăit",
    "nespălăcita": "nespălăcit",
    "nespălăcită": "nespălăcit",
    "nespălăcite": "nespălăcit",
    "nespălăcitei": "nespălăcit",
    "nespălăcitele": "nespălăcit",
    "nespălăcitelor": "nespălăcit",
    "nespălăciți": "nespălăcit",
    "nespălăciții": "nespălăcit",
    "nespălăciților": "nespălăcit",
    "nespălăcitul": "nespălăcit",
    "nespălăcitului": "nespălăcit",
    "nespălata": "nespălat",
    "nespălată": "nespălat",
    "nespălate": "nespălat",
    "nespălatei": "nespălat",
    "nespălatele": "nespălat",
    "nespălatelor": "nespălat",
    "nespălați": "nespălat",
    "nespălații": "nespălat",
    "nespălaților": "nespălat",
    "nespălatul": "nespălat",
    "nespălatului": "nespălat",
    "nespânzurata": "nespânzurat",
    "nespânzurată": "nespânzurat",
    "nespânzurate": "nespânzurat",
    "nespânzuratei": "nespânzurat",
    "nespânzurați": "nespânzurat",
    "nespânzurații": "nespânzurat",
    "nespânzuraților": "nespânzurat",
    "nespânzuratul": "nespânzurat",
    "nespânzuratului": "nespânzurat",
    "nespârcuită": "nespârcuit",
    "nespârcuite": "nespârcuit",
    "nespârcuiți": "nespârcuit",
    "nespartă": "nespart",
    "nesparte": "nespart",
    "nesparți": "nespart",
    "nespațiată": "nespațiat",
    "nespațiate": "nespațiat",
    "nespațiați": "nespațiat",
    "nespecializată": "nespecializat",
    "nespecializate": "nespecializat",
    "nespecializați": "nespecializat",
    "nespecifica": "nespecific",
    "nespecifică": "nespecific",
    "nespecifice": "nespecific",
    "nespecificei": "nespecific",
    "nespecificele": "nespecific",
    "nespecificelor": "nespecific",
    "nespecifici": "nespecific",
    "nespecificii": "nespecific",
    "nespecificilor": "nespecific",
    "nespecificată": "nespecificat",
    "nespecificate": "nespecificat",
    "nespecificați": "nespecificat",
    "nespectaculoasa": "nespectaculos",
    "nespectaculoasă": "nespectaculos",
    "nespectaculoase": "nespectaculos",
    "nespectaculoasei": "nespectaculos",
    "nespectaculoasele": "nespectaculos",
    "nespectaculoaselor": "nespectaculos",
    "nespectaculoși": "nespectaculos",
    "nespectaculoșii": "nespectaculos",
    "nespectaculoșilor": "nespectaculos",
    "nespectaculosul": "nespectaculos",
    "nespectaculosului": "nespectaculos",
    "nespeculată": "nespeculat",
    "nespeculate": "nespeculat",
    "nespeculați": "nespeculat",
    "nesperata": "nesperat",
    "nesperată": "nesperat",
    "nesperate": "nesperat",
    "nesperatei": "nesperat",
    "nesperatele": "nesperat",
    "nesperatelor": "nesperat",
    "nesperați": "nesperat",
    "nesperații": "nesperat",
    "nesperaților": "nesperat",
    "nesperatul": "nesperat",
    "nesperatului": "nesperat",
    "nesperiata": "nesperiat",
    "nesperiată": "nesperiat",
    "nesperiate": "nesperiat",
    "nesperiatei": "nesperiat",
    "nesperiatele": "nesperiat",
    "nesperiatelor": "nesperiat",
    "nesperiați": "nesperiat",
    "nesperiații": "nesperiat",
    "nesperiaților": "nesperiat",
    "nesperiatul": "nesperiat",
    "nesperiatului": "nesperiat",
    "neșperțuită": "neșperțuit",
    "neșperțuite": "neșperțuit",
    "neșperțuiți": "neșperțuit",
    "nespetită": "nespetit",
    "nespetite": "nespetit",
    "nespetiți": "nespetit",
    "nespilcuită": "nespilcuit",
    "nespilcuite": "nespilcuit",
    "nespilcuiți": "nespilcuit",
    "nespintecata": "nespintecat",
    "nespintecată": "nespintecat",
    "nespintecate": "nespintecat",
    "nespintecatei": "nespintecat",
    "nespintecatele": "nespintecat",
    "nespintecatelor": "nespintecat",
    "nespintecați": "nespintecat",
    "nespintecații": "nespintecat",
    "nespintecaților": "nespintecat",
    "nespintecatul": "nespintecat",
    "nespintecatului": "nespintecat",
    "nespionată": "nespionat",
    "nespionate": "nespionat",
    "nespionați": "nespionat",
    "nespiritualizată": "nespiritualizat",
    "nespiritualizate": "nespiritualizat",
    "nespiritualizați": "nespiritualizat",
    "nespitalizată": "nespitalizat",
    "nespitalizate": "nespitalizat",
    "nespitalizați": "nespitalizat",
    "nespoită": "nespoit",
    "nespoite": "nespoit",
    "nespoiți": "nespoit",
    "nesporită": "nesporit",
    "nesporite": "nesporit",
    "nesporiți": "nesporit",
    "nesporovăită": "nesporovăit",
    "nesporovăite": "nesporovăit",
    "nesporovăiți": "nesporovăit",
    "nesportiva": "nesportiv",
    "nesportivă": "nesportiv",
    "nesportive": "nesportiv",
    "nesportivei": "nesportiv",
    "nesportivele": "nesportiv",
    "nesportivelor": "nesportiv",
    "nesportivi": "nesportiv",
    "nesportivii": "nesportiv",
    "nesportivilor": "nesportiv",
    "nesportivul": "nesportiv",
    "nesportivului": "nesportiv",
    "nespovedită": "nespovedit",
    "nespovedite": "nespovedit",
    "nespovediți": "nespovedit",
    "nesprijinita": "nesprijinit",
    "nesprijinită": "nesprijinit",
    "nesprijinite": "nesprijinit",
    "nesprijinitei": "nesprijinit",
    "nesprijinitele": "nesprijinit",
    "nesprijinitelor": "nesprijinit",
    "nesprijiniți": "nesprijinit",
    "nesprijiniții": "nesprijinit",
    "nesprijiniților": "nesprijinit",
    "nesprijinitul": "nesprijinit",
    "nesprijinitului": "nesprijinit",
    "nesprintată": "nesprintat",
    "nesprintate": "nesprintat",
    "nesprintați": "nesprintat",
    "neșprițuita": "neșprițuit",
    "neșprițuită": "neșprițuit",
    "neșprițuite": "neșprițuit",
    "neșprițuitei": "neșprițuit",
    "neșprițuitele": "neșprițuit",
    "neșprițuitelor": "neșprițuit",
    "neșprițuiți": "neșprițuit",
    "neșprițuiții": "neșprițuit",
    "neșprițuiților": "neșprițuit",
    "neșprițuitul": "neșprițuit",
    "neșprițuitului": "neșprițuit",
    "nespulberată": "nespulberat",
    "nespulberate": "nespulberat",
    "nespulberați": "nespulberat",
    "nespumată": "nespumat",
    "nespumate": "nespumat",
    "nespumați": "nespumat",
    "nespumegată": "nespumegat",
    "nespumegate": "nespumegat",
    "nespumegați": "nespumegat",
    "nespurcată": "nespurcat",
    "nespurcate": "nespurcat",
    "nespurcați": "nespurcat",
    "nespusa": "nespus",
    "nespusă": "nespus",
    "nespuse": "nespus",
    "nespusei": "nespus",
    "nespusele": "nespus",
    "nespuselor": "nespus",
    "nespusi": "nespus",
    "nespuși": "nespus",
    "nespusii": "nespus",
    "nespusilor": "nespus",
    "nespusul": "nespus",
    "nespusului": "nespus",
    "nespuzită": "nespuzit",
    "nespuzite": "nespuzit",
    "nespuziți": "nespuzit",
    "nestabila": "nestabil",
    "nestabilă": "nestabil",
    "nestabile": "nestabil",
    "nestabilei": "nestabil",
    "nestabilele": "nestabil",
    "nestabilelor": "nestabil",
    "nestabili": "nestabil",
    "nestabilii": "nestabil",
    "nestabililor": "nestabil",
    "nestabilul": "nestabil",
    "nestabilului": "nestabil",
    "nestabilită": "nestabilit",
    "nestabilite": "nestabilit",
    "nestabiliți": "nestabilit",
    "nestabilizată": "nestabilizat",
    "nestabilizate": "nestabilizat",
    "nestabilizați": "nestabilizat",
    "nestafidită": "nestafidit",
    "nestafidite": "nestafidit",
    "nestafidiți": "nestafidit",
    "nestagnată": "nestagnat",
    "nestagnate": "nestagnat",
    "nestagnați": "nestagnat",
    "nestâlcită": "nestâlcit",
    "nestâlcite": "nestâlcit",
    "nestâlciți": "nestâlcit",
    "nestampată": "nestampat",
    "nestampate": "nestampat",
    "nestampați": "nestampat",
    "neștampilată": "neștampilat",
    "neștampilate": "neștampilat",
    "neștampilați": "neștampilat",
    "nestandardizată": "nestandardizat",
    "nestandardizate": "nestandardizat",
    "nestandardizați": "nestandardizat",
    "nestânjenita": "nestânjenit",
    "nestânjenită": "nestânjenit",
    "nestânjenite": "nestânjenit",
    "nestânjenitei": "nestânjenit",
    "nestânjenitele": "nestânjenit",
    "nestânjenitelor": "nestânjenit",
    "nestânjeniți": "nestânjenit",
    "nestânjeniții": "nestânjenit",
    "nestânjeniților": "nestânjenit",
    "nestânjenitul": "nestânjenit",
    "nestânjenitului": "nestânjenit",
    "neștanțată": "neștanțat",
    "neștanțate": "neștanțat",
    "neștanțați": "neștanțat",
    "nestăpânirea": "nestăpânire",
    "nestăpâniri": "nestăpânire",
    "nestăpânirii": "nestăpânire",
    "nestăpânirile": "nestăpânire",
    "nestăpânirilor": "nestăpânire",
    "nestăpânita": "nestăpânit",
    "nestăpânită": "nestăpânit",
    "nestăpânite": "nestăpânit",
    "nestăpânitei": "nestăpânit",
    "nestăpânitele": "nestăpânit",
    "nestăpânitelor": "nestăpânit",
    "nestăpâniți": "nestăpânit",
    "nestăpâniții": "nestăpânit",
    "nestăpâniților": "nestăpânit",
    "nestăpânitul": "nestăpânit",
    "nestăpânitului": "nestăpânit",
    "nestârnită": "nestârnit",
    "nestârnite": "nestârnit",
    "nestârniți": "nestârnit",
    "nestârpită": "nestârpit",
    "nestârpite": "nestârpit",
    "nestârpiți": "nestârpit",
    "nestăruită": "nestăruit",
    "nestăruite": "nestăruit",
    "nestăruiți": "nestăruit",
    "nestată": "nestat",
    "nestate": "nestat",
    "nestați": "nestat",
    "nestaționată": "nestaționat",
    "nestaționate": "nestaționat",
    "nestaționați": "nestaționat",
    "nestatornica": "nestatornic",
    "nestatornică": "nestatornic",
    "nestatornice": "nestatornic",
    "nestatornicei": "nestatornic",
    "nestatornicele": "nestatornic",
    "nestatornicelor": "nestatornic",
    "nestatornici": "nestatornic",
    "nestatornicii": "nestatornic",
    "nestatornicilor": "nestatornic",
    "nestatornicul": "nestatornic",
    "nestatornicului": "nestatornic",
    "nestatornicia": "nestatornicie",
    "nestatorniciei": "nestatornicie",
    "nestatornicii": "nestatornicie",
    "nestatorniciile": "nestatornicie",
    "nestatorniciilor": "nestatornicie",
    "nestatornicită": "nestatornicit",
    "nestatornicite": "nestatornicit",
    "nestatorniciți": "nestatornicit",
    "nestatuată": "nestatuat",
    "nestatuate": "nestatuat",
    "nestatuați": "nestatuat",
    "nestatutara": "nestatutar",
    "nestatutară": "nestatutar",
    "nestatutare": "nestatutar",
    "nestatutarei": "nestatutar",
    "nestatutarele": "nestatutar",
    "nestatutarelor": "nestatutar",
    "nestatutari": "nestatutar",
    "nestatutarii": "nestatutar",
    "nestatutarilor": "nestatutar",
    "nestăvilita": "nestăvilit",
    "nestăvilită": "nestăvilit",
    "nestăvilite": "nestăvilit",
    "nestăvilitei": "nestăvilit",
    "nestăvilitele": "nestăvilit",
    "nestăvilitelor": "nestăvilit",
    "nestăviliți": "nestăvilit",
    "nestăviliții": "nestăvilit",
    "nestăviliților": "nestăvilit",
    "nestăvilitul": "nestăvilit",
    "nestăvilitului": "nestăvilit",
    "nestemata": "nestemată",
    "nestemate": "nestemată",
    "nestematei": "nestemată",
    "nestematele": "nestemată",
    "nestematelor": "nestemată",
    "neștemuită": "neștemuit",
    "neștemuite": "neștemuit",
    "neștemuiți": "neștemuit",
    "nestenografiată": "nestenografiat",
    "nestenografiate": "nestenografiat",
    "nestenografiați": "nestenografiat",
    "nesterilizată": "nesterilizat",
    "nesterilizate": "nesterilizat",
    "nesterilizați": "nesterilizat",
    "neșterpelită": "neșterpelit",
    "neșterpelite": "neșterpelit",
    "neșterpeliți": "neșterpelit",
    "neștearsa": "neșters",
    "neștearsă": "neșters",
    "neșterse": "neșters",
    "neștersei": "neșters",
    "neștersele": "neșters",
    "neșterselor": "neșters",
    "neșterși": "neșters",
    "neșterșii": "neșters",
    "neșterșilor": "neșters",
    "neștersul": "neșters",
    "neștersului": "neșters",
    "nesticlită": "nesticlit",
    "nesticlite": "nesticlit",
    "nesticliți": "nesticlit",
    "nestigmatizată": "nestigmatizat",
    "nestigmatizate": "nestigmatizat",
    "nestigmatizați": "nestigmatizat",
    "neștiința": "neștiință",
    "neștiințe": "neștiință",
    "neștiinței": "neștiință",
    "neștiințele": "neștiință",
    "neștiințelor": "neștiință",
    "nestilizată": "nestilizat",
    "nestilizate": "nestilizat",
    "nestilizați": "nestilizat",
    "nestimata": "nestimat",
    "nestimată": "nestimat",
    "nestimate": "nestimat",
    "nestimatei": "nestimat",
    "nestimatele": "nestimat",
    "nestimatelor": "nestimat",
    "nestimați": "nestimat",
    "nestimații": "nestimat",
    "nestimaților": "nestimat",
    "nestimatul": "nestimat",
    "nestimatului": "nestimat",
    "nestimulată": "nestimulat",
    "nestimulate": "nestimulat",
    "nestimulați": "nestimulat",
    "nestingherita": "nestingherit",
    "nestingherită": "nestingherit",
    "nestingherite": "nestingherit",
    "nestingheritei": "nestingherit",
    "nestingheritele": "nestingherit",
    "nestingheritelor": "nestingherit",
    "nestingheriți": "nestingherit",
    "nestingheriții": "nestingherit",
    "nestingheriților": "nestingherit",
    "nestingheritul": "nestingherit",
    "nestingheritului": "nestingherit",
    "nestingibila": "nestingibil",
    "nestingibilă": "nestingibil",
    "nestingibile": "nestingibil",
    "nestingibilei": "nestingibil",
    "nestingibilele": "nestingibil",
    "nestingibilelor": "nestingibil",
    "nestingibili": "nestingibil",
    "nestingibilii": "nestingibil",
    "nestingibililor": "nestingibil",
    "nestingibilul": "nestingibil",
    "nestingibilului": "nestingibil",
    "nestinsa": "nestins",
    "nestinsă": "nestins",
    "nestinse": "nestins",
    "nestinsei": "nestins",
    "nestinsele": "nestins",
    "nestinselor": "nestins",
    "nestinsi": "nestins",
    "nestinși": "nestins",
    "nestinsii": "nestins",
    "nestinșii": "nestins",
    "nestinsilor": "nestins",
    "nestinșilor": "nestins",
    "nestinsul": "nestins",
    "nestinsului": "nestins",
    "nestipendiată": "nestipendiat",
    "nestipendiate": "nestipendiat",
    "nestipendiați": "nestipendiat",
    "nestipulată": "nestipulat",
    "nestipulate": "nestipulat",
    "nestipulați": "nestipulat",
    "neștirbita": "neștirbit",
    "neștirbită": "neștirbit",
    "neștirbite": "neștirbit",
    "neștirbitei": "neștirbit",
    "neștirbitele": "neștirbit",
    "neștirbitelor": "neștirbit",
    "neștirbiți": "neștirbit",
    "neștirbiții": "neștirbit",
    "neștirbiților": "neștirbit",
    "neștirbitul": "neștirbit",
    "neștirbitului": "neștirbit",
    "neștiuta": "neștiut",
    "neștiută": "neștiut",
    "neștiute": "neștiut",
    "neștiutei": "neștiut",
    "neștiutele": "neștiut",
    "neștiutelor": "neștiut",
    "neștiuți": "neștiut",
    "neștiuții": "neștiut",
    "neștiuților": "neștiut",
    "neștiutul": "neștiut",
    "neștiutului": "neștiut",
    "neștiutoare": "neștiutor",
    "neștiutoarea": "neștiutor",
    "neștiutoarei": "neștiutor",
    "neștiutoarele": "neștiutor",
    "neștiutoarelor": "neștiutor",
    "neștiutori": "neștiutor",
    "neștiutorii": "neștiutor",
    "neștiutorilor": "neștiutor",
    "neștiutorul": "neștiutor",
    "neștiutorului": "neștiutor",
    "nestivuita": "nestivuit",
    "nestivuită": "nestivuit",
    "nestivuite": "nestivuit",
    "nestivuitei": "nestivuit",
    "nestivuitele": "nestivuit",
    "nestivuitelor": "nestivuit",
    "nestivuiți": "nestivuit",
    "nestivuiții": "nestivuit",
    "nestivuiților": "nestivuit",
    "nestivuitul": "nestivuit",
    "nestivuitului": "nestivuit",
    "nestoarsă": "nestivuit",
    "nestoarse": "nestivuit",
    "nestocată": "nestocat",
    "nestocate": "nestocat",
    "nestocați": "nestocat",
    "nestopată": "nestopat",
    "nestopate": "nestopat",
    "nestopați": "nestopat",
    "nestorși": "nestors",
    "nestrăbătuta": "nestrăbătut",
    "nestrăbătută": "nestrăbătut",
    "nestrăbătute": "nestrăbătut",
    "nestrăbătutei": "nestrăbătut",
    "nestrăbătutele": "nestrăbătut",
    "nestrăbătutelor": "nestrăbătut",
    "nestrăbătuți": "nestrăbătut",
    "nestrăbătuții": "nestrăbătut",
    "nestrăbătuților": "nestrăbătut",
    "nestrăbătutul": "nestrăbătut",
    "nestrăbătutului": "nestrăbătut",
    "nestrăduită": "nestrăduit",
    "nestrăduite": "nestrăduit",
    "nestrăduiți": "nestrăduit",
    "nestrăfulgerată": "nestrăfulgerat",
    "nestrăfulgerate": "nestrăfulgerat",
    "nestrăfulgerați": "nestrăfulgerat",
    "nestrăjuită": "nestrăjuit",
    "nestrăjuite": "nestrăjuit",
    "nestrăjuiți": "nestrăjuit",
    "nestrălucită": "nestrălucit",
    "nestrălucite": "nestrălucit",
    "nestrăluciți": "nestrălucit",
    "nestrâmbată": "nestrâmbat",
    "nestrâmbate": "nestrâmbat",
    "nestrâmbați": "nestrâmbat",
    "nestrâmtată": "nestrâmtat",
    "nestrâmtate": "nestrâmtat",
    "nestrâmtați": "nestrâmtat",
    "nestrâmtorată": "nestrâmtorat",
    "nestrâmtorate": "nestrâmtorat",
    "nestrâmtorați": "nestrâmtorat",
    "nestrămutata": "nestrămutat",
    "nestrămutată": "nestrămutat",
    "nestrămutate": "nestrămutat",
    "nestrămutatei": "nestrămutat",
    "nestrămutatele": "nestrămutat",
    "nestrămutatelor": "nestrămutat",
    "nestrămutați": "nestrămutat",
    "nestrămutații": "nestrămutat",
    "nestrămutaților": "nestrămutat",
    "nestrămutatul": "nestrămutat",
    "nestrămutatului": "nestrămutat",
    "nestrangulată": "nestrangulat",
    "nestrangulate": "nestrangulat",
    "nestrangulați": "nestrangulat",
    "nestrânsă": "nestrâns",
    "nestrânse": "nestrâns",
    "nestrânși": "nestrâns",
    "nestrănutată": "nestrănutat",
    "nestrănutate": "nestrănutat",
    "nestrănutați": "nestrănutat",
    "nestrăpunsă": "nestrăpuns",
    "nestrăpunse": "nestrăpuns",
    "nestrăpunși": "nestrăpuns",
    "nestratificata": "nestratificat",
    "nestratificată": "nestratificat",
    "nestratificate": "nestratificat",
    "nestratificatei": "nestratificat",
    "nestratificatele": "nestratificat",
    "nestratificatelor": "nestratificat",
    "nestratificați": "nestratificat",
    "nestratificații": "nestratificat",
    "nestratificaților": "nestratificat",
    "nestratificatul": "nestratificat",
    "nestratificatului": "nestratificat",
    "nestrecurata": "nestrecurat",
    "nestrecurată": "nestrecurat",
    "nestrecurate": "nestrecurat",
    "nestrecuratei": "nestrecurat",
    "nestrecuratele": "nestrecurat",
    "nestrecuratelor": "nestrecurat",
    "nestrecurați": "nestrecurat",
    "nestrecurații": "nestrecurat",
    "nestrecuraților": "nestrecurat",
    "nestrecuratul": "nestrecurat",
    "nestrecuratului": "nestrecurat",
    "nestrepezita": "nestrepezit",
    "nestrepezită": "nestrepezit",
    "nestrepezite": "nestrepezit",
    "nestrepezitei": "nestrepezit",
    "nestrepezitele": "nestrepezit",
    "nestrepezitelor": "nestrepezit",
    "nestrepeziți": "nestrepezit",
    "nestrepeziților": "nestrepezit",
    "nestrepezitul": "nestrepezit",
    "nestrepezitului": "nestrepezit",
    "nestricata": "nestricat",
    "nestricată": "nestricat",
    "nestricate": "nestricat",
    "nestricatei": "nestricat",
    "nestricatele": "nestricat",
    "nestricatelor": "nestricat",
    "nestricați": "nestricat",
    "nestricații": "nestricat",
    "nestricaților": "nestricat",
    "nestricatul": "nestricat",
    "nestricatului": "nestricat",
    "nestrigata": "nestrigat",
    "nestrigată": "nestrigat",
    "nestrigate": "nestrigat",
    "nestrigatei": "nestrigat",
    "nestrigatele": "nestrigat",
    "nestrigatelor": "nestrigat",
    "nestrigați": "nestrigat",
    "nestrigații": "nestrigat",
    "nestrigaților": "nestrigat",
    "nestrigatul": "nestrigat",
    "nestrigatului": "nestrigat",
    "nestrivita": "nestrivit",
    "nestrivită": "nestrivit",
    "nestrivite": "nestrivit",
    "nestrivitei": "nestrivit",
    "nestrivitele": "nestrivit",
    "nestrivitelor": "nestrivit",
    "nestriviți": "nestrivit",
    "nestriviții": "nestrivit",
    "nestriviților": "nestrivit",
    "nestrivitul": "nestrivit",
    "nestrivitului": "nestrivit",
    "nestropită": "nestropit",
    "nestropite": "nestropit",
    "nestropiți": "nestropit",
    "nestropșită": "nestropșit",
    "nestropșite": "nestropșit",
    "nestropșiți": "nestropșit",
    "nestructurată": "nestructurat",
    "nestructurate": "nestructurat",
    "nestructurați": "nestructurat",
    "nestrunită": "nestrunit",
    "nestrunite": "nestrunit",
    "nestruniți": "nestrunit",
    "nestrunjita": "nestrunjit",
    "nestrunjită": "nestrunjit",
    "nestrunjite": "nestrunjit",
    "nestrunjitei": "nestrunjit",
    "nestrunjitele": "nestrunjit",
    "nestrunjitelor": "nestrunjit",
    "nestrunjiți": "nestrunjit",
    "nestrunjiții": "nestrunjit",
    "nestrunjiților": "nestrunjit",
    "nestrunjitul": "nestrunjit",
    "nestrunjitului": "nestrunjit",
    "nestudiata": "nestudiat",
    "nestudiată": "nestudiat",
    "nestudiate": "nestudiat",
    "nestudiatei": "nestudiat",
    "nestudiatele": "nestudiat",
    "nestudiatelor": "nestudiat",
    "nestudiați": "nestudiat",
    "nestudiații": "nestudiat",
    "nestudiaților": "nestudiat",
    "nestudiatul": "nestudiat",
    "nestudiatului": "nestudiat",
    "nestupefiată": "nestupefiat",
    "nestupefiate": "nestupefiat",
    "nestupefiați": "nestupefiat",
    "nestupită": "nestupit",
    "nestupite": "nestupit",
    "nestupiți": "nestupit",
    "nesubalimentată": "nesubalimentat",
    "nesubalimentate": "nesubalimentat",
    "nesubalimentați": "nesubalimentat",
    "nesubapreciată": "nesubapreciat",
    "nesubapreciate": "nesubapreciat",
    "nesubapreciați": "nesubapreciat",
    "nesubarendată": "nesubarendat",
    "nesubarendate": "nesubarendat",
    "nesubarendați": "nesubarendat",
    "nesubestimata": "nesubestimat",
    "nesubestimată": "nesubestimat",
    "nesubestimate": "nesubestimat",
    "nesubestimatei": "nesubestimat",
    "nesubestimatele": "nesubestimat",
    "nesubestimatelor": "nesubestimat",
    "nesubestimați": "nesubestimat",
    "nesubestimații": "nesubestimat",
    "nesubestimaților": "nesubestimat",
    "nesubestimatul": "nesubestimat",
    "nesubestimatului": "nesubestimat",
    "nesubevaluată": "nesubevaluat",
    "nesubevaluate": "nesubevaluat",
    "nesubevaluați": "nesubevaluat",
    "nesubîmpărțită": "nesubîmpărțit",
    "nesubîmpărțite": "nesubîmpărțit",
    "nesubîmpărțiți": "nesubîmpărțit",
    "nesubînchiriată": "nesubînchiriat",
    "nesubînchiriate": "nesubînchiriat",
    "nesubînchiriați": "nesubînchiriat",
    "nesubînțeleasa": "nesubînțeles",
    "nesubînțeleasă": "nesubînțeles",
    "nesubînțelese": "nesubînțeles",
    "nesubînțelesei": "nesubînțeles",
    "nesubînțelesele": "nesubînțeles",
    "nesubînțeleselor": "nesubînțeles",
    "nesubînțeleși": "nesubînțeles",
    "nesubînțeleșii": "nesubînțeles",
    "nesubînțeleșilor": "nesubînțeles",
    "nesubînțelesul": "nesubînțeles",
    "nesubînțelesului": "nesubînțeles",
    "nesubintitulată": "nesubintitulat",
    "nesubintitulate": "nesubintitulat",
    "nesubintitulați": "nesubintitulat",
    "nesubjugată": "nesubjugat",
    "nesubjugate": "nesubjugat",
    "nesubjugați": "nesubjugat",
    "nesublimată": "nesublimat",
    "nesublimate": "nesublimat",
    "nesublimați": "nesublimat",
    "nesubliniată": "nesubliniat",
    "nesubliniate": "nesubliniat",
    "nesubliniați": "nesubliniat",
    "nesubminata": "nesubminat",
    "nesubminată": "nesubminat",
    "nesubminate": "nesubminat",
    "nesubminatei": "nesubminat",
    "nesubminatele": "nesubminat",
    "nesubminatelor": "nesubminat",
    "nesubminați": "nesubminat",
    "nesubminații": "nesubminat",
    "nesubminaților": "nesubminat",
    "nesubminatul": "nesubminat",
    "nesubminatului": "nesubminat",
    "nesubordonata": "nesubordonat",
    "nesubordonată": "nesubordonat",
    "nesubordonate": "nesubordonat",
    "nesubordonatei": "nesubordonat",
    "nesubordonatele": "nesubordonat",
    "nesubordonatelor": "nesubordonat",
    "nesubordonați": "nesubordonat",
    "nesubordonații": "nesubordonat",
    "nesubordonaților": "nesubordonat",
    "nesubordonatul": "nesubordonat",
    "nesubordonatului": "nesubordonat",
    "nesubscrisă": "nesubscris",
    "nesubscrise": "nesubscris",
    "nesubscriși": "nesubscris",
    "nesubstantivizată": "nesubstantivizat",
    "nesubstantivizate": "nesubstantivizat",
    "nesubstantivizați": "nesubstantivizat",
    "nesubstituită": "nesubstituit",
    "nesubstituite": "nesubstituit",
    "nesubstituiți": "nesubstituit",
    "nesubsumată": "nesubsumat",
    "nesubsumate": "nesubsumat",
    "nesubsumați": "nesubsumat",
    "nesubțiata": "nesubțiat",
    "nesubțiată": "nesubțiat",
    "nesubțiate": "nesubțiat",
    "nesubțiatei": "nesubțiat",
    "nesubțiatele": "nesubțiat",
    "nesubțiatelor": "nesubțiat",
    "nesubțiați": "nesubțiat",
    "nesubțiații": "nesubțiat",
    "nesubțiaților": "nesubțiat",
    "nesubțiatul": "nesubțiat",
    "nesubțiatului": "nesubțiat",
    "nesubtilizată": "nesubtilizat",
    "nesubtilizate": "nesubtilizat",
    "nesubtilizați": "nesubtilizat",
    "nesubvenționată": "nesubvenționat",
    "nesubvenționate": "nesubvenționat",
    "nesubvenționați": "nesubvenționat",
    "nesubzistată": "nesubzistat",
    "nesubzistate": "nesubzistat",
    "nesubzistați": "nesubzistat",
    "nesucălită": "nesucălit",
    "nesucălite": "nesucălit",
    "nesucăliți": "nesucălit",
    "nesuccedată": "nesuccedat",
    "nesuccedate": "nesuccedat",
    "nesuccedați": "nesuccedat",
    "nesucită": "nesucit",
    "nesucite": "nesucit",
    "nesuciți": "nesucit",
    "nesucombată": "nesucombat",
    "nesucombate": "nesucombat",
    "nesucombați": "nesucombat",
    "nesudată": "nesudat",
    "nesudate": "nesudat",
    "nesudați": "nesudat",
    "nesuduită": "nesuduit",
    "nesuduite": "nesuduit",
    "nesuduiți": "nesuduit",
    "nesuferita": "nesuferit",
    "nesuferită": "nesuferit",
    "nesuferite": "nesuferit",
    "nesuferitei": "nesuferit",
    "nesuferitele": "nesuferit",
    "nesuferitelor": "nesuferit",
    "nesuferiți": "nesuferit",
    "nesuferiții": "nesuferit",
    "nesuferiților": "nesuferit",
    "nesuferitul": "nesuferit",
    "nesuferitului": "nesuferit",
    "nesufixată": "nesufixat",
    "nesufixate": "nesufixat",
    "nesufixați": "nesufixat",
    "nesuflată": "nesuflat",
    "nesuflate": "nesuflat",
    "nesuflați": "nesuflat",
    "nesuflecata": "nesuflecat",
    "nesuflecată": "nesuflecat",
    "nesuflecate": "nesuflecat",
    "nesuflecatei": "nesuflecat",
    "nesuflecatele": "nesuflecat",
    "nesuflecatelor": "nesuflecat",
    "nesuflecați": "nesuflecat",
    "nesuflecații": "nesuflecat",
    "nesuflecaților": "nesuflecat",
    "nesuflecatul": "nesuflecat",
    "nesuflecatului": "nesuflecat",
    "nesufocata": "nesufocat",
    "nesufocată": "nesufocat",
    "nesufocate": "nesufocat",
    "nesufocatei": "nesufocat",
    "nesufocatele": "nesufocat",
    "nesufocatelor": "nesufocat",
    "nesufocați": "nesufocat",
    "nesufocații": "nesufocat",
    "nesufocaților": "nesufocat",
    "nesufocatul": "nesufocat",
    "nesufocatului": "nesufocat",
    "nesugerată": "nesugerat",
    "nesugerate": "nesugerat",
    "nesugerați": "nesugerat",
    "nesugestionată": "nesugestionat",
    "nesugestionate": "nesugestionat",
    "nesugestionați": "nesugestionat",
    "nesughițată": "nesughițat",
    "nesughițate": "nesughițat",
    "nesughițați": "nesughițat",
    "nesugrumata": "nesugrumat",
    "nesugrumată": "nesugrumat",
    "nesugrumate": "nesugrumat",
    "nesugrumatei": "nesugrumat",
    "nesugrumatele": "nesugrumat",
    "nesugrumatelor": "nesugrumat",
    "nesugrumați": "nesugrumat",
    "nesugrumații": "nesugrumat",
    "nesugrumaților": "nesugrumat",
    "nesugrumatul": "nesugrumat",
    "nesugrumatului": "nesugrumat",
    "neșuierata": "neșuierat",
    "neșuierată": "neșuierat",
    "neșuierate": "neșuierat",
    "neșuieratei": "neșuierat",
    "neșuieratele": "neșuierat",
    "neșuieratelor": "neșuierat",
    "neșuierați": "neșuierat",
    "neșuierații": "neșuierat",
    "neșuieratul": "neșuierat",
    "nesuită": "nesuit",
    "nesuite": "nesuit",
    "nesuiți": "nesuit",
    "nesulemenita": "nesulemenit",
    "nesulemenită": "nesulemenit",
    "nesulemenite": "nesulemenit",
    "nesulemenitei": "nesulemenit",
    "nesulemenitele": "nesulemenit",
    "nesulemenitelor": "nesulemenit",
    "nesulemeniți": "nesulemenit",
    "nesulemeniții": "nesulemenit",
    "nesulemeniților": "nesulemenit",
    "nesulemenitul": "nesulemenit",
    "nesulemenitului": "nesulemenit",
    "nesulfatată": "nesulfatat",
    "nesulfatate": "nesulfatat",
    "nesulfatați": "nesulfatat",
    "nesulfurată": "nesulfurat",
    "nesulfurate": "nesulfurat",
    "nesulfurați": "nesulfurat",
    "nesulimenită": "nesulimenit",
    "nesulimenite": "nesulimenit",
    "nesulimeniți": "nesulimenit",
    "nesunată": "nesunat",
    "nesunate": "nesunat",
    "nesunați": "nesunat",
    "nesupărata": "nesupărat",
    "nesupărată": "nesupărat",
    "nesupărate": "nesupărat",
    "nesupăratei": "nesupărat",
    "nesupăratele": "nesupărat",
    "nesupăratelor": "nesupărat",
    "nesupărați": "nesupărat",
    "nesupărații": "nesupărat",
    "nesupăraților": "nesupărat",
    "nesupăratul": "nesupărat",
    "nesupăratului": "nesupărat",
    "nesuplinită": "nesuplinit",
    "nesuplinite": "nesuplinit",
    "nesupliniți": "nesuplinit",
    "nesuportata": "nesuportat",
    "nesuportată": "nesuportat",
    "nesuportate": "nesuportat",
    "nesuportatei": "nesuportat",
    "nesuportatele": "nesuportat",
    "nesuportatelor": "nesuportat",
    "nesuportați": "nesuportat",
    "nesuportații": "nesuportat",
    "nesuportaților": "nesuportat",
    "nesuportatul": "nesuportat",
    "nesuportatului": "nesuportat",
    "nesupraalimentată": "nesupraalimentat",
    "nesupraalimentate": "nesupraalimentat",
    "nesupraalimentați": "nesupraalimentat",
    "nesupraestimată": "nesupraestimat",
    "nesupraestimate": "nesupraestimat",
    "nesupraestimați": "nesupraestimat",
    "nesupraîncălzită": "nesupraîncălzit",
    "nesupraîncălzite": "nesupraîncălzit",
    "nesupraîncălziți": "nesupraîncălzit",
    "nesupraîncărcată": "nesupraîncărcat",
    "nesupraîncărcate": "nesupraîncărcat",
    "nesupraîncărcați": "nesupraîncărcat",
    "nesupralicitată": "nesupralicitat",
    "nesupralicitate": "nesupralicitat",
    "nesupralicitați": "nesupralicitat",
    "nesupranumită": "nesupranumit",
    "nesupranumite": "nesupranumit",
    "nesupranumiți": "nesupranumit",
    "nesuprapusa": "nesuprapus",
    "nesuprapusă": "nesuprapus",
    "nesuprapuse": "nesuprapus",
    "nesuprapusei": "nesuprapus",
    "nesuprapusele": "nesuprapus",
    "nesuprapuselor": "nesuprapus",
    "nesuprapuși": "nesuprapus",
    "nesuprapusii": "nesuprapus",
    "nesuprapusilor": "nesuprapus",
    "nesuprapusul": "nesuprapus",
    "nesuprapusului": "nesuprapus",
    "nesuprataxată": "nesuprataxat",
    "nesuprataxate": "nesuprataxat",
    "nesuprataxați": "nesuprataxat",
    "nesupravegheată": "nesupravegheat",
    "nesupravegheate": "nesupravegheat",
    "nesupravegheați": "nesupravegheat",
    "nesupraviețuită": "nesupraviețuit",
    "nesupraviețuite": "nesupraviețuit",
    "nesupraviețuiți": "nesupraviețuit",
    "nesuprimata": "nesuprimat",
    "nesuprimată": "nesuprimat",
    "nesuprimate": "nesuprimat",
    "nesuprimatei": "nesuprimat",
    "nesuprimatele": "nesuprimat",
    "nesuprimatelor": "nesuprimat",
    "nesuprimați": "nesuprimat",
    "nesuprimații": "nesuprimat",
    "nesuprimaților": "nesuprimat",
    "nesuprimatul": "nesuprimat",
    "nesuprimatului": "nesuprimat",
    "nesuptă": "nesupt",
    "nesupte": "nesupt",
    "nesupți": "nesupt",
    "nesupunerea": "nesupunere",
    "nesupuneri": "nesupunere",
    "nesupunerii": "nesupunere",
    "nesupunerile": "nesupunere",
    "nesupunerilor": "nesupunere",
    "nesupurată": "nesupurat",
    "nesupurate": "nesupurat",
    "nesupurați": "nesupurat",
    "nesupusa": "nesupus",
    "nesupusă": "nesupus",
    "nesupuse": "nesupus",
    "nesupusei": "nesupus",
    "nesupusele": "nesupus",
    "nesupuselor": "nesupus",
    "nesupusi": "nesupus",
    "nesupuși": "nesupus",
    "nesupusii": "nesupus",
    "nesupusilor": "nesupus",
    "nesupusul": "nesupus",
    "nesupusului": "nesupus",
    "nesurâsă": "nesurâs",
    "nesurâse": "nesurâs",
    "nesurâși": "nesurâs",
    "nesurfilată": "nesurfilat",
    "nesurfilate": "nesurfilat",
    "nesurfilați": "nesurfilat",
    "nesurghiunită": "nesurghiunit",
    "nesurghiunite": "nesurghiunit",
    "nesurghiuniți": "nesurghiunit",
    "nesurmenată": "nesurmenat",
    "nesurmenate": "nesurmenat",
    "nesurmenați": "nesurmenat",
    "nesurpată": "nesurpat",
    "nesurpate": "nesurpat",
    "nesurpați": "nesurpat",
    "nesurpatul": "nesurpat",
    "nesurpatului": "nesurpat",
    "nesurprinsă": "nesurprins",
    "nesurprinse": "nesurprins",
    "nesurprinși": "nesurprins",
    "nesurprinsii": "nesurprins",
    "nesurprinsilor": "nesurprins",
    "nesurprinsul": "nesurprins",
    "nesurprinsului": "nesurprins",
    "nesurvenită": "nesurvenit",
    "nesurvenite": "nesurvenit",
    "nesurveniți": "nesurvenit",
    "nesurzită": "nesurzit",
    "nesurzite": "nesurzit",
    "nesurziți": "nesurzit",
    "nesusceptibila": "nesusceptibil",
    "nesusceptibilă": "nesusceptibil",
    "nesusceptibile": "nesusceptibil",
    "nesusceptibilei": "nesusceptibil",
    "nesusceptibilele": "nesusceptibil",
    "nesusceptibilelor": "nesusceptibil",
    "nesusceptibili": "nesusceptibil",
    "nesusceptibilii": "nesusceptibil",
    "nesusceptibililor": "nesusceptibil",
    "nesusceptibilul": "nesusceptibil",
    "nesusceptibilului": "nesusceptibil",
    "nesuscitată": "nesuscitat",
    "nesuscitate": "nesuscitat",
    "nesuscitați": "nesuscitat",
    "neșușotită": "neșușotit",
    "neșușotite": "neșușotit",
    "neșușotiți": "neșușotit",
    "nesuspectată": "nesuspectat",
    "nesuspectate": "nesuspectat",
    "nesuspectați": "nesuspectat",
    "nesuspendata": "nesuspendat",
    "nesuspendată": "nesuspendat",
    "nesuspendate": "nesuspendat",
    "nesuspendatei": "nesuspendat",
    "nesuspendatele": "nesuspendat",
    "nesuspendatelor": "nesuspendat",
    "nesuspendați": "nesuspendat",
    "nesuspendații": "nesuspendat",
    "nesuspendaților": "nesuspendat",
    "nesuspendatul": "nesuspendat",
    "nesuspendatului": "nesuspendat",
    "nesuspinată": "nesuspinat",
    "nesuspinate": "nesuspinat",
    "nesuspinați": "nesuspinat",
    "nesusținuta": "nesusținut",
    "nesusținută": "nesusținut",
    "nesusținute": "nesusținut",
    "nesusținutei": "nesusținut",
    "nesusținutele": "nesusținut",
    "nesusținutelor": "nesusținut",
    "nesusținuți": "nesusținut",
    "nesusținuții": "nesusținut",
    "nesusținuților": "nesusținut",
    "nesusținutul": "nesusținut",
    "nesusținutului": "nesusținut",
    "nesustrasă": "nesustras",
    "nesustrase": "nesustras",
    "nesustrași": "nesustras",
    "nesusurată": "nesusurat",
    "nesusurate": "nesusurat",
    "nesusurați": "nesusurat",
    "neșutată": "neșutat",
    "neșutate": "neșutat",
    "neșutați": "neșutat",
    "nesuturată": "nesuturat",
    "nesuturate": "nesuturat",
    "nesuturați": "nesuturat",
    "neta": "net",
    "netă": "net",
    "nete": "net",
    "netei": "net",
    "netele": "net",
    "netelor": "net",
    "neți": "net",
    "neții": "net",
    "neților": "net",
    "netul": "net",
    "netului": "net",
    "netăbăcita": "netăbăcit",
    "netăbăcită": "netăbăcit",
    "netăbăcite": "netăbăcit",
    "netăbăcitei": "netăbăcit",
    "netăbăcitele": "netăbăcit",
    "netăbăcitelor": "netăbăcit",
    "netăbăciți": "netăbăcit",
    "netăbăciții": "netăbăcit",
    "netăbăciților": "netăbăcit",
    "netăbăcitul": "netăbăcit",
    "netăbăcitului": "netăbăcit",
    "netăbărâta": "netăbărât",
    "netăbărâtă": "netăbărât",
    "netăbărâte": "netăbărât",
    "netăbărâtei": "netăbărât",
    "netăbărâtele": "netăbărât",
    "netăbărâtelor": "netăbărât",
    "netăbărâți": "netăbărât",
    "netăbărâții": "netăbărât",
    "netăbărâților": "netăbărât",
    "netăbărâtul": "netăbărât",
    "netăbărâtului": "netăbărât",
    "nețăcănita": "nețăcănit",
    "nețăcănită": "nețăcănit",
    "nețăcănite": "nețăcănit",
    "nețăcănitei": "nețăcănit",
    "nețăcănitele": "nețăcănit",
    "nețăcănitelor": "nețăcănit",
    "nețăcăniți": "nețăcănit",
    "nețăcăniții": "nețăcănit",
    "nețăcăniților": "nețăcănit",
    "nețăcănitul": "nețăcănit",
    "nețăcănitului": "nețăcănit",
    "netachinata": "netachinat",
    "netachinată": "netachinat",
    "netachinate": "netachinat",
    "netachinatei": "netachinat",
    "netachinatele": "netachinat",
    "netachinatelor": "netachinat",
    "netachinați": "netachinat",
    "netachinații": "netachinat",
    "netachinaților": "netachinat",
    "netachinatul": "netachinat",
    "netachinatului": "netachinat",
    "netăcuta": "netăcut",
    "netăcută": "netăcut",
    "netăcute": "netăcut",
    "netăcutei": "netăcut",
    "netăcutele": "netăcut",
    "netăcutelor": "netăcut",
    "netăcuți": "netăcut",
    "netăcuții": "netăcut",
    "netăcuților": "netăcut",
    "netăcutul": "netăcut",
    "netăcutului": "netăcut",
    "netăgăduita": "netăgăduit",
    "netăgăduită": "netăgăduit",
    "netăgăduite": "netăgăduit",
    "netăgăduitei": "netăgăduit",
    "netăgăduitele": "netăgăduit",
    "netăgăduitelor": "netăgăduit",
    "netăgăduiți": "netăgăduit",
    "netăgăduiții": "netăgăduit",
    "netăgăduiților": "netăgăduit",
    "netăgăduitul": "netăgăduit",
    "netăgăduitului": "netăgăduit",
    "netăiata": "netăiat",
    "netăiată": "netăiat",
    "netăiate": "netăiat",
    "netăiatei": "netăiat",
    "netăiatele": "netăiat",
    "netăiatelor": "netăiat",
    "netăiați": "netăiat",
    "netăiații": "netăiat",
    "netăiaților": "netăiat",
    "netăiatul": "netăiat",
    "netăiatului": "netăiat",
    "netăinuita": "netăinuit",
    "netăinuită": "netăinuit",
    "netăinuite": "netăinuit",
    "netăinuitei": "netăinuit",
    "netăinuitele": "netăinuit",
    "netăinuitelor": "netăinuit",
    "netăinuiți": "netăinuit",
    "netăinuiții": "netăinuit",
    "netăinuiților": "netăinuit",
    "netăinuitul": "netăinuit",
    "netăinuitului": "netăinuit",
    "netălăzuita": "netălăzuit",
    "netălăzuită": "netălăzuit",
    "netălăzuite": "netălăzuit",
    "netălăzuitei": "netălăzuit",
    "netălăzuitele": "netălăzuit",
    "netălăzuitelor": "netălăzuit",
    "netălăzuiți": "netălăzuit",
    "netălăzuiții": "netălăzuit",
    "netălăzuiților": "netălăzuit",
    "netălăzuitul": "netălăzuit",
    "netălăzuitului": "netălăzuit",
    "netâlcuita": "netâlcuit",
    "netâlcuită": "netâlcuit",
    "netâlcuite": "netâlcuit",
    "netâlcuitei": "netâlcuit",
    "netâlcuitele": "netâlcuit",
    "netâlcuitelor": "netâlcuit",
    "netâlcuiți": "netâlcuit",
    "netâlcuiții": "netâlcuit",
    "netâlcuiților": "netâlcuit",
    "netâlcuitul": "netâlcuit",
    "netâlcuitului": "netâlcuit",
    "netălmăcita": "netălmăcit",
    "netălmăcită": "netălmăcit",
    "netălmăcite": "netălmăcit",
    "netălmăcitei": "netălmăcit",
    "netălmăcitele": "netălmăcit",
    "netălmăcitelor": "netălmăcit",
    "netălmăciți": "netălmăcit",
    "netălmăciții": "netălmăcit",
    "netălmăciților": "netălmăcit",
    "netălmăcitul": "netălmăcit",
    "netălmăcitului": "netălmăcit",
    "netalonata": "netalonat",
    "netalonată": "netalonat",
    "netalonate": "netalonat",
    "netalonatei": "netalonat",
    "netalonatele": "netalonat",
    "netalonatelor": "netalonat",
    "netalonați": "netalonat",
    "netalonații": "netalonat",
    "netalonaților": "netalonat",
    "netalonatul": "netalonat",
    "netalonatului": "netalonat",
    "netămăduita": "netămăduit",
    "netămăduită": "netămăduit",
    "netămăduite": "netămăduit",
    "netămăduitei": "netămăduit",
    "netămăduitele": "netămăduit",
    "netămăduitelor": "netămăduit",
    "netămăduiți": "netămăduit",
    "netămăduiții": "netămăduit",
    "netămăduiților": "netămăduit",
    "netămăduitul": "netămăduit",
    "netămăduitului": "netămăduit",
    "netămâiata": "netămâiat",
    "netămâiată": "netămâiat",
    "netămâiate": "netămâiat",
    "netămâiatei": "netămâiat",
    "netămâiatele": "netămâiat",
    "netămâiatelor": "netămâiat",
    "netămâiați": "netămâiat",
    "netămâiații": "netămâiat",
    "netămâiaților": "netămâiat",
    "netămâiatul": "netămâiat",
    "netămâiatului": "netămâiat",
    "netâmpita": "netâmpit",
    "netâmpită": "netâmpit",
    "netâmpite": "netâmpit",
    "netâmpitei": "netâmpit",
    "netâmpitele": "netâmpit",
    "netâmpitelor": "netâmpit",
    "netâmpiți": "netâmpit",
    "netâmpiții": "netâmpit",
    "netâmpiților": "netâmpit",
    "netâmpitul": "netâmpit",
    "netâmpitului": "netâmpit",
    "netamponata": "netamponat",
    "netamponată": "netamponat",
    "netamponate": "netamponat",
    "netamponatei": "netamponat",
    "netamponatele": "netamponat",
    "netamponatelor": "netamponat",
    "netamponați": "netamponat",
    "netamponații": "netamponat",
    "netamponaților": "netamponat",
    "netamponatul": "netamponat",
    "netamponatului": "netamponat",
    "netândălita": "netândălit",
    "netândălită": "netândălit",
    "netândălite": "netândălit",
    "netândălitei": "netândălit",
    "netândălitele": "netândălit",
    "netândălitelor": "netândălit",
    "netândăliți": "netândălit",
    "netândăliții": "netândălit",
    "netândăliților": "netândălit",
    "netândălitul": "netândălit",
    "netândălitului": "netândălit",
    "netânguita": "netânguit",
    "netânguită": "netânguit",
    "netânguite": "netânguit",
    "netânguitei": "netânguit",
    "netânguitele": "netânguit",
    "netânguitelor": "netânguit",
    "netânguiți": "netânguit",
    "netânguiții": "netânguit",
    "netânguiților": "netânguit",
    "netânguitul": "netânguit",
    "netânguitului": "netânguit",
    "netânjita": "netânjit",
    "netânjită": "netânjit",
    "netânjite": "netânjit",
    "netânjitei": "netânjit",
    "netânjitele": "netânjit",
    "netânjitelor": "netânjit",
    "netânjiți": "netânjit",
    "netânjiții": "netânjit",
    "netânjiților": "netânjit",
    "netânjitul": "netânjit",
    "netânjitului": "netânjit",
    "netapata": "netapat",
    "netapată": "netapat",
    "netapate": "netapat",
    "netapatei": "netapat",
    "netapatele": "netapat",
    "netapatelor": "netapat",
    "netapați": "netapat",
    "netapații": "netapat",
    "netapaților": "netapat",
    "netapatul": "netapat",
    "netapatului": "netapat",
    "netapetata": "netapetat",
    "netapetată": "netapetat",
    "netapetate": "netapetat",
    "netapetatei": "netapetat",
    "netapetatele": "netapetat",
    "netapetatelor": "netapetat",
    "netapetați": "netapetat",
    "netapetații": "netapetat",
    "netapetaților": "netapetat",
    "netapetatul": "netapetat",
    "netapetatului": "netapetat",
    "netapisata": "netapisat",
    "netapisată": "netapisat",
    "netapisate": "netapisat",
    "netapisatei": "netapisat",
    "netapisatele": "netapisat",
    "netapisatelor": "netapisat",
    "netapisați": "netapisat",
    "netapisații": "netapisat",
    "netapisaților": "netapisat",
    "netapisatul": "netapisat",
    "netapisatului": "netapisat",
    "netapițata": "netapițat",
    "netapițată": "netapițat",
    "netapițate": "netapițat",
    "netapițatei": "netapițat",
    "netapițatele": "netapițat",
    "netapițatelor": "netapițat",
    "netapițați": "netapițat",
    "netapițații": "netapițat",
    "netapițaților": "netapițat",
    "netapițatul": "netapițat",
    "netapițatului": "netapițat",
    "netăpșita": "netăpșit",
    "netăpșită": "netăpșit",
    "netăpșite": "netăpșit",
    "netăpșitei": "netăpșit",
    "netăpșitele": "netăpșit",
    "netăpșitelor": "netăpșit",
    "netăpșiți": "netăpșit",
    "netăpșiții": "netăpșit",
    "netăpșiților": "netăpșit",
    "netăpșitul": "netăpșit",
    "netăpșitului": "netăpșit",
    "netărăgănata": "netărăgănat",
    "netărăgănată": "netărăgănat",
    "netărăgănate": "netărăgănat",
    "netărăgănatei": "netărăgănat",
    "netărăgănatele": "netărăgănat",
    "netărăgănatelor": "netărăgănat",
    "netărăgănați": "netărăgănat",
    "netărăgănații": "netărăgănat",
    "netărăgănaților": "netărăgănat",
    "netărăgănatul": "netărăgănat",
    "netărăgănatului": "netărăgănat",
    "netârâita": "netârâit",
    "netârâită": "netârâit",
    "netârâite": "netârâit",
    "netârâitei": "netârâit",
    "netârâitele": "netârâit",
    "netârâitelor": "netârâit",
    "netârâiți": "netârâit",
    "netârâiții": "netârâit",
    "netârâiților": "netârâit",
    "netârâitul": "netârâit",
    "netârâitului": "netârâit",
    "netârguita": "netârguit",
    "netârguită": "netârguit",
    "netârguite": "netârguit",
    "netârguitei": "netârguit",
    "netârguitele": "netârguit",
    "netârguitelor": "netârguit",
    "netârguiți": "netârguit",
    "netârguiții": "netârguit",
    "netârguiților": "netârguit",
    "netârguitul": "netârguit",
    "netârguitului": "netârguit",
    "nețărmurita": "nețărmurit",
    "nețărmurită": "nețărmurit",
    "nețărmurite": "nețărmurit",
    "nețărmuritei": "nețărmurit",
    "nețărmuritele": "nețărmurit",
    "nețărmuritelor": "nețărmurit",
    "nețărmuriți": "nețărmurit",
    "nețărmuriții": "nețărmurit",
    "nețărmuriților": "nețărmurit",
    "nețărmuritul": "nețărmurit",
    "nețărmuritului": "nețărmurit",
    "netârnosita": "netârnosit",
    "netârnosită": "netârnosit",
    "netârnosite": "netârnosit",
    "netârnositei": "netârnosit",
    "netârnositele": "netârnosit",
    "netârnositelor": "netârnosit",
    "netârnosiți": "netârnosit",
    "netârnosiții": "netârnosit",
    "netârnosiților": "netârnosit",
    "netârnositul": "netârnosit",
    "netârnositului": "netârnosit",
    "netârșâita": "netârșâit",
    "netârșâită": "netârșâit",
    "netârșâite": "netârșâit",
    "netârșâitei": "netârșâit",
    "netârșâitele": "netârșâit",
    "netârșâitelor": "netârșâit",
    "netârșâiți": "netârșâit",
    "netârșâiții": "netârșâit",
    "netârșâiților": "netârșâit",
    "netârșâitul": "netârșâit",
    "netârșâitului": "netârșâit",
    "netasata": "netasat",
    "netasată": "netasat",
    "netasate": "netasat",
    "netasatei": "netasat",
    "netasatele": "netasat",
    "netasatelor": "netasat",
    "netasați": "netasat",
    "netasații": "netasat",
    "netasaților": "netasat",
    "netasatul": "netasat",
    "netasatului": "netasat",
    "nețâșnită": "nețâșnit",
    "nețâșnite": "nețâșnit",
    "nețâșniți": "nețâșnit",
    "netatonata": "netatonat",
    "netatonată": "netatonat",
    "netatonate": "netatonat",
    "netatonatei": "netatonat",
    "netatonatele": "netatonat",
    "netatonatelor": "netatonat",
    "netatonați": "netatonat",
    "netatonații": "netatonat",
    "netatonaților": "netatonat",
    "netatonatul": "netatonat",
    "netatonatului": "netatonat",
    "netatuata": "netatuat",
    "netatuată": "netatuat",
    "netatuate": "netatuat",
    "netatuatei": "netatuat",
    "netatuatele": "netatuat",
    "netatuatelor": "netatuat",
    "netatuați": "netatuat",
    "netatuații": "netatuat",
    "netatuaților": "netatuat",
    "netatuatul": "netatuat",
    "netatuatului": "netatuat",
    "neteda": "neted",
    "netedă": "neted",
    "netede": "neted",
    "netedei": "neted",
    "netedele": "neted",
    "netedelor": "neted",
    "netedul": "neted",
    "netedului": "neted",
    "netezi": "neted",
    "netezii": "neted",
    "netezilor": "neted",
    "neteleghidata": "neteleghidat",
    "neteleghidată": "neteleghidat",
    "neteleghidate": "neteleghidat",
    "neteleghidatei": "neteleghidat",
    "neteleghidatele": "neteleghidat",
    "neteleghidatelor": "neteleghidat",
    "neteleghidați": "neteleghidat",
    "neteleghidații": "neteleghidat",
    "neteleghidaților": "neteleghidat",
    "neteleghidatul": "neteleghidat",
    "neteleghidatului": "neteleghidat",
    "netemeinicia": "netemeinicie",
    "netemeiniciei": "netemeinicie",
    "netemeinicii": "netemeinicie",
    "netemeiniciile": "netemeinicie",
    "netemeiniciilor": "netemeinicie",
    "netemperata": "netemperat",
    "netemperată": "netemperat",
    "netemperate": "netemperat",
    "netemperatei": "netemperat",
    "netemperatele": "netemperat",
    "netemperatelor": "netemperat",
    "netemperați": "netemperat",
    "netemperații": "netemperat",
    "netemperaților": "netemperat",
    "netemperatul": "netemperat",
    "netemperatului": "netemperat",
    "netemuta": "netemut",
    "netemută": "netemut",
    "netemute": "netemut",
    "netemutei": "netemut",
    "netemutele": "netemut",
    "netemutelor": "netemut",
    "netemuți": "netemut",
    "netemuții": "netemut",
    "netemuților": "netemut",
    "netemutul": "netemut",
    "netemutului": "netemut",
    "netentata": "netentat",
    "netentată": "netentat",
    "netentate": "netentat",
    "netentatei": "netentat",
    "netentatele": "netentat",
    "netentatelor": "netentat",
    "netentați": "netentat",
    "netentații": "netentat",
    "netentaților": "netentat",
    "netentatul": "netentat",
    "netentatului": "netentat",
    "neteoretizata": "neteoretizat",
    "neteoretizată": "neteoretizat",
    "neteoretizate": "neteoretizat",
    "neteoretizatei": "neteoretizat",
    "neteoretizatele": "neteoretizat",
    "neteoretizatelor": "neteoretizat",
    "neteoretizați": "neteoretizat",
    "neteoretizații": "neteoretizat",
    "neteoretizaților": "neteoretizat",
    "neteoretizatul": "neteoretizat",
    "neteoretizatului": "neteoretizat",
    "neterfelita": "neterfelit",
    "neterfelită": "neterfelit",
    "neterfelite": "neterfelit",
    "neterfelitei": "neterfelit",
    "neterfelitele": "neterfelit",
    "neterfelitelor": "neterfelit",
    "neterfeliți": "neterfelit",
    "neterfeliții": "neterfelit",
    "neterfeliților": "neterfelit",
    "neterfelitul": "neterfelit",
    "neterfelitului": "neterfelit",
    "netergiversata": "netergiversat",
    "netergiversată": "netergiversat",
    "netergiversate": "netergiversat",
    "netergiversatei": "netergiversat",
    "netergiversatele": "netergiversat",
    "netergiversatelor": "netergiversat",
    "netergiversați": "netergiversat",
    "netergiversații": "netergiversat",
    "netergiversaților": "netergiversat",
    "netergiversatul": "netergiversat",
    "netetergiversatului": "netergiversat",
    "netermificata": "netermificat",
    "netermificată": "netermificat",
    "netermificate": "netermificat",
    "netermificatei": "netermificat",
    "netermificatele": "netermificat",
    "netermificatelor": "netermificat",
    "netermificați": "netermificat",
    "netermificații": "netermificat",
    "netermificaților": "netermificat",
    "netermificatul": "netermificat",
    "netermificatului": "netermificat",
    "neterminata": "neterminat",
    "neterminată": "neterminat",
    "neterminate": "neterminat",
    "neterminatei": "neterminat",
    "neterminatele": "neterminat",
    "neterminatelor": "neterminat",
    "neterminați": "neterminat",
    "neterminații": "neterminat",
    "neterminaților": "neterminat",
    "neterminatul": "neterminat",
    "neterminatului": "neterminat",
    "netermoficata": "netermoficat",
    "netermoficată": "netermoficat",
    "netermoficate": "netermoficat",
    "netermoficatei": "netermoficat",
    "netermoficatele": "netermoficat",
    "netermoficatelor": "netermoficat",
    "netermoficați": "netermoficat",
    "netermoficații": "netermoficat",
    "netermoficaților": "netermoficat",
    "netermoficatul": "netermoficat",
    "netermoficatului": "netermoficat",
    "neterorizata": "neterorizat",
    "neterorizată": "neterorizat",
    "neterorizate": "neterorizat",
    "neterorizatei": "neterorizat",
    "neterorizatele": "neterorizat",
    "neterorizatelor": "neterorizat",
    "neterorizați": "neterorizat",
    "neterorizații": "neterorizat",
    "neterorizaților": "neterorizat",
    "neterorizatul": "neterorizat",
    "neterorizatului": "neterorizat",
    "nețesălata": "nețesălat",
    "nețesălată": "nețesălat",
    "nețesălate": "nețesălat",
    "nețesălatei": "nețesălat",
    "nețesălatele": "nețesălat",
    "nețesălatelor": "nețesălat",
    "nețesălați": "nețesălat",
    "nețesălații": "nețesălat",
    "nețesălaților": "nețesălat",
    "nețesălatul": "nețesălat",
    "nețesălatului": "nețesălat",
    "neteșita": "neteșit",
    "neteșită": "neteșit",
    "neteșite": "neteșit",
    "neteșitei": "neteșit",
    "neteșitele": "neteșit",
    "neteșitelor": "neteșit",
    "neteșiți": "neteșit",
    "neteșiții": "neteșit",
    "neteșiților": "neteșit",
    "neteșitul": "neteșit",
    "neteșitului": "neteșit",
    "nețestă": "nețest",
    "nețeste": "nețest",
    "nețesți": "nețest",
    "netestata": "netestat",
    "netestată": "netestat",
    "netestate": "netestat",
    "netestatei": "netestat",
    "netestatele": "netestat",
    "netestatelor": "netestat",
    "netestați": "netestat",
    "netestații": "netestat",
    "netestaților": "netestat",
    "netestatul": "netestat",
    "netestatului": "netestat",
    "netezaurizata": "netezaurizat",
    "netezaurizată": "netezaurizat",
    "netezaurizate": "netezaurizat",
    "netezaurizatei": "netezaurizat",
    "netezaurizatele": "netezaurizat",
    "netezaurizatelor": "netezaurizat",
    "netezaurizați": "netezaurizat",
    "netezaurizații": "netezaurizat",
    "netezaurizaților": "netezaurizat",
    "netezaurizatul": "netezaurizat",
    "netezaurizatului": "netezaurizat",
    "nemainetezind": "netezi",
    "nemainetezindu": "netezi",
    "nenetezind": "netezi",
    "nenetezindu": "netezi",
    "netezea": "netezi",
    "netezeai": "netezi",
    "netezeam": "netezi",
    "netezească": "netezi",
    "netezeați": "netezi",
    "netezeau": "netezi",
    "netezesc": "netezi",
    "netezește": "netezi",
    "netezești": "netezi",
    "netezii": "netezi",
    "netezim": "netezi",
    "netezind": "netezi",
    "netezindu": "netezi",
    "neteziră": "netezi",
    "netezirăm": "netezi",
    "netezirăți": "netezi",
    "netezise": "netezi",
    "netezisem": "netezi",
    "neteziseră": "netezi",
    "neteziserăm": "netezi",
    "neteziserăți": "netezi",
    "neteziseși": "netezi",
    "neteziși": "netezi",
    "netezit": "netezi",
    "neteziți": "netezi",
    "netezimea": "netezime",
    "netezimi": "netezime",
    "netezimii": "netezime",
    "netezimile": "netezime",
    "netezimilor": "netezime",
    "netezită": "netezit",
    "netezite": "netezit",
    "neteziți": "netezit",
    "neticăita": "neticăit",
    "neticăită": "neticăit",
    "neticăite": "neticăit",
    "neticăitei": "neticăit",
    "neticăitele": "neticăit",
    "neticăitelor": "neticăit",
    "neticăiți": "neticăit",
    "neticăiții": "neticăit",
    "neticăiților": "neticăit",
    "neticăitul": "neticăit",
    "neticăitului": "neticăit",
    "neticăloșită": "neticăloșit",
    "neticăloșite": "neticăloșit",
    "neticăloșiți": "neticăloșit",
    "neticluita": "neticluit",
    "neticluită": "neticluit",
    "neticluite": "neticluit",
    "neticluitei": "neticluit",
    "neticluitele": "neticluit",
    "neticluitelor": "neticluit",
    "neticluiți": "neticluit",
    "neticluiții": "neticluit",
    "neticluiților": "neticluit",
    "neticluitul": "neticluit",
    "neticluitului": "neticluit",
    "neticsita": "neticsit",
    "neticsită": "neticsit",
    "neticsite": "neticsit",
    "neticsitei": "neticsit",
    "neticsitele": "neticsit",
    "neticsitelor": "neticsit",
    "neticsiți": "neticsit",
    "neticsiții": "neticsit",
    "neticsiților": "neticsit",
    "neticsitul": "neticsit",
    "neticsitului": "neticsit",
    "netihnita": "netihnit",
    "netihnită": "netihnit",
    "netihnite": "netihnit",
    "netihnitei": "netihnit",
    "netihnitele": "netihnit",
    "netihnitelor": "netihnit",
    "netihniți": "netihnit",
    "netihniții": "netihnit",
    "netihniților": "netihnit",
    "netihnitul": "netihnit",
    "netihnitului": "netihnit",
    "netinsa": "netins",
    "netinsă": "netins",
    "netinse": "netins",
    "netinsei": "netins",
    "netinsele": "netins",
    "netinselor": "netins",
    "netinși": "netins",
    "netinșii": "netins",
    "netinșilor": "netins",
    "netinsul": "netins",
    "netinsului": "netins",
    "nețintita": "nețintit",
    "nețintită": "nețintit",
    "nețintite": "nețintit",
    "nețintitei": "nețintit",
    "nețintitele": "nețintit",
    "nețintitelor": "nețintit",
    "nețintiți": "nețintit",
    "nețintiții": "nețintit",
    "nețintiților": "nețintit",
    "nețintitul": "nețintit",
    "nețintitului": "nețintit",
    "nețintuita": "nețintuit",
    "nețintuită": "nețintuit",
    "nețintuite": "nețintuit",
    "nețintuitei": "nețintuit",
    "nețintuitele": "nețintuit",
    "nețintuitelor": "nețintuit",
    "nețintuiți": "nețintuit",
    "nețintuitii": "nețintuit",
    "nețintuiții": "nețintuit",
    "nețintuitilor": "nețintuit",
    "nețintuiților": "nețintuit",
    "nețintuitul": "nețintuit",
    "nețintuitului": "nețintuit",
    "neținută": "neținut",
    "neținute": "neținut",
    "neținuți": "neținut",
    "netipărita": "netipărit",
    "netipărită": "netipărit",
    "netipărite": "netipărit",
    "netipăritei": "netipărit",
    "netipăritele": "netipărit",
    "netipăritelor": "netipărit",
    "netipăriți": "netipărit",
    "netipăriții": "netipărit",
    "netipăriților": "netipărit",
    "netipăritul": "netipărit",
    "netipăritului": "netipărit",
    "nețipata": "nețipat",
    "nețipată": "nețipat",
    "nețipate": "nețipat",
    "nețipatei": "nețipat",
    "nețipatele": "nețipat",
    "nețipatelor": "nețipat",
    "nețipați": "nețipat",
    "nețipații": "nețipat",
    "nețipaților": "nețipat",
    "nețipatul": "nețipat",
    "nețipatului": "nețipat",
    "netipizata": "netipizat",
    "netipizată": "netipizat",
    "netipizate": "netipizat",
    "netipizatei": "netipizat",
    "netipizatele": "netipizat",
    "netipizatelor": "netipizat",
    "netipizați": "netipizat",
    "netipizații": "netipizat",
    "netipizaților": "netipizat",
    "netipizatul": "netipizat",
    "netipizatului": "netipizat",
    "netiranizată": "netiranizat",
    "netiranizate": "netiranizat",
    "netiranizați": "netiranizat",
    "netitrata": "netitrat",
    "netitrată": "netitrat",
    "netitrate": "netitrat",
    "netitratei": "netitrat",
    "netitratele": "netitrat",
    "netitratelor": "netitrat",
    "netitrați": "netitrat",
    "netitrații": "netitrat",
    "netitraților": "netitrat",
    "netitratul": "netitrat",
    "netitratului": "netitrat",
    "netitularizaii": "netitularizat",
    "netitularizata": "netitularizat",
    "netitularizată": "netitularizat",
    "netitularizate": "netitularizat",
    "netitularizatei": "netitularizat",
    "netitularizatele": "netitularizat",
    "netitularizatelor": "netitularizat",
    "netitularizați": "netitularizat",
    "netitularizaților": "netitularizat",
    "netitularizatul": "netitularizat",
    "netitularizatului": "netitularizat",
    "netoastata": "netoastat",
    "netoastată": "netoastat",
    "netoastate": "netoastat",
    "netoastatei": "netoastat",
    "netoastatele": "netoastat",
    "netoastatelor": "netoastat",
    "netoastați": "netoastat",
    "netoastații": "netoastat",
    "netoastaților": "netoastat",
    "netoastatul": "netoastat",
    "netoastatului": "netoastat",
    "netoata": "netoată",
    "netoate": "netoată",
    "netoatei": "netoată",
    "netoatele": "netoată",
    "netoatelor": "netoată",
    "netocita": "netocit",
    "netocită": "netocit",
    "netocite": "netocit",
    "netocitei": "netocit",
    "netocitele": "netocit",
    "netocitelor": "netocit",
    "netociți": "netocit",
    "netociții": "netocit",
    "netociților": "netocit",
    "netocitul": "netocit",
    "netocitului": "netocit",
    "netocmita": "netocmit",
    "netocmită": "netocmit",
    "netocmite": "netocmit",
    "netocmitei": "netocmit",
    "netocmitele": "netocmit",
    "netocmitelor": "netocmit",
    "netocmiți": "netocmit",
    "netocmiții": "netocmit",
    "netocmiților": "netocmit",
    "netocmitul": "netocmit",
    "netocmitului": "netocmit",
    "netolerata": "netolerat",
    "netolerată": "netolerat",
    "netolerate": "netolerat",
    "netoleratei": "netolerat",
    "netoleratele": "netolerat",
    "netoleratelor": "netolerat",
    "netolerați": "netolerat",
    "netolerații": "netolerat",
    "netoleraților": "netolerat",
    "netoleratul": "netolerat",
    "netoleratului": "netolerat",
    "netologita": "netologit",
    "netologită": "netologit",
    "netologite": "netologit",
    "netologitei": "netologit",
    "netologitele": "netologit",
    "netologitelor": "netologit",
    "netologiți": "netologit",
    "netologiții": "netologit",
    "netologiților": "netologit",
    "netologitul": "netologit",
    "netologitului": "netologit",
    "netonificata": "netonificat",
    "netonificată": "netonificat",
    "netonificate": "netonificat",
    "netonificatei": "netonificat",
    "netonificatele": "netonificat",
    "netonificatelor": "netonificat",
    "netonificați": "netonificat",
    "netonificații": "netonificat",
    "netonificaților": "netonificat",
    "netonificatul": "netonificat",
    "netonificatului": "netonificat",
    "nețopăita": "nețopăit",
    "nețopăită": "nețopăit",
    "nețopăite": "nețopăit",
    "nețopăitei": "nețopăit",
    "nețopăitele": "nețopăit",
    "nețopăitelor": "nețopăit",
    "nețopăiți": "nețopăit",
    "nețopăiții": "nețopăit",
    "nețopăiților": "nețopăit",
    "nețopăitul": "nețopăit",
    "nețopăitului": "nețopăit",
    "netopita": "netopit",
    "netopită": "netopit",
    "netopite": "netopit",
    "netopitei": "netopit",
    "netopitele": "netopit",
    "netopitelor": "netopit",
    "netopiți": "netopit",
    "netopiții": "netopit",
    "netopiților": "netopit",
    "netopitul": "netopit",
    "netopitului": "netopit",
    "netoropita": "netoropit",
    "netoropită": "netoropit",
    "netoropite": "netoropit",
    "netoropitei": "netoropit",
    "netoropitele": "netoropit",
    "netoropitelor": "netoropit",
    "netoropiți": "netoropit",
    "netoropiții": "netoropit",
    "netoropiților": "netoropit",
    "netoropitul": "netoropit",
    "netoropitului": "netoropit",
    "netorturata": "netorturat",
    "netorturată": "netorturat",
    "netorturate": "netorturat",
    "netorturatei": "netorturat",
    "netorturatele": "netorturat",
    "netorturatelor": "netorturat",
    "netorturați": "netorturat",
    "netorturații": "netorturat",
    "netorturaților": "netorturat",
    "netorturatul": "netorturat",
    "netorturatului": "netorturat",
    "netota": "netot",
    "netotă": "netot",
    "netote": "netot",
    "netotei": "netot",
    "netotele": "netot",
    "netotelor": "netot",
    "netoți": "netot",
    "netoții": "netot",
    "netoților": "netot",
    "netotul": "netot",
    "netotului": "netot",
    "netracasata": "netracasat",
    "netracasată": "netracasat",
    "netracasate": "netracasat",
    "netracasatei": "netracasat",
    "netracasatele": "netracasat",
    "netracasatelor": "netracasat",
    "netracasați": "netracasat",
    "netracasații": "netracasat",
    "netracasaților": "netracasat",
    "netracasatul": "netracasat",
    "netracasatului": "netracasat",
    "netrădata": "netrădat",
    "netrădată": "netrădat",
    "netrădate": "netrădat",
    "netrădatei": "netrădat",
    "netrădatele": "netrădat",
    "netrădatelor": "netrădat",
    "netrădați": "netrădat",
    "netrădații": "netrădat",
    "netrădaților": "netrădat",
    "netrădatul": "netrădat",
    "netrădatului": "netrădat",
    "netradusa": "netradus",
    "netradusă": "netradus",
    "netraduse": "netradus",
    "netradusei": "netradus",
    "netradusele": "netradus",
    "netraduselor": "netradus",
    "netraduși": "netradus",
    "netradușii": "netradus",
    "netradușilor": "netradus",
    "netradusul": "netradus",
    "netradusului": "netradus",
    "netraficata": "netraficat",
    "netraficată": "netraficat",
    "netraficate": "netraficat",
    "netraficatei": "netraficat",
    "netraficatele": "netraficat",
    "netraficatelor": "netraficat",
    "netraficați": "netraficat",
    "netraficații": "netraficat",
    "netraficaților": "netraficat",
    "netraficatul": "netraficat",
    "netraficatului": "netraficat",
    "netrăită": "netrăit",
    "netrăite": "netrăit",
    "netrăiți": "netrăit",
    "netrambalată": "netrambalat",
    "netrambalate": "netrambalat",
    "netrambalați": "netrambalat",
    "netrăncănita": "netrăncănit",
    "netrăncănită": "netrăncănit",
    "netrăncănite": "netrăncănit",
    "netrăncănitei": "netrăncănit",
    "netrăncănitele": "netrăncănit",
    "netrăncănitelor": "netrăncănit",
    "netrăncăniți": "netrăncănit",
    "netrăncăniții": "netrăncănit",
    "netrăncăniților": "netrăncănit",
    "netrăncănitul": "netrăncănit",
    "netrăncănitului": "netrăncănit",
    "netrândăvita": "netrândăvit",
    "netrândăvită": "netrândăvit",
    "netrândăvite": "netrândăvit",
    "netrândăvitei": "netrândăvit",
    "netrândăvitele": "netrândăvit",
    "netrândăvitelor": "netrândăvit",
    "netrândăviți": "netrândăvit",
    "netrândăviții": "netrândăvit",
    "netrândăviților": "netrândăvit",
    "netrândăvitul": "netrândăvit",
    "netrândăvitului": "netrândăvit",
    "netranșata": "netranșat",
    "netranșată": "netranșat",
    "netranșate": "netranșat",
    "netranșatei": "netranșat",
    "netranșatele": "netranșat",
    "netranșatelor": "netranșat",
    "netranșați": "netranșat",
    "netranșații": "netranșat",
    "netranșaților": "netranșat",
    "netranșatul": "netranșat",
    "netranșatului": "netranșat",
    "netransbordata": "netransbordat",
    "netransbordată": "netransbordat",
    "netransbordate": "netransbordat",
    "netransbordatei": "netransbordat",
    "netransbordatele": "netransbordat",
    "netransbordatelor": "netransbordat",
    "netransbordați": "netransbordat",
    "netransbordații": "netransbordat",
    "netransbordaților": "netransbordat",
    "netransbordatul": "netransbordat",
    "netransbordatului": "netransbordat",
    "netranscrisa": "netranscris",
    "netranscrisă": "netranscris",
    "netranscrise": "netranscris",
    "netranscrisei": "netranscris",
    "netranscrisele": "netranscris",
    "netranscriselor": "netranscris",
    "netranscriși": "netranscris",
    "netranscrișii": "netranscris",
    "netranscrișilor": "netranscris",
    "netranscrisul": "netranscris",
    "netranscrisului": "netranscris",
    "netransferata": "netransferat",
    "netransferată": "netransferat",
    "netransferate": "netransferat",
    "netransferatei": "netransferat",
    "netransferatele": "netransferat",
    "netransferatelor": "netransferat",
    "netransferați": "netransferat",
    "netransferații": "netransferat",
    "netransferaților": "netransferat",
    "netransferatul": "netransferat",
    "netransferatului": "netransferat",
    "netransformata": "netransformat",
    "netransformată": "netransformat",
    "netransformate": "netransformat",
    "netransformatei": "netransformat",
    "netransformatele": "netransformat",
    "netransformatelor": "netransformat",
    "netransformați": "netransformat",
    "netransformații": "netransformat",
    "netransformaților": "netransformat",
    "netransformatul": "netransformat",
    "netransformatului": "netransformat",
    "netransmisa": "netransmis",
    "netransmisă": "netransmis",
    "netransmise": "netransmis",
    "netransmisei": "netransmis",
    "netransmisele": "netransmis",
    "netransmiselor": "netransmis",
    "netransmiși": "netransmis",
    "netransmișii": "netransmis",
    "netransmișilor": "netransmis",
    "netransmisul": "netransmis",
    "netransmisului": "netransmis",
    "netranspirata": "netranspirat",
    "netranspirată": "netranspirat",
    "netranspirate": "netranspirat",
    "netranspiratei": "netranspirat",
    "netranspiratele": "netranspirat",
    "netranspiratelor": "netranspirat",
    "netranspirați": "netranspirat",
    "netranspirații": "netranspirat",
    "netranspiraților": "netranspirat",
    "netranspiratul": "netranspirat",
    "netranspiratului": "netranspirat",
    "netransplantata": "netransplantat",
    "netransplantată": "netransplantat",
    "netransplantate": "netransplantat",
    "netransplantatei": "netransplantat",
    "netransplantatele": "netransplantat",
    "netransplantatelor": "netransplantat",
    "netransplantați": "netransplantat",
    "netransplantații": "netransplantat",
    "netransplantaților": "netransplantat",
    "netransplantatul": "netransplantat",
    "netransplantatului": "netransplantat",
    "netransportabila": "netransportabil",
    "netransportabilă": "netransportabil",
    "netransportabile": "netransportabil",
    "netransportabilei": "netransportabil",
    "netransportabilele": "netransportabil",
    "netransportabilelor": "netransportabil",
    "netransportabili": "netransportabil",
    "netransportabilii": "netransportabil",
    "netransportabililor": "netransportabil",
    "netransportabilul": "netransportabil",
    "netransportabilului": "netransportabil",
    "netransportata": "netransportat",
    "netransportată": "netransportat",
    "netransportate": "netransportat",
    "netransportatei": "netransportat",
    "netransportatele": "netransportat",
    "netransportatelor": "netransportat",
    "netransportați": "netransportat",
    "netransportații": "netransportat",
    "netransportaților": "netransportat",
    "netransportatul": "netransportat",
    "netransportatului": "netransportat",
    "netranspusa": "netranspus",
    "netranspusă": "netranspus",
    "netranspuse": "netranspus",
    "netranspusei": "netranspus",
    "netranspusele": "netranspus",
    "netranspuselor": "netranspus",
    "netranspuși": "netranspus",
    "netranspușii": "netranspus",
    "netranspușilor": "netranspus",
    "netranspusul": "netranspus",
    "netranspusului": "netranspus",
    "netransvazata": "netransvazat",
    "netransvazată": "netransvazat",
    "netransvazate": "netransvazat",
    "netransvazatei": "netransvazat",
    "netransvazatele": "netransvazat",
    "netransvazatelor": "netransvazat",
    "netransvazați": "netransvazat",
    "netransvazații": "netransvazat",
    "netransvazaților": "netransvazat",
    "netransvazatul": "netransvazat",
    "netransvazatului": "netransvazat",
    "netrântita": "netrântit",
    "netrântită": "netrântit",
    "netrântite": "netrântit",
    "netrântitei": "netrântit",
    "netrântitele": "netrântit",
    "netrântitelor": "netrântit",
    "netrântiți": "netrântit",
    "netrântiții": "netrântit",
    "netrântiților": "netrântit",
    "netrântitul": "netrântit",
    "netrântitului": "netrântit",
    "netrasa": "netras",
    "netrasă": "netras",
    "netrase": "netras",
    "netrasei": "netras",
    "netrasele": "netras",
    "netraselor": "netras",
    "netrași": "netras",
    "netrașii": "netras",
    "netrașilor": "netras",
    "netrasul": "netras",
    "netrasului": "netras",
    "netrasata": "netrasat",
    "netrasată": "netrasat",
    "netrasate": "netrasat",
    "netrasatei": "netrasat",
    "netrasatele": "netrasat",
    "netrasatelor": "netrasat",
    "netrasați": "netrasat",
    "netrasații": "netrasat",
    "netrasaților": "netrasat",
    "netrasatul": "netrasat",
    "netrasatului": "netrasat",
    "netratata": "netratat",
    "netratată": "netratat",
    "netratate": "netratat",
    "netratatei": "netratat",
    "netratatele": "netratat",
    "netratatelor": "netratat",
    "netratați": "netratat",
    "netratații": "netratat",
    "netrataților": "netratat",
    "netratatul": "netratat",
    "netratatului": "netratat",
    "netraumatizata": "netraumatizat",
    "netraumatizată": "netraumatizat",
    "netraumatizate": "netraumatizat",
    "netraumatizatei": "netraumatizat",
    "netraumatizatele": "netraumatizat",
    "netraumatizatelor": "netraumatizat",
    "netraumatizați": "netraumatizat",
    "netraumatizații": "netraumatizat",
    "netraumatizaților": "netraumatizat",
    "netraumatizatul": "netraumatizat",
    "netraumatizatului": "netraumatizat",
    "netraversata": "netraversat",
    "netraversată": "netraversat",
    "netraversate": "netraversat",
    "netraversatei": "netraversat",
    "netraversatele": "netraversat",
    "netraversatelor": "netraversat",
    "netraversați": "netraversat",
    "netraversații": "netraversat",
    "netraversaților": "netraversat",
    "netraversatul": "netraversat",
    "netraversatului": "netraversat",
    "netravestita": "netravestit",
    "netravestită": "netravestit",
    "netravestite": "netravestit",
    "netravestitei": "netravestit",
    "netravestitele": "netravestit",
    "netravestitelor": "netravestit",
    "netravestiți": "netravestit",
    "netravestiții": "netravestit",
    "netravestiților": "netravestit",
    "netravestitul": "netravestit",
    "netravestitului": "netravestit",
    "netrebnica": "netrebnic",
    "netrebnică": "netrebnic",
    "netrebnice": "netrebnic",
    "netrebnicei": "netrebnic",
    "netrebnicele": "netrebnic",
    "netrebnicelor": "netrebnic",
    "netrebnici": "netrebnic",
    "netrebnicii": "netrebnic",
    "netrebnicilor": "netrebnic",
    "netrebnicul": "netrebnic",
    "netrebnicului": "netrebnic",
    "netrebnicia": "netrebnicie",
    "netrebniciei": "netrebnicie",
    "netrebnicii": "netrebnicie",
    "netrebniciile": "netrebnicie",
    "netrebniciilor": "netrebnicie",
    "netrecuta": "netrecut",
    "netrecută": "netrecut",
    "netrecute": "netrecut",
    "netrecutei": "netrecut",
    "netrecutele": "netrecut",
    "netrecutelor": "netrecut",
    "netrecuți": "netrecut",
    "netrecuții": "netrecut",
    "netrecuților": "netrecut",
    "netrecutul": "netrecut",
    "netrecutului": "netrecut",
    "netrefilata": "netrefilat",
    "netrefilată": "netrefilat",
    "netrefilate": "netrefilat",
    "netrefilatei": "netrefilat",
    "netrefilatele": "netrefilat",
    "netrefilatelor": "netrefilat",
    "netrefilați": "netrefilat",
    "netrefilații": "netrefilat",
    "netrefilaților": "netrefilat",
    "netrefilatul": "netrefilat",
    "netrefilatului": "netrefilat",
    "netreierata": "netreierat",
    "netreierată": "netreierat",
    "netreierate": "netreierat",
    "netreieratei": "netreierat",
    "netreieratele": "netreierat",
    "netreieratelor": "netreierat",
    "netreierați": "netreierat",
    "netreierații": "netreierat",
    "netreieraților": "netreierat",
    "netreieratul": "netreierat",
    "netreieratului": "netreierat",
    "netremurata": "netremurat",
    "netremurată": "netremurat",
    "netremurate": "netremurat",
    "netremuratei": "netremurat",
    "netremuratele": "netremurat",
    "netremuratelor": "netremurat",
    "netremurați": "netremurat",
    "netremurații": "netremurat",
    "netremuraților": "netremurat",
    "netremuratul": "netremurat",
    "netremuratului": "netremurat",
    "netrenata": "netrenat",
    "netrenată": "netrenat",
    "netrenate": "netrenat",
    "netrenatei": "netrenat",
    "netrenatele": "netrenat",
    "netrenatelor": "netrenat",
    "netrenați": "netrenat",
    "netrenații": "netrenat",
    "netrenaților": "netrenat",
    "netrenatul": "netrenat",
    "netrenatului": "netrenat",
    "netrepădata": "netrepădat",
    "netrepădată": "netrepădat",
    "netrepădate": "netrepădat",
    "netrepădatei": "netrepădat",
    "netrepădatele": "netrepădat",
    "netrepădatelor": "netrepădat",
    "netrepădați": "netrepădat",
    "netrepădații": "netrepădat",
    "netrepădaților": "netrepădat",
    "netrepădatul": "netrepădat",
    "netrepădatului": "netrepădat",
    "netresăltată": "netresăltat",
    "netresăltate": "netresăltat",
    "netresăltați": "netresăltat",
    "netresărita": "netresărit",
    "netresărită": "netresărit",
    "netresărite": "netresărit",
    "netresăritei": "netresărit",
    "netresăritele": "netresărit",
    "netresăritelor": "netresărit",
    "netresăriți": "netresărit",
    "netresăriții": "netresărit",
    "netresăriților": "netresărit",
    "netresăritul": "netresărit",
    "netresăritului": "netresărit",
    "netrezita": "netrezit",
    "netrezită": "netrezit",
    "netrezite": "netrezit",
    "netrezitei": "netrezit",
    "netrezitele": "netrezit",
    "netrezitelor": "netrezit",
    "netreziți": "netrezit",
    "netreziții": "netrezit",
    "netreziților": "netrezit",
    "netrezitul": "netrezit",
    "netrezitului": "netrezit",
    "netriata": "netriat",
    "netriată": "netriat",
    "netriate": "netriat",
    "netriatei": "netriat",
    "netriatele": "netriat",
    "netriatelor": "netriat",
    "netriați": "netriat",
    "netriații": "netriat",
    "netriaților": "netriat",
    "netriatul": "netriat",
    "netriatului": "netriat",
    "netricotata": "netricotat",
    "netricotată": "netricotat",
    "netricotate": "netricotat",
    "netricotatei": "netricotat",
    "netricotatele": "netricotat",
    "netricotatelor": "netricotat",
    "netricotați": "netricotat",
    "netricotații": "netricotat",
    "netricotaților": "netricotat",
    "netricotatul": "netricotat",
    "netricotatului": "netricotat",
    "netrimisa": "netrimis",
    "netrimisă": "netrimis",
    "netrimise": "netrimis",
    "netrimisei": "netrimis",
    "netrimisele": "netrimis",
    "netrimiselor": "netrimis",
    "netrimiși": "netrimis",
    "netrimișii": "netrimis",
    "netrimișilor": "netrimis",
    "netrimisul": "netrimis",
    "netrimisului": "netrimis",
    "netriplata": "netriplat",
    "netriplată": "netriplat",
    "netriplate": "netriplat",
    "netriplatei": "netriplat",
    "netriplatele": "netriplat",
    "netriplatelor": "netriplat",
    "netriplați": "netriplat",
    "netriplații": "netriplat",
    "netriplaților": "netriplat",
    "netriplatul": "netriplat",
    "netriplatului": "netriplat",
    "netrișata": "netrișat",
    "netrișată": "netrișat",
    "netrișate": "netrișat",
    "netrișatei": "netrișat",
    "netrișatele": "netrișat",
    "netrișatelor": "netrișat",
    "netrișați": "netrișat",
    "netrișații": "netrișat",
    "netrișaților": "netrișat",
    "netrișatul": "netrișat",
    "netrișatului": "netrișat",
    "netriumfata": "netriumfat",
    "netriumfată": "netriumfat",
    "netriumfate": "netriumfat",
    "netriumfatei": "netriumfat",
    "netriumfatele": "netriumfat",
    "netriumfatelor": "netriumfat",
    "netriumfați": "netriumfat",
    "netriumfații": "netriumfat",
    "netriumfaților": "netriumfat",
    "netriumfatul": "netriumfat",
    "netriumfatului": "netriumfat",
    "netronata": "netronat",
    "netronată": "netronat",
    "netronate": "netronat",
    "netronatei": "netronat",
    "netronatele": "netronat",
    "netronatelor": "netronat",
    "netronați": "netronat",
    "netronații": "netronat",
    "netronaților": "netronat",
    "netronatul": "netronat",
    "netronatului": "netronat",
    "netropăita": "netropăit",
    "netropăită": "netropăit",
    "netropăite": "netropăit",
    "netropăitei": "netropăit",
    "netropăitele": "netropăit",
    "netropăitelor": "netropăit",
    "netropăiți": "netropăit",
    "netropăiții": "netropăit",
    "netropăiților": "netropăit",
    "netropăitul": "netropăit",
    "netropăitului": "netropăit",
    "netrosnita": "netrosnit",
    "netrosnită": "netrosnit",
    "netrosnite": "netrosnit",
    "netrosnitei": "netrosnit",
    "netrosnitele": "netrosnit",
    "netrosnitelor": "netrosnit",
    "netrosniți": "netrosnit",
    "netrosniții": "netrosnit",
    "netrosniților": "netrosnit",
    "netrosnitul": "netrosnit",
    "netrosnitului": "netrosnit",
    "netrucata": "netrucat",
    "netrucată": "netrucat",
    "netrucate": "netrucat",
    "netrucatei": "netrucat",
    "netrucatele": "netrucat",
    "netrucatelor": "netrucat",
    "netrucați": "netrucat",
    "netrucații": "netrucat",
    "netrucaților": "netrucat",
    "netrucatul": "netrucat",
    "netrucatului": "netrucat",
    "netrudita": "netrudit",
    "netrudită": "netrudit",
    "netrudite": "netrudit",
    "netruditei": "netrudit",
    "netruditele": "netrudit",
    "netruditelor": "netrudit",
    "netrudiți": "netrudit",
    "netrudiții": "netrudit",
    "netrudiților": "netrudit",
    "netruditul": "netrudit",
    "netruditului": "netrudit",
    "netrunchiata": "netrunchiat",
    "netrunchiată": "netrunchiat",
    "netrunchiate": "netrunchiat",
    "netrunchiatei": "netrunchiat",
    "netrunchiatele": "netrunchiat",
    "netrunchiatelor": "netrunchiat",
    "netrunchiați": "netrunchiat",
    "netrunchiații": "netrunchiat",
    "netrunchiaților": "netrunchiat",
    "netrunchiatul": "netrunchiat",
    "netrunchiatului": "netrunchiat",
    "nețuguită": "nețuguit",
    "nețuguite": "nețuguit",
    "nețuguiți": "nețuguit",
    "netulburata": "netulburat",
    "netulburată": "netulburat",
    "netulburate": "netulburat",
    "netulburatei": "netulburat",
    "netulburatele": "netulburat",
    "netulburatelor": "netulburat",
    "netulburați": "netulburat",
    "netulburații": "netulburat",
    "netulburaților": "netulburat",
    "netulburatul": "netulburat",
    "netulburatului": "netulburat",
    "netulita": "netulit",
    "netulită": "netulit",
    "netulite": "netulit",
    "netulitei": "netulit",
    "netulitele": "netulit",
    "netulitelor": "netulit",
    "netuliți": "netulit",
    "netuliții": "netulit",
    "netuliților": "netulit",
    "netulitul": "netulit",
    "netulitului": "netulit",
    "netumefiata": "netumefiat",
    "netumefiată": "netumefiat",
    "netumefiate": "netumefiat",
    "netumefiatei": "netumefiat",
    "netumefiatele": "netumefiat",
    "netumefiatelor": "netumefiat",
    "netumefiați": "netumefiat",
    "netumefiații": "netumefiat",
    "netumefiaților": "netumefiat",
    "netumefiatul": "netumefiat",
    "netumefiatului": "netumefiat",
    "netunata": "netunat",
    "netunată": "netunat",
    "netunate": "netunat",
    "netunatei": "netunat",
    "netunatele": "netunat",
    "netunatelor": "netunat",
    "netunați": "netunat",
    "netunații": "netunat",
    "netunaților": "netunat",
    "netunatul": "netunat",
    "netunatului": "netunat",
    "netunsa": "netuns",
    "netunsă": "netuns",
    "netunse": "netuns",
    "netunsei": "netuns",
    "netunsele": "netuns",
    "netunselor": "netuns",
    "netunși": "netuns",
    "netunșii": "netuns",
    "netunșilor": "netuns",
    "netunsul": "netuns",
    "netunsului": "netuns",
    "netupilată": "netupilat",
    "netupilate": "netupilat",
    "netupilați": "netupilat",
    "neturbata": "neturbat",
    "neturbată": "neturbat",
    "neturbate": "neturbat",
    "neturbatei": "neturbat",
    "neturbatele": "neturbat",
    "neturbatelor": "neturbat",
    "neturbați": "neturbat",
    "neturbații": "neturbat",
    "neturbaților": "neturbat",
    "neturbatul": "neturbat",
    "neturbatului": "neturbat",
    "neturmentata": "neturmentat",
    "neturmentată": "neturmentat",
    "neturmentate": "neturmentat",
    "neturmentatei": "neturmentat",
    "neturmentatele": "neturmentat",
    "neturmentatelor": "neturmentat",
    "neturmentați": "neturmentat",
    "neturmentații": "neturmentat",
    "neturmentaților": "neturmentat",
    "neturmentatul": "neturmentat",
    "neturmentatului": "neturmentat",
    "neturnata": "neturnat",
    "neturnată": "neturnat",
    "neturnate": "neturnat",
    "neturnatei": "neturnat",
    "neturnatele": "neturnat",
    "neturnatelor": "neturnat",
    "neturnați": "neturnat",
    "neturnații": "neturnat",
    "neturnaților": "neturnat",
    "neturnatul": "neturnat",
    "neturnatului": "neturnat",
    "neturtita": "neturtit",
    "neturtită": "neturtit",
    "neturtite": "neturtit",
    "neturtitei": "neturtit",
    "neturtitele": "neturtit",
    "neturtitelor": "neturtit",
    "neturtiți": "neturtit",
    "neturtiții": "neturtit",
    "neturtiților": "neturtit",
    "neturtitul": "neturtit",
    "neturtitului": "neturtit",
    "neturuita": "neturuit",
    "neturuită": "neturuit",
    "neturuite": "neturuit",
    "neturuitei": "neturuit",
    "neturuitele": "neturuit",
    "neturuitelor": "neturuit",
    "neturuiți": "neturuit",
    "neturuiții": "neturuit",
    "neturuiților": "neturuit",
    "neturuitul": "neturuit",
    "neturuitului": "neturuit",
    "netușita": "netușit",
    "netușită": "netușit",
    "netușite": "netușit",
    "netușitei": "netușit",
    "netușitele": "netușit",
    "netușitelor": "netușit",
    "netușiți": "netușit",
    "netușiții": "netușit",
    "netușiților": "netușit",
    "netușitul": "netușit",
    "netușitului": "netușit",
    "neucenicită": "neucenicit",
    "neucenicite": "neucenicit",
    "neuceniciți": "neucenicit",
    "neucisă": "neucis",
    "neucise": "neucis",
    "neuciși": "neucis",
    "neudată": "neudat",
    "neudate": "neudat",
    "neudați": "neudat",
    "neuguită": "neuguit",
    "neuguite": "neuguit",
    "neuguiți": "neuguit",
    "neuimita": "neuimit",
    "neuimită": "neuimit",
    "neuimite": "neuimit",
    "neuimitei": "neuimit",
    "neuimitele": "neuimit",
    "neuimitelor": "neuimit",
    "neuimiți": "neuimit",
    "neuimiții": "neuimit",
    "neuimiților": "neuimit",
    "neuimitul": "neuimit",
    "neuimitului": "neuimit",
    "neuitata": "neuitat",
    "neuitată": "neuitat",
    "neuitate": "neuitat",
    "neuitatei": "neuitat",
    "neuitatele": "neuitat",
    "neuitatelor": "neuitat",
    "neuitați": "neuitat",
    "neuitații": "neuitat",
    "neuitaților": "neuitat",
    "neuitatul": "neuitat",
    "neuitatului": "neuitat",
    "neulcerata": "neulcerat",
    "neulcerată": "neulcerat",
    "neulcerate": "neulcerat",
    "neulceratei": "neulcerat",
    "neulceratele": "neulcerat",
    "neulceratelor": "neulcerat",
    "neulcerați": "neulcerat",
    "neulcerații": "neulcerat",
    "neulceraților": "neulcerat",
    "neulceratul": "neulcerat",
    "neulceratului": "neulcerat",
    "neuleiata": "neuleiat",
    "neuleiată": "neuleiat",
    "neuleiate": "neuleiat",
    "neuleiatei": "neuleiat",
    "neuleiatele": "neuleiat",
    "neuleiatelor": "neuleiat",
    "neuleiați": "neuleiat",
    "neuleiații": "neuleiat",
    "neuleiaților": "neuleiat",
    "neuleiatul": "neuleiat",
    "neuleiatului": "neuleiat",
    "neultragiata": "neultragiat",
    "neultragiată": "neultragiat",
    "neultragiate": "neultragiat",
    "neultragiatei": "neultragiat",
    "neultragiatele": "neultragiat",
    "neultragiatelor": "neultragiat",
    "neultragiați": "neultragiat",
    "neultragiatii": "neultragiat",
    "neultragiatilor": "neultragiat",
    "neultragiatul": "neultragiat",
    "neultragiatului": "neultragiat",
    "neulucită": "neulucit",
    "neulucite": "neulucit",
    "neuluciți": "neulucit",
    "neuluita": "neuluit",
    "neuluită": "neuluit",
    "neuluite": "neuluit",
    "neuluitei": "neuluit",
    "neuluitele": "neuluit",
    "neuluitelor": "neuluit",
    "neuluiți": "neuluit",
    "neuluiții": "neuluit",
    "neuluiților": "neuluit",
    "neuluitul": "neuluit",
    "neuluitului": "neuluit",
    "neumanizată": "neumanizat",
    "neumanizate": "neumanizat",
    "neumanizați": "neumanizat",
    "neumblata": "neumblat",
    "neumblată": "neumblat",
    "neumblate": "neumblat",
    "neumblatei": "neumblat",
    "neumblatele": "neumblat",
    "neumblatelor": "neumblat",
    "neumblați": "neumblat",
    "neumblații": "neumblat",
    "neumblaților": "neumblat",
    "neumblatul": "neumblat",
    "neumblatului": "neumblat",
    "neumbrita": "neumbrit",
    "neumbrită": "neumbrit",
    "neumbrite": "neumbrit",
    "neumbritei": "neumbrit",
    "neumbritele": "neumbrit",
    "neumbritelor": "neumbrit",
    "neumbriți": "neumbrit",
    "neumbriții": "neumbrit",
    "neumbriților": "neumbrit",
    "neumbritul": "neumbrit",
    "neumbritului": "neumbrit",
    "neumectată": "neumectat",
    "neumectate": "neumectat",
    "neumectați": "neumectat",
    "neumezita": "neumezit",
    "neumezită": "neumezit",
    "neumezite": "neumezit",
    "neumezitei": "neumezit",
    "neumezitele": "neumezit",
    "neumezitelor": "neumezit",
    "neumeziți": "neumezit",
    "neumeziții": "neumezit",
    "neumeziților": "neumezit",
    "neumezitul": "neumezit",
    "neumezitului": "neumezit",
    "neumflata": "neumflat",
    "neumflată": "neumflat",
    "neumflate": "neumflat",
    "neumflatei": "neumflat",
    "neumflatele": "neumflat",
    "neumflatelor": "neumflat",
    "neumflați": "neumflat",
    "neumflații": "neumflat",
    "neumflaților": "neumflat",
    "neumflatul": "neumflat",
    "neumflatului": "neumflat",
    "neumilita": "neumilit",
    "neumilită": "neumilit",
    "neumilite": "neumilit",
    "neumilitei": "neumilit",
    "neumilitele": "neumilit",
    "neumilitelor": "neumilit",
    "neumiliți": "neumilit",
    "neumiliții": "neumilit",
    "neumiliților": "neumilit",
    "neumilitul": "neumilit",
    "neumilitului": "neumilit",
    "neumpluta": "neumplut",
    "neumplută": "neumplut",
    "neumplute": "neumplut",
    "neumplutei": "neumplut",
    "neumplutele": "neumplut",
    "neumplutelor": "neumplut",
    "neumpluți": "neumplut",
    "neumpluții": "neumplut",
    "neumpluților": "neumplut",
    "neumplutul": "neumplut",
    "neumplutului": "neumplut",
    "neunduita": "neunduit",
    "neunduită": "neunduit",
    "neunduite": "neunduit",
    "neunduitei": "neunduit",
    "neunduitele": "neunduit",
    "neunduitelor": "neunduit",
    "neunduiți": "neunduit",
    "neunduiții": "neunduit",
    "neunduiților": "neunduit",
    "neunduitul": "neunduit",
    "neunduitului": "neunduit",
    "neuneltită": "neuneltit",
    "neuneltite": "neuneltit",
    "neuneltiți": "neuneltit",
    "neunificata": "neunificat",
    "neunificată": "neunificat",
    "neunificate": "neunificat",
    "neunificatei": "neunificat",
    "neunificatele": "neunificat",
    "neunificatelor": "neunificat",
    "neunificați": "neunificat",
    "neunificații": "neunificat",
    "neunificaților": "neunificat",
    "neunificatul": "neunificat",
    "neunificatului": "neunificat",
    "neuniformizata": "neuniformizat",
    "neuniformizată": "neuniformizat",
    "neuniformizate": "neuniformizat",
    "neuniformizatei": "neuniformizat",
    "neuniformizatele": "neuniformizat",
    "neuniformizatelor": "neuniformizat",
    "neuniformizați": "neuniformizat",
    "neuniformizații": "neuniformizat",
    "neuniformizaților": "neuniformizat",
    "neuniformizatul": "neuniformizat",
    "neuniformizatului": "neuniformizat",
    "neunita": "neunit",
    "neunită": "neunit",
    "neunite": "neunit",
    "neunitei": "neunit",
    "neunitele": "neunit",
    "neunitelor": "neunit",
    "neuniți": "neunit",
    "neuniții": "neunit",
    "neuniților": "neunit",
    "neunitul": "neunit",
    "neunitului": "neunit",
    "neunsă": "neuns",
    "neunse": "neuns",
    "neunși": "neuns",
    "neurala": "neural",
    "neurală": "neural",
    "neurale": "neural",
    "neuralei": "neural",
    "neuralele": "neural",
    "neuralelor": "neural",
    "neurali": "neural",
    "neuralii": "neural",
    "neuralilor": "neural",
    "neuralul": "neural",
    "neuralului": "neural",
    "nemaineurastenizând": "neurasteniza",
    "nemaineurastenizându": "neurasteniza",
    "neneurastenizând": "neurasteniza",
    "neneurastenizându": "neurasteniza",
    "neurasteniză": "neurasteniza",
    "neurastenizai": "neurasteniza",
    "neurastenizam": "neurasteniza",
    "neurastenizăm": "neurasteniza",
    "neurastenizând": "neurasteniza",
    "neurastenizându": "neurasteniza",
    "neurastenizară": "neurasteniza",
    "neurastenizarăm": "neurasteniza",
    "neurastenizarăți": "neurasteniza",
    "neurastenizase": "neurasteniza",
    "neurastenizasem": "neurasteniza",
    "neurastenizaseră": "neurasteniza",
    "neurastenizaserăm": "neurasteniza",
    "neurastenizaserăți": "neurasteniza",
    "neurastenizaseși": "neurasteniza",
    "neurastenizași": "neurasteniza",
    "neurastenizat": "neurasteniza",
    "neurastenizați": "neurasteniza",
    "neurastenizau": "neurasteniza",
    "neurastenizează": "neurasteniza",
    "neurastenizez": "neurasteniza",
    "neurastenizeze": "neurasteniza",
    "neurastenizezi": "neurasteniza",
    "neurastenizanta": "neurastenizant",
    "neurastenizantă": "neurastenizant",
    "neurastenizante": "neurastenizant",
    "neurastenizantei": "neurastenizant",
    "neurastenizantele": "neurastenizant",
    "neurastenizantelor": "neurastenizant",
    "neurastenizanți": "neurastenizant",
    "neurastenizanții": "neurastenizant",
    "neurastenizanților": "neurastenizant",
    "neurastenizantul": "neurastenizant",
    "neurastenizantului": "neurastenizant",
    "neurastenizată": "neurastenizat",
    "neurastenizate": "neurastenizat",
    "neurastenizați": "neurastenizat",
    "neurata": "neurat",
    "neurată": "neurat",
    "neurate": "neurat",
    "neuratei": "neurat",
    "neuratele": "neurat",
    "neuratelor": "neurat",
    "neurați": "neurat",
    "neurații": "neurat",
    "neuraților": "neurat",
    "neuratul": "neurat",
    "neuratului": "neurat",
    "neurâtă": "neurât",
    "neurâte": "neurât",
    "neurâți": "neurât",
    "neurâții": "neurât",
    "neurâților": "neurât",
    "neurâtul": "neurât",
    "neurâtului": "neurât",
    "neurâțita": "neurâțit",
    "neurâțită": "neurâțit",
    "neurâțite": "neurâțit",
    "neurâțitei": "neurâțit",
    "neurâțitele": "neurâțit",
    "neurâțitelor": "neurâțit",
    "neurâțiți": "neurâțit",
    "neurâțiții": "neurâțit",
    "neurâțiților": "neurâțit",
    "neurâțitul": "neurâțit",
    "neurâțitului": "neurâțit",
    "neurcata": "neurcat",
    "neurcată": "neurcat",
    "neurcate": "neurcat",
    "neurcatei": "neurcat",
    "neurcatele": "neurcat",
    "neurcatelor": "neurcat",
    "neurcați": "neurcat",
    "neurcații": "neurcat",
    "neurcaților": "neurcat",
    "neurcatul": "neurcat",
    "neurcatului": "neurcat",
    "neurecheata": "neurecheat",
    "neurecheată": "neurecheat",
    "neurecheate": "neurecheat",
    "neurecheatei": "neurecheat",
    "neurecheatele": "neurecheat",
    "neurecheatelor": "neurecheat",
    "neurecheați": "neurecheat",
    "neurecheații": "neurecheat",
    "neurecheaților": "neurecheat",
    "neurecheatul": "neurecheat",
    "neurecheatului": "neurecheat",
    "neurgentată": "neurgentat",
    "neurgentate": "neurgentat",
    "neurgentați": "neurgentat",
    "neurgisita": "neurgisit",
    "neurgisită": "neurgisit",
    "neurgisite": "neurgisit",
    "neurgisitei": "neurgisit",
    "neurgisitele": "neurgisit",
    "neurgisitelor": "neurgisit",
    "neurgisiți": "neurgisit",
    "neurgisiții": "neurgisit",
    "neurgisiților": "neurgisit",
    "neurgisitul": "neurgisit",
    "neurgisitului": "neurgisit",
    "neurlata": "neurlat",
    "neurlată": "neurlat",
    "neurlate": "neurlat",
    "neurlatei": "neurlat",
    "neurlatele": "neurlat",
    "neurlatelor": "neurlat",
    "neurlați": "neurlat",
    "neurlații": "neurlat",
    "neurlaților": "neurlat",
    "neurlatul": "neurlat",
    "neurlatului": "neurlat",
    "neurluita": "neurluit",
    "neurluită": "neurluit",
    "neurluite": "neurluit",
    "neurluitei": "neurluit",
    "neurluitele": "neurluit",
    "neurluitelor": "neurluit",
    "neurluiți": "neurluit",
    "neurluiții": "neurluit",
    "neurluiților": "neurluit",
    "neurluitul": "neurluit",
    "neurluitului": "neurluit",
    "neurmărirea": "neurmărire",
    "neurmăriri": "neurmărire",
    "neurmăririi": "neurmărire",
    "neurmăririle": "neurmărire",
    "neurmăririlor": "neurmărire",
    "neurmărita": "neurmărit",
    "neurmărită": "neurmărit",
    "neurmărite": "neurmărit",
    "neurmăritei": "neurmărit",
    "neurmăritele": "neurmărit",
    "neurmăritelor": "neurmărit",
    "neurmăriți": "neurmărit",
    "neurmăriții": "neurmărit",
    "neurmăriților": "neurmărit",
    "neurmăritul": "neurmărit",
    "neurmăritului": "neurmărit",
    "neurmată": "neurmat",
    "neurmate": "neurmat",
    "neurmați": "neurmat",
    "neurnita": "neurnit",
    "neurnită": "neurnit",
    "neurnite": "neurnit",
    "neurnitei": "neurnit",
    "neurnitele": "neurnit",
    "neurnitelor": "neurnit",
    "neurniți": "neurnit",
    "neurniții": "neurnit",
    "neurniților": "neurnit",
    "neurnitul": "neurnit",
    "neurnitului": "neurnit",
    "neuroleptica": "neuroleptic",
    "neuroleptică": "neuroleptic",
    "neuroleptice": "neuroleptic",
    "neurolepticei": "neuroleptic",
    "neurolepticele": "neuroleptic",
    "neurolepticelor": "neuroleptic",
    "neuroleptici": "neuroleptic",
    "neurolepticii": "neuroleptic",
    "neurolepticilor": "neuroleptic",
    "neurolepticul": "neuroleptic",
    "neurolepticului": "neuroleptic",
    "neurologi": "neurolog",
    "neurologii": "neurolog",
    "neurologilor": "neurolog",
    "neurologul": "neurolog",
    "neurologului": "neurolog",
    "neurologica": "neurologic",
    "neurologică": "neurologic",
    "neurologice": "neurologic",
    "neurologicei": "neurologic",
    "neurologicele": "neurologic",
    "neurologicelor": "neurologic",
    "neurologici": "neurologic",
    "neurologicii": "neurologic",
    "neurologicilor": "neurologic",
    "neurologicul": "neurologic",
    "neurologicului": "neurologic",
    "neurologia": "neurologie",
    "neurologiei": "neurologie",
    "neurologii": "neurologie",
    "neurologiile": "neurologie",
    "neurologiilor": "neurologie",
    "neuromusculara": "neuromuscular",
    "neuromusculară": "neuromuscular",
    "neuromusculare": "neuromuscular",
    "neuromuscularei": "neuromuscular",
    "neuromuscularele": "neuromuscular",
    "neuromuscularelor": "neuromuscular",
    "neuromusculari": "neuromuscular",
    "neuromuscularii": "neuromuscular",
    "neuromuscularilor": "neuromuscular",
    "neuromuscularul": "neuromuscular",
    "neuromuscularului": "neuromuscular",
    "neuroni": "neuron",
    "neuronii": "neuron",
    "neuronilor": "neuron",
    "neuronul": "neuron",
    "neuronului": "neuron",
    "neuroplegica": "neuroplegic",
    "neuroplegică": "neuroplegic",
    "neuroplegice": "neuroplegic",
    "neuroplegicei": "neuroplegic",
    "neuroplegicele": "neuroplegic",
    "neuroplegicelor": "neuroplegic",
    "neuroplegici": "neuroplegic",
    "neuroplegicii": "neuroplegic",
    "neuroplegicilor": "neuroplegic",
    "neuroplegicul": "neuroplegic",
    "neuroplegicului": "neuroplegic",
    "neurosimpatica": "neurosimpatic",
    "neurosimpatică": "neurosimpatic",
    "neurosimpatice": "neurosimpatic",
    "neurosimpaticei": "neurosimpatic",
    "neurosimpaticele": "neurosimpatic",
    "neurosimpaticelor": "neurosimpatic",
    "neurosimpatici": "neurosimpatic",
    "neurosimpaticii": "neurosimpatic",
    "neurosimpaticilor": "neurosimpatic",
    "neurosimpaticul": "neurosimpatic",
    "neurosimpaticului": "neurosimpatic",
    "neurotropa": "neurotrop",
    "neurotropă": "neurotrop",
    "neurotrope": "neurotrop",
    "neurotropei": "neurotrop",
    "neurotropele": "neurotrop",
    "neurotropelor": "neurotrop",
    "neurotropi": "neurotrop",
    "neurotropii": "neurotrop",
    "neurotropilor": "neurotrop",
    "neurotropul": "neurotrop",
    "neurotropului": "neurotrop",
    "neurovegetativa": "neurovegetativ",
    "neurovegetativă": "neurovegetativ",
    "neurovegetative": "neurovegetativ",
    "neurovegetativei": "neurovegetativ",
    "neurovegetativele": "neurovegetativ",
    "neurovegetativelor": "neurovegetativ",
    "neurovegetativi": "neurovegetativ",
    "neurovegetativii": "neurovegetativ",
    "neurovegetativilor": "neurovegetativ",
    "neurovegetativul": "neurovegetativ",
    "neurovegetativului": "neurovegetativ",
    "neursita": "neursit",
    "neursită": "neursit",
    "neursite": "neursit",
    "neursitei": "neursit",
    "neursitele": "neursit",
    "neursitelor": "neursit",
    "neursiți": "neursit",
    "neursiții": "neursit",
    "neursiților": "neursit",
    "neursitul": "neursit",
    "neursitului": "neursit",
    "neurzita": "neurzit",
    "neurzită": "neurzit",
    "neurzite": "neurzit",
    "neurzitei": "neurzit",
    "neurzitele": "neurzit",
    "neurzitelor": "neurzit",
    "neurziți": "neurzit",
    "neurziții": "neurzit",
    "neurziților": "neurzit",
    "neurzitul": "neurzit",
    "neurzitului": "neurzit",
    "neuscata": "neuscat",
    "neuscată": "neuscat",
    "neuscate": "neuscat",
    "neuscatei": "neuscat",
    "neuscatele": "neuscat",
    "neuscatelor": "neuscat",
    "neuscați": "neuscat",
    "neuscații": "neuscat",
    "neuscaților": "neuscat",
    "neuscatul": "neuscat",
    "neuscatului": "neuscat",
    "neusturată": "neusturat",
    "neusturate": "neusturat",
    "neusturați": "neusturat",
    "neusturoiata": "neusturoiat",
    "neusturoiată": "neusturoiat",
    "neusturoiate": "neusturoiat",
    "neusturoiatei": "neusturoiat",
    "neusturoiatele": "neusturoiat",
    "neusturoiatelor": "neusturoiat",
    "neusturoiați": "neusturoiat",
    "neusturoiații": "neusturoiat",
    "neusturoiaților": "neusturoiat",
    "neusturoiatul": "neusturoiat",
    "neusturoiatului": "neusturoiat",
    "neușurata": "neușurat",
    "neușurată": "neușurat",
    "neușurate": "neușurat",
    "neușuratei": "neușurat",
    "neușuratele": "neușurat",
    "neușuratelor": "neușurat",
    "neușurați": "neușurat",
    "neușurații": "neușurat",
    "neușuraților": "neușurat",
    "neușuratul": "neușurat",
    "neușuratului": "neușurat",
    "neutilata": "neutilat",
    "neutilată": "neutilat",
    "neutilate": "neutilat",
    "neutilatei": "neutilat",
    "neutilatele": "neutilat",
    "neutilatelor": "neutilat",
    "neutilați": "neutilat",
    "neutilații": "neutilat",
    "neutilaților": "neutilat",
    "neutilatul": "neutilat",
    "neutilatului": "neutilat",
    "neutilizata": "neutilizat",
    "neutilizată": "neutilizat",
    "neutilizate": "neutilizat",
    "neutilizatei": "neutilizat",
    "neutilizatele": "neutilizat",
    "neutilizatelor": "neutilizat",
    "neutilizați": "neutilizat",
    "neutilizații": "neutilizat",
    "neutilizaților": "neutilizat",
    "neutilizatul": "neutilizat",
    "neutilizatului": "neutilizat",
    "neutrala": "neutral",
    "neutrală": "neutral",
    "neutrale": "neutral",
    "neutralei": "neutral",
    "neutralele": "neutral",
    "neutralelor": "neutral",
    "neutrali": "neutral",
    "neutralii": "neutral",
    "neutralilor": "neutral",
    "neutralul": "neutral",
    "neutralului": "neutral",
    "neutralitatea": "neutralitate",
    "neutralități": "neutralitate",
    "neutralității": "neutralitate",
    "neutralitățile": "neutralitate",
    "neutralităților": "neutralitate",
    "nemaineutralizându": "neutraliza",
    "neneutralizându": "neutraliza",
    "neutraliză": "neutraliza",
    "neutralizai": "neutraliza",
    "neutralizam": "neutraliza",
    "neutralizăm": "neutraliza",
    "neutralizând": "neutraliza",
    "neutralizându": "neutraliza",
    "neutralizară": "neutraliza",
    "neutralizarăm": "neutraliza",
    "neutralizarăți": "neutraliza",
    "neutralizase": "neutraliza",
    "neutralizasem": "neutraliza",
    "neutralizaseră": "neutraliza",
    "neutralizaserăm": "neutraliza",
    "neutralizaserăți": "neutraliza",
    "neutralizaseși": "neutraliza",
    "neutralizași": "neutraliza",
    "neutralizat": "neutraliza",
    "neutralizați": "neutraliza",
    "neutralizau": "neutraliza",
    "neutralizează": "neutraliza",
    "neutralizez": "neutraliza",
    "neutralizeze": "neutraliza",
    "neutralizezi": "neutraliza",
    "neutralizanta": "neutralizant",
    "neutralizantă": "neutralizant",
    "neutralizante": "neutralizant",
    "neutralizantei": "neutralizant",
    "neutralizantele": "neutralizant",
    "neutralizantelor": "neutralizant",
    "neutralizanți": "neutralizant",
    "neutralizanții": "neutralizant",
    "neutralizanților": "neutralizant",
    "neutralizantul": "neutralizant",
    "neutralizantului": "neutralizant",
    "neutralizarea": "neutralizare",
    "neutralizări": "neutralizare",
    "neutralizării": "neutralizare",
    "neutralizările": "neutralizare",
    "neutralizărilor": "neutralizare",
    "neutralizată": "neutralizat",
    "neutralizate": "neutralizat",
    "neutralizați": "neutralizat",
    "neutroni": "neutron",
    "neutronii": "neutron",
    "neutronilor": "neutron",
    "neutronul": "neutron",
    "neutronului": "neutron",
    "neutronica": "neutronic",
    "neutronică": "neutronic",
    "neutronice": "neutronic",
    "neutronicei": "neutronic",
    "neutronicele": "neutronic",
    "neutronicelor": "neutronic",
    "neutronici": "neutronic",
    "neutronicii": "neutronic",
    "neutronicilor": "neutronic",
    "neutronicul": "neutronic",
    "neutronicului": "neutronic",
    "n.": "neutru",
    "neutra": "neutru",
    "neutră": "neutru",
    "neutre": "neutru",
    "neutrei": "neutru",
    "neutrele": "neutru",
    "neutrelor": "neutru",
    "neutri": "neutru",
    "neutrii": "neutru",
    "neutrilor": "neutru",
    "neutrul": "neutru",
    "neutrului": "neutru",
    "neuzata": "neuzat",
    "neuzată": "neuzat",
    "neuzate": "neuzat",
    "neuzatei": "neuzat",
    "neuzatele": "neuzat",
    "neuzatelor": "neuzat",
    "neuzați": "neuzat",
    "neuzații": "neuzat",
    "neuzaților": "neuzat",
    "neuzatul": "neuzat",
    "neuzatului": "neuzat",
    "neuzitată": "neuzitat",
    "neuzitate": "neuzitat",
    "neuzitați": "neuzitat",
    "neuzurpata": "neuzurpat",
    "neuzurpată": "neuzurpat",
    "neuzurpate": "neuzurpat",
    "neuzurpatei": "neuzurpat",
    "neuzurpatele": "neuzurpat",
    "neuzurpatelor": "neuzurpat",
    "neuzurpați": "neuzurpat",
    "neuzurpații": "neuzurpat",
    "neuzurpaților": "neuzurpat",
    "neuzurpatul": "neuzurpat",
    "neuzurpatului": "neuzurpat",
    "nevădită": "nevădit",
    "nevădite": "nevădit",
    "nevădiți": "nevădit",
    "nevăduvita": "nevăduvit",
    "nevăduvită": "nevăduvit",
    "nevăduvite": "nevăduvit",
    "nevăduvitei": "nevăduvit",
    "nevăduvitele": "nevăduvit",
    "nevăduvitelor": "nevăduvit",
    "nevăduviți": "nevăduvit",
    "nevăduviții": "nevăduvit",
    "nevăduviților": "nevăduvit",
    "nevăduvitul": "nevăduvit",
    "nevăduvitului": "nevăduvit",
    "nevăicărită": "nevăicărit",
    "nevăicărite": "nevăicărit",
    "nevăicăriți": "nevăicărit",
    "nevăitată": "nevăitat",
    "nevăitate": "nevăitat",
    "nevăitați": "nevăitat",
    "nevâjâită": "nevâjâit",
    "nevâjâite": "nevâjâit",
    "nevâjâiți": "nevâjâit",
    "nevalidata": "nevalidat",
    "nevalidată": "nevalidat",
    "nevalidate": "nevalidat",
    "nevalidatei": "nevalidat",
    "nevalidatele": "nevalidat",
    "nevalidatelor": "nevalidat",
    "nevalidați": "nevalidat",
    "nevalidații": "nevalidat",
    "nevalidaților": "nevalidat",
    "nevalidatul": "nevalidat",
    "nevalidatului": "nevalidat",
    "nevalorată": "nevalorat",
    "nevalorate": "nevalorat",
    "nevalorați": "nevalorat",
    "nevalorificata": "nevalorificat",
    "nevalorificată": "nevalorificat",
    "nevalorificate": "nevalorificat",
    "nevalorificatei": "nevalorificat",
    "nevalorificatele": "nevalorificat",
    "nevalorificatelor": "nevalorificat",
    "nevalorificați": "nevalorificat",
    "nevalorificații": "nevalorificat",
    "nevalorificaților": "nevalorificat",
    "nevalorificatul": "nevalorificat",
    "nevalorificatului": "nevalorificat",
    "nevalsată": "nevalsat",
    "nevalsate": "nevalsat",
    "nevalsați": "nevalsat",
    "nevămuită": "nevămuit",
    "nevămuite": "nevămuit",
    "nevămuiți": "nevămuit",
    "nevânată": "nevânat",
    "nevânate": "nevânat",
    "nevânați": "nevânat",
    "nevandabilă": "nevandabil",
    "nevandabile": "nevandabil",
    "nevandabili": "nevandabil",
    "nevândută": "nevândut",
    "nevândute": "nevândut",
    "nevânduți": "nevândut",
    "nevânturată": "nevânturat",
    "nevânturate": "nevânturat",
    "nevânturați": "nevânturat",
    "nevânzolită": "nevânzolit",
    "nevânzolite": "nevânzolit",
    "nevânzoliți": "nevânzolit",
    "nevaporizată": "nevaporizat",
    "nevaporizate": "nevaporizat",
    "nevaporizați": "nevaporizat",
    "nevârâtă": "nevârât",
    "nevârâte": "nevârât",
    "nevârâți": "nevârât",
    "nevariata": "nevariat",
    "nevariată": "nevariat",
    "nevariate": "nevariat",
    "nevariatei": "nevariat",
    "nevariatele": "nevariat",
    "nevariatelor": "nevariat",
    "nevariați": "nevariat",
    "nevariații": "nevariat",
    "nevariaților": "nevariat",
    "nevariatul": "nevariat",
    "nevariatului": "nevariat",
    "nevărsata": "nevărsat",
    "nevărsată": "nevărsat",
    "nevărsate": "nevărsat",
    "nevărsatei": "nevărsat",
    "nevărsatele": "nevărsat",
    "nevărsatelor": "nevărsat",
    "nevărsați": "nevărsat",
    "nevărsații": "nevărsat",
    "nevărsaților": "nevărsat",
    "nevărsatul": "nevărsat",
    "nevărsatului": "nevărsat",
    "nevârstnica": "nevârstnic",
    "nevârstnică": "nevârstnic",
    "nevârstnice": "nevârstnic",
    "nevârstnicei": "nevârstnic",
    "nevârstnicele": "nevârstnic",
    "nevârstnicelor": "nevârstnic",
    "nevârstnici": "nevârstnic",
    "nevârstnicii": "nevârstnic",
    "nevârstnicilor": "nevârstnic",
    "nevârstnicul": "nevârstnic",
    "nevârstnicului": "nevârstnic",
    "nevăruita": "nevăruit",
    "nevăruită": "nevăruit",
    "nevăruite": "nevăruit",
    "nevăruitei": "nevăruit",
    "nevăruitele": "nevăruit",
    "nevăruitelor": "nevăruit",
    "nevăruiți": "nevăruit",
    "nevăruiții": "nevăruit",
    "nevăruiților": "nevăruit",
    "nevăruitul": "nevăruit",
    "nevăruitului": "nevăruit",
    "nevascularizata": "nevascularizat",
    "nevascularizată": "nevascularizat",
    "nevascularizate": "nevascularizat",
    "nevascularizatei": "nevascularizat",
    "nevascularizatele": "nevascularizat",
    "nevascularizatelor": "nevascularizat",
    "nevascularizați": "nevascularizat",
    "nevascularizații": "nevascularizat",
    "nevascularizaților": "nevascularizat",
    "nevascularizatul": "nevascularizat",
    "nevascularizatului": "nevascularizat",
    "nevâslită": "nevâslit",
    "nevâslite": "nevâslit",
    "nevâsliți": "nevâslit",
    "nevasta": "nevastă",
    "neveste": "nevastă",
    "nevestei": "nevastă",
    "nevestele": "nevastă",
    "nevestelor": "nevastă",
    "nevăstuica": "nevăstuică",
    "nevăstuici": "nevăstuică",
    "nevăstuicii": "nevăstuică",
    "nevăstuicile": "nevăstuică",
    "nevăstuicilor": "nevăstuică",
    "nevătămata": "nevătămat",
    "nevătămată": "nevătămat",
    "nevătămate": "nevătămat",
    "nevătămatei": "nevătămat",
    "nevătămatele": "nevătămat",
    "nevătămatelor": "nevătămat",
    "nevătămați": "nevătămat",
    "nevătămații": "nevătămat",
    "nevătămaților": "nevătămat",
    "nevătămatul": "nevătămat",
    "nevătămatului": "nevătămat",
    "nevătămătoare": "nevătămător",
    "nevătămători": "nevătămător",
    "nevătămătorii": "nevătămător",
    "nevătămătorilor": "nevătămător",
    "nevătămătorul": "nevătămător",
    "nevătămătorului": "nevătămător",
    "nevătuita": "nevătuit",
    "nevătuită": "nevătuit",
    "nevătuite": "nevătuit",
    "nevătuitei": "nevătuit",
    "nevătuitele": "nevătuit",
    "nevătuitelor": "nevătuit",
    "nevătuiți": "nevătuit",
    "nevătuiții": "nevătuit",
    "nevătuiților": "nevătuit",
    "nevătuitul": "nevătuit",
    "nevătuitului": "nevătuit",
    "nevăzătoarea": "nevăzătoare",
    "nevăzătoarei": "nevăzătoare",
    "nevăzătoarele": "nevăzătoare",
    "nevăzătoarelor": "nevăzătoare",
    "nevăzători": "nevăzător",
    "nevăzătorii": "nevăzător",
    "nevăzătorilor": "nevăzător",
    "nevăzătorul": "nevăzător",
    "nevăzătorului": "nevăzător",
    "nevăzuta": "nevăzut",
    "nevăzută": "nevăzut",
    "nevăzute": "nevăzut",
    "nevăzutei": "nevăzut",
    "nevăzutele": "nevăzut",
    "nevăzutelor": "nevăzut",
    "nevăzuți": "nevăzut",
    "nevăzuții": "nevăzut",
    "nevăzuților": "nevăzut",
    "nevăzutul": "nevăzut",
    "nevăzutului": "nevăzut",
    "nevegetată": "nevegetat",
    "nevegetate": "nevegetat",
    "nevegetați": "nevegetat",
    "nevegheata": "nevegheat",
    "nevegheată": "nevegheat",
    "nevegheate": "nevegheat",
    "nevegheatei": "nevegheat",
    "nevegheatele": "nevegheat",
    "nevegheatelor": "nevegheat",
    "nevegheați": "nevegheat",
    "nevegheații": "nevegheat",
    "nevegheaților": "nevegheat",
    "nevegheatul": "nevegheat",
    "nevegheatului": "nevegheat",
    "nevenerata": "nevenerat",
    "nevenerată": "nevenerat",
    "nevenerate": "nevenerat",
    "neveneratei": "nevenerat",
    "neveneratele": "nevenerat",
    "neveneratelor": "nevenerat",
    "nevenerați": "nevenerat",
    "nevenerații": "nevenerat",
    "neveneraților": "nevenerat",
    "neveneratul": "nevenerat",
    "neveneratului": "nevenerat",
    "nevenită": "nevenit",
    "nevenite": "nevenit",
    "neveniți": "nevenit",
    "neventilată": "neventilat",
    "neventilate": "neventilat",
    "neventilați": "neventilat",
    "neverificata": "neverificat",
    "neverificată": "neverificat",
    "neverificate": "neverificat",
    "neverificatei": "neverificat",
    "neverificatele": "neverificat",
    "neverificatelor": "neverificat",
    "neverificați": "neverificat",
    "neverificații": "neverificat",
    "neverificaților": "neverificat",
    "neverificatul": "neverificat",
    "neverificatului": "neverificat",
    "neverosimila": "neverosimil",
    "neverosimilă": "neverosimil",
    "neverosimile": "neverosimil",
    "neverosimilei": "neverosimil",
    "neverosimilele": "neverosimil",
    "neverosimilelor": "neverosimil",
    "neverosimili": "neverosimil",
    "neverosimilii": "neverosimil",
    "neverosimililor": "neverosimil",
    "neverosimilul": "neverosimil",
    "neverosimilului": "neverosimil",
    "neversificată": "neversificat",
    "neversificate": "neversificat",
    "neversificați": "neversificat",
    "nevertebrata": "nevertebrat",
    "nevertebrată": "nevertebrat",
    "nevertebrate": "nevertebrat",
    "nevertebratei": "nevertebrat",
    "nevertebratele": "nevertebrat",
    "nevertebratelor": "nevertebrat",
    "nevertebrați": "nevertebrat",
    "nevertebrații": "nevertebrat",
    "nevertebraților": "nevertebrat",
    "nevertebratul": "nevertebrat",
    "nevertebratului": "nevertebrat",
    "nevertebrata": "nevertebrată",
    "nevertebrate": "nevertebrată",
    "nevertebratei": "nevertebrată",
    "nevertebratele": "nevertebrată",
    "nevertebratelor": "nevertebrată",
    "neveștejita": "neveștejit",
    "neveștejită": "neveștejit",
    "neveștejite": "neveștejit",
    "neveștejitei": "neveștejit",
    "neveștejitele": "neveștejit",
    "neveștejitelor": "neveștejit",
    "neveștejiți": "neveștejit",
    "neveștejiții": "neveștejit",
    "neveștejiților": "neveștejit",
    "neveștejitul": "neveștejit",
    "neveștejitului": "neveștejit",
    "nevestita": "nevestit",
    "nevestită": "nevestit",
    "nevestite": "nevestit",
    "nevestitei": "nevestit",
    "nevestitele": "nevestit",
    "nevestitelor": "nevestit",
    "nevestiți": "nevestit",
    "nevestiții": "nevestit",
    "nevestiților": "nevestit",
    "nevestitul": "nevestit",
    "nevestitului": "nevestit",
    "nevexată": "nevexat",
    "nevexate": "nevexat",
    "nevexați": "nevexat",
    "neviabila": "neviabil",
    "neviabilă": "neviabil",
    "neviabile": "neviabil",
    "neviabilei": "neviabil",
    "neviabilele": "neviabil",
    "neviabilelor": "neviabil",
    "neviabili": "neviabil",
    "neviabilii": "neviabil",
    "neviabililor": "neviabil",
    "neviabilul": "neviabil",
    "neviabilului": "neviabil",
    "nevibrată": "nevibrat",
    "nevibrate": "nevibrat",
    "nevibrați": "nevibrat",
    "neviciata": "neviciat",
    "neviciată": "neviciat",
    "neviciate": "neviciat",
    "neviciatei": "neviciat",
    "neviciatele": "neviciat",
    "neviciatelor": "neviciat",
    "neviciați": "neviciat",
    "neviciații": "neviciat",
    "neviciaților": "neviciat",
    "neviciatul": "neviciat",
    "neviciatului": "neviciat",
    "neviermuită": "neviermuit",
    "neviermuite": "neviermuit",
    "neviermuiți": "neviermuit",
    "neviețuită": "neviețuit",
    "neviețuite": "neviețuit",
    "neviețuiți": "neviețuit",
    "nevindecabila": "nevindecabil",
    "nevindecabilă": "nevindecabil",
    "nevindecabile": "nevindecabil",
    "nevindecabilei": "nevindecabil",
    "nevindecabilele": "nevindecabil",
    "nevindecabilelor": "nevindecabil",
    "nevindecabili": "nevindecabil",
    "nevindecabilii": "nevindecabil",
    "nevindecabililor": "nevindecabil",
    "nevindecabilul": "nevindecabil",
    "nevindecabilului": "nevindecabil",
    "nevindecata": "nevindecat",
    "nevindecată": "nevindecat",
    "nevindecate": "nevindecat",
    "nevindecatei": "nevindecat",
    "nevindecatele": "nevindecat",
    "nevindecatelor": "nevindecat",
    "nevindecați": "nevindecat",
    "nevindecații": "nevindecat",
    "nevindecaților": "nevindecat",
    "nevindecatul": "nevindecat",
    "nevindecatului": "nevindecat",
    "nevinovata": "nevinovat",
    "nevinovată": "nevinovat",
    "nevinovate": "nevinovat",
    "nevinovatei": "nevinovat",
    "nevinovatele": "nevinovat",
    "nevinovatelor": "nevinovat",
    "nevinovați": "nevinovat",
    "nevinovații": "nevinovat",
    "nevinovaților": "nevinovat",
    "nevinovatul": "nevinovat",
    "nevinovatului": "nevinovat",
    "nevinovăția": "nevinovăție",
    "nevinovăției": "nevinovăție",
    "nevinovății": "nevinovăție",
    "nevinovățiile": "nevinovăție",
    "nevinovățiilor": "nevinovăție",
    "neviolata": "neviolat",
    "neviolată": "neviolat",
    "neviolate": "neviolat",
    "neviolatei": "neviolat",
    "neviolatele": "neviolat",
    "neviolatelor": "neviolat",
    "neviolați": "neviolat",
    "neviolații": "neviolat",
    "neviolaților": "neviolat",
    "neviolatul": "neviolat",
    "neviolatului": "neviolat",
    "neviolentată": "neviolentat",
    "neviolentate": "neviolentat",
    "neviolentați": "neviolentat",
    "nevirată": "nevirat",
    "nevirate": "nevirat",
    "nevirați": "nevirat",
    "nevisata": "nevisat",
    "nevisată": "nevisat",
    "nevisate": "nevisat",
    "nevisatei": "nevisat",
    "nevisatele": "nevisat",
    "nevisatelor": "nevisat",
    "nevisați": "nevisat",
    "nevisații": "nevisat",
    "nevisaților": "nevisat",
    "nevisatul": "nevisat",
    "nevisatului": "nevisat",
    "neviscolita": "neviscolit",
    "neviscolită": "neviscolit",
    "neviscolite": "neviscolit",
    "neviscolitei": "neviscolit",
    "neviscolitele": "neviscolit",
    "neviscolitelor": "neviscolit",
    "neviscoliți": "neviscolit",
    "neviscoliții": "neviscolit",
    "neviscoliților": "neviscolit",
    "neviscolitul": "neviscolit",
    "neviscolitului": "neviscolit",
    "nevitrificată": "nevitrificat",
    "nevitrificate": "nevitrificat",
    "nevitrificați": "nevitrificat",
    "nevizată": "nevizat",
    "nevizate": "nevizat",
    "nevizați": "nevizat",
    "nevizionată": "nevizionat",
    "nevizionate": "nevizionat",
    "nevizionați": "nevizionat",
    "nevizitata": "nevizitat",
    "nevizitată": "nevizitat",
    "nevizitate": "nevizitat",
    "nevizitatei": "nevizitat",
    "nevizitatele": "nevizitat",
    "nevizitatelor": "nevizitat",
    "nevizitați": "nevizitat",
    "nevizitații": "nevizitat",
    "nevizitaților": "nevizitat",
    "nevizitatul": "nevizitat",
    "nevizitatului": "nevizitat",
    "nevizualizată": "nevizualizat",
    "nevizualizate": "nevizualizat",
    "nevizualizați": "nevizualizat",
    "nevlăguita": "nevlăguit",
    "nevlăguită": "nevlăguit",
    "nevlăguite": "nevlăguit",
    "nevlăguitei": "nevlăguit",
    "nevlăguitele": "nevlăguit",
    "nevlăguitelor": "nevlăguit",
    "nevlăguiți": "nevlăguit",
    "nevlăguiții": "nevlăguit",
    "nevlăguiților": "nevlăguit",
    "nevlăguitul": "nevlăguit",
    "nevlăguitului": "nevlăguit",
    "nevoalata": "nevoalat",
    "nevoalată": "nevoalat",
    "nevoalate": "nevoalat",
    "nevoalatei": "nevoalat",
    "nevoalatele": "nevoalat",
    "nevoalatelor": "nevoalat",
    "nevoalați": "nevoalat",
    "nevoalații": "nevoalat",
    "nevoalaților": "nevoalat",
    "nevoalatul": "nevoalat",
    "nevoalatului": "nevoalat",
    "nevocalizată": "nevocalizat",
    "nevocalizate": "nevocalizat",
    "nevocalizați": "nevocalizat",
    "nevociferată": "nevociferat",
    "nevociferate": "nevociferat",
    "nevociferați": "nevociferat",
    "nevoiașa": "nevoiaș",
    "nevoiașă": "nevoiaș",
    "nevoiașe": "nevoiaș",
    "nevoiașei": "nevoiaș",
    "nevoiașele": "nevoiaș",
    "nevoiașelor": "nevoiaș",
    "nevoiași": "nevoiaș",
    "nevoiașii": "nevoiaș",
    "nevoiașilor": "nevoiaș",
    "nevoiașul": "nevoiaș",
    "nevoiașului": "nevoiaș",
    "nevoi": "nevoie",
    "nevoia": "nevoie",
    "nevoii": "nevoie",
    "nevoile": "nevoie",
    "nevoilor": "nevoie",
    "nevoinicită": "nevoinicit",
    "nevoinicite": "nevoinicit",
    "nevoiniciți": "nevoinicit",
    "nevoita": "nevoit",
    "nevoită": "nevoit",
    "nevoite": "nevoit",
    "nevoitei": "nevoit",
    "nevoitele": "nevoit",
    "nevoitelor": "nevoit",
    "nevoiți": "nevoit",
    "nevoiții": "nevoit",
    "nevoiților": "nevoit",
    "nevoitul": "nevoit",
    "nevoitului": "nevoit",
    "nevolatilizată": "nevolatilizat",
    "nevolatilizate": "nevolatilizat",
    "nevolatilizați": "nevolatilizat",
    "nevolnica": "nevolnic",
    "nevolnică": "nevolnic",
    "nevolnice": "nevolnic",
    "nevolnicei": "nevolnic",
    "nevolnicele": "nevolnic",
    "nevolnicelor": "nevolnic",
    "nevolnici": "nevolnic",
    "nevolnicii": "nevolnic",
    "nevolnicilor": "nevolnic",
    "nevolnicul": "nevolnic",
    "nevolnicului": "nevolnic",
    "nevolnicia": "nevolnicie",
    "nevolniciei": "nevolnicie",
    "nevolnicii": "nevolnicie",
    "nevolniciile": "nevolnicie",
    "nevolniciilor": "nevolnicie",
    "nevomitată": "nevomitat",
    "nevomitate": "nevomitat",
    "nevomitați": "nevomitat",
    "nevopsita": "nevopsit",
    "nevopsită": "nevopsit",
    "nevopsite": "nevopsit",
    "nevopsitei": "nevopsit",
    "nevopsitele": "nevopsit",
    "nevopsitelor": "nevopsit",
    "nevopsiți": "nevopsit",
    "nevopsiții": "nevopsit",
    "nevopsiților": "nevopsit",
    "nevopsitul": "nevopsit",
    "nevopsitului": "nevopsit",
    "nevorbita": "nevorbit",
    "nevorbită": "nevorbit",
    "nevorbite": "nevorbit",
    "nevorbitei": "nevorbit",
    "nevorbitele": "nevorbit",
    "nevorbitelor": "nevorbit",
    "nevorbiți": "nevorbit",
    "nevorbiții": "nevorbit",
    "nevorbiților": "nevorbit",
    "nevorbitul": "nevorbit",
    "nevorbitului": "nevorbit",
    "nevotată": "nevotat",
    "nevotate": "nevotat",
    "nevotați": "nevotat",
    "nevrăfuită": "nevrăfuit",
    "nevrăfuite": "nevrăfuit",
    "nevrăfuiți": "nevrăfuit",
    "nevrăjita": "nevrăjit",
    "nevrăjită": "nevrăjit",
    "nevrăjite": "nevrăjit",
    "nevrăjitei": "nevrăjit",
    "nevrăjitele": "nevrăjit",
    "nevrăjitelor": "nevrăjit",
    "nevrăjiți": "nevrăjit",
    "nevrăjiții": "nevrăjit",
    "nevrăjiților": "nevrăjit",
    "nevrăjitul": "nevrăjit",
    "nevrăjitului": "nevrăjit",
    "nevralgica": "nevralgic",
    "nevralgică": "nevralgic",
    "nevralgice": "nevralgic",
    "nevralgicei": "nevralgic",
    "nevralgicele": "nevralgic",
    "nevralgicelor": "nevralgic",
    "nevralgici": "nevralgic",
    "nevralgicii": "nevralgic",
    "nevralgicilor": "nevralgic",
    "nevralgicul": "nevralgic",
    "nevralgicului": "nevralgic",
    "nevralgia": "nevralgie",
    "nevralgiei": "nevralgie",
    "nevralgii": "nevralgie",
    "nevralgiile": "nevralgie",
    "nevralgiilor": "nevralgie",
    "nevrednica": "nevrednic",
    "nevrednică": "nevrednic",
    "nevrednice": "nevrednic",
    "nevrednicei": "nevrednic",
    "nevrednicele": "nevrednic",
    "nevrednicelor": "nevrednic",
    "nevrednici": "nevrednic",
    "nevrednicii": "nevrednic",
    "nevrednicilor": "nevrednic",
    "nevrednicul": "nevrednic",
    "nevrednicului": "nevrednic",
    "nevrednicia": "nevrednicie",
    "nevredniciei": "nevrednicie",
    "nevrednicii": "nevrednicie",
    "nevredniciile": "nevrednicie",
    "nevredniciilor": "nevrednicie",
    "nevremuită": "nevremuit",
    "nevremuite": "nevremuit",
    "nevremuiți": "nevremuit",
    "nevricale": "nevrica",
    "nevricalei": "nevrica",
    "nevricalele": "nevrica",
    "nevricalelor": "nevrica",
    "nevricaua": "nevrica",
    "nevricoasa": "nevricos",
    "nevricoasă": "nevricos",
    "nevricoase": "nevricos",
    "nevricoasei": "nevricos",
    "nevricoasele": "nevricos",
    "nevricoaselor": "nevricos",
    "nevricoși": "nevricos",
    "nevricoșii": "nevricos",
    "nevricoșilor": "nevricos",
    "nevricosul": "nevricos",
    "nevricosului": "nevricos",
    "nevropata": "nevropat",
    "nevropată": "nevropat",
    "nevropate": "nevropat",
    "nevropatei": "nevropat",
    "nevropatele": "nevropat",
    "nevropatelor": "nevropat",
    "nevropați": "nevropat",
    "nevropații": "nevropat",
    "nevropaților": "nevropat",
    "nevropatul": "nevropat",
    "nevropatului": "nevropat",
    "nevropatica": "nevropatic",
    "nevropatică": "nevropatic",
    "nevropatice": "nevropatic",
    "nevropaticei": "nevropatic",
    "nevropaticele": "nevropatic",
    "nevropaticelor": "nevropatic",
    "nevropatici": "nevropatic",
    "nevropaticii": "nevropatic",
    "nevropaticilor": "nevropatic",
    "nevropaticul": "nevropatic",
    "nevropaticului": "nevropatic",
    "nevrotica": "nevrotic",
    "nevrotică": "nevrotic",
    "nevrotice": "nevrotic",
    "nevroticei": "nevrotic",
    "nevroticele": "nevrotic",
    "nevroticelor": "nevrotic",
    "nevrotici": "nevrotic",
    "nevroticii": "nevrotic",
    "nevroticilor": "nevrotic",
    "nevroticul": "nevrotic",
    "nevroticului": "nevrotic",
    "nevroza": "nevroză",
    "nevroze": "nevroză",
    "nevrozei": "nevroză",
    "nevrozele": "nevroză",
    "nevrozelor": "nevroză",
    "nevrozata": "nevrozat",
    "nevrozată": "nevrozat",
    "nevrozate": "nevrozat",
    "nevrozatei": "nevrozat",
    "nevrozatele": "nevrozat",
    "nevrozatelor": "nevrozat",
    "nevrozați": "nevrozat",
    "nevrozații": "nevrozat",
    "nevrozaților": "nevrozat",
    "nevrozatul": "nevrozat",
    "nevrozatului": "nevrozat",
    "nevrută": "nevrut",
    "nevrute": "nevrut",
    "nevruți": "nevrut",
    "nevuita": "nevuit",
    "nevuită": "nevuit",
    "nevuite": "nevuit",
    "nevuitei": "nevuit",
    "nevuitele": "nevuit",
    "nevuitelor": "nevuit",
    "nevuiți": "nevuit",
    "nevuiții": "nevuit",
    "nevuiților": "nevuit",
    "nevuitul": "nevuit",
    "nevuitului": "nevuit",
    "nevulcanizată": "nevulcanizat",
    "nevulcanizate": "nevulcanizat",
    "nevulcanizați": "nevulcanizat",
    "nevuvuită": "nevuvuit",
    "nevuvuite": "nevuvuit",
    "nevuvuiți": "nevuvuit",
    "N": "newton",
    "newtoni": "newton",
    "newtonii": "newton",
    "newtonilor": "newton",
    "newtonul": "newton",
    "newtonului": "newton",
    "newtoniana": "newtonian",
    "newtoniană": "newtonian",
    "newtonianul": "newtonian",
    "newtonianului": "newtonian",
    "newtoniene": "newtonian",
    "newtonienei": "newtonian",
    "newtonienele": "newtonian",
    "newtonienelor": "newtonian",
    "newtonieni": "newtonian",
    "newtonienii": "newtonian",
    "newtonienilor": "newtonian",
    "nezăbovita": "nezăbovit",
    "nezăbovită": "nezăbovit",
    "nezăbovite": "nezăbovit",
    "nezăbovitei": "nezăbovit",
    "nezăbovitele": "nezăbovit",
    "nezăbovitelor": "nezăbovit",
    "nezăboviți": "nezăbovit",
    "nezăboviții": "nezăbovit",
    "nezăboviților": "nezăbovit",
    "nezăbovitul": "nezăbovit",
    "nezăbovitului": "nezăbovit",
    "nezăcuta": "nezăcut",
    "nezăcută": "nezăcut",
    "nezăcute": "nezăcut",
    "nezăcutei": "nezăcut",
    "nezăcutele": "nezăcut",
    "nezăcutelor": "nezăcut",
    "nezăcuți": "nezăcut",
    "nezăcuții": "nezăcut",
    "nezăcuților": "nezăcut",
    "nezăcutul": "nezăcut",
    "nezăcutului": "nezăcut",
    "nezădărâta": "nezădărât",
    "nezădărâtă": "nezădărât",
    "nezădărâte": "nezădărât",
    "nezădărâtei": "nezădărât",
    "nezădărâtele": "nezădărât",
    "nezădărâtelor": "nezădărât",
    "nezădărâți": "nezădărât",
    "nezădărâții": "nezădărât",
    "nezădărâților": "nezădărât",
    "nezădărâtul": "nezădărât",
    "nezădărâtului": "nezădărât",
    "nezădărnicita": "nezădărnicit",
    "nezădărnicită": "nezădărnicit",
    "nezădărnicite": "nezădărnicit",
    "nezădărnicitei": "nezădărnicit",
    "nezădărnicitele": "nezădărnicit",
    "nezădărnicitelor": "nezădărnicit",
    "nezădărniciți": "nezădărnicit",
    "nezădărniciții": "nezădărnicit",
    "nezădărniciților": "nezădărnicit",
    "nezădărnicitul": "nezădărnicit",
    "nezădărnicitului": "nezădărnicit",
    "nezăgăzuita": "nezăgăzuit",
    "nezăgăzuită": "nezăgăzuit",
    "nezăgăzuite": "nezăgăzuit",
    "nezăgăzuitei": "nezăgăzuit",
    "nezăgăzuitele": "nezăgăzuit",
    "nezăgăzuitelor": "nezăgăzuit",
    "nezăgăzuiți": "nezăgăzuit",
    "nezăgăzuiții": "nezăgăzuit",
    "nezăgăzuiților": "nezăgăzuit",
    "nezăgăzuitul": "nezăgăzuit",
    "nezăgăzuitului": "nezăgăzuit",
    "nezălogita": "nezălogit",
    "nezălogită": "nezălogit",
    "nezălogite": "nezălogit",
    "nezălogitei": "nezălogit",
    "nezălogitele": "nezălogit",
    "nezălogitelor": "nezălogit",
    "nezălogiți": "nezălogit",
    "nezălogiții": "nezălogit",
    "nezălogiților": "nezălogit",
    "nezălogitul": "nezălogit",
    "nezălogitului": "nezălogit",
    "nezâmbita": "nezâmbit",
    "nezâmbită": "nezâmbit",
    "nezâmbite": "nezâmbit",
    "nezâmbitei": "nezâmbit",
    "nezâmbitele": "nezâmbit",
    "nezâmbitelor": "nezâmbit",
    "nezâmbiți": "nezâmbit",
    "nezâmbiții": "nezâmbit",
    "nezâmbiților": "nezâmbit",
    "nezâmbitul": "nezâmbit",
    "nezâmbitului": "nezâmbit",
    "nezămislita": "nezămislit",
    "nezămislită": "nezămislit",
    "nezămislite": "nezămislit",
    "nezămislitei": "nezămislit",
    "nezămislitele": "nezămislit",
    "nezămislitelor": "nezămislit",
    "nezămisliți": "nezămislit",
    "nezămisliții": "nezămislit",
    "nezămisliților": "nezămislit",
    "nezămislitul": "nezămislit",
    "nezămislitului": "nezămislit",
    "nezăngănita": "nezăngănit",
    "nezăngănită": "nezăngănit",
    "nezăngănite": "nezăngănit",
    "nezăngănitei": "nezăngănit",
    "nezăngănitele": "nezăngănit",
    "nezăngănitelor": "nezăngănit",
    "nezăngăniți": "nezăngănit",
    "nezăngăniții": "nezăngănit",
    "nezăngăniților": "nezăngănit",
    "nezăngănitul": "nezăngănit",
    "nezăngănitului": "nezăngănit",
    "nezăpăcita": "nezăpăcit",
    "nezăpăcită": "nezăpăcit",
    "nezăpăcite": "nezăpăcit",
    "nezăpăcitei": "nezăpăcit",
    "nezăpăcitele": "nezăpăcit",
    "nezăpăcitelor": "nezăpăcit",
    "nezăpăciți": "nezăpăcit",
    "nezăpăciții": "nezăpăcit",
    "nezăpăciților": "nezăpăcit",
    "nezăpăcitul": "nezăpăcit",
    "nezăpăcitului": "nezăpăcit",
    "nezăpușita": "nezăpușit",
    "nezăpușită": "nezăpușit",
    "nezăpușite": "nezăpușit",
    "nezăpușitei": "nezăpușit",
    "nezăpușitele": "nezăpușit",
    "nezăpușitelor": "nezăpușit",
    "nezăpușiți": "nezăpușit",
    "nezăpușiților": "nezăpușit",
    "nezăpușitul": "nezăpușit",
    "nezăpușitului": "nezăpușit",
    "nezărita": "nezărit",
    "nezărită": "nezărit",
    "nezărite": "nezărit",
    "nezăritei": "nezărit",
    "nezăritele": "nezărit",
    "nezăritelor": "nezărit",
    "nezăriți": "nezărit",
    "nezăriții": "nezărit",
    "nezăriților": "nezărit",
    "nezăritul": "nezărit",
    "nezăritului": "nezărit",
    "nezăvorâtă": "nezăvorât",
    "nezăvorâte": "nezăvorât",
    "nezăvorâți": "nezăvorât",
    "nezbârcita": "nezbârcit",
    "nezbârcită": "nezbârcit",
    "nezbârcite": "nezbârcit",
    "nezbârcitei": "nezbârcit",
    "nezbârcitele": "nezbârcit",
    "nezbârcitelor": "nezbârcit",
    "nezbârciți": "nezbârcit",
    "nezbârciții": "nezbârcit",
    "nezbârciților": "nezbârcit",
    "nezbârcitul": "nezbârcit",
    "nezbârcitului": "nezbârcit",
    "nezbătuta": "nezbătut",
    "nezbătută": "nezbătut",
    "nezbătute": "nezbătut",
    "nezbătutei": "nezbătut",
    "nezbătutele": "nezbătut",
    "nezbătutelor": "nezbătut",
    "nezbătuți": "nezbătut",
    "nezbătuții": "nezbătut",
    "nezbătuților": "nezbătut",
    "nezbătutul": "nezbătut",
    "nezbătutului": "nezbătut",
    "nezbicita": "nezbicit",
    "nezbicită": "nezbicit",
    "nezbicite": "nezbicit",
    "nezbicitei": "nezbicit",
    "nezbicitele": "nezbicit",
    "nezbicitelor": "nezbicit",
    "nezbiciți": "nezbicit",
    "nezbiciții": "nezbicit",
    "nezbiciților": "nezbicit",
    "nezbicitul": "nezbicit",
    "nezbicitului": "nezbicit",
    "nezbierata": "nezbierat",
    "nezbierată": "nezbierat",
    "nezbierate": "nezbierat",
    "nezbieratei": "nezbierat",
    "nezbieratele": "nezbierat",
    "nezbieratelor": "nezbierat",
    "nezbierați": "nezbierat",
    "nezbierații": "nezbierat",
    "nezbieraților": "nezbierat",
    "nezbieratul": "nezbierat",
    "nezbieratului": "nezbierat",
    "nezbuciumata": "nezbuciumat",
    "nezbuciumată": "nezbuciumat",
    "nezbuciumate": "nezbuciumat",
    "nezbuciumatei": "nezbuciumat",
    "nezbuciumatele": "nezbuciumat",
    "nezbuciumatelor": "nezbuciumat",
    "nezbuciumați": "nezbuciumat",
    "nezbuciumații": "nezbuciumat",
    "nezbuciumaților": "nezbuciumat",
    "nezbuciumatul": "nezbuciumat",
    "nezbuciumatului": "nezbuciumat",
    "nezbughita": "nezbughit",
    "nezbughită": "nezbughit",
    "nezbughite": "nezbughit",
    "nezbughitei": "nezbughit",
    "nezbughitele": "nezbughit",
    "nezbughitelor": "nezbughit",
    "nezbughiți": "nezbughit",
    "nezbughiții": "nezbughit",
    "nezbughiților": "nezbughit",
    "nezbughitul": "nezbughit",
    "nezbughitului": "nezbughit",
    "nezburata": "nezburat",
    "nezburată": "nezburat",
    "nezburate": "nezburat",
    "nezburatei": "nezburat",
    "nezburatele": "nezburat",
    "nezburatelor": "nezburat",
    "nezburați": "nezburat",
    "nezburații": "nezburat",
    "nezburaților": "nezburat",
    "nezburatul": "nezburat",
    "nezburatului": "nezburat",
    "nezburătăcita": "nezburătăcit",
    "nezburătăcită": "nezburătăcit",
    "nezburătăcite": "nezburătăcit",
    "nezburătăcitei": "nezburătăcit",
    "nezburătăcitele": "nezburătăcit",
    "nezburătăcitelor": "nezburătăcit",
    "nezburătăciți": "nezburătăcit",
    "nezburătăciții": "nezburătăcit",
    "nezburătăciților": "nezburătăcit",
    "nezburătăcitul": "nezburătăcit",
    "nezburătăcitului": "nezburătăcit",
    "nezburdată": "nezburdat",
    "nezburdate": "nezburdat",
    "nezburdați": "nezburdat",
    "nezdrelita": "nezdrelit",
    "nezdrelită": "nezdrelit",
    "nezdrelite": "nezdrelit",
    "nezdrelitei": "nezdrelit",
    "nezdrelitele": "nezdrelit",
    "nezdrelitelor": "nezdrelit",
    "nezdreliți": "nezdrelit",
    "nezdreliții": "nezdrelit",
    "nezdreliților": "nezdrelit",
    "nezdrelitul": "nezdrelit",
    "nezdrelitului": "nezdrelit",
    "nezdrențuita": "nezdrențuit",
    "nezdrențuită": "nezdrențuit",
    "nezdrențuite": "nezdrențuit",
    "nezdrențuitei": "nezdrențuit",
    "nezdrențuitele": "nezdrențuit",
    "nezdrențuitelor": "nezdrențuit",
    "nezdrențuiți": "nezdrențuit",
    "nezdrențuiții": "nezdrențuit",
    "nezdrențuiților": "nezdrențuit",
    "nezdrențuitul": "nezdrențuit",
    "nezdrențuitului": "nezdrențuit",
    "nezdrobita": "nezdrobit",
    "nezdrobită": "nezdrobit",
    "nezdrobite": "nezdrobit",
    "nezdrobitei": "nezdrobit",
    "nezdrobitele": "nezdrobit",
    "nezdrobitelor": "nezdrobit",
    "nezdrobiți": "nezdrobit",
    "nezdrobiții": "nezdrobit",
    "nezdrobiților": "nezdrobit",
    "nezdrobitul": "nezdrobit",
    "nezdrobitului": "nezdrobit",
    "nezdrumicata": "nezdrumicat",
    "nezdrumicată": "nezdrumicat",
    "nezdrumicate": "nezdrumicat",
    "nezdrumicatei": "nezdrumicat",
    "nezdrumicatele": "nezdrumicat",
    "nezdrumicatelor": "nezdrumicat",
    "nezdrumicați": "nezdrumicat",
    "nezdrumicații": "nezdrumicat",
    "nezdrumicaților": "nezdrumicat",
    "nezdrumicatul": "nezdrumicat",
    "nezdrumicatului": "nezdrumicat",
    "nezdruncinata": "nezdruncinat",
    "nezdruncinată": "nezdruncinat",
    "nezdruncinate": "nezdruncinat",
    "nezdruncinatei": "nezdruncinat",
    "nezdruncinatele": "nezdruncinat",
    "nezdruncinatelor": "nezdruncinat",
    "nezdruncinați": "nezdruncinat",
    "nezdruncinații": "nezdruncinat",
    "nezdruncinaților": "nezdruncinat",
    "nezdruncinatul": "nezdruncinat",
    "nezdruncinatului": "nezdruncinat",
    "nezeciuita": "nezeciuit",
    "nezeciuită": "nezeciuit",
    "nezeciuite": "nezeciuit",
    "nezeciuitei": "nezeciuit",
    "nezeciuitele": "nezeciuit",
    "nezeciuitelor": "nezeciuit",
    "nezeciuiți": "nezeciuit",
    "nezeciuiții": "nezeciuit",
    "nezeciuiților": "nezeciuit",
    "nezeciuitul": "nezeciuit",
    "nezeciuitului": "nezeciuit",
    "nezeflemisita": "nezeflemisit",
    "nezeflemisită": "nezeflemisit",
    "nezeflemisite": "nezeflemisit",
    "nezeflemisitei": "nezeflemisit",
    "nezeflemisitele": "nezeflemisit",
    "nezeflemisitelor": "nezeflemisit",
    "nezeflemisiți": "nezeflemisit",
    "nezeflemisiții": "nezeflemisit",
    "nezeflemisiților": "nezeflemisit",
    "nezeflemisitul": "nezeflemisit",
    "nezeflemisitului": "nezeflemisit",
    "nezgâita": "nezgâit",
    "nezgâită": "nezgâit",
    "nezgâite": "nezgâit",
    "nezgâitei": "nezgâit",
    "nezgâitele": "nezgâit",
    "nezgâitelor": "nezgâit",
    "nezgâiți": "nezgâit",
    "nezgâiții": "nezgâit",
    "nezgâiților": "nezgâit",
    "nezgâitul": "nezgâit",
    "nezgâitului": "nezgâit",
    "nezgârcita": "nezgârcit",
    "nezgârcită": "nezgârcit",
    "nezgârcite": "nezgârcit",
    "nezgârcitei": "nezgârcit",
    "nezgârcitele": "nezgârcit",
    "nezgârcitelor": "nezgârcit",
    "nezgârciți": "nezgârcit",
    "nezgârciții": "nezgârcit",
    "nezgârciților": "nezgârcit",
    "nezgârcitul": "nezgârcit",
    "nezgârcitului": "nezgârcit",
    "nezguduita": "nezguduit",
    "nezguduită": "nezguduit",
    "nezguduite": "nezguduit",
    "nezguduitei": "nezguduit",
    "nezguduitele": "nezguduit",
    "nezguduitelor": "nezguduit",
    "nezguduiți": "nezguduit",
    "nezguduiții": "nezguduit",
    "nezguduiților": "nezguduit",
    "nezguduitul": "nezguduit",
    "nezguduitului": "nezguduit",
    "nezisa": "nezis",
    "nezisă": "nezis",
    "nezise": "nezis",
    "nezisei": "nezis",
    "nezisele": "nezis",
    "neziselor": "nezis",
    "neziși": "nezis",
    "nezișii": "nezis",
    "nezișilor": "nezis",
    "nezisul": "nezis",
    "nezisului": "nezis",
    "nezorita": "nezorit",
    "nezorită": "nezorit",
    "nezorite": "nezorit",
    "nezoritei": "nezorit",
    "nezoritele": "nezorit",
    "nezoritelor": "nezorit",
    "nezoriți": "nezorit",
    "nezoriții": "nezorit",
    "nezoriților": "nezorit",
    "nezoritul": "nezorit",
    "nezoritului": "nezorit",
    "nezuruita": "nezuruit",
    "nezuruită": "nezuruit",
    "nezuruite": "nezuruit",
    "nezuruitei": "nezuruit",
    "nezuruitele": "nezuruit",
    "nezuruitelor": "nezuruit",
    "nezuruiți": "nezuruit",
    "nezuruiții": "nezuruit",
    "nezuruiților": "nezuruit",
    "nezuruitul": "nezuruit",
    "nezuruitului": "nezuruit",
    "nezvâcnita": "nezvâcnit",
    "nezvâcnită": "nezvâcnit",
    "nezvâcnite": "nezvâcnit",
    "nezvâcnitei": "nezvâcnit",
    "nezvâcnitele": "nezvâcnit",
    "nezvâcnitelor": "nezvâcnit",
    "nezvâcniți": "nezvâcnit",
    "nezvâcniții": "nezvâcnit",
    "nezvâcniților": "nezvâcnit",
    "nezvâcnitul": "nezvâcnit",
    "nezvâcnitului": "nezvâcnit",
    "nezvântata": "nezvântat",
    "nezvântată": "nezvântat",
    "nezvântate": "nezvântat",
    "nezvântatei": "nezvântat",
    "nezvântatele": "nezvântat",
    "nezvântatelor": "nezvântat",
    "nezvântați": "nezvântat",
    "nezvântații": "nezvântat",
    "nezvântaților": "nezvântat",
    "nezvântatul": "nezvântat",
    "nezvântatului": "nezvântat",
    "nezvârcolita": "nezvârcolit",
    "nezvârcolită": "nezvârcolit",
    "nezvârcolite": "nezvârcolit",
    "nezvârcolitei": "nezvârcolit",
    "nezvârcolitele": "nezvârcolit",
    "nezvârcolitelor": "nezvârcolit",
    "nezvârcoliți": "nezvârcolit",
    "nezvârcoliții": "nezvârcolit",
    "nezvârcoliților": "nezvârcolit",
    "nezvârcolitul": "nezvârcolit",
    "nezvârcolitului": "nezvârcolit",
    "nezvârlita": "nezvârlit",
    "nezvârlită": "nezvârlit",
    "nezvârlite": "nezvârlit",
    "nezvârlitei": "nezvârlit",
    "nezvârlitele": "nezvârlit",
    "nezvârlitelor": "nezvârlit",
    "nezvârliți": "nezvârlit",
    "nezvârliții": "nezvârlit",
    "nezvârliților": "nezvârlit",
    "nezvârlitul": "nezvârlit",
    "nezvârlitului": "nezvârlit",
    "nezvonita": "nezvonit",
    "nezvonită": "nezvonit",
    "nezvonite": "nezvonit",
    "nezvonitei": "nezvonit",
    "nezvonitele": "nezvonit",
    "nezvonitelor": "nezvonit",
    "nezvoniți": "nezvonit",
    "nezvoniții": "nezvonit",
    "nezvoniților": "nezvonit",
    "nezvonitul": "nezvonit",
    "nezvonitului": "nezvonit",
    "nicaraguana": "nicaraguan",
    "nicaraguană": "nicaraguan",
    "nicaraguane": "nicaraguan",
    "nicaraguanei": "nicaraguan",
    "nicaraguanele": "nicaraguan",
    "nicaraguanelor": "nicaraguan",
    "nicaraguani": "nicaraguan",
    "nicaraguanii": "nicaraguan",
    "nicaraguanilor": "nicaraguan",
    "nicaraguanul": "nicaraguan",
    "nicaraguanului": "nicaraguan",
    "nichelul": "nichel",
    "nichelului": "nichel",
    "nemainichelând": "nichela",
    "nemainichelându": "nichela",
    "nenichelând": "nichela",
    "nenichelându": "nichela",
    "nichelă": "nichela",
    "nichelai": "nichela",
    "nichelam": "nichela",
    "nichelăm": "nichela",
    "nichelând": "nichela",
    "nichelându": "nichela",
    "nichelară": "nichela",
    "nichelarăm": "nichela",
    "nichelarăți": "nichela",
    "nichelase": "nichela",
    "nichelasem": "nichela",
    "nichelaseră": "nichela",
    "nichelaserăm": "nichela",
    "nichelaserăți": "nichela",
    "nichelaseși": "nichela",
    "nichelași": "nichela",
    "nichelat": "nichela",
    "nichelați": "nichela",
    "nichelau": "nichela",
    "nichelează": "nichela",
    "nichelez": "nichela",
    "nicheleze": "nichela",
    "nichelezi": "nichela",
    "nichelată": "nichelat",
    "nichelate": "nichelat",
    "nichelați": "nichelat",
    "nici_o": "nici_un",
    "nici_unei": "nici_un",
    "nici_unii": "nici_un",
    "nici_unor": "nici_un",
    "nici_unui": "nici_un",
    "nici-o": "nici_un",
    "nici_una": "nici_unul",
    "nici_uneia": "nici_unul",
    "nici_unele": "nici_unul",
    "nici_unii": "nici_unul",
    "nici_unora": "nici_unul",
    "nici_unuia": "nici_unul",
    "Nicodimei": "Nicodima",
    "N.": "Nicolae",
    "nicotina": "nicotină",
    "nicotinica": "nicotinic",
    "nicotinică": "nicotinic",
    "nicotinice": "nicotinic",
    "nicotinicei": "nicotinic",
    "nicotinicele": "nicotinic",
    "nicotinicelor": "nicotinic",
    "nicotinici": "nicotinic",
    "nicotinicii": "nicotinic",
    "nicotinicilor": "nicotinic",
    "nicotinicul": "nicotinic",
    "nicotinicului": "nicotinic",
    "nicotinizata": "nicotinizat",
    "nicotinizată": "nicotinizat",
    "nicotinizate": "nicotinizat",
    "nicotinizatei": "nicotinizat",
    "nicotinizatele": "nicotinizat",
    "nicotinizatelor": "nicotinizat",
    "nicotinizați": "nicotinizat",
    "nicotinizații": "nicotinizat",
    "nicotinizaților": "nicotinizat",
    "nicotinizatul": "nicotinizat",
    "nicotinizatului": "nicotinizat",
    "nicovala": "nicovală",
    "nicovale": "nicovală",
    "nicovalei": "nicovală",
    "nicovalele": "nicovală",
    "nicovalelor": "nicovală",
    "nictalopa": "nictalop",
    "nictalopă": "nictalop",
    "nictalope": "nictalop",
    "nictalopei": "nictalop",
    "nictalopele": "nictalop",
    "nictalopelor": "nictalop",
    "nictalopi": "nictalop",
    "nictalopii": "nictalop",
    "nictalopilor": "nictalop",
    "nictalopul": "nictalop",
    "nictalopului": "nictalop",
    "Niculinei": "Niculina",
    "Nigeriei": "Nigeria",
    "nigeriana": "nigerian",
    "nigeriană": "nigerian",
    "nigerianul": "nigerian",
    "nigerianului": "nigerian",
    "nigeriene": "nigerian",
    "nigerienei": "nigerian",
    "nigerienele": "nigerian",
    "nigerienelor": "nigerian",
    "nigerieni": "nigerian",
    "nigerienii": "nigerian",
    "nigerienilor": "nigerian",
    "nihilismul": "nihilism",
    "nihilismului": "nihilism",
    "nihilista": "nihilist",
    "nihilistă": "nihilist",
    "nihiliste": "nihilist",
    "nihilistei": "nihilist",
    "nihilistele": "nihilist",
    "nihilistelor": "nihilist",
    "nihiliști": "nihilist",
    "nihiliștii": "nihilist",
    "nihiliștilor": "nihilist",
    "nihilistul": "nihilist",
    "nihilistului": "nihilist",
    "nimbul": "nimb",
    "nimbului": "nimb",
    "nimburi": "nimb",
    "nimburile": "nimb",
    "nimburilor": "nimb",
    "nimănui": "nimeni",
    "nimănuia": "nimeni",
    "nimereala": "nimereală",
    "nimereli": "nimereală",
    "nimerelii": "nimereală",
    "nimerelile": "nimereală",
    "nimerelilor": "nimereală",
    "nemainimerind": "nimeri",
    "nemainimerindu": "nimeri",
    "nenimerind": "nimeri",
    "nenimerindu": "nimeri",
    "nimerea": "nimeri",
    "nimereai": "nimeri",
    "nimeream": "nimeri",
    "nimerească": "nimeri",
    "nimereați": "nimeri",
    "nimereau": "nimeri",
    "nimeresc": "nimeri",
    "nimerește": "nimeri",
    "nimerești": "nimeri",
    "nimerii": "nimeri",
    "nimerim": "nimeri",
    "nimerind": "nimeri",
    "nimerindu": "nimeri",
    "nimeriră": "nimeri",
    "nimerirăm": "nimeri",
    "nimerirăți": "nimeri",
    "nimerise": "nimeri",
    "nimerisem": "nimeri",
    "nimeriseră": "nimeri",
    "nimeriserăm": "nimeri",
    "nimeriserăți": "nimeri",
    "nimeriseși": "nimeri",
    "nimeriși": "nimeri",
    "nimerit": "nimeri",
    "nimeriți": "nimeri",
    "nimerită": "nimerit",
    "nimerite": "nimerit",
    "nimeriți": "nimerit",
    "nimfa": "nimfă",
    "nimfe": "nimfă",
    "nimfei": "nimfă",
    "nimfele": "nimfă",
    "nimfelor": "nimfă",
    "nimicul": "nimic",
    "nimicului": "nimic",
    "nimicuri": "nimic",
    "nimicurile": "nimic",
    "nimicurilor": "nimic",
    "nemainimicind": "nimici",
    "nemainimicindu": "nimici",
    "nenimicind": "nimici",
    "nenimicindu": "nimici",
    "nimicea": "nimici",
    "nimiceai": "nimici",
    "nimiceam": "nimici",
    "nimicească": "nimici",
    "nimiceați": "nimici",
    "nimiceau": "nimici",
    "nimicesc": "nimici",
    "nimicește": "nimici",
    "nimicești": "nimici",
    "nimicii": "nimici",
    "nimicim": "nimici",
    "nimicind": "nimici",
    "nimicindu": "nimici",
    "nimiciră": "nimici",
    "nimicirăm": "nimici",
    "nimicirăți": "nimici",
    "nimicise": "nimici",
    "nimicisem": "nimici",
    "nimiciseră": "nimici",
    "nimiciserăm": "nimici",
    "nimiciserăți": "nimici",
    "nimiciseși": "nimici",
    "nimiciși": "nimici",
    "nimicit": "nimici",
    "nimiciți": "nimici",
    "nimicirea": "nimicire",
    "nimiciri": "nimicire",
    "nimicirii": "nimicire",
    "nimicirile": "nimicire",
    "nimicirilor": "nimicire",
    "nimicită": "nimicit",
    "nimicite": "nimicit",
    "nimiciți": "nimicit",
    "nimicitoare": "nimicitor",
    "nimicitoarea": "nimicitor",
    "nimicitoarei": "nimicitor",
    "nimicitoarele": "nimicitor",
    "nimicitoarelor": "nimicitor",
    "nimicitori": "nimicitor",
    "nimicitorii": "nimicitor",
    "nimicitorilor": "nimicitor",
    "nimicitorul": "nimicitor",
    "nimicitorului": "nimicitor",
    "nimicnicia": "nimicnicie",
    "nimicniciei": "nimicnicie",
    "nimicnicii": "nimicnicie",
    "nimicniciile": "nimicnicie",
    "nimicniciilor": "nimicnicie",
    "Ninei": "Nina",
    "ningă": "ninge",
    "ningând": "ninge",
    "ningându": "ninge",
    "ningea": "ninge",
    "ninse": "ninge",
    "ninsese": "ninge",
    "ninsoarea": "ninsoare",
    "ninsori": "ninsoare",
    "ninsorii": "ninsoare",
    "ninsorile": "ninsoare",
    "ninsorilor": "ninsoare",
    "Niobei": "Niobe",
    "Nb": "niobiu",
    "niobiul": "niobiu",
    "niobiului": "niobiu",
    "nipona": "nipon",
    "niponă": "nipon",
    "nipone": "nipon",
    "niponei": "nipon",
    "niponele": "nipon",
    "niponelor": "nipon",
    "niponi": "nipon",
    "niponii": "nipon",
    "niponilor": "nipon",
    "niponul": "nipon",
    "niponului": "nipon",
    "nipona": "niponă",
    "nipone": "niponă",
    "niponei": "niponă",
    "niponele": "niponă",
    "niponelor": "niponă",
    "nișa": "nișă",
    "nișe": "nișă",
    "nișei": "nișă",
    "nișele": "nișă",
    "nișelor": "nișă",
    "nisetri": "nisetru",
    "nisetrii": "nisetru",
    "nisetrilor": "nisetru",
    "nisetrul": "nisetru",
    "nisetrului": "nisetru",
    "nisipul": "nisip",
    "nisipului": "nisip",
    "nisipuri": "nisip",
    "nisipurile": "nisip",
    "nisipurilor": "nisip",
    "nisipita": "nisipit",
    "nisipită": "nisipit",
    "nisipite": "nisipit",
    "nisipitei": "nisipit",
    "nisipitele": "nisipit",
    "nisipitelor": "nisipit",
    "nisipiți": "nisipit",
    "nisipiții": "nisipit",
    "nisipiților": "nisipit",
    "nisipitul": "nisipit",
    "nisipitului": "nisipit",
    "nisipia": "nisipiu",
    "nisipie": "nisipiu",
    "nisipiei": "nisipiu",
    "nisipii": "nisipiu",
    "nisipiii": "nisipiu",
    "nisipiile": "nisipiu",
    "nisipiilor": "nisipiu",
    "nisipiul": "nisipiu",
    "nisipiului": "nisipiu",
    "nisipoasa": "nisipos",
    "nisipoasă": "nisipos",
    "nisipoase": "nisipos",
    "nisipoasei": "nisipos",
    "nisipoasele": "nisipos",
    "nisipoaselor": "nisipos",
    "nisipoși": "nisipos",
    "nisipoșii": "nisipos",
    "nisipoșilor": "nisipos",
    "nisiposul": "nisipos",
    "nisiposului": "nisipos",
    "Nistrul": "Nistru",
    "Nistrului": "Nistru",
    "nitul": "nit",
    "nitului": "nit",
    "nituri": "nit",
    "niturile": "nit",
    "niturilor": "nit",
    "niței": "nițel",
    "nițeii": "nițel",
    "nițeilor": "nițel",
    "nițele": "nițel",
    "nițelei": "nițel",
    "nițelele": "nițel",
    "nițelelor": "nițel",
    "nițelul": "nițel",
    "nițelului": "nițel",
    "nițică": "nițel",
    "nițelușa": "nițeluș",
    "nițelușă": "nițeluș",
    "nițelușe": "nițeluș",
    "nițelușei": "nițeluș",
    "nițelușele": "nițeluș",
    "nițelușelor": "nițeluș",
    "nițeluși": "nițeluș",
    "nițelușii": "nițeluș",
    "nițelușilor": "nițeluș",
    "nițelușul": "nițeluș",
    "nițelușului": "nițeluș",
    "nitrați": "nitrat",
    "nitrații": "nitrat",
    "nitraților": "nitrat",
    "nitratul": "nitrat",
    "nitratului": "nitrat",
    "nitrica": "nitric",
    "nitrică": "nitric",
    "nitrice": "nitric",
    "nitricei": "nitric",
    "nitricele": "nitric",
    "nitricelor": "nitric",
    "nitrici": "nitric",
    "nitricii": "nitric",
    "nitricilor": "nitric",
    "nitricul": "nitric",
    "nitricului": "nitric",
    "nitrificatoare": "nitrificator",
    "nitrificatoarea": "nitrificator",
    "nitrificatoarei": "nitrificator",
    "nitrificatoarele": "nitrificator",
    "nitrificatoarelor": "nitrificator",
    "nitrificatori": "nitrificator",
    "nitrificatorii": "nitrificator",
    "nitrificatorilor": "nitrificator",
    "nitrificatorul": "nitrificator",
    "nitrificatorului": "nitrificator",
    "nitroglicerina": "nitroglicerină",
    "nitroglicerine": "nitroglicerină",
    "nitroglicerinei": "nitroglicerină",
    "nitroasa": "nitros",
    "nitroasă": "nitros",
    "nitroase": "nitros",
    "nitroasei": "nitros",
    "nitroasele": "nitros",
    "nitroaselor": "nitros",
    "nitroși": "nitros",
    "nitroșii": "nitros",
    "nitroșilor": "nitros",
    "nitrosul": "nitros",
    "nitrosului": "nitros",
    "nemainituind": "nitui",
    "nemainituindu": "nitui",
    "nenituind": "nitui",
    "nenituindu": "nitui",
    "nituia": "nitui",
    "nituiai": "nitui",
    "nituiam": "nitui",
    "nituiască": "nitui",
    "nituiați": "nitui",
    "nituiau": "nitui",
    "nituiesc": "nitui",
    "nituiește": "nitui",
    "nituiești": "nitui",
    "nituii": "nitui",
    "nituim": "nitui",
    "nituind": "nitui",
    "nituindu": "nitui",
    "nituiră": "nitui",
    "nituirăm": "nitui",
    "nituirăți": "nitui",
    "nituise": "nitui",
    "nituisem": "nitui",
    "nituiseră": "nitui",
    "nituiserăm": "nitui",
    "nituiserăți": "nitui",
    "nituiseși": "nitui",
    "nituiși": "nitui",
    "nituit": "nitui",
    "nituiți": "nitui",
    "nituită": "nituit",
    "nituite": "nituit",
    "nituiți": "nituit",
    "nivele": "nivel",
    "nivelele": "nivel",
    "nivelelor": "nivel",
    "nivelul": "nivel",
    "nivelului": "nivel",
    "niveluri": "nivel",
    "nivelurile": "nivel",
    "nivelurilor": "nivel",
    "nemainivelând": "nivela",
    "nemainivelându": "nivela",
    "nenivelând": "nivela",
    "nenivelându": "nivela",
    "nivelă": "nivela",
    "nivelai": "nivela",
    "nivelam": "nivela",
    "nivelăm": "nivela",
    "nivelând": "nivela",
    "nivelându": "nivela",
    "nivelară": "nivela",
    "nivelarăm": "nivela",
    "nivelarăți": "nivela",
    "nivelase": "nivela",
    "nivelasem": "nivela",
    "nivelaseră": "nivela",
    "nivelaserăm": "nivela",
    "nivelaserăți": "nivela",
    "nivelaseși": "nivela",
    "nivelași": "nivela",
    "nivelat": "nivela",
    "nivelați": "nivela",
    "nivelau": "nivela",
    "nivelează": "nivela",
    "nivelez": "nivela",
    "niveleze": "nivela",
    "nivelezi": "nivela",
    "nivelată": "nivelat",
    "nivelate": "nivelat",
    "nivelați": "nivelat",
    "nivelatoare": "nivelator",
    "nivelatoarea": "nivelator",
    "nivelatoarei": "nivelator",
    "nivelatoarele": "nivelator",
    "nivelatoarelor": "nivelator",
    "nivelatori": "nivelator",
    "nivelatorii": "nivelator",
    "nivelatorilor": "nivelator",
    "nivelatorul": "nivelator",
    "nivelatorului": "nivelator",
    "noada": "noadă",
    "noade": "noadă",
    "noadei": "noadă",
    "noadele": "noadă",
    "noadelor": "noadă",
    "noaptea": "noapte",
    "nopți": "noapte",
    "nopții": "noapte",
    "nopțile": "noapte",
    "nopților": "noapte",
    "Nobelul": "Nobel",
    "Nobelului": "Nobel",
    "No": "nobeliu",
    "nobeliul": "nobeliu",
    "nobeliului": "nobeliu",
    "nobila": "nobil",
    "nobilă": "nobil",
    "nobile": "nobil",
    "nobilei": "nobil",
    "nobilele": "nobil",
    "nobilelor": "nobil",
    "nobili": "nobil",
    "nobilii": "nobil",
    "nobililor": "nobil",
    "nobilul": "nobil",
    "nobilului": "nobil",
    "nobila": "nobilă",
    "nobile": "nobilă",
    "nobilei": "nobilă",
    "nobilele": "nobilă",
    "nobilelor": "nobilă",
    "nobiliara": "nobiliar",
    "nobiliară": "nobiliar",
    "nobiliare": "nobiliar",
    "nobiliarei": "nobiliar",
    "nobiliarele": "nobiliar",
    "nobiliarelor": "nobiliar",
    "nobiliari": "nobiliar",
    "nobiliarii": "nobiliar",
    "nobiliarilor": "nobiliar",
    "nobiliarul": "nobiliar",
    "nobiliarului": "nobiliar",
    "nobilimea": "nobilime",
    "nobilimi": "nobilime",
    "nobilimii": "nobilime",
    "nobilimile": "nobilime",
    "nobilimilor": "nobilime",
    "nobilitara": "nobilitar",
    "nobilitară": "nobilitar",
    "nobilitare": "nobilitar",
    "nobilitarei": "nobilitar",
    "nobilitarele": "nobilitar",
    "nobilitarelor": "nobilitar",
    "nobilitari": "nobilitar",
    "nobilitarii": "nobilitar",
    "nobilitarilor": "nobilitar",
    "nobilitarul": "nobilitar",
    "nobilitarului": "nobilitar",
    "noblețea": "noblețe",
    "nobleți": "noblețe",
    "nobleții": "noblețe",
    "nociva": "nociv",
    "nocivă": "nociv",
    "nocive": "nociv",
    "nocivei": "nociv",
    "nocivele": "nociv",
    "nocivelor": "nociv",
    "nocivi": "nociv",
    "nocivii": "nociv",
    "nocivilor": "nociv",
    "nocivul": "nociv",
    "nocivului": "nociv",
    "nocivitatea": "nocivitate",
    "nocivități": "nocivitate",
    "nocivității": "nocivitate",
    "nocivitățile": "nocivitate",
    "nocivităților": "nocivitate",
    "nocturna": "nocturn",
    "nocturnă": "nocturn",
    "nocturne": "nocturn",
    "nocturnei": "nocturn",
    "nocturnele": "nocturn",
    "nocturnelor": "nocturn",
    "nocturni": "nocturn",
    "nocturnii": "nocturn",
    "nocturnilor": "nocturn",
    "nocturnul": "nocturn",
    "nocturnului": "nocturn",
    "nodul": "nod",
    "nodului": "nod",
    "noduri": "nod",
    "nodurile": "nod",
    "nodurilor": "nod",
    "nodala": "nodal",
    "nodală": "nodal",
    "nodale": "nodal",
    "nodalei": "nodal",
    "nodalele": "nodal",
    "nodalelor": "nodal",
    "nodali": "nodal",
    "nodalii": "nodal",
    "nodalilor": "nodal",
    "nodalul": "nodal",
    "nodalului": "nodal",
    "nodoasa": "nodos",
    "nodoasă": "nodos",
    "nodoase": "nodos",
    "nodoasei": "nodos",
    "nodoasele": "nodos",
    "nodoaselor": "nodos",
    "nodoși": "nodos",
    "nodoșii": "nodos",
    "nodoșilor": "nodos",
    "nodosul": "nodos",
    "nodosului": "nodos",
    "noduli": "nodul",
    "nodulii": "nodul",
    "nodulilor": "nodul",
    "nodulul": "nodul",
    "nodulului": "nodul",
    "noduroasa": "noduros",
    "noduroasă": "noduros",
    "noduroase": "noduros",
    "noduroasei": "noduros",
    "noduroasele": "noduros",
    "noduroaselor": "noduros",
    "noduroși": "noduros",
    "noduroșii": "noduros",
    "noduroșilor": "noduros",
    "nodurosul": "noduros",
    "nodurosului": "noduros",
    "ne": "noi",
    "ne-": "noi",
    "ni": "noi",
    "ni-": "noi",
    "nouă": "noi",
    "noiane": "noian",
    "noianele": "noian",
    "noianelor": "noian",
    "noianul": "noian",
    "noianului": "noian",
    "nov.": "noiembrie",
    "noima": "noimă",
    "noime": "noimă",
    "noimei": "noimă",
    "noimele": "noimă",
    "noimelor": "noimă",
    "noimea": "noime",
    "noimi": "noime",
    "noimii": "noime",
    "noimile": "noime",
    "noimilor": "noime",
    "nojița": "nojiță",
    "nojițe": "nojiță",
    "nojiței": "nojiță",
    "nojițele": "nojiță",
    "nojițelor": "nojiță",
    "nomada": "nomad",
    "nomadă": "nomad",
    "nomade": "nomad",
    "nomadei": "nomad",
    "nomadele": "nomad",
    "nomadelor": "nomad",
    "nomadul": "nomad",
    "nomadului": "nomad",
    "nomazi": "nomad",
    "nomazii": "nomad",
    "nomazilor": "nomad",
    "nomada": "nomadă",
    "nomade": "nomadă",
    "nomadei": "nomadă",
    "nomadele": "nomadă",
    "nomadelor": "nomadă",
    "n.n.": "nomen_nescio",
    "nomenclatoare": "nomenclator",
    "nomenclatoarele": "nomenclator",
    "nomenclatoarelor": "nomenclator",
    "nomenclatorul": "nomenclator",
    "nomenclatorului": "nomenclator",
    "nomenclatura": "nomenclatură",
    "nomenclaturi": "nomenclatură",
    "nomenclaturii": "nomenclatură",
    "nomenclaturile": "nomenclatură",
    "nomenclaturilor": "nomenclatură",
    "nomenclaturistica": "nomenclaturistic",
    "nomenclaturistică": "nomenclaturistic",
    "nomenclaturistice": "nomenclaturistic",
    "nomenclaturisticei": "nomenclaturistic",
    "nomenclaturisticele": "nomenclaturistic",
    "nomenclaturisticelor": "nomenclaturistic",
    "nomenclaturistici": "nomenclaturistic",
    "nomenclaturisticii": "nomenclaturistic",
    "nomenclaturisticilor": "nomenclaturistic",
    "nomenclaturisticul": "nomenclaturistic",
    "nomenclaturisticului": "nomenclaturistic",
    "nominala": "nominal",
    "nominală": "nominal",
    "nominale": "nominal",
    "nominalei": "nominal",
    "nominalele": "nominal",
    "nominalelor": "nominal",
    "nominali": "nominal",
    "nominalii": "nominal",
    "nominalilor": "nominal",
    "nominalul": "nominal",
    "nominalului": "nominal",
    "nominalista": "nominalist",
    "nominalistă": "nominalist",
    "nominaliste": "nominalist",
    "nominalistei": "nominalist",
    "nominalistele": "nominalist",
    "nominalistelor": "nominalist",
    "nominaliști": "nominalist",
    "nominaliștii": "nominalist",
    "nominaliștilor": "nominalist",
    "nominalistul": "nominalist",
    "nominalistului": "nominalist",
    "nemainominalizând": "nominaliza",
    "nemainominalizându": "nominaliza",
    "nenominalizând": "nominaliza",
    "nenominalizându": "nominaliza",
    "nominaliză": "nominaliza",
    "nominalizai": "nominaliza",
    "nominalizam": "nominaliza",
    "nominalizăm": "nominaliza",
    "nominalizând": "nominaliza",
    "nominalizându": "nominaliza",
    "nominalizară": "nominaliza",
    "nominalizarăm": "nominaliza",
    "nominalizarăți": "nominaliza",
    "nominalizase": "nominaliza",
    "nominalizasem": "nominaliza",
    "nominalizaseră": "nominaliza",
    "nominalizaserăm": "nominaliza",
    "nominalizaserăți": "nominaliza",
    "nominalizaseși": "nominaliza",
    "nominalizași": "nominaliza",
    "nominalizat": "nominaliza",
    "nominalizați": "nominaliza",
    "nominalizau": "nominaliza",
    "nominalizează": "nominaliza",
    "nominalizez": "nominaliza",
    "nominalizeze": "nominaliza",
    "nominalizezi": "nominaliza",
    "nominalizată": "nominalizat",
    "nominalizate": "nominalizat",
    "nominalizați": "nominalizat",
    "nom.": "nominativ",
    "nominativa": "nominativ",
    "nominativă": "nominativ",
    "nominative": "nominativ",
    "nominativei": "nominativ",
    "nominativele": "nominativ",
    "nominativelor": "nominativ",
    "nominativi": "nominativ",
    "nominativii": "nominativ",
    "nominativilor": "nominativ",
    "nominativul": "nominativ",
    "nominativului": "nominativ",
    "nomografica": "nomografic",
    "nomografică": "nomografic",
    "nomografice": "nomografic",
    "nomograficei": "nomografic",
    "nomograficele": "nomografic",
    "nomograficelor": "nomografic",
    "nomografici": "nomografic",
    "nomograficii": "nomografic",
    "nomograficilor": "nomografic",
    "nomograficul": "nomografic",
    "nomograficului": "nomografic",
    "n.l.": "non_licet",
    "n.r.": "non_repetatur",
    "nona": "nonă",
    "none": "nonă",
    "nonei": "nonă",
    "nonele": "nonă",
    "nonelor": "nonă",
    "nonagenara": "nonagenar",
    "nonagenară": "nonagenar",
    "nonagenare": "nonagenar",
    "nonagenarei": "nonagenar",
    "nonagenarele": "nonagenar",
    "nonagenarelor": "nonagenar",
    "nonagenari": "nonagenar",
    "nonagenarii": "nonagenar",
    "nonagenarilor": "nonagenar",
    "nonagenarul": "nonagenar",
    "nonagenarului": "nonagenar",
    "nonagenara": "nonagenară",
    "nonagenare": "nonagenară",
    "nonagenarei": "nonagenară",
    "nonagenarele": "nonagenară",
    "nonagenarelor": "nonagenară",
    "nonconformista": "nonconformist",
    "nonconformistă": "nonconformist",
    "nonconformiste": "nonconformist",
    "nonconformistei": "nonconformist",
    "nonconformistele": "nonconformist",
    "nonconformistelor": "nonconformist",
    "nonconformiști": "nonconformist",
    "nonconformiștii": "nonconformist",
    "nonconformiștilor": "nonconformist",
    "nonconformistul": "nonconformist",
    "nonconformistului": "nonconformist",
    "nonexistența": "nonexistență",
    "nonexistențe": "nonexistență",
    "nonexistenței": "nonexistență",
    "nonexistențele": "nonexistență",
    "nonexistențelor": "nonexistență",
    "nonfigurativa": "nonfigurativ",
    "nonfigurativă": "nonfigurativ",
    "nonfigurative": "nonfigurativ",
    "nonfigurativei": "nonfigurativ",
    "nonfigurativele": "nonfigurativ",
    "nonfigurativelor": "nonfigurativ",
    "nonfigurativi": "nonfigurativ",
    "nonfigurativii": "nonfigurativ",
    "nonfigurativilor": "nonfigurativ",
    "nonfigurativul": "nonfigurativ",
    "nonfigurativului": "nonfigurativ",
    "nonșalanta": "nonșalant",
    "nonșalantă": "nonșalant",
    "nonșalante": "nonșalant",
    "nonșalantei": "nonșalant",
    "nonșalantele": "nonșalant",
    "nonșalantelor": "nonșalant",
    "nonșalanți": "nonșalant",
    "nonșalanții": "nonșalant",
    "nonșalanților": "nonșalant",
    "nonșalantul": "nonșalant",
    "nonșalantului": "nonșalant",
    "nonșalanța": "nonșalanță",
    "nonșalanțe": "nonșalanță",
    "nonșalanței": "nonșalanță",
    "nonșalanțele": "nonșalanță",
    "nonșalanțelor": "nonșalanță",
    "nonsensul": "nonsens",
    "nonsensului": "nonsens",
    "nonsensuri": "nonsens",
    "nonsensurile": "nonsens",
    "nonsensurilor": "nonsens",
    "noptatica": "noptatic",
    "noptatică": "noptatic",
    "noptatice": "noptatic",
    "noptaticei": "noptatic",
    "noptaticele": "noptatic",
    "noptaticelor": "noptatic",
    "noptatici": "noptatic",
    "noptaticii": "noptatic",
    "noptaticilor": "noptatic",
    "noptaticul": "noptatic",
    "noptaticului": "noptatic",
    "noptiera": "noptieră",
    "noptiere": "noptieră",
    "noptierei": "noptieră",
    "noptierele": "noptieră",
    "noptierelor": "noptieră",
    "noptoasa": "noptos",
    "noptoasă": "noptos",
    "noptoase": "noptos",
    "noptoasei": "noptos",
    "noptoasele": "noptos",
    "noptoaselor": "noptos",
    "noptoși": "noptos",
    "noptoșii": "noptos",
    "noptoșilor": "noptos",
    "noptosul": "noptos",
    "noptosului": "noptos",
    "nori": "nor",
    "norii": "nor",
    "norilor": "nor",
    "norul": "nor",
    "norului": "nor",
    "nora": "noră",
    "nurori": "noră",
    "nurorii": "noră",
    "nurorile": "noră",
    "nurorilor": "noră",
    "N": "nord",
    "nordul": "nord",
    "nordului": "nord",
    "N.E.": "nord_est",
    "NE": "nord_est",
    "N.V.": "nord_vest",
    "NV": "nord_vest",
    "nord-estul": "nord-est",
    "nord-estului": "nord-est",
    "nordica": "nordic",
    "nordică": "nordic",
    "nordice": "nordic",
    "nordicei": "nordic",
    "nordicele": "nordic",
    "nordicelor": "nordic",
    "nordici": "nordic",
    "nordicii": "nordic",
    "nordicilor": "nordic",
    "nordicul": "nordic",
    "nordicului": "nordic",
    "nord-sudul": "nord-sud",
    "nord-sudului": "nord-sud",
    "nord-vestul": "nord-vest",
    "nord-vestului": "nord-vest",
    "nemainormând": "norma",
    "nemainormându": "norma",
    "nenormând": "norma",
    "nenormându": "norma",
    "normă": "norma",
    "normai": "norma",
    "normam": "norma",
    "normăm": "norma",
    "normând": "norma",
    "normându": "norma",
    "normară": "norma",
    "normarăm": "norma",
    "normarăți": "norma",
    "normase": "norma",
    "normasem": "norma",
    "normaseră": "norma",
    "normaserăm": "norma",
    "normaserăți": "norma",
    "normaseși": "norma",
    "normași": "norma",
    "normat": "norma",
    "normați": "norma",
    "normau": "norma",
    "normează": "norma",
    "normez": "norma",
    "normeze": "norma",
    "normezi": "norma",
    "norma": "normă",
    "norme": "normă",
    "normei": "normă",
    "normele": "normă",
    "normelor": "normă",
    "normala": "normal",
    "normală": "normal",
    "normale": "normal",
    "normalei": "normal",
    "normalele": "normal",
    "normalelor": "normal",
    "normali": "normal",
    "normalii": "normal",
    "normalilor": "normal",
    "normalul": "normal",
    "normalului": "normal",
    "normalitatea": "normalitate",
    "normalități": "normalitate",
    "normalității": "normalitate",
    "normalitățile": "normalitate",
    "normalităților": "normalitate",
    "nemainormalizând": "normaliza",
    "nemainormalizându": "normaliza",
    "nenormalizând": "normaliza",
    "nenormalizându": "normaliza",
    "normaliză": "normaliza",
    "normalizai": "normaliza",
    "normalizam": "normaliza",
    "normalizăm": "normaliza",
    "normalizând": "normaliza",
    "normalizându": "normaliza",
    "normalizară": "normaliza",
    "normalizarăm": "normaliza",
    "normalizarăți": "normaliza",
    "normalizase": "normaliza",
    "normalizasem": "normaliza",
    "normalizaseră": "normaliza",
    "normalizaserăm": "normaliza",
    "normalizaserăți": "normaliza",
    "normalizaseși": "normaliza",
    "normalizași": "normaliza",
    "normalizat": "normaliza",
    "normalizați": "normaliza",
    "normalizau": "normaliza",
    "normalizează": "normaliza",
    "normalizez": "normaliza",
    "normalizeze": "normaliza",
    "normalizezi": "normaliza",
    "normalizarea": "normalizare",
    "normalizări": "normalizare",
    "normalizării": "normalizare",
    "normalizările": "normalizare",
    "normalizărilor": "normalizare",
    "normalizată": "normalizat",
    "normalizate": "normalizat",
    "normalizați": "normalizat",
    "normanda": "normand",
    "normandă": "normand",
    "normande": "normand",
    "normandei": "normand",
    "normandele": "normand",
    "normandelor": "normand",
    "normandul": "normand",
    "normandului": "normand",
    "normanzi": "normand",
    "normanzii": "normand",
    "normanzilor": "normand",
    "normata": "normat",
    "normată": "normat",
    "normate": "normat",
    "normatei": "normat",
    "normatele": "normat",
    "normatelor": "normat",
    "normați": "normat",
    "normații": "normat",
    "normaților": "normat",
    "normatul": "normat",
    "normatului": "normat",
    "normativa": "normativ",
    "normativă": "normativ",
    "normative": "normativ",
    "normativei": "normativ",
    "normativele": "normativ",
    "normativelor": "normativ",
    "normativi": "normativ",
    "normativii": "normativ",
    "normativilor": "normativ",
    "normativul": "normativ",
    "normativului": "normativ",
    "normatoarea": "normatoare",
    "normatoarei": "normatoare",
    "normatoarele": "normatoare",
    "normatoarelor": "normatoare",
    "normatori": "normator",
    "normatorii": "normator",
    "normatorilor": "normator",
    "normatorul": "normator",
    "normatorului": "normator",
    "norocul": "noroc",
    "norocului": "noroc",
    "nemainorocind": "noroci",
    "nemainorocindu": "noroci",
    "nenorocind": "noroci",
    "nenorocindu": "noroci",
    "norocea": "noroci",
    "noroceai": "noroci",
    "noroceam": "noroci",
    "norocească": "noroci",
    "noroceați": "noroci",
    "noroceau": "noroci",
    "norocesc": "noroci",
    "norocește": "noroci",
    "norocești": "noroci",
    "norocii": "noroci",
    "norocim": "noroci",
    "norocind": "noroci",
    "norocindu": "noroci",
    "norociră": "noroci",
    "norocirăm": "noroci",
    "norocirăți": "noroci",
    "norocise": "noroci",
    "norocisem": "noroci",
    "norociseră": "noroci",
    "norociserăm": "noroci",
    "norociserăți": "noroci",
    "norociseși": "noroci",
    "norociși": "noroci",
    "norocit": "noroci",
    "norociți": "noroci",
    "norocirea": "norocire",
    "norociri": "norocire",
    "norocirii": "norocire",
    "norocirile": "norocire",
    "norocirilor": "norocire",
    "norocită": "norocit",
    "norocite": "norocit",
    "norociți": "norocit",
    "norocoasa": "norocos",
    "norocoasă": "norocos",
    "norocoase": "norocos",
    "norocoasei": "norocos",
    "norocoasele": "norocos",
    "norocoaselor": "norocos",
    "norocoși": "norocos",
    "norocoșii": "norocos",
    "norocoșilor": "norocos",
    "norocosul": "norocos",
    "norocosului": "norocos",
    "noroade": "norod",
    "noroadele": "norod",
    "noroadelor": "norod",
    "norodul": "norod",
    "norodului": "norod",
    "noroaie": "noroi",
    "noroaiele": "noroi",
    "noroaielor": "noroi",
    "noroiul": "noroi",
    "noroiului": "noroi",
    "noroioasa": "noroios",
    "noroioasă": "noroios",
    "noroioase": "noroios",
    "noroioasei": "noroios",
    "noroioasele": "noroios",
    "noroioaselor": "noroios",
    "noroioși": "noroios",
    "noroioșii": "noroios",
    "noroioșilor": "noroios",
    "noroiosul": "noroios",
    "noroiosului": "noroios",
    "noroita": "noroit",
    "noroită": "noroit",
    "noroite": "noroit",
    "noroitei": "noroit",
    "noroitele": "noroit",
    "noroitelor": "noroit",
    "noroiți": "noroit",
    "noroiții": "noroit",
    "noroiților": "noroit",
    "noroitul": "noroit",
    "noroitului": "noroit",
    "noroasa": "noros",
    "noroasă": "noros",
    "noroase": "noros",
    "noroasei": "noros",
    "noroasele": "noros",
    "noroaselor": "noros",
    "noroși": "noros",
    "noroșii": "noros",
    "noroșilor": "noros",
    "norosul": "noros",
    "norosului": "noros",
    "Norv.": "Norvegia",
    "Norvegiei": "Norvegia",
    "norvegiana": "norvegian",
    "norvegiană": "norvegian",
    "norvegianul": "norvegian",
    "norvegianului": "norvegian",
    "norvegiene": "norvegian",
    "norvegienei": "norvegian",
    "norvegienele": "norvegian",
    "norvegienelor": "norvegian",
    "norvegieni": "norvegian",
    "norvegienii": "norvegian",
    "norvegienilor": "norvegian",
    "norvegiana": "norvegiană",
    "norvegiene": "norvegiană",
    "norvegienei": "norvegiană",
    "norvegienele": "norvegiană",
    "norvegienelor": "norvegiană",
    "nostalgica": "nostalgic",
    "nostalgică": "nostalgic",
    "nostalgice": "nostalgic",
    "nostalgicei": "nostalgic",
    "nostalgicele": "nostalgic",
    "nostalgicelor": "nostalgic",
    "nostalgici": "nostalgic",
    "nostalgicii": "nostalgic",
    "nostalgicilor": "nostalgic",
    "nostalgicul": "nostalgic",
    "nostalgicului": "nostalgic",
    "nostalgica": "nostalgică",
    "nostalgice": "nostalgică",
    "nostalgicei": "nostalgică",
    "nostalgicele": "nostalgică",
    "nostalgicelor": "nostalgică",
    "nostalgia": "nostalgie",
    "nostalgiei": "nostalgie",
    "nostalgii": "nostalgie",
    "nostalgiile": "nostalgie",
    "nostalgiilor": "nostalgie",
    "nostima": "nostim",
    "nostimă": "nostim",
    "nostime": "nostim",
    "nostimei": "nostim",
    "nostimele": "nostim",
    "nostimelor": "nostim",
    "nostimi": "nostim",
    "nostimii": "nostim",
    "nostimilor": "nostim",
    "nostimul": "nostim",
    "nostimului": "nostim",
    "nostimada": "nostimadă",
    "nostimade": "nostimadă",
    "nostimadei": "nostimadă",
    "nostimadele": "nostimadă",
    "nostimadelor": "nostimadă",
    "nostimioara": "nostimior",
    "nostimioară": "nostimior",
    "nostimioare": "nostimior",
    "nostimioarei": "nostimior",
    "nostimioarele": "nostimior",
    "nostimioarelor": "nostimior",
    "nostimiori": "nostimior",
    "nostimiorii": "nostimior",
    "nostimiorilor": "nostimior",
    "nostimiorul": "nostimior",
    "nostimiorului": "nostimior",
    "noastră": "nostru",
    "noastre": "nostru",
    "noștri": "nostru",
    "nemainotând": "nota",
    "nemainotându": "nota",
    "nenotând": "nota",
    "nenotându": "nota",
    "notă": "nota",
    "notai": "nota",
    "notam": "nota",
    "notăm": "nota",
    "notând": "nota",
    "notându": "nota",
    "notară": "nota",
    "notarăm": "nota",
    "notarăți": "nota",
    "notase": "nota",
    "notasem": "nota",
    "notaseră": "nota",
    "notaserăm": "nota",
    "notaserăți": "nota",
    "notaseși": "nota",
    "notași": "nota",
    "notat": "nota",
    "notați": "nota",
    "notau": "nota",
    "notează": "nota",
    "notez": "nota",
    "noteze": "nota",
    "notezi": "nota",
    "nota": "notă",
    "note": "notă",
    "notei": "notă",
    "notele": "notă",
    "notelor": "notă",
    "N.a.": "nota_autorului",
    "N.B.": "nota_bene",
    "n.n.": "nota_noastră",
    "n.r.": "nota_redacției",
    "N.trad.": "nota_traducătorului",
    "notabila": "notabil",
    "notabilă": "notabil",
    "notabile": "notabil",
    "notabilei": "notabil",
    "notabilele": "notabil",
    "notabilelor": "notabil",
    "notabili": "notabil",
    "notabilii": "notabil",
    "notabililor": "notabil",
    "notabilul": "notabil",
    "notabilului": "notabil",
    "notabilitatea": "notabilitate",
    "notabilități": "notabilitate",
    "notabilității": "notabilitate",
    "notabilitățile": "notabilitate",
    "notabilităților": "notabilitate",
    "notari": "notar",
    "notarii": "notar",
    "notarilor": "notar",
    "notarul": "notar",
    "notarului": "notar",
    "notariala": "notarial",
    "notarială": "notarial",
    "notariale": "notarial",
    "notarialei": "notarial",
    "notarialele": "notarial",
    "notarialelor": "notarial",
    "notariali": "notarial",
    "notarialii": "notarial",
    "notarialilor": "notarial",
    "notarialul": "notarial",
    "notarialului": "notarial",
    "notariate": "notariat",
    "notariatele": "notariat",
    "notariatelor": "notariat",
    "notariatul": "notariat",
    "notariatului": "notariat",
    "notată": "notat",
    "notate": "notat",
    "notați": "notat",
    "notația": "notație",
    "notației": "notație",
    "notații": "notație",
    "notațiile": "notație",
    "notațiilor": "notație",
    "nemainotificând": "notifica",
    "nemainotificându": "notifica",
    "nenotificând": "notifica",
    "nenotificându": "notifica",
    "notific": "notifica",
    "notifică": "notifica",
    "notificai": "notifica",
    "notificam": "notifica",
    "notificăm": "notifica",
    "notificând": "notifica",
    "notificându": "notifica",
    "notificară": "notifica",
    "notificarăm": "notifica",
    "notificarăți": "notifica",
    "notificase": "notifica",
    "notificasem": "notifica",
    "notificaseră": "notifica",
    "notificaserăm": "notifica",
    "notificaserăți": "notifica",
    "notificaseși": "notifica",
    "notificași": "notifica",
    "notificat": "notifica",
    "notificați": "notifica",
    "notificau": "notifica",
    "notifice": "notifica",
    "notifici": "notifica",
    "notificarea": "notificare",
    "notificări": "notificare",
    "notificării": "notificare",
    "notificările": "notificare",
    "notificărilor": "notificare",
    "notificată": "notificat",
    "notificate": "notificat",
    "notificați": "notificat",
    "noționala": "noțional",
    "noțională": "noțional",
    "noționale": "noțional",
    "noționalei": "noțional",
    "noționalele": "noțional",
    "noționalelor": "noțional",
    "noționali": "noțional",
    "noționalii": "noțional",
    "noționalilor": "noțional",
    "noționalul": "noțional",
    "noționalului": "noțional",
    "notița": "notiță",
    "notițe": "notiță",
    "notiței": "notiță",
    "notițele": "notiță",
    "notițelor": "notiță",
    "noțiunea": "noțiune",
    "noțiuni": "noțiune",
    "noțiunii": "noțiune",
    "noțiunile": "noțiune",
    "noțiunilor": "noțiune",
    "notorietatea": "notorietate",
    "notorietăți": "notorietate",
    "notorietății": "notorietate",
    "notorietățile": "notorietate",
    "notorietăților": "notorietate",
    "notoria": "notoriu",
    "notorie": "notoriu",
    "notoriei": "notoriu",
    "notorii": "notoriu",
    "notoriii": "notoriu",
    "notoriile": "notoriu",
    "notoriilor": "notoriu",
    "notoriul": "notoriu",
    "notoriului": "notoriu",
    "noi": "nou",
    "noii": "nou",
    "noile": "nou",
    "noilor": "nou",
    "noua": "nou",
    "nouă": "nou",
    "noul": "nou",
    "noului": "nou",
    "IX": "nouă",
    "noua": "nouă",
    "nouălea": "nouă",
    "nouășpe": "nouăsprezece",
    "nouășpea": "nouăsprezece",
    "nouăsprezecea": "nouăsprezece",
    "nouăsprezecelea": "nouăsprezece",
    "XIX": "nouăsprezece",
    "nouăsprezecimea": "nouăsprezecime",
    "nouăsprezecimi": "nouăsprezecime",
    "nouăsprezecimii": "nouăsprezecime",
    "nouăsprezecimile": "nouăsprezecime",
    "nouăsprezecimilor": "nouăsprezecime",
    "nouăzecea": "nouăzeci",
    "nouăzecilea": "nouăzeci",
    "XC": "nouăzeci",
    "nou-născuta": "nou-născut",
    "nou-născută": "nou-născut",
    "nou-născute": "nou-născut",
    "nou-născutei": "nou-născut",
    "nou-născutele": "nou-născut",
    "nou-născutelor": "nou-născut",
    "nou-născuți": "nou-născut",
    "nou-născuții": "nou-născut",
    "nou-născuților": "nou-născut",
    "nou-născutul": "nou-născut",
    "nou-născutului": "nou-născut",
    "nou-născuta": "nou-născută",
    "nou-născute": "nou-născută",
    "nou-născutei": "nou-născută",
    "nou-născutele": "nou-născută",
    "nou-născutelor": "nou-născută",
    "noi-nouțe": "nou-nouț",
    "noi-nouți": "nou-nouț",
    "nouă-nouță": "nou-nouț",
    "nou-nouță": "nou-nouț",
    "nou-nouțe": "nou-nouț",
    "nou-nouți": "nou-nouț",
    "nouri": "nour",
    "nourii": "nour",
    "nourilor": "nour",
    "nourul": "nour",
    "nourului": "nour",
    "noutatea": "noutate",
    "noutăți": "noutate",
    "noutății": "noutate",
    "noutățile": "noutate",
    "noutăților": "noutate",
    "nou-venita": "nou-venit",
    "nou-venită": "nou-venit",
    "nou-venite": "nou-venit",
    "nou-venitei": "nou-venit",
    "nou-venitele": "nou-venit",
    "nou-venitelor": "nou-venit",
    "nou-veniți": "nou-venit",
    "nou-veniții": "nou-venit",
    "nou-veniților": "nou-venit",
    "nou-venitul": "nou-venit",
    "nou-venitului": "nou-venit",
    "Nouvorba": "Nouvorbă",
    "Nouvorbei": "Nouvorbă",
    "nova": "novă",
    "nove": "novă",
    "novei": "novă",
    "novele": "novă",
    "novelor": "novă",
    "novăceasca": "novăcesc",
    "novăcească": "novăcesc",
    "novăcescul": "novăcesc",
    "novăcescului": "novăcesc",
    "novăcești": "novăcesc",
    "novăceștii": "novăcesc",
    "novăceștile": "novăcesc",
    "novăceștilor": "novăcesc",
    "novatoarea": "novatoare",
    "novatoarei": "novatoare",
    "novatoarele": "novatoare",
    "novatoarelor": "novatoare",
    "novatori": "novator",
    "novatorii": "novator",
    "novatorilor": "novator",
    "novatorul": "novator",
    "novatorului": "novator",
    "novicea": "novice",
    "novicei": "novice",
    "novicele": "novice",
    "novicelor": "novice",
    "novicelui": "novice",
    "novici": "novice",
    "novicii": "novice",
    "novicilor": "novice",
    "noxa": "noxă",
    "noxe": "noxă",
    "noxei": "noxă",
    "noxele": "noxă",
    "noxelor": "noxă",
    "n-": "nu",
    "nemainuanțând": "nuanța",
    "nemainuanțându": "nuanța",
    "nenuanțând": "nuanța",
    "nenuanțându": "nuanța",
    "nuanță": "nuanța",
    "nuanțai": "nuanța",
    "nuanțam": "nuanța",
    "nuanțăm": "nuanța",
    "nuanțând": "nuanța",
    "nuanțându": "nuanța",
    "nuanțară": "nuanța",
    "nuanțarăm": "nuanța",
    "nuanțarăți": "nuanța",
    "nuanțase": "nuanța",
    "nuanțasem": "nuanța",
    "nuanțaseră": "nuanța",
    "nuanțaserăm": "nuanța",
    "nuanțaserăți": "nuanța",
    "nuanțaseși": "nuanța",
    "nuanțași": "nuanța",
    "nuanțat": "nuanța",
    "nuanțați": "nuanța",
    "nuanțau": "nuanța",
    "nuanțează": "nuanța",
    "nuanțez": "nuanța",
    "nuanțeze": "nuanța",
    "nuanțezi": "nuanța",
    "nuanța": "nuanță",
    "nuanțe": "nuanță",
    "nuanței": "nuanță",
    "nuanțele": "nuanță",
    "nuanțelor": "nuanță",
    "nuanțată": "nuanțat",
    "nuanțate": "nuanțat",
    "nuanțați": "nuanțat",
    "nubila": "nubil",
    "nubilă": "nubil",
    "nubile": "nubil",
    "nubilei": "nubil",
    "nubilele": "nubil",
    "nubilelor": "nubil",
    "nubili": "nubil",
    "nubilii": "nubil",
    "nubililor": "nubil",
    "nubilul": "nubil",
    "nubilului": "nubil",
    "nuci": "nuc",
    "nucii": "nuc",
    "nucilor": "nuc",
    "nucul": "nuc",
    "nucule": "nuc",
    "nucului": "nuc",
    "nuca": "nucă",
    "nuci": "nucă",
    "nucii": "nucă",
    "nucile": "nucă",
    "nucilor": "nucă",
    "nucifera": "nucifer",
    "nuciferă": "nucifer",
    "nucifere": "nucifer",
    "nuciferei": "nucifer",
    "nuciferele": "nucifer",
    "nuciferelor": "nucifer",
    "nuciferi": "nucifer",
    "nuciferii": "nucifer",
    "nuciferilor": "nucifer",
    "nuciferul": "nucifer",
    "nuciferului": "nucifer",
    "nuciforma": "nuciform",
    "nuciformă": "nuciform",
    "nuciforme": "nuciform",
    "nuciformei": "nuciform",
    "nuciformele": "nuciform",
    "nuciformelor": "nuciform",
    "nuciformi": "nuciform",
    "nuciformii": "nuciform",
    "nuciformilor": "nuciform",
    "nuciformul": "nuciform",
    "nuciformului": "nuciform",
    "nucl.": "nuclear",
    "nucleara": "nuclear",
    "nucleară": "nuclear",
    "nucleare": "nuclear",
    "nuclearei": "nuclear",
    "nuclearele": "nuclear",
    "nuclearelor": "nuclear",
    "nucleari": "nuclear",
    "nuclearii": "nuclear",
    "nuclearilor": "nuclear",
    "nuclearul": "nuclear",
    "nuclearului": "nuclear",
    "nucleici": "nucleic",
    "nucleicii": "nucleic",
    "nucleicilor": "nucleic",
    "nucleicul": "nucleic",
    "nucleicului": "nucleic",
    "nucleinici": "nucleinic",
    "nucleinicii": "nucleinic",
    "nucleinicilor": "nucleinic",
    "nucleinicul": "nucleinic",
    "nucleinicului": "nucleinic",
    "nucleoli": "nucleol",
    "nucleolii": "nucleol",
    "nucleolilor": "nucleol",
    "nucleolul": "nucleol",
    "nucleolului": "nucleol",
    "nucleoni": "nucleon",
    "nucleonii": "nucleon",
    "nucleonilor": "nucleon",
    "nucleonul": "nucleon",
    "nucleonului": "nucleon",
    "nuclee": "nucleu",
    "nucleele": "nucleu",
    "nucleelor": "nucleu",
    "nucleul": "nucleu",
    "nucleului": "nucleu",
    "Nucșoarei-Argeș": "Nucșoara-Argeș",
    "nuda": "nud",
    "nudă": "nud",
    "nude": "nud",
    "nudei": "nud",
    "nudele": "nud",
    "nudelor": "nud",
    "nudul": "nud",
    "nudului": "nud",
    "nuzi": "nud",
    "nuzii": "nud",
    "nuzilor": "nud",
    "nudismul": "nudism",
    "nudismului": "nudism",
    "nuditatea": "nuditate",
    "nudități": "nuditate",
    "nudității": "nuditate",
    "nuditățile": "nuditate",
    "nudităților": "nuditate",
    "nufărul": "nufăr",
    "nufărului": "nufăr",
    "nuferi": "nufăr",
    "nuferii": "nufăr",
    "nuferilor": "nufăr",
    "nugale": "nuga",
    "nugalei": "nuga",
    "nugalele": "nuga",
    "nugalelor": "nuga",
    "nugaua": "nuga",
    "nuiaua": "nuia",
    "nuiele": "nuia",
    "nuielei": "nuia",
    "nuielele": "nuia",
    "nuielelor": "nuia",
    "nula": "nul",
    "nulă": "nul",
    "nule": "nul",
    "nulei": "nul",
    "nulele": "nul",
    "nulelor": "nul",
    "nuli": "nul",
    "nulii": "nul",
    "nulilor": "nul",
    "nulul": "nul",
    "nulului": "nul",
    "nuligesta": "nuligestă",
    "nuligeste": "nuligestă",
    "nuligestei": "nuligestă",
    "nuligestele": "nuligestă",
    "nuligestelor": "nuligestă",
    "nulipara": "nulipară",
    "nulipare": "nulipară",
    "nuliparei": "nulipară",
    "nuliparele": "nulipară",
    "nuliparelor": "nulipară",
    "nulitatea": "nulitate",
    "nulități": "nulitate",
    "nulității": "nulitate",
    "nulitățile": "nulitate",
    "nulităților": "nulitate",
    "numa'": "numai",
    "no.": "număr",
    "număru'": "număr",
    "numărul": "număr",
    "numărului": "număr",
    "numere": "număr",
    "numerele": "număr",
    "numerelor": "număr",
    "nemainumărând": "număra",
    "nemainumărându": "număra",
    "nenumărând": "număra",
    "nenumărându": "număra",
    "număr": "număra",
    "numără": "număra",
    "numărai": "număra",
    "număram": "număra",
    "numărăm": "număra",
    "numărând": "număra",
    "numărându": "număra",
    "numărară": "număra",
    "numărarăm": "număra",
    "numărarăți": "număra",
    "numărase": "număra",
    "numărasem": "număra",
    "număraseră": "număra",
    "număraserăm": "număra",
    "număraserăți": "număra",
    "număraseși": "număra",
    "numărași": "număra",
    "numărat": "număra",
    "numărați": "număra",
    "numărau": "număra",
    "numere": "număra",
    "numeri": "număra",
    "numărarea": "numărare",
    "numărări": "numărare",
    "numărării": "numărare",
    "numărările": "numărare",
    "numărărilor": "numărare",
    "numărată": "numărat",
    "numărate": "numărat",
    "numărați": "numărat",
    "număratul": "numărat",
    "număratului": "numărat",
    "numărătoarea": "numărătoare",
    "numărători": "numărătoare",
    "numărătorii": "numărătoare",
    "numărătorile": "numărătoare",
    "numărătorilor": "numărătoare",
    "numărători": "numărător",
    "numărătorii": "numărător",
    "numărătorilor": "numărător",
    "numărătorul": "numărător",
    "numărătorului": "numărător",
    "nr.": "numărul",
    "numele": "nume",
    "numelor": "nume",
    "numelui": "nume",
    "n.l.": "nume_de_locuitor",
    "n.pr.": "nume_propriu",
    "numenala": "numenal",
    "numenală": "numenal",
    "numenale": "numenal",
    "numenalei": "numenal",
    "numenalele": "numenal",
    "numenalelor": "numenal",
    "numenali": "numenal",
    "numenalii": "numenal",
    "numenalilor": "numenal",
    "numenalul": "numenal",
    "numenalului": "numenal",
    "numerabila": "numerabil",
    "numerabilă": "numerabil",
    "numerabile": "numerabil",
    "numerabilei": "numerabil",
    "numerabilele": "numerabil",
    "numerabilelor": "numerabil",
    "numerabili": "numerabil",
    "numerabilii": "numerabil",
    "numerabililor": "numerabil",
    "numerabilul": "numerabil",
    "numerabilului": "numerabil",
    "num.": "numeral",
    "numerale": "numeral",
    "numeralele": "numeral",
    "numeralelor": "numeral",
    "numeralul": "numeral",
    "numeralului": "numeral",
    "num.adv": "numeral_adverbial",
    "num.card.": "numeral_cardinal",
    "num.col.": "numeral_colectiv",
    "num.multipl.": "numeral_multiplicativ",
    "num.ord.": "numeral_ordinal",
    "numerarul": "numerar",
    "numerarului": "numerar",
    "numerația": "numerație",
    "numerației": "numerație",
    "numerații": "numerație",
    "numerațiile": "numerație",
    "numerațiilor": "numerație",
    "numerica": "numeric",
    "numerică": "numeric",
    "numerice": "numeric",
    "numericei": "numeric",
    "numericele": "numeric",
    "numericelor": "numeric",
    "numerici": "numeric",
    "numericii": "numeric",
    "numericilor": "numeric",
    "numericul": "numeric",
    "numericului": "numeric",
    "numeroasa": "numeros",
    "numeroasă": "numeros",
    "numeroase": "numeros",
    "numeroasei": "numeros",
    "numeroasele": "numeros",
    "numeroaselor": "numeros",
    "numeroși": "numeros",
    "numeroșii": "numeros",
    "numeroșilor": "numeros",
    "numerosul": "numeros",
    "numerosului": "numeros",
    "nemainumerotând": "numerota",
    "nemainumerotându": "numerota",
    "nenumerotând": "numerota",
    "nenumerotându": "numerota",
    "numerotă": "numerota",
    "numerotai": "numerota",
    "numerotam": "numerota",
    "numerotăm": "numerota",
    "numerotând": "numerota",
    "numerotându": "numerota",
    "numerotară": "numerota",
    "numerotarăm": "numerota",
    "numerotarăți": "numerota",
    "numerotase": "numerota",
    "numerotasem": "numerota",
    "numerotaseră": "numerota",
    "numerotaserăm": "numerota",
    "numerotaserăți": "numerota",
    "numerotaseși": "numerota",
    "numerotași": "numerota",
    "numerotat": "numerota",
    "numerotați": "numerota",
    "numerotau": "numerota",
    "numerotează": "numerota",
    "numerotez": "numerota",
    "numeroteze": "numerota",
    "numerotezi": "numerota",
    "numerotarea": "numerotare",
    "numerotări": "numerotare",
    "numerotării": "numerotare",
    "numerotările": "numerotare",
    "numerotărilor": "numerotare",
    "numerotată": "numerotat",
    "numerotate": "numerotat",
    "numerotați": "numerotat",
    "nemainumind": "numi",
    "nemainumindu": "numi",
    "nenumind": "numi",
    "nenumindu": "numi",
    "numea": "numi",
    "numeai": "numi",
    "numeam": "numi",
    "numească": "numi",
    "numeați": "numi",
    "numeau": "numi",
    "numesc": "numi",
    "numește": "numi",
    "numești": "numi",
    "numii": "numi",
    "numim": "numi",
    "numind": "numi",
    "numindu": "numi",
    "numiră": "numi",
    "numirăm": "numi",
    "numirăți": "numi",
    "numise": "numi",
    "numisem": "numi",
    "numiseră": "numi",
    "numiserăm": "numi",
    "numiserăți": "numi",
    "numiseși": "numi",
    "numiși": "numi",
    "numit": "numi",
    "numiți": "numi",
    "numirea": "numire",
    "numiri": "numire",
    "numirii": "numire",
    "numirile": "numire",
    "numirilor": "numire",
    "numismați": "numismat",
    "numismații": "numismat",
    "numismaților": "numismat",
    "numismatul": "numismat",
    "numismatului": "numismat",
    "numismata": "numismată",
    "numismate": "numismată",
    "numismatei": "numismată",
    "numismatele": "numismată",
    "numismatelor": "numismată",
    "numismatica": "numismatic",
    "numismatică": "numismatic",
    "numismatice": "numismatic",
    "numismaticei": "numismatic",
    "numismaticele": "numismatic",
    "numismaticelor": "numismatic",
    "numismatici": "numismatic",
    "numismaticii": "numismatic",
    "numismaticilor": "numismatic",
    "numismaticul": "numismatic",
    "numismaticului": "numismatic",
    "numismatica": "numismatică",
    "numismatici": "numismatică",
    "numismaticii": "numismatică",
    "numita": "numit",
    "numită": "numit",
    "numite": "numit",
    "numitei": "numit",
    "numitele": "numit",
    "numitelor": "numit",
    "numiți": "numit",
    "numiții": "numit",
    "numiților": "numit",
    "numitul": "numit",
    "numitului": "numit",
    "numitori": "numitor",
    "numitorii": "numitor",
    "numitorilor": "numitor",
    "numitorul": "numitor",
    "numitorului": "numitor",
    "nuni": "nun",
    "nunii": "nun",
    "nunilor": "nun",
    "nunul": "nun",
    "nunului": "nun",
    "nuna": "nună",
    "nune": "nună",
    "nunei": "nună",
    "nunele": "nună",
    "nunelor": "nună",
    "nunta": "nuntă",
    "nunți": "nuntă",
    "nunții": "nuntă",
    "nunțile": "nuntă",
    "nunților": "nuntă",
    "nuntași": "nuntaș",
    "nuntașii": "nuntaș",
    "nuntașilor": "nuntaș",
    "nuntașul": "nuntaș",
    "nuntașului": "nuntaș",
    "nuntașa": "nuntașă",
    "nuntașe": "nuntașă",
    "nuntașei": "nuntașă",
    "nuntașele": "nuntașă",
    "nuntașelor": "nuntașă",
    "nemainuntind": "nunti",
    "nemainuntindu": "nunti",
    "nenuntind": "nunti",
    "nenuntindu": "nunti",
    "nuntea": "nunti",
    "nunteai": "nunti",
    "nunteam": "nunti",
    "nuntească": "nunti",
    "nunteați": "nunti",
    "nunteau": "nunti",
    "nuntesc": "nunti",
    "nuntește": "nunti",
    "nuntești": "nunti",
    "nuntii": "nunti",
    "nuntim": "nunti",
    "nuntind": "nunti",
    "nuntindu": "nunti",
    "nuntiră": "nunti",
    "nuntirăm": "nunti",
    "nuntirăți": "nunti",
    "nuntise": "nunti",
    "nuntisem": "nunti",
    "nuntiseră": "nunti",
    "nuntiserăm": "nunti",
    "nuntiserăți": "nunti",
    "nuntiseși": "nunti",
    "nuntiși": "nunti",
    "nuntit": "nunti",
    "nuntiți": "nunti",
    "nunțiala": "nunțial",
    "nunțială": "nunțial",
    "nunțiale": "nunțial",
    "nunțialei": "nunțial",
    "nunțialele": "nunțial",
    "nunțialelor": "nunțial",
    "nunțiali": "nunțial",
    "nunțialii": "nunțial",
    "nunțialilor": "nunțial",
    "nunțialul": "nunțial",
    "nunțialului": "nunțial",
    "nuntită": "nuntit",
    "nuntite": "nuntit",
    "nuntiți": "nuntit",
    "nuntitoare": "nuntitor",
    "nuntitoarea": "nuntitor",
    "nuntitoarei": "nuntitor",
    "nuntitoarele": "nuntitor",
    "nuntitoarelor": "nuntitor",
    "nuntitori": "nuntitor",
    "nuntitorii": "nuntitor",
    "nuntitorilor": "nuntitor",
    "nuntitorul": "nuntitor",
    "nuntitorului": "nuntitor",
    "nupțiala": "nupțial",
    "nupțială": "nupțial",
    "nupțiale": "nupțial",
    "nupțialei": "nupțial",
    "nupțialele": "nupțial",
    "nupțialelor": "nupțial",
    "nupțiali": "nupțial",
    "nupțialii": "nupțial",
    "nupțialilor": "nupțial",
    "nupțialul": "nupțial",
    "nupțialului": "nupțial",
    "nuri": "nur",
    "nurii": "nur",
    "nurilor": "nur",
    "nurul": "nur",
    "nurului": "nur",
    "nurca": "nurcă",
    "nurci": "nurcă",
    "nurcii": "nurcă",
    "nurcile": "nurcă",
    "nurcilor": "nurcă",
    "Nurembergul": "Nuremberg",
    "Nurembergului": "Nuremberg",
    "nurlia": "nurliu",
    "nurlie": "nurliu",
    "nurliei": "nurliu",
    "nurlii": "nurliu",
    "nurliii": "nurliu",
    "nurliile": "nurliu",
    "nurliilor": "nurliu",
    "nurliul": "nurliu",
    "nurliului": "nurliu",
    "nutrețul": "nutreț",
    "nutrețului": "nutreț",
    "nutrețuri": "nutreț",
    "nutrețurile": "nutreț",
    "nutrețurilor": "nutreț",
    "nemainutrind": "nutri",
    "nemainutrindu": "nutri",
    "nenutrind": "nutri",
    "nenutrindu": "nutri",
    "nutrea": "nutri",
    "nutreai": "nutri",
    "nutream": "nutri",
    "nutrească": "nutri",
    "nutreați": "nutri",
    "nutreau": "nutri",
    "nutresc": "nutri",
    "nutrește": "nutri",
    "nutrești": "nutri",
    "nutrii": "nutri",
    "nutrim": "nutri",
    "nutrind": "nutri",
    "nutrindu": "nutri",
    "nutriră": "nutri",
    "nutrirăm": "nutri",
    "nutrirăți": "nutri",
    "nutrise": "nutri",
    "nutrisem": "nutri",
    "nutriseră": "nutri",
    "nutriserăm": "nutri",
    "nutriserăți": "nutri",
    "nutriseși": "nutri",
    "nutriși": "nutri",
    "nutrit": "nutri",
    "nutriți": "nutri",
    "nutriei": "nutria",
    "nutrii": "nutria",
    "nutriile": "nutria",
    "nutriilor": "nutria",
    "nutrită": "nutrit",
    "nutrite": "nutrit",
    "nutriți": "nutrit",
    "nutriția": "nutriție",
    "nutriției": "nutriție",
    "nutriții": "nutriție",
    "nutrițiile": "nutriție",
    "nutrițiilor": "nutriție",
    "nutritiva": "nutritiv",
    "nutritivă": "nutritiv",
    "nutritive": "nutritiv",
    "nutritivei": "nutritiv",
    "nutritivele": "nutritiv",
    "nutritivelor": "nutritiv",
    "nutritivi": "nutritiv",
    "nutritivii": "nutritiv",
    "nutritivilor": "nutritiv",
    "nutritivul": "nutritiv",
    "nutritivului": "nutritiv",
    "nuvela": "nuvelă",
    "nuvele": "nuvelă",
    "nuvelei": "nuvelă",
    "nuvelele": "nuvelă",
    "nuvelelor": "nuvelă",
    "nuveliști": "nuvelist",
    "nuveliștii": "nuvelist",
    "nuveliștilor": "nuvelist",
    "nuvelistul": "nuvelist",
    "nuvelistului": "nuvelist",
    "nuvelista": "nuvelistă",
    "nuveliste": "nuvelistă",
    "nuvelistei": "nuvelistă",
    "nuvelistele": "nuvelistă",
    "nuvelistelor": "nuvelistă",
    "nuvelistica": "nuvelistic",
    "nuvelistică": "nuvelistic",
    "nuvelistice": "nuvelistic",
    "nuvelisticei": "nuvelistic",
    "nuvelisticele": "nuvelistic",
    "nuvelisticelor": "nuvelistic",
    "nuvelistici": "nuvelistic",
    "nuvelisticii": "nuvelistic",
    "nuvelisticilor": "nuvelistic",
    "nuvelisticul": "nuvelistic",
    "nuvelisticului": "nuvelistic",
    "oacăra": "oacăr",
    "oacără": "oacăr",
    "oacăre": "oacăr",
    "oacărei": "oacăr",
    "oacărele": "oacăr",
    "oacărelor": "oacăr",
    "oacări": "oacăr",
    "oacării": "oacăr",
    "oacărilor": "oacăr",
    "oacărul": "oacăr",
    "oacărului": "oacăr",
    "oacheșa": "oacheș",
    "oacheșă": "oacheș",
    "oacheșe": "oacheș",
    "oacheșei": "oacheș",
    "oacheșele": "oacheș",
    "oacheșelor": "oacheș",
    "oacheși": "oacheș",
    "oacheșii": "oacheș",
    "oacheșilor": "oacheș",
    "oacheșul": "oacheș",
    "oacheșului": "oacheș",
    "oaia": "oaie",
    "oi": "oaie",
    "oii": "oaie",
    "oile": "oaie",
    "oilor": "oaie",
    "oala": "oală",
    "oale": "oală",
    "oalei": "oală",
    "oalele": "oală",
    "oalelor": "oală",
    "Oanei": "Oana",
    "ori": "oară",
    "oarba": "oarbă",
    "oarbe": "oarbă",
    "oarbei": "oarbă",
    "oarbele": "oarbă",
    "oarbelor": "oarbă",
    "oarecui": "oarecine",
    "oaspetele": "oaspete",
    "oaspetelui": "oaspete",
    "oaspeți": "oaspete",
    "oaspeții": "oaspete",
    "oaspeților": "oaspete",
    "oastea": "oaste",
    "oastei": "oaste",
    "oști": "oaste",
    "oștii": "oaste",
    "oștile": "oaste",
    "oștilor": "oaste",
    "oaza": "oază",
    "oaze": "oază",
    "oazei": "oază",
    "oazele": "oază",
    "oazelor": "oază",
    "obada": "obadă",
    "obezi": "obadă",
    "obezii": "obadă",
    "obezile": "obadă",
    "obezilor": "obadă",
    "obârșia": "obârșie",
    "obârșiei": "obârșie",
    "obârșii": "obârșie",
    "obârșiile": "obârșie",
    "obârșiilor": "obârșie",
    "obcina": "obcină",
    "obcine": "obcină",
    "obcinei": "obcină",
    "obcinele": "obcină",
    "obcinelor": "obcină",
    "obedienta": "obedient",
    "obedientă": "obedient",
    "obediente": "obedient",
    "obedientei": "obedient",
    "obedientele": "obedient",
    "obedientelor": "obedient",
    "obedienți": "obedient",
    "obedienții": "obedient",
    "obedienților": "obedient",
    "obedientul": "obedient",
    "obedientului": "obedient",
    "obediența": "obediență",
    "obediențe": "obediență",
    "obedienței": "obediență",
    "obediențele": "obediență",
    "obediențelor": "obediență",
    "obeliscul": "obelisc",
    "obeliscului": "obelisc",
    "obeliscuri": "obelisc",
    "obeliscurile": "obelisc",
    "obeliscurilor": "obelisc",
    "oberlihtul": "oberliht",
    "oberlihtului": "oberliht",
    "oberlihturi": "oberliht",
    "oberlihturile": "oberliht",
    "oberlihturilor": "oberliht",
    "obeza": "obez",
    "obeză": "obez",
    "obeze": "obez",
    "obezei": "obez",
    "obezele": "obez",
    "obezelor": "obez",
    "obezi": "obez",
    "obezii": "obez",
    "obezilor": "obez",
    "obezul": "obez",
    "obezului": "obez",
    "obezitatea": "obezitate",
    "obezități": "obezitate",
    "obezității": "obezitate",
    "obezitățile": "obezitate",
    "obezităților": "obezitate",
    "obiala": "obială",
    "obiele": "obială",
    "obielei": "obială",
    "obielele": "obială",
    "obielelor": "obială",
    "obiceiul": "obicei",
    "obiceiului": "obicei",
    "obiceiuri": "obicei",
    "obiceiurile": "obicei",
    "obiceiurilor": "obicei",
    "obida": "obidă",
    "obide": "obidă",
    "obidei": "obidă",
    "obidele": "obidă",
    "obidelor": "obidă",
    "obidoasa": "obidos",
    "obidoasă": "obidos",
    "obidoase": "obidos",
    "obidoasei": "obidos",
    "obidoasele": "obidos",
    "obidoaselor": "obidos",
    "obidoși": "obidos",
    "obidoșii": "obidos",
    "obidoșilor": "obidos",
    "obidosul": "obidos",
    "obidosului": "obidos",
    "obiecte": "obiect",
    "obiectele": "obiect",
    "obiectelor": "obiect",
    "obiectul": "obiect",
    "obiectului": "obiect",
    "nemaiobiectând": "obiecta",
    "nemaiobiectându": "obiecta",
    "neobiectând": "obiecta",
    "neobiectându": "obiecta",
    "obiectă": "obiecta",
    "obiectai": "obiecta",
    "obiectam": "obiecta",
    "obiectăm": "obiecta",
    "obiectând": "obiecta",
    "obiectându": "obiecta",
    "obiectară": "obiecta",
    "obiectarăm": "obiecta",
    "obiectarăți": "obiecta",
    "obiectase": "obiecta",
    "obiectasem": "obiecta",
    "obiectaseră": "obiecta",
    "obiectaserăm": "obiecta",
    "obiectaserăți": "obiecta",
    "obiectaseși": "obiecta",
    "obiectași": "obiecta",
    "obiectat": "obiecta",
    "obiectați": "obiecta",
    "obiectau": "obiecta",
    "obiectează": "obiecta",
    "obiectez": "obiecta",
    "obiecteze": "obiecta",
    "obiectezi": "obiecta",
    "obiectată": "obiectat",
    "obiectate": "obiectat",
    "obiectați": "obiectat",
    "O.Z.N.": "Obiecte_Zburătoare_Neidentificate",
    "obiecția": "obiecție",
    "obiecției": "obiecție",
    "obiecții": "obiecție",
    "obiecțiile": "obiecție",
    "obiecțiilor": "obiecție",
    "obiecțiunea": "obiecțiune",
    "obiecțiuni": "obiecțiune",
    "obiecțiunii": "obiecțiune",
    "obiecțiunile": "obiecțiune",
    "obiecțiunilor": "obiecțiune",
    "obiectiva": "obiectiv",
    "obiectivă": "obiectiv",
    "obiective": "obiectiv",
    "obiectivei": "obiectiv",
    "obiectivele": "obiectiv",
    "obiectivelor": "obiectiv",
    "obiectivi": "obiectiv",
    "obiectivii": "obiectiv",
    "obiectivilor": "obiectiv",
    "obiectivul": "obiectiv",
    "obiectivului": "obiectiv",
    "obiectivai": "obiectiva",
    "obiectivam": "obiectiva",
    "obiectivară": "obiectiva",
    "obiectivarăm": "obiectiva",
    "obiectivarăți": "obiectiva",
    "obiectivase": "obiectiva",
    "obiectivasem": "obiectiva",
    "obiectivaseră": "obiectiva",
    "obiectivaserăm": "obiectiva",
    "obiectivaserăți": "obiectiva",
    "obiectivaseși": "obiectiva",
    "obiectivași": "obiectiva",
    "obiectivat": "obiectiva",
    "obiectivați": "obiectiva",
    "obiectivau": "obiectiva",
    "obiectivează": "obiectiva",
    "obiectivez": "obiectiva",
    "obiectiveze": "obiectiva",
    "obiectivezi": "obiectiva",
    "obiectivată": "obiectivat",
    "obiectivate": "obiectivat",
    "obiectivați": "obiectivat",
    "obiectivismul": "obiectivism",
    "obiectivismului": "obiectivism",
    "obiectivista": "obiectivist",
    "obiectivistă": "obiectivist",
    "obiectiviste": "obiectivist",
    "obiectivistei": "obiectivist",
    "obiectivistele": "obiectivist",
    "obiectivistelor": "obiectivist",
    "obiectiviști": "obiectivist",
    "obiectiviștii": "obiectivist",
    "obiectiviștilor": "obiectivist",
    "obiectivistul": "obiectivist",
    "obiectivistului": "obiectivist",
    "obiectivista": "obiectivistă",
    "obiectiviste": "obiectivistă",
    "obiectivistei": "obiectivistă",
    "obiectivistele": "obiectivistă",
    "obiectivistelor": "obiectivistă",
    "obiectivitatea": "obiectivitate",
    "obiectivități": "obiectivitate",
    "obiectivității": "obiectivitate",
    "obiectivitățile": "obiectivitate",
    "obiectivităților": "obiectivitate",
    "obiectuala": "obiectual",
    "obiectuală": "obiectual",
    "obiectuale": "obiectual",
    "obiectualei": "obiectual",
    "obiectualele": "obiectual",
    "obiectualelor": "obiectual",
    "obiectuali": "obiectual",
    "obiectualii": "obiectual",
    "obiectualilor": "obiectual",
    "obiectualul": "obiectual",
    "obiectualului": "obiectual",
    "ob.": "obiit",
    "nemaiobișnuind": "obișnui",
    "nemaiobișnuindu": "obișnui",
    "neobișnuind": "obișnui",
    "neobișnuindu": "obișnui",
    "obișnuia": "obișnui",
    "obișnuiai": "obișnui",
    "obișnuiam": "obișnui",
    "obișnuiască": "obișnui",
    "obișnuiați": "obișnui",
    "obișnuiau": "obișnui",
    "obișnuiesc": "obișnui",
    "obișnuiește": "obișnui",
    "obișnuiești": "obișnui",
    "obișnuii": "obișnui",
    "obișnuim": "obișnui",
    "obișnuind": "obișnui",
    "obișnuindu": "obișnui",
    "obișnuiră": "obișnui",
    "obișnuirăm": "obișnui",
    "obișnuirăți": "obișnui",
    "obișnuise": "obișnui",
    "obișnuisem": "obișnui",
    "obișnuiseră": "obișnui",
    "obișnuiserăm": "obișnui",
    "obișnuiserăți": "obișnui",
    "obișnuiseși": "obișnui",
    "obișnuiși": "obișnui",
    "obișnuit": "obișnui",
    "obișnuiți": "obișnui",
    "obișnuința": "obișnuință",
    "obișnuințe": "obișnuință",
    "obișnuinței": "obișnuință",
    "obișnuințele": "obișnuință",
    "obișnuințelor": "obișnuință",
    "obișnuita": "obișnuit",
    "obișnuită": "obișnuit",
    "obișnuite": "obișnuit",
    "obișnuitei": "obișnuit",
    "obișnuitele": "obișnuit",
    "obișnuitelor": "obișnuit",
    "obișnuiți": "obișnuit",
    "obișnuiții": "obișnuit",
    "obișnuiților": "obișnuit",
    "obișnuitul": "obișnuit",
    "obișnuitului": "obișnuit",
    "nemaioblăduind": "oblădui",
    "nemaioblăduindu": "oblădui",
    "neoblăduind": "oblădui",
    "neoblăduindu": "oblădui",
    "oblăduia": "oblădui",
    "oblăduiai": "oblădui",
    "oblăduiam": "oblădui",
    "oblăduiască": "oblădui",
    "oblăduiați": "oblădui",
    "oblăduiau": "oblădui",
    "oblăduiesc": "oblădui",
    "oblăduiește": "oblădui",
    "oblăduiești": "oblădui",
    "oblăduii": "oblădui",
    "oblăduim": "oblădui",
    "oblăduind": "oblădui",
    "oblăduindu": "oblădui",
    "oblăduiră": "oblădui",
    "oblăduirăm": "oblădui",
    "oblăduirăți": "oblădui",
    "oblăduise": "oblădui",
    "oblăduisem": "oblădui",
    "oblăduiseră": "oblădui",
    "oblăduiserăm": "oblădui",
    "oblăduiserăți": "oblădui",
    "oblăduiseși": "oblădui",
    "oblăduiși": "oblădui",
    "oblăduit": "oblădui",
    "oblăduiți": "oblădui",
    "oblăduirea": "oblăduire",
    "oblăduiri": "oblăduire",
    "oblăduirii": "oblăduire",
    "oblăduirile": "oblăduire",
    "oblăduirilor": "oblăduire",
    "oblăduită": "oblăduit",
    "oblăduite": "oblăduit",
    "oblăduiți": "oblăduit",
    "oblăduitoare": "oblăduitor",
    "oblăduitoarea": "oblăduitor",
    "oblăduitoarei": "oblăduitor",
    "oblăduitoarele": "oblăduitor",
    "oblăduitoarelor": "oblăduitor",
    "oblăduitori": "oblăduitor",
    "oblăduitorii": "oblăduitor",
    "oblăduitorilor": "oblăduitor",
    "oblăduitorul": "oblăduitor",
    "oblăduitorului": "oblăduitor",
    "oblâncul": "oblânc",
    "oblâncului": "oblânc",
    "oblâncuri": "oblânc",
    "oblâncurile": "oblânc",
    "oblâncurilor": "oblânc",
    "obleți": "obleț",
    "obleții": "obleț",
    "obleților": "obleț",
    "oblețul": "obleț",
    "oblețului": "obleț",
    "oblica": "oblic",
    "oblică": "oblic",
    "oblice": "oblic",
    "oblicei": "oblic",
    "oblicele": "oblic",
    "oblicelor": "oblic",
    "oblici": "oblic",
    "oblicii": "oblic",
    "oblicilor": "oblic",
    "oblicul": "oblic",
    "oblicului": "oblic",
    "nemaiobligând": "obliga",
    "nemaiobligându": "obliga",
    "neobligând": "obliga",
    "neobligându": "obliga",
    "oblig": "obliga",
    "obligă": "obliga",
    "obligai": "obliga",
    "obligam": "obliga",
    "obligăm": "obliga",
    "obligând": "obliga",
    "obligându": "obliga",
    "obligară": "obliga",
    "obligarăm": "obliga",
    "obligarăți": "obliga",
    "obligase": "obliga",
    "obligasem": "obliga",
    "obligaseră": "obliga",
    "obligaserăm": "obliga",
    "obligaserăți": "obliga",
    "obligaseși": "obliga",
    "obligași": "obliga",
    "obligat": "obliga",
    "obligați": "obliga",
    "obligau": "obliga",
    "oblige": "obliga",
    "obligi": "obliga",
    "obligată": "obligat",
    "obligate": "obligat",
    "obligați": "obligat",
    "obligația": "obligație",
    "obligației": "obligație",
    "obligații": "obligație",
    "obligațiile": "obligație",
    "obligațiilor": "obligație",
    "obligațiunea": "obligațiune",
    "obligațiuni": "obligațiune",
    "obligațiunii": "obligațiune",
    "obligațiunile": "obligațiune",
    "obligațiunilor": "obligațiune",
    "obligativitatea": "obligativitate",
    "obligativități": "obligativitate",
    "obligativității": "obligativitate",
    "obligatoria": "obligatoriu",
    "obligatorie": "obligatoriu",
    "obligatoriei": "obligatoriu",
    "obligatorii": "obligatoriu",
    "obligatoriii": "obligatoriu",
    "obligatoriile": "obligatoriu",
    "obligatoriilor": "obligatoriu",
    "obligatoriul": "obligatoriu",
    "obligatoriului": "obligatoriu",
    "obliteranta": "obliterant",
    "obliterantă": "obliterant",
    "obliterante": "obliterant",
    "obliterantei": "obliterant",
    "obliterantele": "obliterant",
    "obliterantelor": "obliterant",
    "obliteranți": "obliterant",
    "obliteranții": "obliterant",
    "obliteranților": "obliterant",
    "obliterantul": "obliterant",
    "obliterantului": "obliterant",
    "oblojeala": "oblojeală",
    "oblojeli": "oblojeală",
    "oblojelii": "oblojeală",
    "oblojelile": "oblojeală",
    "oblojelilor": "oblojeală",
    "nemaioblojind": "obloji",
    "nemaioblojindu": "obloji",
    "neoblojind": "obloji",
    "neoblojindu": "obloji",
    "oblojea": "obloji",
    "oblojeai": "obloji",
    "oblojeam": "obloji",
    "oblojească": "obloji",
    "oblojeați": "obloji",
    "oblojeau": "obloji",
    "oblojesc": "obloji",
    "oblojește": "obloji",
    "oblojești": "obloji",
    "oblojii": "obloji",
    "oblojim": "obloji",
    "oblojind": "obloji",
    "oblojindu": "obloji",
    "oblojiră": "obloji",
    "oblojirăm": "obloji",
    "oblojirăți": "obloji",
    "oblojise": "obloji",
    "oblojisem": "obloji",
    "oblojiseră": "obloji",
    "oblojiserăm": "obloji",
    "oblojiserăți": "obloji",
    "oblojiseși": "obloji",
    "oblojiși": "obloji",
    "oblojit": "obloji",
    "oblojiți": "obloji",
    "oblojită": "oblojit",
    "oblojite": "oblojit",
    "oblojiți": "oblojit",
    "obloane": "oblon",
    "obloanele": "oblon",
    "obloanelor": "oblon",
    "oblonul": "oblon",
    "oblonului": "oblon",
    "oblonea": "obloni",
    "obloneai": "obloni",
    "obloneam": "obloni",
    "oblonească": "obloni",
    "obloneați": "obloni",
    "obloneau": "obloni",
    "oblonesc": "obloni",
    "oblonește": "obloni",
    "oblonești": "obloni",
    "oblonii": "obloni",
    "oblonim": "obloni",
    "oblonind": "obloni",
    "oblonindu": "obloni",
    "obloniră": "obloni",
    "oblonirăm": "obloni",
    "oblonirăți": "obloni",
    "oblonise": "obloni",
    "oblonisem": "obloni",
    "obloniseră": "obloni",
    "obloniserăm": "obloni",
    "obloniserăți": "obloni",
    "obloniseși": "obloni",
    "obloniși": "obloni",
    "oblonit": "obloni",
    "obloniți": "obloni",
    "oblonită": "oblonit",
    "oblonite": "oblonit",
    "obloniți": "oblonit",
    "oboaie": "oboi",
    "oboaiele": "oboi",
    "oboaielor": "oboi",
    "oboiul": "oboi",
    "oboiului": "oboi",
    "obolul": "obol",
    "obolului": "obol",
    "oboluri": "obol",
    "obolurile": "obol",
    "obolurilor": "obol",
    "oboare": "obor",
    "oboarele": "obor",
    "oboarelor": "obor",
    "oborul": "obor",
    "oborului": "obor",
    "oboroace": "oboroc",
    "oboroacele": "oboroc",
    "oboroacelor": "oboroc",
    "oborocul": "oboroc",
    "oborocului": "oboroc",
    "oboseala": "oboseală",
    "oboseli": "oboseală",
    "oboselii": "oboseală",
    "oboselile": "oboseală",
    "oboselilor": "oboseală",
    "nemaiobosind": "obosi",
    "nemaiobosindu": "obosi",
    "neobosind": "obosi",
    "neobosindu": "obosi",
    "obosea": "obosi",
    "oboseai": "obosi",
    "oboseam": "obosi",
    "obosească": "obosi",
    "oboseați": "obosi",
    "oboseau": "obosi",
    "obosesc": "obosi",
    "obosește": "obosi",
    "obosești": "obosi",
    "obosii": "obosi",
    "obosim": "obosi",
    "obosind": "obosi",
    "obosindu": "obosi",
    "obosiră": "obosi",
    "obosirăm": "obosi",
    "obosirăți": "obosi",
    "obosise": "obosi",
    "obosisem": "obosi",
    "obosiseră": "obosi",
    "obosiserăm": "obosi",
    "obosiserăți": "obosi",
    "obosiseși": "obosi",
    "obosiși": "obosi",
    "obosit": "obosi",
    "obosiți": "obosi",
    "obosirea": "obosire",
    "obosiri": "obosire",
    "obosirii": "obosire",
    "obosirile": "obosire",
    "obosirilor": "obosire",
    "obosită": "obosit",
    "obosite": "obosit",
    "obosiți": "obosit",
    "obositoare": "obositor",
    "obositoarea": "obositor",
    "obositoarei": "obositor",
    "obositoarele": "obositor",
    "obositoarelor": "obositor",
    "obositori": "obositor",
    "obositorii": "obositor",
    "obositorilor": "obositor",
    "obositorul": "obositor",
    "obositorului": "obositor",
    "obraji": "obraz",
    "obrajii": "obraz",
    "obrajilor": "obraz",
    "obraze": "obraz",
    "obrazele": "obraz",
    "obrazelor": "obraz",
    "obrazul": "obraz",
    "obrazului": "obraz",
    "obrăzare": "obrăzar",
    "obrăzarele": "obrăzar",
    "obrăzarelor": "obrăzar",
    "obrăzarul": "obrăzar",
    "obrăzarului": "obrăzar",
    "obrăzata": "obrăzat",
    "obrăzată": "obrăzat",
    "obrăzate": "obrăzat",
    "obrăzatei": "obrăzat",
    "obrăzatele": "obrăzat",
    "obrăzatelor": "obrăzat",
    "obrăzați": "obrăzat",
    "obrăzații": "obrăzat",
    "obrăzaților": "obrăzat",
    "obrăzatul": "obrăzat",
    "obrăzatului": "obrăzat",
    "obraznica": "obraznic",
    "obraznică": "obraznic",
    "obraznice": "obraznic",
    "obraznicei": "obraznic",
    "obraznicele": "obraznic",
    "obraznicelor": "obraznic",
    "obraznici": "obraznic",
    "obraznicii": "obraznic",
    "obraznicilor": "obraznic",
    "obraznicul": "obraznic",
    "obraznicului": "obraznic",
    "obraznica": "obraznică",
    "obraznice": "obraznică",
    "obraznicei": "obraznică",
    "obraznicele": "obraznică",
    "obraznicelor": "obraznică",
    "nemaiobrăznicind": "obrăznici",
    "nemaiobrăznicindu": "obrăznici",
    "neobrăznicind": "obrăznici",
    "neobrăznicindu": "obrăznici",
    "obrăznicea": "obrăznici",
    "obrăzniceai": "obrăznici",
    "obrăzniceam": "obrăznici",
    "obrăznicească": "obrăznici",
    "obrăzniceați": "obrăznici",
    "obrăzniceau": "obrăznici",
    "obrăznicesc": "obrăznici",
    "obrăznicește": "obrăznici",
    "obrăznicești": "obrăznici",
    "obrăznicii": "obrăznici",
    "obrăznicim": "obrăznici",
    "obrăznicind": "obrăznici",
    "obrăznicindu": "obrăznici",
    "obrăzniciră": "obrăznici",
    "obrăznicirăm": "obrăznici",
    "obrăznicirăți": "obrăznici",
    "obrăznicise": "obrăznici",
    "obrăznicisem": "obrăznici",
    "obrăzniciseră": "obrăznici",
    "obrăzniciserăm": "obrăznici",
    "obrăzniciserăți": "obrăznici",
    "obrăzniciseși": "obrăznici",
    "obrăzniciși": "obrăznici",
    "obrăznicit": "obrăznici",
    "obrăzniciți": "obrăznici",
    "obrăznicia": "obrăznicie",
    "obrăzniciei": "obrăznicie",
    "obrăznicii": "obrăznicie",
    "obrăzniciile": "obrăznicie",
    "obrăzniciilor": "obrăznicie",
    "obrăznicită": "obrăznicit",
    "obrăznicite": "obrăznicit",
    "obrăzniciți": "obrăznicit",
    "obrocul": "obroc",
    "obrocului": "obroc",
    "obscena": "obscen",
    "obscenă": "obscen",
    "obscene": "obscen",
    "obscenei": "obscen",
    "obscenele": "obscen",
    "obscenelor": "obscen",
    "obsceni": "obscen",
    "obscenii": "obscen",
    "obscenilor": "obscen",
    "obscenul": "obscen",
    "obscenului": "obscen",
    "obscenitatea": "obscenitate",
    "obscenități": "obscenitate",
    "obscenității": "obscenitate",
    "obscenitățile": "obscenitate",
    "obscenităților": "obscenitate",
    "obscura": "obscur",
    "obscură": "obscur",
    "obscure": "obscur",
    "obscurei": "obscur",
    "obscurele": "obscur",
    "obscurelor": "obscur",
    "obscuri": "obscur",
    "obscurii": "obscur",
    "obscurilor": "obscur",
    "obscurul": "obscur",
    "obscurului": "obscur",
    "obscurantismul": "obscurantism",
    "obscurantismului": "obscurantism",
    "obscurantista": "obscurantist",
    "obscurantistă": "obscurantist",
    "obscurantiste": "obscurantist",
    "obscurantistei": "obscurantist",
    "obscurantistele": "obscurantist",
    "obscurantistelor": "obscurantist",
    "obscurantiști": "obscurantist",
    "obscurantiștii": "obscurantist",
    "obscurantiștilor": "obscurantist",
    "obscurantistul": "obscurantist",
    "obscurantistului": "obscurantist",
    "obscuritatea": "obscuritate",
    "obscurități": "obscuritate",
    "obscurității": "obscuritate",
    "obscuritățile": "obscuritate",
    "obscurităților": "obscuritate",
    "obsecventa": "obsecvent",
    "obsecventă": "obsecvent",
    "obsecvente": "obsecvent",
    "obsecventei": "obsecvent",
    "obsecventele": "obsecvent",
    "obsecventelor": "obsecvent",
    "obsecvenți": "obsecvent",
    "obsecvenții": "obsecvent",
    "obsecvenților": "obsecvent",
    "obsecventul": "obsecvent",
    "obsecventului": "obsecvent",
    "nemaiobsedând": "obseda",
    "nemaiobsedându": "obseda",
    "neobsedând": "obseda",
    "neobsedându": "obseda",
    "obsedă": "obseda",
    "obsedai": "obseda",
    "obsedam": "obseda",
    "obsedăm": "obseda",
    "obsedând": "obseda",
    "obsedându": "obseda",
    "obsedară": "obseda",
    "obsedarăm": "obseda",
    "obsedarăți": "obseda",
    "obsedase": "obseda",
    "obsedasem": "obseda",
    "obsedaseră": "obseda",
    "obsedaserăm": "obseda",
    "obsedaserăți": "obseda",
    "obsedaseși": "obseda",
    "obsedași": "obseda",
    "obsedat": "obseda",
    "obsedați": "obseda",
    "obsedau": "obseda",
    "obsedează": "obseda",
    "obsedez": "obseda",
    "obsedeze": "obseda",
    "obsedezi": "obseda",
    "obsedanta": "obsedant",
    "obsedantă": "obsedant",
    "obsedante": "obsedant",
    "obsedantei": "obsedant",
    "obsedantele": "obsedant",
    "obsedantelor": "obsedant",
    "obsedanți": "obsedant",
    "obsedanții": "obsedant",
    "obsedanților": "obsedant",
    "obsedantul": "obsedant",
    "obsedantului": "obsedant",
    "obsedata": "obsedat",
    "obsedată": "obsedat",
    "obsedate": "obsedat",
    "obsedatei": "obsedat",
    "obsedatele": "obsedat",
    "obsedatelor": "obsedat",
    "obsedați": "obsedat",
    "obsedații": "obsedat",
    "obsedaților": "obsedat",
    "obsedatul": "obsedat",
    "obsedatului": "obsedat",
    "nemaiobservând": "observa",
    "nemaiobservându": "observa",
    "neobservând": "observa",
    "neobservându": "observa",
    "observ": "observa",
    "observă": "observa",
    "observai": "observa",
    "observam": "observa",
    "observăm": "observa",
    "observând": "observa",
    "observându": "observa",
    "observară": "observa",
    "observarăm": "observa",
    "observarăți": "observa",
    "observase": "observa",
    "observasem": "observa",
    "observaseră": "observa",
    "observaserăm": "observa",
    "observaserăți": "observa",
    "observaseși": "observa",
    "observași": "observa",
    "observat": "observa",
    "observați": "observa",
    "observau": "observa",
    "observe": "observa",
    "observi": "observa",
    "observabila": "observabil",
    "observabilă": "observabil",
    "observabile": "observabil",
    "observabilei": "observabil",
    "observabilele": "observabil",
    "observabilelor": "observabil",
    "observabili": "observabil",
    "observabilii": "observabil",
    "observabililor": "observabil",
    "observabilul": "observabil",
    "observabilului": "observabil",
    "observarea": "observare",
    "observări": "observare",
    "observării": "observare",
    "observările": "observare",
    "observărilor": "observare",
    "observată": "observat",
    "observate": "observat",
    "observați": "observat",
    "obs.": "observație",
    "observația": "observație",
    "observației": "observație",
    "observații": "observație",
    "observațiile": "observație",
    "observațiilor": "observație",
    "observatoare": "observator",
    "observatoarea": "observator",
    "observatoarei": "observator",
    "observatoarele": "observator",
    "observatoarelor": "observator",
    "observatori": "observator",
    "observatorii": "observator",
    "observatorilor": "observator",
    "observatorul": "observator",
    "observatorului": "observator",
    "obsesia": "obsesie",
    "obsesiei": "obsesie",
    "obsesii": "obsesie",
    "obsesiile": "obsesie",
    "obsesiilor": "obsesie",
    "obsesiva": "obsesiv",
    "obsesivă": "obsesiv",
    "obsesive": "obsesiv",
    "obsesivei": "obsesiv",
    "obsesivele": "obsesiv",
    "obsesivelor": "obsesiv",
    "obsesivi": "obsesiv",
    "obsesivii": "obsesiv",
    "obsesivilor": "obsesiv",
    "obsesivul": "obsesiv",
    "obsesivului": "obsesiv",
    "obstacole": "obstacol",
    "obstacolele": "obstacol",
    "obstacolelor": "obstacol",
    "obstacolul": "obstacol",
    "obstacolului": "obstacol",
    "obștea": "obște",
    "obști": "obște",
    "obștii": "obște",
    "obștile": "obște",
    "obștilor": "obște",
    "obșteasca": "obștesc",
    "obștească": "obștesc",
    "obștescul": "obștesc",
    "obștescului": "obștesc",
    "obștești": "obștesc",
    "obșteștii": "obștesc",
    "obșteștile": "obștesc",
    "obșteștilor": "obștesc",
    "obstetrica": "obstetric",
    "obstetrică": "obstetric",
    "obstetrice": "obstetric",
    "obstetricei": "obstetric",
    "obstetricele": "obstetric",
    "obstetricelor": "obstetric",
    "obstetrici": "obstetric",
    "obstetricii": "obstetric",
    "obstetricilor": "obstetric",
    "obstetricul": "obstetric",
    "obstetricului": "obstetric",
    "obstetrica": "obstetrică",
    "obstetrice": "obstetrică",
    "obstetricei": "obstetrică",
    "obstetricala": "obstetrical",
    "obstetricală": "obstetrical",
    "obstetricale": "obstetrical",
    "obstetricalei": "obstetrical",
    "obstetricalele": "obstetrical",
    "obstetricalelor": "obstetrical",
    "obstetricali": "obstetrical",
    "obstetricalii": "obstetrical",
    "obstetricalilor": "obstetrical",
    "obstetricalul": "obstetrical",
    "obstetricalului": "obstetrical",
    "nemaiobstinând": "obstina",
    "nemaiobstinându": "obstina",
    "neobstinând": "obstina",
    "neobstinându": "obstina",
    "obstină": "obstina",
    "obstinai": "obstina",
    "obstinam": "obstina",
    "obstinăm": "obstina",
    "obstinând": "obstina",
    "obstinându": "obstina",
    "obstinară": "obstina",
    "obstinarăm": "obstina",
    "obstinarăți": "obstina",
    "obstinase": "obstina",
    "obstinasem": "obstina",
    "obstinaseră": "obstina",
    "obstinaserăm": "obstina",
    "obstinaserăți": "obstina",
    "obstinaseși": "obstina",
    "obstinași": "obstina",
    "obstinat": "obstina",
    "obstinați": "obstina",
    "obstinau": "obstina",
    "obstinează": "obstina",
    "obstinez": "obstina",
    "obstineze": "obstina",
    "obstinezi": "obstina",
    "obstinată": "obstinat",
    "obstinate": "obstinat",
    "obstinați": "obstinat",
    "obstinația": "obstinație",
    "obstinații": "obstinație",
    "obstinațiii": "obstinație",
    "obstinațiile": "obstinație",
    "obstinațiilor": "obstinație",
    "obstrucția": "obstrucție",
    "obstrucției": "obstrucție",
    "obstrucții": "obstrucție",
    "obstrucțiile": "obstrucție",
    "obstrucțiilor": "obstrucție",
    "obstrucționismul": "obstrucționism",
    "obstrucționismului": "obstrucționism",
    "obstrucționista": "obstrucționist",
    "obstrucționistă": "obstrucționist",
    "obstrucționiste": "obstrucționist",
    "obstrucționistei": "obstrucționist",
    "obstrucționistele": "obstrucționist",
    "obstrucționistelor": "obstrucționist",
    "obstrucționiști": "obstrucționist",
    "obstrucționiștii": "obstrucționist",
    "obstrucționiștilor": "obstrucționist",
    "obstrucționistul": "obstrucționist",
    "obstrucționistului": "obstrucționist",
    "obstrucționista": "obstrucționistă",
    "obstrucționiste": "obstrucționistă",
    "obstrucționistei": "obstrucționistă",
    "obstrucționistele": "obstrucționistă",
    "obstrucționistelor": "obstrucționistă",
    "obstructiva": "obstructiv",
    "obstructivă": "obstructiv",
    "obstructive": "obstructiv",
    "obstructivei": "obstructiv",
    "obstructivele": "obstructiv",
    "obstructivelor": "obstructiv",
    "obstructivi": "obstructiv",
    "obstructivii": "obstructiv",
    "obstructivilor": "obstructiv",
    "obstructivul": "obstructiv",
    "obstructivului": "obstructiv",
    "nemaiobținând": "obține",
    "nemaiobținându": "obține",
    "neobținând": "obține",
    "neobținându": "obține",
    "obții": "obține",
    "obțin": "obține",
    "obțină": "obține",
    "obținând": "obține",
    "obținându": "obține",
    "obținea": "obține",
    "obțineai": "obține",
    "obțineam": "obține",
    "obțineați": "obține",
    "obțineau": "obține",
    "obținem": "obține",
    "obțineți": "obține",
    "obținu": "obține",
    "obținui": "obține",
    "obținură": "obține",
    "obținurăm": "obține",
    "obținurăți": "obține",
    "obținuse": "obține",
    "obținusem": "obține",
    "obținuseră": "obține",
    "obținuserăm": "obține",
    "obținuserăți": "obține",
    "obținuseși": "obține",
    "obținuși": "obține",
    "obținut": "obține",
    "obținerea": "obținere",
    "obțineri": "obținere",
    "obținerii": "obținere",
    "obținerile": "obținere",
    "obținerilor": "obținere",
    "obținută": "obținut",
    "obținute": "obținut",
    "obținuți": "obținut",
    "nemaiobturând": "obtura",
    "nemaiobturându": "obtura",
    "neobturând": "obtura",
    "neobturându": "obtura",
    "obtură": "obtura",
    "obturai": "obtura",
    "obturam": "obtura",
    "obturăm": "obtura",
    "obturând": "obtura",
    "obturându": "obtura",
    "obturară": "obtura",
    "obturarăm": "obtura",
    "obturarăți": "obtura",
    "obturase": "obtura",
    "obturasem": "obtura",
    "obturaseră": "obtura",
    "obturaserăm": "obtura",
    "obturaserăți": "obtura",
    "obturaseși": "obtura",
    "obturași": "obtura",
    "obturat": "obtura",
    "obturați": "obtura",
    "obturau": "obtura",
    "obturează": "obtura",
    "obturez": "obtura",
    "obtureze": "obtura",
    "obturezi": "obtura",
    "obturată": "obturat",
    "obturate": "obturat",
    "obturați": "obturat",
    "obturația": "obturație",
    "obturației": "obturație",
    "obturații": "obturație",
    "obturațiile": "obturație",
    "obturațiilor": "obturație",
    "obturatori": "obturator",
    "obturatorii": "obturator",
    "obturatorilor": "obturator",
    "obturatorul": "obturator",
    "obturatorului": "obturator",
    "obtuza": "obtuz",
    "obtuză": "obtuz",
    "obtuze": "obtuz",
    "obtuzei": "obtuz",
    "obtuzele": "obtuz",
    "obtuzelor": "obtuz",
    "obtuzi": "obtuz",
    "obtuzii": "obtuz",
    "obtuzilor": "obtuz",
    "obtuzul": "obtuz",
    "obtuzului": "obtuz",
    "obtuzitatea": "obtuzitate",
    "obtuzități": "obtuzitate",
    "obtuzității": "obtuzitate",
    "obtuzitățile": "obtuzitate",
    "obtuzităților": "obtuzitate",
    "obuze": "obuz",
    "obuzele": "obuz",
    "obuzelor": "obuz",
    "obuzul": "obuz",
    "obuzului": "obuz",
    "obuziere": "obuzier",
    "obuzierele": "obuzier",
    "obuzierelor": "obuzier",
    "obuzierul": "obuzier",
    "obuzierului": "obuzier",
    "ocale": "oca",
    "ocalei": "oca",
    "ocalele": "oca",
    "ocalelor": "oca",
    "ocaua": "oca",
    "ocara": "ocară",
    "ocări": "ocară",
    "ocării": "ocară",
    "ocările": "ocară",
    "ocărilor": "ocară",
    "ocărâtă": "ocărât",
    "ocărâte": "ocărât",
    "ocărâți": "ocărât",
    "ocărâtoare": "ocărâtor",
    "ocărâtoarea": "ocărâtor",
    "ocărâtoarei": "ocărâtor",
    "ocărâtoarele": "ocărâtor",
    "ocărâtoarelor": "ocărâtor",
    "ocărâtori": "ocărâtor",
    "ocărâtorii": "ocărâtor",
    "ocărâtorilor": "ocărâtor",
    "ocărâtorul": "ocărâtor",
    "ocărâtorului": "ocărâtor",
    "nemaiocărând": "ocărî",
    "nemaiocărându": "ocărî",
    "neocărând": "ocărî",
    "neocărându": "ocărî",
    "ocăra": "ocărî",
    "ocărai": "ocărî",
    "ocărâi": "ocărî",
    "ocăram": "ocărî",
    "ocărâm": "ocărî",
    "ocărând": "ocărî",
    "ocărându": "ocărî",
    "ocărâră": "ocărî",
    "ocărârăm": "ocărî",
    "ocărârăți": "ocărî",
    "ocărăsc": "ocărî",
    "ocărască": "ocărî",
    "ocărâse": "ocărî",
    "ocărâsem": "ocărî",
    "ocărâseră": "ocărî",
    "ocărâserăm": "ocărî",
    "ocărâserăți": "ocărî",
    "ocărâseși": "ocărî",
    "ocărâși": "ocărî",
    "ocărăște": "ocărî",
    "ocărăști": "ocărî",
    "ocărât": "ocărî",
    "ocărați": "ocărî",
    "ocărâți": "ocărî",
    "ocărau": "ocărî",
    "ocarina": "ocarină",
    "ocarine": "ocarină",
    "ocarinei": "ocarină",
    "ocarinele": "ocarină",
    "ocarinelor": "ocarină",
    "nemaiocârmuind": "ocârmui",
    "nemaiocârmuindu": "ocârmui",
    "neocârmuind": "ocârmui",
    "neocârmuindu": "ocârmui",
    "ocârmuia": "ocârmui",
    "ocârmuiai": "ocârmui",
    "ocârmuiam": "ocârmui",
    "ocârmuiască": "ocârmui",
    "ocârmuiați": "ocârmui",
    "ocârmuiau": "ocârmui",
    "ocârmuiesc": "ocârmui",
    "ocârmuiește": "ocârmui",
    "ocârmuiești": "ocârmui",
    "ocârmuii": "ocârmui",
    "ocârmuim": "ocârmui",
    "ocârmuind": "ocârmui",
    "ocârmuindu": "ocârmui",
    "ocârmuiră": "ocârmui",
    "ocârmuirăm": "ocârmui",
    "ocârmuirăți": "ocârmui",
    "ocârmuise": "ocârmui",
    "ocârmuisem": "ocârmui",
    "ocârmuiseră": "ocârmui",
    "ocârmuiserăm": "ocârmui",
    "ocârmuiserăți": "ocârmui",
    "ocârmuiseși": "ocârmui",
    "ocârmuiși": "ocârmui",
    "ocârmuit": "ocârmui",
    "ocârmuiți": "ocârmui",
    "ocârmuirea": "ocârmuire",
    "ocârmuiri": "ocârmuire",
    "ocârmuirii": "ocârmuire",
    "ocârmuirile": "ocârmuire",
    "ocârmuirilor": "ocârmuire",
    "ocârmuită": "ocârmuit",
    "ocârmuite": "ocârmuit",
    "ocârmuiți": "ocârmuit",
    "ocârmuitoare": "ocârmuitor",
    "ocârmuitoarea": "ocârmuitor",
    "ocârmuitoarei": "ocârmuitor",
    "ocârmuitoarele": "ocârmuitor",
    "ocârmuitoarelor": "ocârmuitor",
    "ocârmuitori": "ocârmuitor",
    "ocârmuitorii": "ocârmuitor",
    "ocârmuitorilor": "ocârmuitor",
    "ocârmuitorul": "ocârmuitor",
    "ocârmuitorului": "ocârmuitor",
    "ocazia": "ocazie",
    "ocaziei": "ocazie",
    "ocazii": "ocazie",
    "ocaziile": "ocazie",
    "ocaziilor": "ocazie",
    "nemaiocazionând": "ocaziona",
    "nemaiocazionându": "ocaziona",
    "neocazionând": "ocaziona",
    "neocazionându": "ocaziona",
    "ocazionă": "ocaziona",
    "ocazionai": "ocaziona",
    "ocazionam": "ocaziona",
    "ocazionăm": "ocaziona",
    "ocazionând": "ocaziona",
    "ocazionându": "ocaziona",
    "ocazionară": "ocaziona",
    "ocazionarăm": "ocaziona",
    "ocazionarăți": "ocaziona",
    "ocazionase": "ocaziona",
    "ocazionasem": "ocaziona",
    "ocazionaseră": "ocaziona",
    "ocazionaserăm": "ocaziona",
    "ocazionaserăți": "ocaziona",
    "ocazionaseși": "ocaziona",
    "ocazionași": "ocaziona",
    "ocazionat": "ocaziona",
    "ocazionați": "ocaziona",
    "ocazionau": "ocaziona",
    "ocazionează": "ocaziona",
    "ocazionez": "ocaziona",
    "ocazioneze": "ocaziona",
    "ocazionezi": "ocaziona",
    "ocazionala": "ocazional",
    "ocazională": "ocazional",
    "ocazionale": "ocazional",
    "ocazionalei": "ocazional",
    "ocazionalele": "ocazional",
    "ocazionalelor": "ocazional",
    "ocazionali": "ocazional",
    "ocazionalii": "ocazional",
    "ocazionalilor": "ocazional",
    "ocazionalul": "ocazional",
    "ocazionalului": "ocazional",
    "ocazionată": "ocazionat",
    "ocazionate": "ocazionat",
    "ocazionați": "ocazionat",
    "Occ.": "Occident",
    "occidentul": "occident",
    "Occidentului": "Occident",
    "occidentala": "occidental",
    "occidentală": "occidental",
    "occidentale": "occidental",
    "occidentalei": "occidental",
    "occidentalele": "occidental",
    "occidentalelor": "occidental",
    "occidentali": "occidental",
    "occidentalii": "occidental",
    "occidentalilor": "occidental",
    "occidentalul": "occidental",
    "occidentalului": "occidental",
    "occidentala": "occidentală",
    "occidentale": "occidentală",
    "occidentalei": "occidentală",
    "occidentalele": "occidentală",
    "occidentalelor": "occidentală",
    "occipitala": "occipital",
    "occipitală": "occipital",
    "occipitale": "occipital",
    "occipitalei": "occipital",
    "occipitalele": "occipital",
    "occipitalelor": "occipital",
    "occipitali": "occipital",
    "occipitalii": "occipital",
    "occipitalilor": "occipital",
    "occipitalul": "occipital",
    "occipitalului": "occipital",
    "occiputul": "occiput",
    "occiputului": "occiput",
    "occiputuri": "occiput",
    "occiputurile": "occiput",
    "occiputurilor": "occiput",
    "oc.": "ocean",
    "oceane": "ocean",
    "oceanele": "ocean",
    "oceanelor": "ocean",
    "oceanul": "ocean",
    "oceanului": "ocean",
    "Oceanie": "Oceania",
    "Oceaniei": "Oceania",
    "oceanica": "oceanic",
    "oceanică": "oceanic",
    "oceanice": "oceanic",
    "oceanicei": "oceanic",
    "oceanicele": "oceanic",
    "oceanicelor": "oceanic",
    "oceanici": "oceanic",
    "oceanicii": "oceanic",
    "oceanicilor": "oceanic",
    "oceanicul": "oceanic",
    "oceanicului": "oceanic",
    "oceanografi": "oceanograf",
    "oceanografii": "oceanograf",
    "oceanografilor": "oceanograf",
    "oceanograful": "oceanograf",
    "oceanografului": "oceanograf",
    "oceanografica": "oceanografic",
    "oceanografică": "oceanografic",
    "oceanografice": "oceanografic",
    "oceanograficei": "oceanografic",
    "oceanograficele": "oceanografic",
    "oceanograficelor": "oceanografic",
    "oceanografici": "oceanografic",
    "oceanograficii": "oceanografic",
    "oceanograficilor": "oceanografic",
    "oceanograficul": "oceanografic",
    "oceanograficului": "oceanografic",
    "oceanografia": "oceanografie",
    "oceanografiei": "oceanografie",
    "oceanografii": "oceanografie",
    "oceanografiile": "oceanografie",
    "oceanografiilor": "oceanografie",
    "ocheada": "ocheadă",
    "ocheade": "ocheadă",
    "ocheadei": "ocheadă",
    "ocheadele": "ocheadă",
    "ocheadelor": "ocheadă",
    "ocheane": "ochean",
    "ocheanele": "ochean",
    "ocheanelor": "ochean",
    "ocheanul": "ochean",
    "ocheanului": "ochean",
    "ochene": "ocheană",
    "ochenele": "ocheană",
    "ochenelor": "ocheană",
    "ochelarii": "ochelari",
    "ochelarilor": "ochelari",
    "ochelariști": "ochelarist",
    "ochelariștii": "ochelarist",
    "ochelariștilor": "ochelarist",
    "ochelaristul": "ochelarist",
    "ochelaristule": "ochelarist",
    "ochelaristului": "ochelarist",
    "ochelarista": "ochelaristă",
    "ochelariste": "ochelaristă",
    "ochelaristei": "ochelaristă",
    "ochelaristele": "ochelaristă",
    "ochelaristelor": "ochelaristă",
    "ochelaristo": "ochelaristă",
    "nemaiochind": "ochi",
    "nemaiochindu": "ochi",
    "neochind": "ochi",
    "neochindu": "ochi",
    "ochea": "ochi",
    "ocheai": "ochi",
    "ocheam": "ochi",
    "ochească": "ochi",
    "ocheați": "ochi",
    "ocheau": "ochi",
    "ochesc": "ochi",
    "ochește": "ochi",
    "ochești": "ochi",
    "ochii": "ochi",
    "ochilor": "ochi",
    "ochim": "ochi",
    "ochind": "ochi",
    "ochindu": "ochi",
    "ochiră": "ochi",
    "ochirăm": "ochi",
    "ochirăți": "ochi",
    "ochise": "ochi",
    "ochisem": "ochi",
    "ochiseră": "ochi",
    "ochiserăm": "ochi",
    "ochiserăți": "ochi",
    "ochiseși": "ochi",
    "ochiși": "ochi",
    "ochit": "ochi",
    "ochiți": "ochi",
    "ochiul": "ochi",
    "ochiului": "ochi",
    "ochiuri": "ochi",
    "ochiurile": "ochi",
    "ochiurilor": "ochi",
    "ochii-de-pisică": "ochi-de-pisică",
    "ochilor-de-pisică": "ochi-de-pisică",
    "ochiul-de-pisică": "ochi-de-pisică",
    "ochiului-de-pisică": "ochi-de-pisică",
    "ochioasa": "ochios",
    "ochioasă": "ochios",
    "ochioase": "ochios",
    "ochioasei": "ochios",
    "ochioasele": "ochios",
    "ochioaselor": "ochios",
    "ochioși": "ochios",
    "ochioșii": "ochios",
    "ochioșilor": "ochios",
    "ochiosul": "ochios",
    "ochiosului": "ochios",
    "ochirea": "ochire",
    "ochiri": "ochire",
    "ochirii": "ochire",
    "ochirile": "ochire",
    "ochirilor": "ochire",
    "ochită": "ochit",
    "ochite": "ochit",
    "ochiți": "ochit",
    "ochitori": "ochitor",
    "ochitorii": "ochitor",
    "ochitorilor": "ochitor",
    "ochitorul": "ochitor",
    "ochitorului": "ochitor",
    "ocina": "ocină",
    "ocine": "ocină",
    "ocinei": "ocină",
    "ocinele": "ocină",
    "ocinelor": "ocină",
    "oclusiva": "oclusiv",
    "oclusivă": "oclusiv",
    "oclusive": "oclusiv",
    "oclusivei": "oclusiv",
    "oclusivele": "oclusiv",
    "oclusivelor": "oclusiv",
    "oclusivi": "oclusiv",
    "oclusivii": "oclusiv",
    "oclusivilor": "oclusiv",
    "oclusivul": "oclusiv",
    "oclusivului": "oclusiv",
    "ocluziunea": "ocluziune",
    "ocluziuni": "ocluziune",
    "ocluziunii": "ocluziune",
    "ocluziunile": "ocluziune",
    "ocluziunilor": "ocluziune",
    "ocna": "ocnă",
    "ocne": "ocnă",
    "ocnei": "ocnă",
    "ocnele": "ocnă",
    "ocnelor": "ocnă",
    "ocnași": "ocnaș",
    "ocnașii": "ocnaș",
    "ocnașilor": "ocnaș",
    "ocnașul": "ocnaș",
    "ocnașului": "ocnaș",
    "ocneana": "ocnean",
    "ocneană": "ocnean",
    "ocneanul": "ocnean",
    "ocneanului": "ocnean",
    "ocnene": "ocnean",
    "ocnenei": "ocnean",
    "ocnenele": "ocnean",
    "ocnenelor": "ocnean",
    "ocneni": "ocnean",
    "ocnenii": "ocnean",
    "ocnenilor": "ocnean",
    "ocnița": "ocniță",
    "ocnițe": "ocniță",
    "ocniței": "ocniță",
    "ocnițele": "ocniță",
    "ocnițelor": "ocniță",
    "ocoale": "ocol",
    "ocoalele": "ocol",
    "ocoalelor": "ocol",
    "ocolul": "ocol",
    "ocolului": "ocol",
    "ocoluri": "ocol",
    "ocolurile": "ocol",
    "ocolurilor": "ocol",
    "nemaiocolind": "ocoli",
    "nemaiocolindu": "ocoli",
    "neocolind": "ocoli",
    "neocolindu": "ocoli",
    "ocolea": "ocoli",
    "ocoleai": "ocoli",
    "ocoleam": "ocoli",
    "ocolească": "ocoli",
    "ocoleați": "ocoli",
    "ocoleau": "ocoli",
    "ocolesc": "ocoli",
    "ocolește": "ocoli",
    "ocolești": "ocoli",
    "ocolii": "ocoli",
    "ocolim": "ocoli",
    "ocolind": "ocoli",
    "ocolindu": "ocoli",
    "ocoliră": "ocoli",
    "ocolirăm": "ocoli",
    "ocolirăți": "ocoli",
    "ocolise": "ocoli",
    "ocolisem": "ocoli",
    "ocoliseră": "ocoli",
    "ocoliserăm": "ocoli",
    "ocoliserăți": "ocoli",
    "ocoliseși": "ocoli",
    "ocoliși": "ocoli",
    "ocolit": "ocoli",
    "ocoliți": "ocoli",
    "ocolișul": "ocoliș",
    "ocolișului": "ocoliș",
    "ocolișuri": "ocoliș",
    "ocolișurile": "ocoliș",
    "ocolișurilor": "ocoliș",
    "ocolită": "ocolit",
    "ocolite": "ocolit",
    "ocoliți": "ocolit",
    "ocolitoare": "ocolitor",
    "ocolitori": "ocolitor",
    "nemaiocrotind": "ocroti",
    "nemaiocrotindu": "ocroti",
    "neocrotind": "ocroti",
    "neocrotindu": "ocroti",
    "ocrotea": "ocroti",
    "ocroteai": "ocroti",
    "ocroteam": "ocroti",
    "ocrotească": "ocroti",
    "ocroteați": "ocroti",
    "ocroteau": "ocroti",
    "ocrotesc": "ocroti",
    "ocrotește": "ocroti",
    "ocrotești": "ocroti",
    "ocrotii": "ocroti",
    "ocrotim": "ocroti",
    "ocrotind": "ocroti",
    "ocrotindu": "ocroti",
    "ocrotiră": "ocroti",
    "ocrotirăm": "ocroti",
    "ocrotirăți": "ocroti",
    "ocrotise": "ocroti",
    "ocrotisem": "ocroti",
    "ocrotiseră": "ocroti",
    "ocrotiserăm": "ocroti",
    "ocrotiserăți": "ocroti",
    "ocrotiseși": "ocroti",
    "ocrotiși": "ocroti",
    "ocrotit": "ocroti",
    "ocrotiți": "ocroti",
    "ocrotirea": "ocrotire",
    "ocrotiri": "ocrotire",
    "ocrotirii": "ocrotire",
    "ocrotită": "ocrotit",
    "ocrotite": "ocrotit",
    "ocrotiți": "ocrotit",
    "ocrotitoarea": "ocrotitoare",
    "ocrotitoarei": "ocrotitoare",
    "ocrotitoarele": "ocrotitoare",
    "ocrotitoarelor": "ocrotitoare",
    "ocrotitoare": "ocrotitor",
    "ocrotitoarea": "ocrotitor",
    "ocrotitoarei": "ocrotitor",
    "ocrotitoarele": "ocrotitor",
    "ocrotitoarelor": "ocrotitor",
    "ocrotitori": "ocrotitor",
    "ocrotitorii": "ocrotitor",
    "ocrotitorilor": "ocrotitor",
    "ocrotitorul": "ocrotitor",
    "ocrotitorului": "ocrotitor",
    "ocrul": "ocru",
    "ocrului": "ocru",
    "octacorda": "octacord",
    "octacordă": "octacord",
    "octacorde": "octacord",
    "octacordei": "octacord",
    "octacordele": "octacord",
    "octacordelor": "octacord",
    "octacordul": "octacord",
    "octacordului": "octacord",
    "octacorzi": "octacord",
    "octacorzii": "octacord",
    "octacorzilor": "octacord",
    "octaedrica": "octaedric",
    "octaedrică": "octaedric",
    "octaedrice": "octaedric",
    "octaedricei": "octaedric",
    "octaedricele": "octaedric",
    "octaedricelor": "octaedric",
    "octaedrici": "octaedric",
    "octaedricii": "octaedric",
    "octaedricilor": "octaedric",
    "octaedricul": "octaedric",
    "octaedricului": "octaedric",
    "octaedre": "octaedru",
    "octaedrele": "octaedru",
    "octaedrelor": "octaedru",
    "octaedrul": "octaedru",
    "octaedrului": "octaedru",
    "octala": "octal",
    "octală": "octal",
    "octale": "octal",
    "octalei": "octal",
    "octalele": "octal",
    "octalelor": "octal",
    "octali": "octal",
    "octalii": "octal",
    "octalilor": "octal",
    "octalul": "octal",
    "octalului": "octal",
    "octani": "octan",
    "octanii": "octan",
    "octanilor": "octan",
    "octanul": "octan",
    "octanului": "octan",
    "octanica": "octanic",
    "octanică": "octanic",
    "octanice": "octanic",
    "octanicei": "octanic",
    "octanicele": "octanic",
    "octanicelor": "octanic",
    "octanici": "octanic",
    "octanicii": "octanic",
    "octanicilor": "octanic",
    "octanicul": "octanic",
    "octanicului": "octanic",
    "octante": "octant",
    "octantele": "octant",
    "octantelor": "octant",
    "octantul": "octant",
    "octantului": "octant",
    "O.": "Octav",
    "octava": "octavă",
    "octave": "octavă",
    "octavei": "octavă",
    "octavele": "octavă",
    "octavelor": "octavă",
    "O.": "Octavian",
    "octeți": "octet",
    "octeții": "octet",
    "octeților": "octet",
    "octetul": "octet",
    "octetului": "octet",
    "octoda": "octodă",
    "octode": "octodă",
    "octodei": "octodă",
    "octodele": "octodă",
    "octodelor": "octodă",
    "octogenara": "octogenar",
    "octogenară": "octogenar",
    "octogenare": "octogenar",
    "octogenarei": "octogenar",
    "octogenarele": "octogenar",
    "octogenarelor": "octogenar",
    "octogenari": "octogenar",
    "octogenarii": "octogenar",
    "octogenarilor": "octogenar",
    "octogenarul": "octogenar",
    "octogenarului": "octogenar",
    "octogenara": "octogenară",
    "octogenare": "octogenară",
    "octogenarei": "octogenară",
    "octogenarele": "octogenară",
    "octogenarelor": "octogenară",
    "octogoane": "octogon",
    "octogoanele": "octogon",
    "octogoanelor": "octogon",
    "octogoni": "octogon",
    "octogonii": "octogon",
    "octogonilor": "octogon",
    "octogonul": "octogon",
    "octogonului": "octogon",
    "octogonala": "octogonal",
    "octogonală": "octogonal",
    "octogonale": "octogonal",
    "octogonalei": "octogonal",
    "octogonalele": "octogonal",
    "octogonalelor": "octogonal",
    "octogonali": "octogonal",
    "octogonalii": "octogonal",
    "octogonalilor": "octogonal",
    "octogonalul": "octogonal",
    "octogonalului": "octogonal",
    "oct.": "octombrie",
    "octopoda": "octopod",
    "octopodă": "octopod",
    "octopode": "octopod",
    "octopodei": "octopod",
    "octopodele": "octopod",
    "octopodelor": "octopod",
    "octopodul": "octopod",
    "octopodului": "octopod",
    "octopozi": "octopod",
    "octopozii": "octopod",
    "octopozilor": "octopod",
    "octosilabica": "octosilabic",
    "octosilabică": "octosilabic",
    "octosilabice": "octosilabic",
    "octosilabicei": "octosilabic",
    "octosilabicele": "octosilabic",
    "octosilabicelor": "octosilabic",
    "octosilabici": "octosilabic",
    "octosilabicii": "octosilabic",
    "octosilabicilor": "octosilabic",
    "octosilabicul": "octosilabic",
    "octosilabicului": "octosilabic",
    "oculara": "ocular",
    "oculară": "ocular",
    "oculare": "ocular",
    "ocularei": "ocular",
    "ocularele": "ocular",
    "ocularelor": "ocular",
    "oculari": "ocular",
    "ocularii": "ocular",
    "ocularilor": "ocular",
    "ocularul": "ocular",
    "ocularului": "ocular",
    "oculiști": "oculist",
    "oculiștii": "oculist",
    "oculiștilor": "oculist",
    "oculistul": "oculist",
    "oculistului": "oculist",
    "oculistica": "oculistic",
    "oculistică": "oculistic",
    "oculistice": "oculistic",
    "oculisticei": "oculistic",
    "oculisticele": "oculistic",
    "oculisticelor": "oculistic",
    "oculistici": "oculistic",
    "oculisticii": "oculistic",
    "oculisticilor": "oculistic",
    "oculisticul": "oculistic",
    "oculisticului": "oculistic",
    "oculta": "ocult",
    "ocultă": "ocult",
    "oculte": "ocult",
    "ocultei": "ocult",
    "ocultele": "ocult",
    "ocultelor": "ocult",
    "oculți": "ocult",
    "oculții": "ocult",
    "oculților": "ocult",
    "ocultul": "ocult",
    "ocultului": "ocult",
    "ocultisme": "ocultism",
    "ocultismele": "ocultism",
    "ocultismelor": "ocultism",
    "ocultismul": "ocultism",
    "ocultismului": "ocultism",
    "ocultista": "ocultist",
    "ocultistă": "ocultist",
    "ocultiste": "ocultist",
    "ocultistei": "ocultist",
    "ocultistele": "ocultist",
    "ocultistelor": "ocultist",
    "ocultiști": "ocultist",
    "ocultiștii": "ocultist",
    "ocultiștilor": "ocultist",
    "ocultistul": "ocultist",
    "ocultistului": "ocultist",
    "ocultistica": "ocultistic",
    "ocultistică": "ocultistic",
    "ocultistice": "ocultistic",
    "ocultisticei": "ocultistic",
    "ocultisticele": "ocultistic",
    "ocultisticelor": "ocultistic",
    "ocultistici": "ocultistic",
    "ocultisticii": "ocultistic",
    "ocultisticilor": "ocultistic",
    "ocultisticul": "ocultistic",
    "ocultisticului": "ocultistic",
    "nemaiocupând": "ocupa",
    "nemaiocupându": "ocupa",
    "neocupând": "ocupa",
    "neocupându": "ocupa",
    "ocup": "ocupa",
    "ocupă": "ocupa",
    "ocupai": "ocupa",
    "ocupam": "ocupa",
    "ocupăm": "ocupa",
    "ocupând": "ocupa",
    "ocupându": "ocupa",
    "ocupară": "ocupa",
    "ocuparăm": "ocupa",
    "ocuparăți": "ocupa",
    "ocupase": "ocupa",
    "ocupasem": "ocupa",
    "ocupaseră": "ocupa",
    "ocupaserăm": "ocupa",
    "ocupaserăți": "ocupa",
    "ocupaseși": "ocupa",
    "ocupași": "ocupa",
    "ocupat": "ocupa",
    "ocupați": "ocupa",
    "ocupau": "ocupa",
    "ocupe": "ocupa",
    "ocupi": "ocupa",
    "ocupanți": "ocupant",
    "ocupanții": "ocupant",
    "ocupanților": "ocupant",
    "ocupantul": "ocupant",
    "ocupantului": "ocupant",
    "ocupanta": "ocupantă",
    "ocupante": "ocupantă",
    "ocupantei": "ocupantă",
    "ocupantele": "ocupantă",
    "ocupantelor": "ocupantă",
    "ocuparea": "ocupare",
    "ocupări": "ocupare",
    "ocupării": "ocupare",
    "ocupările": "ocupare",
    "ocupărilor": "ocupare",
    "ocupată": "ocupat",
    "ocupate": "ocupat",
    "ocupați": "ocupat",
    "ocupația": "ocupație",
    "ocupației": "ocupație",
    "ocupații": "ocupație",
    "ocupațiile": "ocupație",
    "ocupațiilor": "ocupație",
    "ocurenta": "ocurent",
    "ocurentă": "ocurent",
    "ocurente": "ocurent",
    "ocurentei": "ocurent",
    "ocurentele": "ocurent",
    "ocurentelor": "ocurent",
    "ocurenți": "ocurent",
    "ocurenții": "ocurent",
    "ocurenților": "ocurent",
    "ocurentul": "ocurent",
    "ocurentului": "ocurent",
    "ocurența": "ocurență",
    "ocurențe": "ocurență",
    "ocurenței": "ocurență",
    "ocurențele": "ocurență",
    "ocurențelor": "ocurență",
    "oda": "odă",
    "ode": "odă",
    "odei": "odă",
    "odele": "odă",
    "odelor": "odă",
    "odăi": "odaie",
    "odaia": "odaie",
    "odăii": "odaie",
    "odăile": "odaie",
    "odăilor": "odaie",
    "odăjdiile": "odăjdii",
    "odăjdiilor": "odăjdii",
    "odalisca": "odaliscă",
    "odalisce": "odaliscă",
    "odaliscei": "odaliscă",
    "odaliscele": "odaliscă",
    "odaliscelor": "odaliscă",
    "odgoane": "odgon",
    "odgoanele": "odgon",
    "odgoanelor": "odgon",
    "odgonul": "odgon",
    "odgonului": "odgon",
    "odihna": "odihnă",
    "odihne": "odihnă",
    "odihnei": "odihnă",
    "odihnele": "odihnă",
    "odihnelor": "odihnă",
    "nemaiodihnind": "odihni",
    "nemaiodihnindu": "odihni",
    "neodihnind": "odihni",
    "neodihnindu": "odihni",
    "odihnea": "odihni",
    "odihneai": "odihni",
    "odihneam": "odihni",
    "odihnească": "odihni",
    "odihneați": "odihni",
    "odihneau": "odihni",
    "odihnesc": "odihni",
    "odihnește": "odihni",
    "odihnești": "odihni",
    "odihnii": "odihni",
    "odihnim": "odihni",
    "odihnind": "odihni",
    "odihnindu": "odihni",
    "odihniră": "odihni",
    "odihnirăm": "odihni",
    "odihnirăți": "odihni",
    "odihnise": "odihni",
    "odihnisem": "odihni",
    "odihniseră": "odihni",
    "odihniserăm": "odihni",
    "odihniserăți": "odihni",
    "odihniseși": "odihni",
    "odihniși": "odihni",
    "odihnit": "odihni",
    "odihniți": "odihni",
    "odihnită": "odihnit",
    "odihnite": "odihnit",
    "odihniți": "odihnit",
    "odihnitoare": "odihnitor",
    "odihnitoarea": "odihnitor",
    "odihnitoarei": "odihnitor",
    "odihnitoarele": "odihnitor",
    "odihnitoarelor": "odihnitor",
    "odihnitori": "odihnitor",
    "odihnitorii": "odihnitor",
    "odihnitorilor": "odihnitor",
    "odihnitorul": "odihnitor",
    "odihnitorului": "odihnitor",
    "odioasa": "odios",
    "odioasă": "odios",
    "odioase": "odios",
    "odioasei": "odios",
    "odioasele": "odios",
    "odioaselor": "odios",
    "odioși": "odios",
    "odioșii": "odios",
    "odioșilor": "odios",
    "odiosul": "odios",
    "odiosului": "odios",
    "odiseea": "odisee",
    "odiseei": "odisee",
    "odiseele": "odisee",
    "odiseelor": "odisee",
    "Od.": "Odiseea",
    "odoleanul": "odolean",
    "odoleanului": "odolean",
    "odoleni": "odolean",
    "odolenii": "odolean",
    "odolenilor": "odolean",
    "odontalgica": "odontalgic",
    "odontalgică": "odontalgic",
    "odontalgice": "odontalgic",
    "odontalgicei": "odontalgic",
    "odontalgicele": "odontalgic",
    "odontalgicelor": "odontalgic",
    "odontalgici": "odontalgic",
    "odontalgicii": "odontalgic",
    "odontalgicilor": "odontalgic",
    "odontalgicul": "odontalgic",
    "odontalgicului": "odontalgic",
    "odontologica": "odontologic",
    "odontologică": "odontologic",
    "odontologice": "odontologic",
    "odontologicei": "odontologic",
    "odontologicele": "odontologic",
    "odontologicelor": "odontologic",
    "odontologici": "odontologic",
    "odontologicii": "odontologic",
    "odontologicilor": "odontologic",
    "odontologicul": "odontologic",
    "odontologicului": "odontologic",
    "odoare": "odor",
    "odoarele": "odor",
    "odoarelor": "odor",
    "odorul": "odor",
    "odorului": "odor",
    "odoranta": "odorant",
    "odorantă": "odorant",
    "odorante": "odorant",
    "odorantei": "odorant",
    "odorantele": "odorant",
    "odorantelor": "odorant",
    "odoranți": "odorant",
    "odoranții": "odorant",
    "odoranților": "odorant",
    "odorantul": "odorant",
    "odorantului": "odorant",
    "odorifera": "odorifer",
    "odoriferă": "odorifer",
    "odorifere": "odorifer",
    "odoriferei": "odorifer",
    "odoriferele": "odorifer",
    "odoriferelor": "odorifer",
    "odoriferi": "odorifer",
    "odoriferii": "odorifer",
    "odoriferilor": "odorifer",
    "odoriferul": "odorifer",
    "odoriferului": "odorifer",
    "odoriferanta": "odoriferant",
    "odoriferantă": "odoriferant",
    "odoriferante": "odoriferant",
    "odoriferantei": "odoriferant",
    "odoriferantele": "odoriferant",
    "odoriferantelor": "odoriferant",
    "odoriferanți": "odoriferant",
    "odoriferanții": "odoriferant",
    "odoriferanților": "odoriferant",
    "odoriferantul": "odoriferant",
    "odoriferantului": "odoriferant",
    "odorifica": "odorific",
    "odorifică": "odorific",
    "odorifice": "odorific",
    "odorificei": "odorific",
    "odorificele": "odorific",
    "odorificelor": "odorific",
    "odorifici": "odorific",
    "odorificii": "odorific",
    "odorificilor": "odorific",
    "odorificul": "odorific",
    "odorificului": "odorific",
    "nemaiodorizând": "odoriza",
    "nemaiodorizându": "odoriza",
    "neodorizând": "odoriza",
    "neodorizându": "odoriza",
    "odoriză": "odoriza",
    "odorizai": "odoriza",
    "odorizam": "odoriza",
    "odorizăm": "odoriza",
    "odorizând": "odoriza",
    "odorizându": "odoriza",
    "odorizară": "odoriza",
    "odorizarăm": "odoriza",
    "odorizarăți": "odoriza",
    "odorizase": "odoriza",
    "odorizasem": "odoriza",
    "odorizaseră": "odoriza",
    "odorizaserăm": "odoriza",
    "odorizaserăți": "odoriza",
    "odorizaseși": "odoriza",
    "odorizași": "odoriza",
    "odorizat": "odoriza",
    "odorizați": "odoriza",
    "odorizau": "odoriza",
    "odorizează": "odoriza",
    "odorizez": "odoriza",
    "odorizeze": "odoriza",
    "odorizezi": "odoriza",
    "odorizanți": "odorizant",
    "odorizanții": "odorizant",
    "odorizanților": "odorizant",
    "odorizantul": "odorizant",
    "odorizantului": "odorizant",
    "odorizată": "odorizat",
    "odorizate": "odorizat",
    "odorizați": "odorizat",
    "odrasla": "odraslă",
    "odrasle": "odraslă",
    "odraslei": "odraslă",
    "odraslele": "odraslă",
    "odraslelor": "odraslă",
    "nemaiodrăslind": "odrăsli",
    "nemaiodrăslindu": "odrăsli",
    "neodrăslind": "odrăsli",
    "neodrăslindu": "odrăsli",
    "odrăslea": "odrăsli",
    "odrăsleai": "odrăsli",
    "odrăsleam": "odrăsli",
    "odrăslească": "odrăsli",
    "odrăsleați": "odrăsli",
    "odrăsleau": "odrăsli",
    "odrăslesc": "odrăsli",
    "odrăslește": "odrăsli",
    "odrăslești": "odrăsli",
    "odrăslii": "odrăsli",
    "odrăslim": "odrăsli",
    "odrăslind": "odrăsli",
    "odrăslindu": "odrăsli",
    "odrăsliră": "odrăsli",
    "odrăslirăm": "odrăsli",
    "odrăslirăți": "odrăsli",
    "odrăslise": "odrăsli",
    "odrăslisem": "odrăsli",
    "odrăsliseră": "odrăsli",
    "odrăsliserăm": "odrăsli",
    "odrăsliserăți": "odrăsli",
    "odrăsliseși": "odrăsli",
    "odrăsliși": "odrăsli",
    "odrăslit": "odrăsli",
    "odrăsliți": "odrăsli",
    "odrăslită": "odrăslit",
    "odrăslite": "odrăslit",
    "odrăsliți": "odrăslit",
    "odrăslitoare": "odrăslitor",
    "odrăslitoarea": "odrăslitor",
    "odrăslitoarei": "odrăslitor",
    "odrăslitoarele": "odrăslitor",
    "odrăslitoarelor": "odrăslitor",
    "odrăslitori": "odrăslitor",
    "odrăslitorii": "odrăslitor",
    "odrăslitorilor": "odrăslitor",
    "odrăslitorul": "odrăslitor",
    "odrăslitorului": "odrăslitor",
    "odrăsluiesc": "odrăslui",
    "oful": "of",
    "ofului": "of",
    "ofuri": "of",
    "ofurile": "of",
    "ofurilor": "of",
    "nemaiofensând": "ofensa",
    "nemaiofensându": "ofensa",
    "neofensând": "ofensa",
    "neofensându": "ofensa",
    "ofensă": "ofensa",
    "ofensai": "ofensa",
    "ofensam": "ofensa",
    "ofensăm": "ofensa",
    "ofensând": "ofensa",
    "ofensându": "ofensa",
    "ofensară": "ofensa",
    "ofensarăm": "ofensa",
    "ofensarăți": "ofensa",
    "ofensase": "ofensa",
    "ofensasem": "ofensa",
    "ofensaseră": "ofensa",
    "ofensaserăm": "ofensa",
    "ofensaserăți": "ofensa",
    "ofensaseși": "ofensa",
    "ofensași": "ofensa",
    "ofensat": "ofensa",
    "ofensați": "ofensa",
    "ofensau": "ofensa",
    "ofensează": "ofensa",
    "ofensez": "ofensa",
    "ofenseze": "ofensa",
    "ofensezi": "ofensa",
    "ofensa": "ofensă",
    "ofense": "ofensă",
    "ofensei": "ofensă",
    "ofensele": "ofensă",
    "ofenselor": "ofensă",
    "ofensanta": "ofensant",
    "ofensantă": "ofensant",
    "ofensante": "ofensant",
    "ofensantei": "ofensant",
    "ofensantele": "ofensant",
    "ofensantelor": "ofensant",
    "ofensanți": "ofensant",
    "ofensanții": "ofensant",
    "ofensanților": "ofensant",
    "ofensantul": "ofensant",
    "ofensantului": "ofensant",
    "ofensată": "ofensat",
    "ofensate": "ofensat",
    "ofensați": "ofensat",
    "ofensatoare": "ofensator",
    "ofensatoarea": "ofensator",
    "ofensatoarei": "ofensator",
    "ofensatoarele": "ofensator",
    "ofensatoarelor": "ofensator",
    "ofensatori": "ofensator",
    "ofensatorii": "ofensator",
    "ofensatorilor": "ofensator",
    "ofensatorul": "ofensator",
    "ofensatorului": "ofensator",
    "ofensiva": "ofensiv",
    "ofensivă": "ofensiv",
    "ofensive": "ofensiv",
    "ofensivei": "ofensiv",
    "ofensivele": "ofensiv",
    "ofensivelor": "ofensiv",
    "ofensivi": "ofensiv",
    "ofensivii": "ofensiv",
    "ofensivilor": "ofensiv",
    "ofensivul": "ofensiv",
    "ofensivului": "ofensiv",
    "ofensiva": "ofensivă",
    "ofensive": "ofensivă",
    "ofensivei": "ofensivă",
    "ofensivele": "ofensivă",
    "ofensivelor": "ofensivă",
    "nemaioferind": "oferi",
    "nemaioferindu": "oferi",
    "neoferind": "oferi",
    "neoferindu": "oferi",
    "ofer": "oferi",
    "oferă": "oferi",
    "ofere": "oferi",
    "oferea": "oferi",
    "ofereai": "oferi",
    "ofeream": "oferi",
    "ofereați": "oferi",
    "ofereau": "oferi",
    "oferii": "oferi",
    "oferim": "oferi",
    "oferind": "oferi",
    "oferindu": "oferi",
    "oferiră": "oferi",
    "oferirăm": "oferi",
    "oferirăți": "oferi",
    "oferise": "oferi",
    "oferisem": "oferi",
    "oferiseră": "oferi",
    "oferiserăm": "oferi",
    "oferiserăți": "oferi",
    "oferiseși": "oferi",
    "oferiși": "oferi",
    "oferit": "oferi",
    "oferiți": "oferi",
    "oferită": "oferit",
    "oferite": "oferit",
    "oferiți": "oferit",
    "oferta": "ofertă",
    "oferte": "ofertă",
    "ofertei": "ofertă",
    "ofertele": "ofertă",
    "ofertelor": "ofertă",
    "OPI": "Oferta_Publică_Internațională",
    "ofertanta": "ofertant",
    "ofertantă": "ofertant",
    "ofertante": "ofertant",
    "ofertantei": "ofertant",
    "ofertantele": "ofertant",
    "ofertantelor": "ofertant",
    "ofertanți": "ofertant",
    "ofertanții": "ofertant",
    "ofertanților": "ofertant",
    "ofertantul": "ofertant",
    "ofertantului": "ofertant",
    "ofertanta": "ofertantă",
    "ofertante": "ofertantă",
    "ofertantei": "ofertantă",
    "ofertantele": "ofertantă",
    "ofertantelor": "ofertantă",
    "nemaioficiind": "oficia",
    "nemaioficiindu": "oficia",
    "neoficiind": "oficia",
    "neoficiindu": "oficia",
    "oficiai": "oficia",
    "oficiam": "oficia",
    "oficiară": "oficia",
    "oficiarăm": "oficia",
    "oficiarăți": "oficia",
    "oficiase": "oficia",
    "oficiasem": "oficia",
    "oficiaseră": "oficia",
    "oficiaserăm": "oficia",
    "oficiaserăți": "oficia",
    "oficiaseși": "oficia",
    "oficiași": "oficia",
    "oficiat": "oficia",
    "oficiați": "oficia",
    "oficiau": "oficia",
    "oficiază": "oficia",
    "oficie": "oficia",
    "oficiem": "oficia",
    "oficiez": "oficia",
    "oficieze": "oficia",
    "oficiezi": "oficia",
    "oficiind": "oficia",
    "oficiindu": "oficia",
    "oficiala": "oficial",
    "oficială": "oficial",
    "oficiale": "oficial",
    "oficialei": "oficial",
    "oficialele": "oficial",
    "oficialelor": "oficial",
    "oficiali": "oficial",
    "oficialii": "oficial",
    "oficialilor": "oficial",
    "oficialul": "oficial",
    "oficialului": "oficial",
    "oficialitatea": "oficialitate",
    "oficialități": "oficialitate",
    "oficialității": "oficialitate",
    "oficialitățile": "oficialitate",
    "oficialităților": "oficialitate",
    "nemaioficializând": "oficializa",
    "nemaioficializându": "oficializa",
    "neoficializând": "oficializa",
    "neoficializându": "oficializa",
    "oficializă": "oficializa",
    "oficializai": "oficializa",
    "oficializam": "oficializa",
    "oficializăm": "oficializa",
    "oficializând": "oficializa",
    "oficializându": "oficializa",
    "oficializară": "oficializa",
    "oficializarăm": "oficializa",
    "oficializarăți": "oficializa",
    "oficializase": "oficializa",
    "oficializasem": "oficializa",
    "oficializaseră": "oficializa",
    "oficializaserăm": "oficializa",
    "oficializaserăți": "oficializa",
    "oficializaseși": "oficializa",
    "oficializași": "oficializa",
    "oficializat": "oficializa",
    "oficializați": "oficializa",
    "oficializau": "oficializa",
    "oficializează": "oficializa",
    "oficializez": "oficializa",
    "oficializeze": "oficializa",
    "oficializezi": "oficializa",
    "oficializată": "oficializat",
    "oficializate": "oficializat",
    "oficializați": "oficializat",
    "oficianta": "oficiant",
    "oficiantă": "oficiant",
    "oficiante": "oficiant",
    "oficiantei": "oficiant",
    "oficiantele": "oficiant",
    "oficiantelor": "oficiant",
    "oficianți": "oficiant",
    "oficianții": "oficiant",
    "oficianților": "oficiant",
    "oficiantul": "oficiant",
    "oficiantului": "oficiant",
    "oficiată": "oficiat",
    "oficiate": "oficiat",
    "oficiați": "oficiat",
    "oficina": "oficină",
    "oficine": "oficină",
    "oficinei": "oficină",
    "oficinele": "oficină",
    "oficinelor": "oficină",
    "oficinala": "oficinal",
    "oficinală": "oficinal",
    "oficinale": "oficinal",
    "oficinalei": "oficinal",
    "oficinalele": "oficinal",
    "oficinalelor": "oficinal",
    "oficinali": "oficinal",
    "oficinalii": "oficinal",
    "oficinalilor": "oficinal",
    "oficinalul": "oficinal",
    "oficinalului": "oficinal",
    "oficioasa": "oficios",
    "oficioasă": "oficios",
    "oficioase": "oficios",
    "oficioasei": "oficios",
    "oficioasele": "oficios",
    "oficioaselor": "oficios",
    "oficioși": "oficios",
    "oficioșii": "oficios",
    "oficioșilor": "oficios",
    "oficiosul": "oficios",
    "oficiosului": "oficios",
    "of.": "oficiu",
    "oficii": "oficiu",
    "oficiile": "oficiu",
    "oficiilor": "oficiu",
    "oficiul": "oficiu",
    "oficiului": "oficiu",
    "of.p.": "oficiu_poștal",
    "nemaiofilind": "ofili",
    "nemaiofilindu": "ofili",
    "neofilind": "ofili",
    "neofilindu": "ofili",
    "ofilea": "ofili",
    "ofileai": "ofili",
    "ofileam": "ofili",
    "ofilească": "ofili",
    "ofileați": "ofili",
    "ofileau": "ofili",
    "ofilesc": "ofili",
    "ofilește": "ofili",
    "ofilești": "ofili",
    "ofilii": "ofili",
    "ofilim": "ofili",
    "ofilind": "ofili",
    "ofilindu": "ofili",
    "ofiliră": "ofili",
    "ofilirăm": "ofili",
    "ofilirăți": "ofili",
    "ofilise": "ofili",
    "ofilisem": "ofili",
    "ofiliseră": "ofili",
    "ofiliserăm": "ofili",
    "ofiliserăți": "ofili",
    "ofiliseși": "ofili",
    "ofiliși": "ofili",
    "ofilit": "ofili",
    "ofiliți": "ofili",
    "ofilirea": "ofilire",
    "ofiliri": "ofilire",
    "ofilirii": "ofilire",
    "ofilirile": "ofilire",
    "ofilirilor": "ofilire",
    "ofilita": "ofilit",
    "ofilită": "ofilit",
    "ofilite": "ofilit",
    "ofilitei": "ofilit",
    "ofilitele": "ofilit",
    "ofilitelor": "ofilit",
    "ofiliți": "ofilit",
    "ofiliții": "ofilit",
    "ofiliților": "ofilit",
    "ofilitul": "ofilit",
    "ofilitului": "ofilit",
    "ofițeri": "ofițer",
    "ofițerii": "ofițer",
    "ofițerilor": "ofițer",
    "ofițerul": "ofițer",
    "ofițerului": "ofițer",
    "ofițereasca": "ofițeresc",
    "ofițerească": "ofițeresc",
    "ofițerescul": "ofițeresc",
    "ofițerescului": "ofițeresc",
    "ofițerești": "ofițeresc",
    "ofițereștii": "ofițeresc",
    "ofițereștile": "ofițeresc",
    "ofițereștilor": "ofițeresc",
    "ofițerimea": "ofițerime",
    "ofițerimi": "ofițerime",
    "ofițerimii": "ofițerime",
    "ofițerimile": "ofițerime",
    "ofițerimilor": "ofițerime",
    "ofitica": "ofitic",
    "ofitică": "ofitic",
    "ofitice": "ofitic",
    "ofiticei": "ofitic",
    "ofiticele": "ofitic",
    "ofiticelor": "ofitic",
    "ofitici": "ofitic",
    "ofiticii": "ofitic",
    "ofiticilor": "ofitic",
    "ofiticul": "ofitic",
    "ofiticului": "ofitic",
    "ofranda": "ofrandă",
    "ofrande": "ofrandă",
    "ofrandei": "ofrandă",
    "ofrandele": "ofrandă",
    "ofrandelor": "ofrandă",
    "ofsaidul": "ofsaid",
    "ofsaidului": "ofsaid",
    "ofsaiduri": "ofsaid",
    "ofsaidurile": "ofsaid",
    "ofsaidurilor": "ofsaid",
    "ofsetul": "ofset",
    "ofsetului": "ofset",
    "ofseturi": "ofset",
    "ofseturile": "ofset",
    "ofseturilor": "ofset",
    "nemaioftând": "ofta",
    "nemaioftându": "ofta",
    "neoftând": "ofta",
    "neoftându": "ofta",
    "oftă": "ofta",
    "oftai": "ofta",
    "oftam": "ofta",
    "oftăm": "ofta",
    "oftând": "ofta",
    "oftându": "ofta",
    "oftară": "ofta",
    "oftarăm": "ofta",
    "oftarăți": "ofta",
    "oftase": "ofta",
    "oftasem": "ofta",
    "oftaseră": "ofta",
    "oftaserăm": "ofta",
    "oftaserăți": "ofta",
    "oftaseși": "ofta",
    "oftași": "ofta",
    "oftat": "ofta",
    "oftați": "ofta",
    "oftau": "ofta",
    "oftează": "ofta",
    "oftez": "ofta",
    "ofteze": "ofta",
    "oftezi": "ofta",
    "oftalmica": "oftalmic",
    "oftalmică": "oftalmic",
    "oftalmice": "oftalmic",
    "oftalmicei": "oftalmic",
    "oftalmicele": "oftalmic",
    "oftalmicelor": "oftalmic",
    "oftalmici": "oftalmic",
    "oftalmicii": "oftalmic",
    "oftalmicilor": "oftalmic",
    "oftalmicul": "oftalmic",
    "oftalmicului": "oftalmic",
    "oftalmia": "oftalmie",
    "oftalmiei": "oftalmie",
    "oftalmii": "oftalmie",
    "oftalmiile": "oftalmie",
    "oftalmiilor": "oftalmie",
    "oftalmologi": "oftalmolog",
    "oftalmologii": "oftalmolog",
    "oftalmologilor": "oftalmolog",
    "oftalmologul": "oftalmolog",
    "oftalmologului": "oftalmolog",
    "oftalmologica": "oftalmologic",
    "oftalmologică": "oftalmologic",
    "oftalmologice": "oftalmologic",
    "oftalmologicei": "oftalmologic",
    "oftalmologicele": "oftalmologic",
    "oftalmologicelor": "oftalmologic",
    "oftalmologici": "oftalmologic",
    "oftalmologicii": "oftalmologic",
    "oftalmologicilor": "oftalmologic",
    "oftalmologicul": "oftalmologic",
    "oftalmologicului": "oftalmologic",
    "oftalmologia": "oftalmologie",
    "oftalmologiei": "oftalmologie",
    "oftalmologii": "oftalmologie",
    "oftalmologiile": "oftalmologie",
    "oftalmologiilor": "oftalmologie",
    "oftalmoscopica": "oftalmoscopic",
    "oftalmoscopică": "oftalmoscopic",
    "oftalmoscopice": "oftalmoscopic",
    "oftalmoscopicei": "oftalmoscopic",
    "oftalmoscopicele": "oftalmoscopic",
    "oftalmoscopicelor": "oftalmoscopic",
    "oftalmoscopici": "oftalmoscopic",
    "oftalmoscopicii": "oftalmoscopic",
    "oftalmoscopicilor": "oftalmoscopic",
    "oftalmoscopicul": "oftalmoscopic",
    "oftalmoscopicului": "oftalmoscopic",
    "oftată": "oftat",
    "oftate": "oftat",
    "oftați": "oftat",
    "oftatul": "oftat",
    "oftatului": "oftat",
    "oftaturi": "oftat",
    "oftaturile": "oftat",
    "oftaturilor": "oftat",
    "nemaiofticând": "oftica",
    "nemaiofticându": "oftica",
    "neofticând": "oftica",
    "neofticându": "oftica",
    "oftic": "oftica",
    "oftică": "oftica",
    "ofticai": "oftica",
    "ofticam": "oftica",
    "ofticăm": "oftica",
    "ofticând": "oftica",
    "ofticându": "oftica",
    "ofticară": "oftica",
    "ofticarăm": "oftica",
    "ofticarăți": "oftica",
    "ofticase": "oftica",
    "ofticasem": "oftica",
    "ofticaseră": "oftica",
    "ofticaserăm": "oftica",
    "ofticaserăți": "oftica",
    "ofticaseși": "oftica",
    "ofticași": "oftica",
    "ofticat": "oftica",
    "ofticați": "oftica",
    "ofticau": "oftica",
    "oftice": "oftica",
    "oftici": "oftica",
    "oftica": "oftică",
    "oftici": "oftică",
    "ofticii": "oftică",
    "ofticile": "oftică",
    "ofticilor": "oftică",
    "ofticată": "ofticat",
    "ofticate": "ofticat",
    "ofticați": "ofticat",
    "ofticoasa": "ofticos",
    "ofticoasă": "ofticos",
    "ofticoase": "ofticos",
    "ofticoasei": "ofticos",
    "ofticoasele": "ofticos",
    "ofticoaselor": "ofticos",
    "ofticoși": "ofticos",
    "ofticoșii": "ofticos",
    "ofticoșilor": "ofticos",
    "ofticosul": "ofticos",
    "ofticosului": "ofticos",
    "ogari": "ogar",
    "ogarii": "ogar",
    "ogarilor": "ogar",
    "ogarul": "ogar",
    "ogarului": "ogar",
    "ogăratica": "ogăratic",
    "ogăratică": "ogăratic",
    "ogăratice": "ogăratic",
    "ogăraticei": "ogăratic",
    "ogăraticele": "ogăratic",
    "ogăraticelor": "ogăratic",
    "ogăratici": "ogăratic",
    "ogăraticii": "ogăratic",
    "ogăraticilor": "ogăratic",
    "ogăraticul": "ogăratic",
    "ogăraticului": "ogăratic",
    "ogarnica": "ogarnic",
    "ogarnică": "ogarnic",
    "ogarnice": "ogarnic",
    "ogarnicei": "ogarnic",
    "ogarnicele": "ogarnic",
    "ogarnicelor": "ogarnic",
    "ogarnici": "ogarnic",
    "ogarnicii": "ogarnic",
    "ogarnicilor": "ogarnic",
    "ogarnicul": "ogarnic",
    "ogarnicului": "ogarnic",
    "ogiva": "ogivă",
    "ogive": "ogivă",
    "ogivei": "ogivă",
    "ogivele": "ogivă",
    "ogivelor": "ogivă",
    "ogivala": "ogival",
    "ogivală": "ogival",
    "ogivale": "ogival",
    "ogivalei": "ogival",
    "ogivalele": "ogival",
    "ogivalelor": "ogival",
    "ogivali": "ogival",
    "ogivalii": "ogival",
    "ogivalilor": "ogival",
    "ogivalul": "ogival",
    "ogivalului": "ogival",
    "oglinda": "oglindă",
    "oglinzi": "oglindă",
    "oglinzii": "oglindă",
    "oglinzile": "oglindă",
    "oglinzilor": "oglindă",
    "nemaioglindind": "oglindi",
    "nemaioglindindu": "oglindi",
    "neoglindind": "oglindi",
    "neoglindindu": "oglindi",
    "oglindea": "oglindi",
    "oglindeai": "oglindi",
    "oglindeam": "oglindi",
    "oglindească": "oglindi",
    "oglindeați": "oglindi",
    "oglindeau": "oglindi",
    "oglindesc": "oglindi",
    "oglindește": "oglindi",
    "oglindești": "oglindi",
    "oglindii": "oglindi",
    "oglindim": "oglindi",
    "oglindind": "oglindi",
    "oglindindu": "oglindi",
    "oglindiră": "oglindi",
    "oglindirăm": "oglindi",
    "oglindirăți": "oglindi",
    "oglindise": "oglindi",
    "oglindisem": "oglindi",
    "oglindiseră": "oglindi",
    "oglindiserăm": "oglindi",
    "oglindiserăți": "oglindi",
    "oglindiseși": "oglindi",
    "oglindiși": "oglindi",
    "oglindit": "oglindi",
    "oglindiți": "oglindi",
    "oglindirea": "oglindire",
    "oglindiri": "oglindire",
    "oglindirii": "oglindire",
    "oglindirile": "oglindire",
    "oglindirilor": "oglindire",
    "oglindită": "oglindit",
    "oglindite": "oglindit",
    "oglindiți": "oglindit",
    "oglinditoare": "oglinditor",
    "oglinditoarea": "oglinditor",
    "oglinditoarei": "oglinditor",
    "oglinditoarele": "oglinditor",
    "oglinditoarelor": "oglinditor",
    "oglinditori": "oglinditor",
    "oglinditorii": "oglinditor",
    "oglinditorilor": "oglinditor",
    "oglinditorul": "oglinditor",
    "oglinditorului": "oglinditor",
    "oglindoasa": "oglindos",
    "oglindoasă": "oglindos",
    "oglindoase": "oglindos",
    "oglindoasei": "oglindos",
    "oglindoasele": "oglindos",
    "oglindoaselor": "oglindos",
    "oglindoși": "oglindos",
    "oglindoșii": "oglindos",
    "oglindoșilor": "oglindos",
    "oglindosul": "oglindos",
    "oglindosului": "oglindos",
    "nemaiogoind": "ogoi",
    "nemaiogoindu": "ogoi",
    "neogoind": "ogoi",
    "neogoindu": "ogoi",
    "ogoia": "ogoi",
    "ogoiai": "ogoi",
    "ogoiam": "ogoi",
    "ogoiască": "ogoi",
    "ogoiați": "ogoi",
    "ogoiau": "ogoi",
    "ogoiesc": "ogoi",
    "ogoiește": "ogoi",
    "ogoiești": "ogoi",
    "ogoii": "ogoi",
    "ogoim": "ogoi",
    "ogoind": "ogoi",
    "ogoindu": "ogoi",
    "ogoiră": "ogoi",
    "ogoirăm": "ogoi",
    "ogoirăți": "ogoi",
    "ogoise": "ogoi",
    "ogoisem": "ogoi",
    "ogoiseră": "ogoi",
    "ogoiserăm": "ogoi",
    "ogoiserăți": "ogoi",
    "ogoiseși": "ogoi",
    "ogoiși": "ogoi",
    "ogoit": "ogoi",
    "ogoiți": "ogoi",
    "ogoită": "ogoit",
    "ogoite": "ogoit",
    "ogoiți": "ogoit",
    "ogoare": "ogor",
    "ogoarele": "ogor",
    "ogoarelor": "ogor",
    "ogorul": "ogor",
    "ogorului": "ogor",
    "ogorâtă": "ogorât",
    "ogorâte": "ogorât",
    "ogorâți": "ogorât",
    "nemaiogorând": "ogorî",
    "nemaiogorându": "ogorî",
    "neogorând": "ogorî",
    "neogorându": "ogorî",
    "ogora": "ogorî",
    "ogorai": "ogorî",
    "ogorâi": "ogorî",
    "ogoram": "ogorî",
    "ogorâm": "ogorî",
    "ogorând": "ogorî",
    "ogorându": "ogorî",
    "ogorâră": "ogorî",
    "ogorârăm": "ogorî",
    "ogorârăți": "ogorî",
    "ogorăsc": "ogorî",
    "ogorască": "ogorî",
    "ogorâse": "ogorî",
    "ogorâsem": "ogorî",
    "ogorâseră": "ogorî",
    "ogorâserăm": "ogorî",
    "ogorâserăți": "ogorî",
    "ogorâseși": "ogorî",
    "ogorâși": "ogorî",
    "ogorăște": "ogorî",
    "ogorăști": "ogorî",
    "ogorât": "ogorî",
    "ogorați": "ogorî",
    "ogorâți": "ogorî",
    "ogorau": "ogorî",
    "ograda": "ogradă",
    "ogrăzi": "ogradă",
    "ogrăzii": "ogradă",
    "ogrăzile": "ogradă",
    "ogrăzilor": "ogradă",
    "ohmi": "ohm",
    "ohmii": "ohm",
    "ohmilor": "ohm",
    "ohmul": "ohm",
    "ohmului": "ohm",
    "ohmica": "ohmic",
    "ohmică": "ohmic",
    "ohmice": "ohmic",
    "ohmicei": "ohmic",
    "ohmicele": "ohmic",
    "ohmicelor": "ohmic",
    "ohmici": "ohmic",
    "ohmicii": "ohmic",
    "ohmicilor": "ohmic",
    "ohmicul": "ohmic",
    "ohmicului": "ohmic",
    "oieri": "oier",
    "oierii": "oier",
    "oierilor": "oier",
    "oierul": "oier",
    "oierului": "oier",
    "oieritul": "oierit",
    "oieritului": "oierit",
    "oikeiopragia": "oikeiopragie",
    "oina": "oină",
    "oine": "oină",
    "oinei": "oină",
    "oiștea": "oiște",
    "oiști": "oiște",
    "oiștii": "oiște",
    "oiștile": "oiște",
    "oiștilor": "oiște",
    "olul": "ol",
    "olului": "ol",
    "oluri": "ol",
    "olurile": "ol",
    "olurilor": "ol",
    "olane": "olan",
    "olanele": "olan",
    "olanelor": "olan",
    "olani": "olan",
    "olanii": "olan",
    "olanilor": "olan",
    "olanul": "olan",
    "olanului": "olan",
    "NL": "Olanda",
    "Olandei": "Olanda",
    "olanda": "olandă",
    "olande": "olandă",
    "olandei": "olandă",
    "olandeza": "olandez",
    "olandeză": "olandez",
    "olandeze": "olandez",
    "olandezei": "olandez",
    "olandezele": "olandez",
    "olandezelor": "olandez",
    "olandezi": "olandez",
    "olandezii": "olandez",
    "olandezilor": "olandez",
    "olandezul": "olandez",
    "olandezului": "olandez",
    "olandeza": "olandeză",
    "olandeze": "olandeză",
    "olandezei": "olandeză",
    "olandezele": "olandeză",
    "olandezelor": "olandeză",
    "olandina": "olandină",
    "olandine": "olandină",
    "olandinei": "olandină",
    "olari": "olar",
    "olarii": "olar",
    "olarilor": "olar",
    "olarul": "olar",
    "olarului": "olar",
    "olărea": "olări",
    "olăreai": "olări",
    "olăream": "olări",
    "olărească": "olări",
    "olăreați": "olări",
    "olăreau": "olări",
    "olăresc": "olări",
    "olărește": "olări",
    "olărești": "olări",
    "olării": "olări",
    "olărim": "olări",
    "olărind": "olări",
    "olărindu": "olări",
    "olăriră": "olări",
    "olărirăm": "olări",
    "olărirăți": "olări",
    "olărise": "olări",
    "olărisem": "olări",
    "olăriseră": "olări",
    "olăriserăm": "olări",
    "olăriserăți": "olări",
    "olăriseși": "olări",
    "olăriși": "olări",
    "olărit": "olări",
    "olăriți": "olări",
    "olăritu": "olări",
    "olărirea": "olărire",
    "olăriri": "olărire",
    "olăririi": "olărire",
    "olăririle": "olărire",
    "olăririlor": "olărire",
    "olărită": "olărit",
    "olărite": "olărit",
    "olăriți": "olărit",
    "olăritul": "olărit",
    "olăritului": "olărit",
    "oleaginoasa": "oleaginos",
    "oleaginoasă": "oleaginos",
    "oleaginoase": "oleaginos",
    "oleaginoasei": "oleaginos",
    "oleaginoasele": "oleaginos",
    "oleaginoaselor": "oleaginos",
    "oleaginoși": "oleaginos",
    "oleaginoșii": "oleaginos",
    "oleaginoșilor": "oleaginos",
    "oleaginosul": "oleaginos",
    "oleaginosului": "oleaginos",
    "oleica": "oleic",
    "oleică": "oleic",
    "oleice": "oleic",
    "oleicei": "oleic",
    "oleicele": "oleic",
    "oleicelor": "oleic",
    "oleici": "oleic",
    "oleicii": "oleic",
    "oleicilor": "oleic",
    "oleicul": "oleic",
    "oleicului": "oleic",
    "oleifera": "oleifer",
    "oleiferă": "oleifer",
    "oleifere": "oleifer",
    "oleiferei": "oleifer",
    "oleiferele": "oleifer",
    "oleiferelor": "oleifer",
    "oleiferi": "oleifer",
    "oleiferii": "oleifer",
    "oleiferilor": "oleifer",
    "oleiferul": "oleifer",
    "oleiferului": "oleifer",
    "olfactiva": "olfactiv",
    "olfactivă": "olfactiv",
    "olfactive": "olfactiv",
    "olfactivei": "olfactiv",
    "olfactivele": "olfactiv",
    "olfactivelor": "olfactiv",
    "olfactivi": "olfactiv",
    "olfactivii": "olfactiv",
    "olfactivilor": "olfactiv",
    "olfactivul": "olfactiv",
    "olfactivului": "olfactiv",
    "Olgăi": "Olga",
    "oliganta": "oligant",
    "oligantă": "oligant",
    "oligante": "oligant",
    "oligantei": "oligant",
    "oligantele": "oligant",
    "oligantelor": "oligant",
    "oliganți": "oligant",
    "oliganții": "oligant",
    "oliganților": "oligant",
    "oligantul": "oligant",
    "oligantului": "oligant",
    "oligarhi": "oligarh",
    "oligarhii": "oligarh",
    "oligarhilor": "oligarh",
    "oligarhul": "oligarh",
    "oligarhului": "oligarh",
    "oligarhica": "oligarhic",
    "oligarhică": "oligarhic",
    "oligarhice": "oligarhic",
    "oligarhicei": "oligarhic",
    "oligarhicele": "oligarhic",
    "oligarhicelor": "oligarhic",
    "oligarhici": "oligarhic",
    "oligarhicii": "oligarhic",
    "oligarhicilor": "oligarhic",
    "oligarhicul": "oligarhic",
    "oligarhicului": "oligarhic",
    "oligarhia": "oligarhie",
    "oligarhiei": "oligarhie",
    "oligarhii": "oligarhie",
    "oligarhiile": "oligarhie",
    "oligarhiilor": "oligarhie",
    "oligocena": "oligocen",
    "oligocenă": "oligocen",
    "oligocene": "oligocen",
    "oligocenei": "oligocen",
    "oligocenele": "oligocen",
    "oligocenelor": "oligocen",
    "oligoceni": "oligocen",
    "oligocenii": "oligocen",
    "oligocenilor": "oligocen",
    "oligocenul": "oligocen",
    "oligocenului": "oligocen",
    "Olimpul": "Olimp",
    "Olimpului": "Olimp",
    "Olimpiei": "Olimpia",
    "olimpiada": "olimpiadă",
    "olimpiade": "olimpiadă",
    "olimpiadei": "olimpiadă",
    "olimpiadele": "olimpiadă",
    "olimpiadelor": "olimpiadă",
    "olimpiana": "olimpian",
    "olimpiană": "olimpian",
    "olimpianul": "olimpian",
    "olimpianului": "olimpian",
    "olimpiene": "olimpian",
    "olimpienei": "olimpian",
    "olimpienele": "olimpian",
    "olimpienelor": "olimpian",
    "olimpieni": "olimpian",
    "olimpienii": "olimpian",
    "olimpienilor": "olimpian",
    "olimpica": "olimpic",
    "olimpică": "olimpic",
    "olimpice": "olimpic",
    "olimpicei": "olimpic",
    "olimpicele": "olimpic",
    "olimpicelor": "olimpic",
    "olimpici": "olimpic",
    "olimpicii": "olimpic",
    "olimpicilor": "olimpic",
    "olimpicul": "olimpic",
    "olimpicului": "olimpic",
    "Oliviei": "Olivia",
    "oloaga": "oloagă",
    "oloage": "oloagă",
    "oloagei": "oloagă",
    "oloagele": "oloagă",
    "oloagelor": "oloagă",
    "oloaga": "olog",
    "oloagă": "olog",
    "oloage": "olog",
    "oloagei": "olog",
    "oloagele": "olog",
    "oloagelor": "olog",
    "ologi": "olog",
    "ologii": "olog",
    "ologilor": "olog",
    "ologul": "olog",
    "ologului": "olog",
    "ologeala": "ologeală",
    "ologeli": "ologeală",
    "ologelii": "ologeală",
    "ologelile": "ologeală",
    "ologelilor": "ologeală",
    "nemaiologind": "ologi",
    "nemaiologindu": "ologi",
    "neologind": "ologi",
    "neologindu": "ologi",
    "ologea": "ologi",
    "ologeai": "ologi",
    "ologeam": "ologi",
    "ologească": "ologi",
    "ologeați": "ologi",
    "ologeau": "ologi",
    "ologesc": "ologi",
    "ologește": "ologi",
    "ologești": "ologi",
    "ologii": "ologi",
    "ologim": "ologi",
    "ologind": "ologi",
    "ologindu": "ologi",
    "ologiră": "ologi",
    "ologirăm": "ologi",
    "ologirăți": "ologi",
    "ologise": "ologi",
    "ologisem": "ologi",
    "ologiseră": "ologi",
    "ologiserăm": "ologi",
    "ologiserăți": "ologi",
    "ologiseși": "ologi",
    "ologiși": "ologi",
    "ologit": "ologi",
    "ologiți": "ologi",
    "ologită": "ologit",
    "ologite": "ologit",
    "ologiți": "ologit",
    "olografa": "olograf",
    "olografă": "olograf",
    "olografe": "olograf",
    "olografei": "olograf",
    "olografele": "olograf",
    "olografelor": "olograf",
    "olografi": "olograf",
    "olografii": "olograf",
    "olografilor": "olograf",
    "olograful": "olograf",
    "olografului": "olograf",
    "oloioasa": "oloios",
    "oloioasă": "oloios",
    "oloioase": "oloios",
    "oloioasei": "oloios",
    "oloioasele": "oloios",
    "oloioaselor": "oloios",
    "oloioși": "oloios",
    "oloioșii": "oloios",
    "oloioșilor": "oloios",
    "oloiosul": "oloios",
    "oloiosului": "oloios",
    "olonoma": "olonom",
    "olonomă": "olonom",
    "olonome": "olonom",
    "olonomei": "olonom",
    "olonomele": "olonom",
    "olonomelor": "olonom",
    "olonomi": "olonom",
    "olonomii": "olonom",
    "olonomilor": "olonom",
    "olonomul": "olonom",
    "olonomului": "olonom",
    "olteana": "oltean",
    "olteană": "oltean",
    "olteanul": "oltean",
    "olteanului": "oltean",
    "oltene": "oltean",
    "oltenei": "oltean",
    "oltenele": "oltean",
    "oltenelor": "oltean",
    "olteni": "oltean",
    "oltenii": "oltean",
    "oltenilor": "oltean",
    "olteanca": "olteancă",
    "oltence": "olteancă",
    "oltencei": "olteancă",
    "oltencele": "olteancă",
    "oltencelor": "olteancă",
    "olteneasca": "oltenesc",
    "oltenească": "oltenesc",
    "oltenescul": "oltenesc",
    "oltenescului": "oltenesc",
    "oltenești": "oltenesc",
    "olteneștii": "oltenesc",
    "olteneștile": "oltenesc",
    "olteneștilor": "oltenesc",
    "Olteniei": "Oltenia",
    "oameni": "om",
    "oamenii": "om",
    "oamenilor": "om",
    "omi": "om",
    "omii": "om",
    "omul": "om",
    "omule": "om",
    "omului": "om",
    "nemaiomagiind": "omagia",
    "nemaiomagiindu": "omagia",
    "neomagiind": "omagia",
    "neomagiindu": "omagia",
    "omagiai": "omagia",
    "omagiam": "omagia",
    "omagiară": "omagia",
    "omagiarăm": "omagia",
    "omagiarăți": "omagia",
    "omagiase": "omagia",
    "omagiasem": "omagia",
    "omagiaseră": "omagia",
    "omagiaserăm": "omagia",
    "omagiaserăți": "omagia",
    "omagiaseși": "omagia",
    "omagiași": "omagia",
    "omagiat": "omagia",
    "omagiați": "omagia",
    "omagiau": "omagia",
    "omagiază": "omagia",
    "omagie": "omagia",
    "omagiem": "omagia",
    "omagiez": "omagia",
    "omagieze": "omagia",
    "omagiezi": "omagia",
    "omagiind": "omagia",
    "omagiindu": "omagia",
    "omagiala": "omagial",
    "omagială": "omagial",
    "omagiale": "omagial",
    "omagialei": "omagial",
    "omagialele": "omagial",
    "omagialelor": "omagial",
    "omagiali": "omagial",
    "omagialii": "omagial",
    "omagialilor": "omagial",
    "omagialul": "omagial",
    "omagialului": "omagial",
    "omagiată": "omagiat",
    "omagiate": "omagiat",
    "omagiați": "omagiat",
    "omagii": "omagiu",
    "omagiile": "omagiu",
    "omagiilor": "omagiu",
    "omagiul": "omagiu",
    "omagiului": "omagiu",
    "omătul": "omăt",
    "omătului": "omăt",
    "omături": "omăt",
    "omăturile": "omăt",
    "omăturilor": "omăt",
    "ombilicul": "ombilic",
    "ombilicului": "ombilic",
    "ombilicuri": "ombilic",
    "ombilicurile": "ombilic",
    "ombilicurilor": "ombilic",
    "ombilicala": "ombilical",
    "ombilicală": "ombilical",
    "ombilicale": "ombilical",
    "ombilicalei": "ombilical",
    "ombilicalele": "ombilical",
    "ombilicalelor": "ombilical",
    "ombilicali": "ombilical",
    "ombilicalii": "ombilical",
    "ombilicalilor": "ombilical",
    "ombilicalul": "ombilical",
    "ombilicalului": "ombilical",
    "omeneasca": "omenesc",
    "omenească": "omenesc",
    "omenescul": "omenesc",
    "omenescului": "omenesc",
    "omenești": "omenesc",
    "omeneștii": "omenesc",
    "omeneștile": "omenesc",
    "omeneștilor": "omenesc",
    "nemaiomenind": "omeni",
    "nemaiomenindu": "omeni",
    "neomenind": "omeni",
    "neomenindu": "omeni",
    "omenea": "omeni",
    "omeneai": "omeni",
    "omeneam": "omeni",
    "omenească": "omeni",
    "omeneați": "omeni",
    "omeneau": "omeni",
    "omenesc": "omeni",
    "omenește": "omeni",
    "omenești": "omeni",
    "omenii": "omeni",
    "omenim": "omeni",
    "omenind": "omeni",
    "omenindu": "omeni",
    "omeniră": "omeni",
    "omenirăm": "omeni",
    "omenirăți": "omeni",
    "omenise": "omeni",
    "omenisem": "omeni",
    "omeniseră": "omeni",
    "omeniserăm": "omeni",
    "omeniserăți": "omeni",
    "omeniseși": "omeni",
    "omeniși": "omeni",
    "omenit": "omeni",
    "omeniți": "omeni",
    "omenia": "omenie",
    "omeniei": "omenie",
    "omenii": "omenie",
    "omenirea": "omenire",
    "omeniri": "omenire",
    "omenirii": "omenire",
    "omenită": "omenit",
    "omenite": "omenit",
    "omeniți": "omenit",
    "omenoasa": "omenos",
    "omenoasă": "omenos",
    "omenoase": "omenos",
    "omenoasei": "omenos",
    "omenoasele": "omenos",
    "omenoaselor": "omenos",
    "omenoși": "omenos",
    "omenoșii": "omenos",
    "omenoșilor": "omenos",
    "omenosul": "omenos",
    "omenosului": "omenos",
    "omida": "omidă",
    "omizi": "omidă",
    "omizii": "omidă",
    "omizile": "omidă",
    "omizilor": "omidă",
    "omisa": "omis",
    "omisă": "omis",
    "omise": "omis",
    "omisei": "omis",
    "omisele": "omis",
    "omiselor": "omis",
    "omiși": "omis",
    "omișii": "omis",
    "omișilor": "omis",
    "omisul": "omis",
    "omisului": "omis",
    "omisiunea": "omisiune",
    "omisiuni": "omisiune",
    "omisiunii": "omisiune",
    "omisiunile": "omisiune",
    "omisiunilor": "omisiune",
    "omisiva": "omisiv",
    "omisivă": "omisiv",
    "omisive": "omisiv",
    "omisivei": "omisiv",
    "omisivele": "omisiv",
    "omisivelor": "omisiv",
    "omisivi": "omisiv",
    "omisivii": "omisiv",
    "omisivilor": "omisiv",
    "omisivul": "omisiv",
    "omisivului": "omisiv",
    "nemaiomițând": "omite",
    "nemaiomițându": "omite",
    "neomițând": "omite",
    "neomițându": "omite",
    "omis": "omite",
    "omise": "omite",
    "omisei": "omite",
    "omiseră": "omite",
    "omiserăm": "omite",
    "omiserăți": "omite",
    "omisese": "omite",
    "omisesem": "omite",
    "omiseseră": "omite",
    "omiseserăm": "omite",
    "omiseserăți": "omite",
    "omiseseși": "omite",
    "omiseși": "omite",
    "omit": "omite",
    "omită": "omite",
    "omițând": "omite",
    "omițându": "omite",
    "omitea": "omite",
    "omiteai": "omite",
    "omiteam": "omite",
    "omiteați": "omite",
    "omiteau": "omite",
    "omitem": "omite",
    "omiteți": "omite",
    "omiți": "omite",
    "omleta": "omletă",
    "omlete": "omletă",
    "omletei": "omletă",
    "omletele": "omletă",
    "omletelor": "omletă",
    "omnibuze": "omnibuz",
    "omnibuzele": "omnibuz",
    "omnibuzelor": "omnibuz",
    "omnibuzul": "omnibuz",
    "omnibuzului": "omnibuz",
    "omnipotenta": "omnipotent",
    "omnipotentă": "omnipotent",
    "omnipotente": "omnipotent",
    "omnipotentei": "omnipotent",
    "omnipotentele": "omnipotent",
    "omnipotentelor": "omnipotent",
    "omnipotenți": "omnipotent",
    "omnipotenții": "omnipotent",
    "omnipotenților": "omnipotent",
    "omnipotentul": "omnipotent",
    "omnipotentului": "omnipotent",
    "omniprezenta": "omniprezent",
    "omniprezentă": "omniprezent",
    "omniprezente": "omniprezent",
    "omniprezentei": "omniprezent",
    "omniprezentele": "omniprezent",
    "omniprezentelor": "omniprezent",
    "omniprezenți": "omniprezent",
    "omniprezenții": "omniprezent",
    "omniprezenților": "omniprezent",
    "omniprezentul": "omniprezent",
    "omniprezentului": "omniprezent",
    "omniprezența": "omniprezență",
    "omniprezențe": "omniprezență",
    "omniprezenței": "omniprezență",
    "omniprezențele": "omniprezență",
    "omniprezențelor": "omniprezență",
    "omniscienta": "omniscient",
    "omniscientă": "omniscient",
    "omnisciente": "omniscient",
    "omniscientei": "omniscient",
    "omniscientele": "omniscient",
    "omniscientelor": "omniscient",
    "omniscienți": "omniscient",
    "omniscienții": "omniscient",
    "omniscienților": "omniscient",
    "omniscientul": "omniscient",
    "omniscientului": "omniscient",
    "omnivora": "omnivor",
    "omnivoră": "omnivor",
    "omnivore": "omnivor",
    "omnivorei": "omnivor",
    "omnivorele": "omnivor",
    "omnivorelor": "omnivor",
    "omnivori": "omnivor",
    "omnivorii": "omnivor",
    "omnivorilor": "omnivor",
    "omnivorul": "omnivor",
    "omnivorului": "omnivor",
    "omnivora": "omnivoră",
    "omnivore": "omnivoră",
    "omnivorei": "omnivoră",
    "omnivorele": "omnivoră",
    "omnivorelor": "omnivoră",
    "omofaga": "omofag",
    "omofagă": "omofag",
    "omofage": "omofag",
    "omofagei": "omofag",
    "omofagele": "omofag",
    "omofagelor": "omofag",
    "omofagi": "omofag",
    "omofagii": "omofag",
    "omofagilor": "omofag",
    "omofagul": "omofag",
    "omofagului": "omofag",
    "omofona": "omofon",
    "omofonă": "omofon",
    "omofone": "omofon",
    "omofonei": "omofon",
    "omofonele": "omofon",
    "omofonelor": "omofon",
    "omofoni": "omofon",
    "omofonii": "omofon",
    "omofonilor": "omofon",
    "omofonul": "omofon",
    "omofonului": "omofon",
    "omofonica": "omofonic",
    "omofonică": "omofonic",
    "omofonice": "omofonic",
    "omofonicei": "omofonic",
    "omofonicele": "omofonic",
    "omofonicelor": "omofonic",
    "omofonici": "omofonic",
    "omofonicii": "omofonic",
    "omofonicilor": "omofonic",
    "omofonicul": "omofonic",
    "omofonicului": "omofonic",
    "omoforma": "omoform",
    "omoformă": "omoform",
    "omoforme": "omoform",
    "omoformei": "omoform",
    "omoformele": "omoform",
    "omoformelor": "omoform",
    "omoformi": "omoform",
    "omoformii": "omoform",
    "omoformilor": "omoform",
    "omoformul": "omoform",
    "omoformului": "omoform",
    "omogena": "omogen",
    "omogenă": "omogen",
    "omogene": "omogen",
    "omogenei": "omogen",
    "omogenele": "omogen",
    "omogenelor": "omogen",
    "omogeni": "omogen",
    "omogenii": "omogen",
    "omogenilor": "omogen",
    "omogenul": "omogen",
    "omogenului": "omogen",
    "omogenitatea": "omogenitate",
    "omogenități": "omogenitate",
    "omogenității": "omogenitate",
    "omogenitățile": "omogenitate",
    "omogenităților": "omogenitate",
    "nemaiomogenizând": "omogeniza",
    "nemaiomogenizându": "omogeniza",
    "neomogenizând": "omogeniza",
    "neomogenizându": "omogeniza",
    "omogeniză": "omogeniza",
    "omogenizai": "omogeniza",
    "omogenizam": "omogeniza",
    "omogenizăm": "omogeniza",
    "omogenizând": "omogeniza",
    "omogenizându": "omogeniza",
    "omogenizară": "omogeniza",
    "omogenizarăm": "omogeniza",
    "omogenizarăți": "omogeniza",
    "omogenizase": "omogeniza",
    "omogenizasem": "omogeniza",
    "omogenizaseră": "omogeniza",
    "omogenizaserăm": "omogeniza",
    "omogenizaserăți": "omogeniza",
    "omogenizaseși": "omogeniza",
    "omogenizași": "omogeniza",
    "omogenizat": "omogeniza",
    "omogenizați": "omogeniza",
    "omogenizau": "omogeniza",
    "omogenizează": "omogeniza",
    "omogenizez": "omogeniza",
    "omogenizeze": "omogeniza",
    "omogenizezi": "omogeniza",
    "omogenizată": "omogenizat",
    "omogenizate": "omogenizat",
    "omogenizați": "omogenizat",
    "omografa": "omograf",
    "omografă": "omograf",
    "omografe": "omograf",
    "omografei": "omograf",
    "omografele": "omograf",
    "omografelor": "omograf",
    "omografi": "omograf",
    "omografii": "omograf",
    "omografilor": "omograf",
    "omograful": "omograf",
    "omografului": "omograf",
    "omoloaga": "omolog",
    "omoloagă": "omolog",
    "omoloage": "omolog",
    "omoloagei": "omolog",
    "omoloagele": "omolog",
    "omoloagelor": "omolog",
    "omologi": "omolog",
    "omologii": "omolog",
    "omologilor": "omolog",
    "omologul": "omolog",
    "omologului": "omolog",
    "nemaiomologând": "omologa",
    "nemaiomologându": "omologa",
    "neomologând": "omologa",
    "neomologându": "omologa",
    "omologă": "omologa",
    "omologai": "omologa",
    "omologam": "omologa",
    "omologăm": "omologa",
    "omologând": "omologa",
    "omologându": "omologa",
    "omologară": "omologa",
    "omologarăm": "omologa",
    "omologarăți": "omologa",
    "omologase": "omologa",
    "omologasem": "omologa",
    "omologaseră": "omologa",
    "omologaserăm": "omologa",
    "omologaserăți": "omologa",
    "omologaseși": "omologa",
    "omologași": "omologa",
    "omologat": "omologa",
    "omologați": "omologa",
    "omologau": "omologa",
    "omologhează": "omologa",
    "omologhez": "omologa",
    "omologheze": "omologa",
    "omologhezi": "omologa",
    "omologata": "omologat",
    "omologată": "omologat",
    "omologate": "omologat",
    "omologatei": "omologat",
    "omologatele": "omologat",
    "omologatelor": "omologat",
    "omologați": "omologat",
    "omologații": "omologat",
    "omologaților": "omologat",
    "omologatul": "omologat",
    "omologatului": "omologat",
    "omonime": "omonim",
    "omonimele": "omonim",
    "omonimelor": "omonim",
    "omonimul": "omonim",
    "omonimului": "omonim",
    "omonimia": "omonimie",
    "omonimiei": "omonimie",
    "omonimii": "omonimie",
    "omonimiile": "omonimie",
    "omonimiilor": "omonimie",
    "omoplați": "omoplat",
    "omoplații": "omoplat",
    "omoplaților": "omoplat",
    "omoplatul": "omoplat",
    "omoplatului": "omoplat",
    "omorul": "omor",
    "omorului": "omor",
    "omoruri": "omor",
    "omorurile": "omor",
    "omorurilor": "omor",
    "omorâtă": "omorât",
    "omorâte": "omorât",
    "omorâți": "omorât",
    "omorâtoare": "omorâtor",
    "omorâtoarea": "omorâtor",
    "omorâtoarei": "omorâtor",
    "omorâtoarele": "omorâtor",
    "omorâtoarelor": "omorâtor",
    "omorâtori": "omorâtor",
    "omorâtorii": "omorâtor",
    "omorâtorilor": "omorâtor",
    "omorâtorul": "omorâtor",
    "omorâtorului": "omorâtor",
    "omorganica": "omorganic",
    "omorganică": "omorganic",
    "omorganice": "omorganic",
    "omorganicei": "omorganic",
    "omorganicele": "omorganic",
    "omorganicelor": "omorganic",
    "omorganici": "omorganic",
    "omorganicii": "omorganic",
    "omorganicilor": "omorganic",
    "omorganicul": "omorganic",
    "omorganicului": "omorganic",
    "nemaiomorând": "omorî",
    "nemaiomorându": "omorî",
    "neomorând": "omorî",
    "neomorându": "omorî",
    "omoară": "omorî",
    "omoare": "omorî",
    "omor": "omorî",
    "omora": "omorî",
    "omorai": "omorî",
    "omorâi": "omorî",
    "omoram": "omorî",
    "omorâm": "omorî",
    "omorând": "omorî",
    "omorându": "omorî",
    "omorâră": "omorî",
    "omorârăm": "omorî",
    "omorârăți": "omorî",
    "omorâse": "omorî",
    "omorâsem": "omorî",
    "omorâseră": "omorî",
    "omorâserăm": "omorî",
    "omorâserăți": "omorî",
    "omorâseși": "omorî",
    "omorâși": "omorî",
    "omorât": "omorî",
    "omorați": "omorî",
    "omorâți": "omorî",
    "omorau": "omorî",
    "omori": "omorî",
    "omotetica": "omotetic",
    "omotetică": "omotetic",
    "omotetice": "omotetic",
    "omoteticei": "omotetic",
    "omoteticele": "omotetic",
    "omoteticelor": "omotetic",
    "omotetici": "omotetic",
    "omoteticii": "omotetic",
    "omoteticilor": "omotetic",
    "omoteticul": "omotetic",
    "omoteticului": "omotetic",
    "omuciderea": "omucidere",
    "omucideri": "omucidere",
    "omuciderii": "omucidere",
    "omuciderile": "omucidere",
    "omuciderilor": "omucidere",
    "omuleți": "omuleț",
    "omuleții": "omuleț",
    "omuleților": "omuleț",
    "omulețul": "omuleț",
    "omulețului": "omuleț",
    "omușoare": "omușor",
    "omușoarele": "omușor",
    "omușoarelor": "omușor",
    "omușorul": "omușor",
    "omușorului": "omușor",
    "om-zile": "om-zi",
    "onania": "onanie",
    "onaniei": "onanie",
    "onanii": "onanie",
    "onaniile": "onanie",
    "onaniilor": "onanie",
    "oncologica": "oncologic",
    "oncologică": "oncologic",
    "oncologice": "oncologic",
    "oncologicei": "oncologic",
    "oncologicele": "oncologic",
    "oncologicelor": "oncologic",
    "oncologici": "oncologic",
    "oncologicii": "oncologic",
    "oncologicilor": "oncologic",
    "oncologicul": "oncologic",
    "oncologicului": "oncologic",
    "oncologia": "oncologie",
    "oncologiei": "oncologie",
    "oncologii": "oncologie",
    "oncologiile": "oncologie",
    "oncologiilor": "oncologie",
    "onctuoasa": "onctuos",
    "onctuoasă": "onctuos",
    "onctuoase": "onctuos",
    "onctuoasei": "onctuos",
    "onctuoasele": "onctuos",
    "onctuoaselor": "onctuos",
    "onctuoși": "onctuos",
    "onctuoșii": "onctuos",
    "onctuoșilor": "onctuos",
    "onctuosul": "onctuos",
    "onctuosului": "onctuos",
    "onctuozitatea": "onctuozitate",
    "onctuozități": "onctuozitate",
    "onctuozității": "onctuozitate",
    "nemaiondulând": "ondula",
    "nemaiondulându": "ondula",
    "neondulând": "ondula",
    "neondulându": "ondula",
    "ondulă": "ondula",
    "ondulai": "ondula",
    "ondulam": "ondula",
    "ondulăm": "ondula",
    "ondulând": "ondula",
    "ondulându": "ondula",
    "ondulară": "ondula",
    "ondularăm": "ondula",
    "ondularăți": "ondula",
    "ondulase": "ondula",
    "ondulasem": "ondula",
    "ondulaseră": "ondula",
    "ondulaserăm": "ondula",
    "ondulaserăți": "ondula",
    "ondulaseși": "ondula",
    "ondulași": "ondula",
    "ondulat": "ondula",
    "ondulați": "ondula",
    "ondulau": "ondula",
    "ondulează": "ondula",
    "ondulez": "ondula",
    "onduleze": "ondula",
    "ondulezi": "ondula",
    "ondularea": "ondulare",
    "ondulări": "ondulare",
    "ondulării": "ondulare",
    "ondulările": "ondulare",
    "ondulărilor": "ondulare",
    "ondulată": "ondulat",
    "ondulate": "ondulat",
    "ondulați": "ondulat",
    "ondulația": "ondulație",
    "ondulației": "ondulație",
    "ondulații": "ondulație",
    "ondulațiile": "ondulație",
    "ondulațiilor": "ondulație",
    "ondulatoare": "ondulator",
    "ondulatoarea": "ondulator",
    "ondulatoarei": "ondulator",
    "ondulatoarele": "ondulator",
    "ondulatoarelor": "ondulator",
    "ondulatori": "ondulator",
    "ondulatorii": "ondulator",
    "ondulatorilor": "ondulator",
    "ondulatorul": "ondulator",
    "ondulatorului": "ondulator",
    "ondulatoria": "ondulatoriu",
    "ondulatorie": "ondulatoriu",
    "ondulatoriei": "ondulatoriu",
    "ondulatorii": "ondulatoriu",
    "ondulatoriii": "ondulatoriu",
    "ondulatoriile": "ondulatoriu",
    "ondulatoriilor": "ondulatoriu",
    "ondulatoriul": "ondulatoriu",
    "ondulatoriului": "ondulatoriu",
    "onduloasa": "ondulos",
    "onduloasă": "ondulos",
    "onduloase": "ondulos",
    "onduloasei": "ondulos",
    "onduloasele": "ondulos",
    "onduloaselor": "ondulos",
    "onduloși": "ondulos",
    "onduloșii": "ondulos",
    "onduloșilor": "ondulos",
    "ondulosul": "ondulos",
    "ondulosului": "ondulos",
    "onerara": "onerar",
    "onerară": "onerar",
    "onerare": "onerar",
    "onerarei": "onerar",
    "onerarele": "onerar",
    "onerarelor": "onerar",
    "onerari": "onerar",
    "onerarii": "onerar",
    "onerarilor": "onerar",
    "onerarul": "onerar",
    "onerarului": "onerar",
    "oneroasa": "oneros",
    "oneroasă": "oneros",
    "oneroase": "oneros",
    "oneroasei": "oneros",
    "oneroasele": "oneros",
    "oneroaselor": "oneros",
    "oneroși": "oneros",
    "oneroșii": "oneros",
    "oneroșilor": "oneros",
    "onerosul": "oneros",
    "onerosului": "oneros",
    "onesta": "onest",
    "onestă": "onest",
    "oneste": "onest",
    "onestei": "onest",
    "onestele": "onest",
    "onestelor": "onest",
    "onești": "onest",
    "oneștii": "onest",
    "oneștilor": "onest",
    "onestul": "onest",
    "onestului": "onest",
    "onestitatea": "onestitate",
    "onestități": "onestitate",
    "onestității": "onestitate",
    "onirica": "oniric",
    "onirică": "oniric",
    "onirice": "oniric",
    "oniricei": "oniric",
    "oniricele": "oniric",
    "oniricelor": "oniric",
    "onirici": "oniric",
    "oniricii": "oniric",
    "oniricilor": "oniric",
    "oniricul": "oniric",
    "oniricului": "oniric",
    "onixul": "onix",
    "onixului": "onix",
    "onoarea": "onoare",
    "onoarei": "onoare",
    "onori": "onoare",
    "onomastica": "onomastic",
    "onomastică": "onomastic",
    "onomastice": "onomastic",
    "onomasticei": "onomastic",
    "onomasticele": "onomastic",
    "onomasticelor": "onomastic",
    "onomastici": "onomastic",
    "onomasticii": "onomastic",
    "onomasticilor": "onomastic",
    "onomasticul": "onomastic",
    "onomasticului": "onomastic",
    "onomatopeea": "onomatopee",
    "onomatopeei": "onomatopee",
    "onomatopeele": "onomatopee",
    "onomatopeelor": "onomatopee",
    "onomatopeica": "onomatopeic",
    "onomatopeică": "onomatopeic",
    "onomatopeice": "onomatopeic",
    "onomatopeicei": "onomatopeic",
    "onomatopeicele": "onomatopeic",
    "onomatopeicelor": "onomatopeic",
    "onomatopeici": "onomatopeic",
    "onomatopeicii": "onomatopeic",
    "onomatopeicilor": "onomatopeic",
    "onomatopeicul": "onomatopeic",
    "onomatopeicului": "onomatopeic",
    "onomatopoetica": "onomatopoetic",
    "onomatopoetică": "onomatopoetic",
    "onomatopoetice": "onomatopoetic",
    "onomatopoeticei": "onomatopoetic",
    "onomatopoeticele": "onomatopoetic",
    "onomatopoeticelor": "onomatopoetic",
    "onomatopoetici": "onomatopoetic",
    "onomatopoeticii": "onomatopoetic",
    "onomatopoeticilor": "onomatopoetic",
    "onomatopoeticul": "onomatopoetic",
    "onomatopoeticului": "onomatopoetic",
    "onorul": "onor",
    "onorului": "onor",
    "onoruri": "onor",
    "onorurile": "onor",
    "onorurilor": "onor",
    "nemaionorând": "onora",
    "nemaionorându": "onora",
    "neonorând": "onora",
    "neonorându": "onora",
    "onoră": "onora",
    "onorai": "onora",
    "onoram": "onora",
    "onorăm": "onora",
    "onorând": "onora",
    "onorându": "onora",
    "onorară": "onora",
    "onorarăm": "onora",
    "onorarăți": "onora",
    "onorase": "onora",
    "onorasem": "onora",
    "onoraseră": "onora",
    "onoraserăm": "onora",
    "onoraserăți": "onora",
    "onoraseși": "onora",
    "onorași": "onora",
    "onorat": "onora",
    "onorați": "onora",
    "onorau": "onora",
    "onorează": "onora",
    "onorez": "onora",
    "onoreze": "onora",
    "onorezi": "onora",
    "onorabila": "onorabil",
    "onorabilă": "onorabil",
    "onorabile": "onorabil",
    "onorabilei": "onorabil",
    "onorabilele": "onorabil",
    "onorabilelor": "onorabil",
    "onorabili": "onorabil",
    "onorabilii": "onorabil",
    "onorabililor": "onorabil",
    "onorabilul": "onorabil",
    "onorabilului": "onorabil",
    "onoranta": "onorant",
    "onorantă": "onorant",
    "onorante": "onorant",
    "onorantei": "onorant",
    "onorantele": "onorant",
    "onorantelor": "onorant",
    "onoranți": "onorant",
    "onoranții": "onorant",
    "onoranților": "onorant",
    "onorantul": "onorant",
    "onorantului": "onorant",
    "onorara": "onorar",
    "onorară": "onorar",
    "onorare": "onorar",
    "onorarei": "onorar",
    "onorarele": "onorar",
    "onorarelor": "onorar",
    "onorari": "onorar",
    "onorarii": "onorar",
    "onorarilor": "onorar",
    "onorarul": "onorar",
    "onorarului": "onorar",
    "onorarii": "onorariu",
    "onorariile": "onorariu",
    "onorariilor": "onorariu",
    "onorariul": "onorariu",
    "onorariului": "onorariu",
    "onorata": "onorat",
    "onorată": "onorat",
    "onorate": "onorat",
    "onoratei": "onorat",
    "onoratele": "onorat",
    "onoratelor": "onorat",
    "onorați": "onorat",
    "onorații": "onorat",
    "onoraților": "onorat",
    "onoratul": "onorat",
    "onoratului": "onorat",
    "onorifica": "onorific",
    "onorifică": "onorific",
    "onorifice": "onorific",
    "onorificei": "onorific",
    "onorificele": "onorific",
    "onorificelor": "onorific",
    "onorifici": "onorific",
    "onorificii": "onorific",
    "onorificilor": "onorific",
    "onorificul": "onorific",
    "onorificului": "onorific",
    "ontica": "ontic",
    "ontică": "ontic",
    "ontice": "ontic",
    "onticei": "ontic",
    "onticele": "ontic",
    "onticelor": "ontic",
    "ontici": "ontic",
    "onticii": "ontic",
    "onticilor": "ontic",
    "onticul": "ontic",
    "onticului": "ontic",
    "ontogenetica": "ontogenetic",
    "ontogenetică": "ontogenetic",
    "ontogenetice": "ontogenetic",
    "ontogeneticei": "ontogenetic",
    "ontogeneticele": "ontogenetic",
    "ontogeneticelor": "ontogenetic",
    "ontogenetici": "ontogenetic",
    "ontogeneticii": "ontogenetic",
    "ontogeneticilor": "ontogenetic",
    "ontogeneticul": "ontogenetic",
    "ontogeneticului": "ontogenetic",
    "ontogeneza": "ontogeneză",
    "ontogeneze": "ontogeneză",
    "ontogenezei": "ontogeneză",
    "ontogenezele": "ontogeneză",
    "ontogenezelor": "ontogeneză",
    "ontogenica": "ontogenic",
    "ontogenică": "ontogenic",
    "ontogenice": "ontogenic",
    "ontogenicei": "ontogenic",
    "ontogenicele": "ontogenic",
    "ontogenicelor": "ontogenic",
    "ontogenici": "ontogenic",
    "ontogenicii": "ontogenic",
    "ontogenicilor": "ontogenic",
    "ontogenicul": "ontogenic",
    "ontogenicului": "ontogenic",
    "ontogonica": "ontogonic",
    "ontogonică": "ontogonic",
    "ontogonice": "ontogonic",
    "ontogonicei": "ontogonic",
    "ontogonicele": "ontogonic",
    "ontogonicelor": "ontogonic",
    "ontogonici": "ontogonic",
    "ontogonicii": "ontogonic",
    "ontogonicilor": "ontogonic",
    "ontogonicul": "ontogonic",
    "ontogonicului": "ontogonic",
    "ontologica": "ontologic",
    "ontologică": "ontologic",
    "ontologice": "ontologic",
    "ontologicei": "ontologic",
    "ontologicele": "ontologic",
    "ontologicelor": "ontologic",
    "ontologici": "ontologic",
    "ontologicii": "ontologic",
    "ontologicilor": "ontologic",
    "ontologicul": "ontologic",
    "ontologicului": "ontologic",
    "ontologia": "ontologie",
    "ontologiei": "ontologie",
    "ontologii": "ontologie",
    "ontologiile": "ontologie",
    "ontologiilor": "ontologie",
    "oolitica": "oolitic",
    "oolitică": "oolitic",
    "oolitice": "oolitic",
    "ooliticei": "oolitic",
    "ooliticele": "oolitic",
    "ooliticelor": "oolitic",
    "oolitici": "oolitic",
    "ooliticii": "oolitic",
    "ooliticilor": "oolitic",
    "ooliticul": "oolitic",
    "ooliticului": "oolitic",
    "oosfera": "oosferă",
    "oosfere": "oosferă",
    "oosferei": "oosferă",
    "oosferele": "oosferă",
    "oosferelor": "oosferă",
    "opul": "op",
    "opului": "op",
    "opuri": "op",
    "opurile": "op",
    "opurilor": "op",
    "opaca": "opac",
    "opacă": "opac",
    "opace": "opac",
    "opacei": "opac",
    "opacele": "opac",
    "opacelor": "opac",
    "opaci": "opac",
    "opacii": "opac",
    "opacilor": "opac",
    "opacul": "opac",
    "opacului": "opac",
    "nemaiopacifiind": "opacifia",
    "nemaiopacifiindu": "opacifia",
    "neopacifiind": "opacifia",
    "neopacifiindu": "opacifia",
    "opacifiai": "opacifia",
    "opacifiam": "opacifia",
    "opacifiară": "opacifia",
    "opacifiarăm": "opacifia",
    "opacifiarăți": "opacifia",
    "opacifiase": "opacifia",
    "opacifiasem": "opacifia",
    "opacifiaseră": "opacifia",
    "opacifiaserăm": "opacifia",
    "opacifiaserăți": "opacifia",
    "opacifiaseși": "opacifia",
    "opacifiași": "opacifia",
    "opacifiat": "opacifia",
    "opacifiați": "opacifia",
    "opacifiau": "opacifia",
    "opacifiază": "opacifia",
    "opacifie": "opacifia",
    "opacifiem": "opacifia",
    "opacifiez": "opacifia",
    "opacifieze": "opacifia",
    "opacifiezi": "opacifia",
    "opacifiind": "opacifia",
    "opacifiindu": "opacifia",
    "opacifiată": "opacifiat",
    "opacifiate": "opacifiat",
    "opacifiați": "opacifiat",
    "opacitatea": "opacitate",
    "opacități": "opacitate",
    "opacității": "opacitate",
    "opacitățile": "opacitate",
    "opacităților": "opacitate",
    "opacizanta": "opacizant",
    "opacizantă": "opacizant",
    "opacizante": "opacizant",
    "opacizantei": "opacizant",
    "opacizantele": "opacizant",
    "opacizantelor": "opacizant",
    "opacizanți": "opacizant",
    "opacizanții": "opacizant",
    "opacizanților": "opacizant",
    "opacizantul": "opacizant",
    "opacizantului": "opacizant",
    "opaițe": "opaiț",
    "opaițele": "opaiț",
    "opaițelor": "opaiț",
    "opaițul": "opaiț",
    "opaițului": "opaiț",
    "opale": "opal",
    "opalele": "opal",
    "opalelor": "opal",
    "opalul": "opal",
    "opalului": "opal",
    "opalescenta": "opalescent",
    "opalescentă": "opalescent",
    "opalescente": "opalescent",
    "opalescentei": "opalescent",
    "opalescentele": "opalescent",
    "opalescentelor": "opalescent",
    "opalescenți": "opalescent",
    "opalescenții": "opalescent",
    "opalescenților": "opalescent",
    "opalescentul": "opalescent",
    "opalescentului": "opalescent",
    "opalescența": "opalescență",
    "opalescențe": "opalescență",
    "opalescenței": "opalescență",
    "opalescențele": "opalescență",
    "opalescențelor": "opalescență",
    "opalina": "opalin",
    "opalină": "opalin",
    "opaline": "opalin",
    "opalinei": "opalin",
    "opalinele": "opalin",
    "opalinelor": "opalin",
    "opalini": "opalin",
    "opalinii": "opalin",
    "opalinilor": "opalin",
    "opalinul": "opalin",
    "opalinului": "opalin",
    "opăreala": "opăreală",
    "opăreli": "opăreală",
    "opărelii": "opăreală",
    "opărelile": "opăreală",
    "opărelilor": "opăreală",
    "nemaiopărind": "opări",
    "nemaiopărindu": "opări",
    "neopărind": "opări",
    "neopărindu": "opări",
    "opărea": "opări",
    "opăreai": "opări",
    "opăream": "opări",
    "opărească": "opări",
    "opăreați": "opări",
    "opăreau": "opări",
    "opăresc": "opări",
    "opărește": "opări",
    "opărești": "opări",
    "opării": "opări",
    "opărim": "opări",
    "opărind": "opări",
    "opărindu": "opări",
    "opăriră": "opări",
    "opărirăm": "opări",
    "opărirăți": "opări",
    "opărise": "opări",
    "opărisem": "opări",
    "opăriseră": "opări",
    "opăriserăm": "opări",
    "opăriserăți": "opări",
    "opăriseși": "opări",
    "opăriși": "opări",
    "opărit": "opări",
    "opăriți": "opări",
    "opărită": "opărit",
    "opărite": "opărit",
    "opăriți": "opărit",
    "opăritoare": "opăritor",
    "opăritoarea": "opăritor",
    "opăritoarei": "opăritor",
    "opăritoarele": "opăritor",
    "opăritoarelor": "opăritor",
    "opăritori": "opăritor",
    "opăritorii": "opăritor",
    "opăritorilor": "opăritor",
    "opăritorul": "opăritor",
    "opăritorului": "opăritor",
    "Openului": "Open",
    "nemaioperând": "opera",
    "nemaioperându": "opera",
    "neoperând": "opera",
    "neoperându": "opera",
    "operă": "opera",
    "operai": "opera",
    "operam": "opera",
    "operăm": "opera",
    "operând": "opera",
    "operându": "opera",
    "operară": "opera",
    "operarăm": "opera",
    "operarăți": "opera",
    "operase": "opera",
    "operasem": "opera",
    "operaseră": "opera",
    "operaserăm": "opera",
    "operaserăți": "opera",
    "operaseși": "opera",
    "operași": "opera",
    "operat": "opera",
    "operați": "opera",
    "operau": "opera",
    "operează": "opera",
    "operez": "opera",
    "opereze": "opera",
    "operezi": "opera",
    "op.": "operă",
    "opera": "operă",
    "opere": "operă",
    "operei": "operă",
    "operele": "operă",
    "operelor": "operă",
    "operabila": "operabil",
    "operabilă": "operabil",
    "operabile": "operabil",
    "operabilei": "operabil",
    "operabilele": "operabil",
    "operabilelor": "operabil",
    "operabili": "operabil",
    "operabilii": "operabil",
    "operabililor": "operabil",
    "operabilul": "operabil",
    "operabilului": "operabil",
    "operanta": "operant",
    "operantă": "operant",
    "operante": "operant",
    "operantei": "operant",
    "operantele": "operant",
    "operantelor": "operant",
    "operanți": "operant",
    "operanții": "operant",
    "operanților": "operant",
    "operantul": "operant",
    "operantului": "operant",
    "operata": "operat",
    "operată": "operat",
    "operate": "operat",
    "operatei": "operat",
    "operatele": "operat",
    "operatelor": "operat",
    "operați": "operat",
    "operații": "operat",
    "operaților": "operat",
    "operatul": "operat",
    "operatului": "operat",
    "operația": "operație",
    "operației": "operație",
    "operații": "operație",
    "operațiile": "operație",
    "operațiilor": "operație",
    "operaționala": "operațional",
    "operațională": "operațional",
    "operaționale": "operațional",
    "operaționalei": "operațional",
    "operaționalele": "operațional",
    "operaționalelor": "operațional",
    "operaționali": "operațional",
    "operaționalii": "operațional",
    "operaționalilor": "operațional",
    "operaționalul": "operațional",
    "operaționalului": "operațional",
    "operațiunea": "operațiune",
    "operațiuni": "operațiune",
    "operațiunii": "operațiune",
    "operațiunile": "operațiune",
    "operațiunilor": "operațiune",
    "operativa": "operativ",
    "operativă": "operativ",
    "operative": "operativ",
    "operativei": "operativ",
    "operativele": "operativ",
    "operativelor": "operativ",
    "operativi": "operativ",
    "operativii": "operativ",
    "operativilor": "operativ",
    "operativul": "operativ",
    "operativului": "operativ",
    "operativitatea": "operativitate",
    "operativități": "operativitate",
    "operativității": "operativitate",
    "operatoarea": "operatoare",
    "operatoarei": "operatoare",
    "operatoarele": "operatoare",
    "operatoarelor": "operatoare",
    "operatori": "operator",
    "operatorii": "operator",
    "operatorilor": "operator",
    "operatorul": "operator",
    "operatorului": "operator",
    "operatoria": "operatoriu",
    "operatorie": "operatoriu",
    "operatoriei": "operatoriu",
    "operatorii": "operatoriu",
    "operatoriii": "operatoriu",
    "operatoriile": "operatoriu",
    "operatoriilor": "operatoriu",
    "operatoriul": "operatoriu",
    "operatoriului": "operatoriu",
    "opercule": "opercul",
    "operculele": "opercul",
    "operculelor": "opercul",
    "operculul": "opercul",
    "operculului": "opercul",
    "opereta": "operetă",
    "operete": "operetă",
    "operetei": "operetă",
    "operetele": "operetă",
    "operetelor": "operetă",
    "nemaiopinând": "opina",
    "nemaiopinându": "opina",
    "neopinând": "opina",
    "neopinându": "opina",
    "opină": "opina",
    "opinai": "opina",
    "opinam": "opina",
    "opinăm": "opina",
    "opinând": "opina",
    "opinându": "opina",
    "opinară": "opina",
    "opinarăm": "opina",
    "opinarăți": "opina",
    "opinase": "opina",
    "opinasem": "opina",
    "opinaseră": "opina",
    "opinaserăm": "opina",
    "opinaserăți": "opina",
    "opinaseși": "opina",
    "opinași": "opina",
    "opinat": "opina",
    "opinați": "opina",
    "opinau": "opina",
    "opinează": "opina",
    "opinez": "opina",
    "opineze": "opina",
    "opinezi": "opina",
    "opinabila": "opinabil",
    "opinabilă": "opinabil",
    "opinabile": "opinabil",
    "opinabilei": "opinabil",
    "opinabilele": "opinabil",
    "opinabilelor": "opinabil",
    "opinabili": "opinabil",
    "opinabilii": "opinabil",
    "opinabililor": "opinabil",
    "opinabilul": "opinabil",
    "opinabilului": "opinabil",
    "opinarea": "opinare",
    "opinată": "opinat",
    "opinate": "opinat",
    "opinați": "opinat",
    "opinca": "opincă",
    "opinci": "opincă",
    "opincii": "opincă",
    "opincile": "opincă",
    "opincilor": "opincă",
    "opincari": "opincar",
    "opincarii": "opincar",
    "opincarilor": "opincar",
    "opincarul": "opincar",
    "opincarului": "opincar",
    "opinenți": "opinent",
    "opinenții": "opinent",
    "opinenților": "opinent",
    "opinentul": "opinent",
    "opinentului": "opinent",
    "opinenta": "opinentă",
    "opinente": "opinentă",
    "opinentei": "opinentă",
    "opinentele": "opinentă",
    "opinentelor": "opinentă",
    "opinia": "opinie",
    "opiniei": "opinie",
    "opinii": "opinie",
    "opiniile": "opinie",
    "opiniilor": "opinie",
    "opinteala": "opinteală",
    "opinteli": "opinteală",
    "opintelii": "opinteală",
    "opintelile": "opinteală",
    "opintelilor": "opinteală",
    "nemaiopintind": "opinti",
    "nemaiopintindu": "opinti",
    "neopintind": "opinti",
    "neopintindu": "opinti",
    "opintea": "opinti",
    "opinteai": "opinti",
    "opinteam": "opinti",
    "opintească": "opinti",
    "opinteați": "opinti",
    "opinteau": "opinti",
    "opintesc": "opinti",
    "opintește": "opinti",
    "opintești": "opinti",
    "opintii": "opinti",
    "opintim": "opinti",
    "opintind": "opinti",
    "opintindu": "opinti",
    "opintiră": "opinti",
    "opintirăm": "opinti",
    "opintirăți": "opinti",
    "opintise": "opinti",
    "opintisem": "opinti",
    "opintiseră": "opinti",
    "opintiserăm": "opinti",
    "opintiserăți": "opinti",
    "opintiseși": "opinti",
    "opintiși": "opinti",
    "opintit": "opinti",
    "opintiți": "opinti",
    "opintită": "opintit",
    "opintite": "opintit",
    "opintiți": "opintit",
    "opiul": "opiu",
    "opiului": "opiu",
    "opiumul": "opium",
    "opiumului": "opium",
    "opleanul": "oplean",
    "opleanului": "oplean",
    "oplene": "oplean",
    "oplenele": "oplean",
    "oplenelor": "oplean",
    "nemaioploșind": "oploși",
    "nemaioploșindu": "oploși",
    "neoploșind": "oploși",
    "neoploșindu": "oploși",
    "oploșea": "oploși",
    "oploșeai": "oploși",
    "oploșeam": "oploși",
    "oploșească": "oploși",
    "oploșeați": "oploși",
    "oploșeau": "oploși",
    "oploșesc": "oploși",
    "oploșește": "oploși",
    "oploșești": "oploși",
    "oploșii": "oploși",
    "oploșim": "oploși",
    "oploșind": "oploși",
    "oploșindu": "oploși",
    "oploșiră": "oploși",
    "oploșirăm": "oploși",
    "oploșirăți": "oploși",
    "oploșise": "oploși",
    "oploșisem": "oploși",
    "oploșiseră": "oploși",
    "oploșiserăm": "oploși",
    "oploșiserăți": "oploși",
    "oploșiseși": "oploși",
    "oploșiși": "oploși",
    "oploșit": "oploși",
    "oploșiți": "oploși",
    "oploșită": "oploșit",
    "oploșite": "oploșit",
    "oploșiți": "oploșit",
    "oponenta": "oponent",
    "oponentă": "oponent",
    "oponente": "oponent",
    "oponentei": "oponent",
    "oponentele": "oponent",
    "oponentelor": "oponent",
    "oponenți": "oponent",
    "oponenții": "oponent",
    "oponenților": "oponent",
    "oponentul": "oponent",
    "oponentului": "oponent",
    "oponenta": "oponentă",
    "oponente": "oponentă",
    "oponentei": "oponentă",
    "oponentele": "oponentă",
    "oponentelor": "oponentă",
    "oportuna": "oportun",
    "oportună": "oportun",
    "oportune": "oportun",
    "oportunei": "oportun",
    "oportunele": "oportun",
    "oportunelor": "oportun",
    "oportuni": "oportun",
    "oportunii": "oportun",
    "oportunilor": "oportun",
    "oportunul": "oportun",
    "oportunului": "oportun",
    "oportunismul": "oportunism",
    "oportunismului": "oportunism",
    "oportunista": "oportunist",
    "oportunistă": "oportunist",
    "oportuniste": "oportunist",
    "oportunistei": "oportunist",
    "oportunistele": "oportunist",
    "oportunistelor": "oportunist",
    "oportuniști": "oportunist",
    "oportuniștii": "oportunist",
    "oportuniștilor": "oportunist",
    "oportunistul": "oportunist",
    "oportunistului": "oportunist",
    "oportunista": "oportunistă",
    "oportuniste": "oportunistă",
    "oportunistei": "oportunistă",
    "oportunistele": "oportunistă",
    "oportunistelor": "oportunistă",
    "oportunitatea": "oportunitate",
    "oportunități": "oportunitate",
    "oportunității": "oportunitate",
    "oportunitățile": "oportunitate",
    "oportunităților": "oportunitate",
    "opozabila": "opozabil",
    "opozabilă": "opozabil",
    "opozabile": "opozabil",
    "opozabilei": "opozabil",
    "opozabilele": "opozabil",
    "opozabilelor": "opozabil",
    "opozabili": "opozabil",
    "opozabilii": "opozabil",
    "opozabililor": "opozabil",
    "opozabilul": "opozabil",
    "opozabilului": "opozabil",
    "opozanți": "opozant",
    "opozanții": "opozant",
    "opozanților": "opozant",
    "opozantul": "opozant",
    "opozantului": "opozant",
    "opozanta": "opozantă",
    "opozante": "opozantă",
    "opozantei": "opozantă",
    "opozantele": "opozantă",
    "opozantelor": "opozantă",
    "opozita": "opozit",
    "opozită": "opozit",
    "opozite": "opozit",
    "opozitei": "opozit",
    "opozitele": "opozit",
    "opozitelor": "opozit",
    "opoziți": "opozit",
    "opoziții": "opozit",
    "opoziților": "opozit",
    "opozitul": "opozit",
    "opozitului": "opozit",
    "opoziția": "opoziție",
    "opoziției": "opoziție",
    "opoziții": "opoziție",
    "opozițiile": "opoziție",
    "opozițiilor": "opoziție",
    "opoziționala": "opozițional",
    "opozițională": "opozițional",
    "opoziționale": "opozițional",
    "opoziționalei": "opozițional",
    "opoziționalele": "opozițional",
    "opoziționalelor": "opozițional",
    "opoziționali": "opozițional",
    "opoziționalii": "opozițional",
    "opoziționalilor": "opozițional",
    "opoziționalul": "opozițional",
    "opoziționalului": "opozițional",
    "opoziționista": "opoziționist",
    "opoziționistă": "opoziționist",
    "opoziționiste": "opoziționist",
    "opoziționistei": "opoziționist",
    "opoziționistele": "opoziționist",
    "opoziționistelor": "opoziționist",
    "opoziționiști": "opoziționist",
    "opoziționiștii": "opoziționist",
    "opoziționiștilor": "opoziționist",
    "opoziționistul": "opoziționist",
    "opoziționistului": "opoziționist",
    "opreala": "opreală",
    "opreli": "opreală",
    "oprelii": "opreală",
    "oprelile": "opreală",
    "oprelilor": "opreală",
    "opreliștea": "opreliște",
    "opreliști": "opreliște",
    "opreliștii": "opreliște",
    "opreliștile": "opreliște",
    "opreliștilor": "opreliște",
    "opresiunea": "opresiune",
    "opresiuni": "opresiune",
    "opresiunii": "opresiune",
    "opresiunile": "opresiune",
    "opresiunilor": "opresiune",
    "opresiva": "opresiv",
    "opresivă": "opresiv",
    "opresive": "opresiv",
    "opresivei": "opresiv",
    "opresivele": "opresiv",
    "opresivelor": "opresiv",
    "opresivi": "opresiv",
    "opresivii": "opresiv",
    "opresivilor": "opresiv",
    "opresivul": "opresiv",
    "opresivului": "opresiv",
    "opresoare": "opresor",
    "opresoarea": "opresor",
    "opresoarei": "opresor",
    "opresoarele": "opresor",
    "opresoarelor": "opresor",
    "opresori": "opresor",
    "opresorii": "opresor",
    "opresorilor": "opresor",
    "opresorul": "opresor",
    "opresorului": "opresor",
    "nemaioprind": "opri",
    "nemaioprindu": "opri",
    "neoprind": "opri",
    "neoprindu": "opri",
    "oprea": "opri",
    "opreai": "opri",
    "opream": "opri",
    "oprească": "opri",
    "opreați": "opri",
    "opreau": "opri",
    "opresc": "opri",
    "oprește": "opri",
    "oprești": "opri",
    "oprii": "opri",
    "oprim": "opri",
    "oprind": "opri",
    "oprindu": "opri",
    "opriră": "opri",
    "oprirăm": "opri",
    "oprirăți": "opri",
    "oprise": "opri",
    "oprisem": "opri",
    "opriseră": "opri",
    "opriserăm": "opri",
    "opriserăți": "opri",
    "opriseși": "opri",
    "opriși": "opri",
    "oprit": "opri",
    "opriți": "opri",
    "nemaioprimând": "oprima",
    "nemaioprimându": "oprima",
    "neoprimând": "oprima",
    "neoprimându": "oprima",
    "oprim": "oprima",
    "oprimă": "oprima",
    "oprimai": "oprima",
    "oprimam": "oprima",
    "oprimăm": "oprima",
    "oprimând": "oprima",
    "oprimându": "oprima",
    "oprimară": "oprima",
    "oprimarăm": "oprima",
    "oprimarăți": "oprima",
    "oprimase": "oprima",
    "oprimasem": "oprima",
    "oprimaseră": "oprima",
    "oprimaserăm": "oprima",
    "oprimaserăți": "oprima",
    "oprimaseși": "oprima",
    "oprimași": "oprima",
    "oprimat": "oprima",
    "oprimați": "oprima",
    "oprimau": "oprima",
    "oprime": "oprima",
    "oprimi": "oprima",
    "oprimată": "oprimat",
    "oprimate": "oprimat",
    "oprimați": "oprimat",
    "oprirea": "oprire",
    "opriri": "oprire",
    "opririi": "oprire",
    "opririle": "oprire",
    "opririlor": "oprire",
    "oprită": "oprit",
    "oprite": "oprit",
    "opriți": "oprit",
    "oprobrii": "oprobriu",
    "oprobriile": "oprobriu",
    "oprobriilor": "oprobriu",
    "oprobriul": "oprobriu",
    "oprobriului": "oprobriu",
    "opta": "opt",
    "optulea": "opt",
    "VIII": "opt",
    "nemaioptând": "opta",
    "nemaioptându": "opta",
    "neoptând": "opta",
    "neoptându": "opta",
    "optă": "opta",
    "optai": "opta",
    "optam": "opta",
    "optăm": "opta",
    "optând": "opta",
    "optându": "opta",
    "optară": "opta",
    "optarăm": "opta",
    "optarăți": "opta",
    "optase": "opta",
    "optasem": "opta",
    "optaseră": "opta",
    "optaserăm": "opta",
    "optaserăți": "opta",
    "optaseși": "opta",
    "optași": "opta",
    "optat": "opta",
    "optați": "opta",
    "optau": "opta",
    "optează": "opta",
    "optez": "opta",
    "opteze": "opta",
    "optezi": "opta",
    "optată": "optat",
    "optate": "optat",
    "optați": "optat",
    "optativa": "optativ",
    "optativă": "optativ",
    "optative": "optativ",
    "optativei": "optativ",
    "optativele": "optativ",
    "optativelor": "optativ",
    "optativi": "optativ",
    "optativii": "optativ",
    "optativilor": "optativ",
    "optativul": "optativ",
    "optativului": "optativ",
    "optica": "optic",
    "optică": "optic",
    "optice": "optic",
    "opticei": "optic",
    "opticele": "optic",
    "opticelor": "optic",
    "optici": "optic",
    "opticii": "optic",
    "opticilor": "optic",
    "opticul": "optic",
    "opticului": "optic",
    "opt.": "optică",
    "optica": "optică",
    "optici": "optică",
    "opticii": "optică",
    "opticile": "optică",
    "opticilor": "optică",
    "opticianul": "optician",
    "opticianului": "optician",
    "opticieni": "optician",
    "opticienii": "optician",
    "opticienilor": "optician",
    "opticiana": "opticiană",
    "opticiene": "opticiană",
    "opticienei": "opticiană",
    "opticienele": "opticiană",
    "opticienelor": "opticiană",
    "optima": "optim",
    "optimă": "optim",
    "optime": "optim",
    "optimei": "optim",
    "optimele": "optim",
    "optimelor": "optim",
    "optimi": "optim",
    "optimii": "optim",
    "optimilor": "optim",
    "optimul": "optim",
    "optimului": "optim",
    "optimea": "optime",
    "optimi": "optime",
    "optimii": "optime",
    "optimile": "optime",
    "optimilor": "optime",
    "optimismul": "optimism",
    "optimismului": "optimism",
    "optimista": "optimist",
    "optimistă": "optimist",
    "optimiste": "optimist",
    "optimistei": "optimist",
    "optimistele": "optimist",
    "optimistelor": "optimist",
    "optimiști": "optimist",
    "optimiștii": "optimist",
    "optimiștilor": "optimist",
    "optimistul": "optimist",
    "optimistului": "optimist",
    "optimista": "optimistă",
    "optimiste": "optimistă",
    "optimistei": "optimistă",
    "optimistele": "optimistă",
    "optimistelor": "optimistă",
    "optimizarea": "optimizare",
    "optimizări": "optimizare",
    "optimizării": "optimizare",
    "optimizările": "optimizare",
    "optimizărilor": "optimizare",
    "optimizată": "optimizat",
    "optimizate": "optimizat",
    "optimizați": "optimizat",
    "opționala": "opțional",
    "opțională": "opțional",
    "opționale": "opțional",
    "opționalei": "opțional",
    "opționalele": "opțional",
    "opționalelor": "opțional",
    "opționali": "opțional",
    "opționalii": "opțional",
    "opționalilor": "opțional",
    "opționalul": "opțional",
    "opționalului": "opțional",
    "optisprezecimea": "optisprezecime",
    "optisprezecimi": "optisprezecime",
    "optisprezecimii": "optisprezecime",
    "optisprezecimile": "optisprezecime",
    "optisprezecimilor": "optisprezecime",
    "opțiunea": "opțiune",
    "opțiuni": "opțiune",
    "opțiunii": "opțiune",
    "opțiunile": "opțiune",
    "opțiunilor": "opțiune",
    "optișpe": "optsprezece",
    "optișpea": "optsprezece",
    "optișpelea": "optsprezece",
    "optisprezecelea": "optsprezece",
    "optsprezecea": "optsprezece",
    "XVIII": "optsprezece",
    "LXXX": "optzeci",
    "optzecea": "optzeci",
    "optzecilea": "optzeci",
    "opulenta": "opulent",
    "opulentă": "opulent",
    "opulente": "opulent",
    "opulentei": "opulent",
    "opulentele": "opulent",
    "opulentelor": "opulent",
    "opulenți": "opulent",
    "opulenții": "opulent",
    "opulenților": "opulent",
    "opulentul": "opulent",
    "opulentului": "opulent",
    "nemaiopunând": "opune",
    "nemaiopunându": "opune",
    "neopunând": "opune",
    "neopunându": "opune",
    "opui": "opune",
    "opun": "opune",
    "opună": "opune",
    "opunând": "opune",
    "opunându": "opune",
    "opunea": "opune",
    "opuneai": "opune",
    "opuneam": "opune",
    "opuneați": "opune",
    "opuneau": "opune",
    "opunem": "opune",
    "opuneți": "opune",
    "opus": "opune",
    "opuse": "opune",
    "opusei": "opune",
    "opuseră": "opune",
    "opuserăm": "opune",
    "opuserăți": "opune",
    "opusese": "opune",
    "opusesem": "opune",
    "opuseseră": "opune",
    "opuseserăm": "opune",
    "opuseserăți": "opune",
    "opuseseși": "opune",
    "opuseși": "opune",
    "opusa": "opus",
    "opusă": "opus",
    "opuse": "opus",
    "opusei": "opus",
    "opusele": "opus",
    "opuselor": "opus",
    "opuși": "opus",
    "opușii": "opus",
    "opușilor": "opus",
    "opusul": "opus",
    "opusului": "opus",
    "opusuri": "opus",
    "opusurile": "opus",
    "opusurilor": "opus",
    "op.cit.": "opus_citatum",
    "opuscule": "opuscul",
    "opusculele": "opuscul",
    "opusculelor": "opuscul",
    "opusculul": "opuscul",
    "opusculului": "opuscul",
    "h.": "oră",
    "ora": "oră",
    "ore": "oră",
    "orei": "oră",
    "orele": "oră",
    "orelor": "oră",
    "nemaiorăcăind": "orăcăi",
    "nemaiorăcăindu": "orăcăi",
    "neorăcăind": "orăcăi",
    "neorăcăindu": "orăcăi",
    "orăcăia": "orăcăi",
    "orăcăiai": "orăcăi",
    "orăcăiam": "orăcăi",
    "orăcăiați": "orăcăi",
    "orăcăiau": "orăcăi",
    "orăcăie": "orăcăi",
    "orăcăii": "orăcăi",
    "orăcăim": "orăcăi",
    "orăcăind": "orăcăi",
    "orăcăindu": "orăcăi",
    "orăcăiră": "orăcăi",
    "orăcăirăm": "orăcăi",
    "orăcăirăți": "orăcăi",
    "orăcăise": "orăcăi",
    "orăcăisem": "orăcăi",
    "orăcăiseră": "orăcăi",
    "orăcăiserăm": "orăcăi",
    "orăcăiserăți": "orăcăi",
    "orăcăiseși": "orăcăi",
    "orăcăiși": "orăcăi",
    "orăcăit": "orăcăi",
    "orăcăiți": "orăcăi",
    "orăcăită": "orăcăit",
    "orăcăite": "orăcăit",
    "orăcăiți": "orăcăit",
    "orăcăitul": "orăcăit",
    "orăcăitului": "orăcăit",
    "orăcăituri": "orăcăit",
    "orăcăiturile": "orăcăit",
    "orăcăiturilor": "orăcăit",
    "oracole": "oracol",
    "oracolele": "oracol",
    "oracolelor": "oracol",
    "oracolul": "oracol",
    "oracolului": "oracol",
    "oraculara": "oracular",
    "oraculară": "oracular",
    "oraculare": "oracular",
    "oracularei": "oracular",
    "oracularele": "oracular",
    "oracularelor": "oracular",
    "oraculari": "oracular",
    "oracularii": "oracular",
    "oracularilor": "oracular",
    "oracularul": "oracular",
    "oracularului": "oracular",
    "Oradei": "Oradea",
    "orădeana": "orădean",
    "orădeană": "orădean",
    "orădeanul": "orădean",
    "orădeanului": "orădean",
    "orădene": "orădean",
    "orădenei": "orădean",
    "orădenele": "orădean",
    "orădenelor": "orădean",
    "orădeni": "orădean",
    "orădenii": "orădean",
    "orădenilor": "orădean",
    "orala": "oral",
    "orală": "oral",
    "orale": "oral",
    "oralei": "oral",
    "oralele": "oral",
    "oralelor": "oral",
    "orali": "oral",
    "oralii": "oral",
    "oralilor": "oral",
    "oralul": "oral",
    "oralului": "oral",
    "oralitatea": "oralitate",
    "oralități": "oralitate",
    "oralității": "oralitate",
    "nemaiorânduind": "orândui",
    "nemaiorânduindu": "orândui",
    "neorânduind": "orândui",
    "neorânduindu": "orândui",
    "orânduia": "orândui",
    "orânduiai": "orândui",
    "orânduiam": "orândui",
    "orânduiască": "orândui",
    "orânduiați": "orândui",
    "orânduiau": "orândui",
    "orânduiesc": "orândui",
    "orânduiește": "orândui",
    "orânduiești": "orândui",
    "orânduii": "orândui",
    "orânduim": "orândui",
    "orânduind": "orândui",
    "orânduindu": "orândui",
    "orânduiră": "orândui",
    "orânduirăm": "orândui",
    "orânduirăți": "orândui",
    "orânduise": "orândui",
    "orânduisem": "orândui",
    "orânduiseră": "orândui",
    "orânduiserăm": "orândui",
    "orânduiserăți": "orândui",
    "orânduiseși": "orândui",
    "orânduiși": "orândui",
    "orânduit": "orândui",
    "orânduiți": "orândui",
    "orânduitu": "orândui",
    "orânduiala": "orânduială",
    "orânduieli": "orânduială",
    "orânduielii": "orânduială",
    "orânduielile": "orânduială",
    "orânduielilor": "orânduială",
    "orânduirea": "orânduire",
    "orânduiri": "orânduire",
    "orânduirii": "orânduire",
    "orânduirile": "orânduire",
    "orânduirilor": "orânduire",
    "orânduită": "orânduit",
    "orânduite": "orânduit",
    "orânduiți": "orânduit",
    "oranjada": "oranjadă",
    "oranjade": "oranjadă",
    "oranjadei": "oranjadă",
    "oranjadele": "oranjadă",
    "oranjadelor": "oranjadă",
    "orara": "orar",
    "orară": "orar",
    "orare": "orar",
    "orarei": "orar",
    "orarele": "orar",
    "orarelor": "orar",
    "orari": "orar",
    "orarii": "orar",
    "orarilor": "orar",
    "orarul": "orar",
    "orarului": "orar",
    "or.": "oraș",
    "orașe": "oraș",
    "orașele": "oraș",
    "orașelor": "oraș",
    "orașul": "oraș",
    "orașului": "oraș",
    "orășanca": "orășancă",
    "orășeanul": "orășean",
    "orășeanului": "orășean",
    "orășeni": "orășean",
    "orășenii": "orășean",
    "orășenilor": "orășean",
    "orășeanca": "orășeancă",
    "orășence": "orășeancă",
    "orășencei": "orășeancă",
    "orășencele": "orășeancă",
    "orășencelor": "orășeancă",
    "orășele": "orășel",
    "orășelele": "orășel",
    "orășelelor": "orășel",
    "orășelul": "orășel",
    "orășelului": "orășel",
    "orășeneasca": "orășenesc",
    "orășenească": "orășenesc",
    "orășenescul": "orășenesc",
    "orășenescului": "orășenesc",
    "orășenești": "orășenesc",
    "orășeneștii": "orășenesc",
    "orășeneștile": "orășenesc",
    "orășeneștilor": "orășenesc",
    "Orăștiei": "Orăștie",
    "orătania": "orătanie",
    "orătăniei": "orătanie",
    "orătănii": "orătanie",
    "orătăniile": "orătanie",
    "orătăniilor": "orătanie",
    "orația": "orație",
    "orației": "orație",
    "orații": "orație",
    "orațiile": "orație",
    "orațiilor": "orație",
    "oratori": "orator",
    "oratorii": "orator",
    "oratorilor": "orator",
    "oratorul": "orator",
    "oratorului": "orator",
    "oratorica": "oratoric",
    "oratorică": "oratoric",
    "oratorice": "oratoric",
    "oratoricei": "oratoric",
    "oratoricele": "oratoric",
    "oratoricelor": "oratoric",
    "oratorici": "oratoric",
    "oratoricii": "oratoric",
    "oratoricilor": "oratoric",
    "oratoricul": "oratoric",
    "oratoricului": "oratoric",
    "oratoria": "oratorie",
    "oratoriei": "oratorie",
    "oratorii": "oratorie",
    "oratoriile": "oratorie",
    "oratoriilor": "oratorie",
    "oratoria": "oratoriu",
    "oratorie": "oratoriu",
    "oratoriei": "oratoriu",
    "oratorii": "oratoriu",
    "oratoriii": "oratoriu",
    "oratoriile": "oratoriu",
    "oratoriilor": "oratoriu",
    "oratoriul": "oratoriu",
    "oratoriului": "oratoriu",
    "oarba": "orb",
    "oarbă": "orb",
    "oarbe": "orb",
    "oarbei": "orb",
    "oarbele": "orb",
    "oarbelor": "orb",
    "orbi": "orb",
    "orbii": "orb",
    "orbilor": "orb",
    "orbu'": "orb",
    "orbul": "orb",
    "orbului": "orb",
    "nemaiorbecăind": "orbecăi",
    "nemaiorbecăindu": "orbecăi",
    "neorbecăind": "orbecăi",
    "neorbecăindu": "orbecăi",
    "orbecăia": "orbecăi",
    "orbecăiai": "orbecăi",
    "orbecăiam": "orbecăi",
    "orbecăiați": "orbecăi",
    "orbecăiau": "orbecăi",
    "orbecăie": "orbecăi",
    "orbecăii": "orbecăi",
    "orbecăim": "orbecăi",
    "orbecăind": "orbecăi",
    "orbecăindu": "orbecăi",
    "orbecăiră": "orbecăi",
    "orbecăirăm": "orbecăi",
    "orbecăirăți": "orbecăi",
    "orbecăise": "orbecăi",
    "orbecăisem": "orbecăi",
    "orbecăiseră": "orbecăi",
    "orbecăiserăm": "orbecăi",
    "orbecăiserăți": "orbecăi",
    "orbecăiseși": "orbecăi",
    "orbecăiși": "orbecăi",
    "orbecăit": "orbecăi",
    "orbecăiți": "orbecăi",
    "orbecăită": "orbecăit",
    "orbecăite": "orbecăit",
    "orbecăiți": "orbecăit",
    "orbeasca": "orbesc",
    "orbească": "orbesc",
    "orbescul": "orbesc",
    "orbescului": "orbesc",
    "orbești": "orbesc",
    "orbeștii": "orbesc",
    "orbeștile": "orbesc",
    "orbeștilor": "orbesc",
    "orbeața": "orbeț",
    "orbeață": "orbeț",
    "orbețe": "orbeț",
    "orbeței": "orbeț",
    "orbețele": "orbeț",
    "orbețelor": "orbeț",
    "orbeți": "orbeț",
    "orbeții": "orbeț",
    "orbeților": "orbeț",
    "orbețul": "orbeț",
    "orbețului": "orbeț",
    "orbetele": "orbete",
    "orbetelui": "orbete",
    "orbeți": "orbete",
    "orbeții": "orbete",
    "orbeților": "orbete",
    "nemaiorbind": "orbi",
    "nemaiorbindu": "orbi",
    "neorbind": "orbi",
    "neorbindu": "orbi",
    "orbea": "orbi",
    "orbeai": "orbi",
    "orbeam": "orbi",
    "orbească": "orbi",
    "orbeați": "orbi",
    "orbeau": "orbi",
    "orbesc": "orbi",
    "orbește": "orbi",
    "orbești": "orbi",
    "orbii": "orbi",
    "orbim": "orbi",
    "orbind": "orbi",
    "orbindu": "orbi",
    "orbiră": "orbi",
    "orbirăm": "orbi",
    "orbirăți": "orbi",
    "orbise": "orbi",
    "orbisem": "orbi",
    "orbiseră": "orbi",
    "orbiserăm": "orbi",
    "orbiserăți": "orbi",
    "orbiseși": "orbi",
    "orbiși": "orbi",
    "orbit": "orbi",
    "orbiți": "orbi",
    "orbiculara": "orbicular",
    "orbiculară": "orbicular",
    "orbiculare": "orbicular",
    "orbicularei": "orbicular",
    "orbicularele": "orbicular",
    "orbicularelor": "orbicular",
    "orbiculari": "orbicular",
    "orbicularii": "orbicular",
    "orbicularilor": "orbicular",
    "orbicularul": "orbicular",
    "orbicularului": "orbicular",
    "orbirea": "orbire",
    "orbiri": "orbire",
    "orbirii": "orbire",
    "orbirile": "orbire",
    "orbirilor": "orbire",
    "orbită": "orbit",
    "orbite": "orbit",
    "orbiți": "orbit",
    "orbita": "orbită",
    "orbite": "orbită",
    "orbitei": "orbită",
    "orbitele": "orbită",
    "orbitelor": "orbită",
    "orbitala": "orbital",
    "orbitală": "orbital",
    "orbitale": "orbital",
    "orbitalei": "orbital",
    "orbitalele": "orbital",
    "orbitalelor": "orbital",
    "orbitali": "orbital",
    "orbitalii": "orbital",
    "orbitalilor": "orbital",
    "orbitalul": "orbital",
    "orbitalului": "orbital",
    "orbitara": "orbitar",
    "orbitară": "orbitar",
    "orbitare": "orbitar",
    "orbitarei": "orbitar",
    "orbitarele": "orbitar",
    "orbitarelor": "orbitar",
    "orbitari": "orbitar",
    "orbitarii": "orbitar",
    "orbitarilor": "orbitar",
    "orbitarul": "orbitar",
    "orbitarului": "orbitar",
    "orbitoare": "orbitor",
    "orbitoarea": "orbitor",
    "orbitoarei": "orbitor",
    "orbitoarele": "orbitor",
    "orbitoarelor": "orbitor",
    "orbitori": "orbitor",
    "orbitorii": "orbitor",
    "orbitorilor": "orbitor",
    "orbitorul": "orbitor",
    "orbitorului": "orbitor",
    "nemaiorchestrând": "orchestra",
    "nemaiorchestrându": "orchestra",
    "neorchestrând": "orchestra",
    "neorchestrându": "orchestra",
    "orchestră": "orchestra",
    "orchestrai": "orchestra",
    "orchestram": "orchestra",
    "orchestrăm": "orchestra",
    "orchestrând": "orchestra",
    "orchestrându": "orchestra",
    "orchestrară": "orchestra",
    "orchestrarăm": "orchestra",
    "orchestrarăți": "orchestra",
    "orchestrase": "orchestra",
    "orchestrasem": "orchestra",
    "orchestraseră": "orchestra",
    "orchestraserăm": "orchestra",
    "orchestraserăți": "orchestra",
    "orchestraseși": "orchestra",
    "orchestrași": "orchestra",
    "orchestrat": "orchestra",
    "orchestrați": "orchestra",
    "orchestrau": "orchestra",
    "orchestrează": "orchestra",
    "orchestrez": "orchestra",
    "orchestreze": "orchestra",
    "orchestrezi": "orchestra",
    "orchestra": "orchestră",
    "orchestre": "orchestră",
    "orchestrei": "orchestră",
    "orchestrele": "orchestră",
    "orchestrelor": "orchestră",
    "orchestrala": "orchestral",
    "orchestrală": "orchestral",
    "orchestrale": "orchestral",
    "orchestralei": "orchestral",
    "orchestralele": "orchestral",
    "orchestralelor": "orchestral",
    "orchestrali": "orchestral",
    "orchestralii": "orchestral",
    "orchestralilor": "orchestral",
    "orchestralul": "orchestral",
    "orchestralului": "orchestral",
    "orchestrată": "orchestrat",
    "orchestrate": "orchestrat",
    "orchestrați": "orchestrat",
    "orchestrația": "orchestrație",
    "orchestrației": "orchestrație",
    "orchestrații": "orchestrație",
    "orchestrațiile": "orchestrație",
    "orchestrațiilor": "orchestrație",
    "ordia": "ordie",
    "ordiei": "ordie",
    "ordii": "ordie",
    "ordiile": "ordie",
    "ordiilor": "ordie",
    "ordine": "ordin",
    "ordinele": "ordin",
    "ordinelor": "ordin",
    "ordinul": "ordin",
    "ordinului": "ordin",
    "ordinara": "ordinar",
    "ordinară": "ordinar",
    "ordinare": "ordinar",
    "ordinarei": "ordinar",
    "ordinarele": "ordinar",
    "ordinarelor": "ordinar",
    "ordinari": "ordinar",
    "ordinarii": "ordinar",
    "ordinarilor": "ordinar",
    "ordinarul": "ordinar",
    "ordinarului": "ordinar",
    "ordinatoare": "ordinator",
    "ordinatoarele": "ordinator",
    "ordinatoarelor": "ordinator",
    "ordinatorul": "ordinator",
    "ordinatorului": "ordinator",
    "ordinea": "ordine",
    "ordini": "ordine",
    "ordinii": "ordine",
    "ordinile": "ordine",
    "ordinilor": "ordine",
    "nemaiordonând": "ordona",
    "nemaiordonându": "ordona",
    "neordonând": "ordona",
    "neordonându": "ordona",
    "ordon": "ordona",
    "ordonă": "ordona",
    "ordonai": "ordona",
    "ordonam": "ordona",
    "ordonăm": "ordona",
    "ordonând": "ordona",
    "ordonându": "ordona",
    "ordonară": "ordona",
    "ordonarăm": "ordona",
    "ordonarăți": "ordona",
    "ordonase": "ordona",
    "ordonasem": "ordona",
    "ordonaseră": "ordona",
    "ordonaserăm": "ordona",
    "ordonaserăți": "ordona",
    "ordonaseși": "ordona",
    "ordonași": "ordona",
    "ordonat": "ordona",
    "ordonați": "ordona",
    "ordonau": "ordona",
    "ordone": "ordona",
    "ordonează": "ordona",
    "ordonez": "ordona",
    "ordoneze": "ordona",
    "ordonezi": "ordona",
    "ordoni": "ordona",
    "ordonanța": "ordonanță",
    "ordonanțe": "ordonanță",
    "ordonanței": "ordonanță",
    "ordonanțele": "ordonanță",
    "ordonanțelor": "ordonanță",
    "ordonarea": "ordonare",
    "ordonări": "ordonare",
    "ordonării": "ordonare",
    "ordonările": "ordonare",
    "ordonărilor": "ordonare",
    "ordonata": "ordonat",
    "ordonată": "ordonat",
    "ordonate": "ordonat",
    "ordonatei": "ordonat",
    "ordonatele": "ordonat",
    "ordonatelor": "ordonat",
    "ordonați": "ordonat",
    "ordonații": "ordonat",
    "ordonaților": "ordonat",
    "ordonatul": "ordonat",
    "ordonatului": "ordonat",
    "ordonata": "ordonată",
    "ordonate": "ordonată",
    "ordonatei": "ordonată",
    "ordonatele": "ordonată",
    "ordonatelor": "ordonată",
    "ordonatoarea": "ordonatoare",
    "ordonatoarei": "ordonatoare",
    "ordonatoarele": "ordonatoare",
    "ordonatoarelor": "ordonatoare",
    "ordonatori": "ordonator",
    "ordonatorii": "ordonator",
    "ordonatorilor": "ordonator",
    "ordonatorul": "ordonator",
    "ordonatorului": "ordonator",
    "ordoviciana": "ordovician",
    "ordoviciană": "ordovician",
    "ordovicianul": "ordovician",
    "ordovicianului": "ordovician",
    "ordoviciene": "ordovician",
    "ordovicienei": "ordovician",
    "ordovicienele": "ordovician",
    "ordovicienelor": "ordovician",
    "ordovicieni": "ordovician",
    "ordovicienii": "ordovician",
    "ordovicienilor": "ordovician",
    "oreionul": "oreion",
    "oreionului": "oreion",
    "orezul": "orez",
    "orezului": "orez",
    "orezăria": "orezărie",
    "orezăriei": "orezărie",
    "orezării": "orezărie",
    "orezăriile": "orezărie",
    "orezăriilor": "orezărie",
    "orfana": "orfan",
    "orfană": "orfan",
    "orfane": "orfan",
    "orfanei": "orfan",
    "orfanele": "orfan",
    "orfanelor": "orfan",
    "orfani": "orfan",
    "orfanii": "orfan",
    "orfanilor": "orfan",
    "orfanul": "orfan",
    "orfanului": "orfan",
    "orfana": "orfană",
    "orfane": "orfană",
    "orfanei": "orfană",
    "orfanele": "orfană",
    "orfanelor": "orfană",
    "orfelina": "orfelin",
    "orfelină": "orfelin",
    "orfeline": "orfelin",
    "orfelinei": "orfelin",
    "orfelinele": "orfelin",
    "orfelinelor": "orfelin",
    "orfelini": "orfelin",
    "orfelinii": "orfelin",
    "orfelinilor": "orfelin",
    "orfelinul": "orfelin",
    "orfelinului": "orfelin",
    "orfelinate": "orfelinat",
    "orfelinatele": "orfelinat",
    "orfelinatelor": "orfelinat",
    "orfelinatul": "orfelinat",
    "orfelinatului": "orfelinat",
    "orga": "orgă",
    "orgi": "orgă",
    "orgii": "orgă",
    "orgile": "orgă",
    "orgilor": "orgă",
    "organe": "organ",
    "organele": "organ",
    "organelor": "organ",
    "organul": "organ",
    "organului": "organ",
    "organdiul": "organdi",
    "organdiului": "organdi",
    "organica": "organic",
    "organică": "organic",
    "organice": "organic",
    "organicei": "organic",
    "organicele": "organic",
    "organicelor": "organic",
    "organici": "organic",
    "organicii": "organic",
    "organicilor": "organic",
    "organicul": "organic",
    "organicului": "organic",
    "organicista": "organicist",
    "organicistă": "organicist",
    "organiciste": "organicist",
    "organicistei": "organicist",
    "organicistele": "organicist",
    "organicistelor": "organicist",
    "organiciști": "organicist",
    "organiciștii": "organicist",
    "organiciștilor": "organicist",
    "organicistul": "organicist",
    "organicistului": "organicist",
    "organigrama": "organigramă",
    "organigrame": "organigramă",
    "organigramei": "organigramă",
    "organigramele": "organigramă",
    "organigramelor": "organigramă",
    "organisme": "organism",
    "organismele": "organism",
    "organismelor": "organism",
    "organismul": "organism",
    "organismului": "organism",
    "organiști": "organist",
    "organiștii": "organist",
    "organiștilor": "organist",
    "organistul": "organist",
    "organistului": "organist",
    "organista": "organistă",
    "organiste": "organistă",
    "organistei": "organistă",
    "organistele": "organistă",
    "organistelor": "organistă",
    "nemaiorganizând": "organiza",
    "nemaiorganizându": "organiza",
    "neorganizând": "organiza",
    "neorganizându": "organiza",
    "organiză": "organiza",
    "organizai": "organiza",
    "organizam": "organiza",
    "organizăm": "organiza",
    "organizând": "organiza",
    "organizându": "organiza",
    "organizară": "organiza",
    "organizarăm": "organiza",
    "organizarăți": "organiza",
    "organizase": "organiza",
    "organizasem": "organiza",
    "organizaseră": "organiza",
    "organizaserăm": "organiza",
    "organizaserăți": "organiza",
    "organizaseși": "organiza",
    "organizași": "organiza",
    "organizat": "organiza",
    "organizați": "organiza",
    "organizau": "organiza",
    "organizează": "organiza",
    "organizez": "organiza",
    "organizeze": "organiza",
    "organizezi": "organiza",
    "org.": "organizare",
    "organizarea": "organizare",
    "organizări": "organizare",
    "organizării": "organizare",
    "organizările": "organizare",
    "organizărilor": "organizare",
    "organizată": "organizat",
    "organizate": "organizat",
    "organizați": "organizat",
    "ONU": "Organizația_Națiunilor_Unite",
    "organizația": "organizație",
    "organizației": "organizație",
    "organizații": "organizație",
    "organizațiile": "organizație",
    "organizațiilor": "organizație",
    "organizatoarea": "organizatoare",
    "organizatoarei": "organizatoare",
    "organizatoarele": "organizatoare",
    "organizatoarelor": "organizatoare",
    "organizatoare": "organizator",
    "organizatoarea": "organizator",
    "organizatoarei": "organizator",
    "organizatoarele": "organizator",
    "organizatoarelor": "organizator",
    "organizatori": "organizator",
    "organizatorii": "organizator",
    "organizatorilor": "organizator",
    "organizatorul": "organizator",
    "organizatorului": "organizator",
    "organizatorica": "organizatoric",
    "organizatorică": "organizatoric",
    "organizatorice": "organizatoric",
    "organizatoricei": "organizatoric",
    "organizatoricele": "organizatoric",
    "organizatoricelor": "organizatoric",
    "organizatorici": "organizatoric",
    "organizatoricii": "organizatoric",
    "organizatoricilor": "organizatoric",
    "organizatoricul": "organizatoric",
    "organizatoricului": "organizatoric",
    "organogena": "organogen",
    "organogenă": "organogen",
    "organogene": "organogen",
    "organogenei": "organogen",
    "organogenele": "organogen",
    "organogenelor": "organogen",
    "organogeni": "organogen",
    "organogenii": "organogen",
    "organogenilor": "organogen",
    "organogenul": "organogen",
    "organogenului": "organogen",
    "organogeneza": "organogeneză",
    "organogeneze": "organogeneză",
    "organogenezei": "organogeneză",
    "organogenezele": "organogeneză",
    "organogenezelor": "organogeneză",
    "organografica": "organografic",
    "organografică": "organografic",
    "organografice": "organografic",
    "organograficei": "organografic",
    "organograficele": "organografic",
    "organograficelor": "organografic",
    "organografici": "organografic",
    "organograficii": "organografic",
    "organograficilor": "organografic",
    "organograficul": "organografic",
    "organograficului": "organografic",
    "organoleptica": "organoleptic",
    "organoleptică": "organoleptic",
    "organoleptice": "organoleptic",
    "organolepticei": "organoleptic",
    "organolepticele": "organoleptic",
    "organolepticelor": "organoleptic",
    "organoleptici": "organoleptic",
    "organolepticii": "organoleptic",
    "organolepticilor": "organoleptic",
    "organolepticul": "organoleptic",
    "organolepticului": "organoleptic",
    "organotropa": "organotrop",
    "organotropă": "organotrop",
    "organotrope": "organotrop",
    "organotropei": "organotrop",
    "organotropele": "organotrop",
    "organotropelor": "organotrop",
    "organotropi": "organotrop",
    "organotropii": "organotrop",
    "organotropilor": "organotrop",
    "organotropul": "organotrop",
    "organotropului": "organotrop",
    "orgasmul": "orgasm",
    "orgasmului": "orgasm",
    "orgiaca": "orgiac",
    "orgiacă": "orgiac",
    "orgiace": "orgiac",
    "orgiacei": "orgiac",
    "orgiacele": "orgiac",
    "orgiacelor": "orgiac",
    "orgiaci": "orgiac",
    "orgiacii": "orgiac",
    "orgiacilor": "orgiac",
    "orgiacul": "orgiac",
    "orgiacului": "orgiac",
    "orgiastica": "orgiastic",
    "orgiastică": "orgiastic",
    "orgiastice": "orgiastic",
    "orgiasticei": "orgiastic",
    "orgiasticele": "orgiastic",
    "orgiasticelor": "orgiastic",
    "orgiastici": "orgiastic",
    "orgiasticii": "orgiastic",
    "orgiasticilor": "orgiastic",
    "orgiasticul": "orgiastic",
    "orgiasticului": "orgiastic",
    "orgia": "orgie",
    "orgiei": "orgie",
    "orgii": "orgie",
    "orgiile": "orgie",
    "orgiilor": "orgie",
    "orgolioasa": "orgolios",
    "orgolioasă": "orgolios",
    "orgolioase": "orgolios",
    "orgolioasei": "orgolios",
    "orgolioasele": "orgolios",
    "orgolioaselor": "orgolios",
    "orgolioși": "orgolios",
    "orgolioșii": "orgolios",
    "orgolioșilor": "orgolios",
    "orgoliosul": "orgolios",
    "orgoliosului": "orgolios",
    "orgolii": "orgoliu",
    "orgoliile": "orgoliu",
    "orgoliilor": "orgoliu",
    "orgoliul": "orgoliu",
    "orgoliului": "orgoliu",
    "orhidea": "orhidee",
    "orhideei": "orhidee",
    "orhideele": "orhidee",
    "orhideelor": "orhidee",
    "or'": "ori",
    "oribila": "oribil",
    "oribilă": "oribil",
    "oribile": "oribil",
    "oribilei": "oribil",
    "oribilele": "oribil",
    "oribilelor": "oribil",
    "oribili": "oribil",
    "oribilii": "oribil",
    "oribililor": "oribil",
    "oribilul": "oribil",
    "oribilului": "oribil",
    "oricărei": "oricare",
    "oricăreia": "oricare",
    "oricăror": "oricare",
    "oricărora": "oricare",
    "oricărui": "oricare",
    "oricăruia": "oricare",
    "oricâtă": "oricât",
    "oricâte": "oricât",
    "oricâți": "oricât",
    "oricâtor": "oricât",
    "or'cine": "oricine",
    "oricui": "oricine",
    "Or.": "Orient",
    "orientul": "orient",
    "Orientului": "Orient",
    "nemaiorientând": "orienta",
    "nemaiorientându": "orienta",
    "neorientând": "orienta",
    "neorientându": "orienta",
    "orientă": "orienta",
    "orientai": "orienta",
    "orientam": "orienta",
    "orientăm": "orienta",
    "orientând": "orienta",
    "orientându": "orienta",
    "orientară": "orienta",
    "orientarăm": "orienta",
    "orientarăți": "orienta",
    "orientase": "orienta",
    "orientasem": "orienta",
    "orientaseră": "orienta",
    "orientaserăm": "orienta",
    "orientaserăți": "orienta",
    "orientaseși": "orienta",
    "orientași": "orienta",
    "orientat": "orienta",
    "orientați": "orienta",
    "orientau": "orienta",
    "orientează": "orienta",
    "orientez": "orienta",
    "orienteze": "orienta",
    "orientezi": "orienta",
    "orientabila": "orientabil",
    "orientabilă": "orientabil",
    "orientabile": "orientabil",
    "orientabilei": "orientabil",
    "orientabilele": "orientabil",
    "orientabilelor": "orientabil",
    "orientabili": "orientabil",
    "orientabilii": "orientabil",
    "orientabililor": "orientabil",
    "orientabilul": "orientabil",
    "orientabilului": "orientabil",
    "orientala": "oriental",
    "orientală": "oriental",
    "orientale": "oriental",
    "orientalei": "oriental",
    "orientalele": "oriental",
    "orientalelor": "oriental",
    "orientali": "oriental",
    "orientalii": "oriental",
    "orientalilor": "oriental",
    "orientalul": "oriental",
    "orientalului": "oriental",
    "orientala": "orientală",
    "orientale": "orientală",
    "orientalei": "orientală",
    "orientalele": "orientală",
    "orientalelor": "orientală",
    "orientalismul": "orientalism",
    "orientalismului": "orientalism",
    "orientaliști": "orientalist",
    "orientaliștii": "orientalist",
    "orientaliștilor": "orientalist",
    "orientalistul": "orientalist",
    "orientalistului": "orientalist",
    "orientalista": "orientalistă",
    "orientaliste": "orientalistă",
    "orientalistei": "orientalistă",
    "orientalistele": "orientalistă",
    "orientalistelor": "orientalistă",
    "orientarea": "orientare",
    "orientări": "orientare",
    "orientării": "orientare",
    "orientările": "orientare",
    "orientărilor": "orientare",
    "orientată": "orientat",
    "orientate": "orientat",
    "orientați": "orientat",
    "orientativa": "orientativ",
    "orientativă": "orientativ",
    "orientative": "orientativ",
    "orientativei": "orientativ",
    "orientativele": "orientativ",
    "orientativelor": "orientativ",
    "orientativi": "orientativ",
    "orientativii": "orientativ",
    "orientativilor": "orientativ",
    "orientativul": "orientativ",
    "orientativului": "orientativ",
    "orientatoare": "orientator",
    "orientatoarea": "orientator",
    "orientatoarei": "orientator",
    "orientatoarele": "orientator",
    "orientatoarelor": "orientator",
    "orientatori": "orientator",
    "orientatorii": "orientator",
    "orientatorilor": "orientator",
    "orientatorul": "orientator",
    "orientatorului": "orientator",
    "orificii": "orificiu",
    "orificiile": "orificiu",
    "orificiilor": "orificiu",
    "orificiul": "orificiu",
    "orificiului": "orificiu",
    "originala": "original",
    "originală": "original",
    "originale": "original",
    "originalei": "original",
    "originalele": "original",
    "originalelor": "original",
    "originali": "original",
    "originalii": "original",
    "originalilor": "original",
    "originalul": "original",
    "originalului": "original",
    "originalitatea": "originalitate",
    "originalități": "originalitate",
    "originalității": "originalitate",
    "originara": "originar",
    "originară": "originar",
    "originare": "originar",
    "originarei": "originar",
    "originarele": "originar",
    "originarelor": "originar",
    "originari": "originar",
    "originarii": "originar",
    "originarilor": "originar",
    "originarul": "originar",
    "originarului": "originar",
    "originea": "origine",
    "origini": "origine",
    "originii": "origine",
    "originile": "origine",
    "originilor": "origine",
    "nemaioripilând": "oripila",
    "nemaioripilându": "oripila",
    "neoripilând": "oripila",
    "neoripilându": "oripila",
    "oripilă": "oripila",
    "oripilai": "oripila",
    "oripilam": "oripila",
    "oripilăm": "oripila",
    "oripilând": "oripila",
    "oripilându": "oripila",
    "oripilară": "oripila",
    "oripilarăm": "oripila",
    "oripilarăți": "oripila",
    "oripilase": "oripila",
    "oripilasem": "oripila",
    "oripilaseră": "oripila",
    "oripilaserăm": "oripila",
    "oripilaserăți": "oripila",
    "oripilaseși": "oripila",
    "oripilași": "oripila",
    "oripilat": "oripila",
    "oripilați": "oripila",
    "oripilau": "oripila",
    "oripilează": "oripila",
    "oripilez": "oripila",
    "oripileze": "oripila",
    "oripilezi": "oripila",
    "oripilanta": "oripilant",
    "oripilantă": "oripilant",
    "oripilante": "oripilant",
    "oripilantei": "oripilant",
    "oripilantele": "oripilant",
    "oripilantelor": "oripilant",
    "oripilanți": "oripilant",
    "oripilanții": "oripilant",
    "oripilanților": "oripilant",
    "oripilantul": "oripilant",
    "oripilantului": "oripilant",
    "oripilată": "oripilat",
    "oripilate": "oripilat",
    "oripilați": "oripilat",
    "orișicărei": "orișicare",
    "orișicăreia": "orișicare",
    "orișicărui": "orișicare",
    "orișicăruia": "orișicare",
    "orișicâtă": "orișicât",
    "orișicâte": "orișicât",
    "orișicâți": "orișicât",
    "orișicâtor": "orișicât",
    "orișicui": "orișicine",
    "orizontul": "orizont",
    "orizontului": "orizont",
    "orizonturi": "orizont",
    "orizonturile": "orizont",
    "orizonturilor": "orizont",
    "orizontala": "orizontal",
    "orizontală": "orizontal",
    "orizontale": "orizontal",
    "orizontalei": "orizontal",
    "orizontalele": "orizontal",
    "orizontalelor": "orizontal",
    "orizontali": "orizontal",
    "orizontalii": "orizontal",
    "orizontalilor": "orizontal",
    "orizontalul": "orizontal",
    "orizontalului": "orizontal",
    "orizontala": "orizontală",
    "orizontale": "orizontală",
    "orizontalei": "orizontală",
    "orizontalele": "orizontală",
    "orizontalelor": "orizontală",
    "orizontalitatea": "orizontalitate",
    "orizontalități": "orizontalitate",
    "orizontalității": "orizontalitate",
    "nemaiornând": "orna",
    "nemaiornându": "orna",
    "neornând": "orna",
    "neornându": "orna",
    "ornă": "orna",
    "ornai": "orna",
    "ornam": "orna",
    "ornăm": "orna",
    "ornând": "orna",
    "ornându": "orna",
    "ornară": "orna",
    "ornarăm": "orna",
    "ornarăți": "orna",
    "ornase": "orna",
    "ornasem": "orna",
    "ornaseră": "orna",
    "ornaserăm": "orna",
    "ornaserăți": "orna",
    "ornaseși": "orna",
    "ornași": "orna",
    "ornat": "orna",
    "ornați": "orna",
    "ornau": "orna",
    "ornează": "orna",
    "ornez": "orna",
    "orneze": "orna",
    "ornezi": "orna",
    "ornamente": "ornament",
    "ornamentele": "ornament",
    "ornamentelor": "ornament",
    "ornamentul": "ornament",
    "ornamentului": "ornament",
    "nemaiornamentând": "ornamenta",
    "nemaiornamentându": "ornamenta",
    "neornamentând": "ornamenta",
    "neornamentându": "ornamenta",
    "ornamentă": "ornamenta",
    "ornamentai": "ornamenta",
    "ornamentam": "ornamenta",
    "ornamentăm": "ornamenta",
    "ornamentând": "ornamenta",
    "ornamentându": "ornamenta",
    "ornamentară": "ornamenta",
    "ornamentarăm": "ornamenta",
    "ornamentarăți": "ornamenta",
    "ornamentase": "ornamenta",
    "ornamentasem": "ornamenta",
    "ornamentaseră": "ornamenta",
    "ornamentaserăm": "ornamenta",
    "ornamentaserăți": "ornamenta",
    "ornamentaseși": "ornamenta",
    "ornamentași": "ornamenta",
    "ornamentat": "ornamenta",
    "ornamentați": "ornamenta",
    "ornamentau": "ornamenta",
    "ornamentează": "ornamenta",
    "ornamentez": "ornamenta",
    "ornamenteze": "ornamenta",
    "ornamentezi": "ornamenta",
    "ornamentala": "ornamental",
    "ornamentală": "ornamental",
    "ornamentale": "ornamental",
    "ornamentalei": "ornamental",
    "ornamentalele": "ornamental",
    "ornamentalelor": "ornamental",
    "ornamentali": "ornamental",
    "ornamentalii": "ornamental",
    "ornamentalilor": "ornamental",
    "ornamentalul": "ornamental",
    "ornamentalului": "ornamental",
    "ornamentată": "ornamentat",
    "ornamentate": "ornamentat",
    "ornamentați": "ornamentat",
    "ornamentația": "ornamentație",
    "ornamentației": "ornamentație",
    "ornamentații": "ornamentație",
    "ornamentațiile": "ornamentație",
    "ornamentațiilor": "ornamentație",
    "ornanta": "ornant",
    "ornantă": "ornant",
    "ornante": "ornant",
    "ornantei": "ornant",
    "ornantele": "ornant",
    "ornantelor": "ornant",
    "ornanți": "ornant",
    "ornanții": "ornant",
    "ornanților": "ornant",
    "ornantul": "ornant",
    "ornantului": "ornant",
    "ornată": "ornat",
    "ornate": "ornat",
    "ornați": "ornat",
    "ornice": "ornic",
    "ornicele": "ornic",
    "ornicelor": "ornic",
    "ornicul": "ornic",
    "ornicului": "ornic",
    "ornitologi": "ornitolog",
    "ornitologii": "ornitolog",
    "ornitologilor": "ornitolog",
    "ornitologul": "ornitolog",
    "ornitologului": "ornitolog",
    "ornitologica": "ornitologic",
    "ornitologică": "ornitologic",
    "ornitologice": "ornitologic",
    "ornitologicei": "ornitologic",
    "ornitologicele": "ornitologic",
    "ornitologicelor": "ornitologic",
    "ornitologici": "ornitologic",
    "ornitologicii": "ornitologic",
    "ornitologicilor": "ornitologic",
    "ornitologicul": "ornitologic",
    "ornitologicului": "ornitologic",
    "ornitologia": "ornitologie",
    "ornitologiei": "ornitologie",
    "ornitologii": "ornitologie",
    "ornitologiile": "ornitologie",
    "ornitologiilor": "ornitologie",
    "ornitorinci": "ornitorinc",
    "ornitorincii": "ornitorinc",
    "ornitorincilor": "ornitorinc",
    "ornitorincul": "ornitorinc",
    "ornitorincului": "ornitorinc",
    "oroarea": "oroare",
    "orori": "oroare",
    "ororii": "oroare",
    "ororile": "oroare",
    "ororilor": "oroare",
    "orogene": "orogen",
    "orogenele": "orogen",
    "orogenelor": "orogen",
    "orogenul": "orogen",
    "orogenului": "orogen",
    "orogenetica": "orogenetic",
    "orogenetică": "orogenetic",
    "orogenetice": "orogenetic",
    "orogeneticei": "orogenetic",
    "orogeneticele": "orogenetic",
    "orogeneticelor": "orogenetic",
    "orogenetici": "orogenetic",
    "orogeneticii": "orogenetic",
    "orogeneticilor": "orogenetic",
    "orogeneticul": "orogenetic",
    "orogeneticului": "orogenetic",
    "orogeneza": "orogeneză",
    "orogeneze": "orogeneză",
    "orogenezei": "orogeneză",
    "orogenezele": "orogeneză",
    "orogenezelor": "orogeneză",
    "orogenica": "orogenic",
    "orogenică": "orogenic",
    "orogenice": "orogenic",
    "orogenicei": "orogenic",
    "orogenicele": "orogenic",
    "orogenicelor": "orogenic",
    "orogenici": "orogenic",
    "orogenicii": "orogenic",
    "orogenicilor": "orogenic",
    "orogenicul": "orogenic",
    "orogenicului": "orogenic",
    "orografi": "orograf",
    "orografii": "orograf",
    "orografilor": "orograf",
    "orograful": "orograf",
    "orografului": "orograf",
    "orografica": "orografic",
    "orografică": "orografic",
    "orografice": "orografic",
    "orograficei": "orografic",
    "orograficele": "orografic",
    "orograficelor": "orografic",
    "orografici": "orografic",
    "orograficii": "orografic",
    "orograficilor": "orografic",
    "orograficul": "orografic",
    "orograficului": "orografic",
    "orohidrografica": "orohidrografic",
    "orohidrografică": "orohidrografic",
    "orohidrografice": "orohidrografic",
    "orohidrograficei": "orohidrografic",
    "orohidrograficele": "orohidrografic",
    "orohidrograficelor": "orohidrografic",
    "orohidrografici": "orohidrografic",
    "orohidrograficii": "orohidrografic",
    "orohidrograficilor": "orohidrografic",
    "orohidrograficul": "orohidrografic",
    "orohidrograficului": "orohidrografic",
    "orologii": "orologiu",
    "orologiile": "orologiu",
    "orologiilor": "orologiu",
    "orologiul": "orologiu",
    "orologiului": "orologiu",
    "nemaioropsind": "oropsi",
    "nemaioropsindu": "oropsi",
    "neoropsind": "oropsi",
    "neoropsindu": "oropsi",
    "oropsea": "oropsi",
    "oropseai": "oropsi",
    "oropseam": "oropsi",
    "oropsească": "oropsi",
    "oropseați": "oropsi",
    "oropseau": "oropsi",
    "oropsesc": "oropsi",
    "oropsește": "oropsi",
    "oropsești": "oropsi",
    "oropsii": "oropsi",
    "oropsim": "oropsi",
    "oropsind": "oropsi",
    "oropsindu": "oropsi",
    "oropsiră": "oropsi",
    "oropsirăm": "oropsi",
    "oropsirăți": "oropsi",
    "oropsise": "oropsi",
    "oropsisem": "oropsi",
    "oropsiseră": "oropsi",
    "oropsiserăm": "oropsi",
    "oropsiserăți": "oropsi",
    "oropsiseși": "oropsi",
    "oropsiși": "oropsi",
    "oropsit": "oropsi",
    "oropsiți": "oropsi",
    "oropsită": "oropsit",
    "oropsite": "oropsit",
    "oropsiți": "oropsit",
    "oropsiții": "oropsit",
    "oropsiților": "oropsit",
    "oropsitul": "oropsit",
    "oropsitului": "oropsit",
    "oropsita": "oropsită",
    "oropsite": "oropsită",
    "oropsitei": "oropsită",
    "oropsitele": "oropsită",
    "oropsitelor": "oropsită",
    "orșoveana": "orșovean",
    "orșoveană": "orșovean",
    "orșoveanul": "orșovean",
    "orșoveanului": "orșovean",
    "orșovene": "orșovean",
    "orșovenei": "orșovean",
    "orșovenele": "orșovean",
    "orșovenelor": "orșovean",
    "orșoveni": "orșovean",
    "orșovenii": "orșovean",
    "orșovenilor": "orșovean",
    "orți": "ort",
    "orții": "ort",
    "orților": "ort",
    "ortul": "ort",
    "ortului": "ort",
    "ortaci": "ortac",
    "ortacii": "ortac",
    "ortacilor": "ortac",
    "ortacul": "ortac",
    "ortacului": "ortac",
    "ortica": "ortic",
    "ortică": "ortic",
    "ortice": "ortic",
    "orticei": "ortic",
    "orticele": "ortic",
    "orticelor": "ortic",
    "ortici": "ortic",
    "orticii": "ortic",
    "orticilor": "ortic",
    "orticul": "ortic",
    "orticului": "ortic",
    "ortocentrica": "ortocentric",
    "ortocentrică": "ortocentric",
    "ortocentrice": "ortocentric",
    "ortocentricei": "ortocentric",
    "ortocentricele": "ortocentric",
    "ortocentricelor": "ortocentric",
    "ortocentrici": "ortocentric",
    "ortocentricii": "ortocentric",
    "ortocentricilor": "ortocentric",
    "ortocentricul": "ortocentric",
    "ortocentricului": "ortocentric",
    "ortocentre": "ortocentru",
    "ortocentrele": "ortocentru",
    "ortocentrelor": "ortocentru",
    "ortocentrul": "ortocentru",
    "ortocentrului": "ortocentru",
    "ortocromatica": "ortocromatic",
    "ortocromatică": "ortocromatic",
    "ortocromatice": "ortocromatic",
    "ortocromaticei": "ortocromatic",
    "ortocromaticele": "ortocromatic",
    "ortocromaticelor": "ortocromatic",
    "ortocromatici": "ortocromatic",
    "ortocromaticii": "ortocromatic",
    "ortocromaticilor": "ortocromatic",
    "ortocromaticul": "ortocromatic",
    "ortocromaticului": "ortocromatic",
    "ortodiagonala": "ortodiagonal",
    "ortodiagonală": "ortodiagonal",
    "ortodiagonale": "ortodiagonal",
    "ortodiagonalei": "ortodiagonal",
    "ortodiagonalele": "ortodiagonal",
    "ortodiagonalelor": "ortodiagonal",
    "ortodiagonali": "ortodiagonal",
    "ortodiagonalii": "ortodiagonal",
    "ortodiagonalilor": "ortodiagonal",
    "ortodiagonalul": "ortodiagonal",
    "ortodiagonalului": "ortodiagonal",
    "ortodocși": "ortodox",
    "ortodocșii": "ortodox",
    "ortodocșilor": "ortodox",
    "ortodoxa": "ortodox",
    "ortodoxă": "ortodox",
    "ortodoxe": "ortodox",
    "ortodoxei": "ortodox",
    "ortodoxele": "ortodox",
    "ortodoxelor": "ortodox",
    "ortodoxul": "ortodox",
    "ortodoxului": "ortodox",
    "ortodoxa": "ortodoxă",
    "ortodoxe": "ortodoxă",
    "ortodoxei": "ortodoxă",
    "ortodoxele": "ortodoxă",
    "ortodoxelor": "ortodoxă",
    "ortodoxia": "ortodoxie",
    "ortodoxiei": "ortodoxie",
    "ortodoxii": "ortodoxie",
    "ortodoxismul": "ortodoxism",
    "ortodoxismului": "ortodoxism",
    "ortoedrica": "ortoedric",
    "ortoedrică": "ortoedric",
    "ortoedrice": "ortoedric",
    "ortoedricei": "ortoedric",
    "ortoedricele": "ortoedric",
    "ortoedricelor": "ortoedric",
    "ortoedrici": "ortoedric",
    "ortoedricii": "ortoedric",
    "ortoedricilor": "ortoedric",
    "ortoedricul": "ortoedric",
    "ortoedricului": "ortoedric",
    "ortoepica": "ortoepic",
    "ortoepică": "ortoepic",
    "ortoepice": "ortoepic",
    "ortoepicei": "ortoepic",
    "ortoepicele": "ortoepic",
    "ortoepicelor": "ortoepic",
    "ortoepici": "ortoepic",
    "ortoepicii": "ortoepic",
    "ortoepicilor": "ortoepic",
    "ortoepicul": "ortoepic",
    "ortoepicului": "ortoepic",
    "ortoepia": "ortoepie",
    "ortoepiei": "ortoepie",
    "ortoepii": "ortoepie",
    "ortoepiile": "ortoepie",
    "ortoepiilor": "ortoepie",
    "ortofonica": "ortofonic",
    "ortofonică": "ortofonic",
    "ortofonice": "ortofonic",
    "ortofonicei": "ortofonic",
    "ortofonicele": "ortofonic",
    "ortofonicelor": "ortofonic",
    "ortofonici": "ortofonic",
    "ortofonicii": "ortofonic",
    "ortofonicilor": "ortofonic",
    "ortofonicul": "ortofonic",
    "ortofonicului": "ortofonic",
    "ortofosforica": "ortofosforic",
    "ortofosforică": "ortofosforic",
    "ortofosforice": "ortofosforic",
    "ortofosforicei": "ortofosforic",
    "ortofosforicele": "ortofosforic",
    "ortofosforicelor": "ortofosforic",
    "ortofosforici": "ortofosforic",
    "ortofosforicii": "ortofosforic",
    "ortofosforicilor": "ortofosforic",
    "ortofosforicul": "ortofosforic",
    "ortofosforicului": "ortofosforic",
    "ortogonala": "ortogonal",
    "ortogonală": "ortogonal",
    "ortogonale": "ortogonal",
    "ortogonalei": "ortogonal",
    "ortogonalele": "ortogonal",
    "ortogonalelor": "ortogonal",
    "ortogonali": "ortogonal",
    "ortogonalii": "ortogonal",
    "ortogonalilor": "ortogonal",
    "ortogonalul": "ortogonal",
    "ortogonalului": "ortogonal",
    "ortografica": "ortografic",
    "ortografică": "ortografic",
    "ortografice": "ortografic",
    "ortograficei": "ortografic",
    "ortograficele": "ortografic",
    "ortograficelor": "ortografic",
    "ortografici": "ortografic",
    "ortograficii": "ortografic",
    "ortograficilor": "ortografic",
    "ortograficul": "ortografic",
    "ortograficului": "ortografic",
    "ortografia": "ortografie",
    "ortografiei": "ortografie",
    "ortografii": "ortografie",
    "ortografiile": "ortografie",
    "ortografiilor": "ortografie",
    "ortomana": "ortoman",
    "ortomană": "ortoman",
    "ortomane": "ortoman",
    "ortomanei": "ortoman",
    "ortomanele": "ortoman",
    "ortomanelor": "ortoman",
    "ortomani": "ortoman",
    "ortomanii": "ortoman",
    "ortomanilor": "ortoman",
    "ortomanul": "ortoman",
    "ortomanului": "ortoman",
    "ortomăneasca": "ortomănesc",
    "ortomănească": "ortomănesc",
    "ortomănescul": "ortomănesc",
    "ortomănescului": "ortomănesc",
    "ortomănești": "ortomănesc",
    "ortomăneștii": "ortomănesc",
    "ortomăneștile": "ortomănesc",
    "ortomăneștilor": "ortomănesc",
    "ortopedul": "ortoped",
    "ortopedului": "ortoped",
    "ortopezi": "ortoped",
    "ortopezii": "ortoped",
    "ortopezilor": "ortoped",
    "ortopedica": "ortopedic",
    "ortopedică": "ortopedic",
    "ortopedice": "ortopedic",
    "ortopedicei": "ortopedic",
    "ortopedicele": "ortopedic",
    "ortopedicelor": "ortopedic",
    "ortopedici": "ortopedic",
    "ortopedicii": "ortopedic",
    "ortopedicilor": "ortopedic",
    "ortopedicul": "ortopedic",
    "ortopedicului": "ortopedic",
    "ortopedia": "ortopedie",
    "ortopediei": "ortopedie",
    "ortopedii": "ortopedie",
    "ortopediile": "ortopedie",
    "ortopediilor": "ortopedie",
    "ortoptere": "ortopter",
    "ortopterele": "ortopter",
    "ortopterelor": "ortopter",
    "ortopterul": "ortopter",
    "ortopterului": "ortopter",
    "ortoscopica": "ortoscopic",
    "ortoscopică": "ortoscopic",
    "ortoscopice": "ortoscopic",
    "ortoscopicei": "ortoscopic",
    "ortoscopicele": "ortoscopic",
    "ortoscopicelor": "ortoscopic",
    "ortoscopici": "ortoscopic",
    "ortoscopicii": "ortoscopic",
    "ortoscopicilor": "ortoscopic",
    "ortoscopicul": "ortoscopic",
    "ortoscopicului": "ortoscopic",
    "ortotropica": "ortotropic",
    "ortotropică": "ortotropic",
    "ortotropice": "ortotropic",
    "ortotropicei": "ortotropic",
    "ortotropicele": "ortotropic",
    "ortotropicelor": "ortotropic",
    "ortotropici": "ortotropic",
    "ortotropicii": "ortotropic",
    "ortotropicilor": "ortotropic",
    "ortotropicul": "ortotropic",
    "ortotropicului": "ortotropic",
    "orzul": "orz",
    "orzului": "orz",
    "orzoaica": "orzoaică",
    "orzoaice": "orzoaică",
    "orzoaicei": "orzoaică",
    "orzoaicele": "orzoaică",
    "orzoaicelor": "orzoaică",
    "oase": "os",
    "oasele": "os",
    "oaselor": "os",
    "osul": "os",
    "osului": "os",
    "osanale": "osana",
    "osanalei": "osana",
    "osanalele": "osana",
    "osanalelor": "osana",
    "osanaua": "osana",
    "osânda": "osândă",
    "osânde": "osândă",
    "osândei": "osândă",
    "osândele": "osândă",
    "osândelor": "osândă",
    "nemaiosândind": "osândi",
    "nemaiosândindu": "osândi",
    "neosândind": "osândi",
    "neosândindu": "osândi",
    "osândea": "osândi",
    "osândeai": "osândi",
    "osândeam": "osândi",
    "osândească": "osândi",
    "osândeați": "osândi",
    "osândeau": "osândi",
    "osândesc": "osândi",
    "osândește": "osândi",
    "osândești": "osândi",
    "osândii": "osândi",
    "osândim": "osândi",
    "osândind": "osândi",
    "osândindu": "osândi",
    "osândiră": "osândi",
    "osândirăm": "osândi",
    "osândirăți": "osândi",
    "osândise": "osândi",
    "osândisem": "osândi",
    "osândiseră": "osândi",
    "osândiserăm": "osândi",
    "osândiserăți": "osândi",
    "osândiseși": "osândi",
    "osândiși": "osândi",
    "osândit": "osândi",
    "osândiți": "osândi",
    "osândită": "osândit",
    "osândite": "osândit",
    "osândiți": "osândit",
    "osândiții": "osândit",
    "osândiților": "osândit",
    "osânditul": "osândit",
    "osânditului": "osândit",
    "osândita": "osândită",
    "osândite": "osândită",
    "osânditei": "osândită",
    "osânditele": "osândită",
    "osânditelor": "osândită",
    "osânditoare": "osânditor",
    "osânditoarea": "osânditor",
    "osânditoarei": "osânditor",
    "osânditoarele": "osânditor",
    "osânditoarelor": "osânditor",
    "osânditori": "osânditor",
    "osânditorii": "osânditor",
    "osânditorilor": "osânditor",
    "osânditorul": "osânditor",
    "osânditorului": "osânditor",
    "osânza": "osânză",
    "osânze": "osânză",
    "osânzei": "osânză",
    "osânzele": "osânză",
    "osânzelor": "osânză",
    "osârdia": "osârdie",
    "osârdiei": "osârdie",
    "osârdii": "osârdie",
    "osârdiile": "osârdie",
    "osârdiilor": "osârdie",
    "osârdnica": "osârdnic",
    "osârdnică": "osârdnic",
    "osârdnice": "osârdnic",
    "osârdnicei": "osârdnic",
    "osârdnicele": "osârdnic",
    "osârdnicelor": "osârdnic",
    "osârdnici": "osârdnic",
    "osârdnicii": "osârdnic",
    "osârdnicilor": "osârdnic",
    "osârdnicul": "osârdnic",
    "osârdnicului": "osârdnic",
    "osârduitoare": "osârduitor",
    "osârduitoarea": "osârduitor",
    "osârduitoarei": "osârduitor",
    "osârduitoarele": "osârduitor",
    "osârduitoarelor": "osârduitor",
    "osârduitori": "osârduitor",
    "osârduitorii": "osârduitor",
    "osârduitorilor": "osârduitor",
    "osârduitorul": "osârduitor",
    "osârduitorului": "osârduitor",
    "osatura": "osatură",
    "osaturi": "osatură",
    "osaturii": "osatură",
    "osaturile": "osatură",
    "osaturilor": "osatură",
    "nemaioscilând": "oscila",
    "nemaioscilându": "oscila",
    "neoscilând": "oscila",
    "neoscilându": "oscila",
    "oscilă": "oscila",
    "oscilai": "oscila",
    "oscilam": "oscila",
    "oscilăm": "oscila",
    "oscilând": "oscila",
    "oscilându": "oscila",
    "oscilară": "oscila",
    "oscilarăm": "oscila",
    "oscilarăți": "oscila",
    "oscilase": "oscila",
    "oscilasem": "oscila",
    "oscilaseră": "oscila",
    "oscilaserăm": "oscila",
    "oscilaserăți": "oscila",
    "oscilaseși": "oscila",
    "oscilași": "oscila",
    "oscilat": "oscila",
    "oscilați": "oscila",
    "oscilau": "oscila",
    "oscilează": "oscila",
    "oscilez": "oscila",
    "oscileze": "oscila",
    "oscilezi": "oscila",
    "oscilanta": "oscilant",
    "oscilantă": "oscilant",
    "oscilante": "oscilant",
    "oscilantei": "oscilant",
    "oscilantele": "oscilant",
    "oscilantelor": "oscilant",
    "oscilanți": "oscilant",
    "oscilanții": "oscilant",
    "oscilanților": "oscilant",
    "oscilantul": "oscilant",
    "oscilantului": "oscilant",
    "oscilată": "oscilat",
    "oscilate": "oscilat",
    "oscilați": "oscilat",
    "oscilația": "oscilație",
    "oscilației": "oscilație",
    "oscilații": "oscilație",
    "oscilațiile": "oscilație",
    "oscilațiilor": "oscilație",
    "oscilatoare": "oscilator",
    "oscilatoarele": "oscilator",
    "oscilatoarelor": "oscilator",
    "oscilatorul": "oscilator",
    "oscilatorului": "oscilator",
    "oscilatoria": "oscilatoriu",
    "oscilatorie": "oscilatoriu",
    "oscilatoriei": "oscilatoriu",
    "oscilatorii": "oscilatoriu",
    "oscilatoriii": "oscilatoriu",
    "oscilatoriile": "oscilatoriu",
    "oscilatoriilor": "oscilatoriu",
    "oscilatoriul": "oscilatoriu",
    "oscilatoriului": "oscilatoriu",
    "oscilografe": "oscilograf",
    "oscilografele": "oscilograf",
    "oscilografelor": "oscilograf",
    "oscilograful": "oscilograf",
    "oscilografului": "oscilograf",
    "oscilograma": "oscilogramă",
    "oscilograme": "oscilogramă",
    "oscilogramei": "oscilogramă",
    "oscilogramele": "oscilogramă",
    "oscilogramelor": "oscilogramă",
    "osciloscoape": "osciloscop",
    "osciloscoapele": "osciloscop",
    "osciloscoapelor": "osciloscop",
    "osciloscopul": "osciloscop",
    "osciloscopului": "osciloscop",
    "oșeana": "oșean",
    "oșeană": "oșean",
    "oșeanul": "oșean",
    "oșeanului": "oșean",
    "oșene": "oșean",
    "oșenei": "oșean",
    "oșenele": "oșean",
    "oșenelor": "oșean",
    "oșeni": "oșean",
    "oșenii": "oșean",
    "oșenilor": "oșean",
    "osebirea": "osebire",
    "osebiri": "osebire",
    "osebirii": "osebire",
    "osebirile": "osebire",
    "osebirilor": "osebire",
    "osebită": "osebit",
    "osebite": "osebit",
    "osebiți": "osebit",
    "oseina": "oseină",
    "oseine": "oseină",
    "oseinei": "oseină",
    "osemintele": "oseminte",
    "osemintelor": "oseminte",
    "osia": "osie",
    "osiei": "osie",
    "osii": "osie",
    "osiile": "osie",
    "osiilor": "osie",
    "nemaiosificând": "osifica",
    "nemaiosificându": "osifica",
    "neosificând": "osifica",
    "neosificându": "osifica",
    "osific": "osifica",
    "osifică": "osifica",
    "osificai": "osifica",
    "osificam": "osifica",
    "osificăm": "osifica",
    "osificând": "osifica",
    "osificându": "osifica",
    "osificară": "osifica",
    "osificarăm": "osifica",
    "osificarăți": "osifica",
    "osificase": "osifica",
    "osificasem": "osifica",
    "osificaseră": "osifica",
    "osificaserăm": "osifica",
    "osificaserăți": "osifica",
    "osificaseși": "osifica",
    "osificași": "osifica",
    "osificat": "osifica",
    "osificați": "osifica",
    "osificau": "osifica",
    "osifice": "osifica",
    "osifici": "osifica",
    "osificata": "osificat",
    "osificată": "osificat",
    "osificate": "osificat",
    "osificatei": "osificat",
    "osificatele": "osificat",
    "osificatelor": "osificat",
    "osificați": "osificat",
    "osificații": "osificat",
    "osificaților": "osificat",
    "osificatul": "osificat",
    "osificatului": "osificat",
    "osmana": "osman",
    "osmană": "osman",
    "osmane": "osman",
    "osmanei": "osman",
    "osmanele": "osman",
    "osmanelor": "osman",
    "osmani": "osman",
    "osmanii": "osman",
    "osmanilor": "osman",
    "osmanul": "osman",
    "osmanului": "osman",
    "osmanlâi": "osmanlâu",
    "osmanlâii": "osmanlâu",
    "osmanlâilor": "osmanlâu",
    "osmanlâul": "osmanlâu",
    "osmanlâului": "osmanlâu",
    "osmanlia": "osmanlâu",
    "osmanlie": "osmanlâu",
    "osmanliei": "osmanlâu",
    "osmanlii": "osmanlâu",
    "osmanliile": "osmanlâu",
    "osmanliilor": "osmanlâu",
    "osmanlia": "osmanlie",
    "osmanliei": "osmanlie",
    "osmanlii": "osmanlie",
    "osmanliile": "osmanlie",
    "osmanliilor": "osmanlie",
    "osmiul": "osmiu",
    "osmiului": "osmiu",
    "osmotica": "osmotic",
    "osmotică": "osmotic",
    "osmotice": "osmotic",
    "osmoticei": "osmotic",
    "osmoticele": "osmotic",
    "osmoticelor": "osmotic",
    "osmotici": "osmotic",
    "osmoticii": "osmotic",
    "osmoticilor": "osmotic",
    "osmoticul": "osmotic",
    "osmoticului": "osmotic",
    "osmoza": "osmoză",
    "osmoze": "osmoză",
    "osmozei": "osmoză",
    "osmozele": "osmoză",
    "osmozelor": "osmoză",
    "osoasa": "osos",
    "osoasă": "osos",
    "osoase": "osos",
    "osoasei": "osos",
    "osoasele": "osos",
    "osoaselor": "osos",
    "osoși": "osos",
    "osoșii": "osos",
    "osoșilor": "osos",
    "ososul": "osos",
    "ososului": "osos",
    "ospățul": "ospăț",
    "ospățului": "ospăț",
    "ospețe": "ospăț",
    "ospețele": "ospăț",
    "ospețelor": "ospăț",
    "nemaiospătând": "ospăta",
    "nemaiospătându": "ospăta",
    "neospătând": "ospăta",
    "neospătându": "ospăta",
    "ospătă": "ospăta",
    "ospătai": "ospăta",
    "ospătam": "ospăta",
    "ospătăm": "ospăta",
    "ospătând": "ospăta",
    "ospătându": "ospăta",
    "ospătară": "ospăta",
    "ospătarăm": "ospăta",
    "ospătarăți": "ospăta",
    "ospătase": "ospăta",
    "ospătasem": "ospăta",
    "ospătaseră": "ospăta",
    "ospătaserăm": "ospăta",
    "ospătaserăți": "ospăta",
    "ospătaseși": "ospăta",
    "ospătași": "ospăta",
    "ospătat": "ospăta",
    "ospătați": "ospăta",
    "ospătau": "ospăta",
    "ospătează": "ospăta",
    "ospătez": "ospăta",
    "ospăteze": "ospăta",
    "ospătezi": "ospăta",
    "ospătari": "ospătar",
    "ospătarii": "ospătar",
    "ospătarilor": "ospătar",
    "ospătarul": "ospătar",
    "ospătarului": "ospătar",
    "ospătăria": "ospătărie",
    "ospătăriei": "ospătărie",
    "ospătării": "ospătărie",
    "ospătăriile": "ospătărie",
    "ospătăriilor": "ospătărie",
    "ospătată": "ospătat",
    "ospătate": "ospătat",
    "ospătați": "ospătat",
    "ospătoasa": "ospătos",
    "ospătoasă": "ospătos",
    "ospătoase": "ospătos",
    "ospătoasei": "ospătos",
    "ospătoasele": "ospătos",
    "ospătoaselor": "ospătos",
    "ospătoși": "ospătos",
    "ospătoșii": "ospătos",
    "ospătoșilor": "ospătos",
    "ospătosul": "ospătos",
    "ospătosului": "ospătos",
    "ospeția": "ospeție",
    "ospeției": "ospeție",
    "ospeții": "ospeție",
    "ospețiile": "ospeție",
    "ospețiilor": "ospeție",
    "ospicii": "ospiciu",
    "ospiciile": "ospiciu",
    "ospiciilor": "ospiciu",
    "ospiciul": "ospiciu",
    "ospiciului": "ospiciu",
    "ospitaliera": "ospitalier",
    "ospitalieră": "ospitalier",
    "ospitaliere": "ospitalier",
    "ospitalierei": "ospitalier",
    "ospitalierele": "ospitalier",
    "ospitalierelor": "ospitalier",
    "ospitalieri": "ospitalier",
    "ospitalierii": "ospitalier",
    "ospitalierilor": "ospitalier",
    "ospitalierul": "ospitalier",
    "ospitalierului": "ospitalier",
    "ospitalitatea": "ospitalitate",
    "ospitalități": "ospitalitate",
    "ospitalității": "ospitalitate",
    "ostași": "ostaș",
    "ostașii": "ostaș",
    "ostașilor": "ostaș",
    "ostașul": "ostaș",
    "ostașului": "ostaș",
    "ostășeasca": "ostășesc",
    "ostășească": "ostășesc",
    "ostășescul": "ostășesc",
    "ostășescului": "ostășesc",
    "ostășești": "ostășesc",
    "ostășeștii": "ostășesc",
    "ostășeștile": "ostășesc",
    "ostășeștilor": "ostășesc",
    "ostatici": "ostatic",
    "ostaticii": "ostatic",
    "ostaticilor": "ostatic",
    "ostaticul": "ostatic",
    "ostaticului": "ostatic",
    "ostatica": "ostatică",
    "ostatice": "ostatică",
    "ostaticei": "ostatică",
    "ostaticele": "ostatică",
    "ostaticelor": "ostatică",
    "oșteanul": "oștean",
    "oșteanului": "oștean",
    "oșteni": "oștean",
    "oștenii": "oștean",
    "oștenilor": "oștean",
    "osteita": "osteită",
    "osteite": "osteită",
    "osteitei": "osteită",
    "osteitele": "osteită",
    "osteitelor": "osteită",
    "osteneala": "osteneală",
    "osteneli": "osteneală",
    "ostenelii": "osteneală",
    "ostenelile": "osteneală",
    "ostenelilor": "osteneală",
    "oșteneasca": "oștenesc",
    "oștenească": "oștenesc",
    "oștenescul": "oștenesc",
    "oștenescului": "oștenesc",
    "oștenești": "oștenesc",
    "oșteneștii": "oștenesc",
    "oșteneștile": "oștenesc",
    "oșteneștilor": "oștenesc",
    "nemaiostenind": "osteni",
    "nemaiostenindu": "osteni",
    "neostenind": "osteni",
    "neostenindu": "osteni",
    "ostenea": "osteni",
    "osteneai": "osteni",
    "osteneam": "osteni",
    "ostenească": "osteni",
    "osteneați": "osteni",
    "osteneau": "osteni",
    "ostenesc": "osteni",
    "ostenește": "osteni",
    "ostenești": "osteni",
    "ostenii": "osteni",
    "ostenim": "osteni",
    "ostenind": "osteni",
    "ostenindu": "osteni",
    "osteniră": "osteni",
    "ostenirăm": "osteni",
    "ostenirăți": "osteni",
    "ostenise": "osteni",
    "ostenisem": "osteni",
    "osteniseră": "osteni",
    "osteniserăm": "osteni",
    "osteniserăți": "osteni",
    "osteniseși": "osteni",
    "osteniși": "osteni",
    "ostenit": "osteni",
    "osteniți": "osteni",
    "ostenită": "ostenit",
    "ostenite": "ostenit",
    "osteniți": "ostenit",
    "ostenitoare": "ostenitor",
    "ostenitoarea": "ostenitor",
    "ostenitoarei": "ostenitor",
    "ostenitoarele": "ostenitor",
    "ostenitoarelor": "ostenitor",
    "ostenitori": "ostenitor",
    "ostenitorii": "ostenitor",
    "ostenitorilor": "ostenitor",
    "ostenitorul": "ostenitor",
    "ostenitorului": "ostenitor",
    "ostentația": "ostentație",
    "ostentației": "ostentație",
    "ostentații": "ostentație",
    "ostentațiile": "ostentație",
    "ostentațiilor": "ostentație",
    "ostentativa": "ostentativ",
    "ostentativă": "ostentativ",
    "ostentative": "ostentativ",
    "ostentativei": "ostentativ",
    "ostentativele": "ostentativ",
    "ostentativelor": "ostentativ",
    "ostentativi": "ostentativ",
    "ostentativii": "ostentativ",
    "ostentativilor": "ostentativ",
    "ostentativul": "ostentativ",
    "ostentativului": "ostentativ",
    "ostentatoria": "ostentatoriu",
    "ostentatorie": "ostentatoriu",
    "ostentatoriei": "ostentatoriu",
    "ostentatorii": "ostentatoriu",
    "ostentatoriii": "ostentatoriu",
    "ostentatoriile": "ostentatoriu",
    "ostentatoriilor": "ostentatoriu",
    "ostentatoriul": "ostentatoriu",
    "ostentatoriului": "ostentatoriu",
    "osteogena": "osteogen",
    "osteogenă": "osteogen",
    "osteogene": "osteogen",
    "osteogenei": "osteogen",
    "osteogenele": "osteogen",
    "osteogenelor": "osteogen",
    "osteogeni": "osteogen",
    "osteogenii": "osteogen",
    "osteogenilor": "osteogen",
    "osteogenul": "osteogen",
    "osteogenului": "osteogen",
    "osteoliți": "osteolit",
    "osteoliții": "osteolit",
    "osteoliților": "osteolit",
    "osteolitul": "osteolit",
    "osteolitului": "osteolit",
    "osteologica": "osteologic",
    "osteologică": "osteologic",
    "osteologice": "osteologic",
    "osteologicei": "osteologic",
    "osteologicele": "osteologic",
    "osteologicelor": "osteologic",
    "osteologici": "osteologic",
    "osteologicii": "osteologic",
    "osteologicilor": "osteologic",
    "osteologicul": "osteologic",
    "osteologicului": "osteologic",
    "osteologia": "osteologie",
    "osteologiei": "osteologie",
    "osteologii": "osteologie",
    "osteologiile": "osteologie",
    "osteologiilor": "osteologie",
    "ostica": "ostic",
    "ostică": "ostic",
    "ostice": "ostic",
    "osticei": "ostic",
    "osticele": "ostic",
    "osticelor": "ostic",
    "ostici": "ostic",
    "osticii": "ostic",
    "osticilor": "ostic",
    "osticul": "ostic",
    "osticului": "ostic",
    "ostila": "ostil",
    "ostilă": "ostil",
    "ostile": "ostil",
    "ostilei": "ostil",
    "ostilele": "ostil",
    "ostilelor": "ostil",
    "ostili": "ostil",
    "ostilii": "ostil",
    "ostililor": "ostil",
    "ostilul": "ostil",
    "ostilului": "ostil",
    "ostilitatea": "ostilitate",
    "ostilități": "ostilitate",
    "ostilității": "ostilitate",
    "ostilitățile": "ostilitate",
    "ostilităților": "ostilitate",
    "oștirea": "oștire",
    "oștiri": "oștire",
    "oștirii": "oștire",
    "oștirile": "oștire",
    "oștirilor": "oștire",
    "nemaiostoind": "ostoi",
    "nemaiostoindu": "ostoi",
    "neostoind": "ostoi",
    "neostoindu": "ostoi",
    "ostoia": "ostoi",
    "ostoiai": "ostoi",
    "ostoiam": "ostoi",
    "ostoiască": "ostoi",
    "ostoiați": "ostoi",
    "ostoiau": "ostoi",
    "ostoiesc": "ostoi",
    "ostoiește": "ostoi",
    "ostoiești": "ostoi",
    "ostoii": "ostoi",
    "ostoim": "ostoi",
    "ostoind": "ostoi",
    "ostoindu": "ostoi",
    "ostoiră": "ostoi",
    "ostoirăm": "ostoi",
    "ostoirăți": "ostoi",
    "ostoise": "ostoi",
    "ostoisem": "ostoi",
    "ostoiseră": "ostoi",
    "ostoiserăm": "ostoi",
    "ostoiserăți": "ostoi",
    "ostoiseși": "ostoi",
    "ostoiși": "ostoi",
    "ostoit": "ostoi",
    "ostoiți": "ostoi",
    "ostoită": "ostoit",
    "ostoite": "ostoit",
    "ostoiți": "ostoit",
    "ostracismul": "ostracism",
    "ostracismului": "ostracism",
    "nemaiostracizând": "ostraciza",
    "nemaiostracizându": "ostraciza",
    "neostracizând": "ostraciza",
    "neostracizându": "ostraciza",
    "ostraciză": "ostraciza",
    "ostracizai": "ostraciza",
    "ostracizam": "ostraciza",
    "ostracizăm": "ostraciza",
    "ostracizând": "ostraciza",
    "ostracizându": "ostraciza",
    "ostracizară": "ostraciza",
    "ostracizarăm": "ostraciza",
    "ostracizarăți": "ostraciza",
    "ostracizase": "ostraciza",
    "ostracizasem": "ostraciza",
    "ostracizaseră": "ostraciza",
    "ostracizaserăm": "ostraciza",
    "ostracizaserăți": "ostraciza",
    "ostracizaseși": "ostraciza",
    "ostracizași": "ostraciza",
    "ostracizat": "ostraciza",
    "ostracizați": "ostraciza",
    "ostracizau": "ostraciza",
    "ostracizează": "ostraciza",
    "ostracizez": "ostraciza",
    "ostracizeze": "ostraciza",
    "ostracizezi": "ostraciza",
    "ostracizarea": "ostracizare",
    "ostracizări": "ostracizare",
    "ostracizării": "ostracizare",
    "ostracizările": "ostracizare",
    "ostracizărilor": "ostracizare",
    "ostracizată": "ostracizat",
    "ostracizate": "ostracizat",
    "ostracizați": "ostracizat",
    "ostrogoți": "ostrogot",
    "ostrogoții": "ostrogot",
    "ostrogoților": "ostrogot",
    "ostrogotul": "ostrogot",
    "ostrogotului": "ostrogot",
    "ostrogota": "ostrogotă",
    "ostrogote": "ostrogotă",
    "ostrogotei": "ostrogotă",
    "ostrogotele": "ostrogotă",
    "ostrogotelor": "ostrogotă",
    "ostrogotica": "ostrogotic",
    "ostrogotică": "ostrogotic",
    "ostrogotice": "ostrogotic",
    "ostrogoticei": "ostrogotic",
    "ostrogoticele": "ostrogotic",
    "ostrogoticelor": "ostrogotic",
    "ostrogotici": "ostrogotic",
    "ostrogoticii": "ostrogotic",
    "ostrogoticilor": "ostrogotic",
    "ostrogoticul": "ostrogotic",
    "ostrogoticului": "ostrogotic",
    "ostropelul": "ostropel",
    "ostropelului": "ostropel",
    "ostropeluri": "ostropel",
    "ostropelurile": "ostropel",
    "ostropelurilor": "ostropel",
    "ostroave": "ostrov",
    "ostroavele": "ostrov",
    "ostroavelor": "ostrov",
    "ostrovul": "ostrov",
    "ostrovului": "ostrov",
    "ostroveana": "ostrovean",
    "ostroveană": "ostrovean",
    "ostroveanul": "ostrovean",
    "ostroveanului": "ostrovean",
    "ostrovene": "ostrovean",
    "ostrovenei": "ostrovean",
    "ostrovenele": "ostrovean",
    "ostrovenelor": "ostrovean",
    "ostroveni": "ostrovean",
    "ostrovenii": "ostrovean",
    "ostrovenilor": "ostrovean",
    "osuare": "osuar",
    "osuarele": "osuar",
    "osuarelor": "osuar",
    "osuarul": "osuar",
    "osuarului": "osuar",
    "oțărâtă": "oțărât",
    "oțărâte": "oțărât",
    "oțărâți": "oțărât",
    "nemaioțărând": "oțărî",
    "nemaioțărându": "oțărî",
    "neoțărând": "oțărî",
    "neoțărându": "oțărî",
    "oțăra": "oțărî",
    "oțărai": "oțărî",
    "oțărâi": "oțărî",
    "oțăram": "oțărî",
    "oțărâm": "oțărî",
    "oțărând": "oțărî",
    "oțărându": "oțărî",
    "oțărâră": "oțărî",
    "oțărârăm": "oțărî",
    "oțărârăți": "oțărî",
    "oțărăsc": "oțărî",
    "oțărască": "oțărî",
    "oțărâse": "oțărî",
    "oțărâsem": "oțărî",
    "oțărâseră": "oțărî",
    "oțărâserăm": "oțărî",
    "oțărâserăți": "oțărî",
    "oțărâseși": "oțărî",
    "oțărâși": "oțărî",
    "oțărăște": "oțărî",
    "oțărăști": "oțărî",
    "oțărât": "oțărî",
    "oțărați": "oțărî",
    "oțărâți": "oțărî",
    "oțărau": "oțărî",
    "oțărea": "oțărî",
    "oțăreai": "oțărî",
    "oțăream": "oțărî",
    "oțărească": "oțărî",
    "oțăreați": "oțărî",
    "oțăreau": "oțărî",
    "oțăresc": "oțărî",
    "oțărește": "oțărî",
    "oțărești": "oțărî",
    "oțărîi": "oțărî",
    "oțărîm": "oțărî",
    "oțărînd": "oțărî",
    "oțărîndu": "oțărî",
    "oțărîră": "oțărî",
    "oțărîrăm": "oțărî",
    "oțărîrăți": "oțărî",
    "oțărîse": "oțărî",
    "oțărîsem": "oțărî",
    "oțărîseră": "oțărî",
    "oțărîserăm": "oțărî",
    "oțărîserăți": "oțărî",
    "oțărîseși": "oțărî",
    "oțărîși": "oțărî",
    "oțărît": "oțărî",
    "oțărîți": "oțărî",
    "oțărîtă": "oțărît",
    "oțărîte": "oțărît",
    "oțărîți": "oțărît",
    "otava": "otavă",
    "otave": "otavă",
    "otavei": "otavă",
    "oțele": "oțel",
    "oțelul": "oțel",
    "oțelului": "oțel",
    "oțeluri": "oțel",
    "oțelurile": "oțel",
    "oțelurilor": "oțel",
    "oțelari": "oțelar",
    "oțelarii": "oțelar",
    "oțelarilor": "oțelar",
    "oțelarul": "oțelar",
    "oțelarului": "oțelar",
    "oțelăria": "oțelărie",
    "oțelăriei": "oțelărie",
    "oțelării": "oțelărie",
    "oțelăriile": "oțelărie",
    "oțelăriilor": "oțelărie",
    "nemaioțelind": "oțeli",
    "nemaioțelindu": "oțeli",
    "neoțelind": "oțeli",
    "neoțelindu": "oțeli",
    "oțelea": "oțeli",
    "oțeleai": "oțeli",
    "oțeleam": "oțeli",
    "oțelească": "oțeli",
    "oțeleați": "oțeli",
    "oțeleau": "oțeli",
    "oțelesc": "oțeli",
    "oțelește": "oțeli",
    "oțelești": "oțeli",
    "oțelii": "oțeli",
    "oțelim": "oțeli",
    "oțelind": "oțeli",
    "oțelindu": "oțeli",
    "oțeliră": "oțeli",
    "oțelirăm": "oțeli",
    "oțelirăți": "oțeli",
    "oțelise": "oțeli",
    "oțelisem": "oțeli",
    "oțeliseră": "oțeli",
    "oțeliserăm": "oțeli",
    "oțeliserăți": "oțeli",
    "oțeliseși": "oțeli",
    "oțeliși": "oțeli",
    "oțelit": "oțeli",
    "oțeliți": "oțeli",
    "oțelită": "oțelit",
    "oțelite": "oțelit",
    "oțeliți": "oțelit",
    "oțetul": "oțet",
    "oțetului": "oțet",
    "nemaioțetind": "oțeti",
    "nemaioțetindu": "oțeti",
    "neoțetind": "oțeti",
    "neoțetindu": "oțeti",
    "oțetea": "oțeti",
    "oțeteai": "oțeti",
    "oțeteam": "oțeti",
    "oțetească": "oțeti",
    "oțeteați": "oțeti",
    "oțeteau": "oțeti",
    "oțetesc": "oțeti",
    "oțetește": "oțeti",
    "oțetești": "oțeti",
    "oțetii": "oțeti",
    "oțetim": "oțeti",
    "oțetind": "oțeti",
    "oțetindu": "oțeti",
    "oțetiră": "oțeti",
    "oțetirăm": "oțeti",
    "oțetirăți": "oțeti",
    "oțetise": "oțeti",
    "oțetisem": "oțeti",
    "oțetiseră": "oțeti",
    "oțetiserăm": "oțeti",
    "oțetiserăți": "oțeti",
    "oțetiseși": "oțeti",
    "oțetiși": "oțeti",
    "oțetit": "oțeti",
    "oțetiți": "oțeti",
    "oțetită": "oțetit",
    "oțetite": "oțetit",
    "oțetiți": "oțetit",
    "otita": "otită",
    "otite": "otită",
    "otitei": "otită",
    "otitele": "otită",
    "otitelor": "otită",
    "otomana": "otoman",
    "otomană": "otoman",
    "otomane": "otoman",
    "otomanei": "otoman",
    "otomanele": "otoman",
    "otomanelor": "otoman",
    "otomani": "otoman",
    "otomanii": "otoman",
    "otomanilor": "otoman",
    "otomanul": "otoman",
    "otomanului": "otoman",
    "otomana": "otomană",
    "otomane": "otomană",
    "otomanei": "otomană",
    "otomanele": "otomană",
    "otomanelor": "otomană",
    "Otopeniul": "Otopeni",
    "Otopeniului": "Otopeni",
    "otorinolaringologi": "otorinolaringolog",
    "otorinolaringologii": "otorinolaringolog",
    "otorinolaringologilor": "otorinolaringolog",
    "otorinolaringologul": "otorinolaringolog",
    "otorinolaringologului": "otorinolaringolog",
    "otorinolaringologia": "otorinolaringologie",
    "otorinolaringologiei": "otorinolaringologie",
    "otorinolaringologii": "otorinolaringologie",
    "otorinolaringologiile": "otorinolaringologie",
    "otorinolaringologiilor": "otorinolaringologie",
    "otrava": "otravă",
    "otrăvi": "otravă",
    "otrăvii": "otravă",
    "otrăvuri": "otravă",
    "otrăvurile": "otravă",
    "otrăvurilor": "otravă",
    "nemaiotrăvind": "otrăvi",
    "nemaiotrăvindu": "otrăvi",
    "neotrăvind": "otrăvi",
    "neotrăvindu": "otrăvi",
    "otrăvea": "otrăvi",
    "otrăveai": "otrăvi",
    "otrăveam": "otrăvi",
    "otrăvească": "otrăvi",
    "otrăveați": "otrăvi",
    "otrăveau": "otrăvi",
    "otrăvesc": "otrăvi",
    "otrăvește": "otrăvi",
    "otrăvești": "otrăvi",
    "otrăvii": "otrăvi",
    "otrăvim": "otrăvi",
    "otrăvind": "otrăvi",
    "otrăvindu": "otrăvi",
    "otrăviră": "otrăvi",
    "otrăvirăm": "otrăvi",
    "otrăvirăți": "otrăvi",
    "otrăvise": "otrăvi",
    "otrăvisem": "otrăvi",
    "otrăviseră": "otrăvi",
    "otrăviserăm": "otrăvi",
    "otrăviserăți": "otrăvi",
    "otrăviseși": "otrăvi",
    "otrăviși": "otrăvi",
    "otrăvit": "otrăvi",
    "otrăviți": "otrăvi",
    "otrăvicioasa": "otrăvicios",
    "otrăvicioasă": "otrăvicios",
    "otrăvicioase": "otrăvicios",
    "otrăvicioasei": "otrăvicios",
    "otrăvicioasele": "otrăvicios",
    "otrăvicioaselor": "otrăvicios",
    "otrăvicioși": "otrăvicios",
    "otrăvicioșii": "otrăvicios",
    "otrăvicioșilor": "otrăvicios",
    "otrăviciosul": "otrăvicios",
    "otrăviciosului": "otrăvicios",
    "otrăvită": "otrăvit",
    "otrăvite": "otrăvit",
    "otrăviți": "otrăvit",
    "otrăvitoare": "otrăvitor",
    "otrăvitoarea": "otrăvitor",
    "otrăvitoarei": "otrăvitor",
    "otrăvitoarele": "otrăvitor",
    "otrăvitoarelor": "otrăvitor",
    "otrăvitori": "otrăvitor",
    "otrăvitorii": "otrăvitor",
    "otrăvitorilor": "otrăvitor",
    "otrăvitorul": "otrăvitor",
    "otrăvitorului": "otrăvitor",
    "otreapa": "otreapă",
    "otrepe": "otreapă",
    "otrepei": "otreapă",
    "otrepele": "otreapă",
    "otrepelor": "otreapă",
    "ouă": "ou",
    "ouăle": "ou",
    "ouălor": "ou",
    "oul": "ou",
    "oului": "ou",
    "nemaiouând": "oua",
    "nemaiouându": "oua",
    "neouând": "oua",
    "neouându": "oua",
    "ouă": "oua",
    "ouând": "oua",
    "ouându": "oua",
    "ouară": "oua",
    "ouase": "oua",
    "ouaseră": "oua",
    "ouat": "oua",
    "ouau": "oua",
    "ouată": "ouat",
    "ouate": "ouat",
    "ouați": "ouat",
    "ouatul": "ouat",
    "ouatului": "ouat",
    "ovala": "oval",
    "ovală": "oval",
    "ovale": "oval",
    "ovalei": "oval",
    "ovalele": "oval",
    "ovalelor": "oval",
    "ovali": "oval",
    "ovalii": "oval",
    "ovalilor": "oval",
    "ovalul": "oval",
    "ovalului": "oval",
    "ovare": "ovar",
    "ovarele": "ovar",
    "ovarelor": "ovar",
    "ovarul": "ovar",
    "ovarului": "ovar",
    "ovariana": "ovarian",
    "ovariană": "ovarian",
    "ovarianul": "ovarian",
    "ovarianului": "ovarian",
    "ovariene": "ovarian",
    "ovarienei": "ovarian",
    "ovarienele": "ovarian",
    "ovarienelor": "ovarian",
    "ovarieni": "ovarian",
    "ovarienii": "ovarian",
    "ovarienilor": "ovarian",
    "ovata": "ovat",
    "ovată": "ovat",
    "ovate": "ovat",
    "ovatei": "ovat",
    "ovatele": "ovat",
    "ovatelor": "ovat",
    "ovați": "ovat",
    "ovații": "ovat",
    "ovaților": "ovat",
    "ovatul": "ovat",
    "ovatului": "ovat",
    "ovația": "ovație",
    "ovației": "ovație",
    "ovații": "ovație",
    "ovațiile": "ovație",
    "ovațiilor": "ovație",
    "nemaiovaționând": "ovaționa",
    "nemaiovaționându": "ovaționa",
    "neovaționând": "ovaționa",
    "neovaționându": "ovaționa",
    "ovaționă": "ovaționa",
    "ovaționai": "ovaționa",
    "ovaționam": "ovaționa",
    "ovaționăm": "ovaționa",
    "ovaționând": "ovaționa",
    "ovaționându": "ovaționa",
    "ovaționară": "ovaționa",
    "ovaționarăm": "ovaționa",
    "ovaționarăți": "ovaționa",
    "ovaționase": "ovaționa",
    "ovaționasem": "ovaționa",
    "ovaționaseră": "ovaționa",
    "ovaționaserăm": "ovaționa",
    "ovaționaserăți": "ovaționa",
    "ovaționaseși": "ovaționa",
    "ovaționași": "ovaționa",
    "ovaționat": "ovaționa",
    "ovaționați": "ovaționa",
    "ovaționau": "ovaționa",
    "ovaționează": "ovaționa",
    "ovaționez": "ovaționa",
    "ovaționeze": "ovaționa",
    "ovaționezi": "ovaționa",
    "ovaționată": "ovaționat",
    "ovaționate": "ovaționat",
    "ovaționați": "ovaționat",
    "ovăzul": "ovăz",
    "ovăzului": "ovăz",
    "oviducte": "oviduct",
    "oviductele": "oviduct",
    "oviductelor": "oviduct",
    "oviductul": "oviduct",
    "oviductului": "oviduct",
    "oviforma": "oviform",
    "oviformă": "oviform",
    "oviforme": "oviform",
    "oviformei": "oviform",
    "oviformele": "oviform",
    "oviformelor": "oviform",
    "oviformi": "oviform",
    "oviformii": "oviform",
    "oviformilor": "oviform",
    "oviformul": "oviform",
    "oviformului": "oviform",
    "ovina": "ovin",
    "ovină": "ovin",
    "ovine": "ovin",
    "ovinei": "ovin",
    "ovinele": "ovin",
    "ovinelor": "ovin",
    "ovini": "ovin",
    "ovinii": "ovin",
    "ovinilor": "ovin",
    "ovinul": "ovin",
    "ovinului": "ovin",
    "ovina": "ovină",
    "ovine": "ovină",
    "ovinei": "ovină",
    "ovinele": "ovină",
    "ovinelor": "ovină",
    "ov.": "ovine",
    "ovipara": "ovipar",
    "ovipară": "ovipar",
    "ovipare": "ovipar",
    "oviparei": "ovipar",
    "oviparele": "ovipar",
    "oviparelor": "ovipar",
    "ovipari": "ovipar",
    "oviparii": "ovipar",
    "oviparilor": "ovipar",
    "oviparul": "ovipar",
    "oviparului": "ovipar",
    "ovoida": "ovoid",
    "ovoidă": "ovoid",
    "ovoide": "ovoid",
    "ovoidei": "ovoid",
    "ovoidele": "ovoid",
    "ovoidelor": "ovoid",
    "ovoidul": "ovoid",
    "ovoidului": "ovoid",
    "ovoizi": "ovoid",
    "ovoizii": "ovoid",
    "ovoizilor": "ovoid",
    "ovoidala": "ovoidal",
    "ovoidală": "ovoidal",
    "ovoidale": "ovoidal",
    "ovoidalei": "ovoidal",
    "ovoidalele": "ovoidal",
    "ovoidalelor": "ovoidal",
    "ovoidali": "ovoidal",
    "ovoidalii": "ovoidal",
    "ovoidalilor": "ovoidal",
    "ovoidalul": "ovoidal",
    "ovoidalului": "ovoidal",
    "ovovivipara": "ovovivipar",
    "ovovivipară": "ovovivipar",
    "ovovivipare": "ovovivipar",
    "ovoviviparei": "ovovivipar",
    "ovoviviparele": "ovovivipar",
    "ovoviviparelor": "ovovivipar",
    "ovovivipari": "ovovivipar",
    "ovoviviparii": "ovovivipar",
    "ovoviviparilor": "ovovivipar",
    "ovoviviparul": "ovovivipar",
    "ovoviviparului": "ovovivipar",
    "ovreii": "ovrei",
    "ovreilor": "ovrei",
    "ovreiul": "ovrei",
    "ovreiului": "ovrei",
    "ovreiasca": "ovreiesc",
    "ovreiască": "ovreiesc",
    "ovreiescul": "ovreiesc",
    "ovreiescului": "ovreiesc",
    "ovreiești": "ovreiesc",
    "ovreieștii": "ovreiesc",
    "ovreieștile": "ovreiesc",
    "ovreieștilor": "ovreiesc",
    "ovreul": "ovreu",
    "ovreului": "ovreu",
    "ovule": "ovul",
    "ovulele": "ovul",
    "ovulelor": "ovul",
    "ovulul": "ovul",
    "ovulului": "ovul",
    "ovulara": "ovular",
    "ovulară": "ovular",
    "ovulare": "ovular",
    "ovularei": "ovular",
    "ovularele": "ovular",
    "ovularelor": "ovular",
    "ovulari": "ovular",
    "ovularii": "ovular",
    "ovularilor": "ovular",
    "ovularul": "ovular",
    "ovularului": "ovular",
    "oxalați": "oxalat",
    "oxalații": "oxalat",
    "oxalaților": "oxalat",
    "oxalatul": "oxalat",
    "oxalatului": "oxalat",
    "oxalica": "oxalic",
    "oxalică": "oxalic",
    "oxalice": "oxalic",
    "oxalicei": "oxalic",
    "oxalicele": "oxalic",
    "oxalicelor": "oxalic",
    "oxalici": "oxalic",
    "oxalicii": "oxalic",
    "oxalicilor": "oxalic",
    "oxalicul": "oxalic",
    "oxalicului": "oxalic",
    "Oxfordul": "Oxford",
    "Oxfordului": "Oxford",
    "oxidul": "oxid",
    "oxidului": "oxid",
    "oxizi": "oxid",
    "oxizii": "oxid",
    "oxizilor": "oxid",
    "nemaioxidând": "oxida",
    "nemaioxidându": "oxida",
    "neoxidând": "oxida",
    "neoxidându": "oxida",
    "oxidă": "oxida",
    "oxidai": "oxida",
    "oxidam": "oxida",
    "oxidăm": "oxida",
    "oxidând": "oxida",
    "oxidându": "oxida",
    "oxidară": "oxida",
    "oxidarăm": "oxida",
    "oxidarăți": "oxida",
    "oxidase": "oxida",
    "oxidasem": "oxida",
    "oxidaseră": "oxida",
    "oxidaserăm": "oxida",
    "oxidaserăți": "oxida",
    "oxidaseși": "oxida",
    "oxidași": "oxida",
    "oxidat": "oxida",
    "oxidați": "oxida",
    "oxidau": "oxida",
    "oxidează": "oxida",
    "oxidez": "oxida",
    "oxideze": "oxida",
    "oxidezi": "oxida",
    "oxidabila": "oxidabil",
    "oxidabilă": "oxidabil",
    "oxidabile": "oxidabil",
    "oxidabilei": "oxidabil",
    "oxidabilele": "oxidabil",
    "oxidabilelor": "oxidabil",
    "oxidabili": "oxidabil",
    "oxidabilii": "oxidabil",
    "oxidabililor": "oxidabil",
    "oxidabilul": "oxidabil",
    "oxidabilului": "oxidabil",
    "oxidanta": "oxidant",
    "oxidantă": "oxidant",
    "oxidante": "oxidant",
    "oxidantei": "oxidant",
    "oxidantele": "oxidant",
    "oxidantelor": "oxidant",
    "oxidanți": "oxidant",
    "oxidanții": "oxidant",
    "oxidanților": "oxidant",
    "oxidantul": "oxidant",
    "oxidantului": "oxidant",
    "oxidată": "oxidat",
    "oxidate": "oxidat",
    "oxidați": "oxidat",
    "oxidativa": "oxidativ",
    "oxidativă": "oxidativ",
    "oxidative": "oxidativ",
    "oxidativei": "oxidativ",
    "oxidativele": "oxidativ",
    "oxidativelor": "oxidativ",
    "oxidativi": "oxidativ",
    "oxidativii": "oxidativ",
    "oxidativilor": "oxidativ",
    "oxidativul": "oxidativ",
    "oxidativului": "oxidativ",
    "oxidrili": "oxidril",
    "oxidrilii": "oxidril",
    "oxidrililor": "oxidril",
    "oxidrilul": "oxidril",
    "oxidrilului": "oxidril",
    "oxigenul": "oxigen",
    "oxigenului": "oxigen",
    "nemaioxigenând": "oxigena",
    "nemaioxigenându": "oxigena",
    "neoxigenând": "oxigena",
    "neoxigenându": "oxigena",
    "oxigenă": "oxigena",
    "oxigenai": "oxigena",
    "oxigenam": "oxigena",
    "oxigenăm": "oxigena",
    "oxigenând": "oxigena",
    "oxigenându": "oxigena",
    "oxigenară": "oxigena",
    "oxigenarăm": "oxigena",
    "oxigenarăți": "oxigena",
    "oxigenase": "oxigena",
    "oxigenasem": "oxigena",
    "oxigenaseră": "oxigena",
    "oxigenaserăm": "oxigena",
    "oxigenaserăți": "oxigena",
    "oxigenaseși": "oxigena",
    "oxigenași": "oxigena",
    "oxigenat": "oxigena",
    "oxigenați": "oxigena",
    "oxigenau": "oxigena",
    "oxigenează": "oxigena",
    "oxigenez": "oxigena",
    "oxigeneze": "oxigena",
    "oxigenezi": "oxigena",
    "oxigenată": "oxigenat",
    "oxigenate": "oxigenat",
    "oxigenați": "oxigenat",
    "oxitona": "oxiton",
    "oxitonă": "oxiton",
    "oxitone": "oxiton",
    "oxitonei": "oxiton",
    "oxitonele": "oxiton",
    "oxitonelor": "oxiton",
    "oxitoni": "oxiton",
    "oxitonii": "oxiton",
    "oxitonilor": "oxiton",
    "oxitonul": "oxiton",
    "oxitonului": "oxiton",
    "oxiuri": "oxiur",
    "oxiurii": "oxiur",
    "oxiurilor": "oxiur",
    "oxiurul": "oxiur",
    "oxiurului": "oxiur",
    "ozalidul": "ozalid",
    "ozalidului": "ozalid",
    "ozonul": "ozon",
    "ozonului": "ozon",
    "ozoniză": "ozoniza",
    "ozonizai": "ozoniza",
    "ozonizam": "ozoniza",
    "ozonizăm": "ozoniza",
    "ozonizară": "ozoniza",
    "ozonizarăm": "ozoniza",
    "ozonizarăți": "ozoniza",
    "ozonizase": "ozoniza",
    "ozonizasem": "ozoniza",
    "ozonizaseră": "ozoniza",
    "ozonizaserăm": "ozoniza",
    "ozonizaserăți": "ozoniza",
    "ozonizaseși": "ozoniza",
    "ozonizași": "ozoniza",
    "ozonizat": "ozoniza",
    "ozonizați": "ozoniza",
    "ozonizau": "ozoniza",
    "ozonizează": "ozoniza",
    "ozonizez": "ozoniza",
    "ozonizeze": "ozoniza",
    "ozonizezi": "ozoniza",
    "ozonizată": "ozonizat",
    "ozonizate": "ozonizat",
    "ozonizați": "ozonizat",
    "nemaipâcâind": "pâcâi",
    "nemaipâcâindu": "pâcâi",
    "nepâcâind": "pâcâi",
    "nepâcâindu": "pâcâi",
    "pâcâia": "pâcâi",
    "pâcâiai": "pâcâi",
    "pâcâiam": "pâcâi",
    "pâcâiați": "pâcâi",
    "pâcâiau": "pâcâi",
    "pâcâie": "pâcâi",
    "pâcâii": "pâcâi",
    "pâcâim": "pâcâi",
    "pâcâind": "pâcâi",
    "pâcâindu": "pâcâi",
    "pâcâiră": "pâcâi",
    "pâcâirăm": "pâcâi",
    "pâcâirăți": "pâcâi",
    "pâcâise": "pâcâi",
    "pâcâisem": "pâcâi",
    "pâcâiseră": "pâcâi",
    "pâcâiserăm": "pâcâi",
    "pâcâiserăți": "pâcâi",
    "pâcâiseși": "pâcâi",
    "pâcâiși": "pâcâi",
    "pâcâit": "pâcâi",
    "pâcâiți": "pâcâi",
    "pâcâită": "pâcâit",
    "pâcâite": "pâcâit",
    "pâcâiți": "pâcâit",
    "păcăleala": "păcăleală",
    "păcăleli": "păcăleală",
    "păcălelii": "păcăleală",
    "păcălelile": "păcăleală",
    "păcălelilor": "păcăleală",
    "nemaipăcălind": "păcăli",
    "nemaipăcălindu": "păcăli",
    "nepăcălind": "păcăli",
    "nepăcălindu": "păcăli",
    "păcălea": "păcăli",
    "păcăleai": "păcăli",
    "păcăleam": "păcăli",
    "păcălească": "păcăli",
    "păcăleați": "păcăli",
    "păcăleau": "păcăli",
    "păcălesc": "păcăli",
    "păcălește": "păcăli",
    "păcălești": "păcăli",
    "păcălii": "păcăli",
    "păcălim": "păcăli",
    "păcălind": "păcăli",
    "păcălindu": "păcăli",
    "păcăliră": "păcăli",
    "păcălirăm": "păcăli",
    "păcălirăți": "păcăli",
    "păcălise": "păcăli",
    "păcălisem": "păcăli",
    "păcăliseră": "păcăli",
    "păcăliserăm": "păcăli",
    "păcăliserăți": "păcăli",
    "păcăliseși": "păcăli",
    "păcăliși": "păcăli",
    "păcălit": "păcăli",
    "păcăliți": "păcăli",
    "păcălicii": "păcălici",
    "păcălicilor": "păcălici",
    "păcăliciul": "păcălici",
    "păcăliciului": "păcălici",
    "păcălita": "păcălit",
    "păcălită": "păcălit",
    "păcălite": "păcălit",
    "păcălitei": "păcălit",
    "păcălitele": "păcălit",
    "păcălitelor": "păcălit",
    "păcăliți": "păcălit",
    "păcăliții": "păcălit",
    "păcăliților": "păcălit",
    "păcălitul": "păcălit",
    "păcălitului": "păcălit",
    "nemaipăcănind": "păcăni",
    "nemaipăcănindu": "păcăni",
    "nepăcănind": "păcăni",
    "nepăcănindu": "păcăni",
    "păcănea": "păcăni",
    "păcăneai": "păcăni",
    "păcăneam": "păcăni",
    "păcănească": "păcăni",
    "păcăneați": "păcăni",
    "păcăneau": "păcăni",
    "păcănesc": "păcăni",
    "păcănește": "păcăni",
    "păcănești": "păcăni",
    "păcănii": "păcăni",
    "păcănim": "păcăni",
    "păcănind": "păcăni",
    "păcănindu": "păcăni",
    "păcăniră": "păcăni",
    "păcănirăm": "păcăni",
    "păcănirăți": "păcăni",
    "păcănise": "păcăni",
    "păcănisem": "păcăni",
    "păcăniseră": "păcăni",
    "păcăniserăm": "păcăni",
    "păcăniserăți": "păcăni",
    "păcăniseși": "păcăni",
    "păcăniși": "păcăni",
    "păcănit": "păcăni",
    "păcăniți": "păcăni",
    "păcănită": "păcănit",
    "păcănite": "păcănit",
    "păcăniți": "păcănit",
    "păcate": "păcat",
    "păcatele": "păcat",
    "păcatelor": "păcat",
    "păcatul": "păcat",
    "păcatului": "păcat",
    "păcătoasa": "păcătos",
    "păcătoasă": "păcătos",
    "păcătoase": "păcătos",
    "păcătoasei": "păcătos",
    "păcătoasele": "păcătos",
    "păcătoaselor": "păcătos",
    "păcătoși": "păcătos",
    "păcătoșii": "păcătos",
    "păcătoșilor": "păcătos",
    "păcătosul": "păcătos",
    "păcătosului": "păcătos",
    "păcătoșenia": "păcătoșenie",
    "păcătoșeniei": "păcătoșenie",
    "păcătoșenii": "păcătoșenie",
    "păcătoșeniile": "păcătoșenie",
    "păcătoșeniilor": "păcătoșenie",
    "nemaipăcătuind": "păcătui",
    "nemaipăcătuindu": "păcătui",
    "nepăcătuind": "păcătui",
    "nepăcătuindu": "păcătui",
    "păcătuia": "păcătui",
    "păcătuiai": "păcătui",
    "păcătuiam": "păcătui",
    "păcătuiască": "păcătui",
    "păcătuiați": "păcătui",
    "păcătuiau": "păcătui",
    "păcătuiesc": "păcătui",
    "păcătuiește": "păcătui",
    "păcătuiești": "păcătui",
    "păcătuii": "păcătui",
    "păcătuim": "păcătui",
    "păcătuind": "păcătui",
    "păcătuindu": "păcătui",
    "păcătuiră": "păcătui",
    "păcătuirăm": "păcătui",
    "păcătuirăți": "păcătui",
    "păcătuise": "păcătui",
    "păcătuisem": "păcătui",
    "păcătuiseră": "păcătui",
    "păcătuiserăm": "păcătui",
    "păcătuiserăți": "păcătui",
    "păcătuiseși": "păcătui",
    "păcătuiși": "păcătui",
    "păcătuit": "păcătui",
    "păcătuiți": "păcătui",
    "păcătuită": "păcătuit",
    "păcătuite": "păcătuit",
    "păcătuiți": "păcătuit",
    "pacea": "pace",
    "păci": "pace",
    "păcii": "pace",
    "păcile": "pace",
    "păcilor": "pace",
    "pachebotul": "pachebot",
    "pachebotului": "pachebot",
    "pacheboturi": "pachebot",
    "pacheboturile": "pachebot",
    "pacheboturilor": "pachebot",
    "pachete": "pachet",
    "pachetele": "pachet",
    "pachetelor": "pachet",
    "pachetul": "pachet",
    "pachetului": "pachet",
    "pachidermi": "pachiderm",
    "pachidermii": "pachiderm",
    "pachidermilor": "pachiderm",
    "pachidermul": "pachiderm",
    "pachidermului": "pachiderm",
    "pacienți": "pacient",
    "pacienții": "pacient",
    "pacienților": "pacient",
    "pacientul": "pacient",
    "pacientului": "pacient",
    "pacienta": "pacientă",
    "paciente": "pacientă",
    "pacientei": "pacientă",
    "pacientele": "pacientă",
    "pacientelor": "pacientă",
    "paciența": "paciență",
    "paciențe": "paciență",
    "pacienței": "paciență",
    "Pacificul": "Pacific",
    "Pacificului": "Pacific",
    "nemaipacificând": "pacifica",
    "nemaipacificându": "pacifica",
    "nepacificând": "pacifica",
    "nepacificându": "pacifica",
    "pacific": "pacifica",
    "pacifică": "pacifica",
    "pacificai": "pacifica",
    "pacificam": "pacifica",
    "pacificăm": "pacifica",
    "pacificând": "pacifica",
    "pacificându": "pacifica",
    "pacificară": "pacifica",
    "pacificarăm": "pacifica",
    "pacificarăți": "pacifica",
    "pacificase": "pacifica",
    "pacificasem": "pacifica",
    "pacificaseră": "pacifica",
    "pacificaserăm": "pacifica",
    "pacificaserăți": "pacifica",
    "pacificaseși": "pacifica",
    "pacificași": "pacifica",
    "pacificat": "pacifica",
    "pacificați": "pacifica",
    "pacificau": "pacifica",
    "pacifice": "pacifica",
    "pacifici": "pacifica",
    "pacificată": "pacificat",
    "pacificate": "pacificat",
    "pacificați": "pacificat",
    "pacificatoare": "pacificator",
    "pacificatoarea": "pacificator",
    "pacificatoarei": "pacificator",
    "pacificatoarele": "pacificator",
    "pacificatoarelor": "pacificator",
    "pacificatori": "pacificator",
    "pacificatorii": "pacificator",
    "pacificatorilor": "pacificator",
    "pacificatorul": "pacificator",
    "pacificatorului": "pacificator",
    "pacifismul": "pacifism",
    "pacifismului": "pacifism",
    "pacifista": "pacifist",
    "pacifistă": "pacifist",
    "pacifiste": "pacifist",
    "pacifistei": "pacifist",
    "pacifistele": "pacifist",
    "pacifistelor": "pacifist",
    "pacifiști": "pacifist",
    "pacifiștii": "pacifist",
    "pacifiștilor": "pacifist",
    "pacifistul": "pacifist",
    "pacifistului": "pacifist",
    "pâcla": "pâclă",
    "pâcle": "pâclă",
    "pâclei": "pâclă",
    "pâclele": "pâclă",
    "pâclelor": "pâclă",
    "pâcloasa": "pâclos",
    "pâcloasă": "pâclos",
    "pâcloase": "pâclos",
    "pâcloasei": "pâclos",
    "pâcloasele": "pâclos",
    "pâcloaselor": "pâclos",
    "pâcloși": "pâclos",
    "pâcloșii": "pâclos",
    "pâcloșilor": "pâclos",
    "pâclosul": "pâclos",
    "pâclosului": "pâclos",
    "pacostea": "pacoste",
    "pacostei": "pacoste",
    "pacostele": "pacoste",
    "pacostelor": "pacoste",
    "pacte": "pact",
    "pactele": "pact",
    "pactelor": "pact",
    "pactul": "pact",
    "pactului": "pact",
    "nemaipactizând": "pactiza",
    "nemaipactizându": "pactiza",
    "nepactizând": "pactiza",
    "nepactizându": "pactiza",
    "pactiză": "pactiza",
    "pactizai": "pactiza",
    "pactizam": "pactiza",
    "pactizăm": "pactiza",
    "pactizând": "pactiza",
    "pactizându": "pactiza",
    "pactizară": "pactiza",
    "pactizarăm": "pactiza",
    "pactizarăți": "pactiza",
    "pactizase": "pactiza",
    "pactizasem": "pactiza",
    "pactizaseră": "pactiza",
    "pactizaserăm": "pactiza",
    "pactizaserăți": "pactiza",
    "pactizaseși": "pactiza",
    "pactizași": "pactiza",
    "pactizat": "pactiza",
    "pactizați": "pactiza",
    "pactizau": "pactiza",
    "pactizează": "pactiza",
    "pactizez": "pactiza",
    "pactizeze": "pactiza",
    "pactizezi": "pactiza",
    "pactizarea": "pactizare",
    "pactizări": "pactizare",
    "pactizării": "pactizare",
    "pactizările": "pactizare",
    "pactizărilor": "pactizare",
    "pactizată": "pactizat",
    "pactizate": "pactizat",
    "pactizați": "pactizat",
    "păcura": "păcură",
    "păcuri": "păcură",
    "păcurii": "păcură",
    "păcurari": "păcurar",
    "păcurarii": "păcurar",
    "păcurarilor": "păcurar",
    "păcurarul": "păcurar",
    "păcurarului": "păcurar",
    "păcurăria": "păcurărie",
    "păcurăriei": "păcurărie",
    "păcurării": "păcurărie",
    "păcurăriile": "păcurărie",
    "păcurăriilor": "păcurărie",
    "padina": "padină",
    "padini": "padină",
    "padinii": "padină",
    "padinile": "padină",
    "padinilor": "padină",
    "padocul": "padoc",
    "padocului": "padoc",
    "padocuri": "padoc",
    "padocurile": "padoc",
    "padocurilor": "padoc",
    "păducei": "păducel",
    "păduceii": "păducel",
    "păduceilor": "păducel",
    "păducelul": "păducel",
    "păducelului": "păducel",
    "păduchele": "păduche",
    "păduchelui": "păduche",
    "păduchi": "păduche",
    "păduchii": "păduche",
    "păduchilor": "păduche",
    "păduchioasa": "păduchios",
    "păduchioasă": "păduchios",
    "păduchioase": "păduchios",
    "păduchioasei": "păduchios",
    "păduchioasele": "păduchios",
    "păduchioaselor": "păduchios",
    "păduchioși": "păduchios",
    "păduchioșii": "păduchios",
    "păduchioșilor": "păduchios",
    "păduchiosul": "păduchios",
    "păduchiosului": "păduchios",
    "pădurari": "pădurar",
    "pădurarii": "pădurar",
    "pădurarilor": "pădurar",
    "pădurarul": "pădurar",
    "pădurarului": "pădurar",
    "pădurăritul": "pădurărit",
    "pădurăritului": "pădurărit",
    "pădurea": "pădure",
    "păduri": "pădure",
    "pădurii": "pădure",
    "pădurile": "pădure",
    "pădurilor": "pădure",
    "pădureana": "pădureană",
    "pădurene": "pădureană",
    "pădurenei": "pădureană",
    "pădurenele": "pădureană",
    "pădurenelor": "pădureană",
    "pădureața": "pădureț",
    "pădureață": "pădureț",
    "pădurețe": "pădureț",
    "pădureței": "pădureț",
    "pădurețele": "pădureț",
    "pădurețelor": "pădureț",
    "pădureți": "pădureț",
    "pădureții": "pădureț",
    "pădureților": "pădureț",
    "pădurețul": "pădureț",
    "pădurețului": "pădureț",
    "păduricea": "pădurice",
    "pădurici": "pădurice",
    "păduricii": "pădurice",
    "păduricile": "pădurice",
    "păduricilor": "pădurice",
    "păduroasa": "păduros",
    "păduroasă": "păduros",
    "păduroase": "păduros",
    "păduroasei": "păduros",
    "păduroasele": "păduros",
    "păduroaselor": "păduros",
    "păduroși": "păduros",
    "păduroșii": "păduros",
    "păduroșilor": "păduros",
    "pădurosul": "păduros",
    "pădurosului": "păduros",
    "paftale": "pafta",
    "paftalei": "pafta",
    "paftalele": "pafta",
    "paftalelor": "pafta",
    "paftaua": "pafta",
    "paga": "pag",
    "pagă": "pag",
    "page": "pag",
    "pagei": "pag",
    "pagele": "pag",
    "pagelor": "pag",
    "pagi": "pag",
    "pagii": "pag",
    "pagilor": "pag",
    "pagul": "pag",
    "pagului": "pag",
    "pagaia": "pagaie",
    "pagaiei": "pagaie",
    "pagaiele": "pagaie",
    "pagaielor": "pagaie",
    "păgâna": "păgân",
    "păgână": "păgân",
    "păgâne": "păgân",
    "păgânei": "păgân",
    "păgânele": "păgân",
    "păgânelor": "păgân",
    "păgâni": "păgân",
    "păgânii": "păgân",
    "păgânilor": "păgân",
    "păgânul": "păgân",
    "păgânului": "păgân",
    "păgânătatea": "păgânătate",
    "păgânătăți": "păgânătate",
    "păgânătății": "păgânătate",
    "păgânismul": "păgânism",
    "păgânismului": "păgânism",
    "pagere": "pager",
    "pagerele": "pager",
    "pagerelor": "pager",
    "pagerul": "pager",
    "pagerului": "pager",
    "nemaipaginând": "pagina",
    "nemaipaginându": "pagina",
    "nepaginând": "pagina",
    "nepaginându": "pagina",
    "pagină": "pagina",
    "paginai": "pagina",
    "paginam": "pagina",
    "paginăm": "pagina",
    "paginând": "pagina",
    "paginându": "pagina",
    "paginară": "pagina",
    "paginarăm": "pagina",
    "paginarăți": "pagina",
    "paginase": "pagina",
    "paginasem": "pagina",
    "paginaseră": "pagina",
    "paginaserăm": "pagina",
    "paginaserăți": "pagina",
    "paginaseși": "pagina",
    "paginași": "pagina",
    "paginat": "pagina",
    "paginați": "pagina",
    "paginau": "pagina",
    "paginează": "pagina",
    "paginez": "pagina",
    "pagineze": "pagina",
    "paginezi": "pagina",
    "p.": "pagină",
    "pag.": "pagină",
    "pagina": "pagină",
    "pagini": "pagină",
    "paginii": "pagină",
    "paginile": "pagină",
    "paginilor": "pagină",
    "paginată": "paginat",
    "paginate": "paginat",
    "paginați": "paginat",
    "paginația": "paginație",
    "paginației": "paginație",
    "paginații": "paginație",
    "paginațiile": "paginație",
    "paginațiilor": "paginație",
    "pp.": "paginile",
    "pagoda": "pagodă",
    "pagode": "pagodă",
    "pagodei": "pagodă",
    "pagodele": "pagodă",
    "pagodelor": "pagodă",
    "paguba": "pagubă",
    "pagube": "pagubă",
    "pagubei": "pagubă",
    "pagubele": "pagubă",
    "pagubelor": "pagubă",
    "păgubași": "păgubaș",
    "păgubașii": "păgubaș",
    "păgubașilor": "păgubaș",
    "păgubașul": "păgubaș",
    "păgubașului": "păgubaș",
    "nemaipăgubind": "păgubi",
    "nemaipăgubindu": "păgubi",
    "nepăgubind": "păgubi",
    "nepăgubindu": "păgubi",
    "păgubea": "păgubi",
    "păgubeai": "păgubi",
    "păgubeam": "păgubi",
    "păgubească": "păgubi",
    "păgubeați": "păgubi",
    "păgubeau": "păgubi",
    "păgubesc": "păgubi",
    "păgubește": "păgubi",
    "păgubești": "păgubi",
    "păgubii": "păgubi",
    "păgubim": "păgubi",
    "păgubind": "păgubi",
    "păgubindu": "păgubi",
    "păgubiră": "păgubi",
    "păgubirăm": "păgubi",
    "păgubirăți": "păgubi",
    "păgubise": "păgubi",
    "păgubisem": "păgubi",
    "păgubiseră": "păgubi",
    "păgubiserăm": "păgubi",
    "păgubiserăți": "păgubi",
    "păgubiseși": "păgubi",
    "păgubiși": "păgubi",
    "păgubit": "păgubi",
    "păgubiți": "păgubi",
    "păgubita": "păgubit",
    "păgubită": "păgubit",
    "păgubite": "păgubit",
    "păgubitei": "păgubit",
    "păgubitele": "păgubit",
    "păgubitelor": "păgubit",
    "păgubiți": "păgubit",
    "păgubiții": "păgubit",
    "păgubiților": "păgubit",
    "păgubitul": "păgubit",
    "păgubitului": "păgubit",
    "păgubita": "păgubită",
    "păgubite": "păgubită",
    "păgubitei": "păgubită",
    "păgubitele": "păgubită",
    "păgubitoare": "păgubitor",
    "păgubitoarea": "păgubitor",
    "păgubitoarei": "păgubitor",
    "păgubitoarele": "păgubitor",
    "păgubitoarelor": "păgubitor",
    "păgubitori": "păgubitor",
    "păgubitorii": "păgubitor",
    "păgubitorilor": "păgubitor",
    "păgubitorul": "păgubitor",
    "păgubitorului": "păgubitor",
    "păguboasa": "păgubos",
    "păguboasă": "păgubos",
    "păguboase": "păgubos",
    "păguboasei": "păgubos",
    "păguboasele": "păgubos",
    "păguboaselor": "păgubos",
    "păguboși": "păgubos",
    "păguboșii": "păgubos",
    "păguboșilor": "păgubos",
    "păgubosul": "păgubos",
    "păgubosului": "păgubos",
    "pahare": "pahar",
    "paharele": "pahar",
    "paharelor": "pahar",
    "paharul": "pahar",
    "paharului": "pahar",
    "paharnici": "paharnic",
    "paharnicii": "paharnic",
    "paharnicilor": "paharnic",
    "paharnicul": "paharnic",
    "paharnicului": "paharnic",
    "paie": "pai",
    "paiele": "pai",
    "paielor": "pai",
    "paiul": "pai",
    "paiului": "pai",
    "paianjeni": "paianjen",
    "paianjenii": "paianjen",
    "paianjenilor": "paianjen",
    "paianjenul": "paianjen",
    "paianjenului": "paianjen",
    "păianjeni": "păianjen",
    "păianjenii": "păianjen",
    "păianjenilor": "păianjen",
    "păianjenul": "păianjen",
    "păianjenului": "păianjen",
    "paianta": "paiantă",
    "paiante": "paiantă",
    "paiantei": "paiantă",
    "paiantele": "paiantă",
    "paiantelor": "paiantă",
    "paiața": "paiață",
    "paiațe": "paiață",
    "paiaței": "paiață",
    "paiațele": "paiață",
    "paiațelor": "paiață",
    "păienjenișul": "păienjeniș",
    "păienjenișului": "păienjeniș",
    "păienjenișuri": "păienjeniș",
    "păienjenișurile": "păienjeniș",
    "păienjenișurilor": "păienjeniș",
    "paieta": "paietă",
    "paiete": "paietă",
    "paietei": "paietă",
    "paietele": "paietă",
    "paietelor": "paietă",
    "pâinea": "pâine",
    "pâini": "pâine",
    "pâinii": "pâine",
    "pâinile": "pâine",
    "pâinilor": "pâine",
    "pâinica": "pâinică",
    "pâinici": "pâinică",
    "pâinicii": "pâinică",
    "pâinicile": "pâinică",
    "pâinicilor": "pâinică",
    "păioasa": "păios",
    "păioasă": "păios",
    "păioase": "păios",
    "păioasei": "păios",
    "păioasele": "păios",
    "păioaselor": "păios",
    "păioși": "păios",
    "păioșii": "păios",
    "păioșilor": "păios",
    "păiosul": "păios",
    "păiosului": "păios",
    "paișpe": "paisprezece",
    "paișpea": "paisprezece",
    "paișpelea": "paisprezece",
    "paisprezecea": "paisprezece",
    "paisprezecelea": "paisprezece",
    "XIV": "paisprezece",
    "paisprezecimea": "paisprezecime",
    "paisprezecimi": "paisprezecime",
    "paisprezecimii": "paisprezecime",
    "paisprezecimile": "paisprezecime",
    "paisprezecimilor": "paisprezecime",
    "paji": "paj",
    "pajii": "paj",
    "pajilor": "paj",
    "pajul": "paj",
    "pajului": "paj",
    "pajiștea": "pajiște",
    "pajiști": "pajiște",
    "pajiștii": "pajiște",
    "pajiștile": "pajiște",
    "pajiștilor": "pajiște",
    "pajura": "pajură",
    "pajuri": "pajură",
    "pajurii": "pajură",
    "pajurile": "pajură",
    "pajurilor": "pajură",
    "pala": "pal",
    "pală": "pal",
    "pale": "pal",
    "palei": "pal",
    "palele": "pal",
    "palelor": "pal",
    "pali": "pal",
    "palii": "pal",
    "palilor": "pal",
    "palul": "pal",
    "palului": "pal",
    "pala": "pală",
    "pale": "pală",
    "palei": "pală",
    "palele": "pală",
    "palelor": "pală",
    "paladini": "paladin",
    "paladinii": "paladin",
    "paladinilor": "paladin",
    "paladinul": "paladin",
    "paladinului": "paladin",
    "paladiul": "paladiu",
    "paladiului": "paladiu",
    "palafita": "palafită",
    "palafite": "palafită",
    "palafitei": "palafită",
    "palafitele": "palafită",
    "palafitelor": "palafită",
    "nemaipălălăind": "pălălăi",
    "nemaipălălăindu": "pălălăi",
    "nepălălăind": "pălălăi",
    "nepălălăindu": "pălălăi",
    "pălălăia": "pălălăi",
    "pălălăiai": "pălălăi",
    "pălălăiam": "pălălăi",
    "pălălăiască": "pălălăi",
    "pălălăiați": "pălălăi",
    "pălălăiau": "pălălăi",
    "pălălăiesc": "pălălăi",
    "pălălăiește": "pălălăi",
    "pălălăiești": "pălălăi",
    "pălălăii": "pălălăi",
    "pălălăim": "pălălăi",
    "pălălăind": "pălălăi",
    "pălălăindu": "pălălăi",
    "pălălăiră": "pălălăi",
    "pălălăirăm": "pălălăi",
    "pălălăirăți": "pălălăi",
    "pălălăise": "pălălăi",
    "pălălăisem": "pălălăi",
    "pălălăiseră": "pălălăi",
    "pălălăiserăm": "pălălăi",
    "pălălăiserăți": "pălălăi",
    "pălălăiseși": "pălălăi",
    "pălălăiși": "pălălăi",
    "pălălăit": "pălălăi",
    "pălălăiți": "pălălăi",
    "pălălăi": "pălălaie",
    "pălălaia": "pălălaie",
    "pălălăii": "pălălaie",
    "pălălăile": "pălălaie",
    "pălălăilor": "pălălaie",
    "pălălăită": "pălălăit",
    "pălălăite": "pălălăit",
    "pălălăiți": "pălălăit",
    "palane": "palan",
    "palanele": "palan",
    "palanelor": "palan",
    "palanul": "palan",
    "palanului": "palan",
    "pălăria": "pălărie",
    "pălăriei": "pălărie",
    "pălării": "pălărie",
    "pălăriile": "pălărie",
    "pălăriilor": "pălărie",
    "pălărieri": "pălărier",
    "pălărierii": "pălărier",
    "pălărierilor": "pălărier",
    "pălărierul": "pălărier",
    "pălărierului": "pălărier",
    "palate": "palat",
    "palatele": "palat",
    "palatelor": "palat",
    "palatul": "palat",
    "palatului": "palat",
    "palatina": "palatin",
    "palatină": "palatin",
    "palatine": "palatin",
    "palatinei": "palatin",
    "palatinele": "palatin",
    "palatinelor": "palatin",
    "palatini": "palatin",
    "palatinii": "palatin",
    "palatinilor": "palatin",
    "palatinul": "palatin",
    "palatinului": "palatin",
    "palavra": "palavră",
    "palavre": "palavră",
    "palavrei": "palavră",
    "palavrele": "palavră",
    "palavrelor": "palavră",
    "pălăvrăgeala": "pălăvrăgeală",
    "pălăvrăgeli": "pălăvrăgeală",
    "pălăvrăgelii": "pălăvrăgeală",
    "pălăvrăgelile": "pălăvrăgeală",
    "pălăvrăgelilor": "pălăvrăgeală",
    "nemaipălăvrăgind": "pălăvrăgi",
    "nemaipălăvrăgindu": "pălăvrăgi",
    "nepălăvrăgind": "pălăvrăgi",
    "nepălăvrăgindu": "pălăvrăgi",
    "pălăvrăgea": "pălăvrăgi",
    "pălăvrăgeai": "pălăvrăgi",
    "pălăvrăgeam": "pălăvrăgi",
    "pălăvrăgească": "pălăvrăgi",
    "pălăvrăgeați": "pălăvrăgi",
    "pălăvrăgeau": "pălăvrăgi",
    "pălăvrăgesc": "pălăvrăgi",
    "pălăvrăgește": "pălăvrăgi",
    "pălăvrăgești": "pălăvrăgi",
    "pălăvrăgii": "pălăvrăgi",
    "pălăvrăgim": "pălăvrăgi",
    "pălăvrăgind": "pălăvrăgi",
    "pălăvrăgindu": "pălăvrăgi",
    "pălăvrăgiră": "pălăvrăgi",
    "pălăvrăgirăm": "pălăvrăgi",
    "pălăvrăgirăți": "pălăvrăgi",
    "pălăvrăgise": "pălăvrăgi",
    "pălăvrăgisem": "pălăvrăgi",
    "pălăvrăgiseră": "pălăvrăgi",
    "pălăvrăgiserăm": "pălăvrăgi",
    "pălăvrăgiserăți": "pălăvrăgi",
    "pălăvrăgiseși": "pălăvrăgi",
    "pălăvrăgiși": "pălăvrăgi",
    "pălăvrăgit": "pălăvrăgi",
    "pălăvrăgiți": "pălăvrăgi",
    "palavragioaica": "palavragioaică",
    "palavragioaice": "palavragioaică",
    "palavragioaicei": "palavragioaică",
    "palavragioaicele": "palavragioaică",
    "palavragioaicelor": "palavragioaică",
    "pălăvrăgită": "pălăvrăgit",
    "pălăvrăgite": "pălăvrăgit",
    "pălăvrăgiți": "pălăvrăgit",
    "palavragii": "palavragiu",
    "palavragiii": "palavragiu",
    "palavragiilor": "palavragiu",
    "palavragiul": "palavragiu",
    "palavragiului": "palavragiu",
    "pâlcul": "pâlc",
    "pâlcului": "pâlc",
    "pâlcuri": "pâlc",
    "pâlcurile": "pâlc",
    "pâlcurilor": "pâlc",
    "paleea": "palee",
    "paleei": "palee",
    "paleele": "palee",
    "paleelor": "palee",
    "paleocena": "paleocen",
    "paleocenă": "paleocen",
    "paleocene": "paleocen",
    "paleocenei": "paleocen",
    "paleocenele": "paleocen",
    "paleocenelor": "paleocen",
    "paleoceni": "paleocen",
    "paleocenii": "paleocen",
    "paleocenilor": "paleocen",
    "paleocenul": "paleocen",
    "paleocenului": "paleocen",
    "paleocreștina": "paleocreștin",
    "paleocreștină": "paleocreștin",
    "paleocreștine": "paleocreștin",
    "paleocreștinei": "paleocreștin",
    "paleocreștinele": "paleocreștin",
    "paleocreștinelor": "paleocreștin",
    "paleocreștini": "paleocreștin",
    "paleocreștinii": "paleocreștin",
    "paleocreștinilor": "paleocreștin",
    "paleocreștinul": "paleocreștin",
    "paleocreștinului": "paleocreștin",
    "paleogena": "paleogen",
    "paleogenă": "paleogen",
    "paleogene": "paleogen",
    "paleogenei": "paleogen",
    "paleogenele": "paleogen",
    "paleogenelor": "paleogen",
    "paleogeni": "paleogen",
    "paleogenii": "paleogen",
    "paleogenilor": "paleogen",
    "paleogenul": "paleogen",
    "paleogenului": "paleogen",
    "paleografi": "paleograf",
    "paleografii": "paleograf",
    "paleografilor": "paleograf",
    "paleograful": "paleograf",
    "paleografului": "paleograf",
    "paleografia": "paleografie",
    "paleografiei": "paleografie",
    "paleografii": "paleografie",
    "paleolitica": "paleolitic",
    "paleolitică": "paleolitic",
    "paleolitice": "paleolitic",
    "paleoliticei": "paleolitic",
    "paleoliticele": "paleolitic",
    "paleoliticelor": "paleolitic",
    "paleolitici": "paleolitic",
    "paleoliticii": "paleolitic",
    "paleoliticilor": "paleolitic",
    "paleoliticul": "paleolitic",
    "paleoliticului": "paleolitic",
    "paleontologi": "paleontolog",
    "paleontologii": "paleontolog",
    "paleontologilor": "paleontolog",
    "paleontologul": "paleontolog",
    "paleontologului": "paleontolog",
    "paleontologica": "paleontologic",
    "paleontologică": "paleontologic",
    "paleontologice": "paleontologic",
    "paleontologicei": "paleontologic",
    "paleontologicele": "paleontologic",
    "paleontologicelor": "paleontologic",
    "paleontologici": "paleontologic",
    "paleontologicii": "paleontologic",
    "paleontologicilor": "paleontologic",
    "paleontologicul": "paleontologic",
    "paleontologicului": "paleontologic",
    "paleont.": "paleontologie",
    "paleontologia": "paleontologie",
    "paleontologiei": "paleontologie",
    "paleontologii": "paleontologie",
    "paleoterii": "paleoteriu",
    "paleoteriii": "paleoteriu",
    "paleoteriilor": "paleoteriu",
    "paleoteriul": "paleoteriu",
    "paleoteriului": "paleoteriu",
    "palestiniana": "palestinian",
    "palestiniană": "palestinian",
    "palestinianul": "palestinian",
    "palestinianului": "palestinian",
    "palestiniene": "palestinian",
    "palestinienei": "palestinian",
    "palestinienele": "palestinian",
    "palestinienelor": "palestinian",
    "palestinieni": "palestinian",
    "palestinienii": "palestinian",
    "palestinienilor": "palestinian",
    "palestra": "palestră",
    "palestre": "palestră",
    "palestrei": "palestră",
    "palestrele": "palestră",
    "palestrelor": "palestră",
    "paleta": "paletă",
    "palete": "paletă",
    "paletei": "paletă",
    "paletele": "paletă",
    "paletelor": "paletă",
    "nemaipălind": "păli",
    "nemaipălindu": "păli",
    "nepălind": "păli",
    "nepălindu": "păli",
    "pălea": "păli",
    "păleai": "păli",
    "păleam": "păli",
    "pălească": "păli",
    "păleați": "păli",
    "păleau": "păli",
    "pălesc": "păli",
    "pălește": "păli",
    "pălești": "păli",
    "pălii": "păli",
    "pălim": "păli",
    "pălind": "păli",
    "pălindu": "păli",
    "păliră": "păli",
    "pălirăm": "păli",
    "pălirăți": "păli",
    "pălise": "păli",
    "pălisem": "păli",
    "păliseră": "păli",
    "păliserăm": "păli",
    "păliserăți": "păli",
    "păliseși": "păli",
    "păliși": "păli",
    "pălit": "păli",
    "păliți": "păli",
    "paliativa": "paliativ",
    "paliativă": "paliativ",
    "paliative": "paliativ",
    "paliativei": "paliativ",
    "paliativele": "paliativ",
    "paliativelor": "paliativ",
    "paliativi": "paliativ",
    "paliativii": "paliativ",
    "paliativilor": "paliativ",
    "paliativul": "paliativ",
    "paliativului": "paliativ",
    "palida": "palid",
    "palidă": "palid",
    "palide": "palid",
    "palidei": "palid",
    "palidele": "palid",
    "palidelor": "palid",
    "palidul": "palid",
    "palidului": "palid",
    "palizi": "palid",
    "palizii": "palid",
    "palizilor": "palid",
    "paliditatea": "paliditate",
    "palidități": "paliditate",
    "palidității": "paliditate",
    "palia": "palie",
    "paliei": "palie",
    "palii": "palie",
    "paliile": "palie",
    "paliilor": "palie",
    "paliere": "palier",
    "palierele": "palier",
    "palierelor": "palier",
    "palierul": "palier",
    "palierului": "palier",
    "palimpseste": "palimpsest",
    "palimpsestele": "palimpsest",
    "palimpsestelor": "palimpsest",
    "palimpsestul": "palimpsest",
    "palimpsestului": "palimpsest",
    "pălirea": "pălire",
    "păliri": "pălire",
    "pălirii": "pălire",
    "palisandri": "palisandru",
    "palisandrii": "palisandru",
    "palisandrilor": "palisandru",
    "palisandrul": "palisandru",
    "palisandrului": "palisandru",
    "pălita": "pălit",
    "pălită": "pălit",
    "pălite": "pălit",
    "pălitei": "pălit",
    "pălitele": "pălit",
    "pălitelor": "pălit",
    "păliți": "pălit",
    "păliții": "pălit",
    "păliților": "pălit",
    "pălitul": "pălit",
    "pălitului": "pălit",
    "palma": "palmă",
    "palme": "palmă",
    "palmei": "palmă",
    "palmele": "palmă",
    "palmelor": "palmă",
    "palmaresul": "palmares",
    "palmaresului": "palmares",
    "palmaresuri": "palmares",
    "palmaresurile": "palmares",
    "palmaresurilor": "palmares",
    "palmata": "palmat",
    "palmată": "palmat",
    "palmate": "palmat",
    "palmatei": "palmat",
    "palmatele": "palmat",
    "palmatelor": "palmat",
    "palmați": "palmat",
    "palmații": "palmat",
    "palmaților": "palmat",
    "palmatul": "palmat",
    "palmatului": "palmat",
    "palmieri": "palmier",
    "palmierii": "palmier",
    "palmierilor": "palmier",
    "palmierul": "palmier",
    "palmierului": "palmier",
    "palmipede": "palmiped",
    "palmipedele": "palmiped",
    "palmipedelor": "palmiped",
    "palmipedul": "palmiped",
    "palmipedului": "palmiped",
    "nemaipălmuind": "pălmui",
    "nemaipălmuindu": "pălmui",
    "nepălmuind": "pălmui",
    "nepălmuindu": "pălmui",
    "pălmuia": "pălmui",
    "pălmuiai": "pălmui",
    "pălmuiam": "pălmui",
    "pălmuiască": "pălmui",
    "pălmuiați": "pălmui",
    "pălmuiau": "pălmui",
    "pălmuiesc": "pălmui",
    "pălmuiește": "pălmui",
    "pălmuiești": "pălmui",
    "pălmuii": "pălmui",
    "pălmuim": "pălmui",
    "pălmuind": "pălmui",
    "pălmuindu": "pălmui",
    "pălmuiră": "pălmui",
    "pălmuirăm": "pălmui",
    "pălmuirăți": "pălmui",
    "pălmuise": "pălmui",
    "pălmuisem": "pălmui",
    "pălmuiseră": "pălmui",
    "pălmuiserăm": "pălmui",
    "pălmuiserăți": "pălmui",
    "pălmuiseși": "pălmui",
    "pălmuiși": "pălmui",
    "pălmuit": "pălmui",
    "pălmuiți": "pălmui",
    "pălmuita": "pălmuit",
    "pălmuită": "pălmuit",
    "pălmuite": "pălmuit",
    "pălmuitei": "pălmuit",
    "pălmuitele": "pălmuit",
    "pălmuitelor": "pălmuit",
    "pălmuiți": "pălmuit",
    "pălmuiții": "pălmuit",
    "pălmuiților": "pălmuit",
    "pălmuitul": "pălmuit",
    "pălmuitului": "pălmuit",
    "pâlnia": "pâlnie",
    "pâlniei": "pâlnie",
    "pâlnii": "pâlnie",
    "pâlniile": "pâlnie",
    "pâlniilor": "pâlnie",
    "paloarea": "paloare",
    "palori": "paloare",
    "palorii": "paloare",
    "palorile": "paloare",
    "palorilor": "paloare",
    "paloșe": "paloș",
    "paloșele": "paloș",
    "paloșelor": "paloș",
    "paloșul": "paloș",
    "paloșului": "paloș",
    "palpabila": "palpabil",
    "palpabilă": "palpabil",
    "palpabile": "palpabil",
    "palpabilei": "palpabil",
    "palpabilele": "palpabil",
    "palpabilelor": "palpabil",
    "palpabili": "palpabil",
    "palpabilii": "palpabil",
    "palpabililor": "palpabil",
    "palpabilul": "palpabil",
    "palpabilului": "palpabil",
    "nemaipâlpâind": "pâlpâi",
    "nemaipâlpâindu": "pâlpâi",
    "nepâlpâind": "pâlpâi",
    "nepâlpâindu": "pâlpâi",
    "pâlpâia": "pâlpâi",
    "pâlpâiai": "pâlpâi",
    "pâlpâiam": "pâlpâi",
    "pâlpâiați": "pâlpâi",
    "pâlpâiau": "pâlpâi",
    "pâlpâie": "pâlpâi",
    "pâlpâii": "pâlpâi",
    "pâlpâim": "pâlpâi",
    "pâlpâind": "pâlpâi",
    "pâlpâindu": "pâlpâi",
    "pâlpâiră": "pâlpâi",
    "pâlpâirăm": "pâlpâi",
    "pâlpâirăți": "pâlpâi",
    "pâlpâise": "pâlpâi",
    "pâlpâisem": "pâlpâi",
    "pâlpâiseră": "pâlpâi",
    "pâlpâiserăm": "pâlpâi",
    "pâlpâiserăți": "pâlpâi",
    "pâlpâiseși": "pâlpâi",
    "pâlpâiși": "pâlpâi",
    "pâlpâit": "pâlpâi",
    "pâlpâiți": "pâlpâi",
    "pâlpâiala": "pâlpâială",
    "pâlpâieli": "pâlpâială",
    "pâlpâielii": "pâlpâială",
    "pâlpâielile": "pâlpâială",
    "pâlpâielilor": "pâlpâială",
    "pâlpâirea": "pâlpâire",
    "pâlpâiri": "pâlpâire",
    "pâlpâirii": "pâlpâire",
    "pâlpâirile": "pâlpâire",
    "pâlpâirilor": "pâlpâire",
    "pâlpâită": "pâlpâit",
    "pâlpâite": "pâlpâit",
    "pâlpâiți": "pâlpâit",
    "pâlpâitul": "pâlpâit",
    "pâlpâitului": "pâlpâit",
    "pâlpâitoare": "pâlpâitor",
    "pâlpâitoarea": "pâlpâitor",
    "pâlpâitoarei": "pâlpâitor",
    "pâlpâitoarele": "pâlpâitor",
    "pâlpâitoarelor": "pâlpâitor",
    "pâlpâitori": "pâlpâitor",
    "pâlpâitorii": "pâlpâitor",
    "pâlpâitorilor": "pâlpâitor",
    "pâlpâitorul": "pâlpâitor",
    "pâlpâitorului": "pâlpâitor",
    "nemaipalpitând": "palpita",
    "nemaipalpitându": "palpita",
    "nepalpitând": "palpita",
    "nepalpitându": "palpita",
    "palpit": "palpita",
    "palpită": "palpita",
    "palpitai": "palpita",
    "palpitam": "palpita",
    "palpităm": "palpita",
    "palpitând": "palpita",
    "palpitându": "palpita",
    "palpitară": "palpita",
    "palpitarăm": "palpita",
    "palpitarăți": "palpita",
    "palpitase": "palpita",
    "palpitasem": "palpita",
    "palpitaseră": "palpita",
    "palpitaserăm": "palpita",
    "palpitaserăți": "palpita",
    "palpitaseși": "palpita",
    "palpitași": "palpita",
    "palpitat": "palpita",
    "palpitați": "palpita",
    "palpitau": "palpita",
    "palpite": "palpita",
    "palpiți": "palpita",
    "palpitanta": "palpitant",
    "palpitantă": "palpitant",
    "palpitante": "palpitant",
    "palpitantei": "palpitant",
    "palpitantele": "palpitant",
    "palpitantelor": "palpitant",
    "palpitanți": "palpitant",
    "palpitanții": "palpitant",
    "palpitanților": "palpitant",
    "palpitantul": "palpitant",
    "palpitantului": "palpitant",
    "palpitată": "palpitat",
    "palpitate": "palpitat",
    "palpitați": "palpitat",
    "palpitația": "palpitație",
    "palpitației": "palpitație",
    "palpitații": "palpitație",
    "palpitațiile": "palpitație",
    "palpitațiilor": "palpitație",
    "paltini": "paltin",
    "paltinii": "paltin",
    "paltinilor": "paltin",
    "paltinul": "paltin",
    "paltinului": "paltin",
    "paltoane": "palton",
    "paltoanele": "palton",
    "paltoanelor": "palton",
    "paltonul": "palton",
    "paltonului": "palton",
    "paludica": "paludic",
    "paludică": "paludic",
    "paludice": "paludic",
    "paludicei": "paludic",
    "paludicele": "paludic",
    "paludicelor": "paludic",
    "paludici": "paludic",
    "paludicii": "paludic",
    "paludicilor": "paludic",
    "paludicul": "paludic",
    "paludicului": "paludic",
    "paludismul": "paludism",
    "paludismului": "paludism",
    "palustra": "palustru",
    "palustră": "palustru",
    "palustre": "palustru",
    "palustrei": "palustru",
    "palustrele": "palustru",
    "palustrelor": "palustru",
    "paluștri": "palustru",
    "paluștrii": "palustru",
    "paluștrilor": "palustru",
    "palustrul": "palustru",
    "palustrului": "palustru",
    "pământul": "pământ",
    "pământului": "pământ",
    "pământuri": "pământ",
    "pământurile": "pământ",
    "pământurilor": "pământ",
    "pământeana": "pământean",
    "pământeană": "pământean",
    "pământeanul": "pământean",
    "pământeanului": "pământean",
    "pământene": "pământean",
    "pământenei": "pământean",
    "pământenele": "pământean",
    "pământenelor": "pământean",
    "pământeni": "pământean",
    "pământenii": "pământean",
    "pământenilor": "pământean",
    "pământeanca": "pământeancă",
    "pământence": "pământeancă",
    "pământencei": "pământeancă",
    "pământencele": "pământeancă",
    "pământencelor": "pământeancă",
    "pământeasca": "pământesc",
    "pământească": "pământesc",
    "pământescul": "pământesc",
    "pământescului": "pământesc",
    "pământești": "pământesc",
    "pământeștii": "pământesc",
    "pământeștile": "pământesc",
    "pământeștilor": "pământesc",
    "pământia": "pământiu",
    "pământie": "pământiu",
    "pământiei": "pământiu",
    "pământii": "pământiu",
    "pământiii": "pământiu",
    "pământiile": "pământiu",
    "pământiilor": "pământiu",
    "pământiul": "pământiu",
    "pământiului": "pământiu",
    "pamflete": "pamflet",
    "pamfletele": "pamflet",
    "pamfletelor": "pamflet",
    "pamfletul": "pamflet",
    "pamfletului": "pamflet",
    "pamfletara": "pamfletar",
    "pamfletară": "pamfletar",
    "pamfletare": "pamfletar",
    "pamfletarei": "pamfletar",
    "pamfletarele": "pamfletar",
    "pamfletarelor": "pamfletar",
    "pamfletari": "pamfletar",
    "pamfletarii": "pamfletar",
    "pamfletarilor": "pamfletar",
    "pamfletarul": "pamfletar",
    "pamfletarului": "pamfletar",
    "pamfletăreasca": "pamfletăresc",
    "pamfletărească": "pamfletăresc",
    "pamfletărescul": "pamfletăresc",
    "pamfletărescului": "pamfletăresc",
    "pamfletărești": "pamfletăresc",
    "pamfletăreștii": "pamfletăresc",
    "pamfletăreștile": "pamfletăresc",
    "pamfletăreștilor": "pamfletăresc",
    "pampasul": "pampas",
    "pampasului": "pampas",
    "pampasuri": "pampas",
    "pampasurile": "pampas",
    "pampasurilor": "pampas",
    "pana": "pană",
    "pene": "pană",
    "penei": "pană",
    "penele": "pană",
    "penelor": "pană",
    "pân": "până",
    "pân-": "până",
    "până-": "până",
    "până-n": "până_în",
    "pân-la": "până_la",
    "panacee": "panaceu",
    "panaceele": "panaceu",
    "panaceelor": "panaceu",
    "panaceul": "panaceu",
    "panaceului": "panaceu",
    "panamale": "panama",
    "panamalei": "panama",
    "panamalele": "panama",
    "panamalelor": "panama",
    "panamaua": "panama",
    "panamericana": "panamerican",
    "panamericană": "panamerican",
    "panamericane": "panamerican",
    "panamericanei": "panamerican",
    "panamericanele": "panamerican",
    "panamericanelor": "panamerican",
    "panamericani": "panamerican",
    "panamericanii": "panamerican",
    "panamericanilor": "panamerican",
    "panamericanul": "panamerican",
    "panamericanului": "panamerican",
    "panameza": "panamez",
    "panameză": "panamez",
    "panameze": "panamez",
    "panamezei": "panamez",
    "panamezele": "panamez",
    "panamezelor": "panamez",
    "panamezi": "panamez",
    "panamezii": "panamez",
    "panamezilor": "panamez",
    "panamezul": "panamez",
    "panamezului": "panamez",
    "panariții": "panarițiu",
    "panarițiile": "panarițiu",
    "panarițiilor": "panarițiu",
    "panarițiul": "panarițiu",
    "panarițiului": "panarițiu",
    "panașul": "panaș",
    "panașului": "panaș",
    "panașuri": "panaș",
    "panașurile": "panaș",
    "panașurilor": "panaș",
    "panașata": "panașat",
    "panașată": "panașat",
    "panașate": "panașat",
    "panașatei": "panașat",
    "panașatele": "panașat",
    "panașatelor": "panașat",
    "panașați": "panașat",
    "panașații": "panașat",
    "panașaților": "panașat",
    "panașatul": "panașat",
    "panașatului": "panașat",
    "pancarta": "pancartă",
    "pancarte": "pancartă",
    "pancartei": "pancartă",
    "pancartele": "pancartă",
    "pancartelor": "pancartă",
    "pancratiastul": "pancratiast",
    "pancreasul": "pancreas",
    "pancreasului": "pancreas",
    "pancreasuri": "pancreas",
    "pancreasurile": "pancreas",
    "pancreasurilor": "pancreas",
    "pancreatica": "pancreatic",
    "pancreatică": "pancreatic",
    "pancreatice": "pancreatic",
    "pancreaticei": "pancreatic",
    "pancreaticele": "pancreatic",
    "pancreaticelor": "pancreatic",
    "pancreatici": "pancreatic",
    "pancreaticii": "pancreatic",
    "pancreaticilor": "pancreatic",
    "pancreaticul": "pancreatic",
    "pancreaticului": "pancreatic",
    "pânda": "pândă",
    "pânde": "pândă",
    "pândei": "pândă",
    "pândele": "pândă",
    "pândelor": "pândă",
    "pandalia": "pandalie",
    "pandaliei": "pandalie",
    "pandalii": "pandalie",
    "pandaliile": "pandalie",
    "pandaliilor": "pandalie",
    "pandante": "pandant",
    "pandantele": "pandant",
    "pandantelor": "pandant",
    "pandantul": "pandant",
    "pandantului": "pandant",
    "pandantive": "pandantiv",
    "pandantivele": "pandantiv",
    "pandantivelor": "pandantiv",
    "pandantivul": "pandantiv",
    "pandantivului": "pandantiv",
    "pândari": "pândar",
    "pândarii": "pândar",
    "pândarilor": "pândar",
    "pândarul": "pândar",
    "pândarului": "pândar",
    "nemaipândind": "pândi",
    "nemaipândindu": "pândi",
    "nepândind": "pândi",
    "nepândindu": "pândi",
    "pândea": "pândi",
    "pândeai": "pândi",
    "pândeam": "pândi",
    "pândească": "pândi",
    "pândeați": "pândi",
    "pândeau": "pândi",
    "pândesc": "pândi",
    "pândește": "pândi",
    "pândești": "pândi",
    "pândii": "pândi",
    "pândim": "pândi",
    "pândind": "pândi",
    "pândindu": "pândi",
    "pândiră": "pândi",
    "pândirăm": "pândi",
    "pândirăți": "pândi",
    "pândise": "pândi",
    "pândisem": "pândi",
    "pândiseră": "pândi",
    "pândiserăm": "pândi",
    "pândiserăți": "pândi",
    "pândiseși": "pândi",
    "pândiși": "pândi",
    "pândit": "pândi",
    "pândiți": "pândi",
    "pandișpanul": "pandișpan",
    "pandișpanului": "pandișpan",
    "pandișpanuri": "pandișpan",
    "pandișpanurile": "pandișpan",
    "pandișpanurilor": "pandișpan",
    "pândită": "pândit",
    "pândite": "pândit",
    "pândiți": "pândit",
    "pânditul": "pândit",
    "pânditului": "pândit",
    "pânditoare": "pânditor",
    "pânditoarea": "pânditor",
    "pânditoarei": "pânditor",
    "pânditoarele": "pânditor",
    "pânditoarelor": "pânditor",
    "pânditori": "pânditor",
    "pânditorii": "pânditor",
    "pânditorilor": "pânditor",
    "pânditorul": "pânditor",
    "pânditorului": "pânditor",
    "Pandorei": "Pandora",
    "panduri": "pandur",
    "pandurii": "pandur",
    "pandurilor": "pandur",
    "pandurul": "pandur",
    "pandurului": "pandur",
    "pandureasca": "panduresc",
    "pandurească": "panduresc",
    "pandurescul": "panduresc",
    "pandurescului": "panduresc",
    "pandurești": "panduresc",
    "pandureștii": "panduresc",
    "pandureștile": "panduresc",
    "pandureștilor": "panduresc",
    "panegirice": "panegiric",
    "panegiricele": "panegiric",
    "panegiricelor": "panegiric",
    "panegiricul": "panegiric",
    "panegiricului": "panegiric",
    "panelenica": "panelenic",
    "panelenică": "panelenic",
    "panelenice": "panelenic",
    "panelenicei": "panelenic",
    "panelenicele": "panelenic",
    "panelenicelor": "panelenic",
    "panelenici": "panelenic",
    "panelenicii": "panelenic",
    "panelenicilor": "panelenic",
    "panelenicul": "panelenic",
    "panelenicului": "panelenic",
    "panere": "paner",
    "panerele": "paner",
    "panerelor": "paner",
    "panerul": "paner",
    "panerului": "paner",
    "nemaipângărind": "pângări",
    "nemaipângărindu": "pângări",
    "nepângărind": "pângări",
    "nepângărindu": "pângări",
    "pângărea": "pângări",
    "pângăreai": "pângări",
    "pângăream": "pângări",
    "pângărească": "pângări",
    "pângăreați": "pângări",
    "pângăreau": "pângări",
    "pângăresc": "pângări",
    "pângărește": "pângări",
    "pângărești": "pângări",
    "pângării": "pângări",
    "pângărim": "pângări",
    "pângărind": "pângări",
    "pângărindu": "pângări",
    "pângăriră": "pângări",
    "pângărirăm": "pângări",
    "pângărirăți": "pângări",
    "pângărise": "pângări",
    "pângărisem": "pângări",
    "pângăriseră": "pângări",
    "pângăriserăm": "pângări",
    "pângăriserăți": "pângări",
    "pângăriseși": "pângări",
    "pângăriși": "pângări",
    "pângărit": "pângări",
    "pângăriți": "pângări",
    "pângărirea": "pângărire",
    "pângăriri": "pângărire",
    "pângăririi": "pângărire",
    "pângăririle": "pângărire",
    "pângăririlor": "pângărire",
    "pângărită": "pângărit",
    "pângărite": "pângărit",
    "pângăriți": "pângărit",
    "pângăritoarea": "pângăritoare",
    "pângăritoarele": "pângăritoare",
    "pângăritoarelor": "pângăritoare",
    "pângăritoare": "pângăritor",
    "pângăritoarea": "pângăritor",
    "pângăritoarei": "pângăritor",
    "pângăritoarele": "pângăritor",
    "pângăritoarelor": "pângăritor",
    "pângăritori": "pângăritor",
    "pângăritorii": "pângăritor",
    "pângăritorilor": "pângăritor",
    "pângăritorul": "pângăritor",
    "pângăritorului": "pângăritor",
    "panglica": "panglică",
    "panglici": "panglică",
    "panglicii": "panglică",
    "panglicile": "panglică",
    "panglicilor": "panglică",
    "panglicari": "panglicar",
    "panglicarii": "panglicar",
    "panglicarilor": "panglicar",
    "panglicarul": "panglicar",
    "panglicarului": "panglicar",
    "panglicăria": "panglicărie",
    "panglicăriei": "panglicărie",
    "panglicării": "panglicărie",
    "panglicăriile": "panglicărie",
    "panglicăriilor": "panglicărie",
    "panica": "panică",
    "panici": "panică",
    "panicii": "panică",
    "panicile": "panică",
    "panicilor": "panică",
    "panicarda": "panicard",
    "panicardă": "panicard",
    "panicarde": "panicard",
    "panicardei": "panicard",
    "panicardele": "panicard",
    "panicardelor": "panicard",
    "panicardul": "panicard",
    "panicardului": "panicard",
    "panicarzi": "panicard",
    "panicarzii": "panicard",
    "panicarzilor": "panicard",
    "nemaipanificând": "panifica",
    "nemaipanificându": "panifica",
    "nepanificând": "panifica",
    "nepanificându": "panifica",
    "panific": "panifica",
    "panifică": "panifica",
    "panificai": "panifica",
    "panificam": "panifica",
    "panificăm": "panifica",
    "panificând": "panifica",
    "panificându": "panifica",
    "panificară": "panifica",
    "panificarăm": "panifica",
    "panificarăți": "panifica",
    "panificase": "panifica",
    "panificasem": "panifica",
    "panificaseră": "panifica",
    "panificaserăm": "panifica",
    "panificaserăți": "panifica",
    "panificaseși": "panifica",
    "panificași": "panifica",
    "panificat": "panifica",
    "panificați": "panifica",
    "panificau": "panifica",
    "panifice": "panifica",
    "panifici": "panifica",
    "panificabila": "panificabil",
    "panificabilă": "panificabil",
    "panificabile": "panificabil",
    "panificabilei": "panificabil",
    "panificabilele": "panificabil",
    "panificabilelor": "panificabil",
    "panificabili": "panificabil",
    "panificabilii": "panificabil",
    "panificabililor": "panificabil",
    "panificabilul": "panificabil",
    "panificabilului": "panificabil",
    "panificată": "panificat",
    "panificate": "panificat",
    "panificați": "panificat",
    "panificația": "panificație",
    "panificației": "panificație",
    "panificații": "panificație",
    "panoniana": "panonian",
    "panoniană": "panonian",
    "panonianul": "panonian",
    "panonianului": "panonian",
    "panoniene": "panonian",
    "panonienei": "panonian",
    "panonienele": "panonian",
    "panonienelor": "panonian",
    "panonieni": "panonian",
    "panonienii": "panonian",
    "panonienilor": "panonian",
    "panonica": "panonic",
    "panonică": "panonic",
    "panonice": "panonic",
    "panonicei": "panonic",
    "panonicele": "panonic",
    "panonicelor": "panonic",
    "panonici": "panonic",
    "panonicii": "panonic",
    "panonicilor": "panonic",
    "panonicul": "panonic",
    "panonicului": "panonic",
    "panoplia": "panoplie",
    "panopliei": "panoplie",
    "panoplii": "panoplie",
    "panopliile": "panoplie",
    "panopliilor": "panoplie",
    "panoptice": "panoptic",
    "panopticele": "panoptic",
    "panopticelor": "panoptic",
    "panopticul": "panoptic",
    "panopticului": "panoptic",
    "panorama": "panoramă",
    "panorame": "panoramă",
    "panoramei": "panoramă",
    "panoramele": "panoramă",
    "panoramelor": "panoramă",
    "panoramarea": "panoramare",
    "panoramari": "panoramare",
    "panoramarii": "panoramare",
    "panoramarile": "panoramare",
    "panoramarilor": "panoramare",
    "panoramica": "panoramic",
    "panoramică": "panoramic",
    "panoramice": "panoramic",
    "panoramicei": "panoramic",
    "panoramicele": "panoramic",
    "panoramicelor": "panoramic",
    "panoramici": "panoramic",
    "panoramicii": "panoramic",
    "panoramicilor": "panoramic",
    "panoramicul": "panoramic",
    "panoramicului": "panoramic",
    "panoul": "panou",
    "panoului": "panou",
    "panouri": "panou",
    "panourile": "panou",
    "panourilor": "panou",
    "nemaipansând": "pansa",
    "nemaipansându": "pansa",
    "nepansând": "pansa",
    "nepansându": "pansa",
    "pansă": "pansa",
    "pansai": "pansa",
    "pansam": "pansa",
    "pansăm": "pansa",
    "pansând": "pansa",
    "pansându": "pansa",
    "pansară": "pansa",
    "pansarăm": "pansa",
    "pansarăți": "pansa",
    "pansase": "pansa",
    "pansasem": "pansa",
    "pansaseră": "pansa",
    "pansaserăm": "pansa",
    "pansaserăți": "pansa",
    "pansaseși": "pansa",
    "pansași": "pansa",
    "pansat": "pansa",
    "pansați": "pansa",
    "pansau": "pansa",
    "pansează": "pansa",
    "pansez": "pansa",
    "panseze": "pansa",
    "pansezi": "pansa",
    "pansamente": "pansament",
    "pansamentele": "pansament",
    "pansamentelor": "pansament",
    "pansamentul": "pansament",
    "pansamentului": "pansament",
    "pansată": "pansat",
    "pansate": "pansat",
    "pansați": "pansat",
    "panseaua": "pansea",
    "pansele": "pansea",
    "panselei": "pansea",
    "panselele": "pansea",
    "panselelor": "pansea",
    "panseluța": "panseluță",
    "panseluțe": "panseluță",
    "panseluței": "panseluță",
    "panseluțele": "panseluță",
    "panseluțelor": "panseluță",
    "panseul": "panseu",
    "panseului": "panseu",
    "panseuri": "panseu",
    "panseurile": "panseu",
    "panseurilor": "panseu",
    "panta": "pantă",
    "pante": "pantă",
    "pantei": "pantă",
    "pantele": "pantă",
    "pantelor": "pantă",
    "pantagruelica": "pantagruelic",
    "pantagruelică": "pantagruelic",
    "pantagruelice": "pantagruelic",
    "pantagruelicei": "pantagruelic",
    "pantagruelicele": "pantagruelic",
    "pantagruelicelor": "pantagruelic",
    "pantagruelici": "pantagruelic",
    "pantagruelicii": "pantagruelic",
    "pantagruelicilor": "pantagruelic",
    "pantagruelicul": "pantagruelic",
    "pantagruelicului": "pantagruelic",
    "pantaloni": "pantalon",
    "pantalonii": "pantalon",
    "pantalonilor": "pantalon",
    "pantalonul": "pantalon",
    "pantalonului": "pantalon",
    "pantalonari": "pantalonar",
    "pantalonarii": "pantalonar",
    "pantalonarilor": "pantalonar",
    "pantalonarul": "pantalonar",
    "pantalonarului": "pantalonar",
    "pântecul": "pântec",
    "pântecului": "pântec",
    "pântecele": "pântece",
    "pântecelor": "pântece",
    "pântecelui": "pântece",
    "pântecoasa": "pântecos",
    "pântecoasă": "pântecos",
    "pântecoase": "pântecos",
    "pântecoasei": "pântecos",
    "pântecoasele": "pântecos",
    "pântecoaselor": "pântecos",
    "pântecoși": "pântecos",
    "pântecoșii": "pântecos",
    "pântecoșilor": "pântecos",
    "pântecosul": "pântecos",
    "pântecosului": "pântecos",
    "panteismul": "panteism",
    "panteismului": "panteism",
    "panteista": "panteist",
    "panteistă": "panteist",
    "panteiste": "panteist",
    "panteistei": "panteist",
    "panteistele": "panteist",
    "panteistelor": "panteist",
    "panteiști": "panteist",
    "panteiștii": "panteist",
    "panteiștilor": "panteist",
    "panteistul": "panteist",
    "panteistului": "panteist",
    "panteistica": "panteistic",
    "panteistică": "panteistic",
    "panteistice": "panteistic",
    "panteisticei": "panteistic",
    "panteisticele": "panteistic",
    "panteisticelor": "panteistic",
    "panteistici": "panteistic",
    "panteisticii": "panteistic",
    "panteisticilor": "panteistic",
    "panteisticul": "panteistic",
    "panteisticului": "panteistic",
    "Pantelimonul": "Pantelimon",
    "Pantelimonului": "Pantelimon",
    "panteonul": "panteon",
    "panteonului": "panteon",
    "panteonuri": "panteon",
    "panteonurile": "panteon",
    "panteonurilor": "panteon",
    "pantera": "panteră",
    "pantere": "panteră",
    "panterei": "panteră",
    "panterele": "panteră",
    "panterelor": "panteră",
    "pantofi": "pantof",
    "pantofii": "pantof",
    "pantofilor": "pantof",
    "pantoful": "pantof",
    "pantofului": "pantof",
    "pantofăria": "pantofărie",
    "pantofăriei": "pantofărie",
    "pantofării": "pantofărie",
    "pantofăriile": "pantofărie",
    "pantofăriilor": "pantofărie",
    "pantografe": "pantograf",
    "pantografele": "pantograf",
    "pantografelor": "pantograf",
    "pantograful": "pantograf",
    "pantografului": "pantograf",
    "pantomimi": "pantomim",
    "pantomimii": "pantomim",
    "pantomimilor": "pantomim",
    "pantomimul": "pantomim",
    "pantomimului": "pantomim",
    "pantomima": "pantomimă",
    "pantomime": "pantomimă",
    "pantomimei": "pantomimă",
    "pantomimele": "pantomimă",
    "pantomimelor": "pantomimă",
    "pantomimica": "pantomimic",
    "pantomimică": "pantomimic",
    "pantomimice": "pantomimic",
    "pantomimicei": "pantomimic",
    "pantomimicele": "pantomimic",
    "pantomimicelor": "pantomimic",
    "pantomimici": "pantomimic",
    "pantomimicii": "pantomimic",
    "pantomimicilor": "pantomimic",
    "pantomimicul": "pantomimic",
    "pantomimicului": "pantomimic",
    "pănușa": "pănușă",
    "pănuși": "pănușă",
    "pănușii": "pănușă",
    "pănușile": "pănușă",
    "pănușilor": "pănușă",
    "pânza": "pânză",
    "pânze": "pânză",
    "pânzei": "pânză",
    "pânzele": "pânză",
    "pânzelor": "pânză",
    "pânzari": "pânzar",
    "pânzarii": "pânzar",
    "pânzarilor": "pânzar",
    "pânzarul": "pânzar",
    "pânzarului": "pânzar",
    "pânzata": "pânzat",
    "pânzată": "pânzat",
    "pânzate": "pânzat",
    "pânzatei": "pânzat",
    "pânzatele": "pânzat",
    "pânzatelor": "pânzat",
    "pânzați": "pânzat",
    "pânzații": "pânzat",
    "pânzaților": "pânzat",
    "pânzatul": "pânzat",
    "pânzatului": "pânzat",
    "papul": "pap",
    "papului": "pap",
    "papa": "papă",
    "papăl": "papă",
    "papălui": "papă",
    "papei": "papă",
    "papi": "papă",
    "papii": "papă",
    "papilor": "papă",
    "nemaipăpând": "păpa",
    "nemaipăpându": "păpa",
    "nepăpând": "păpa",
    "nepăpându": "păpa",
    "pap": "păpa",
    "papă": "păpa",
    "păpă": "păpa",
    "păpai": "păpa",
    "păpam": "păpa",
    "păpăm": "păpa",
    "păpând": "păpa",
    "păpându": "păpa",
    "păpară": "păpa",
    "păparăm": "păpa",
    "păparăți": "păpa",
    "păpase": "păpa",
    "păpasem": "păpa",
    "păpaseră": "păpa",
    "păpaserăm": "păpa",
    "păpaserăți": "păpa",
    "păpaseși": "păpa",
    "păpași": "păpa",
    "păpat": "păpa",
    "păpați": "păpa",
    "păpau": "păpa",
    "pape": "păpa",
    "papi": "păpa",
    "păpădia": "păpădie",
    "păpădiei": "păpădie",
    "păpădii": "păpădie",
    "păpădiile": "păpădie",
    "păpădiilor": "păpădie",
    "papagali": "papagal",
    "papagalii": "papagal",
    "papagalilor": "papagal",
    "papagalul": "papagal",
    "papagalului": "papagal",
    "papagaliceasca": "papagalicesc",
    "papagalicească": "papagalicesc",
    "papagalicescul": "papagalicesc",
    "papagalicescului": "papagalicesc",
    "papagalicești": "papagalicesc",
    "papagaliceștii": "papagalicesc",
    "papagaliceștile": "papagalicesc",
    "papagaliceștilor": "papagalicesc",
    "papala": "papal",
    "papală": "papal",
    "papale": "papal",
    "papalei": "papal",
    "papalele": "papal",
    "papalelor": "papal",
    "papali": "papal",
    "papalii": "papal",
    "papalilor": "papal",
    "papalul": "papal",
    "papalului": "papal",
    "papalitatea": "papalitate",
    "papalități": "papalitate",
    "papalității": "papalitate",
    "papanași": "papanaș",
    "papanașii": "papanaș",
    "papanașilor": "papanaș",
    "papanașul": "papanaș",
    "papanașului": "papanaș",
    "papara": "papară",
    "papăre": "papară",
    "papărei": "papară",
    "papari": "papară",
    "paparii": "papară",
    "paparuda": "paparudă",
    "paparude": "paparudă",
    "paparudei": "paparudă",
    "paparudele": "paparudă",
    "paparudelor": "paparudă",
    "păpată": "păpat",
    "păpate": "păpat",
    "păpați": "păpat",
    "papaverina": "papaverină",
    "papaverine": "papaverină",
    "papaverinei": "papaverină",
    "papetara": "papetar",
    "papetară": "papetar",
    "papetare": "papetar",
    "papetarei": "papetar",
    "papetarele": "papetar",
    "papetarelor": "papetar",
    "papetari": "papetar",
    "papetarii": "papetar",
    "papetarilor": "papetar",
    "papetarul": "papetar",
    "papetarului": "papetar",
    "papetăria": "papetărie",
    "papetăriei": "papetărie",
    "papetării": "papetărie",
    "papetăriile": "papetărie",
    "papetăriilor": "papetărie",
    "papila": "papilă",
    "papile": "papilă",
    "papilei": "papilă",
    "papilele": "papilă",
    "papilelor": "papilă",
    "papilara": "papilar",
    "papilară": "papilar",
    "papilare": "papilar",
    "papilarei": "papilar",
    "papilarele": "papilar",
    "papilarelor": "papilar",
    "papilari": "papilar",
    "papilarii": "papilar",
    "papilarilor": "papilar",
    "papilarul": "papilar",
    "papilarului": "papilar",
    "papioane": "papion",
    "papioanele": "papion",
    "papioanelor": "papion",
    "papionul": "papion",
    "papionului": "papion",
    "papiota": "papiotă",
    "papiote": "papiotă",
    "papiotei": "papiotă",
    "papiotele": "papiotă",
    "papiotelor": "papiotă",
    "papirologia": "papirologie",
    "papirologiei": "papirologie",
    "papirologii": "papirologie",
    "papirusul": "papirus",
    "papirusului": "papirus",
    "papirusuri": "papirus",
    "papirusurile": "papirus",
    "papirusurilor": "papirus",
    "papistașii": "papistaș",
    "papricașul": "papricaș",
    "papricașului": "papricaș",
    "papricașuri": "papricaș",
    "papricașurile": "papricaș",
    "papricașurilor": "papricaș",
    "papuașa": "papuaș",
    "papuașă": "papuaș",
    "papuașe": "papuaș",
    "papuașei": "papuaș",
    "papuașele": "papuaș",
    "papuașelor": "papuaș",
    "papuași": "papuaș",
    "papuașii": "papuaș",
    "papuașilor": "papuaș",
    "papuașul": "papuaș",
    "papuașului": "papuaș",
    "papuașa": "papuașă",
    "papuașe": "papuașă",
    "papuașei": "papuașă",
    "papuașele": "papuașă",
    "papuașelor": "papuașă",
    "papuci": "papuc",
    "papucii": "papuc",
    "papucilor": "papuc",
    "papucul": "papuc",
    "papucului": "papuc",
    "papura": "papură",
    "papuri": "papură",
    "papurii": "papură",
    "papurile": "papură",
    "papurilor": "papură",
    "păpușa": "păpușă",
    "păpuși": "păpușă",
    "păpușii": "păpușă",
    "păpușile": "păpușă",
    "păpușilor": "păpușă",
    "păpușari": "păpușar",
    "păpușarii": "păpușar",
    "păpușarilor": "păpușar",
    "păpușarul": "păpușar",
    "păpușarului": "păpușar",
    "para": "par",
    "pară": "par",
    "pare": "par",
    "parei": "par",
    "parele": "par",
    "parelor": "par",
    "pari": "par",
    "parii": "par",
    "parilor": "par",
    "parul": "par",
    "parului": "par",
    "părul": "păr",
    "părului": "păr",
    "peri": "păr",
    "perilor": "păr",
    "parale": "para",
    "paralei": "para",
    "paralele": "para",
    "paralelor": "para",
    "paraua": "para",
    "para": "pară",
    "pere": "pară",
    "perei": "pară",
    "perele": "pară",
    "perelor": "pară",
    "pâra": "pâră",
    "pâre": "pâră",
    "pârei": "pâră",
    "pârele": "pâră",
    "pârelor": "pâră",
    "parabila": "parabil",
    "parabilă": "parabil",
    "parabile": "parabil",
    "parabilei": "parabil",
    "parabilele": "parabil",
    "parabilelor": "parabil",
    "parabili": "parabil",
    "parabilii": "parabil",
    "parabililor": "parabil",
    "parabilul": "parabil",
    "parabilului": "parabil",
    "parabola": "parabolă",
    "parabole": "parabolă",
    "parabolei": "parabolă",
    "parabolele": "parabolă",
    "parabolelor": "parabolă",
    "parabolica": "parabolic",
    "parabolică": "parabolic",
    "parabolice": "parabolic",
    "parabolicei": "parabolic",
    "parabolicele": "parabolic",
    "parabolicelor": "parabolic",
    "parabolici": "parabolic",
    "parabolicii": "parabolic",
    "parabolicilor": "parabolic",
    "parabolicul": "parabolic",
    "parabolicului": "parabolic",
    "paraboloide": "paraboloid",
    "paraboloidele": "paraboloid",
    "paraboloidelor": "paraboloid",
    "paraboloidul": "paraboloid",
    "paraboloidului": "paraboloid",
    "paraboloidala": "paraboloidal",
    "paraboloidală": "paraboloidal",
    "paraboloidale": "paraboloidal",
    "paraboloidalei": "paraboloidal",
    "paraboloidalele": "paraboloidal",
    "paraboloidalelor": "paraboloidal",
    "paraboloidali": "paraboloidal",
    "paraboloidalii": "paraboloidal",
    "paraboloidalilor": "paraboloidal",
    "paraboloidalul": "paraboloidal",
    "paraboloidalului": "paraboloidal",
    "pârâcioasa": "pârâcios",
    "pârâcioasă": "pârâcios",
    "pârâcioase": "pârâcios",
    "pârâcioasei": "pârâcios",
    "pârâcioasele": "pârâcios",
    "pârâcioaselor": "pârâcios",
    "pârâcioși": "pârâcios",
    "pârâcioșii": "pârâcios",
    "pârâcioșilor": "pârâcios",
    "pârâciosul": "pârâcios",
    "pârâciosului": "pârâcios",
    "paraclise": "paraclis",
    "paraclisele": "paraclis",
    "paracliselor": "paraclis",
    "paraclisul": "paraclis",
    "paraclisului": "paraclis",
    "paracliseri": "paracliser",
    "paracliserii": "paracliser",
    "paracliserilor": "paracliser",
    "paracliserul": "paracliser",
    "paracliserului": "paracliser",
    "parada": "paradă",
    "parade": "paradă",
    "paradei": "paradă",
    "paradele": "paradă",
    "paradelor": "paradă",
    "parăzi": "paradă",
    "parăzii": "paradă",
    "parăzile": "paradă",
    "parăzilor": "paradă",
    "paradentoza": "paradentoză",
    "paradentoze": "paradentoză",
    "paradentozei": "paradentoză",
    "paradentozele": "paradentoză",
    "paradentozelor": "paradentoză",
    "paradigma": "paradigmă",
    "paradigme": "paradigmă",
    "paradigmei": "paradigmă",
    "paradigmele": "paradigmă",
    "paradigmelor": "paradigmă",
    "paradigmatica": "paradigmatic",
    "paradigmatică": "paradigmatic",
    "paradigmatice": "paradigmatic",
    "paradigmaticei": "paradigmatic",
    "paradigmaticele": "paradigmatic",
    "paradigmaticelor": "paradigmatic",
    "paradigmatici": "paradigmatic",
    "paradigmaticii": "paradigmatic",
    "paradigmaticilor": "paradigmatic",
    "paradigmaticul": "paradigmatic",
    "paradigmaticului": "paradigmatic",
    "paradisul": "paradis",
    "paradisului": "paradis",
    "paradisuri": "paradis",
    "paradisurile": "paradis",
    "paradisurilor": "paradis",
    "paradiziaca": "paradiziac",
    "paradiziacă": "paradiziac",
    "paradiziace": "paradiziac",
    "paradiziacei": "paradiziac",
    "paradiziacele": "paradiziac",
    "paradiziacelor": "paradiziac",
    "paradiziaci": "paradiziac",
    "paradiziacii": "paradiziac",
    "paradiziacilor": "paradiziac",
    "paradiziacul": "paradiziac",
    "paradiziacului": "paradiziac",
    "paradoxul": "paradox",
    "paradoxului": "paradox",
    "paradoxuri": "paradox",
    "paradoxurile": "paradox",
    "paradoxurilor": "paradox",
    "paradoxala": "paradoxal",
    "paradoxală": "paradoxal",
    "paradoxale": "paradoxal",
    "paradoxalei": "paradoxal",
    "paradoxalele": "paradoxal",
    "paradoxalelor": "paradoxal",
    "paradoxali": "paradoxal",
    "paradoxalii": "paradoxal",
    "paradoxalilor": "paradoxal",
    "paradoxalul": "paradoxal",
    "paradoxalului": "paradoxal",
    "nemaiparafând": "parafa",
    "nemaiparafându": "parafa",
    "neparafând": "parafa",
    "neparafându": "parafa",
    "parafă": "parafa",
    "parafai": "parafa",
    "parafam": "parafa",
    "parafăm": "parafa",
    "parafând": "parafa",
    "parafându": "parafa",
    "parafară": "parafa",
    "parafarăm": "parafa",
    "parafarăți": "parafa",
    "parafase": "parafa",
    "parafasem": "parafa",
    "parafaseră": "parafa",
    "parafaserăm": "parafa",
    "parafaserăți": "parafa",
    "parafaseși": "parafa",
    "parafași": "parafa",
    "parafat": "parafa",
    "parafați": "parafa",
    "parafau": "parafa",
    "parafează": "parafa",
    "parafez": "parafa",
    "parafeze": "parafa",
    "parafezi": "parafa",
    "parafa": "parafă",
    "parafe": "parafă",
    "parafei": "parafă",
    "parafele": "parafă",
    "parafelor": "parafă",
    "parafarea": "parafare",
    "parafări": "parafare",
    "parafării": "parafare",
    "parafările": "parafare",
    "parafărilor": "parafare",
    "parafată": "parafat",
    "parafate": "parafat",
    "parafați": "parafat",
    "parafina": "parafină",
    "parafine": "parafină",
    "parafinei": "parafină",
    "parafinele": "parafină",
    "parafinelor": "parafină",
    "parafinarea": "parafinare",
    "parafinări": "parafinare",
    "parafinării": "parafinare",
    "parafinările": "parafinare",
    "parafinărilor": "parafinare",
    "parafinica": "parafinic",
    "parafinică": "parafinic",
    "parafinice": "parafinic",
    "parafinicei": "parafinic",
    "parafinicele": "parafinic",
    "parafinicelor": "parafinic",
    "parafinici": "parafinic",
    "parafinicii": "parafinic",
    "parafinicilor": "parafinic",
    "parafinicul": "parafinic",
    "parafinicului": "parafinic",
    "parafinoasa": "parafinos",
    "parafinoasă": "parafinos",
    "parafinoase": "parafinos",
    "parafinoasei": "parafinos",
    "parafinoasele": "parafinos",
    "parafinoaselor": "parafinos",
    "parafinoși": "parafinos",
    "parafinoșii": "parafinos",
    "parafinoșilor": "parafinos",
    "parafinosul": "parafinos",
    "parafinosului": "parafinos",
    "nemaiparafrazând": "parafraza",
    "nemaiparafrazându": "parafraza",
    "neparafrazând": "parafraza",
    "neparafrazându": "parafraza",
    "parafrază": "parafraza",
    "parafrazai": "parafraza",
    "parafrazam": "parafraza",
    "parafrazăm": "parafraza",
    "parafrazând": "parafraza",
    "parafrazându": "parafraza",
    "parafrazară": "parafraza",
    "parafrazarăm": "parafraza",
    "parafrazarăți": "parafraza",
    "parafrazase": "parafraza",
    "parafrazasem": "parafraza",
    "parafrazaseră": "parafraza",
    "parafrazaserăm": "parafraza",
    "parafrazaserăți": "parafraza",
    "parafrazaseși": "parafraza",
    "parafrazași": "parafraza",
    "parafrazat": "parafraza",
    "parafrazați": "parafraza",
    "parafrazau": "parafraza",
    "parafrazează": "parafraza",
    "parafrazez": "parafraza",
    "parafrazeze": "parafraza",
    "parafrazezi": "parafraza",
    "parafraza": "parafrază",
    "parafraze": "parafrază",
    "parafrazei": "parafrază",
    "parafrazele": "parafrază",
    "parafrazelor": "parafrază",
    "parafrazarea": "parafrazare",
    "parafrazări": "parafrazare",
    "parafrazării": "parafrazare",
    "parafrazările": "parafrazare",
    "parafrazărilor": "parafrazare",
    "parafrazată": "parafrazat",
    "parafrazate": "parafrazat",
    "parafrazați": "parafrazat",
    "paragina": "paragină",
    "paragini": "paragină",
    "paraginii": "paragină",
    "paraginile": "paragină",
    "paraginilor": "paragină",
    "nemaipărăginind": "părăgini",
    "nemaipărăginindu": "părăgini",
    "nepărăginind": "părăgini",
    "nepărăginindu": "părăgini",
    "părăginea": "părăgini",
    "părăgineai": "părăgini",
    "părăgineam": "părăgini",
    "părăginească": "părăgini",
    "părăgineați": "părăgini",
    "părăgineau": "părăgini",
    "părăginesc": "părăgini",
    "părăginește": "părăgini",
    "părăginești": "părăgini",
    "părăginii": "părăgini",
    "părăginim": "părăgini",
    "părăginind": "părăgini",
    "părăginindu": "părăgini",
    "părăginiră": "părăgini",
    "părăginirăm": "părăgini",
    "părăginirăți": "părăgini",
    "părăginise": "părăgini",
    "părăginisem": "părăgini",
    "părăginiseră": "părăgini",
    "părăginiserăm": "părăgini",
    "părăginiserăți": "părăgini",
    "părăginiseși": "părăgini",
    "părăginiși": "părăgini",
    "părăginit": "părăgini",
    "părăginiți": "părăgini",
    "părăginirea": "părăginire",
    "părăginiri": "părăginire",
    "părăginirii": "părăginire",
    "părăginirile": "părăginire",
    "părăginirilor": "părăginire",
    "părăginita": "părăginit",
    "părăginită": "părăginit",
    "părăginite": "părăginit",
    "părăginitei": "părăginit",
    "părăginitele": "părăginit",
    "părăginitelor": "părăginit",
    "părăginiți": "părăginit",
    "părăginiții": "părăginit",
    "părăginiților": "părăginit",
    "părăginitul": "părăginit",
    "părăginitului": "părăginit",
    "paragrafe": "paragraf",
    "paragrafele": "paragraf",
    "paragrafelor": "paragraf",
    "paragraful": "paragraf",
    "paragrafului": "paragraf",
    "paraguayana": "paraguayan",
    "paraguayană": "paraguayan",
    "paraguayanul": "paraguayan",
    "paraguayanului": "paraguayan",
    "paraguayene": "paraguayan",
    "paraguayenei": "paraguayan",
    "paraguayenele": "paraguayan",
    "paraguayenelor": "paraguayan",
    "paraguayeni": "paraguayan",
    "paraguayenii": "paraguayan",
    "paraguayenilor": "paraguayan",
    "nemaipârâind": "pârâi",
    "nemaipârâindu": "pârâi",
    "nepârâind": "pârâi",
    "nepârâindu": "pârâi",
    "pârâia": "pârâi",
    "pârâiai": "pârâi",
    "pârâiam": "pârâi",
    "pârâiați": "pârâi",
    "pârâiau": "pârâi",
    "pârâie": "pârâi",
    "pârâii": "pârâi",
    "pârâim": "pârâi",
    "pârâind": "pârâi",
    "pârâindu": "pârâi",
    "pârâiră": "pârâi",
    "pârâirăm": "pârâi",
    "pârâirăți": "pârâi",
    "pârâise": "pârâi",
    "pârâisem": "pârâi",
    "pârâiseră": "pârâi",
    "pârâiserăm": "pârâi",
    "pârâiserăți": "pârâi",
    "pârâiseși": "pârâi",
    "pârâiși": "pârâi",
    "pârâit": "pârâi",
    "pârâiți": "pârâi",
    "pârâiașe": "pârâiaș",
    "pârâiașele": "pârâiaș",
    "pârâiașelor": "pârâiaș",
    "pârâiașul": "pârâiaș",
    "pârâiașului": "pârâiaș",
    "pârâitul": "pârâit",
    "pârâitului": "pârâit",
    "pârâitoare": "pârâitor",
    "pârâitoarea": "pârâitor",
    "pârâitoarei": "pârâitor",
    "pârâitoarele": "pârâitor",
    "pârâitoarelor": "pârâitor",
    "pârâitori": "pârâitor",
    "pârâitorii": "pârâitor",
    "pârâitorilor": "pârâitor",
    "pârâitorul": "pârâitor",
    "pârâitorului": "pârâitor",
    "paralactica": "paralactic",
    "paralactică": "paralactic",
    "paralactice": "paralactic",
    "paralacticei": "paralactic",
    "paralacticele": "paralactic",
    "paralacticelor": "paralactic",
    "paralactici": "paralactic",
    "paralacticii": "paralactic",
    "paralacticilor": "paralactic",
    "paralacticul": "paralactic",
    "paralacticului": "paralactic",
    "paralaxa": "paralaxă",
    "paralaxe": "paralaxă",
    "paralaxei": "paralaxă",
    "paralaxele": "paralaxă",
    "paralaxelor": "paralaxă",
    "paralela": "paralel",
    "paralelă": "paralel",
    "paralele": "paralel",
    "paralelei": "paralel",
    "paralelele": "paralel",
    "paralelelor": "paralel",
    "paraleli": "paralel",
    "paralelii": "paralel",
    "paralelilor": "paralel",
    "paralelul": "paralel",
    "paralelului": "paralel",
    "paralela": "paralelă",
    "paralele": "paralelă",
    "paralelei": "paralelă",
    "paralelele": "paralelă",
    "paralelelor": "paralelă",
    "paralelipipede": "paralelipiped",
    "paralelipipedele": "paralelipiped",
    "paralelipipedelor": "paralelipiped",
    "paralelipipedul": "paralelipiped",
    "paralelipipedului": "paralelipiped",
    "paralelipipedica": "paralelipipedic",
    "paralelipipedică": "paralelipipedic",
    "paralelipipedice": "paralelipipedic",
    "paralelipipedicei": "paralelipipedic",
    "paralelipipedicele": "paralelipipedic",
    "paralelipipedicelor": "paralelipipedic",
    "paralelipipedici": "paralelipipedic",
    "paralelipipedicii": "paralelipipedic",
    "paralelipipedicilor": "paralelipipedic",
    "paralelipipedicul": "paralelipipedic",
    "paralelipipedicului": "paralelipipedic",
    "paralelisme": "paralelism",
    "paralelismele": "paralelism",
    "paralelismelor": "paralelism",
    "paralelismul": "paralelism",
    "paralelismului": "paralelism",
    "nemaiparalelizând": "paraleliza",
    "nemaiparalelizându": "paraleliza",
    "neparalelizând": "paraleliza",
    "neparalelizându": "paraleliza",
    "paraleliză": "paraleliza",
    "paralelizai": "paraleliza",
    "paralelizam": "paraleliza",
    "paralelizăm": "paraleliza",
    "paralelizând": "paraleliza",
    "paralelizându": "paraleliza",
    "paralelizară": "paraleliza",
    "paralelizarăm": "paraleliza",
    "paralelizarăți": "paraleliza",
    "paralelizase": "paraleliza",
    "paralelizasem": "paraleliza",
    "paralelizaseră": "paraleliza",
    "paralelizaserăm": "paraleliza",
    "paralelizaserăți": "paraleliza",
    "paralelizaseși": "paraleliza",
    "paralelizași": "paraleliza",
    "paralelizat": "paraleliza",
    "paralelizați": "paraleliza",
    "paralelizau": "paraleliza",
    "paralelizează": "paraleliza",
    "paralelizez": "paraleliza",
    "paralelizeze": "paraleliza",
    "paralelizezi": "paraleliza",
    "paralelizată": "paralelizat",
    "paralelizate": "paralelizat",
    "paralelizați": "paralelizat",
    "paralelograme": "paralelogram",
    "paralelogramele": "paralelogram",
    "paralelogramelor": "paralelogram",
    "paralelogramul": "paralelogram",
    "paralelogramului": "paralelogram",
    "paralitica": "paralitic",
    "paralitică": "paralitic",
    "paralitice": "paralitic",
    "paraliticei": "paralitic",
    "paraliticele": "paralitic",
    "paraliticelor": "paralitic",
    "paralitici": "paralitic",
    "paraliticii": "paralitic",
    "paraliticilor": "paralitic",
    "paraliticul": "paralitic",
    "paraliticului": "paralitic",
    "paralitica": "paralitică",
    "paralitice": "paralitică",
    "paraliticei": "paralitică",
    "paraliticele": "paralitică",
    "paraliticelor": "paralitică",
    "nemaiparalizând": "paraliza",
    "nemaiparalizându": "paraliza",
    "neparalizând": "paraliza",
    "neparalizându": "paraliza",
    "paraliză": "paraliza",
    "paralizai": "paraliza",
    "paralizam": "paraliza",
    "paralizăm": "paraliza",
    "paralizând": "paraliza",
    "paralizându": "paraliza",
    "paralizară": "paraliza",
    "paralizarăm": "paraliza",
    "paralizarăți": "paraliza",
    "paralizase": "paraliza",
    "paralizasem": "paraliza",
    "paralizaseră": "paraliza",
    "paralizaserăm": "paraliza",
    "paralizaserăți": "paraliza",
    "paralizaseși": "paraliza",
    "paralizași": "paraliza",
    "paralizat": "paraliza",
    "paralizați": "paraliza",
    "paralizau": "paraliza",
    "paralizează": "paraliza",
    "paralizez": "paraliza",
    "paralizeze": "paraliza",
    "paralizezi": "paraliza",
    "paralizanta": "paralizant",
    "paralizantă": "paralizant",
    "paralizante": "paralizant",
    "paralizantei": "paralizant",
    "paralizantele": "paralizant",
    "paralizantelor": "paralizant",
    "paralizanți": "paralizant",
    "paralizanții": "paralizant",
    "paralizanților": "paralizant",
    "paralizantul": "paralizant",
    "paralizantului": "paralizant",
    "paralizarea": "paralizare",
    "paralizări": "paralizare",
    "paralizării": "paralizare",
    "paralizările": "paralizare",
    "paralizărilor": "paralizare",
    "paralizată": "paralizat",
    "paralizate": "paralizat",
    "paralizați": "paralizat",
    "paralizia": "paralizie",
    "paraliziei": "paralizie",
    "paralizii": "paralizie",
    "paraliziile": "paralizie",
    "paraliziilor": "paralizie",
    "parâma": "parâmă",
    "parâme": "parâmă",
    "parâmei": "parâmă",
    "parâmele": "parâmă",
    "parâmelor": "parâmă",
    "paramagnetica": "paramagnetic",
    "paramagnetică": "paramagnetic",
    "paramagnetice": "paramagnetic",
    "paramagneticei": "paramagnetic",
    "paramagneticele": "paramagnetic",
    "paramagneticelor": "paramagnetic",
    "paramagnetici": "paramagnetic",
    "paramagneticii": "paramagnetic",
    "paramagneticilor": "paramagnetic",
    "paramagneticul": "paramagnetic",
    "paramagneticului": "paramagnetic",
    "paramecii": "parameci",
    "paramecilor": "parameci",
    "parameciul": "parameci",
    "parameciului": "parameci",
    "parametrica": "parametric",
    "parametrică": "parametric",
    "parametrice": "parametric",
    "parametricei": "parametric",
    "parametricele": "parametric",
    "parametricelor": "parametric",
    "parametrici": "parametric",
    "parametricii": "parametric",
    "parametricilor": "parametric",
    "parametricul": "parametric",
    "parametricului": "parametric",
    "parametri": "parametru",
    "parametrii": "parametru",
    "parametrilor": "parametru",
    "parametrul": "parametru",
    "parametrului": "parametru",
    "Parângul": "Parâng",
    "Parângului": "Parâng",
    "paranoie": "paranoia",
    "paranoiei": "paranoia",
    "paranoica": "paranoic",
    "paranoică": "paranoic",
    "paranoice": "paranoic",
    "paranoicei": "paranoic",
    "paranoicele": "paranoic",
    "paranoicelor": "paranoic",
    "paranoici": "paranoic",
    "paranoicii": "paranoic",
    "paranoicilor": "paranoic",
    "paranoicul": "paranoic",
    "paranoicului": "paranoic",
    "paranteza": "paranteză",
    "paranteze": "paranteză",
    "parantezei": "paranteză",
    "parantezele": "paranteză",
    "parantezelor": "paranteză",
    "parapete": "parapet",
    "parapetele": "parapet",
    "parapetelor": "parapet",
    "parapetul": "parapet",
    "parapetului": "parapet",
    "paraplegica": "paraplegic",
    "paraplegică": "paraplegic",
    "paraplegice": "paraplegic",
    "paraplegicei": "paraplegic",
    "paraplegicele": "paraplegic",
    "paraplegicelor": "paraplegic",
    "paraplegici": "paraplegic",
    "paraplegicii": "paraplegic",
    "paraplegicilor": "paraplegic",
    "paraplegicul": "paraplegic",
    "paraplegicului": "paraplegic",
    "paraplegica": "paraplegică",
    "paraplegice": "paraplegică",
    "paraplegicei": "paraplegică",
    "paraplegicele": "paraplegică",
    "paraplegicelor": "paraplegică",
    "paraplegia": "paraplegie",
    "paraplegiei": "paraplegie",
    "paraplegii": "paraplegie",
    "paraplegiile": "paraplegie",
    "paraplegiilor": "paraplegie",
    "parapsihologi": "parapsiholog",
    "parapsihologii": "parapsiholog",
    "parapsihologilor": "parapsiholog",
    "parapsihologul": "parapsiholog",
    "parapsihologului": "parapsiholog",
    "parapsihologiea": "parapsihologie",
    "parapsihologii": "parapsihologie",
    "parapsihologiii": "parapsihologie",
    "parapsihologiile": "parapsihologie",
    "parapsihologiilor": "parapsihologie",
    "Paraschivei": "Paraschiva",
    "parascovenia": "parascovenie",
    "parascoveniei": "parascovenie",
    "parascovenii": "parascovenie",
    "parascoveniile": "parascovenie",
    "parascoveniilor": "parascovenie",
    "nemaipărăsind": "părăsi",
    "nemaipărăsindu": "părăsi",
    "nepărăsind": "părăsi",
    "nepărăsindu": "părăsi",
    "părăsea": "părăsi",
    "părăseai": "părăsi",
    "părăseam": "părăsi",
    "părăsească": "părăsi",
    "părăseați": "părăsi",
    "părăseau": "părăsi",
    "părăsesc": "părăsi",
    "părăsește": "părăsi",
    "părăsești": "părăsi",
    "părăsii": "părăsi",
    "părăsim": "părăsi",
    "părăsind": "părăsi",
    "părăsindu": "părăsi",
    "părăsiră": "părăsi",
    "părăsirăm": "părăsi",
    "părăsirăți": "părăsi",
    "părăsise": "părăsi",
    "părăsisem": "părăsi",
    "părăsiseră": "părăsi",
    "părăsiserăm": "părăsi",
    "părăsiserăți": "părăsi",
    "părăsiseși": "părăsi",
    "părăsiși": "părăsi",
    "părăsit": "părăsi",
    "părăsiți": "părăsi",
    "parasimpatica": "parasimpatic",
    "parasimpatică": "parasimpatic",
    "parasimpatice": "parasimpatic",
    "parasimpaticei": "parasimpatic",
    "parasimpaticele": "parasimpatic",
    "parasimpaticelor": "parasimpatic",
    "parasimpatici": "parasimpatic",
    "parasimpaticii": "parasimpatic",
    "parasimpaticilor": "parasimpatic",
    "parasimpaticul": "parasimpatic",
    "parasimpaticului": "parasimpatic",
    "părăsirea": "părăsire",
    "părăsiri": "părăsire",
    "părăsirii": "părăsire",
    "părăsirile": "părăsire",
    "părăsirilor": "părăsire",
    "părăsita": "părăsit",
    "părăsită": "părăsit",
    "părăsite": "părăsit",
    "părăsitei": "părăsit",
    "părăsitele": "părăsit",
    "părăsitelor": "părăsit",
    "părăsiți": "părăsit",
    "părăsiții": "părăsit",
    "părăsiților": "părăsit",
    "părăsitul": "părăsit",
    "părăsitului": "părăsit",
    "parastase": "parastas",
    "parastasele": "parastas",
    "parastaselor": "parastas",
    "parastasul": "parastas",
    "parastasului": "parastas",
    "nemaiparașutând": "parașuta",
    "nemaiparașutându": "parașuta",
    "neparașutând": "parașuta",
    "neparașutându": "parașuta",
    "parașută": "parașuta",
    "parașutai": "parașuta",
    "parașutam": "parașuta",
    "parașutăm": "parașuta",
    "parașutând": "parașuta",
    "parașutându": "parașuta",
    "parașutară": "parașuta",
    "parașutarăm": "parașuta",
    "parașutarăți": "parașuta",
    "parașutase": "parașuta",
    "parașutasem": "parașuta",
    "parașutaseră": "parașuta",
    "parașutaserăm": "parașuta",
    "parașutaserăți": "parașuta",
    "parașutaseși": "parașuta",
    "parașutași": "parașuta",
    "parașutat": "parașuta",
    "parașutați": "parașuta",
    "parașutau": "parașuta",
    "parașutează": "parașuta",
    "parașutez": "parașuta",
    "parașuteze": "parașuta",
    "parașutezi": "parașuta",
    "parașuta": "parașută",
    "parașute": "parașută",
    "parașutei": "parașută",
    "parașutele": "parașută",
    "parașutelor": "parașută",
    "parașutată": "parașutat",
    "parașutate": "parașutat",
    "parașutați": "parașutat",
    "parașutismul": "parașutism",
    "parașutismului": "parașutism",
    "parașutista": "parașutist",
    "parașutistă": "parașutist",
    "parașutiste": "parașutist",
    "parașutistei": "parașutist",
    "parașutistele": "parașutist",
    "parașutistelor": "parașutist",
    "parașutiști": "parașutist",
    "parașutiștii": "parașutist",
    "parașutiștilor": "parașutist",
    "parașutistul": "parașutist",
    "parașutistului": "parașutist",
    "parașutista": "parașutistă",
    "parașutiste": "parașutistă",
    "parașutistei": "parașutistă",
    "parașutistele": "parașutistă",
    "parașutistelor": "parașutistă",
    "pârâtă": "pârât",
    "pârâte": "pârât",
    "pârâți": "pârât",
    "pârâții": "pârât",
    "pârâților": "pârât",
    "pârâtul": "pârât",
    "pârâtului": "pârât",
    "pârâtoare": "pârâtor",
    "pârâtoarea": "pârâtor",
    "pârâtoarei": "pârâtor",
    "pârâtoarele": "pârâtor",
    "pârâtoarelor": "pârâtor",
    "pârâtori": "pârâtor",
    "pârâtorii": "pârâtor",
    "pârâtorilor": "pârâtor",
    "pârâtorul": "pârâtor",
    "pârâtorului": "pârâtor",
    "pârâul": "pârâu",
    "pârâului": "pârâu",
    "pârâuri": "pârâu",
    "pârâurile": "pârâu",
    "pârâurilor": "pârâu",
    "paravane": "paravan",
    "paravanele": "paravan",
    "paravanelor": "paravan",
    "paravanul": "paravan",
    "paravanului": "paravan",
    "paraxiala": "paraxial",
    "paraxială": "paraxial",
    "paraxiale": "paraxial",
    "paraxialei": "paraxial",
    "paraxialele": "paraxial",
    "paraxialelor": "paraxial",
    "paraxiali": "paraxial",
    "paraxialii": "paraxial",
    "paraxialilor": "paraxial",
    "paraxialul": "paraxial",
    "paraxialului": "paraxial",
    "parazita": "parazit",
    "parazită": "parazit",
    "parazite": "parazit",
    "parazitei": "parazit",
    "parazitele": "parazit",
    "parazitelor": "parazit",
    "paraziți": "parazit",
    "paraziții": "parazit",
    "paraziților": "parazit",
    "parazitul": "parazit",
    "parazitului": "parazit",
    "nemaiparazitând": "parazita",
    "nemaiparazitându": "parazita",
    "neparazitând": "parazita",
    "neparazitându": "parazita",
    "parazită": "parazita",
    "parazitai": "parazita",
    "parazitam": "parazita",
    "parazităm": "parazita",
    "parazitând": "parazita",
    "parazitându": "parazita",
    "parazitară": "parazita",
    "parazitarăm": "parazita",
    "parazitarăți": "parazita",
    "parazitase": "parazita",
    "parazitasem": "parazita",
    "parazitaseră": "parazita",
    "parazitaserăm": "parazita",
    "parazitaserăți": "parazita",
    "parazitaseși": "parazita",
    "parazitași": "parazita",
    "parazitat": "parazita",
    "parazitați": "parazita",
    "parazitau": "parazita",
    "parazitează": "parazita",
    "parazitez": "parazita",
    "paraziteze": "parazita",
    "parazitezi": "parazita",
    "parazitara": "parazitar",
    "parazitară": "parazitar",
    "parazitare": "parazitar",
    "parazitarei": "parazitar",
    "parazitarele": "parazitar",
    "parazitarelor": "parazitar",
    "parazitari": "parazitar",
    "parazitarii": "parazitar",
    "parazitarilor": "parazitar",
    "parazitarul": "parazitar",
    "parazitarului": "parazitar",
    "parazitată": "parazitat",
    "parazitate": "parazitat",
    "parazitați": "parazitat",
    "parazitismul": "parazitism",
    "parazitismului": "parazitism",
    "parazitologi": "parazitolog",
    "parazitologii": "parazitolog",
    "parazitologilor": "parazitolog",
    "parazitologul": "parazitolog",
    "parazitologului": "parazitolog",
    "parazitologia": "parazitologie",
    "parazitologiei": "parazitologie",
    "parazitologii": "parazitologie",
    "parazitoza": "parazitoză",
    "parazitoze": "parazitoză",
    "parazitozei": "parazitoză",
    "parazitozele": "parazitoză",
    "parazitozelor": "parazitoză",
    "parbrize": "parbriz",
    "parbrizele": "parbriz",
    "parbrizelor": "parbriz",
    "parbrizul": "parbriz",
    "parbrizului": "parbriz",
    "parcul": "parc",
    "parcului": "parc",
    "parcuri": "parc",
    "parcurile": "parc",
    "parcurilor": "parc",
    "nemaiparcând": "parca",
    "nemaiparcându": "parca",
    "neparcând": "parca",
    "neparcându": "parca",
    "parcă": "parca",
    "parcai": "parca",
    "parcam": "parca",
    "parcăm": "parca",
    "parcând": "parca",
    "parcându": "parca",
    "parcară": "parca",
    "parcarăm": "parca",
    "parcarăți": "parca",
    "parcase": "parca",
    "parcasem": "parca",
    "parcaseră": "parca",
    "parcaserăm": "parca",
    "parcaserăți": "parca",
    "parcaseși": "parca",
    "parcași": "parca",
    "parcat": "parca",
    "parcați": "parca",
    "parcau": "parca",
    "parchează": "parca",
    "parchez": "parca",
    "parcheze": "parca",
    "parchezi": "parca",
    "parc-": "parcă",
    "parcaje": "parcaj",
    "parcajele": "parcaj",
    "parcajelor": "parcaj",
    "parcajul": "parcaj",
    "parcajului": "parcaj",
    "parcată": "parcat",
    "parcate": "parcat",
    "parcați": "parcat",
    "parceaua": "parcea",
    "parcele": "parcea",
    "parcelei": "parcea",
    "parcelele": "parcea",
    "parcelelor": "parcea",
    "nemaiparcelând": "parcela",
    "nemaiparcelându": "parcela",
    "neparcelând": "parcela",
    "neparcelându": "parcela",
    "parcelă": "parcela",
    "parcelai": "parcela",
    "parcelam": "parcela",
    "parcelăm": "parcela",
    "parcelând": "parcela",
    "parcelându": "parcela",
    "parcelară": "parcela",
    "parcelarăm": "parcela",
    "parcelarăți": "parcela",
    "parcelase": "parcela",
    "parcelasem": "parcela",
    "parcelaseră": "parcela",
    "parcelaserăm": "parcela",
    "parcelaserăți": "parcela",
    "parcelaseși": "parcela",
    "parcelași": "parcela",
    "parcelat": "parcela",
    "parcelați": "parcela",
    "parcelau": "parcela",
    "parcelează": "parcela",
    "parcelez": "parcela",
    "parceleze": "parcela",
    "parcelezi": "parcela",
    "parcelata": "parcelat",
    "parcelată": "parcelat",
    "parcelate": "parcelat",
    "parcelatei": "parcelat",
    "parcelatele": "parcelat",
    "parcelatelor": "parcelat",
    "parcelați": "parcelat",
    "parcelații": "parcelat",
    "parcelaților": "parcelat",
    "parcelatul": "parcelat",
    "parcelatului": "parcelat",
    "parchete": "parchet",
    "parchetele": "parchet",
    "parchetelor": "parchet",
    "parchetul": "parchet",
    "parchetului": "parchet",
    "nemaiparchetând": "parcheta",
    "nemaiparchetându": "parcheta",
    "neparchetând": "parcheta",
    "neparchetându": "parcheta",
    "parchetă": "parcheta",
    "parchetai": "parcheta",
    "parchetam": "parcheta",
    "parchetăm": "parcheta",
    "parchetând": "parcheta",
    "parchetându": "parcheta",
    "parchetară": "parcheta",
    "parchetarăm": "parcheta",
    "parchetarăți": "parcheta",
    "parchetase": "parcheta",
    "parchetasem": "parcheta",
    "parchetaseră": "parcheta",
    "parchetaserăm": "parcheta",
    "parchetaserăți": "parcheta",
    "parchetaseși": "parcheta",
    "parchetași": "parcheta",
    "parchetat": "parcheta",
    "parchetați": "parcheta",
    "parchetau": "parcheta",
    "parchetează": "parcheta",
    "parchetez": "parcheta",
    "parcheteze": "parcheta",
    "parchetezi": "parcheta",
    "parchetari": "parchetar",
    "parchetarii": "parchetar",
    "parchetarilor": "parchetar",
    "parchetarul": "parchetar",
    "parchetarului": "parchetar",
    "parchetata": "parchetat",
    "parchetată": "parchetat",
    "parchetate": "parchetat",
    "parchetatei": "parchetat",
    "parchetatele": "parchetat",
    "parchetatelor": "parchetat",
    "parchetați": "parchetat",
    "parchetații": "parchetat",
    "parchetaților": "parchetat",
    "parchetatul": "parchetat",
    "parchetatului": "parchetat",
    "parcimonia": "parcimonie",
    "parcimoniei": "parcimonie",
    "parcimonii": "parcimonie",
    "parcimoniile": "parcimonie",
    "parcimoniilor": "parcimonie",
    "parcimonioasa": "parcimonios",
    "parcimonioasă": "parcimonios",
    "parcimonioase": "parcimonios",
    "parcimonioasei": "parcimonios",
    "parcimonioasele": "parcimonios",
    "parcimonioaselor": "parcimonios",
    "parcimonioși": "parcimonios",
    "parcimonioșii": "parcimonios",
    "parcimonioșilor": "parcimonios",
    "parcimoniosul": "parcimonios",
    "parcimoniosului": "parcimonios",
    "nemaiparcurgând": "parcurge",
    "nemaiparcurgându": "parcurge",
    "neparcurgând": "parcurge",
    "neparcurgându": "parcurge",
    "parcurg": "parcurge",
    "parcurgă": "parcurge",
    "parcurgând": "parcurge",
    "parcurgându": "parcurge",
    "parcurgea": "parcurge",
    "parcurgeai": "parcurge",
    "parcurgeam": "parcurge",
    "parcurgeați": "parcurge",
    "parcurgeau": "parcurge",
    "parcurgem": "parcurge",
    "parcurgeți": "parcurge",
    "parcurgi": "parcurge",
    "parcurs": "parcurge",
    "parcurse": "parcurge",
    "parcursei": "parcurge",
    "parcurseră": "parcurge",
    "parcurserăm": "parcurge",
    "parcurserăți": "parcurge",
    "parcursese": "parcurge",
    "parcursesem": "parcurge",
    "parcurseseră": "parcurge",
    "parcurseserăm": "parcurge",
    "parcurseserăți": "parcurge",
    "parcurseseși": "parcurge",
    "parcurseși": "parcurge",
    "parcurgerea": "parcurgere",
    "parcurgeri": "parcurgere",
    "parcurgerii": "parcurgere",
    "parcurgerile": "parcurgere",
    "parcurgerilor": "parcurgere",
    "parcursă": "parcurs",
    "parcurse": "parcurs",
    "parcurși": "parcurs",
    "parcursul": "parcurs",
    "parcursului": "parcurs",
    "parcursuri": "parcurs",
    "parcursurile": "parcurs",
    "parcursurilor": "parcurs",
    "pârdalnica": "pârdalnic",
    "pârdalnică": "pârdalnic",
    "pârdalnice": "pârdalnic",
    "pârdalnicei": "pârdalnic",
    "pârdalnicele": "pârdalnic",
    "pârdalnicelor": "pârdalnic",
    "pârdalnici": "pârdalnic",
    "pârdalnicii": "pârdalnic",
    "pârdalnicilor": "pârdalnic",
    "pârdalnicul": "pârdalnic",
    "pârdalnicului": "pârdalnic",
    "pardesie": "pardesiu",
    "pardesiele": "pardesiu",
    "pardesielor": "pardesiu",
    "pardesiul": "pardesiu",
    "pardesiului": "pardesiu",
    "pardoseala": "pardoseală",
    "pardoseli": "pardoseală",
    "pardoselii": "pardoseală",
    "pardoselile": "pardoseală",
    "pardoselilor": "pardoseală",
    "nemaipardosind": "pardosi",
    "nemaipardosindu": "pardosi",
    "nepardosind": "pardosi",
    "nepardosindu": "pardosi",
    "pardosea": "pardosi",
    "pardoseai": "pardosi",
    "pardoseam": "pardosi",
    "pardosească": "pardosi",
    "pardoseați": "pardosi",
    "pardoseau": "pardosi",
    "pardosesc": "pardosi",
    "pardosește": "pardosi",
    "pardosești": "pardosi",
    "pardosii": "pardosi",
    "pardosim": "pardosi",
    "pardosind": "pardosi",
    "pardosindu": "pardosi",
    "pardosiră": "pardosi",
    "pardosirăm": "pardosi",
    "pardosirăți": "pardosi",
    "pardosise": "pardosi",
    "pardosisem": "pardosi",
    "pardosiseră": "pardosi",
    "pardosiserăm": "pardosi",
    "pardosiserăți": "pardosi",
    "pardosiseși": "pardosi",
    "pardosiși": "pardosi",
    "pardosit": "pardosi",
    "pardosiți": "pardosi",
    "pardosita": "pardosit",
    "pardosită": "pardosit",
    "pardosite": "pardosit",
    "pardositei": "pardosit",
    "pardositele": "pardosit",
    "pardositelor": "pardosit",
    "pardosiți": "pardosit",
    "pardosiții": "pardosit",
    "pardosiților": "pardosit",
    "pardositul": "pardosit",
    "pardositului": "pardosit",
    "nemaipărând": "părea",
    "nemaipărându": "părea",
    "nepărând": "părea",
    "nepărându": "părea",
    "par": "părea",
    "pară": "părea",
    "părând": "părea",
    "părându": "părea",
    "pare": "părea",
    "păreai": "părea",
    "păream": "părea",
    "păreați": "părea",
    "păreau": "părea",
    "părem": "părea",
    "păreți": "părea",
    "pari": "părea",
    "păru": "părea",
    "părui": "părea",
    "părură": "părea",
    "părurăm": "părea",
    "părurăți": "părea",
    "păruse": "părea",
    "părusem": "părea",
    "păruseră": "părea",
    "păruserăm": "părea",
    "păruserăți": "părea",
    "păruseși": "părea",
    "păruși": "părea",
    "părut": "părea",
    "paremiologi": "paremiolog",
    "paremiologii": "paremiolog",
    "paremiologilor": "paremiolog",
    "paremiologul": "paremiolog",
    "paremiologului": "paremiolog",
    "paremiologica": "paremiologic",
    "paremiologică": "paremiologic",
    "paremiologice": "paremiologic",
    "paremiologicei": "paremiologic",
    "paremiologicele": "paremiologic",
    "paremiologicelor": "paremiologic",
    "paremiologici": "paremiologic",
    "paremiologicii": "paremiologic",
    "paremiologicilor": "paremiologic",
    "paremiologicul": "paremiologic",
    "paremiologicului": "paremiologic",
    "paremiologia": "paremiologie",
    "paremiologiei": "paremiologie",
    "paremiologii": "paremiologie",
    "paremiologiile": "paremiologie",
    "paremiologiilor": "paremiologie",
    "părerea": "părere",
    "păreri": "părere",
    "părerii": "părere",
    "părerile": "părere",
    "părerilor": "părere",
    "pareza": "pareză",
    "pareze": "pareză",
    "parezei": "pareză",
    "parezele": "pareză",
    "parezelor": "pareză",
    "parfeul": "parfeu",
    "parfeului": "parfeu",
    "parfeuri": "parfeu",
    "parfeurile": "parfeu",
    "parfeurilor": "parfeu",
    "parfumul": "parfum",
    "parfumului": "parfum",
    "parfumuri": "parfum",
    "parfumurile": "parfum",
    "parfumurilor": "parfum",
    "nemaiparfumând": "parfuma",
    "nemaiparfumându": "parfuma",
    "neparfumând": "parfuma",
    "neparfumându": "parfuma",
    "parfumă": "parfuma",
    "parfumai": "parfuma",
    "parfumam": "parfuma",
    "parfumăm": "parfuma",
    "parfumând": "parfuma",
    "parfumându": "parfuma",
    "parfumară": "parfuma",
    "parfumarăm": "parfuma",
    "parfumarăți": "parfuma",
    "parfumase": "parfuma",
    "parfumasem": "parfuma",
    "parfumaseră": "parfuma",
    "parfumaserăm": "parfuma",
    "parfumaserăți": "parfuma",
    "parfumaseși": "parfuma",
    "parfumași": "parfuma",
    "parfumat": "parfuma",
    "parfumați": "parfuma",
    "parfumau": "parfuma",
    "parfumează": "parfuma",
    "parfumez": "parfuma",
    "parfumeze": "parfuma",
    "parfumezi": "parfuma",
    "parfumata": "parfumat",
    "parfumată": "parfumat",
    "parfumate": "parfumat",
    "parfumatei": "parfumat",
    "parfumatele": "parfumat",
    "parfumatelor": "parfumat",
    "parfumați": "parfumat",
    "parfumații": "parfumat",
    "parfumaților": "parfumat",
    "parfumatul": "parfumat",
    "parfumatului": "parfumat",
    "parf.": "parfumerie",
    "parfumeria": "parfumerie",
    "parfumeriei": "parfumerie",
    "parfumerii": "parfumerie",
    "parfumeriile": "parfumerie",
    "parfumeriilor": "parfumerie",
    "pârgava": "pârgav",
    "pârgavă": "pârgav",
    "pârgave": "pârgav",
    "pârgavei": "pârgav",
    "pârgavele": "pârgav",
    "pârgavelor": "pârgav",
    "pârgavi": "pârgav",
    "pârgavii": "pârgav",
    "pârgavilor": "pârgav",
    "pârgavul": "pârgav",
    "pârgavului": "pârgav",
    "pârghia": "pârghie",
    "pârghiei": "pârghie",
    "pârghii": "pârghie",
    "pârghiile": "pârghie",
    "pârghiilor": "pârghie",
    "nemaipârguind": "pârgui",
    "nemaipârguindu": "pârgui",
    "nepârguind": "pârgui",
    "nepârguindu": "pârgui",
    "pârguia": "pârgui",
    "pârguiască": "pârgui",
    "pârguiau": "pârgui",
    "pârguiesc": "pârgui",
    "pârguiește": "pârgui",
    "pârguind": "pârgui",
    "pârguindu": "pârgui",
    "pârguiră": "pârgui",
    "pârguise": "pârgui",
    "pârguiseră": "pârgui",
    "pârguit": "pârgui",
    "pârguită": "pârguit",
    "pârguite": "pârguit",
    "pârguiți": "pârguit",
    "nemaipârând": "pârî",
    "nemaipârându": "pârî",
    "nepârând": "pârî",
    "nepârându": "pârî",
    "pâra": "pârî",
    "pârai": "pârî",
    "pârâi": "pârî",
    "pâram": "pârî",
    "pârâm": "pârî",
    "pârând": "pârî",
    "pârându": "pârî",
    "pârâră": "pârî",
    "pârârăm": "pârî",
    "pârârăți": "pârî",
    "pârăsc": "pârî",
    "pârască": "pârî",
    "pârâse": "pârî",
    "pârâsem": "pârî",
    "pârâseră": "pârî",
    "pârâserăm": "pârî",
    "pârâserăți": "pârî",
    "pârâseși": "pârî",
    "pârâși": "pârî",
    "pârăște": "pârî",
    "pârăști": "pârî",
    "pârât": "pârî",
    "pârați": "pârî",
    "pârâți": "pârî",
    "pârau": "pârî",
    "nemaipariind": "paria",
    "nemaipariindu": "paria",
    "nepariind": "paria",
    "nepariindu": "paria",
    "pariai": "paria",
    "pariam": "paria",
    "pariară": "paria",
    "pariarăm": "paria",
    "pariarăți": "paria",
    "pariase": "paria",
    "pariasem": "paria",
    "pariaseră": "paria",
    "pariaserăm": "paria",
    "pariaserăți": "paria",
    "pariaseși": "paria",
    "pariași": "paria",
    "pariat": "paria",
    "pariați": "paria",
    "pariau": "paria",
    "pariază": "paria",
    "parie": "paria",
    "pariem": "paria",
    "pariez": "paria",
    "parieze": "paria",
    "pariezi": "paria",
    "pariind": "paria",
    "pariindu": "paria",
    "pariată": "pariat",
    "pariate": "pariat",
    "pariați": "pariat",
    "paricidul": "paricid",
    "paricidului": "paricid",
    "pariciduri": "paricid",
    "paricidurile": "paricid",
    "paricidurilor": "paricid",
    "paricizi": "paricid",
    "paricizii": "paricid",
    "paricizilor": "paricid",
    "paricida": "paricidă",
    "paricide": "paricidă",
    "paricidei": "paricidă",
    "paricidele": "paricidă",
    "paricidelor": "paricidă",
    "parietala": "parietal",
    "parietală": "parietal",
    "parietale": "parietal",
    "parietalei": "parietal",
    "parietalele": "parietal",
    "parietalelor": "parietal",
    "parietali": "parietal",
    "parietalii": "parietal",
    "parietalilor": "parietal",
    "parietalul": "parietal",
    "parietalului": "parietal",
    "părintele": "părinte",
    "părintelui": "părinte",
    "părinți": "părinte",
    "părinții": "părinte",
    "părinților": "părinte",
    "părinteasca": "părintesc",
    "părintească": "părintesc",
    "părintescul": "părintesc",
    "părintescului": "părintesc",
    "părintești": "părintesc",
    "părinteștii": "părintesc",
    "părinteștile": "părintesc",
    "părinteștilor": "părintesc",
    "Parisul": "Paris",
    "Parisului": "Paris",
    "parisilabica": "parisilabic",
    "parisilabică": "parisilabic",
    "parisilabice": "parisilabic",
    "parisilabicei": "parisilabic",
    "parisilabicele": "parisilabic",
    "parisilabicelor": "parisilabic",
    "parisilabici": "parisilabic",
    "parisilabicii": "parisilabic",
    "parisilabicilor": "parisilabic",
    "parisilabicul": "parisilabic",
    "parisilabicului": "parisilabic",
    "paritatea": "paritate",
    "parități": "paritate",
    "parității": "paritate",
    "paritățile": "paritate",
    "parităților": "paritate",
    "pariul": "pariu",
    "pariului": "pariu",
    "pariuri": "pariu",
    "pariurile": "pariu",
    "pariurilor": "pariu",
    "parizerul": "parizer",
    "parizerului": "parizer",
    "pariziana": "parizian",
    "pariziană": "parizian",
    "parizianul": "parizian",
    "parizianului": "parizian",
    "pariziene": "parizian",
    "parizienei": "parizian",
    "parizienele": "parizian",
    "parizienelor": "parizian",
    "parizieni": "parizian",
    "parizienii": "parizian",
    "parizienilor": "parizian",
    "pârjolul": "pârjol",
    "pârjolului": "pârjol",
    "pârjoluri": "pârjol",
    "pârjolurile": "pârjol",
    "pârjolurilor": "pârjol",
    "nemaipârjolind": "pârjoli",
    "nemaipârjolindu": "pârjoli",
    "nepârjolind": "pârjoli",
    "nepârjolindu": "pârjoli",
    "pârjolea": "pârjoli",
    "pârjoleai": "pârjoli",
    "pârjoleam": "pârjoli",
    "pârjolească": "pârjoli",
    "pârjoleați": "pârjoli",
    "pârjoleau": "pârjoli",
    "pârjolesc": "pârjoli",
    "pârjolește": "pârjoli",
    "pârjolești": "pârjoli",
    "pârjolii": "pârjoli",
    "pârjolim": "pârjoli",
    "pârjolind": "pârjoli",
    "pârjolindu": "pârjoli",
    "pârjoliră": "pârjoli",
    "pârjolirăm": "pârjoli",
    "pârjolirăți": "pârjoli",
    "pârjolise": "pârjoli",
    "pârjolisem": "pârjoli",
    "pârjoliseră": "pârjoli",
    "pârjoliserăm": "pârjoli",
    "pârjoliserăți": "pârjoli",
    "pârjoliseși": "pârjoli",
    "pârjoliși": "pârjoli",
    "pârjolit": "pârjoli",
    "pârjoliți": "pârjoli",
    "pârjolită": "pârjolit",
    "pârjolite": "pârjolit",
    "pârjoliți": "pârjolit",
    "parlamente": "parlament",
    "parlamentele": "parlament",
    "parlamentelor": "parlament",
    "parlamentul": "parlament",
    "parlamentului": "parlament",
    "nemaiparlamentând": "parlamenta",
    "nemaiparlamentându": "parlamenta",
    "neparlamentând": "parlamenta",
    "neparlamentându": "parlamenta",
    "parlamentă": "parlamenta",
    "parlamentai": "parlamenta",
    "parlamentam": "parlamenta",
    "parlamentăm": "parlamenta",
    "parlamentând": "parlamenta",
    "parlamentându": "parlamenta",
    "parlamentară": "parlamenta",
    "parlamentarăm": "parlamenta",
    "parlamentarăți": "parlamenta",
    "parlamentase": "parlamenta",
    "parlamentasem": "parlamenta",
    "parlamentaseră": "parlamenta",
    "parlamentaserăm": "parlamenta",
    "parlamentaserăți": "parlamenta",
    "parlamentaseși": "parlamenta",
    "parlamentași": "parlamenta",
    "parlamentat": "parlamenta",
    "parlamentați": "parlamenta",
    "parlamentau": "parlamenta",
    "parlamentează": "parlamenta",
    "parlamentez": "parlamenta",
    "parlamenteze": "parlamenta",
    "parlamentezi": "parlamenta",
    "parlamentara": "parlamentar",
    "parlamentară": "parlamentar",
    "parlamentare": "parlamentar",
    "parlamentarei": "parlamentar",
    "parlamentarele": "parlamentar",
    "parlamentarelor": "parlamentar",
    "parlamentari": "parlamentar",
    "parlamentarii": "parlamentar",
    "parlamentarilor": "parlamentar",
    "parlamentarul": "parlamentar",
    "parlamentarului": "parlamentar",
    "parlamentată": "parlamentat",
    "parlamentate": "parlamentat",
    "parlamentați": "parlamentat",
    "pârleazul": "pârleaz",
    "pârleazului": "pârleaz",
    "pârleazuri": "pârleaz",
    "pârleazurile": "pârleaz",
    "pârleazurilor": "pârleaz",
    "nemaipârlind": "pârli",
    "nemaipârlindu": "pârli",
    "nepârlind": "pârli",
    "nepârlindu": "pârli",
    "pârlea": "pârli",
    "pârleai": "pârli",
    "pârleam": "pârli",
    "pârlească": "pârli",
    "pârleați": "pârli",
    "pârleau": "pârli",
    "pârlesc": "pârli",
    "pârlește": "pârli",
    "pârlești": "pârli",
    "pârlii": "pârli",
    "pârlim": "pârli",
    "pârlind": "pârli",
    "pârlindu": "pârli",
    "pârliră": "pârli",
    "pârlirăm": "pârli",
    "pârlirăți": "pârli",
    "pârlise": "pârli",
    "pârlisem": "pârli",
    "pârliseră": "pârli",
    "pârliserăm": "pârli",
    "pârliserăți": "pârli",
    "pârliseși": "pârli",
    "pârliși": "pârli",
    "pârlit": "pârli",
    "pârliți": "pârli",
    "pârlirea": "pârlire",
    "pârliri": "pârlire",
    "pârlirii": "pârlire",
    "pârlirile": "pârlire",
    "pârlirilor": "pârlire",
    "pârlită": "pârlit",
    "pârlite": "pârlit",
    "pârliți": "pârlit",
    "pârloaga": "pârloagă",
    "pârloage": "pârloagă",
    "pârloagei": "pârloagă",
    "pârloagele": "pârloagă",
    "pârloagelor": "pârloagă",
    "parmezane": "parmezan",
    "parmezanele": "parmezan",
    "parmezanelor": "parmezan",
    "parmezanul": "parmezan",
    "parmezanului": "parmezan",
    "parnasiana": "parnasian",
    "parnasiană": "parnasian",
    "parnasianul": "parnasian",
    "parnasianului": "parnasian",
    "parnasiene": "parnasian",
    "parnasienei": "parnasian",
    "parnasienele": "parnasian",
    "parnasienelor": "parnasian",
    "parnasieni": "parnasian",
    "parnasienii": "parnasian",
    "parnasienilor": "parnasian",
    "nemaiparodiind": "parodia",
    "nemaiparodiindu": "parodia",
    "neparodiind": "parodia",
    "neparodiindu": "parodia",
    "parodiai": "parodia",
    "parodiam": "parodia",
    "parodiară": "parodia",
    "parodiarăm": "parodia",
    "parodiarăți": "parodia",
    "parodiase": "parodia",
    "parodiasem": "parodia",
    "parodiaseră": "parodia",
    "parodiaserăm": "parodia",
    "parodiaserăți": "parodia",
    "parodiaseși": "parodia",
    "parodiași": "parodia",
    "parodiat": "parodia",
    "parodiați": "parodia",
    "parodiau": "parodia",
    "parodiază": "parodia",
    "parodie": "parodia",
    "parodiem": "parodia",
    "parodiez": "parodia",
    "parodieze": "parodia",
    "parodiezi": "parodia",
    "parodiind": "parodia",
    "parodiindu": "parodia",
    "parodiată": "parodiat",
    "parodiate": "parodiat",
    "parodiați": "parodiat",
    "parodia": "parodie",
    "parodiei": "parodie",
    "parodii": "parodie",
    "parodiile": "parodie",
    "parodiilor": "parodie",
    "parodierea": "parodiere",
    "parodieri": "parodiere",
    "parodierii": "parodiere",
    "parodierile": "parodiere",
    "parodierilor": "parodiere",
    "parohi": "paroh",
    "parohii": "paroh",
    "parohilor": "paroh",
    "parohul": "paroh",
    "parohului": "paroh",
    "parohiala": "parohial",
    "parohială": "parohial",
    "parohiale": "parohial",
    "parohialei": "parohial",
    "parohialele": "parohial",
    "parohialelor": "parohial",
    "parohiali": "parohial",
    "parohialii": "parohial",
    "parohialilor": "parohial",
    "parohialul": "parohial",
    "parohialului": "parohial",
    "parohia": "parohie",
    "parohiei": "parohie",
    "parohii": "parohie",
    "parohiile": "parohie",
    "parohiilor": "parohie",
    "parola": "parolă",
    "parole": "parolă",
    "parolei": "parolă",
    "parolele": "parolă",
    "parolelor": "parolă",
    "paroliști": "parolist",
    "paroliștii": "parolist",
    "paroliștilor": "parolist",
    "parolistul": "parolist",
    "parolistului": "parolist",
    "parolista": "parolistă",
    "paroliste": "parolistă",
    "parolistei": "parolistă",
    "parolistele": "parolistă",
    "parolistelor": "parolistă",
    "paronime": "paronim",
    "paronimele": "paronim",
    "paronimelor": "paronim",
    "paronimul": "paronim",
    "paronimului": "paronim",
    "paronimia": "paronimie",
    "paronimiei": "paronimie",
    "paronimii": "paronimie",
    "paronimiile": "paronimie",
    "paronimiilor": "paronimie",
    "păroasa": "păros",
    "păroasă": "păros",
    "păroase": "păros",
    "păroasei": "păros",
    "păroasele": "păros",
    "păroaselor": "păros",
    "păroși": "păros",
    "păroșii": "păros",
    "păroșilor": "păros",
    "părosul": "păros",
    "părosului": "păros",
    "parotida": "parotidă",
    "parotide": "parotidă",
    "parotidei": "parotidă",
    "parotidele": "parotidă",
    "parotidelor": "parotidă",
    "paroxisme": "paroxism",
    "paroxismele": "paroxism",
    "paroxismelor": "paroxism",
    "paroxismul": "paroxism",
    "paroxismului": "paroxism",
    "parșiva": "parșiv",
    "parșivă": "parșiv",
    "parșive": "parșiv",
    "parșivei": "parșiv",
    "parșivele": "parșiv",
    "parșivelor": "parșiv",
    "parșivi": "parșiv",
    "parșivii": "parșiv",
    "parșivilor": "parșiv",
    "parșivul": "parșiv",
    "parșivului": "parșiv",
    "partaje": "partaj",
    "partajele": "partaj",
    "partajelor": "partaj",
    "partajul": "partaj",
    "partajului": "partaj",
    "părtași": "părtaș",
    "părtașii": "părtaș",
    "părtașilor": "părtaș",
    "părtașul": "părtaș",
    "părtașului": "părtaș",
    "părtașa": "părtașă",
    "părtașe": "părtașă",
    "părtașei": "părtașă",
    "părtașele": "părtașă",
    "părtașelor": "părtașă",
    "partea": "parte",
    "părți": "parte",
    "părții": "parte",
    "părții-neam": "parte",
    "părțile": "parte",
    "părților": "parte",
    "partenera": "partener",
    "parteneră": "partener",
    "partenere": "partener",
    "partenerei": "partener",
    "partenerele": "partener",
    "partenerelor": "partener",
    "parteneri": "partener",
    "partenerii": "partener",
    "partenerilor": "partener",
    "partenerul": "partener",
    "partenerului": "partener",
    "partenera": "parteneră",
    "partenere": "parteneră",
    "partenerei": "parteneră",
    "partenerele": "parteneră",
    "partenerelor": "parteneră",
    "parteneriate": "parteneriat",
    "parteneriatele": "parteneriat",
    "parteneriatelor": "parteneriat",
    "parteneriatul": "parteneriat",
    "parteneriatului": "parteneriat",
    "partere": "parter",
    "parterele": "parter",
    "parterelor": "parter",
    "parterul": "parter",
    "parterului": "parter",
    "Pârteștii": "Pârtești",
    "parțiala": "parțial",
    "parțială": "parțial",
    "parțiale": "parțial",
    "parțialei": "parțial",
    "parțialele": "parțial",
    "parțialelor": "parțial",
    "parțiali": "parțial",
    "parțialii": "parțial",
    "parțialilor": "parțial",
    "parțialul": "parțial",
    "parțialului": "parțial",
    "parțialitatea": "parțialitate",
    "parțialități": "parțialitate",
    "parțialității": "parțialitate",
    "părticele": "părticică",
    "părticelei": "părticică",
    "părticelele": "părticică",
    "părticelelor": "părticică",
    "părticica": "părticică",
    "nemaiparticipând": "participa",
    "nemaiparticipându": "participa",
    "neparticipând": "participa",
    "neparticipându": "participa",
    "particip": "participa",
    "participă": "participa",
    "participai": "participa",
    "participam": "participa",
    "participăm": "participa",
    "participând": "participa",
    "participându": "participa",
    "participară": "participa",
    "participarăm": "participa",
    "participarăți": "participa",
    "participase": "participa",
    "participasem": "participa",
    "participaseră": "participa",
    "participaserăm": "participa",
    "participaserăți": "participa",
    "participaseși": "participa",
    "participași": "participa",
    "participat": "participa",
    "participați": "participa",
    "participau": "participa",
    "participe": "participa",
    "participi": "participa",
    "participanți": "participant",
    "participanții": "participant",
    "participanților": "participant",
    "participantul": "participant",
    "participantului": "participant",
    "participanta": "participantă",
    "participante": "participantă",
    "participantei": "participantă",
    "participantele": "participantă",
    "participantelor": "participantă",
    "participarea": "participare",
    "participări": "participare",
    "participării": "participare",
    "participările": "participare",
    "participărilor": "participare",
    "participată": "participat",
    "participate": "participat",
    "participați": "participat",
    "participiala": "participial",
    "participială": "participial",
    "participiale": "participial",
    "participialei": "participial",
    "participialele": "participial",
    "participialelor": "participial",
    "participiali": "participial",
    "participialii": "participial",
    "participialilor": "participial",
    "participialul": "participial",
    "participialului": "participial",
    "part.": "participiu",
    "participii": "participiu",
    "participiile": "participiu",
    "participiilor": "participiu",
    "participiul": "participiu",
    "participiului": "participiu",
    "particula": "particulă",
    "particule": "particulă",
    "particulei": "particulă",
    "particulele": "particulă",
    "particulelor": "particulă",
    "particulara": "particular",
    "particulară": "particular",
    "particulare": "particular",
    "particularei": "particular",
    "particularele": "particular",
    "particularelor": "particular",
    "particulari": "particular",
    "particularii": "particular",
    "particularilor": "particular",
    "particularul": "particular",
    "particularului": "particular",
    "particularitatea": "particularitate",
    "particularități": "particularitate",
    "particularității": "particularitate",
    "particularitățile": "particularitate",
    "particularităților": "particularitate",
    "partide": "partid",
    "partidele": "partid",
    "partidelor": "partid",
    "partidul": "partid",
    "partidului": "partid",
    "partida": "partidă",
    "partide": "partidă",
    "partidei": "partidă",
    "partidele": "partidă",
    "partidelor": "partidă",
    "P.C.R.": "Partidul_Comunist_Român",
    "PCR": "Partidul_Comunist_Român",
    "PD": "Partidul_Democrat",
    "PDSR": "Partidul_Democrației_Sociale_din_România",
    "PL": "Partidul_Liberal",
    "PNL": "Partidul_Național_Liberal",
    "PNLCD": "Partidul_Național_Liberal_din_Conveția_Democrată",
    "PNL-Quintus": "Partidul_Național_Liberal-Quintus",
    "PNŢ": "Partidul_Național_Ţărănesc",
    "PNŢCD": "Partidul_Național_Ţărănesc_Creștin_și_Democrat",
    "PRM": "Partidul_România_Mare",
    "PSM": "Partidul_Socialist_al_Muncii",
    "PUNR": "Partidul_Uniunii_Naționale_Române",
    "pârtia": "pârtie",
    "pârtiei": "pârtie",
    "pârtii": "pârtie",
    "pârtiile": "pârtie",
    "pârtiilor": "pârtie",
    "nemaipărtinind": "părtini",
    "nemaipărtinindu": "părtini",
    "nepărtinind": "părtini",
    "nepărtinindu": "părtini",
    "părtinea": "părtini",
    "părtineai": "părtini",
    "părtineam": "părtini",
    "părtinească": "părtini",
    "părtineați": "părtini",
    "părtineau": "părtini",
    "părtinesc": "părtini",
    "părtinește": "părtini",
    "părtinești": "părtini",
    "părtinii": "părtini",
    "părtinim": "părtini",
    "părtinind": "părtini",
    "părtinindu": "părtini",
    "părtiniră": "părtini",
    "părtinirăm": "părtini",
    "părtinirăți": "părtini",
    "părtinise": "părtini",
    "părtinisem": "părtini",
    "părtiniseră": "părtini",
    "părtiniserăm": "părtini",
    "părtiniserăți": "părtini",
    "părtiniseși": "părtini",
    "părtiniși": "părtini",
    "părtinit": "părtini",
    "părtiniți": "părtini",
    "partinica": "partinic",
    "partinică": "partinic",
    "partinice": "partinic",
    "partinicei": "partinic",
    "partinicele": "partinic",
    "partinicelor": "partinic",
    "partinici": "partinic",
    "partinicii": "partinic",
    "partinicilor": "partinic",
    "partinicul": "partinic",
    "partinicului": "partinic",
    "părtinirea": "părtinire",
    "părtiniri": "părtinire",
    "părtinirii": "părtinire",
    "părtinirile": "părtinire",
    "părtinirilor": "părtinire",
    "părtinită": "părtinit",
    "părtinite": "părtinit",
    "părtiniți": "părtinit",
    "partinitatea": "partinitate",
    "partinități": "partinitate",
    "partinității": "partinitate",
    "partinitățile": "partinitate",
    "partinităților": "partinitate",
    "părtinitoare": "părtinitor",
    "părtinitoarea": "părtinitor",
    "părtinitoarei": "părtinitor",
    "părtinitoarele": "părtinitor",
    "părtinitoarelor": "părtinitor",
    "părtinitori": "părtinitor",
    "părtinitorii": "părtinitor",
    "părtinitorilor": "părtinitor",
    "părtinitorul": "părtinitor",
    "părtinitorului": "părtinitor",
    "partiția": "partiție",
    "partiției": "partiție",
    "partiții": "partiție",
    "partițiile": "partiție",
    "partițiilor": "partiție",
    "partitiva": "partitiv",
    "partitivă": "partitiv",
    "partitive": "partitiv",
    "partitivei": "partitiv",
    "partitivele": "partitiv",
    "partitivelor": "partitiv",
    "partitivi": "partitiv",
    "partitivii": "partitiv",
    "partitivilor": "partitiv",
    "partitivul": "partitiv",
    "partitivului": "partitiv",
    "partitura": "partitură",
    "partituri": "partitură",
    "partiturii": "partitură",
    "partiturile": "partitură",
    "partiturilor": "partitură",
    "partizani": "partizan",
    "partizanii": "partizan",
    "partizanilor": "partizan",
    "partizanul": "partizan",
    "partizanului": "partizan",
    "nemaipăruind": "părui",
    "nemaipăruindu": "părui",
    "nepăruind": "părui",
    "nepăruindu": "părui",
    "păruia": "părui",
    "păruiai": "părui",
    "păruiam": "părui",
    "păruiască": "părui",
    "păruiați": "părui",
    "păruiau": "părui",
    "păruiesc": "părui",
    "păruiește": "părui",
    "păruiești": "părui",
    "păruii": "părui",
    "păruim": "părui",
    "păruind": "părui",
    "păruindu": "părui",
    "păruiră": "părui",
    "păruirăm": "părui",
    "păruirăți": "părui",
    "păruise": "părui",
    "păruisem": "părui",
    "păruiseră": "părui",
    "păruiserăm": "părui",
    "păruiserăți": "părui",
    "păruiseși": "părui",
    "păruiși": "părui",
    "păruit": "părui",
    "păruiți": "părui",
    "păruiala": "păruială",
    "păruieli": "păruială",
    "păruielii": "păruială",
    "păruielile": "păruială",
    "păruielilor": "păruială",
    "păruită": "păruit",
    "păruite": "păruit",
    "păruiți": "păruit",
    "parura": "parură",
    "paruri": "parură",
    "parurii": "parură",
    "parurile": "parură",
    "parurilor": "parură",
    "părută": "părut",
    "părute": "părut",
    "păruți": "părut",
    "nemaiparvenind": "parveni",
    "nemaiparvenindu": "parveni",
    "neparvenind": "parveni",
    "neparvenindu": "parveni",
    "parvenea": "parveni",
    "parveneai": "parveni",
    "parveneam": "parveni",
    "parveneați": "parveni",
    "parveneau": "parveni",
    "parvenii": "parveni",
    "parvenim": "parveni",
    "parvenind": "parveni",
    "parvenindu": "parveni",
    "parveniră": "parveni",
    "parvenirăm": "parveni",
    "parvenirăți": "parveni",
    "parvenise": "parveni",
    "parvenisem": "parveni",
    "parveniseră": "parveni",
    "parveniserăm": "parveni",
    "parveniserăți": "parveni",
    "parveniseși": "parveni",
    "parveniși": "parveni",
    "parvenit": "parveni",
    "parveniți": "parveni",
    "parvii": "parveni",
    "parvin": "parveni",
    "parvină": "parveni",
    "parvine": "parveni",
    "parvino": "parveni",
    "parvenită": "parvenit",
    "parvenite": "parvenit",
    "parveniți": "parvenit",
    "pași": "pas",
    "pașii": "pas",
    "pașilor": "pas",
    "pasul": "pas",
    "pasului": "pas",
    "pasuri": "pas",
    "pasurile": "pas",
    "pasurilor": "pas",
    "păsul": "păs",
    "păsului": "păs",
    "păsuri": "păs",
    "păsurile": "păs",
    "păsurilor": "păs",
    "nemaipăsând": "pasa",
    "nemaipăsându": "pasa",
    "nepasând": "pasa",
    "nepasându": "pasa",
    "pasă": "pasa",
    "pasai": "pasa",
    "pasam": "pasa",
    "pasăm": "pasa",
    "pasând": "pasa",
    "pasându": "pasa",
    "pasară": "pasa",
    "pasarăm": "pasa",
    "pasarăți": "pasa",
    "pasase": "pasa",
    "pasasem": "pasa",
    "pasaseră": "pasa",
    "pasaserăm": "pasa",
    "pasaserăți": "pasa",
    "pasaseși": "pasa",
    "pasași": "pasa",
    "pasat": "pasa",
    "pasați": "pasa",
    "pasau": "pasa",
    "pasează": "pasa",
    "pasez": "pasa",
    "paseze": "pasa",
    "pasezi": "pasa",
    "pasa": "pasă",
    "pase": "pasă",
    "pasei": "pasă",
    "pasele": "pasă",
    "paselor": "pasă",
    "pașa": "pașă",
    "pașei": "pașă",
    "nemaipăsându": "păsa",
    "nepăsându": "păsa",
    "pasă": "păsa",
    "păsă": "păsa",
    "păsând": "păsa",
    "păsându": "păsa",
    "păsase": "păsa",
    "păsat": "păsa",
    "pese": "păsa",
    "pasabila": "pasabil",
    "pasabilă": "pasabil",
    "pasabile": "pasabil",
    "pasabilei": "pasabil",
    "pasabilele": "pasabil",
    "pasabilelor": "pasabil",
    "pasabili": "pasabil",
    "pasabilii": "pasabil",
    "pasabililor": "pasabil",
    "pasabilul": "pasabil",
    "pasabilului": "pasabil",
    "pasageri": "pasager",
    "pasagerii": "pasager",
    "pasagerilor": "pasager",
    "pasagerul": "pasager",
    "pasagerului": "pasager",
    "pasagera": "pasageră",
    "pasagere": "pasageră",
    "pasagerei": "pasageră",
    "pasagerele": "pasageră",
    "pasagerelor": "pasageră",
    "pasaje": "pasaj",
    "pasajele": "pasaj",
    "pasajelor": "pasaj",
    "pasajul": "pasaj",
    "pasajului": "pasaj",
    "pașalâcul": "pașalâc",
    "pașalâcului": "pașalâc",
    "pașalâcuri": "pașalâc",
    "pașalâcurile": "pașalâc",
    "pașalâcurilor": "pașalâc",
    "pașapoarte": "pașaport",
    "pașapoartele": "pașaport",
    "pașapoartelor": "pașaport",
    "pașaportul": "pașaport",
    "pașaportului": "pașaport",
    "păsărari": "păsărar",
    "păsărarii": "păsărar",
    "păsărarilor": "păsărar",
    "păsărarul": "păsărar",
    "păsărarului": "păsărar",
    "pasărea": "pasăre",
    "păsări": "pasăre",
    "păsării": "pasăre",
    "păsările": "pasăre",
    "păsărilor": "pasăre",
    "păsăreaua": "păsărea",
    "păsărele": "păsărea",
    "păsărelei": "păsărea",
    "păsărelele": "păsărea",
    "păsărelelor": "păsărea",
    "păsări-liră": "pasărea-liră",
    "păsări-muscă": "pasărea-muscă",
    "pasarela": "pasarelă",
    "pasarele": "pasarelă",
    "pasarelei": "pasarelă",
    "pasarelele": "pasarelă",
    "pasarelelor": "pasarelă",
    "păsăreasca": "păsăresc",
    "păsărească": "păsăresc",
    "păsărescul": "păsăresc",
    "păsărescului": "păsăresc",
    "păsărești": "păsăresc",
    "păsăreștii": "păsăresc",
    "păsăreștile": "păsăresc",
    "păsăreștilor": "păsăresc",
    "păs.": "păsări",
    "păsărica": "păsărică",
    "păsăria": "păsărie",
    "păsăriei": "păsărie",
    "păsării": "păsărie",
    "păsăriile": "păsărie",
    "păsăriilor": "păsărie",
    "păsărimea": "păsărime",
    "păsărimi": "păsărime",
    "păsărimii": "păsărime",
    "pasată": "pasat",
    "pasate": "pasat",
    "pasați": "pasat",
    "păsatul": "păsat",
    "păsatului": "păsat",
    "pascala": "pascal",
    "pascală": "pascal",
    "pascale": "pascal",
    "pascalei": "pascal",
    "pascalele": "pascal",
    "pascalelor": "pascal",
    "pascali": "pascal",
    "pascalii": "pascal",
    "pascalilor": "pascal",
    "pascalul": "pascal",
    "pascalului": "pascal",
    "pascalia": "pascalie",
    "pascaliei": "pascalie",
    "pascalii": "pascalie",
    "pascaliile": "pascalie",
    "pascaliilor": "pascalie",
    "Pașcaniul": "Pașcani",
    "Pașcaniului": "Pașcani",
    "păscută": "păscut",
    "păscute": "păscut",
    "păscuți": "păscut",
    "păscutul": "păscut",
    "păscutului": "păscut",
    "pasența": "pasență",
    "pasențe": "pasență",
    "pasenței": "pasență",
    "pasențele": "pasență",
    "pasențelor": "pasență",
    "nemaipășind": "păși",
    "nemaipășindu": "păși",
    "nepășind": "păși",
    "nepășindu": "păși",
    "pășea": "păși",
    "pășeai": "păși",
    "pășeam": "păși",
    "pășească": "păși",
    "pășeați": "păși",
    "pășeau": "păși",
    "pășesc": "păși",
    "pășește": "păși",
    "pășești": "păși",
    "pășii": "păși",
    "pășim": "păși",
    "pășind": "păși",
    "pășindu": "păși",
    "pășiră": "păși",
    "pășirăm": "păși",
    "pășirăți": "păși",
    "pășise": "păși",
    "pășisem": "păși",
    "pășiseră": "păși",
    "pășiserăm": "păși",
    "pășiserăți": "păși",
    "pășiseși": "păși",
    "pășiși": "păși",
    "pășit": "păși",
    "pășiți": "păși",
    "pasibila": "pasibil",
    "pasibilă": "pasibil",
    "pasibile": "pasibil",
    "pasibilei": "pasibil",
    "pasibilele": "pasibil",
    "pasibilelor": "pasibil",
    "pasibili": "pasibil",
    "pasibilii": "pasibil",
    "pasibililor": "pasibil",
    "pasibilul": "pasibil",
    "pasibilului": "pasibil",
    "pasiența": "pasiență",
    "pasiențe": "pasiență",
    "pasienței": "pasiență",
    "pasiențele": "pasiență",
    "pasiențelor": "pasiență",
    "nemaipasionând": "pasiona",
    "nemaipasionându": "pasiona",
    "nepasionând": "pasiona",
    "nepasionându": "pasiona",
    "pasionă": "pasiona",
    "pasionai": "pasiona",
    "pasionam": "pasiona",
    "pasionăm": "pasiona",
    "pasionând": "pasiona",
    "pasionându": "pasiona",
    "pasionară": "pasiona",
    "pasionarăm": "pasiona",
    "pasionarăți": "pasiona",
    "pasionase": "pasiona",
    "pasionasem": "pasiona",
    "pasionaseră": "pasiona",
    "pasionaserăm": "pasiona",
    "pasionaserăți": "pasiona",
    "pasionaseși": "pasiona",
    "pasionași": "pasiona",
    "pasionat": "pasiona",
    "pasionați": "pasiona",
    "pasionau": "pasiona",
    "pasionează": "pasiona",
    "pasionez": "pasiona",
    "pasioneze": "pasiona",
    "pasionezi": "pasiona",
    "pasionala": "pasional",
    "pasională": "pasional",
    "pasionale": "pasional",
    "pasionalei": "pasional",
    "pasionalele": "pasional",
    "pasionalelor": "pasional",
    "pasionali": "pasional",
    "pasionalii": "pasional",
    "pasionalilor": "pasional",
    "pasionalul": "pasional",
    "pasionalului": "pasional",
    "pasionanta": "pasionant",
    "pasionantă": "pasionant",
    "pasionante": "pasionant",
    "pasionantei": "pasionant",
    "pasionantele": "pasionant",
    "pasionantelor": "pasionant",
    "pasionanți": "pasionant",
    "pasionanții": "pasionant",
    "pasionanților": "pasionant",
    "pasionantul": "pasionant",
    "pasionantului": "pasionant",
    "pasionata": "pasionat",
    "pasionată": "pasionat",
    "pasionate": "pasionat",
    "pasionatei": "pasionat",
    "pasionatele": "pasionat",
    "pasionatelor": "pasionat",
    "pasionați": "pasionat",
    "pasionații": "pasionat",
    "pasionaților": "pasionat",
    "pasionatul": "pasionat",
    "pasionatului": "pasionat",
    "pășirea": "pășire",
    "pășiri": "pășire",
    "pășirii": "pășire",
    "pășirile": "pășire",
    "pășirilor": "pășire",
    "pășită": "pășit",
    "pășite": "pășit",
    "pășiți": "pășit",
    "pasiunea": "pasiune",
    "pasiuni": "pasiune",
    "pasiunii": "pasiune",
    "pasiunile": "pasiune",
    "pasiunilor": "pasiune",
    "pas.": "pasiv",
    "pasiva": "pasiv",
    "pasivă": "pasiv",
    "pasive": "pasiv",
    "pasivei": "pasiv",
    "pasivele": "pasiv",
    "pasivelor": "pasiv",
    "pasivi": "pasiv",
    "pasivii": "pasiv",
    "pasivilor": "pasiv",
    "pasivul": "pasiv",
    "pasivului": "pasiv",
    "pasivitatea": "pasivitate",
    "pasivități": "pasivitate",
    "pasivității": "pasivitate",
    "pâsla": "pâslă",
    "pâsle": "pâslă",
    "pâslei": "pâslă",
    "pâsloasa": "pâslos",
    "pâsloasă": "pâslos",
    "pâsloase": "pâslos",
    "pâsloasei": "pâslos",
    "pâsloasele": "pâslos",
    "pâsloaselor": "pâslos",
    "pâsloși": "pâslos",
    "pâsloșii": "pâslos",
    "pâsloșilor": "pâslos",
    "pâslosul": "pâslos",
    "pâslosului": "pâslos",
    "pașnica": "pașnic",
    "pașnică": "pașnic",
    "pașnice": "pașnic",
    "pașnicei": "pașnic",
    "pașnicele": "pașnic",
    "pașnicelor": "pașnic",
    "pașnici": "pașnic",
    "pașnicii": "pașnic",
    "pașnicilor": "pașnic",
    "pașnicul": "pașnic",
    "pașnicului": "pașnic",
    "pasta": "pastă",
    "paste": "pastă",
    "pastei": "pastă",
    "pastele": "pastă",
    "pastelor": "pastă",
    "păstăi": "păstaie",
    "păstaia": "păstaie",
    "păstăii": "păstaie",
    "păstăile": "păstaie",
    "păstăilor": "păstaie",
    "păstârnaci": "păstârnac",
    "păstârnacii": "păstârnac",
    "păstârnacilor": "păstârnac",
    "păstârnacul": "păstârnac",
    "păstârnacului": "păstârnac",
    "nemaipăscând": "paște",
    "nemaipăscându": "paște",
    "nepăscând": "paște",
    "nepăscându": "paște",
    "pasc": "paște",
    "pască": "paște",
    "păscând": "paște",
    "păscându": "paște",
    "păscu": "paște",
    "păscui": "paște",
    "păscură": "paște",
    "păscurăm": "paște",
    "păscurăți": "paște",
    "păscuse": "paște",
    "păscusem": "paște",
    "păscuseră": "paște",
    "păscuserăm": "paște",
    "păscuserăți": "paște",
    "păscuseși": "paște",
    "păscuși": "paște",
    "păscut": "paște",
    "păștea": "paște",
    "pășteai": "paște",
    "pășteam": "paște",
    "pășteați": "paște",
    "pășteau": "paște",
    "Paștele": "Paște",
    "Paștelui": "Paște",
    "paștem": "paște",
    "pașteți": "paște",
    "pășteți": "paște",
    "paști": "paște",
    "Paștile": "Paște",
    "Paștilor": "Paște",
    "pastelul": "pastel",
    "pastelului": "pastel",
    "pasteluri": "pastel",
    "pastelurile": "pastel",
    "pastelurilor": "pastel",
    "pastelata": "pastelat",
    "pastelată": "pastelat",
    "pastelate": "pastelat",
    "pastelatei": "pastelat",
    "pastelatele": "pastelat",
    "pastelatelor": "pastelat",
    "pastelați": "pastelat",
    "pastelații": "pastelat",
    "pastelaților": "pastelat",
    "pastelatul": "pastelat",
    "pastelatului": "pastelat",
    "nemaipasteurizând": "pasteuriza",
    "nemaipasteurizându": "pasteuriza",
    "nepasteurizând": "pasteuriza",
    "nepasteurizându": "pasteuriza",
    "pasteuriză": "pasteuriza",
    "pasteurizai": "pasteuriza",
    "pasteurizam": "pasteuriza",
    "pasteurizăm": "pasteuriza",
    "pasteurizând": "pasteuriza",
    "pasteurizându": "pasteuriza",
    "pasteurizară": "pasteuriza",
    "pasteurizarăm": "pasteuriza",
    "pasteurizarăți": "pasteuriza",
    "pasteurizase": "pasteuriza",
    "pasteurizasem": "pasteuriza",
    "pasteurizaseră": "pasteuriza",
    "pasteurizaserăm": "pasteuriza",
    "pasteurizaserăți": "pasteuriza",
    "pasteurizaseși": "pasteuriza",
    "pasteurizași": "pasteuriza",
    "pasteurizat": "pasteuriza",
    "pasteurizați": "pasteuriza",
    "pasteurizau": "pasteuriza",
    "pasteurizează": "pasteuriza",
    "pasteurizez": "pasteuriza",
    "pasteurizeze": "pasteuriza",
    "pasteurizezi": "pasteuriza",
    "pasteurizata": "pasteurizat",
    "pasteurizată": "pasteurizat",
    "pasteurizate": "pasteurizat",
    "pasteurizatei": "pasteurizat",
    "pasteurizatele": "pasteurizat",
    "pasteurizatelor": "pasteurizat",
    "pasteurizați": "pasteurizat",
    "pasteurizații": "pasteurizat",
    "pasteurizaților": "pasteurizat",
    "pasteurizatul": "pasteurizat",
    "pasteurizatului": "pasteurizat",
    "Paștile": "Paști",
    "Paștilor": "Paști",
    "Paștiul": "Paști",
    "Paștiului": "Paști",
    "pastila": "pastilă",
    "pastile": "pastilă",
    "pastilei": "pastilă",
    "pastilele": "pastilă",
    "pastilelor": "pastilă",
    "pastori": "pastor",
    "pastorii": "pastor",
    "pastorilor": "pastor",
    "pastorul": "pastor",
    "pastorului": "pastor",
    "păstori": "păstor",
    "păstorii": "păstor",
    "păstorilor": "păstor",
    "păstorul": "păstor",
    "păstorului": "păstor",
    "pastorala": "pastoral",
    "pastorală": "pastoral",
    "pastorale": "pastoral",
    "pastoralei": "pastoral",
    "pastoralele": "pastoral",
    "pastoralelor": "pastoral",
    "pastorali": "pastoral",
    "pastoralii": "pastoral",
    "pastoralilor": "pastoral",
    "pastoralul": "pastoral",
    "pastoralului": "pastoral",
    "pastorala": "pastorală",
    "pastorale": "pastorală",
    "pastoralei": "pastorală",
    "pastoralele": "pastorală",
    "pastoralelor": "pastorală",
    "păstoreasca": "păstoresc",
    "păstorească": "păstoresc",
    "păstorescul": "păstoresc",
    "păstorescului": "păstoresc",
    "păstorești": "păstoresc",
    "păstoreștii": "păstoresc",
    "păstoreștile": "păstoresc",
    "păstoreștilor": "păstoresc",
    "nemaipăstorind": "păstori",
    "nemaipăstorindu": "păstori",
    "nepăstorind": "păstori",
    "nepăstorindu": "păstori",
    "păstorea": "păstori",
    "păstoreai": "păstori",
    "păstoream": "păstori",
    "păstorească": "păstori",
    "păstoreați": "păstori",
    "păstoreau": "păstori",
    "păstoresc": "păstori",
    "păstorește": "păstori",
    "păstorești": "păstori",
    "păstorii": "păstori",
    "păstorim": "păstori",
    "păstorind": "păstori",
    "păstorindu": "păstori",
    "păstoriră": "păstori",
    "păstorirăm": "păstori",
    "păstorirăți": "păstori",
    "păstorise": "păstori",
    "păstorisem": "păstori",
    "păstoriseră": "păstori",
    "păstoriserăm": "păstori",
    "păstoriserăți": "păstori",
    "păstoriseși": "păstori",
    "păstoriși": "păstori",
    "păstorit": "păstori",
    "păstoriți": "păstori",
    "păstorită": "păstorit",
    "păstorite": "păstorit",
    "păstoriți": "păstorit",
    "păstoritul": "păstorit",
    "păstoritului": "păstorit",
    "păstoasa": "păstos",
    "păstoasă": "păstos",
    "păstoase": "păstos",
    "păstoasei": "păstos",
    "păstoasele": "păstos",
    "păstoaselor": "păstos",
    "păstoși": "păstos",
    "păstoșii": "păstos",
    "păstoșilor": "păstos",
    "păstosul": "păstos",
    "păstosului": "păstos",
    "nemaipăstrând": "păstra",
    "nemaipăstrându": "păstra",
    "nepăstrând": "păstra",
    "nepăstrându": "păstra",
    "păstră": "păstra",
    "păstrai": "păstra",
    "păstram": "păstra",
    "păstrăm": "păstra",
    "păstrând": "păstra",
    "păstrându": "păstra",
    "păstrară": "păstra",
    "păstrarăm": "păstra",
    "păstrarăți": "păstra",
    "păstrase": "păstra",
    "păstrasem": "păstra",
    "păstraseră": "păstra",
    "păstraserăm": "păstra",
    "păstraserăți": "păstra",
    "păstraseși": "păstra",
    "păstrași": "păstra",
    "păstrat": "păstra",
    "păstrați": "păstra",
    "păstrau": "păstra",
    "păstrează": "păstra",
    "păstrez": "păstra",
    "păstreze": "păstra",
    "păstrezi": "păstra",
    "pastrama": "pastramă",
    "pastrame": "pastramă",
    "pastramei": "pastramă",
    "păstrămuri": "pastramă",
    "păstrămurile": "pastramă",
    "păstrămurilor": "pastramă",
    "păstrarea": "păstrare",
    "păstrări": "păstrare",
    "păstrării": "păstrare",
    "păstrată": "păstrat",
    "păstrate": "păstrat",
    "păstrați": "păstrat",
    "păstrătoarea": "păstrătoare",
    "păstrătoarei": "păstrătoare",
    "păstrătoarele": "păstrătoare",
    "păstrătoarelor": "păstrătoare",
    "păstrătoare": "păstrător",
    "păstrătoarea": "păstrător",
    "păstrătoarei": "păstrător",
    "păstrătoarele": "păstrător",
    "păstrătoarelor": "păstrător",
    "păstrători": "păstrător",
    "păstrătorii": "păstrător",
    "păstrătorilor": "păstrător",
    "păstrătorul": "păstrător",
    "păstrătorului": "păstrător",
    "păstrăvi": "păstrăv",
    "păstrăvii": "păstrăv",
    "păstrăvilor": "păstrăv",
    "păstrăvul": "păstrăv",
    "păstrăvului": "păstrăv",
    "păstrăvăria": "păstrăvărie",
    "păstrăvăriei": "păstrăvărie",
    "păstrăvării": "păstrăvărie",
    "păstrăvăriile": "păstrăvărie",
    "păstrăvăriilor": "păstrăvărie",
    "păstruga": "păstrugă",
    "păstrugi": "păstrugă",
    "păstrugii": "păstrugă",
    "păstrugile": "păstrugă",
    "păstrugilor": "păstrugă",
    "păstura": "păstură",
    "păsturei": "păstură",
    "păsturi": "păstură",
    "nemaipăsuind": "păsui",
    "nemaipăsuindu": "păsui",
    "nepăsuind": "păsui",
    "nepăsuindu": "păsui",
    "păsuia": "păsui",
    "păsuiai": "păsui",
    "păsuiam": "păsui",
    "păsuiască": "păsui",
    "păsuiați": "păsui",
    "păsuiau": "păsui",
    "păsuiesc": "păsui",
    "păsuiește": "păsui",
    "păsuiești": "păsui",
    "păsuii": "păsui",
    "păsuim": "păsui",
    "păsuind": "păsui",
    "păsuindu": "păsui",
    "păsuiră": "păsui",
    "păsuirăm": "păsui",
    "păsuirăți": "păsui",
    "păsuise": "păsui",
    "păsuisem": "păsui",
    "păsuiseră": "păsui",
    "păsuiserăm": "păsui",
    "păsuiserăți": "păsui",
    "păsuiseși": "păsui",
    "păsuiși": "păsui",
    "păsuit": "păsui",
    "păsuiți": "păsui",
    "păsuirea": "păsuire",
    "păsuiri": "păsuire",
    "păsuirii": "păsuire",
    "păsuirile": "păsuire",
    "păsuirilor": "păsuire",
    "păsuita": "păsuit",
    "păsuită": "păsuit",
    "păsuite": "păsuit",
    "păsuitei": "păsuit",
    "păsuitele": "păsuit",
    "păsuitelor": "păsuit",
    "păsuiți": "păsuit",
    "păsuiții": "păsuit",
    "păsuiților": "păsuit",
    "păsuitul": "păsuit",
    "păsuitului": "păsuit",
    "nemaipășunând": "pășuna",
    "nemaipășunându": "pășuna",
    "nepășunând": "pășuna",
    "nepășunându": "pășuna",
    "pășună": "pășuna",
    "pășunai": "pășuna",
    "pășunam": "pășuna",
    "pășunăm": "pășuna",
    "pășunând": "pășuna",
    "pășunându": "pășuna",
    "pășunară": "pășuna",
    "pășunarăm": "pășuna",
    "pășunarăți": "pășuna",
    "pășunase": "pășuna",
    "pășunasem": "pășuna",
    "pășunaseră": "pășuna",
    "pășunaserăm": "pășuna",
    "pășunaserăți": "pășuna",
    "pășunaseși": "pășuna",
    "pășunași": "pășuna",
    "pășunat": "pășuna",
    "pășunați": "pășuna",
    "pășunau": "pășuna",
    "pășunează": "pășuna",
    "pășunez": "pășuna",
    "pășuneze": "pășuna",
    "pășunezi": "pășuna",
    "pășunată": "pășunat",
    "pășunate": "pășunat",
    "pășunați": "pășunat",
    "pășunatul": "pășunat",
    "pășunatului": "pășunat",
    "pășunea": "pășune",
    "pășuni": "pășune",
    "pășunii": "pășune",
    "pășunile": "pășune",
    "pășunilor": "pășune",
    "patul": "pat",
    "patului": "pat",
    "paturi": "pat",
    "paturile": "pat",
    "paturilor": "pat",
    "pata": "pată",
    "pete": "pată",
    "petei": "pată",
    "petele": "pată",
    "petelor": "pată",
    "nemaipătând": "păta",
    "nemaipătându": "păta",
    "nepătând": "păta",
    "nepătându": "păta",
    "pătă": "păta",
    "pătai": "păta",
    "pătam": "păta",
    "pătăm": "păta",
    "pătând": "păta",
    "pătându": "păta",
    "pătară": "păta",
    "pătarăm": "păta",
    "pătarăți": "păta",
    "pătase": "păta",
    "pătasem": "păta",
    "pătaseră": "păta",
    "pătaserăm": "păta",
    "pătaserăți": "păta",
    "pătaseși": "păta",
    "pătași": "păta",
    "pătat": "păta",
    "pătați": "păta",
    "pătau": "păta",
    "pătează": "păta",
    "pătez": "păta",
    "păteze": "păta",
    "pătezi": "păta",
    "patalamale": "patalama",
    "patalamalei": "patalama",
    "patalamalele": "patalama",
    "patalamalelor": "patalama",
    "patalamaua": "patalama",
    "pățania": "pățanie",
    "pățaniei": "pățanie",
    "pățanii": "pățanie",
    "pățaniile": "pățanie",
    "pățaniilor": "pățanie",
    "pătata": "pătat",
    "pătată": "pătat",
    "pătate": "pătat",
    "pătatei": "pătat",
    "pătatele": "pătat",
    "pătatelor": "pătat",
    "pătați": "pătat",
    "pătații": "pătat",
    "pătaților": "pătat",
    "pătatul": "pătat",
    "pătatului": "pătat",
    "patefoane": "patefon",
    "patefoanele": "patefon",
    "patefoanelor": "patefon",
    "patefonul": "patefon",
    "patefonului": "patefon",
    "patenta": "patent",
    "patentă": "patent",
    "patente": "patent",
    "patentei": "patent",
    "patentele": "patent",
    "patentelor": "patent",
    "patenți": "patent",
    "patenții": "patent",
    "patenților": "patent",
    "patentul": "patent",
    "patentului": "patent",
    "nemaipatentând": "patenta",
    "nemaipatentându": "patenta",
    "nepatentând": "patenta",
    "nepatentându": "patenta",
    "patentă": "patenta",
    "patentai": "patenta",
    "patentam": "patenta",
    "patentăm": "patenta",
    "patentând": "patenta",
    "patentându": "patenta",
    "patentară": "patenta",
    "patentarăm": "patenta",
    "patentarăți": "patenta",
    "patentase": "patenta",
    "patentasem": "patenta",
    "patentaseră": "patenta",
    "patentaserăm": "patenta",
    "patentaserăți": "patenta",
    "patentaseși": "patenta",
    "patentași": "patenta",
    "patentat": "patenta",
    "patentați": "patenta",
    "patentau": "patenta",
    "patentează": "patenta",
    "patentez": "patenta",
    "patenteze": "patenta",
    "patentezi": "patenta",
    "patentata": "patentat",
    "patentată": "patentat",
    "patentate": "patentat",
    "patentatei": "patentat",
    "patentatele": "patentat",
    "patentatelor": "patentat",
    "patentați": "patentat",
    "patentații": "patentat",
    "patentaților": "patentat",
    "patentatul": "patentat",
    "patentatului": "patentat",
    "paterice": "pateric",
    "patericele": "pateric",
    "patericelor": "pateric",
    "patericul": "pateric",
    "patericului": "pateric",
    "patericuri": "pateric",
    "patericurile": "pateric",
    "patericurilor": "pateric",
    "paterna": "patern",
    "paternă": "patern",
    "paterne": "patern",
    "paternei": "patern",
    "paternele": "patern",
    "paternelor": "patern",
    "paterni": "patern",
    "paternii": "patern",
    "paternilor": "patern",
    "paternul": "patern",
    "paternului": "patern",
    "paternitatea": "paternitate",
    "paternități": "paternitate",
    "paternității": "paternitate",
    "patetica": "patetic",
    "patetică": "patetic",
    "patetice": "patetic",
    "pateticei": "patetic",
    "pateticele": "patetic",
    "pateticelor": "patetic",
    "patetici": "patetic",
    "pateticii": "patetic",
    "pateticilor": "patetic",
    "pateticul": "patetic",
    "pateticului": "patetic",
    "patetismul": "patetism",
    "patetismului": "patetism",
    "pateul": "pateu",
    "pateului": "pateu",
    "pateuri": "pateu",
    "pateurile": "pateu",
    "pateurilor": "pateu",
    "nemaipățind": "păți",
    "nemaipățindu": "păți",
    "nepățind": "păți",
    "nepățindu": "păți",
    "pață": "păți",
    "pățea": "păți",
    "pățeai": "păți",
    "pățeam": "păți",
    "pățească": "păți",
    "pățeați": "păți",
    "pățeau": "păți",
    "pățesc": "păți",
    "pățește": "păți",
    "pățești": "păți",
    "pății": "păți",
    "pățim": "păți",
    "pățind": "păți",
    "pățindu": "păți",
    "pățiră": "păți",
    "pățirăm": "păți",
    "pățirăți": "păți",
    "pățise": "păți",
    "pățisem": "păți",
    "pățiseră": "păți",
    "pățiserăm": "păți",
    "pățiserăți": "păți",
    "pățiseși": "păți",
    "pățiși": "păți",
    "pățit": "păți",
    "pățiți": "păți",
    "patima": "patimă",
    "patimi": "patimă",
    "patimii": "patimă",
    "patimile": "patimă",
    "patimilor": "patimă",
    "pătimașa": "pătimaș",
    "pătimașă": "pătimaș",
    "pătimașe": "pătimaș",
    "pătimașei": "pătimaș",
    "pătimașele": "pătimaș",
    "pătimașelor": "pătimaș",
    "pătimași": "pătimaș",
    "pătimașii": "pătimaș",
    "pătimașilor": "pătimaș",
    "pătimașul": "pătimaș",
    "pătimașului": "pătimaș",
    "nemaipătimind": "pătimi",
    "nemaipătimindu": "pătimi",
    "nepătimind": "pătimi",
    "nepătimindu": "pătimi",
    "pătimea": "pătimi",
    "pătimeai": "pătimi",
    "pătimeam": "pătimi",
    "pătimească": "pătimi",
    "pătimeați": "pătimi",
    "pătimeau": "pătimi",
    "pătimesc": "pătimi",
    "pătimește": "pătimi",
    "pătimești": "pătimi",
    "pătimii": "pătimi",
    "pătimim": "pătimi",
    "pătimind": "pătimi",
    "pătimindu": "pătimi",
    "pătimiră": "pătimi",
    "pătimirăm": "pătimi",
    "pătimirăți": "pătimi",
    "pătimise": "pătimi",
    "pătimisem": "pătimi",
    "pătimiseră": "pătimi",
    "pătimiserăm": "pătimi",
    "pătimiserăți": "pătimi",
    "pătimiseși": "pătimi",
    "pătimiși": "pătimi",
    "pătimit": "pătimi",
    "pătimiți": "pătimi",
    "pătimirea": "pătimire",
    "pătimiri": "pătimire",
    "pătimirii": "pătimire",
    "pătimirile": "pătimire",
    "pătimirilor": "pătimire",
    "pătimită": "pătimit",
    "pătimite": "pătimit",
    "pătimiți": "pătimit",
    "nemaipatinând": "patina",
    "nemaipatinându": "patina",
    "nepatinând": "patina",
    "nepatinându": "patina",
    "patină": "patina",
    "patinai": "patina",
    "patinam": "patina",
    "patinăm": "patina",
    "patinând": "patina",
    "patinându": "patina",
    "patinară": "patina",
    "patinarăm": "patina",
    "patinarăți": "patina",
    "patinase": "patina",
    "patinasem": "patina",
    "patinaseră": "patina",
    "patinaserăm": "patina",
    "patinaserăți": "patina",
    "patinaseși": "patina",
    "patinași": "patina",
    "patinat": "patina",
    "patinați": "patina",
    "patinau": "patina",
    "patinează": "patina",
    "patinez": "patina",
    "patineze": "patina",
    "patinezi": "patina",
    "patina": "patină",
    "patine": "patină",
    "patinei": "patină",
    "patinele": "patină",
    "patinelor": "patină",
    "patinaje": "patinaj",
    "patinajele": "patinaj",
    "patinajelor": "patinaj",
    "patinajul": "patinaj",
    "patinajului": "patinaj",
    "patinarea": "patinare",
    "patinări": "patinare",
    "patinării": "patinare",
    "patinările": "patinare",
    "patinărilor": "patinare",
    "patinată": "patinat",
    "patinate": "patinat",
    "patinați": "patinat",
    "patinoare": "patinoar",
    "patinoarele": "patinoar",
    "patinoarelor": "patinoar",
    "patinoarul": "patinoar",
    "patinoarului": "patinoar",
    "patiseria": "patiserie",
    "patiseriei": "patiserie",
    "patiserii": "patiserie",
    "patiseriile": "patiserie",
    "patiseriilor": "patiserie",
    "pățita": "pățit",
    "pățită": "pățit",
    "pățite": "pățit",
    "pățitei": "pățit",
    "pățitele": "pățit",
    "pățitelor": "pățit",
    "pățiți": "pățit",
    "pățiții": "pățit",
    "pățiților": "pățit",
    "pățitul": "pățit",
    "pățitului": "pățit",
    "pătlăgeaua": "pătlăgea",
    "pătlăgele": "pătlăgea",
    "pătlăgelei": "pătlăgea",
    "pătlăgelele": "pătlăgea",
    "pătlăgelelor": "pătlăgea",
    "pătlagina": "pătlagină",
    "pătlagini": "pătlagină",
    "pătlaginii": "pătlagină",
    "pătlaginile": "pătlagină",
    "pătlaginilor": "pătlagină",
    "patogena": "patogen",
    "patogenă": "patogen",
    "patogene": "patogen",
    "patogenei": "patogen",
    "patogenele": "patogen",
    "patogenelor": "patogen",
    "patogeni": "patogen",
    "patogenii": "patogen",
    "patogenilor": "patogen",
    "patogenul": "patogen",
    "patogenului": "patogen",
    "patogenia": "patogenie",
    "patogeniei": "patogenie",
    "patogenii": "patogenie",
    "patologica": "patologic",
    "patologică": "patologic",
    "patologice": "patologic",
    "patologicei": "patologic",
    "patologicele": "patologic",
    "patologicelor": "patologic",
    "patologici": "patologic",
    "patologicii": "patologic",
    "patologicilor": "patologic",
    "patologicul": "patologic",
    "patologicului": "patologic",
    "patologia": "patologie",
    "patologiei": "patologie",
    "patologii": "patologie",
    "patrafire": "patrafir",
    "patrafirele": "patrafir",
    "patrafirelor": "patrafir",
    "patrafirul": "patrafir",
    "patrafirului": "patrafir",
    "pătrare": "pătrar",
    "pătrarele": "pătrar",
    "pătrarelor": "pătrar",
    "pătrarul": "pătrar",
    "pătrarului": "pătrar",
    "pătrata": "pătrat",
    "pătrată": "pătrat",
    "pătrate": "pătrat",
    "pătratei": "pătrat",
    "pătratele": "pătrat",
    "pătratelor": "pătrat",
    "pătrați": "pătrat",
    "pătrații": "pătrat",
    "pătraților": "pătrat",
    "pătratul": "pătrat",
    "pătratului": "pătrat",
    "pătrățele": "pătrățel",
    "pătrățelele": "pătrățel",
    "pătrățelelor": "pătrățel",
    "pătrățelul": "pătrățel",
    "pătrățelului": "pătrățel",
    "pătrățoasa": "pătrățos",
    "pătrățoasă": "pătrățos",
    "pătrățoase": "pătrățos",
    "pătrățoasei": "pătrățos",
    "pătrățoasele": "pătrățos",
    "pătrățoaselor": "pătrățos",
    "pătrățoși": "pătrățos",
    "pătrățoșii": "pătrățos",
    "pătrățoșilor": "pătrățos",
    "pătrățosul": "pătrățos",
    "pătrățosului": "pătrățos",
    "patriarhi": "patriarh",
    "patriarhii": "patriarh",
    "patriarhilor": "patriarh",
    "patriarhul": "patriarh",
    "patriarhului": "patriarh",
    "patriarhala": "patriarhal",
    "patriarhală": "patriarhal",
    "patriarhale": "patriarhal",
    "patriarhalei": "patriarhal",
    "patriarhalele": "patriarhal",
    "patriarhalelor": "patriarhal",
    "patriarhali": "patriarhal",
    "patriarhalii": "patriarhal",
    "patriarhalilor": "patriarhal",
    "patriarhalul": "patriarhal",
    "patriarhalului": "patriarhal",
    "patriarhate": "patriarhat",
    "patriarhatele": "patriarhat",
    "patriarhatelor": "patriarhat",
    "patriarhatul": "patriarhat",
    "patriarhatului": "patriarhat",
    "patriarhia": "patriarhie",
    "patriarhiei": "patriarhie",
    "patriarhii": "patriarhie",
    "patriarhiile": "patriarhie",
    "patriarhiilor": "patriarhie",
    "patricianul": "patrician",
    "patricianului": "patrician",
    "patricieni": "patrician",
    "patricienii": "patrician",
    "patricienilor": "patrician",
    "patria": "patrie",
    "patriei": "patrie",
    "patrii": "patrie",
    "patriile": "patrie",
    "patriilor": "patrie",
    "pătrimea": "pătrime",
    "pătrimi": "pătrime",
    "pătrimii": "pătrime",
    "pătrimile": "pătrime",
    "pătrimilor": "pătrime",
    "patrimoniala": "patrimonial",
    "patrimonială": "patrimonial",
    "patrimoniale": "patrimonial",
    "patrimonialei": "patrimonial",
    "patrimonialele": "patrimonial",
    "patrimonialelor": "patrimonial",
    "patrimoniali": "patrimonial",
    "patrimonialii": "patrimonial",
    "patrimonialilor": "patrimonial",
    "patrimonialul": "patrimonial",
    "patrimonialului": "patrimonial",
    "patrimonii": "patrimoniu",
    "patrimoniile": "patrimoniu",
    "patrimoniilor": "patrimoniu",
    "patrimoniul": "patrimoniu",
    "patrimoniului": "patrimoniu",
    "patrioți": "patriot",
    "patrioții": "patriot",
    "patrioților": "patriot",
    "patriotul": "patriot",
    "patriotului": "patriot",
    "patriota": "patriotă",
    "patriote": "patriotă",
    "patriotei": "patriotă",
    "patriotele": "patriotă",
    "patriotelor": "patriotă",
    "patriotica": "patriotic",
    "patriotică": "patriotic",
    "patriotice": "patriotic",
    "patrioticei": "patriotic",
    "patrioticele": "patriotic",
    "patrioticelor": "patriotic",
    "patriotici": "patriotic",
    "patrioticii": "patriotic",
    "patrioticilor": "patriotic",
    "patrioticul": "patriotic",
    "patrioticului": "patriotic",
    "patriotisme": "patriotism",
    "patriotismele": "patriotism",
    "patriotismelor": "patriotism",
    "patriotismul": "patriotism",
    "patriotismului": "patriotism",
    "patroana": "patroană",
    "patroane": "patroană",
    "patroanei": "patroană",
    "patroanele": "patroană",
    "patroanelor": "patroană",
    "patrologia": "patrologie",
    "patrologiei": "patrologie",
    "patrologii": "patrologie",
    "patrologiile": "patrologie",
    "patrologiilor": "patrologie",
    "patroni": "patron",
    "patronii": "patron",
    "patronilor": "patron",
    "patronul": "patron",
    "patronului": "patron",
    "patronaje": "patronaj",
    "patronajele": "patronaj",
    "patronajelor": "patronaj",
    "patronajul": "patronaj",
    "patronajului": "patronaj",
    "patronale": "patronal",
    "patronată": "patronat",
    "patronate": "patronat",
    "patronatele": "patronat",
    "patronatelor": "patronat",
    "patronați": "patronat",
    "patronatul": "patronat",
    "patronatului": "patronat",
    "IV": "patru",
    "patra": "patru",
    "patrulea": "patru",
    "nemaipatrulând": "patrula",
    "nemaipatrulându": "patrula",
    "nepatrulând": "patrula",
    "nepatrulându": "patrula",
    "patrulă": "patrula",
    "patrulai": "patrula",
    "patrulam": "patrula",
    "patrulăm": "patrula",
    "patrulând": "patrula",
    "patrulându": "patrula",
    "patrulară": "patrula",
    "patrularăm": "patrula",
    "patrularăți": "patrula",
    "patrulase": "patrula",
    "patrulasem": "patrula",
    "patrulaseră": "patrula",
    "patrulaserăm": "patrula",
    "patrulaserăți": "patrula",
    "patrulaseși": "patrula",
    "patrulași": "patrula",
    "patrulat": "patrula",
    "patrulați": "patrula",
    "patrulau": "patrula",
    "patrulează": "patrula",
    "patrulez": "patrula",
    "patruleze": "patrula",
    "patrulezi": "patrula",
    "patrula": "patrulă",
    "patrule": "patrulă",
    "patrulei": "patrulă",
    "patrulele": "patrulă",
    "patrulelor": "patrulă",
    "patrulată": "patrulat",
    "patrulate": "patrulat",
    "patrulați": "patrulat",
    "patrulatere": "patrulater",
    "patrulaterele": "patrulater",
    "patrulaterelor": "patrulater",
    "patrulaterul": "patrulater",
    "patrulaterului": "patrulater",
    "nemaipătrunzând": "pătrunde",
    "nemaipătrunzându": "pătrunde",
    "nepătruns": "pătrunde",
    "nepătrunzând": "pătrunde",
    "nepătrunzându": "pătrunde",
    "pătrund": "pătrunde",
    "pătrundă": "pătrunde",
    "pătrundea": "pătrunde",
    "pătrundeai": "pătrunde",
    "pătrundeam": "pătrunde",
    "pătrundeați": "pătrunde",
    "pătrundeau": "pătrunde",
    "pătrundem": "pătrunde",
    "pătrundeți": "pătrunde",
    "pătruns": "pătrunde",
    "pătrunse": "pătrunde",
    "pătrunsei": "pătrunde",
    "pătrunseră": "pătrunde",
    "pătrunserăm": "pătrunde",
    "pătrunserăți": "pătrunde",
    "pătrunsese": "pătrunde",
    "pătrunsesem": "pătrunde",
    "pătrunseseră": "pătrunde",
    "pătrunseserăm": "pătrunde",
    "pătrunseserăți": "pătrunde",
    "pătrunseseși": "pătrunde",
    "pătrunseși": "pătrunde",
    "pătrunzând": "pătrunde",
    "pătrunzându": "pătrunde",
    "pătrunzi": "pătrunde",
    "pătrunderea": "pătrundere",
    "pătrunderi": "pătrundere",
    "pătrunderii": "pătrundere",
    "pătrunderile": "pătrundere",
    "pătrunderilor": "pătrundere",
    "pătrunjei": "pătrunjel",
    "pătrunjeii": "pătrunjel",
    "pătrunjeilor": "pătrunjel",
    "pătrunjelul": "pătrunjel",
    "pătrunjelului": "pătrunjel",
    "pătrunsă": "pătruns",
    "pătrunse": "pătruns",
    "pătrunși": "pătruns",
    "pătrunzătoare": "pătrunzător",
    "pătrunzătoarea": "pătrunzător",
    "pătrunzătoarei": "pătrunzător",
    "pătrunzătoarele": "pătrunzător",
    "pătrunzătoarelor": "pătrunzător",
    "pătrunzători": "pătrunzător",
    "pătrunzătorii": "pătrunzător",
    "pătrunzătorilor": "pătrunzător",
    "pătrunzătorul": "pătrunzător",
    "pătrunzătorului": "pătrunzător",
    "patrupeda": "patruped",
    "patrupedă": "patruped",
    "patrupede": "patruped",
    "patrupedei": "patruped",
    "patrupedele": "patruped",
    "patrupedelor": "patruped",
    "patrupedul": "patruped",
    "patrupedului": "patruped",
    "patrupezi": "patruped",
    "patrupezii": "patruped",
    "patrupezilor": "patruped",
    "patruzecea": "patruzeci",
    "patruzecilea": "patruzeci",
    "XL": "patruzeci",
    "pătule": "pătul",
    "pătulele": "pătul",
    "pătulelor": "pătul",
    "pătulul": "pătul",
    "pătulului": "pătul",
    "pătura": "pătură",
    "pături": "pătură",
    "păturii": "pătură",
    "păturile": "pătură",
    "păturilor": "pătură",
    "păturita": "păturit",
    "păturită": "păturit",
    "păturite": "păturit",
    "păturitei": "păturit",
    "păturitele": "păturit",
    "păturitelor": "păturit",
    "păturiți": "păturit",
    "păturiții": "păturit",
    "păturiților": "păturit",
    "păturitul": "păturit",
    "păturitului": "păturit",
    "păuni": "păun",
    "păunii": "păun",
    "păunilor": "păun",
    "păunul": "păun",
    "păunului": "păun",
    "paupera": "pauper",
    "pauperă": "pauper",
    "paupere": "pauper",
    "pauperei": "pauper",
    "pauperele": "pauper",
    "pauperelor": "pauper",
    "pauperi": "pauper",
    "pauperii": "pauper",
    "pauperilor": "pauper",
    "pauperul": "pauper",
    "pauperului": "pauper",
    "pauperismul": "pauperism",
    "pauperismului": "pauperism",
    "nemaipauperizând": "pauperiza",
    "nemaipauperizându": "pauperiza",
    "nepauperizând": "pauperiza",
    "nepauperizându": "pauperiza",
    "pauperiză": "pauperiza",
    "pauperizai": "pauperiza",
    "pauperizam": "pauperiza",
    "pauperizăm": "pauperiza",
    "pauperizând": "pauperiza",
    "pauperizându": "pauperiza",
    "pauperizară": "pauperiza",
    "pauperizarăm": "pauperiza",
    "pauperizarăți": "pauperiza",
    "pauperizase": "pauperiza",
    "pauperizasem": "pauperiza",
    "pauperizaseră": "pauperiza",
    "pauperizaserăm": "pauperiza",
    "pauperizaserăți": "pauperiza",
    "pauperizaseși": "pauperiza",
    "pauperizași": "pauperiza",
    "pauperizat": "pauperiza",
    "pauperizați": "pauperiza",
    "pauperizau": "pauperiza",
    "pauperizează": "pauperiza",
    "pauperizez": "pauperiza",
    "pauperizeze": "pauperiza",
    "pauperizezi": "pauperiza",
    "pauperizata": "pauperizat",
    "pauperizată": "pauperizat",
    "pauperizate": "pauperizat",
    "pauperizatei": "pauperizat",
    "pauperizatele": "pauperizat",
    "pauperizatelor": "pauperizat",
    "pauperizați": "pauperizat",
    "pauperizații": "pauperizat",
    "pauperizaților": "pauperizat",
    "pauperizatul": "pauperizat",
    "pauperizatului": "pauperizat",
    "paupertatea": "paupertate",
    "paupertăți": "paupertate",
    "paupertății": "paupertate",
    "pauza": "pauză",
    "pauze": "pauză",
    "pauzei": "pauză",
    "pauzele": "pauză",
    "pauzelor": "pauză",
    "nemaipavând": "pava",
    "nemaipavându": "pava",
    "nepavând": "pava",
    "nepavându": "pava",
    "pavă": "pava",
    "pavai": "pava",
    "pavam": "pava",
    "pavăm": "pava",
    "pavând": "pava",
    "pavându": "pava",
    "pavară": "pava",
    "pavarăm": "pava",
    "pavarăți": "pava",
    "pavase": "pava",
    "pavasem": "pava",
    "pavaseră": "pava",
    "pavaserăm": "pava",
    "pavaserăți": "pava",
    "pavaseși": "pava",
    "pavași": "pava",
    "pavat": "pava",
    "pavați": "pava",
    "pavau": "pava",
    "pavează": "pava",
    "pavez": "pava",
    "paveze": "pava",
    "pavezi": "pava",
    "pavaje": "pavaj",
    "pavajele": "pavaj",
    "pavajelor": "pavaj",
    "pavajul": "pavaj",
    "pavajului": "pavaj",
    "pavată": "pavat",
    "pavate": "pavat",
    "pavați": "pavat",
    "pavăza": "pavăză",
    "paveze": "pavăză",
    "pavezei": "pavăză",
    "pavezele": "pavăză",
    "pavezelor": "pavăză",
    "pavecernița": "pavecerniță",
    "pavecernițe": "pavecerniță",
    "pavecerniței": "pavecerniță",
    "pavecernițele": "pavecerniță",
    "pavecernițelor": "pavecerniță",
    "pavilioane": "pavilion",
    "pavilioanele": "pavilion",
    "pavilioanelor": "pavilion",
    "pavilionul": "pavilion",
    "pavilionului": "pavilion",
    "nemaipavoazând": "pavoaza",
    "nemaipavoazându": "pavoaza",
    "nepavoazând": "pavoaza",
    "nepavoazându": "pavoaza",
    "pavoază": "pavoaza",
    "pavoazai": "pavoaza",
    "pavoazam": "pavoaza",
    "pavoazăm": "pavoaza",
    "pavoazând": "pavoaza",
    "pavoazându": "pavoaza",
    "pavoazară": "pavoaza",
    "pavoazarăm": "pavoaza",
    "pavoazarăți": "pavoaza",
    "pavoazase": "pavoaza",
    "pavoazasem": "pavoaza",
    "pavoazaseră": "pavoaza",
    "pavoazaserăm": "pavoaza",
    "pavoazaserăți": "pavoaza",
    "pavoazaseși": "pavoaza",
    "pavoazași": "pavoaza",
    "pavoazat": "pavoaza",
    "pavoazați": "pavoaza",
    "pavoazau": "pavoaza",
    "pavoazează": "pavoaza",
    "pavoazez": "pavoaza",
    "pavoazeze": "pavoaza",
    "pavoazezi": "pavoaza",
    "pavoazarea": "pavoazare",
    "pavoazări": "pavoazare",
    "pavoazării": "pavoazare",
    "pavoazările": "pavoazare",
    "pavoazărilor": "pavoazare",
    "pavoazată": "pavoazat",
    "pavoazate": "pavoazat",
    "pavoazați": "pavoazat",
    "paza": "pază",
    "paze": "pază",
    "pazei": "pază",
    "pazele": "pază",
    "pazelor": "pază",
    "nemaipăzind": "păzi",
    "nemaipăzindu": "păzi",
    "nepăzind": "păzi",
    "nepăzindu": "păzi",
    "păzea": "păzi",
    "păzeai": "păzi",
    "păzeam": "păzi",
    "păzească": "păzi",
    "păzeați": "păzi",
    "păzeau": "păzi",
    "păzesc": "păzi",
    "păzește": "păzi",
    "păzești": "păzi",
    "păzii": "păzi",
    "păzim": "păzi",
    "păzind": "păzi",
    "păzindu": "păzi",
    "păziră": "păzi",
    "păzirăm": "păzi",
    "păzirăți": "păzi",
    "păzise": "păzi",
    "păzisem": "păzi",
    "păziseră": "păzi",
    "păziserăm": "păzi",
    "păziserăți": "păzi",
    "păziseși": "păzi",
    "păziși": "păzi",
    "păzit": "păzi",
    "păziți": "păzi",
    "păzirea": "păzire",
    "păziri": "păzire",
    "păzirii": "păzire",
    "păzirile": "păzire",
    "păzirilor": "păzire",
    "păzita": "păzit",
    "păzită": "păzit",
    "păzite": "păzit",
    "păzitei": "păzit",
    "păzitele": "păzit",
    "păzitelor": "păzit",
    "păziți": "păzit",
    "păziții": "păzit",
    "păziților": "păzit",
    "păzitul": "păzit",
    "păzitului": "păzit",
    "păzitori": "păzitor",
    "păzitorii": "păzitor",
    "păzitorilor": "păzitor",
    "păzitorul": "păzitor",
    "păzitorului": "păzitor",
    "paznici": "paznic",
    "paznicii": "paznic",
    "paznicilor": "paznic",
    "paznicul": "paznic",
    "paznicului": "paznic",
    "paznica": "paznică",
    "paznice": "paznică",
    "paznicei": "paznică",
    "paznicele": "paznică",
    "paznicelor": "paznică",
    "p'": "pe",
    "p-": "pe",
    "pă": "pe",
    "pe-": "pe",
    "pebrina": "pebrină",
    "pebrinei": "pebrină",
    "pebrini": "pebrină",
    "pebrinile": "pebrină",
    "pebrinilor": "pebrină",
    "peceneaga": "peceneagă",
    "pecenege": "peceneagă",
    "pecenegei": "peceneagă",
    "pecenegele": "peceneagă",
    "pecenegelor": "peceneagă",
    "peceneaga": "peceneg",
    "peceneagă": "peceneg",
    "pecenege": "peceneg",
    "pecenegei": "peceneg",
    "pecenegele": "peceneg",
    "pecenegelor": "peceneg",
    "pecenegi": "peceneg",
    "pecenegii": "peceneg",
    "pecenegilor": "peceneg",
    "pecenegul": "peceneg",
    "pecenegului": "peceneg",
    "pecetea": "pecete",
    "peceți": "pecete",
    "peceții": "pecete",
    "pecețile": "pecete",
    "peceților": "pecete",
    "nemaipecetluind": "pecetlui",
    "nemaipecetluindu": "pecetlui",
    "nepecetluind": "pecetlui",
    "nepecetluindu": "pecetlui",
    "pecetluia": "pecetlui",
    "pecetluiai": "pecetlui",
    "pecetluiam": "pecetlui",
    "pecetluiască": "pecetlui",
    "pecetluiați": "pecetlui",
    "pecetluiau": "pecetlui",
    "pecetluiesc": "pecetlui",
    "pecetluiește": "pecetlui",
    "pecetluiești": "pecetlui",
    "pecetluii": "pecetlui",
    "pecetluim": "pecetlui",
    "pecetluind": "pecetlui",
    "pecetluindu": "pecetlui",
    "pecetluiră": "pecetlui",
    "pecetluirăm": "pecetlui",
    "pecetluirăți": "pecetlui",
    "pecetluise": "pecetlui",
    "pecetluisem": "pecetlui",
    "pecetluiseră": "pecetlui",
    "pecetluiserăm": "pecetlui",
    "pecetluiserăți": "pecetlui",
    "pecetluiseși": "pecetlui",
    "pecetluiși": "pecetlui",
    "pecetluit": "pecetlui",
    "pecetluiți": "pecetlui",
    "pecetluirea": "pecetluire",
    "pecetluiri": "pecetluire",
    "pecetluirii": "pecetluire",
    "pecetluirile": "pecetluire",
    "pecetluirilor": "pecetluire",
    "pecetluita": "pecetluit",
    "pecetluită": "pecetluit",
    "pecetluite": "pecetluit",
    "pecetluitei": "pecetluit",
    "pecetluitele": "pecetluit",
    "pecetluitelor": "pecetluit",
    "pecetluiți": "pecetluit",
    "pecetluiții": "pecetluit",
    "pecetluiților": "pecetluit",
    "pecetluitul": "pecetluit",
    "pecetluitului": "pecetluit",
    "pechinezi": "pechinez",
    "pechinezii": "pechinez",
    "pechinezilor": "pechinez",
    "pechinezul": "pechinez",
    "pechinezului": "pechinez",
    "pecia": "pecie",
    "peciei": "pecie",
    "pecii": "pecie",
    "peciile": "pecie",
    "peciilor": "pecie",
    "pecinginea": "pecingine",
    "pecingini": "pecingine",
    "pecinginii": "pecingine",
    "pecinginile": "pecingine",
    "pecinginilor": "pecingine",
    "pectina": "pectină",
    "pectine": "pectină",
    "pectinei": "pectină",
    "pectinele": "pectină",
    "pectinelor": "pectină",
    "pectorala": "pectoral",
    "pectorală": "pectoral",
    "pectorale": "pectoral",
    "pectoralei": "pectoral",
    "pectoralele": "pectoral",
    "pectoralelor": "pectoral",
    "pectorali": "pectoral",
    "pectoralii": "pectoral",
    "pectoralilor": "pectoral",
    "pectoralul": "pectoral",
    "pectoralului": "pectoral",
    "peculiul": "peculiu",
    "peculiului": "peculiu",
    "pecuniara": "pecuniar",
    "pecuniară": "pecuniar",
    "pecuniare": "pecuniar",
    "pecuniarei": "pecuniar",
    "pecuniarele": "pecuniar",
    "pecuniarelor": "pecuniar",
    "pecuniari": "pecuniar",
    "pecuniarii": "pecuniar",
    "pecuniarilor": "pecuniar",
    "pecuniarul": "pecuniar",
    "pecuniarului": "pecuniar",
    "pedagogi": "pedagog",
    "pedagogii": "pedagog",
    "pedagogilor": "pedagog",
    "pedagogul": "pedagog",
    "pedagogului": "pedagog",
    "pedagoga": "pedagogă",
    "pedagoge": "pedagogă",
    "pedagogei": "pedagogă",
    "pedagogele": "pedagogă",
    "pedagogelor": "pedagogă",
    "pedagogica": "pedagogic",
    "pedagogică": "pedagogic",
    "pedagogice": "pedagogic",
    "pedagogicei": "pedagogic",
    "pedagogicele": "pedagogic",
    "pedagogicelor": "pedagogic",
    "pedagogici": "pedagogic",
    "pedagogicii": "pedagogic",
    "pedagogicilor": "pedagogic",
    "pedagogicul": "pedagogic",
    "pedagogicului": "pedagogic",
    "ped.": "pedagogie",
    "pedagogia": "pedagogie",
    "pedagogiei": "pedagogie",
    "pedagogii": "pedagogie",
    "pedagogiile": "pedagogie",
    "pedagogiilor": "pedagogie",
    "nemaipedalând": "pedala",
    "nemaipedalându": "pedala",
    "nepedalând": "pedala",
    "nepedalându": "pedala",
    "pedală": "pedala",
    "pedalai": "pedala",
    "pedalam": "pedala",
    "pedalăm": "pedala",
    "pedalând": "pedala",
    "pedalându": "pedala",
    "pedalară": "pedala",
    "pedalarăm": "pedala",
    "pedalarăți": "pedala",
    "pedalase": "pedala",
    "pedalasem": "pedala",
    "pedalaseră": "pedala",
    "pedalaserăm": "pedala",
    "pedalaserăți": "pedala",
    "pedalaseși": "pedala",
    "pedalași": "pedala",
    "pedalat": "pedala",
    "pedalați": "pedala",
    "pedalau": "pedala",
    "pedalează": "pedala",
    "pedalez": "pedala",
    "pedaleze": "pedala",
    "pedalezi": "pedala",
    "pedala": "pedală",
    "pedale": "pedală",
    "pedalei": "pedală",
    "pedalele": "pedală",
    "pedalelor": "pedală",
    "pedalată": "pedalat",
    "pedalate": "pedalat",
    "pedalați": "pedalat",
    "pedanta": "pedant",
    "pedantă": "pedant",
    "pedante": "pedant",
    "pedantei": "pedant",
    "pedantele": "pedant",
    "pedantelor": "pedant",
    "pedanți": "pedant",
    "pedanții": "pedant",
    "pedanților": "pedant",
    "pedantul": "pedant",
    "pedantului": "pedant",
    "pedanteria": "pedanterie",
    "pedanteriei": "pedanterie",
    "pedanterii": "pedanterie",
    "pedanteriile": "pedanterie",
    "pedanteriilor": "pedanterie",
    "pedeapsa": "pedeapsă",
    "pedepse": "pedeapsă",
    "pedepsei": "pedeapsă",
    "pedepsele": "pedeapsă",
    "pedepselor": "pedeapsă",
    "nemaipedepsind": "pedepsi",
    "nemaipedepsindu": "pedepsi",
    "nepedepsind": "pedepsi",
    "nepedepsindu": "pedepsi",
    "pedepsea": "pedepsi",
    "pedepseai": "pedepsi",
    "pedepseam": "pedepsi",
    "pedepsească": "pedepsi",
    "pedepseați": "pedepsi",
    "pedepseau": "pedepsi",
    "pedepsesc": "pedepsi",
    "pedepsește": "pedepsi",
    "pedepsești": "pedepsi",
    "pedepsii": "pedepsi",
    "pedepsim": "pedepsi",
    "pedepsind": "pedepsi",
    "pedepsindu": "pedepsi",
    "pedepsiră": "pedepsi",
    "pedepsirăm": "pedepsi",
    "pedepsirăți": "pedepsi",
    "pedepsise": "pedepsi",
    "pedepsisem": "pedepsi",
    "pedepsiseră": "pedepsi",
    "pedepsiserăm": "pedepsi",
    "pedepsiserăți": "pedepsi",
    "pedepsiseși": "pedepsi",
    "pedepsiși": "pedepsi",
    "pedepsit": "pedepsi",
    "pedepsiți": "pedepsi",
    "pedepsirea": "pedepsire",
    "pedepsiri": "pedepsire",
    "pedepsirii": "pedepsire",
    "pedepsirile": "pedepsire",
    "pedepsirilor": "pedepsire",
    "pedepsita": "pedepsit",
    "pedepsită": "pedepsit",
    "pedepsite": "pedepsit",
    "pedepsitei": "pedepsit",
    "pedepsitele": "pedepsit",
    "pedepsitelor": "pedepsit",
    "pedepsiți": "pedepsit",
    "pedepsiții": "pedepsit",
    "pedepsiților": "pedepsit",
    "pedepsitul": "pedepsit",
    "pedepsitului": "pedepsit",
    "pederaști": "pederast",
    "pederaștii": "pederast",
    "pederaștilor": "pederast",
    "pederastul": "pederast",
    "pederastului": "pederast",
    "pederastia": "pederastie",
    "pederastiei": "pederastie",
    "pederastii": "pederastie",
    "pedeseristă": "pedeserist",
    "pedestra": "pedestru",
    "pedestră": "pedestru",
    "pedestre": "pedestru",
    "pedestrei": "pedestru",
    "pedestrele": "pedestru",
    "pedestrelor": "pedestru",
    "pedeștri": "pedestru",
    "pedeștrii": "pedestru",
    "pedeștrilor": "pedestru",
    "pedestrul": "pedestru",
    "pedestrului": "pedestru",
    "pediatrica": "pediatric",
    "pediatrică": "pediatric",
    "pediatrice": "pediatric",
    "pediatricei": "pediatric",
    "pediatricele": "pediatric",
    "pediatricelor": "pediatric",
    "pediatrici": "pediatric",
    "pediatricii": "pediatric",
    "pediatricilor": "pediatric",
    "pediatricul": "pediatric",
    "pediatricului": "pediatric",
    "pediatria": "pediatrie",
    "pediatriei": "pediatrie",
    "pediatrii": "pediatrie",
    "pediatri": "pediatru",
    "pediatrii": "pediatru",
    "pediatrilor": "pediatru",
    "pediatrul": "pediatru",
    "pediatrului": "pediatru",
    "pedicele": "pedicel",
    "pedicelele": "pedicel",
    "pedicelelor": "pedicel",
    "pedicelul": "pedicel",
    "pedicelului": "pedicel",
    "pedichiura": "pedichiură",
    "pedichiuri": "pedichiură",
    "pedichiurii": "pedichiură",
    "pedichiurile": "pedichiură",
    "pedichiurilor": "pedichiură",
    "pedichiuriști": "pedichiurist",
    "pedichiuriștii": "pedichiurist",
    "pedichiuriștilor": "pedichiurist",
    "pedichiuristul": "pedichiurist",
    "pedichiuristului": "pedichiurist",
    "pedichiurista": "pedichiuristă",
    "pedichiuriste": "pedichiuristă",
    "pedichiuristei": "pedichiuristă",
    "pedichiuristele": "pedichiuristă",
    "pedichiuristelor": "pedichiuristă",
    "pedicule": "pedicul",
    "pediculele": "pedicul",
    "pediculelor": "pedicul",
    "pediculul": "pedicul",
    "pediculului": "pedicul",
    "pedigriul": "pedigriu",
    "pedigriului": "pedigriu",
    "pediometre": "pediometru",
    "pediometrele": "pediometru",
    "pediometrelor": "pediometru",
    "pediometrul": "pediometru",
    "pediometrului": "pediometru",
    "pedoclimatice": "pedoclimatic",
    "pedoclimatici": "pedoclimatic",
    "pedologi": "pedolog",
    "pedologii": "pedolog",
    "pedologilor": "pedolog",
    "pedologul": "pedolog",
    "pedologului": "pedolog",
    "pedologia": "pedologie",
    "pedologiei": "pedologie",
    "pedologii": "pedologie",
    "pedometre": "pedometru",
    "pedometrele": "pedometru",
    "pedometrelor": "pedometru",
    "pedometrul": "pedometru",
    "pedometrului": "pedometru",
    "pedunculi": "peduncul",
    "pedunculii": "peduncul",
    "pedunculilor": "peduncul",
    "pedunculul": "peduncul",
    "pedunculului": "peduncul",
    "pegași": "pegas",
    "pegașii": "pegas",
    "pegașilor": "pegas",
    "pegasul": "pegas",
    "pegasului": "pegas",
    "pegmatita": "pegmatită",
    "pegmatite": "pegmatită",
    "pegmatitei": "pegmatită",
    "pegmatitele": "pegmatită",
    "pegmatitelor": "pegmatită",
    "pehblenda": "pehblendă",
    "pehblende": "pehblendă",
    "pehblendei": "pehblendă",
    "pehlivane": "pehlivan",
    "pehlivani": "pehlivan",
    "pehlivanii": "pehlivan",
    "pehlivanilor": "pehlivan",
    "pehlivanul": "pehlivan",
    "pehlivanului": "pehlivan",
    "peiorativa": "peiorativ",
    "peiorativă": "peiorativ",
    "peiorative": "peiorativ",
    "peiorativei": "peiorativ",
    "peiorativele": "peiorativ",
    "peiorativelor": "peiorativ",
    "peiorativi": "peiorativ",
    "peiorativii": "peiorativ",
    "peiorativilor": "peiorativ",
    "peiorativul": "peiorativ",
    "peiorativului": "peiorativ",
    "peisagiști": "peisagist",
    "peisagiștii": "peisagist",
    "peisagiștilor": "peisagist",
    "peisagistul": "peisagist",
    "peisagistului": "peisagist",
    "peisagista": "peisagistă",
    "peisagiste": "peisagistă",
    "peisagistei": "peisagistă",
    "peisagistele": "peisagistă",
    "peisagistelor": "peisagistă",
    "peisagistica": "peisagistică",
    "peisagistici": "peisagistică",
    "peisagisticii": "peisagistică",
    "peisaje": "peisaj",
    "peisajele": "peisaj",
    "peisajelor": "peisaj",
    "peisajul": "peisaj",
    "peisajului": "peisaj",
    "pelada": "peladă",
    "pelade": "peladă",
    "peladei": "peladă",
    "peladele": "peladă",
    "peladelor": "peladă",
    "pelagra": "pelagră",
    "pelagre": "pelagră",
    "pelagrei": "pelagră",
    "pelagrele": "pelagră",
    "pelagrelor": "pelagră",
    "pelegrini": "pelegrin",
    "pelegrinii": "pelegrin",
    "pelegrinilor": "pelegrin",
    "pelegrinul": "pelegrin",
    "pelegrinului": "pelegrin",
    "pelengul": "peleng",
    "pelengului": "peleng",
    "pelenguri": "peleng",
    "pelengurile": "peleng",
    "pelengurilor": "peleng",
    "pelerini": "pelerin",
    "pelerinii": "pelerin",
    "pelerinilor": "pelerin",
    "pelerinul": "pelerin",
    "pelerinului": "pelerin",
    "pelerina": "pelerină",
    "pelerine": "pelerină",
    "pelerinei": "pelerină",
    "pelerinele": "pelerină",
    "pelerinelor": "pelerină",
    "pelerinaje": "pelerinaj",
    "pelerinajele": "pelerinaj",
    "pelerinajelor": "pelerinaj",
    "pelerinajul": "pelerinaj",
    "pelerinajului": "pelerinaj",
    "peletice": "peletic",
    "peleticele": "peletic",
    "peleticelor": "peletic",
    "peleticul": "peletic",
    "peleticului": "peletic",
    "pelicani": "pelican",
    "pelicanii": "pelican",
    "pelicanilor": "pelican",
    "pelicanul": "pelican",
    "pelicanului": "pelican",
    "pelicula": "peliculă",
    "pelicule": "peliculă",
    "peliculei": "peliculă",
    "peliculele": "peliculă",
    "peliculelor": "peliculă",
    "pelinul": "pelin",
    "pelinului": "pelin",
    "Pelopizilor": "Pelopid",
    "pelteaua": "peltea",
    "peltele": "peltea",
    "peltelei": "peltea",
    "peltelele": "peltea",
    "peltelelor": "peltea",
    "peltica": "peltic",
    "peltică": "peltic",
    "peltice": "peltic",
    "pelticei": "peltic",
    "pelticele": "peltic",
    "pelticelor": "peltic",
    "peltici": "peltic",
    "pelticii": "peltic",
    "pelticilor": "peltic",
    "pelticul": "peltic",
    "pelticului": "peltic",
    "peluza": "peluză",
    "peluze": "peluză",
    "peluzei": "peluză",
    "peluzele": "peluză",
    "peluzelor": "peluză",
    "pelviana": "pelvian",
    "pelviană": "pelvian",
    "pelvianul": "pelvian",
    "pelvianului": "pelvian",
    "pelviene": "pelvian",
    "pelvienei": "pelvian",
    "pelvienele": "pelvian",
    "pelvienelor": "pelvian",
    "pelvieni": "pelvian",
    "pelvienii": "pelvian",
    "pelvienilor": "pelvian",
    "penaje": "penaj",
    "penajele": "penaj",
    "penajelor": "penaj",
    "penajul": "penaj",
    "penajului": "penaj",
    "penala": "penal",
    "penală": "penal",
    "penale": "penal",
    "penalei": "penal",
    "penalele": "penal",
    "penalelor": "penal",
    "penali": "penal",
    "penalii": "penal",
    "penalilor": "penal",
    "penalul": "penal",
    "penalului": "penal",
    "penaliști": "penalist",
    "penaliștii": "penalist",
    "penaliștilor": "penalist",
    "penalistul": "penalist",
    "penalistului": "penalist",
    "penalitatea": "penalitate",
    "penalități": "penalitate",
    "penalității": "penalitate",
    "penalitățile": "penalitate",
    "penalităților": "penalitate",
    "nemaipenalizând": "penaliza",
    "nemaipenalizându": "penaliza",
    "nepenalizând": "penaliza",
    "nepenalizându": "penaliza",
    "penaliză": "penaliza",
    "penalizai": "penaliza",
    "penalizam": "penaliza",
    "penalizăm": "penaliza",
    "penalizând": "penaliza",
    "penalizându": "penaliza",
    "penalizară": "penaliza",
    "penalizarăm": "penaliza",
    "penalizarăți": "penaliza",
    "penalizase": "penaliza",
    "penalizasem": "penaliza",
    "penalizaseră": "penaliza",
    "penalizaserăm": "penaliza",
    "penalizaserăți": "penaliza",
    "penalizaseși": "penaliza",
    "penalizași": "penaliza",
    "penalizat": "penaliza",
    "penalizați": "penaliza",
    "penalizau": "penaliza",
    "penalizează": "penaliza",
    "penalizez": "penaliza",
    "penalizeze": "penaliza",
    "penalizezi": "penaliza",
    "penalizarea": "penalizare",
    "penalizări": "penalizare",
    "penalizării": "penalizare",
    "penalizările": "penalizare",
    "penalizărilor": "penalizare",
    "penalizată": "penalizat",
    "penalizate": "penalizat",
    "penalizați": "penalizat",
    "penare": "penar",
    "penarele": "penar",
    "penarelor": "penar",
    "penarul": "penar",
    "penarului": "penar",
    "penata": "penat",
    "penată": "penat",
    "penate": "penat",
    "penatei": "penat",
    "penatele": "penat",
    "penatelor": "penat",
    "penați": "penat",
    "penații": "penat",
    "penaților": "penat",
    "penatul": "penat",
    "penatului": "penat",
    "pendule": "pendul",
    "pendulele": "pendul",
    "pendulelor": "pendul",
    "pendulul": "pendul",
    "pendulului": "pendul",
    "nemaipendulând": "pendula",
    "nemaipendulându": "pendula",
    "nependulând": "pendula",
    "nependulându": "pendula",
    "pendulă": "pendula",
    "pendulai": "pendula",
    "pendulam": "pendula",
    "pendulăm": "pendula",
    "pendulând": "pendula",
    "pendulându": "pendula",
    "pendulară": "pendula",
    "pendularăm": "pendula",
    "pendularăți": "pendula",
    "pendulase": "pendula",
    "pendulasem": "pendula",
    "pendulaseră": "pendula",
    "pendulaserăm": "pendula",
    "pendulaserăți": "pendula",
    "pendulaseși": "pendula",
    "pendulași": "pendula",
    "pendulat": "pendula",
    "pendulați": "pendula",
    "pendulau": "pendula",
    "pendulează": "pendula",
    "pendulez": "pendula",
    "penduleze": "pendula",
    "pendulezi": "pendula",
    "pendula": "pendulă",
    "pendule": "pendulă",
    "pendulei": "pendulă",
    "pendulara": "pendular",
    "pendulară": "pendular",
    "pendulare": "pendular",
    "pendularei": "pendular",
    "pendularele": "pendular",
    "pendularelor": "pendular",
    "pendulari": "pendular",
    "pendularii": "pendular",
    "pendularilor": "pendular",
    "pendularul": "pendular",
    "pendularului": "pendular",
    "pendularea": "pendulare",
    "pendulări": "pendulare",
    "pendulării": "pendulare",
    "pendulările": "pendulare",
    "pendulărilor": "pendulare",
    "pendulată": "pendulat",
    "pendulate": "pendulat",
    "pendulați": "pendulat",
    "penelul": "penel",
    "penelului": "penel",
    "peneluri": "penel",
    "penelurile": "penel",
    "penelurilor": "penel",
    "nemaipenetrând": "penetra",
    "nemaipenetrându": "penetra",
    "nepenetrând": "penetra",
    "nepenetrându": "penetra",
    "penetră": "penetra",
    "penetrai": "penetra",
    "penetram": "penetra",
    "penetrăm": "penetra",
    "penetrând": "penetra",
    "penetrându": "penetra",
    "penetrară": "penetra",
    "penetrarăm": "penetra",
    "penetrarăți": "penetra",
    "penetrase": "penetra",
    "penetrasem": "penetra",
    "penetraseră": "penetra",
    "penetraserăm": "penetra",
    "penetraserăți": "penetra",
    "penetraseși": "penetra",
    "penetrași": "penetra",
    "penetrat": "penetra",
    "penetrați": "penetra",
    "penetrau": "penetra",
    "penetrează": "penetra",
    "penetrez": "penetra",
    "penetreze": "penetra",
    "penetrezi": "penetra",
    "penetrabila": "penetrabil",
    "penetrabilă": "penetrabil",
    "penetrabile": "penetrabil",
    "penetrabilei": "penetrabil",
    "penetrabilele": "penetrabil",
    "penetrabilelor": "penetrabil",
    "penetrabili": "penetrabil",
    "penetrabilii": "penetrabil",
    "penetrabililor": "penetrabil",
    "penetrabilul": "penetrabil",
    "penetrabilului": "penetrabil",
    "penetrabilitatea": "penetrabilitate",
    "penetrabilități": "penetrabilitate",
    "penetrabilității": "penetrabilitate",
    "penetranta": "penetrant",
    "penetrantă": "penetrant",
    "penetrante": "penetrant",
    "penetrantei": "penetrant",
    "penetrantele": "penetrant",
    "penetrantelor": "penetrant",
    "penetranți": "penetrant",
    "penetranții": "penetrant",
    "penetranților": "penetrant",
    "penetrantul": "penetrant",
    "penetrantului": "penetrant",
    "penetrată": "penetrat",
    "penetrate": "penetrat",
    "penetrați": "penetrat",
    "penetrația": "penetrație",
    "penetrației": "penetrație",
    "penetrații": "penetrație",
    "penetrațiile": "penetrație",
    "penetrațiilor": "penetrație",
    "penibila": "penibil",
    "penibilă": "penibil",
    "penibile": "penibil",
    "penibilei": "penibil",
    "penibilele": "penibil",
    "penibilelor": "penibil",
    "penibili": "penibil",
    "penibilii": "penibil",
    "penibililor": "penibil",
    "penibilul": "penibil",
    "penibilului": "penibil",
    "penicilina": "penicilină",
    "peniciline": "penicilină",
    "penicilinei": "penicilină",
    "penicilinele": "penicilină",
    "penicilinelor": "penicilină",
    "peninsula": "peninsulă",
    "peninsule": "peninsulă",
    "peninsulei": "peninsulă",
    "peninsulele": "peninsulă",
    "peninsulelor": "peninsulă",
    "peninsulara": "peninsular",
    "peninsulară": "peninsular",
    "peninsulare": "peninsular",
    "peninsularei": "peninsular",
    "peninsularele": "peninsular",
    "peninsularelor": "peninsular",
    "peninsulari": "peninsular",
    "peninsularii": "peninsular",
    "peninsularilor": "peninsular",
    "peninsularul": "peninsular",
    "peninsularului": "peninsular",
    "penisul": "penis",
    "penisului": "penis",
    "penisuri": "penis",
    "penisurile": "penis",
    "penisurilor": "penis",
    "penița": "peniță",
    "penițe": "peniță",
    "peniței": "peniță",
    "penițele": "peniță",
    "penițelor": "peniță",
    "penitenciare": "penitenciar",
    "penitenciarele": "penitenciar",
    "penitenciarelor": "penitenciar",
    "penitenciarul": "penitenciar",
    "penitenciarului": "penitenciar",
    "penitenți": "penitent",
    "penitenții": "penitent",
    "penitenților": "penitent",
    "penitentul": "penitent",
    "penitentului": "penitent",
    "penitenta": "penitentă",
    "penitente": "penitentă",
    "penitentei": "penitentă",
    "penitentele": "penitentă",
    "penitentelor": "penitentă",
    "penitența": "penitență",
    "penitențe": "penitență",
    "penitenței": "penitență",
    "penitențele": "penitență",
    "penitențelor": "penitență",
    "pensa": "pensă",
    "pense": "pensă",
    "pensei": "pensă",
    "pensele": "pensă",
    "penselor": "pensă",
    "penseta": "pensetă",
    "pensete": "pensetă",
    "pensetei": "pensetă",
    "pensetele": "pensetă",
    "pensetelor": "pensetă",
    "pensia": "pensie",
    "pensiei": "pensie",
    "pensii": "pensie",
    "pensiile": "pensie",
    "pensiilor": "pensie",
    "pensioane": "pension",
    "pensioanele": "pension",
    "pensioanelor": "pension",
    "pensionul": "pension",
    "pensionului": "pension",
    "pensionă": "pensiona",
    "pensionai": "pensiona",
    "pensionam": "pensiona",
    "pensionăm": "pensiona",
    "pensionând": "pensiona",
    "pensionară": "pensiona",
    "pensionarăm": "pensiona",
    "pensionarăți": "pensiona",
    "pensionase": "pensiona",
    "pensionasem": "pensiona",
    "pensionaseră": "pensiona",
    "pensionaserăm": "pensiona",
    "pensionaserăți": "pensiona",
    "pensionaseși": "pensiona",
    "pensionași": "pensiona",
    "pensionat": "pensiona",
    "pensionați": "pensiona",
    "pensionau": "pensiona",
    "pensionează": "pensiona",
    "pensionez": "pensiona",
    "pensioneze": "pensiona",
    "pensionezi": "pensiona",
    "pensionari": "pensionar",
    "pensionarii": "pensionar",
    "pensionarilor": "pensionar",
    "pensionarul": "pensionar",
    "pensionarului": "pensionar",
    "pensionara": "pensionară",
    "pensionare": "pensionară",
    "pensionarei": "pensionară",
    "pensionarele": "pensionară",
    "pensionarelor": "pensionară",
    "pensionarea": "pensionare",
    "pensionări": "pensionare",
    "pensionării": "pensionare",
    "pensionările": "pensionare",
    "pensionărilor": "pensionare",
    "pensionata": "pensionat",
    "pensionată": "pensionat",
    "pensionate": "pensionat",
    "pensionatei": "pensionat",
    "pensionatele": "pensionat",
    "pensionatelor": "pensionat",
    "pensionați": "pensionat",
    "pensionații": "pensionat",
    "pensionaților": "pensionat",
    "pensionatul": "pensionat",
    "pensionatului": "pensionat",
    "pensiunea": "pensiune",
    "pensiuni": "pensiune",
    "pensiunii": "pensiune",
    "pensiunile": "pensiune",
    "pensiunilor": "pensiune",
    "pensula": "pensulă",
    "pensule": "pensulă",
    "pensulei": "pensulă",
    "pensulele": "pensulă",
    "pensulelor": "pensulă",
    "pentaedre": "pentaedru",
    "pentaedrele": "pentaedru",
    "pentaedrelor": "pentaedru",
    "pentaedrul": "pentaedru",
    "pentaedrului": "pentaedru",
    "pentagoane": "pentagon",
    "pentagoanele": "pentagon",
    "pentagoanelor": "pentagon",
    "pentagonul": "pentagon",
    "pentagonului": "pentagon",
    "pentagonala": "pentagonal",
    "pentagonală": "pentagonal",
    "pentagonale": "pentagonal",
    "pentagonalei": "pentagonal",
    "pentagonalele": "pentagonal",
    "pentagonalelor": "pentagonal",
    "pentagonali": "pentagonal",
    "pentagonalii": "pentagonal",
    "pentagonalilor": "pentagonal",
    "pentagonalul": "pentagonal",
    "pentagonalului": "pentagonal",
    "pentagrama": "pentagramă",
    "pentagrame": "pentagramă",
    "pentagramei": "pentagramă",
    "pentagramele": "pentagramă",
    "pentagramelor": "pentagramă",
    "pentametri": "pentametru",
    "pentametrii": "pentametru",
    "pentametrilor": "pentametru",
    "pentametrul": "pentametru",
    "pentametrului": "pentametru",
    "pentateuhul": "pentateuh",
    "pentateuhului": "pentateuh",
    "pentateuhuri": "pentateuh",
    "pentateuhurile": "pentateuh",
    "pentateuhurilor": "pentateuh",
    "pentatloane": "pentatlon",
    "pentatloanele": "pentatlon",
    "pentatloanelor": "pentatlon",
    "pentatlonul": "pentatlon",
    "pentatlonului": "pentatlon",
    "penteleie": "penteleu",
    "penteleiele": "penteleu",
    "penteleielor": "penteleu",
    "penteleul": "penteleu",
    "penteleului": "penteleu",
    "penticostare": "penticostar",
    "penticostarele": "penticostar",
    "penticostarelor": "penticostar",
    "penticostarul": "penticostar",
    "penticostarului": "penticostar",
    "pentoda": "pentodă",
    "pentode": "pentodă",
    "pentodei": "pentodă",
    "pentodele": "pentodă",
    "pentodelor": "pentodă",
    "pentr-": "pentru",
    "pt.": "pentru",
    "ptr.": "pentru",
    "penultima": "penultim",
    "penultimă": "penultim",
    "penultime": "penultim",
    "penultimei": "penultim",
    "penultimele": "penultim",
    "penultimelor": "penultim",
    "penultimi": "penultim",
    "penultimii": "penultim",
    "penultimilor": "penultim",
    "penultimul": "penultim",
    "penultimului": "penultim",
    "penumbra": "penumbră",
    "penumbre": "penumbră",
    "penumbrei": "penumbră",
    "penumbrele": "penumbră",
    "penumbrelor": "penumbră",
    "penuria": "penurie",
    "penuriei": "penurie",
    "penurii": "penurie",
    "pepenăria": "pepenărie",
    "pepenăriei": "pepenărie",
    "pepenării": "pepenărie",
    "pepenăriile": "pepenărie",
    "pepenăriilor": "pepenărie",
    "pepenele": "pepene",
    "pepenelui": "pepene",
    "pepeni": "pepene",
    "pepenii": "pepene",
    "pepenilor": "pepene",
    "pepiniera": "pepinieră",
    "pepiniere": "pepinieră",
    "pepinierei": "pepinieră",
    "pepinierele": "pepinieră",
    "pepinierelor": "pepinieră",
    "pepita": "pepit",
    "pepită": "pepit",
    "pepite": "pepit",
    "pepitei": "pepit",
    "pepitele": "pepit",
    "pepitelor": "pepit",
    "pepiți": "pepit",
    "pepiții": "pepit",
    "pepiților": "pepit",
    "pepitul": "pepit",
    "pepitului": "pepit",
    "peplul": "peplu",
    "peplului": "peplu",
    "pepluri": "peplu",
    "peplurile": "peplu",
    "peplurilor": "peplu",
    "pepsina": "pepsină",
    "pepsine": "pepsină",
    "pepsinei": "pepsină",
    "pepsinele": "pepsină",
    "pepsinelor": "pepsină",
    "peptona": "peptonă",
    "peptone": "peptonă",
    "peptonei": "peptonă",
    "peptonele": "peptonă",
    "peptonelor": "peptonă",
    "p.a.": "per_anum",
    "nemaipercepând": "percepe",
    "nemaipercepându": "percepe",
    "nepercepând": "percepe",
    "nepercepându": "percepe",
    "perceapă": "percepe",
    "percep": "percepe",
    "percepând": "percepe",
    "percepându": "percepe",
    "percepea": "percepe",
    "percepeai": "percepe",
    "percepeam": "percepe",
    "percepeați": "percepe",
    "percepeau": "percepe",
    "percepem": "percepe",
    "percepeți": "percepe",
    "percepi": "percepe",
    "percepu": "percepe",
    "percepui": "percepe",
    "percepură": "percepe",
    "percepurăm": "percepe",
    "percepurăți": "percepe",
    "percepuse": "percepe",
    "percepusem": "percepe",
    "percepuseră": "percepe",
    "percepuserăm": "percepe",
    "percepuserăți": "percepe",
    "percepuseși": "percepe",
    "percepuși": "percepe",
    "perceput": "percepe",
    "perceperea": "percepere",
    "perceperi": "percepere",
    "perceperii": "percepere",
    "perceperile": "percepere",
    "perceperilor": "percepere",
    "perceptibila": "perceptibil",
    "perceptibilă": "perceptibil",
    "perceptibile": "perceptibil",
    "perceptibilei": "perceptibil",
    "perceptibilele": "perceptibil",
    "perceptibilelor": "perceptibil",
    "perceptibili": "perceptibil",
    "perceptibilii": "perceptibil",
    "perceptibililor": "perceptibil",
    "perceptibilul": "perceptibil",
    "perceptibilului": "perceptibil",
    "perceptibilitatea": "perceptibilitate",
    "perceptibilități": "perceptibilitate",
    "perceptibilității": "perceptibilitate",
    "percepția": "percepție",
    "percepției": "percepție",
    "percepții": "percepție",
    "percepțiile": "percepție",
    "percepțiilor": "percepție",
    "perceptori": "perceptor",
    "perceptorii": "perceptor",
    "perceptorilor": "perceptor",
    "perceptorul": "perceptor",
    "perceptorului": "perceptor",
    "percepută": "perceput",
    "percepute": "perceput",
    "percepuți": "perceput",
    "percheziția": "percheziție",
    "percheziției": "percheziție",
    "percheziții": "percheziție",
    "perchezițiile": "percheziție",
    "perchezițiilor": "percheziție",
    "nemaipercheziționând": "percheziționa",
    "nemaipercheziționându": "percheziționa",
    "nepercheziționând": "percheziționa",
    "nepercheziționându": "percheziționa",
    "percheziționă": "percheziționa",
    "percheziționai": "percheziționa",
    "percheziționam": "percheziționa",
    "percheziționăm": "percheziționa",
    "percheziționând": "percheziționa",
    "percheziționându": "percheziționa",
    "percheziționară": "percheziționa",
    "percheziționarăm": "percheziționa",
    "percheziționarăți": "percheziționa",
    "percheziționase": "percheziționa",
    "percheziționasem": "percheziționa",
    "percheziționaseră": "percheziționa",
    "percheziționaserăm": "percheziționa",
    "percheziționaserăți": "percheziționa",
    "percheziționaseși": "percheziționa",
    "percheziționași": "percheziționa",
    "percheziționat": "percheziționa",
    "percheziționați": "percheziționa",
    "percheziționau": "percheziționa",
    "percheziționează": "percheziționa",
    "percheziționez": "percheziționa",
    "percheziționeze": "percheziționa",
    "percheziționezi": "percheziționa",
    "percheziționată": "percheziționat",
    "percheziționate": "percheziționat",
    "percheziționați": "percheziționat",
    "perciunata": "perciunat",
    "perciunată": "perciunat",
    "perciunate": "perciunat",
    "perciunatei": "perciunat",
    "perciunatele": "perciunat",
    "perciunatelor": "perciunat",
    "perciunați": "perciunat",
    "perciunații": "perciunat",
    "perciunaților": "perciunat",
    "perciunatul": "perciunat",
    "perciunatului": "perciunat",
    "perciunele": "perciune",
    "perciunelui": "perciune",
    "perciuni": "perciune",
    "perciunii": "perciune",
    "perciunilor": "perciune",
    "nemaipercutând": "percuta",
    "nemaipercutându": "percuta",
    "nepercutând": "percuta",
    "nepercutându": "percuta",
    "percută": "percuta",
    "percutai": "percuta",
    "percutam": "percuta",
    "percutăm": "percuta",
    "percutând": "percuta",
    "percutându": "percuta",
    "percutară": "percuta",
    "percutarăm": "percuta",
    "percutarăți": "percuta",
    "percutase": "percuta",
    "percutasem": "percuta",
    "percutaseră": "percuta",
    "percutaserăm": "percuta",
    "percutaserăți": "percuta",
    "percutaseși": "percuta",
    "percutași": "percuta",
    "percutat": "percuta",
    "percutați": "percuta",
    "percutau": "percuta",
    "percutează": "percuta",
    "percutez": "percuta",
    "percuteze": "percuta",
    "percutezi": "percuta",
    "percutanta": "percutant",
    "percutantă": "percutant",
    "percutante": "percutant",
    "percutantei": "percutant",
    "percutantele": "percutant",
    "percutantelor": "percutant",
    "percutanți": "percutant",
    "percutanții": "percutant",
    "percutanților": "percutant",
    "percutantul": "percutant",
    "percutantului": "percutant",
    "percutată": "percutat",
    "percutate": "percutat",
    "percutați": "percutat",
    "percuția": "percuție",
    "percuției": "percuție",
    "percuții": "percuție",
    "percuțiile": "percuție",
    "percuțiilor": "percuție",
    "percutoare": "percutor",
    "percutoarele": "percutor",
    "percutoarelor": "percutor",
    "percutorul": "percutor",
    "percutorului": "percutor",
    "perdaful": "perdaf",
    "perdafului": "perdaf",
    "perdafuri": "perdaf",
    "perdafurile": "perdaf",
    "perdafurilor": "perdaf",
    "perdeaua": "perdea",
    "perdele": "perdea",
    "perdelei": "perdea",
    "perdelele": "perdea",
    "perdelelor": "perdea",
    "perechea": "pereche",
    "perechi": "pereche",
    "perechii": "pereche",
    "perechile": "pereche",
    "perechilor": "pereche",
    "peregrini": "peregrin",
    "peregrinii": "peregrin",
    "peregrinilor": "peregrin",
    "peregrinul": "peregrin",
    "peregrinului": "peregrin",
    "nemaiperegrinând": "peregrina",
    "nemaiperegrinându": "peregrina",
    "neperegrinând": "peregrina",
    "neperegrinându": "peregrina",
    "peregrină": "peregrina",
    "peregrinai": "peregrina",
    "peregrinam": "peregrina",
    "peregrinăm": "peregrina",
    "peregrinând": "peregrina",
    "peregrinându": "peregrina",
    "peregrinară": "peregrina",
    "peregrinarăm": "peregrina",
    "peregrinarăți": "peregrina",
    "peregrinase": "peregrina",
    "peregrinasem": "peregrina",
    "peregrinaseră": "peregrina",
    "peregrinaserăm": "peregrina",
    "peregrinaserăți": "peregrina",
    "peregrinaseși": "peregrina",
    "peregrinași": "peregrina",
    "peregrinat": "peregrina",
    "peregrinați": "peregrina",
    "peregrinau": "peregrina",
    "peregrinează": "peregrina",
    "peregrinez": "peregrina",
    "peregrineze": "peregrina",
    "peregrinezi": "peregrina",
    "peregrinarea": "peregrinare",
    "peregrinări": "peregrinare",
    "peregrinării": "peregrinare",
    "peregrinările": "peregrinare",
    "peregrinărilor": "peregrinare",
    "peregrinată": "peregrinat",
    "peregrinate": "peregrinat",
    "peregrinați": "peregrinat",
    "perempțiunea": "perempțiune",
    "perempțiuni": "perempțiune",
    "perempțiunii": "perempțiune",
    "perempțiunile": "perempțiune",
    "perempțiunilor": "perempțiune",
    "perena": "peren",
    "perenă": "peren",
    "perene": "peren",
    "perenei": "peren",
    "perenele": "peren",
    "perenelor": "peren",
    "pereni": "peren",
    "perenii": "peren",
    "perenilor": "peren",
    "perenul": "peren",
    "perenului": "peren",
    "perenitatea": "perenitate",
    "perenități": "perenitate",
    "perenității": "perenitate",
    "peretele": "perete",
    "peretelui": "perete",
    "pereți": "perete",
    "pereții": "perete",
    "pereților": "perete",
    "pereul": "pereu",
    "pereului": "pereu",
    "pereuri": "pereu",
    "pereurile": "pereu",
    "pereurilor": "pereu",
    "perfecta": "perfect",
    "perfectă": "perfect",
    "perfecte": "perfect",
    "perfectei": "perfect",
    "perfectele": "perfect",
    "perfectelor": "perfect",
    "perfecți": "perfect",
    "perfecții": "perfect",
    "perfecților": "perfect",
    "perfectul": "perfect",
    "perfectului": "perfect",
    "perf.c.": "perfect_compus",
    "perf.s.": "perfect_simplu",
    "nemaiperfectând": "perfecta",
    "nemaiperfectându": "perfecta",
    "neperfectând": "perfecta",
    "neperfectându": "perfecta",
    "perfectă": "perfecta",
    "perfectai": "perfecta",
    "perfectam": "perfecta",
    "perfectăm": "perfecta",
    "perfectând": "perfecta",
    "perfectându": "perfecta",
    "perfectară": "perfecta",
    "perfectarăm": "perfecta",
    "perfectarăți": "perfecta",
    "perfectase": "perfecta",
    "perfectasem": "perfecta",
    "perfectaseră": "perfecta",
    "perfectaserăm": "perfecta",
    "perfectaserăți": "perfecta",
    "perfectaseși": "perfecta",
    "perfectași": "perfecta",
    "perfectat": "perfecta",
    "perfectați": "perfecta",
    "perfectau": "perfecta",
    "perfectează": "perfecta",
    "perfectez": "perfecta",
    "perfecteze": "perfecta",
    "perfectezi": "perfecta",
    "perfectarea": "perfectare",
    "perfectări": "perfectare",
    "perfectării": "perfectare",
    "perfectările": "perfectare",
    "perfectărilor": "perfectare",
    "perfectată": "perfectat",
    "perfectate": "perfectat",
    "perfectați": "perfectat",
    "perfectibila": "perfectibil",
    "perfectibilă": "perfectibil",
    "perfectibile": "perfectibil",
    "perfectibilei": "perfectibil",
    "perfectibilele": "perfectibil",
    "perfectibilelor": "perfectibil",
    "perfectibili": "perfectibil",
    "perfectibilii": "perfectibil",
    "perfectibililor": "perfectibil",
    "perfectibilul": "perfectibil",
    "perfectibilului": "perfectibil",
    "perfectibilitatea": "perfectibilitate",
    "perfectibilități": "perfectibilitate",
    "perfectibilității": "perfectibilitate",
    "perfecția": "perfecție",
    "perfecției": "perfecție",
    "perfecții": "perfecție",
    "nemaiperfecționând": "perfecționa",
    "nemaiperfecționându": "perfecționa",
    "neperfecționând": "perfecționa",
    "neperfecționându": "perfecționa",
    "perfecționă": "perfecționa",
    "perfecționai": "perfecționa",
    "perfecționam": "perfecționa",
    "perfecționăm": "perfecționa",
    "perfecționând": "perfecționa",
    "perfecționându": "perfecționa",
    "perfecționară": "perfecționa",
    "perfecționarăm": "perfecționa",
    "perfecționarăți": "perfecționa",
    "perfecționase": "perfecționa",
    "perfecționasem": "perfecționa",
    "perfecționaseră": "perfecționa",
    "perfecționaserăm": "perfecționa",
    "perfecționaserăți": "perfecționa",
    "perfecționaseși": "perfecționa",
    "perfecționași": "perfecționa",
    "perfecționat": "perfecționa",
    "perfecționați": "perfecționa",
    "perfecționau": "perfecționa",
    "perfecționează": "perfecționa",
    "perfecționez": "perfecționa",
    "perfecționeze": "perfecționa",
    "perfecționezi": "perfecționa",
    "perfecționarea": "perfecționare",
    "perfecționări": "perfecționare",
    "perfecționării": "perfecționare",
    "perfecționările": "perfecționare",
    "perfecționărilor": "perfecționare",
    "perfecționată": "perfecționat",
    "perfecționate": "perfecționat",
    "perfecționați": "perfecționat",
    "perfecțiunea": "perfecțiune",
    "perfecțiuni": "perfecțiune",
    "perfecțiunii": "perfecțiune",
    "perfida": "perfid",
    "perfidă": "perfid",
    "perfide": "perfid",
    "perfidei": "perfid",
    "perfidele": "perfid",
    "perfidelor": "perfid",
    "perfidul": "perfid",
    "perfidului": "perfid",
    "perfizi": "perfid",
    "perfizii": "perfid",
    "perfizilor": "perfid",
    "perfidia": "perfidie",
    "perfidiei": "perfidie",
    "perfidii": "perfidie",
    "perfidiile": "perfidie",
    "perfidiilor": "perfidie",
    "nemaiperforând": "perfora",
    "nemaiperforându": "perfora",
    "neperforând": "perfora",
    "neperforându": "perfora",
    "perforă": "perfora",
    "perforai": "perfora",
    "perforam": "perfora",
    "perforăm": "perfora",
    "perforând": "perfora",
    "perforându": "perfora",
    "perforară": "perfora",
    "perforarăm": "perfora",
    "perforarăți": "perfora",
    "perforase": "perfora",
    "perforasem": "perfora",
    "perforaseră": "perfora",
    "perforaserăm": "perfora",
    "perforaserăți": "perfora",
    "perforaseși": "perfora",
    "perforași": "perfora",
    "perforat": "perfora",
    "perforați": "perfora",
    "perforau": "perfora",
    "perforează": "perfora",
    "perforez": "perfora",
    "perforeze": "perfora",
    "perforezi": "perfora",
    "perforaje": "perforaj",
    "perforajele": "perforaj",
    "perforajelor": "perforaj",
    "perforajul": "perforaj",
    "perforajului": "perforaj",
    "perforanta": "perforant",
    "perforantă": "perforant",
    "perforante": "perforant",
    "perforantei": "perforant",
    "perforantele": "perforant",
    "perforantelor": "perforant",
    "perforanți": "perforant",
    "perforanții": "perforant",
    "perforanților": "perforant",
    "perforantul": "perforant",
    "perforantului": "perforant",
    "perforarea": "perforare",
    "perforări": "perforare",
    "perforării": "perforare",
    "perforările": "perforare",
    "perforărilor": "perforare",
    "perforata": "perforat",
    "perforată": "perforat",
    "perforate": "perforat",
    "perforatei": "perforat",
    "perforatele": "perforat",
    "perforatelor": "perforat",
    "perforați": "perforat",
    "perforații": "perforat",
    "perforaților": "perforat",
    "perforatul": "perforat",
    "perforatului": "perforat",
    "perforația": "perforație",
    "perforației": "perforație",
    "perforații": "perforație",
    "perforațiile": "perforație",
    "perforațiilor": "perforație",
    "perforatoare": "perforator",
    "perforatoarele": "perforator",
    "perforatoarelor": "perforator",
    "perforatorul": "perforator",
    "perforatorului": "perforator",
    "performanta": "performant",
    "performantă": "performant",
    "performante": "performant",
    "performantei": "performant",
    "performantele": "performant",
    "performantelor": "performant",
    "performanți": "performant",
    "performanții": "performant",
    "performanților": "performant",
    "performantul": "performant",
    "performantului": "performant",
    "performanța": "performanță",
    "performanțe": "performanță",
    "performanței": "performanță",
    "performanțele": "performanță",
    "performanțelor": "performanță",
    "perfuzia": "perfuzie",
    "perfuziei": "perfuzie",
    "perfuzii": "perfuzie",
    "perfuziile": "perfuzie",
    "perfuziilor": "perfuzie",
    "pergamente": "pergament",
    "pergamentele": "pergament",
    "pergamentelor": "pergament",
    "pergamentul": "pergament",
    "pergamentului": "pergament",
    "pergamentoasa": "pergamentos",
    "pergamentoasă": "pergamentos",
    "pergamentoase": "pergamentos",
    "pergamentoasei": "pergamentos",
    "pergamentoasele": "pergamentos",
    "pergamentoaselor": "pergamentos",
    "pergamentoși": "pergamentos",
    "pergamentoșii": "pergamentos",
    "pergamentoșilor": "pergamentos",
    "pergamentosul": "pergamentos",
    "pergamentosului": "pergamentos",
    "pergola": "pergolă",
    "pergole": "pergolă",
    "pergolei": "pergolă",
    "pergolele": "pergolă",
    "pergolelor": "pergolă",
    "perhidrolul": "perhidrol",
    "perhidrolului": "perhidrol",
    "nemaiperiind": "peria",
    "nemaiperiindu": "peria",
    "neperiind": "peria",
    "neperiindu": "peria",
    "periai": "peria",
    "periam": "peria",
    "periară": "peria",
    "periarăm": "peria",
    "periarăți": "peria",
    "periase": "peria",
    "periasem": "peria",
    "periaseră": "peria",
    "periaserăm": "peria",
    "periaserăți": "peria",
    "periaseși": "peria",
    "periași": "peria",
    "periat": "peria",
    "periați": "peria",
    "periau": "peria",
    "perie": "peria",
    "periem": "peria",
    "perii": "peria",
    "periind": "peria",
    "periindu": "peria",
    "periata": "periat",
    "periată": "periat",
    "periate": "periat",
    "periatei": "periat",
    "periatele": "periat",
    "periatelor": "periat",
    "periați": "periat",
    "periații": "periat",
    "periaților": "periat",
    "periatul": "periat",
    "periatului": "periat",
    "pericarde": "pericard",
    "pericardele": "pericard",
    "pericardelor": "pericard",
    "pericardul": "pericard",
    "pericardului": "pericard",
    "pericardita": "pericardită",
    "pericardite": "pericardită",
    "pericarditei": "pericardită",
    "pericarditele": "pericardită",
    "pericarditelor": "pericardită",
    "pericarpe": "pericarp",
    "pericarpele": "pericarp",
    "pericarpelor": "pericarp",
    "pericarpul": "pericarp",
    "pericarpului": "pericarp",
    "periclazul": "periclaz",
    "periclazului": "periclaz",
    "nemaipericlitând": "periclita",
    "nemaipericlitându": "periclita",
    "nepericlitând": "periclita",
    "nepericlitându": "periclita",
    "periclită": "periclita",
    "periclitai": "periclita",
    "periclitam": "periclita",
    "periclităm": "periclita",
    "periclitând": "periclita",
    "periclitându": "periclita",
    "periclitară": "periclita",
    "periclitarăm": "periclita",
    "periclitarăți": "periclita",
    "periclitase": "periclita",
    "periclitasem": "periclita",
    "periclitaseră": "periclita",
    "periclitaserăm": "periclita",
    "periclitaserăți": "periclita",
    "periclitaseși": "periclita",
    "periclitași": "periclita",
    "periclitat": "periclita",
    "periclitați": "periclita",
    "periclitau": "periclita",
    "periclitează": "periclita",
    "periclitez": "periclita",
    "pericliteze": "periclita",
    "periclitezi": "periclita",
    "periclitată": "periclitat",
    "periclitate": "periclitat",
    "periclitați": "periclitat",
    "pericole": "pericol",
    "pericolele": "pericol",
    "pericolelor": "pericol",
    "pericolul": "pericol",
    "pericolului": "pericol",
    "pericopa": "pericopă",
    "pericope": "pericopă",
    "pericopei": "pericopă",
    "pericopele": "pericopă",
    "pericopelor": "pericopă",
    "periculoasa": "periculos",
    "periculoasă": "periculos",
    "periculoase": "periculos",
    "periculoasei": "periculos",
    "periculoasele": "periculos",
    "periculoaselor": "periculos",
    "periculoși": "periculos",
    "periculoșii": "periculos",
    "periculoșilor": "periculos",
    "periculosul": "periculos",
    "periculosului": "periculos",
    "peridromul": "peridrom",
    "peridromului": "peridrom",
    "peridromuri": "peridrom",
    "peridromurile": "peridrom",
    "peridromurilor": "peridrom",
    "peria": "perie",
    "periei": "perie",
    "perii": "perie",
    "periile": "perie",
    "periilor": "perie",
    "perieci": "periec",
    "periecii": "periec",
    "periecilor": "periec",
    "periecul": "periec",
    "periecului": "periec",
    "perierea": "periere",
    "perieri": "periere",
    "perierii": "periere",
    "perierile": "periere",
    "perierilor": "periere",
    "periferica": "periferic",
    "periferică": "periferic",
    "periferice": "periferic",
    "perifericei": "periferic",
    "perifericele": "periferic",
    "perifericelor": "periferic",
    "periferici": "periferic",
    "perifericii": "periferic",
    "perifericilor": "periferic",
    "perifericul": "periferic",
    "perifericului": "periferic",
    "periferia": "periferie",
    "periferiei": "periferie",
    "periferii": "periferie",
    "periferiile": "periferie",
    "periferiilor": "periferie",
    "perifraza": "perifrază",
    "perifraze": "perifrază",
    "perifrazei": "perifrază",
    "perifrazele": "perifrază",
    "perifrazelor": "perifrază",
    "nemaiperimând": "perima",
    "nemaiperimându": "perima",
    "neperimând": "perima",
    "neperimându": "perima",
    "perimă": "perima",
    "perimând": "perima",
    "perimându": "perima",
    "perimară": "perima",
    "perimase": "perima",
    "perimaseră": "perima",
    "perimat": "perima",
    "perimau": "perima",
    "perimează": "perima",
    "perimeze": "perima",
    "perimarea": "perimare",
    "perimări": "perimare",
    "perimării": "perimare",
    "perimările": "perimare",
    "perimărilor": "perimare",
    "perimata": "perimat",
    "perimată": "perimat",
    "perimate": "perimat",
    "perimatei": "perimat",
    "perimatele": "perimat",
    "perimatelor": "perimat",
    "perimați": "perimat",
    "perimații": "perimat",
    "perimaților": "perimat",
    "perimatul": "perimat",
    "perimatului": "perimat",
    "perimete": "perimet",
    "perimetele": "perimet",
    "perimetelor": "perimet",
    "perimetul": "perimet",
    "perimetului": "perimet",
    "perimetrica": "perimetric",
    "perimetrică": "perimetric",
    "perimetrice": "perimetric",
    "perimetricei": "perimetric",
    "perimetricele": "perimetric",
    "perimetricelor": "perimetric",
    "perimetrici": "perimetric",
    "perimetricii": "perimetric",
    "perimetricilor": "perimetric",
    "perimetricul": "perimetric",
    "perimetricului": "perimetric",
    "perimetre": "perimetru",
    "perimetrele": "perimetru",
    "perimetrelor": "perimetru",
    "perimetrul": "perimetru",
    "perimetrului": "perimetru",
    "nemaiperindând": "perinda",
    "nemaiperindându": "perinda",
    "neperindând": "perinda",
    "neperindându": "perinda",
    "perind": "perinda",
    "perindă": "perinda",
    "perindai": "perinda",
    "perindam": "perinda",
    "perindăm": "perinda",
    "perindând": "perinda",
    "perindându": "perinda",
    "perindară": "perinda",
    "perindarăm": "perinda",
    "perindarăți": "perinda",
    "perindase": "perinda",
    "perindasem": "perinda",
    "perindaseră": "perinda",
    "perindaserăm": "perinda",
    "perindaserăți": "perinda",
    "perindaseși": "perinda",
    "perindași": "perinda",
    "perindat": "perinda",
    "perindați": "perinda",
    "perindau": "perinda",
    "perinde": "perinda",
    "perinzi": "perinda",
    "perindarea": "perindare",
    "perindări": "perindare",
    "perindării": "perindare",
    "perindările": "perindare",
    "perindărilor": "perindare",
    "perindată": "perindat",
    "perindate": "perindat",
    "perindați": "perindat",
    "perineul": "perineu",
    "perineului": "perineu",
    "perioada": "perioadă",
    "perioade": "perioadă",
    "perioadei": "perioadă",
    "perioadele": "perioadă",
    "perioadelor": "perioadă",
    "periodica": "periodic",
    "periodică": "periodic",
    "periodice": "periodic",
    "periodicei": "periodic",
    "periodicele": "periodic",
    "periodicelor": "periodic",
    "periodici": "periodic",
    "periodicii": "periodic",
    "periodicilor": "periodic",
    "periodicul": "periodic",
    "periodicului": "periodic",
    "periodicitatea": "periodicitate",
    "periodicități": "periodicitate",
    "periodicității": "periodicitate",
    "periodicitățile": "periodicitate",
    "periodicităților": "periodicitate",
    "nemaiperiodizând": "periodiza",
    "nemaiperiodizându": "periodiza",
    "neperiodizând": "periodiza",
    "neperiodizându": "periodiza",
    "periodiză": "periodiza",
    "periodizai": "periodiza",
    "periodizam": "periodiza",
    "periodizăm": "periodiza",
    "periodizând": "periodiza",
    "periodizându": "periodiza",
    "periodizară": "periodiza",
    "periodizarăm": "periodiza",
    "periodizarăți": "periodiza",
    "periodizase": "periodiza",
    "periodizasem": "periodiza",
    "periodizaseră": "periodiza",
    "periodizaserăm": "periodiza",
    "periodizaserăți": "periodiza",
    "periodizaseși": "periodiza",
    "periodizași": "periodiza",
    "periodizat": "periodiza",
    "periodizați": "periodiza",
    "periodizau": "periodiza",
    "periodizează": "periodiza",
    "periodizez": "periodiza",
    "periodizeze": "periodiza",
    "periodizezi": "periodiza",
    "periodizarea": "periodizare",
    "periodizări": "periodizare",
    "periodizării": "periodizare",
    "periodizările": "periodizare",
    "periodizărilor": "periodizare",
    "periodizată": "periodizat",
    "periodizate": "periodizat",
    "periodizați": "periodizat",
    "periostul": "periost",
    "periostului": "periost",
    "periostita": "periostită",
    "periostite": "periostită",
    "periostitei": "periostită",
    "periostitele": "periostită",
    "periostitelor": "periostită",
    "peripatetica": "peripatetic",
    "peripatetică": "peripatetic",
    "peripatetice": "peripatetic",
    "peripateticei": "peripatetic",
    "peripateticele": "peripatetic",
    "peripateticelor": "peripatetic",
    "peripatetici": "peripatetic",
    "peripateticii": "peripatetic",
    "peripateticilor": "peripatetic",
    "peripateticul": "peripatetic",
    "peripateticului": "peripatetic",
    "peripatetismul": "peripatetism",
    "peripatetismului": "peripatetism",
    "peripeția": "peripeție",
    "peripeției": "peripeție",
    "peripeții": "peripeție",
    "peripețiile": "peripeție",
    "peripețiilor": "peripeție",
    "periple": "periplu",
    "periplele": "periplu",
    "periplelor": "periplu",
    "periplul": "periplu",
    "periplului": "periplu",
    "perișul": "periș",
    "perișului": "periș",
    "perișuri": "periș",
    "perișurile": "periș",
    "perișurilor": "periș",
    "perisabila": "perisabil",
    "perisabilă": "perisabil",
    "perisabile": "perisabil",
    "perisabilei": "perisabil",
    "perisabilele": "perisabil",
    "perisabilelor": "perisabil",
    "perisabili": "perisabil",
    "perisabilii": "perisabil",
    "perisabililor": "perisabil",
    "perisabilul": "perisabil",
    "perisabilului": "perisabil",
    "periscoape": "periscop",
    "periscoapele": "periscop",
    "periscoapelor": "periscop",
    "periscopul": "periscop",
    "periscopului": "periscop",
    "perișoara": "perișoară",
    "perișoare": "perișoară",
    "perișoarei": "perișoară",
    "perișoarele": "perișoară",
    "perișoarelor": "perișoară",
    "peristilul": "peristil",
    "peristilului": "peristil",
    "peristiluri": "peristil",
    "peristilurile": "peristil",
    "peristilurilor": "peristil",
    "peritonee": "peritoneu",
    "peritoneele": "peritoneu",
    "peritoneelor": "peritoneu",
    "peritoneul": "peritoneu",
    "peritoneului": "peritoneu",
    "peritonita": "peritonită",
    "peritonite": "peritonită",
    "peritonitei": "peritonită",
    "peritonitele": "peritonită",
    "peritonitelor": "peritonită",
    "perla": "perlă",
    "perle": "perlă",
    "perlei": "perlă",
    "perlele": "perlă",
    "perlelor": "perlă",
    "perlata": "perlat",
    "perlată": "perlat",
    "perlate": "perlat",
    "perlatei": "perlat",
    "perlatele": "perlat",
    "perlatelor": "perlat",
    "perlați": "perlat",
    "perlații": "perlat",
    "perlaților": "perlat",
    "perlatul": "perlat",
    "perlatului": "perlat",
    "permanenta": "permanent",
    "permanentă": "permanent",
    "permanente": "permanent",
    "permanentei": "permanent",
    "permanentele": "permanent",
    "permanentelor": "permanent",
    "permanenți": "permanent",
    "permanenții": "permanent",
    "permanenților": "permanent",
    "permanentul": "permanent",
    "permanentului": "permanent",
    "permanența": "permanență",
    "permanențe": "permanență",
    "permanenței": "permanență",
    "permanențele": "permanență",
    "permanențelor": "permanență",
    "nemaipermanentizând": "permanentiza",
    "nemaipermanentizându": "permanentiza",
    "nepermanentizând": "permanentiza",
    "nepermanentizându": "permanentiza",
    "permanentiză": "permanentiza",
    "permanentizai": "permanentiza",
    "permanentizam": "permanentiza",
    "permanentizăm": "permanentiza",
    "permanentizând": "permanentiza",
    "permanentizându": "permanentiza",
    "permanentizară": "permanentiza",
    "permanentizarăm": "permanentiza",
    "permanentizarăți": "permanentiza",
    "permanentizase": "permanentiza",
    "permanentizasem": "permanentiza",
    "permanentizaseră": "permanentiza",
    "permanentizaserăm": "permanentiza",
    "permanentizaserăți": "permanentiza",
    "permanentizaseși": "permanentiza",
    "permanentizași": "permanentiza",
    "permanentizat": "permanentiza",
    "permanentizați": "permanentiza",
    "permanentizau": "permanentiza",
    "permanentizează": "permanentiza",
    "permanentizez": "permanentiza",
    "permanentizeze": "permanentiza",
    "permanentizezi": "permanentiza",
    "permanentizarea": "permanentizare",
    "permanentizări": "permanentizare",
    "permanentizării": "permanentizare",
    "permanentizările": "permanentizare",
    "permanentizărilor": "permanentizare",
    "permanentizată": "permanentizat",
    "permanentizate": "permanentizat",
    "permanentizați": "permanentizat",
    "permeabila": "permeabil",
    "permeabilă": "permeabil",
    "permeabile": "permeabil",
    "permeabilei": "permeabil",
    "permeabilele": "permeabil",
    "permeabilelor": "permeabil",
    "permeabili": "permeabil",
    "permeabilii": "permeabil",
    "permeabililor": "permeabil",
    "permeabilul": "permeabil",
    "permeabilului": "permeabil",
    "permeabilitatea": "permeabilitate",
    "permeabilități": "permeabilitate",
    "permeabilității": "permeabilitate",
    "permianul": "permian",
    "permianului": "permian",
    "permisa": "permis",
    "permisă": "permis",
    "permise": "permis",
    "permisei": "permis",
    "permisele": "permis",
    "permiselor": "permis",
    "permiși": "permis",
    "permisii": "permis",
    "permisul": "permis",
    "permisului": "permis",
    "permisia": "permisie",
    "permisiei": "permisie",
    "permisii": "permisie",
    "permisiile": "permisie",
    "permisiilor": "permisie",
    "permisiunea": "permisiune",
    "permisiuni": "permisiune",
    "permisiunii": "permisiune",
    "permisiunile": "permisiune",
    "permisiunilor": "permisiune",
    "nemaipermițând": "permite",
    "nemaipermițându": "permite",
    "nepermițând": "permite",
    "nepermițându": "permite",
    "permis": "permite",
    "permise": "permite",
    "permisei": "permite",
    "permiseră": "permite",
    "permiserăm": "permite",
    "permiserăți": "permite",
    "permisese": "permite",
    "permisesem": "permite",
    "permiseseră": "permite",
    "permiseserăm": "permite",
    "permiseserăți": "permite",
    "permiseseși": "permite",
    "permiseși": "permite",
    "permit": "permite",
    "permită": "permite",
    "permițând": "permite",
    "permițându": "permite",
    "permitea": "permite",
    "permiteai": "permite",
    "permiteam": "permite",
    "permiteați": "permite",
    "permiteau": "permite",
    "permitem": "permite",
    "permiteți": "permite",
    "permiți": "permite",
    "nemaipermutând": "permuta",
    "nemaipermutându": "permuta",
    "nepermutând": "permuta",
    "nepermutându": "permuta",
    "permut": "permuta",
    "permută": "permuta",
    "permutai": "permuta",
    "permutam": "permuta",
    "permutăm": "permuta",
    "permutând": "permuta",
    "permutându": "permuta",
    "permutară": "permuta",
    "permutarăm": "permuta",
    "permutarăți": "permuta",
    "permutase": "permuta",
    "permutasem": "permuta",
    "permutaseră": "permuta",
    "permutaserăm": "permuta",
    "permutaserăți": "permuta",
    "permutaseși": "permuta",
    "permutași": "permuta",
    "permutat": "permuta",
    "permutați": "permuta",
    "permutau": "permuta",
    "permute": "permuta",
    "permuți": "permuta",
    "permutarea": "permutare",
    "permutări": "permutare",
    "permutării": "permutare",
    "permutările": "permutare",
    "permutărilor": "permutare",
    "permutată": "permutat",
    "permutate": "permutat",
    "permutați": "permutat",
    "perna": "pernă",
    "perne": "pernă",
    "pernei": "pernă",
    "pernele": "pernă",
    "pernelor": "pernă",
    "pernicioasa": "pernicios",
    "pernicioasă": "pernicios",
    "pernicioase": "pernicios",
    "pernicioasei": "pernicios",
    "pernicioasele": "pernicios",
    "pernicioaselor": "pernicios",
    "pernicioși": "pernicios",
    "pernicioșii": "pernicios",
    "pernicioșilor": "pernicios",
    "perniciosul": "pernicios",
    "perniciosului": "pernicios",
    "pernița": "perniță",
    "pernițe": "perniță",
    "perniței": "perniță",
    "pernițele": "perniță",
    "pernițelor": "perniță",
    "pernuța": "pernuță",
    "pernuțe": "pernuță",
    "pernuței": "pernuță",
    "pernuțele": "pernuță",
    "pernuțelor": "pernuță",
    "peroane": "peron",
    "peroanele": "peron",
    "peroanelor": "peron",
    "peronul": "peron",
    "peronului": "peron",
    "peronee": "peroneu",
    "peroneele": "peroneu",
    "peroneelor": "peroneu",
    "peroneul": "peroneu",
    "peroneului": "peroneu",
    "nemaiperorând": "perora",
    "nemaiperorându": "perora",
    "neperorând": "perora",
    "neperorându": "perora",
    "peroră": "perora",
    "perorai": "perora",
    "peroram": "perora",
    "perorăm": "perora",
    "perorând": "perora",
    "perorându": "perora",
    "perorară": "perora",
    "perorarăm": "perora",
    "perorarăți": "perora",
    "perorase": "perora",
    "perorasem": "perora",
    "peroraseră": "perora",
    "peroraserăm": "perora",
    "peroraserăți": "perora",
    "peroraseși": "perora",
    "perorași": "perora",
    "perorat": "perora",
    "perorați": "perora",
    "perorau": "perora",
    "perorează": "perora",
    "perorez": "perora",
    "peroreze": "perora",
    "perorezi": "perora",
    "perorată": "perorat",
    "perorate": "perorat",
    "perorați": "perorat",
    "perorația": "perorație",
    "perorației": "perorație",
    "perorații": "perorație",
    "perorațiile": "perorație",
    "perorațiilor": "perorație",
    "peroxidul": "peroxid",
    "peroxidului": "peroxid",
    "peroxizi": "peroxid",
    "peroxizii": "peroxid",
    "peroxizilor": "peroxid",
    "perpeleala": "perpeleală",
    "perpeleli": "perpeleală",
    "perpelelii": "perpeleală",
    "perpelelile": "perpeleală",
    "perpelelilor": "perpeleală",
    "nemaiperpelind": "perpeli",
    "nemaiperpelindu": "perpeli",
    "neperpelind": "perpeli",
    "neperpelindu": "perpeli",
    "perpelea": "perpeli",
    "perpeleai": "perpeli",
    "perpeleam": "perpeli",
    "perpelească": "perpeli",
    "perpeleați": "perpeli",
    "perpeleau": "perpeli",
    "perpelesc": "perpeli",
    "perpelește": "perpeli",
    "perpelești": "perpeli",
    "perpelii": "perpeli",
    "perpelim": "perpeli",
    "perpelind": "perpeli",
    "perpelindu": "perpeli",
    "perpeliră": "perpeli",
    "perpelirăm": "perpeli",
    "perpelirăți": "perpeli",
    "perpelise": "perpeli",
    "perpelisem": "perpeli",
    "perpeliseră": "perpeli",
    "perpeliserăm": "perpeli",
    "perpeliserăți": "perpeli",
    "perpeliseși": "perpeli",
    "perpeliși": "perpeli",
    "perpelit": "perpeli",
    "perpeliți": "perpeli",
    "perpelita": "perpelit",
    "perpelită": "perpelit",
    "perpelite": "perpelit",
    "perpelitei": "perpelit",
    "perpelitele": "perpelit",
    "perpelitelor": "perpelit",
    "perpeliți": "perpelit",
    "perpeliții": "perpelit",
    "perpeliților": "perpelit",
    "perpelitul": "perpelit",
    "perpelitului": "perpelit",
    "perpendiculara": "perpendicular",
    "perpendiculară": "perpendicular",
    "perpendiculare": "perpendicular",
    "perpendicularei": "perpendicular",
    "perpendicularele": "perpendicular",
    "perpendicularelor": "perpendicular",
    "perpendiculari": "perpendicular",
    "perpendicularii": "perpendicular",
    "perpendicularilor": "perpendicular",
    "perpendicularul": "perpendicular",
    "perpendicularului": "perpendicular",
    "perpendicularitatea": "perpendicularitate",
    "perpendicularități": "perpendicularitate",
    "perpendicularității": "perpendicularitate",
    "nemaiperpetuând": "perpetua",
    "nemaiperpetuându": "perpetua",
    "neperpetuând": "perpetua",
    "neperpetuându": "perpetua",
    "perpetuă": "perpetua",
    "perpetuai": "perpetua",
    "perpetuam": "perpetua",
    "perpetuăm": "perpetua",
    "perpetuând": "perpetua",
    "perpetuându": "perpetua",
    "perpetuară": "perpetua",
    "perpetuarăm": "perpetua",
    "perpetuarăți": "perpetua",
    "perpetuase": "perpetua",
    "perpetuasem": "perpetua",
    "perpetuaseră": "perpetua",
    "perpetuaserăm": "perpetua",
    "perpetuaserăți": "perpetua",
    "perpetuaseși": "perpetua",
    "perpetuași": "perpetua",
    "perpetuat": "perpetua",
    "perpetuați": "perpetua",
    "perpetuau": "perpetua",
    "perpetuează": "perpetua",
    "perpetuez": "perpetua",
    "perpetueze": "perpetua",
    "perpetuezi": "perpetua",
    "perpetuarea": "perpetuare",
    "perpetuări": "perpetuare",
    "perpetuării": "perpetuare",
    "perpetuările": "perpetuare",
    "perpetuărilor": "perpetuare",
    "perpetuată": "perpetuat",
    "perpetuate": "perpetuat",
    "perpetuați": "perpetuat",
    "perpetua": "perpetuu",
    "perpetuă": "perpetuu",
    "perpetue": "perpetuu",
    "perpetuei": "perpetuu",
    "perpetuele": "perpetuu",
    "perpetuelor": "perpetuu",
    "perpetui": "perpetuu",
    "perpetuii": "perpetuu",
    "perpetuilor": "perpetuu",
    "perplecși": "perplex",
    "perplecșii": "perplex",
    "perplecșilor": "perplex",
    "perplexa": "perplex",
    "perplexă": "perplex",
    "perplexe": "perplex",
    "perplexei": "perplex",
    "perplexele": "perplex",
    "perplexelor": "perplex",
    "perplexul": "perplex",
    "perplexului": "perplex",
    "perplexitatea": "perplexitate",
    "perplexități": "perplexitate",
    "perplexității": "perplexitate",
    "perplexitățile": "perplexitate",
    "perplexităților": "perplexitate",
    "persana": "persan",
    "persană": "persan",
    "persane": "persan",
    "persanei": "persan",
    "persanele": "persan",
    "persanelor": "persan",
    "persani": "persan",
    "persanii": "persan",
    "persanilor": "persan",
    "persanul": "persan",
    "persanului": "persan",
    "persana": "persană",
    "persane": "persană",
    "persanei": "persană",
    "persanele": "persană",
    "persanelor": "persană",
    "nemaipersecutând": "persecuta",
    "nemaipersecutându": "persecuta",
    "nepersecutând": "persecuta",
    "nepersecutându": "persecuta",
    "persecut": "persecuta",
    "persecută": "persecuta",
    "persecutai": "persecuta",
    "persecutam": "persecuta",
    "persecutăm": "persecuta",
    "persecutând": "persecuta",
    "persecutându": "persecuta",
    "persecutară": "persecuta",
    "persecutarăm": "persecuta",
    "persecutarăți": "persecuta",
    "persecutase": "persecuta",
    "persecutasem": "persecuta",
    "persecutaseră": "persecuta",
    "persecutaserăm": "persecuta",
    "persecutaserăți": "persecuta",
    "persecutaseși": "persecuta",
    "persecutași": "persecuta",
    "persecutat": "persecuta",
    "persecutați": "persecuta",
    "persecutau": "persecuta",
    "persecute": "persecuta",
    "persecuți": "persecuta",
    "persecutarea": "persecutare",
    "persecutări": "persecutare",
    "persecutării": "persecutare",
    "persecutările": "persecutare",
    "persecutărilor": "persecutare",
    "persecutată": "persecutat",
    "persecutate": "persecutat",
    "persecutați": "persecutat",
    "persecuția": "persecuție",
    "persecuției": "persecuție",
    "persecuții": "persecuție",
    "persecuțiile": "persecuție",
    "persecuțiilor": "persecuție",
    "persecutori": "persecutor",
    "persecutorul": "persecutor",
    "persecutorului": "persecutor",
    "nemaiperseverând": "persevera",
    "nemaiperseverându": "persevera",
    "neperseverând": "persevera",
    "neperseverându": "persevera",
    "perseveră": "persevera",
    "perseverai": "persevera",
    "perseveram": "persevera",
    "perseverăm": "persevera",
    "perseverând": "persevera",
    "perseverându": "persevera",
    "perseverară": "persevera",
    "perseverarăm": "persevera",
    "perseverarăți": "persevera",
    "perseverase": "persevera",
    "perseverasem": "persevera",
    "perseveraseră": "persevera",
    "perseveraserăm": "persevera",
    "perseveraserăți": "persevera",
    "perseveraseși": "persevera",
    "perseverași": "persevera",
    "perseverat": "persevera",
    "perseverați": "persevera",
    "perseverau": "persevera",
    "perseverează": "persevera",
    "perseverez": "persevera",
    "persevereze": "persevera",
    "perseverezi": "persevera",
    "perseverată": "perseverat",
    "perseverate": "perseverat",
    "perseverați": "perseverat",
    "perseverenta": "perseverent",
    "perseverentă": "perseverent",
    "perseverente": "perseverent",
    "perseverentei": "perseverent",
    "perseverentele": "perseverent",
    "perseverentelor": "perseverent",
    "perseverenți": "perseverent",
    "perseverenții": "perseverent",
    "perseverenților": "perseverent",
    "perseverentul": "perseverent",
    "perseverentului": "perseverent",
    "perseverența": "perseverență",
    "perseverențe": "perseverență",
    "perseverenței": "perseverență",
    "Persiei": "Persia",
    "persiana": "persiană",
    "persiene": "persiană",
    "persienei": "persiană",
    "persienele": "persiană",
    "persienelor": "persiană",
    "persieneasca": "persienesc",
    "persienească": "persienesc",
    "persienescul": "persienesc",
    "persienescului": "persienesc",
    "persienești": "persienesc",
    "persieneștii": "persienesc",
    "persieneștile": "persienesc",
    "persieneștilor": "persienesc",
    "nemaipersiflând": "persifla",
    "nemaipersiflându": "persifla",
    "nepersiflând": "persifla",
    "nepersiflându": "persifla",
    "persiflă": "persifla",
    "persiflai": "persifla",
    "persiflam": "persifla",
    "persiflăm": "persifla",
    "persiflând": "persifla",
    "persiflându": "persifla",
    "persiflară": "persifla",
    "persiflarăm": "persifla",
    "persiflarăți": "persifla",
    "persiflase": "persifla",
    "persiflasem": "persifla",
    "persiflaseră": "persifla",
    "persiflaserăm": "persifla",
    "persiflaserăți": "persifla",
    "persiflaseși": "persifla",
    "persiflași": "persifla",
    "persiflat": "persifla",
    "persiflați": "persifla",
    "persiflau": "persifla",
    "persiflează": "persifla",
    "persiflez": "persifla",
    "persifleze": "persifla",
    "persiflezi": "persifla",
    "persiflarea": "persiflare",
    "persiflări": "persiflare",
    "persiflării": "persiflare",
    "persiflările": "persiflare",
    "persiflărilor": "persiflare",
    "persiflată": "persiflat",
    "persiflate": "persiflat",
    "persiflați": "persiflat",
    "persiflatoare": "persiflator",
    "persiflatoarea": "persiflator",
    "persiflatoarei": "persiflator",
    "persiflatoarele": "persiflator",
    "persiflatoarelor": "persiflator",
    "persiflatori": "persiflator",
    "persiflatorii": "persiflator",
    "persiflatorilor": "persiflator",
    "persiflatorul": "persiflator",
    "persiflatorului": "persiflator",
    "nemaipersistând": "persista",
    "nemaipersistându": "persista",
    "nepersistând": "persista",
    "nepersistându": "persista",
    "persist": "persista",
    "persistă": "persista",
    "persistai": "persista",
    "persistam": "persista",
    "persistăm": "persista",
    "persistând": "persista",
    "persistându": "persista",
    "persistară": "persista",
    "persistarăm": "persista",
    "persistarăți": "persista",
    "persistase": "persista",
    "persistasem": "persista",
    "persistaseră": "persista",
    "persistaserăm": "persista",
    "persistaserăți": "persista",
    "persistaseși": "persista",
    "persistași": "persista",
    "persistat": "persista",
    "persistați": "persista",
    "persistau": "persista",
    "persiste": "persista",
    "persiști": "persista",
    "persistată": "persistat",
    "persistate": "persistat",
    "persistați": "persistat",
    "persistenta": "persistent",
    "persistentă": "persistent",
    "persistente": "persistent",
    "persistentei": "persistent",
    "persistentele": "persistent",
    "persistentelor": "persistent",
    "persistenți": "persistent",
    "persistenții": "persistent",
    "persistenților": "persistent",
    "persistentul": "persistent",
    "persistentului": "persistent",
    "persistența": "persistență",
    "persistențe": "persistență",
    "persistenței": "persistență",
    "persoana": "persoană",
    "persoane": "persoană",
    "persoanei": "persoană",
    "persoanele": "persoană",
    "persoanelor": "persoană",
    "personaje": "personaj",
    "personajele": "personaj",
    "personajelor": "personaj",
    "personajul": "personaj",
    "personajului": "personaj",
    "personala": "personal",
    "personală": "personal",
    "personale": "personal",
    "personalei": "personal",
    "personalele": "personal",
    "personalelor": "personal",
    "personali": "personal",
    "personalii": "personal",
    "personalilor": "personal",
    "personalul": "personal",
    "personalului": "personal",
    "personalista": "personalist",
    "personalistă": "personalist",
    "personaliste": "personalist",
    "personalistei": "personalist",
    "personalistele": "personalist",
    "personalistelor": "personalist",
    "personaliști": "personalist",
    "personaliștii": "personalist",
    "personaliștilor": "personalist",
    "personalistul": "personalist",
    "personalistului": "personalist",
    "personalitatea": "personalitate",
    "personalități": "personalitate",
    "personalității": "personalitate",
    "personalitățile": "personalitate",
    "personalităților": "personalitate",
    "nemaipersonificând": "personifica",
    "nemaipersonificându": "personifica",
    "nepersonificând": "personifica",
    "nepersonificându": "personifica",
    "personific": "personifica",
    "personifică": "personifica",
    "personificai": "personifica",
    "personificam": "personifica",
    "personificăm": "personifica",
    "personificând": "personifica",
    "personificându": "personifica",
    "personificară": "personifica",
    "personificarăm": "personifica",
    "personificarăți": "personifica",
    "personificase": "personifica",
    "personificasem": "personifica",
    "personificaseră": "personifica",
    "personificaserăm": "personifica",
    "personificaserăți": "personifica",
    "personificaseși": "personifica",
    "personificași": "personifica",
    "personificat": "personifica",
    "personificați": "personifica",
    "personificau": "personifica",
    "personifice": "personifica",
    "personifici": "personifica",
    "personificarea": "personificare",
    "personificări": "personificare",
    "personificării": "personificare",
    "personificările": "personificare",
    "personificărilor": "personificare",
    "personificată": "personificat",
    "personificate": "personificat",
    "personificați": "personificat",
    "perspectiva": "perspectivă",
    "perspective": "perspectivă",
    "perspectivei": "perspectivă",
    "perspectivele": "perspectivă",
    "perspectivelor": "perspectivă",
    "perspicacitatea": "perspicacitate",
    "perspicacități": "perspicacitate",
    "perspicacității": "perspicacitate",
    "perspicacitățile": "perspicacitate",
    "perspicacităților": "perspicacitate",
    "persuasiunea": "persuasiune",
    "persuasiuni": "persuasiune",
    "persuasiunii": "persuasiune",
    "persuasiva": "persuasiv",
    "persuasivă": "persuasiv",
    "persuasive": "persuasiv",
    "persuasivei": "persuasiv",
    "persuasivele": "persuasiv",
    "persuasivelor": "persuasiv",
    "persuasivi": "persuasiv",
    "persuasivii": "persuasiv",
    "persuasivilor": "persuasiv",
    "persuasivul": "persuasiv",
    "persuasivului": "persuasiv",
    "pertinenta": "pertinent",
    "pertinentă": "pertinent",
    "pertinente": "pertinent",
    "pertinentei": "pertinent",
    "pertinentele": "pertinent",
    "pertinentelor": "pertinent",
    "pertinenți": "pertinent",
    "pertinenții": "pertinent",
    "pertinenților": "pertinent",
    "pertinentul": "pertinent",
    "pertinentului": "pertinent",
    "nemaipertractând": "pertracta",
    "nemaipertractându": "pertracta",
    "nepertractând": "pertracta",
    "nepertractându": "pertracta",
    "pertractă": "pertracta",
    "pertractai": "pertracta",
    "pertractam": "pertracta",
    "pertractăm": "pertracta",
    "pertractând": "pertracta",
    "pertractându": "pertracta",
    "pertractară": "pertracta",
    "pertractarăm": "pertracta",
    "pertractarăți": "pertracta",
    "pertractase": "pertracta",
    "pertractasem": "pertracta",
    "pertractaseră": "pertracta",
    "pertractaserăm": "pertracta",
    "pertractaserăți": "pertracta",
    "pertractaseși": "pertracta",
    "pertractași": "pertracta",
    "pertractat": "pertracta",
    "pertractați": "pertracta",
    "pertractau": "pertracta",
    "pertractează": "pertracta",
    "pertractez": "pertracta",
    "pertracteze": "pertracta",
    "pertractezi": "pertracta",
    "pertractată": "pertractat",
    "pertractate": "pertractat",
    "pertractați": "pertractat",
    "nemaiperturbând": "perturba",
    "nemaiperturbându": "perturba",
    "neperturbând": "perturba",
    "neperturbându": "perturba",
    "perturb": "perturba",
    "perturbă": "perturba",
    "perturbai": "perturba",
    "perturbam": "perturba",
    "perturbăm": "perturba",
    "perturbând": "perturba",
    "perturbându": "perturba",
    "perturbară": "perturba",
    "perturbarăm": "perturba",
    "perturbarăți": "perturba",
    "perturbase": "perturba",
    "perturbasem": "perturba",
    "perturbaseră": "perturba",
    "perturbaserăm": "perturba",
    "perturbaserăți": "perturba",
    "perturbaseși": "perturba",
    "perturbași": "perturba",
    "perturbat": "perturba",
    "perturbați": "perturba",
    "perturbau": "perturba",
    "perturbe": "perturba",
    "perturbi": "perturba",
    "perturbarea": "perturbare",
    "perturbări": "perturbare",
    "perturbării": "perturbare",
    "perturbările": "perturbare",
    "perturbărilor": "perturbare",
    "perturbată": "perturbat",
    "perturbate": "perturbat",
    "perturbați": "perturbat",
    "perturbația": "perturbație",
    "perturbației": "perturbație",
    "perturbații": "perturbație",
    "perturbațiile": "perturbație",
    "perturbațiilor": "perturbație",
    "perturbativa": "perturbativ",
    "perturbativă": "perturbativ",
    "perturbative": "perturbativ",
    "perturbativei": "perturbativ",
    "perturbativele": "perturbativ",
    "perturbativelor": "perturbativ",
    "perturbativi": "perturbativ",
    "perturbativii": "perturbativ",
    "perturbativilor": "perturbativ",
    "perturbativul": "perturbativ",
    "perturbativului": "perturbativ",
    "perturbatoare": "perturbator",
    "perturbatoarea": "perturbator",
    "perturbatoarei": "perturbator",
    "perturbatoarele": "perturbator",
    "perturbatoarelor": "perturbator",
    "perturbatori": "perturbator",
    "perturbatorii": "perturbator",
    "perturbatorilor": "perturbator",
    "perturbatorul": "perturbator",
    "perturbatorului": "perturbator",
    "peruana": "peruan",
    "peruană": "peruan",
    "peruane": "peruan",
    "peruanei": "peruan",
    "peruanele": "peruan",
    "peruanelor": "peruan",
    "peruani": "peruan",
    "peruanii": "peruan",
    "peruanilor": "peruan",
    "peruanul": "peruan",
    "peruanului": "peruan",
    "peruca": "perucă",
    "peruci": "perucă",
    "perucii": "perucă",
    "perucile": "perucă",
    "perucilor": "perucă",
    "peruchieri": "peruchier",
    "peruchierii": "peruchier",
    "peruchierilor": "peruchier",
    "peruchierul": "peruchier",
    "peruchierului": "peruchier",
    "peruviana": "peruvian",
    "peruviană": "peruvian",
    "peruvianul": "peruvian",
    "peruvianului": "peruvian",
    "peruviene": "peruvian",
    "peruvienei": "peruvian",
    "peruvienele": "peruvian",
    "peruvienelor": "peruvian",
    "peruvieni": "peruvian",
    "peruvienii": "peruvian",
    "peruvienilor": "peruvian",
    "peruviana": "peruviană",
    "peruviene": "peruviană",
    "peruvienei": "peruviană",
    "peruvienele": "peruviană",
    "peruvienelor": "peruviană",
    "peruzeaua": "peruzea",
    "peruzele": "peruzea",
    "peruzelei": "peruzea",
    "peruzelele": "peruzea",
    "peruzelelor": "peruzea",
    "pervazul": "pervaz",
    "pervazului": "pervaz",
    "pervazuri": "pervaz",
    "pervazurile": "pervaz",
    "pervazurilor": "pervaz",
    "perversa": "pervers",
    "perversă": "pervers",
    "perverse": "pervers",
    "perversei": "pervers",
    "perversele": "pervers",
    "perverselor": "pervers",
    "perverși": "pervers",
    "perverșii": "pervers",
    "perverșilor": "pervers",
    "perversul": "pervers",
    "perversului": "pervers",
    "perversitatea": "perversitate",
    "perversități": "perversitate",
    "perversității": "perversitate",
    "perversitățile": "perversitate",
    "perversităților": "perversitate",
    "perversiunea": "perversiune",
    "perversiuni": "perversiune",
    "perversiunii": "perversiune",
    "perversiunile": "perversiune",
    "perversiunilor": "perversiune",
    "nemaipervertind": "perverti",
    "nemaipervertindu": "perverti",
    "nepervertind": "perverti",
    "nepervertindu": "perverti",
    "pervertea": "perverti",
    "perverteai": "perverti",
    "perverteam": "perverti",
    "pervertească": "perverti",
    "perverteați": "perverti",
    "perverteau": "perverti",
    "pervertesc": "perverti",
    "pervertește": "perverti",
    "pervertești": "perverti",
    "pervertii": "perverti",
    "pervertim": "perverti",
    "pervertind": "perverti",
    "pervertindu": "perverti",
    "pervertiră": "perverti",
    "pervertirăm": "perverti",
    "pervertirăți": "perverti",
    "pervertise": "perverti",
    "pervertisem": "perverti",
    "pervertiseră": "perverti",
    "pervertiserăm": "perverti",
    "pervertiserăți": "perverti",
    "pervertiseși": "perverti",
    "pervertiși": "perverti",
    "pervertit": "perverti",
    "pervertiți": "perverti",
    "pervertită": "pervertit",
    "pervertite": "pervertit",
    "pervertiți": "pervertit",
    "pescaje": "pescaj",
    "pescajele": "pescaj",
    "pescajelor": "pescaj",
    "pescajul": "pescaj",
    "pescajului": "pescaj",
    "pescari": "pescar",
    "pescarii": "pescar",
    "pescarilor": "pescar",
    "pescarul": "pescar",
    "pescarului": "pescar",
    "pescăreasca": "pescăresc",
    "pescărească": "pescăresc",
    "pescărescul": "pescăresc",
    "pescărescului": "pescăresc",
    "pescărești": "pescăresc",
    "pescăreștii": "pescăresc",
    "pescăreștile": "pescăresc",
    "pescăreștilor": "pescăresc",
    "pescăritul": "pescărit",
    "pescăritului": "pescărit",
    "pescăruși": "pescăruș",
    "pescărușii": "pescăruș",
    "pescărușilor": "pescăruș",
    "pescărușul": "pescăruș",
    "pescărușului": "pescăruș",
    "peșcheșul": "peșcheș",
    "peșcheșului": "peșcheș",
    "peșcheșuri": "peșcheș",
    "peșcheșurile": "peșcheș",
    "peșcheșurilor": "peșcheș",
    "nemaipescuind": "pescui",
    "nemaipescuindu": "pescui",
    "nepescuind": "pescui",
    "nepescuindu": "pescui",
    "pescuia": "pescui",
    "pescuiai": "pescui",
    "pescuiam": "pescui",
    "pescuiască": "pescui",
    "pescuiați": "pescui",
    "pescuiau": "pescui",
    "pescuiesc": "pescui",
    "pescuiește": "pescui",
    "pescuiești": "pescui",
    "pescuii": "pescui",
    "pescuim": "pescui",
    "pescuind": "pescui",
    "pescuindu": "pescui",
    "pescuiră": "pescui",
    "pescuirăm": "pescui",
    "pescuirăți": "pescui",
    "pescuise": "pescui",
    "pescuisem": "pescui",
    "pescuiseră": "pescui",
    "pescuiserăm": "pescui",
    "pescuiserăți": "pescui",
    "pescuiseși": "pescui",
    "pescuiși": "pescui",
    "pescuit": "pescui",
    "pescuiți": "pescui",
    "pescuită": "pescuit",
    "pescuite": "pescuit",
    "pescuiți": "pescuit",
    "pescuitul": "pescuit",
    "pescuitului": "pescuit",
    "pesimismul": "pesimism",
    "pesimismului": "pesimism",
    "pesimista": "pesimist",
    "pesimistă": "pesimist",
    "pesimiste": "pesimist",
    "pesimistei": "pesimist",
    "pesimistele": "pesimist",
    "pesimistelor": "pesimist",
    "pesimiști": "pesimist",
    "pesimiștii": "pesimist",
    "pesimiștilor": "pesimist",
    "pesimistul": "pesimist",
    "pesimistului": "pesimist",
    "pesimista": "pesimistă",
    "pesimiste": "pesimistă",
    "pesimistei": "pesimistă",
    "pesimistele": "pesimistă",
    "pesimistelor": "pesimistă",
    "pesmeți": "pesmet",
    "pesmeții": "pesmet",
    "pesmeților": "pesmet",
    "pesmetul": "pesmet",
    "pesmetului": "pesmet",
    "pesta": "pestă",
    "peste": "pestă",
    "pestei": "pestă",
    "pestele": "pestă",
    "pestelor": "pestă",
    "peștele": "pește",
    "peștelui": "pește",
    "pești": "pește",
    "peștii": "pește",
    "peștilor": "pește",
    "peștera": "peșteră",
    "peșteri": "peșteră",
    "peșterii": "peșteră",
    "peșterile": "peșteră",
    "peșterilor": "peșteră",
    "pestifera": "pestifer",
    "pestiferă": "pestifer",
    "pestifere": "pestifer",
    "pestiferei": "pestifer",
    "pestiferele": "pestifer",
    "pestiferelor": "pestifer",
    "pestiferi": "pestifer",
    "pestiferii": "pestifer",
    "pestiferilor": "pestifer",
    "pestiferul": "pestifer",
    "pestiferului": "pestifer",
    "pestiferata": "pestiferat",
    "pestiferată": "pestiferat",
    "pestiferate": "pestiferat",
    "pestiferatei": "pestiferat",
    "pestiferatele": "pestiferat",
    "pestiferatelor": "pestiferat",
    "pestiferați": "pestiferat",
    "pestiferații": "pestiferat",
    "pestiferaților": "pestiferat",
    "pestiferatul": "pestiferat",
    "pestiferatului": "pestiferat",
    "pestilenta": "pestilent",
    "pestilentă": "pestilent",
    "pestilente": "pestilent",
    "pestilentei": "pestilent",
    "pestilentele": "pestilent",
    "pestilentelor": "pestilent",
    "pestilenți": "pestilent",
    "pestilenții": "pestilent",
    "pestilenților": "pestilent",
    "pestilentul": "pestilent",
    "pestilentului": "pestilent",
    "pestilențiala": "pestilențial",
    "pestilențială": "pestilențial",
    "pestilențiale": "pestilențial",
    "pestilențialei": "pestilențial",
    "pestilențialele": "pestilențial",
    "pestilențialelor": "pestilențial",
    "pestilențiali": "pestilențial",
    "pestilențialii": "pestilențial",
    "pestilențialilor": "pestilențial",
    "pestilențialul": "pestilențial",
    "pestilențialului": "pestilențial",
    "peștișori": "peștișor",
    "peștișorii": "peștișor",
    "peștișorilor": "peștișor",
    "peștișorul": "peștișor",
    "peștișorului": "peștișor",
    "pestoasa": "pestos",
    "pestoasă": "pestos",
    "pestoase": "pestos",
    "pestoasei": "pestos",
    "pestoasele": "pestos",
    "pestoaselor": "pestos",
    "pestoși": "pestos",
    "pestoșii": "pestos",
    "pestoșilor": "pestos",
    "pestosul": "pestos",
    "pestosului": "pestos",
    "pestrița": "pestriț",
    "pestriță": "pestriț",
    "pestrițe": "pestriț",
    "pestriței": "pestriț",
    "pestrițele": "pestriț",
    "pestrițelor": "pestriț",
    "pestriți": "pestriț",
    "pestriții": "pestriț",
    "pestriților": "pestriț",
    "pestrițul": "pestriț",
    "pestrițului": "pestriț",
    "petala": "petală",
    "petale": "petală",
    "petalei": "petală",
    "petalele": "petală",
    "petalelor": "petală",
    "petaloida": "petaloid",
    "petaloidă": "petaloid",
    "petaloide": "petaloid",
    "petaloidei": "petaloid",
    "petaloidele": "petaloid",
    "petaloidelor": "petaloid",
    "petaloidul": "petaloid",
    "petaloidului": "petaloid",
    "petaloizi": "petaloid",
    "petaloizii": "petaloid",
    "petaloizilor": "petaloid",
    "petarda": "petardă",
    "petarde": "petardă",
    "petardei": "petardă",
    "petardele": "petardă",
    "petardelor": "petardă",
    "petece": "petec",
    "petecele": "petec",
    "petecelor": "petec",
    "petecul": "petec",
    "petecului": "petec",
    "nemaipețind": "peți",
    "nemaipețindu": "peți",
    "nepețind": "peți",
    "nepețindu": "peți",
    "pețea": "peți",
    "pețeai": "peți",
    "pețeam": "peți",
    "pețească": "peți",
    "pețeați": "peți",
    "pețeau": "peți",
    "pețesc": "peți",
    "pețește": "peți",
    "pețești": "peți",
    "peții": "peți",
    "pețim": "peți",
    "pețind": "peți",
    "pețindu": "peți",
    "pețiră": "peți",
    "pețirăm": "peți",
    "pețirăți": "peți",
    "pețise": "peți",
    "pețisem": "peți",
    "pețiseră": "peți",
    "pețiserăm": "peți",
    "pețiserăți": "peți",
    "pețiseși": "peți",
    "pețiși": "peți",
    "pețit": "peți",
    "pețiți": "peți",
    "petice": "petic",
    "peticele": "petic",
    "peticelor": "petic",
    "peticul": "petic",
    "peticului": "petic",
    "peticari": "peticar",
    "peticarii": "peticar",
    "peticarilor": "peticar",
    "peticarul": "peticar",
    "peticarului": "peticar",
    "nemaipeticind": "petici",
    "nemaipeticindu": "petici",
    "nepeticind": "petici",
    "nepeticindu": "petici",
    "peticea": "petici",
    "peticeai": "petici",
    "peticeam": "petici",
    "peticească": "petici",
    "peticeați": "petici",
    "peticeau": "petici",
    "peticesc": "petici",
    "peticește": "petici",
    "peticești": "petici",
    "peticii": "petici",
    "peticim": "petici",
    "peticind": "petici",
    "peticindu": "petici",
    "peticiră": "petici",
    "peticirăm": "petici",
    "peticirăți": "petici",
    "peticise": "petici",
    "peticisem": "petici",
    "peticiseră": "petici",
    "peticiserăm": "petici",
    "peticiserăți": "petici",
    "peticiseși": "petici",
    "peticiși": "petici",
    "peticit": "petici",
    "peticiți": "petici",
    "peticită": "peticit",
    "peticite": "peticit",
    "peticiți": "peticit",
    "peticoasa": "peticos",
    "peticoasă": "peticos",
    "peticoase": "peticos",
    "peticoasei": "peticos",
    "peticoasele": "peticos",
    "peticoaselor": "peticos",
    "peticoși": "peticos",
    "peticoșii": "peticos",
    "peticoșilor": "peticos",
    "peticosul": "peticos",
    "peticosului": "peticos",
    "pețiolul": "pețiol",
    "pețiolului": "pețiol",
    "pețioluri": "pețiol",
    "pețiolurile": "pețiol",
    "pețiolurilor": "pețiol",
    "pețiolata": "pețiolat",
    "pețiolată": "pețiolat",
    "pețiolate": "pețiolat",
    "pețiolatei": "pețiolat",
    "pețiolatele": "pețiolat",
    "pețiolatelor": "pețiolat",
    "pețiolați": "pețiolat",
    "pețiolații": "pețiolat",
    "pețiolaților": "pețiolat",
    "pețiolatul": "pețiolat",
    "pețiolatului": "pețiolat",
    "pețirea": "pețire",
    "pețiri": "pețire",
    "pețirii": "pețire",
    "pețirile": "pețire",
    "pețirilor": "pețire",
    "pețită": "pețit",
    "pețite": "pețit",
    "pețiți": "pețit",
    "pețitul": "pețit",
    "pețitului": "pețit",
    "petiția": "petiție",
    "petiției": "petiție",
    "petiții": "petiție",
    "petițiile": "petiție",
    "petițiilor": "petiție",
    "petiționari": "petiționar",
    "petiționarii": "petiționar",
    "petiționarilor": "petiționar",
    "petiționarul": "petiționar",
    "petiționarului": "petiționar",
    "petiționara": "petiționară",
    "petiționare": "petiționară",
    "petiționarei": "petiționară",
    "petiționarele": "petiționară",
    "petiționarelor": "petiționară",
    "petitoria": "petitoriu",
    "petitorie": "petitoriu",
    "petitoriei": "petitoriu",
    "petitorii": "petitoriu",
    "petitoriii": "petitoriu",
    "petitoriile": "petitoriu",
    "petitoriilor": "petitoriu",
    "petitoriul": "petitoriu",
    "petitoriului": "petitoriu",
    "petlița": "petliță",
    "petlițe": "petliță",
    "petliței": "petliță",
    "petlițele": "petliță",
    "petlițelor": "petliță",
    "P.": "Petre",
    "petrecania": "petrecanie",
    "petrecaniei": "petrecanie",
    "petrecanii": "petrecanie",
    "petrecaniile": "petrecanie",
    "petrecaniilor": "petrecanie",
    "petrecăreața": "petrecăreț",
    "petrecăreață": "petrecăreț",
    "petrecărețe": "petrecăreț",
    "petrecăreței": "petrecăreț",
    "petrecărețele": "petrecăreț",
    "petrecărețelor": "petrecăreț",
    "petrecăreți": "petrecăreț",
    "petrecăreții": "petrecăreț",
    "petrecăreților": "petrecăreț",
    "petrecărețul": "petrecăreț",
    "petrecărețului": "petrecăreț",
    "petrecătoare": "petrecător",
    "petrecătoarea": "petrecător",
    "petrecătoarei": "petrecător",
    "petrecătoarele": "petrecător",
    "petrecătoarelor": "petrecător",
    "petrecători": "petrecător",
    "petrecătorii": "petrecător",
    "petrecătorilor": "petrecător",
    "petrecătorul": "petrecător",
    "petrecătorului": "petrecător",
    "nemaipetrecând": "petrece",
    "nemaipetrecându": "petrece",
    "nepetrecând": "petrece",
    "nepetrecându": "petrece",
    "petreacă": "petrece",
    "petrec": "petrece",
    "petrecând": "petrece",
    "petrecându": "petrece",
    "petrecea": "petrece",
    "petreceai": "petrece",
    "petreceam": "petrece",
    "petreceați": "petrece",
    "petreceau": "petrece",
    "petrecem": "petrece",
    "petreceți": "petrece",
    "petreci": "petrece",
    "petrecu": "petrece",
    "petrecui": "petrece",
    "petrecură": "petrece",
    "petrecurăm": "petrece",
    "petrecurăți": "petrece",
    "petrecuse": "petrece",
    "petrecusem": "petrece",
    "petrecuseră": "petrece",
    "petrecuserăm": "petrece",
    "petrecuserăți": "petrece",
    "petrecuseși": "petrece",
    "petrecuși": "petrece",
    "petrecut": "petrece",
    "petrecerea": "petrecere",
    "petreceri": "petrecere",
    "petrecerii": "petrecere",
    "petrecerile": "petrecere",
    "petrecerilor": "petrecere",
    "petrecută": "petrecut",
    "petrecute": "petrecut",
    "petrecuți": "petrecut",
    "petrificarea": "petrificare",
    "petrificări": "petrificare",
    "petrificării": "petrificare",
    "petrificările": "petrificare",
    "petrificărilor": "petrificare",
    "petrochimica": "petrochimic",
    "petrochimică": "petrochimic",
    "petrochimice": "petrochimic",
    "petrochimicei": "petrochimic",
    "petrochimicele": "petrochimic",
    "petrochimicelor": "petrochimic",
    "petrochimici": "petrochimic",
    "petrochimicii": "petrochimic",
    "petrochimicilor": "petrochimic",
    "petrochimicul": "petrochimic",
    "petrochimicului": "petrochimic",
    "petrochimia": "petrochimie",
    "petrochimiei": "petrochimie",
    "petrochimii": "petrochimie",
    "petrografica": "petrografic",
    "petrografică": "petrografic",
    "petrografice": "petrografic",
    "petrograficei": "petrografic",
    "petrograficele": "petrografic",
    "petrograficelor": "petrografic",
    "petrografici": "petrografic",
    "petrograficii": "petrografic",
    "petrograficilor": "petrografic",
    "petrograficul": "petrografic",
    "petrograficului": "petrografic",
    "petrografia": "petrografie",
    "petrografiei": "petrografie",
    "petrografii": "petrografie",
    "petrolul": "petrol",
    "petrolului": "petrol",
    "petroluri": "petrol",
    "petrolurile": "petrol",
    "petrolurilor": "petrol",
    "petroliera": "petrolier",
    "petrolieră": "petrolier",
    "petroliere": "petrolier",
    "petrolierei": "petrolier",
    "petrolierele": "petrolier",
    "petrolierelor": "petrolier",
    "petrolieri": "petrolier",
    "petrolierii": "petrolier",
    "petrolierilor": "petrolier",
    "petrolierul": "petrolier",
    "petrolierului": "petrolier",
    "petroliferă": "petrolifer",
    "petrolifere": "petrolifer",
    "petroliferi": "petrolifer",
    "P.": "Petru",
    "petulanta": "petulant",
    "petulantă": "petulant",
    "petulante": "petulant",
    "petulantei": "petulant",
    "petulantele": "petulant",
    "petulantelor": "petulant",
    "petulanți": "petulant",
    "petulanții": "petulant",
    "petulanților": "petulant",
    "petulantul": "petulant",
    "petulantului": "petulant",
    "petunia": "petunie",
    "petuniei": "petunie",
    "petunii": "petunie",
    "petuniile": "petunie",
    "petuniilor": "petunie",
    "peuneriștii": "peunerist",
    "peuneriștilor": "peunerist",
    "pezevenchea": "pezevenche",
    "pezevenchei": "pezevenche",
    "pezevenchele": "pezevenche",
    "pezevenchelor": "pezevenche",
    "pezevenchii": "pezevenchi",
    "pezevenchilor": "pezevenchi",
    "pezevenchiul": "pezevenchi",
    "pezevenchiului": "pezevenchi",
    "pfundul": "pfund",
    "pfundului": "pfund",
    "pfunduri": "pfund",
    "pfundurile": "pfund",
    "pfundurilor": "pfund",
    "pfunzi": "pfund",
    "pfunzii": "pfund",
    "pfunzilor": "pfund",
    "Philbrookul": "Philbrook",
    "Philbrookului": "Philbrook",
    "piane": "pian",
    "pianele": "pian",
    "pianelor": "pian",
    "pianul": "pian",
    "pianului": "pian",
    "pianina": "pianină",
    "pianine": "pianină",
    "pianinei": "pianină",
    "pianinele": "pianină",
    "pianinelor": "pianină",
    "pianiști": "pianist",
    "pianiștii": "pianist",
    "pianiștilor": "pianist",
    "pianistul": "pianist",
    "pianistului": "pianist",
    "pianista": "pianistă",
    "pianiste": "pianistă",
    "pianistei": "pianistă",
    "pianistele": "pianistă",
    "pianistelor": "pianistă",
    "pianistica": "pianistic",
    "pianistică": "pianistic",
    "pianistice": "pianistic",
    "pianisticei": "pianistic",
    "pianisticele": "pianistic",
    "pianisticelor": "pianistic",
    "pianistici": "pianistic",
    "pianisticii": "pianistic",
    "pianisticilor": "pianistic",
    "pianisticul": "pianistic",
    "pianisticului": "pianistic",
    "pianola": "pianolă",
    "pianole": "pianolă",
    "pianolei": "pianolă",
    "pianolele": "pianolă",
    "pianolelor": "pianolă",
    "piața": "piață",
    "piețe": "piață",
    "pieței": "piață",
    "piețele": "piață",
    "piețelor": "piață",
    "pieții": "piață",
    "piatra": "piatră",
    "pietre": "piatră",
    "pietrei": "piatră",
    "pietrele": "piatră",
    "pietrelor": "piatră",
    "piaza": "piază",
    "pieze": "piază",
    "piezei": "piază",
    "piezele": "piază",
    "piezelor": "piază",
    "picul": "pic",
    "picului": "pic",
    "picuri": "pic",
    "picurile": "pic",
    "picurilor": "pic",
    "nemaipicând": "pica",
    "nemaipicându": "pica",
    "nepicând": "pica",
    "nepicându": "pica",
    "pic": "pica",
    "pică": "pica",
    "picai": "pica",
    "picam": "pica",
    "picăm": "pica",
    "picând": "pica",
    "picându": "pica",
    "picară": "pica",
    "picarăm": "pica",
    "picarăți": "pica",
    "picase": "pica",
    "picasem": "pica",
    "picaseră": "pica",
    "picaserăm": "pica",
    "picaserăți": "pica",
    "picaseși": "pica",
    "picași": "pica",
    "picat": "pica",
    "picați": "pica",
    "picau": "pica",
    "pice": "pica",
    "pici": "pica",
    "pica": "pică",
    "picăi": "pică",
    "pici": "pică",
    "picile": "pică",
    "picilor": "pică",
    "picaje": "picaj",
    "picajele": "picaj",
    "picajelor": "picaj",
    "picajul": "picaj",
    "picajului": "picaj",
    "picanta": "picant",
    "picantă": "picant",
    "picante": "picant",
    "picantei": "picant",
    "picantele": "picant",
    "picantelor": "picant",
    "picanți": "picant",
    "picanții": "picant",
    "picanților": "picant",
    "picantul": "picant",
    "picantului": "picant",
    "picanteria": "picanterie",
    "picanteriei": "picanterie",
    "picanterii": "picanterie",
    "picanteriile": "picanterie",
    "picanteriilor": "picanterie",
    "picaresca": "picaresc",
    "picarescă": "picaresc",
    "picarescul": "picaresc",
    "picarescului": "picaresc",
    "picarești": "picaresc",
    "picareștii": "picaresc",
    "picareștile": "picaresc",
    "picareștilor": "picaresc",
    "picată": "picat",
    "picate": "picat",
    "picați": "picat",
    "picatul": "picat",
    "picatului": "picat",
    "picătura": "picătură",
    "picături": "picătură",
    "picăturii": "picătură",
    "picăturile": "picătură",
    "picăturilor": "picătură",
    "pichete": "pichet",
    "pichetele": "pichet",
    "pichetelor": "pichet",
    "pichetul": "pichet",
    "pichetului": "pichet",
    "nemaipichetând": "picheta",
    "nemaipichetându": "picheta",
    "nepichetând": "picheta",
    "nepichetându": "picheta",
    "pichetă": "picheta",
    "pichetai": "picheta",
    "pichetam": "picheta",
    "pichetăm": "picheta",
    "pichetând": "picheta",
    "pichetându": "picheta",
    "pichetară": "picheta",
    "pichetarăm": "picheta",
    "pichetarăți": "picheta",
    "pichetase": "picheta",
    "pichetasem": "picheta",
    "pichetaseră": "picheta",
    "pichetaserăm": "picheta",
    "pichetaserăți": "picheta",
    "pichetaseși": "picheta",
    "pichetași": "picheta",
    "pichetat": "picheta",
    "pichetați": "picheta",
    "pichetau": "picheta",
    "pichetează": "picheta",
    "pichetez": "picheta",
    "picheteze": "picheta",
    "pichetezi": "picheta",
    "pichetarea": "pichetare",
    "pichetări": "pichetare",
    "pichetării": "pichetare",
    "pichetările": "pichetare",
    "pichetărilor": "pichetare",
    "pichetată": "pichetat",
    "pichetate": "pichetat",
    "pichetați": "pichetat",
    "picioare": "picior",
    "picioarele": "picior",
    "picioarelor": "picior",
    "piciorul": "picior",
    "piciorului": "picior",
    "picioroange": "piciorong",
    "picioroangele": "piciorong",
    "picioroangelor": "piciorong",
    "piciorongul": "piciorong",
    "piciorongului": "piciorong",
    "piclaje": "piclaj",
    "piclajele": "piclaj",
    "piclajelor": "piclaj",
    "piclajul": "piclaj",
    "piclajului": "piclaj",
    "nemaipicnind": "picni",
    "nemaipicnindu": "picni",
    "nepicnind": "picni",
    "nepicnindu": "picni",
    "picnea": "picni",
    "picneai": "picni",
    "picneam": "picni",
    "picnească": "picni",
    "picneați": "picni",
    "picneau": "picni",
    "picnesc": "picni",
    "picnește": "picni",
    "picnești": "picni",
    "picnii": "picni",
    "picnim": "picni",
    "picnind": "picni",
    "picnindu": "picni",
    "picniră": "picni",
    "picnirăm": "picni",
    "picnirăți": "picni",
    "picnise": "picni",
    "picnisem": "picni",
    "picniseră": "picni",
    "picniserăm": "picni",
    "picniserăți": "picni",
    "picniseși": "picni",
    "picniși": "picni",
    "picnit": "picni",
    "picniți": "picni",
    "picnicul": "picnic",
    "picnicului": "picnic",
    "picnicuri": "picnic",
    "picnicurile": "picnic",
    "picnicurilor": "picnic",
    "picnită": "picnit",
    "picnite": "picnit",
    "picniți": "picnit",
    "picoli": "picol",
    "picolii": "picol",
    "picolilor": "picol",
    "picolul": "picol",
    "picolului": "picol",
    "nemaipicotind": "picoti",
    "nemaipicotindu": "picoti",
    "nepicotind": "picoti",
    "nepicotindu": "picoti",
    "picotea": "picoti",
    "picoteai": "picoti",
    "picoteam": "picoti",
    "picotească": "picoti",
    "picoteați": "picoti",
    "picoteau": "picoti",
    "picotesc": "picoti",
    "picotește": "picoti",
    "picotești": "picoti",
    "picotii": "picoti",
    "picotim": "picoti",
    "picotind": "picoti",
    "picotindu": "picoti",
    "picotiră": "picoti",
    "picotirăm": "picoti",
    "picotirăți": "picoti",
    "picotise": "picoti",
    "picotisem": "picoti",
    "picotiseră": "picoti",
    "picotiserăm": "picoti",
    "picotiserăți": "picoti",
    "picotiseși": "picoti",
    "picotiși": "picoti",
    "picotit": "picoti",
    "picotiți": "picoti",
    "picotită": "picotit",
    "picotite": "picotit",
    "picotiți": "picotit",
    "picromigdala": "picromigdală",
    "picromigdale": "picromigdală",
    "picromigdalei": "picromigdală",
    "picromigdalele": "picromigdală",
    "picromigdalelor": "picromigdală",
    "nemaipictând": "picta",
    "nemaipictându": "picta",
    "nepictând": "picta",
    "nepictându": "picta",
    "pictă": "picta",
    "pictai": "picta",
    "pictam": "picta",
    "pictăm": "picta",
    "pictând": "picta",
    "pictându": "picta",
    "pictară": "picta",
    "pictarăm": "picta",
    "pictarăți": "picta",
    "pictase": "picta",
    "pictasem": "picta",
    "pictaseră": "picta",
    "pictaserăm": "picta",
    "pictaserăți": "picta",
    "pictaseși": "picta",
    "pictași": "picta",
    "pictat": "picta",
    "pictați": "picta",
    "pictau": "picta",
    "pictează": "picta",
    "pictez": "picta",
    "picteze": "picta",
    "pictezi": "picta",
    "pictata": "pictat",
    "pictată": "pictat",
    "pictate": "pictat",
    "pictatei": "pictat",
    "pictatele": "pictat",
    "pictatelor": "pictat",
    "pictați": "pictat",
    "pictații": "pictat",
    "pictaților": "pictat",
    "pictatul": "pictat",
    "pictatului": "pictat",
    "pictografica": "pictografic",
    "pictografică": "pictografic",
    "pictografice": "pictografic",
    "pictograficei": "pictografic",
    "pictograficele": "pictografic",
    "pictograficelor": "pictografic",
    "pictografici": "pictografic",
    "pictograficii": "pictografic",
    "pictograficilor": "pictografic",
    "pictograficul": "pictografic",
    "pictograficului": "pictografic",
    "pictografia": "pictografie",
    "pictografiei": "pictografie",
    "pictografii": "pictografie",
    "pictori": "pictor",
    "pictorii": "pictor",
    "pictorilor": "pictor",
    "pictorul": "pictor",
    "pictorului": "pictor",
    "pictorița": "pictoriță",
    "pictorițe": "pictoriță",
    "pictoriței": "pictoriță",
    "pictorițele": "pictoriță",
    "pictorițelor": "pictoriță",
    "pict.": "pictură",
    "pictura": "pictură",
    "picturi": "pictură",
    "picturii": "pictură",
    "picturile": "pictură",
    "picturilor": "pictură",
    "picturala": "pictural",
    "picturală": "pictural",
    "picturale": "pictural",
    "picturalei": "pictural",
    "picturalele": "pictural",
    "picturalelor": "pictural",
    "picturali": "pictural",
    "picturalii": "pictural",
    "picturalilor": "pictural",
    "picturalul": "pictural",
    "picturalului": "pictural",
    "piculețe": "piculeț",
    "piculețele": "piculeț",
    "piculețelor": "piculeț",
    "piculețul": "piculeț",
    "piculețului": "piculeț",
    "piculina": "piculină",
    "piculine": "piculină",
    "piculinei": "piculină",
    "piculinele": "piculină",
    "piculinelor": "piculină",
    "picupul": "picup",
    "picupului": "picup",
    "picupuri": "picup",
    "picupurile": "picup",
    "picupurilor": "picup",
    "nemaipicurând": "picura",
    "nemaipicurându": "picura",
    "nepicurând": "picura",
    "nepicurându": "picura",
    "picur": "picura",
    "picură": "picura",
    "picurai": "picura",
    "picuram": "picura",
    "picurăm": "picura",
    "picurând": "picura",
    "picurându": "picura",
    "picurară": "picura",
    "picurarăm": "picura",
    "picurarăți": "picura",
    "picurase": "picura",
    "picurasem": "picura",
    "picuraseră": "picura",
    "picuraserăm": "picura",
    "picuraserăți": "picura",
    "picuraseși": "picura",
    "picurași": "picura",
    "picurat": "picura",
    "picurați": "picura",
    "picurau": "picura",
    "picure": "picura",
    "picuri": "picura",
    "picurată": "picurat",
    "picurate": "picurat",
    "picurați": "picurat",
    "picușe": "picuș",
    "picușele": "picuș",
    "picușelor": "picuș",
    "picușul": "picuș",
    "picușului": "picuș",
    "picușoare": "picușor",
    "picușoarele": "picușor",
    "picușoarelor": "picușor",
    "picușorul": "picușor",
    "picușorului": "picușor",
    "pidosnica": "pidosnic",
    "pidosnică": "pidosnic",
    "pidosnice": "pidosnic",
    "pidosnicei": "pidosnic",
    "pidosnicele": "pidosnic",
    "pidosnicelor": "pidosnic",
    "pidosnici": "pidosnic",
    "pidosnicii": "pidosnic",
    "pidosnicilor": "pidosnic",
    "pidosnicul": "pidosnic",
    "pidosnicului": "pidosnic",
    "piedestale": "piedestal",
    "piedestalele": "piedestal",
    "piedestalelor": "piedestal",
    "piedestalul": "piedestal",
    "piedestalului": "piedestal",
    "piedica": "piedică",
    "piedici": "piedică",
    "piedicii": "piedică",
    "piedicile": "piedică",
    "piedicilor": "piedică",
    "pieirea": "pieire",
    "pieiri": "pieire",
    "pieirii": "pieire",
    "piei": "piele",
    "pieii": "piele",
    "pieile": "piele",
    "pieilor": "piele",
    "pielea": "piele",
    "pieli": "piele",
    "pielii": "piele",
    "pielile": "piele",
    "pielilor": "piele",
    "pielița": "pieliță",
    "pielițe": "pieliță",
    "pieliței": "pieliță",
    "pielițele": "pieliță",
    "pielițelor": "pieliță",
    "pieloasa": "pielos",
    "pieloasă": "pielos",
    "pieloase": "pielos",
    "pieloasei": "pielos",
    "pieloasele": "pielos",
    "pieloaselor": "pielos",
    "pieloși": "pielos",
    "pieloșii": "pielos",
    "pieloșilor": "pielos",
    "pielosul": "pielos",
    "pielosului": "pielos",
    "piemontana": "piemontan",
    "piemontană": "piemontan",
    "piemontane": "piemontan",
    "piemontanei": "piemontan",
    "piemontanele": "piemontan",
    "piemontanelor": "piemontan",
    "piemontani": "piemontan",
    "piemontanii": "piemontan",
    "piemontanilor": "piemontan",
    "piemontanul": "piemontan",
    "piemontanului": "piemontan",
    "piemonteza": "piemontez",
    "piemonteză": "piemontez",
    "piemonteze": "piemontez",
    "piemontezei": "piemontez",
    "piemontezele": "piemontez",
    "piemontezelor": "piemontez",
    "piemontezi": "piemontez",
    "piemontezii": "piemontez",
    "piemontezilor": "piemontez",
    "piemontezul": "piemontez",
    "piemontezului": "piemontez",
    "piepți": "piept",
    "piepții": "piept",
    "piepților": "piept",
    "pieptul": "piept",
    "pieptului": "piept",
    "piepturi": "piept",
    "piepturile": "piept",
    "piepturilor": "piept",
    "nemaipieptănând": "pieptăna",
    "nemaipieptănându": "pieptăna",
    "nepieptănând": "pieptăna",
    "nepieptănându": "pieptăna",
    "pieptăn": "pieptăna",
    "pieptănă": "pieptăna",
    "pieptănai": "pieptăna",
    "pieptănam": "pieptăna",
    "pieptănăm": "pieptăna",
    "pieptănând": "pieptăna",
    "pieptănându": "pieptăna",
    "pieptănară": "pieptăna",
    "pieptănarăm": "pieptăna",
    "pieptănarăți": "pieptăna",
    "pieptănase": "pieptăna",
    "pieptănasem": "pieptăna",
    "pieptănaseră": "pieptăna",
    "pieptănaserăm": "pieptăna",
    "pieptănaserăți": "pieptăna",
    "pieptănaseși": "pieptăna",
    "pieptănași": "pieptăna",
    "pieptănat": "pieptăna",
    "pieptănați": "pieptăna",
    "pieptănau": "pieptăna",
    "pieptăne": "pieptăna",
    "pieptăni": "pieptăna",
    "pieptănată": "pieptănat",
    "pieptănate": "pieptănat",
    "pieptănați": "pieptănat",
    "pieptare": "pieptar",
    "pieptarele": "pieptar",
    "pieptarelor": "pieptar",
    "pieptarul": "pieptar",
    "pieptarului": "pieptar",
    "pieptenele": "pieptene",
    "pieptenelui": "pieptene",
    "piepteni": "pieptene",
    "pieptenii": "pieptene",
    "pieptenilor": "pieptene",
    "pieptișa": "pieptiș",
    "pieptișă": "pieptiș",
    "pieptișe": "pieptiș",
    "pieptișei": "pieptiș",
    "pieptișele": "pieptiș",
    "pieptișelor": "pieptiș",
    "pieptiși": "pieptiș",
    "pieptișii": "pieptiș",
    "pieptișilor": "pieptiș",
    "pieptișul": "pieptiș",
    "pieptișului": "pieptiș",
    "pieptoasa": "pieptos",
    "pieptoasă": "pieptos",
    "pieptoase": "pieptos",
    "pieptoasei": "pieptos",
    "pieptoasele": "pieptos",
    "pieptoaselor": "pieptos",
    "pieptoși": "pieptos",
    "pieptoșii": "pieptos",
    "pieptoșilor": "pieptos",
    "pieptosul": "pieptos",
    "pieptosului": "pieptos",
    "nemaipierzând": "pierde",
    "nemaipierzându": "pierde",
    "nepierzând": "pierde",
    "nepierzându": "pierde",
    "piardă": "pierde",
    "pierd": "pierde",
    "pierdea": "pierde",
    "pierdeai": "pierde",
    "pierdeam": "pierde",
    "pierdeați": "pierde",
    "pierdeau": "pierde",
    "pierdem": "pierde",
    "pierdeți": "pierde",
    "pierdu": "pierde",
    "pierdui": "pierde",
    "pierdură": "pierde",
    "pierdurăm": "pierde",
    "pierdurăți": "pierde",
    "pierduse": "pierde",
    "pierdusem": "pierde",
    "pierduseră": "pierde",
    "pierduserăm": "pierde",
    "pierduserăți": "pierde",
    "pierduseși": "pierde",
    "pierduși": "pierde",
    "pierdut": "pierde",
    "pierzând": "pierde",
    "pierzându": "pierde",
    "pierzi": "pierde",
    "pierderea": "pierdere",
    "pierderi": "pierdere",
    "pierderii": "pierdere",
    "pierderile": "pierdere",
    "pierderilor": "pierdere",
    "pierduta": "pierdut",
    "pierdută": "pierdut",
    "pierdute": "pierdut",
    "pierdutei": "pierdut",
    "pierdutele": "pierdut",
    "pierdutelor": "pierdut",
    "pierduți": "pierdut",
    "pierduții": "pierdut",
    "pierduților": "pierdut",
    "pierdutul": "pierdut",
    "nemaipierind": "pieri",
    "nemaipierindu": "pieri",
    "nepierind": "pieri",
    "nepierindu": "pieri",
    "piară": "pieri",
    "pier": "pieri",
    "piere": "pieri",
    "pierea": "pieri",
    "piereai": "pieri",
    "pieream": "pieri",
    "piereați": "pieri",
    "piereau": "pieri",
    "pierii": "pieri",
    "pierim": "pieri",
    "pierind": "pieri",
    "pierindu": "pieri",
    "pieriră": "pieri",
    "pierirăm": "pieri",
    "pierirăți": "pieri",
    "pierise": "pieri",
    "pierisem": "pieri",
    "pieriseră": "pieri",
    "pieriserăm": "pieri",
    "pieriserăți": "pieri",
    "pieriseși": "pieri",
    "pieriși": "pieri",
    "pierit": "pieri",
    "pieriți": "pieri",
    "pierirea": "pierire",
    "pieriri": "pierire",
    "pieririi": "pierire",
    "pieririle": "pierire",
    "pieririlor": "pierire",
    "pierită": "pierit",
    "pierite": "pierit",
    "pieriți": "pierit",
    "pieritoare": "pieritor",
    "pieritoarea": "pieritor",
    "pieritoarei": "pieritor",
    "pieritoarele": "pieritor",
    "pieritoarelor": "pieritor",
    "pieritori": "pieritor",
    "pieritorii": "pieritor",
    "pieritorilor": "pieritor",
    "pieritorul": "pieritor",
    "pieritorului": "pieritor",
    "piersici": "piersic",
    "piersicii": "piersic",
    "piersicilor": "piersic",
    "piersicul": "piersic",
    "piersicului": "piersic",
    "piersica": "piersică",
    "piersici": "piersică",
    "piersicii": "piersică",
    "piersicile": "piersică",
    "piersicilor": "piersică",
    "piersicia": "piersiciu",
    "piersicie": "piersiciu",
    "piersiciei": "piersiciu",
    "piersicii": "piersiciu",
    "piersiciii": "piersiciu",
    "piersiciile": "piersiciu",
    "piersiciilor": "piersiciu",
    "piersiciul": "piersiciu",
    "piersiciului": "piersiciu",
    "pierzania": "pierzanie",
    "pierzaniei": "pierzanie",
    "pierzanii": "pierzanie",
    "pierzaniile": "pierzanie",
    "pierzaniilor": "pierzanie",
    "pierzătoare": "pierzător",
    "pierzătoarea": "pierzător",
    "pierzătoarei": "pierzător",
    "pierzătoarele": "pierzător",
    "pierzătoarelor": "pierzător",
    "pierzători": "pierzător",
    "pierzătorii": "pierzător",
    "pierzătorilor": "pierzător",
    "pierzătorul": "pierzător",
    "pierzătorului": "pierzător",
    "piesa": "piesă",
    "piese": "piesă",
    "piesei": "piesă",
    "piesele": "piesă",
    "pieselor": "piesă",
    "pietatea": "pietate",
    "pietăți": "pietate",
    "pietății": "pietate",
    "pietismul": "pietism",
    "pietismului": "pietism",
    "pietista": "pietist",
    "pietistă": "pietist",
    "pietiste": "pietist",
    "pietistei": "pietist",
    "pietistele": "pietist",
    "pietistelor": "pietist",
    "pietiști": "pietist",
    "pietiștii": "pietist",
    "pietiștilor": "pietist",
    "pietistul": "pietist",
    "pietistului": "pietist",
    "pietoni": "pieton",
    "pietonii": "pieton",
    "pietonilor": "pieton",
    "pietonul": "pieton",
    "pietonului": "pieton",
    "pietoasa": "pietos",
    "pietoasă": "pietos",
    "pietoase": "pietos",
    "pietoasei": "pietos",
    "pietoasele": "pietos",
    "pietoaselor": "pietos",
    "pietoși": "pietos",
    "pietoșii": "pietos",
    "pietoșilor": "pietos",
    "pietosul": "pietos",
    "pietosului": "pietos",
    "pietreana": "pietrean",
    "pietreană": "pietrean",
    "pietreanul": "pietrean",
    "pietreanului": "pietrean",
    "pietrene": "pietrean",
    "pietrenei": "pietrean",
    "pietrenele": "pietrean",
    "pietrenelor": "pietrean",
    "pietreni": "pietrean",
    "pietrenii": "pietrean",
    "pietrenilor": "pietrean",
    "pietriceaua": "pietricea",
    "pietricele": "pietricică",
    "pietricelei": "pietricică",
    "pietricelele": "pietricică",
    "pietricelelor": "pietricică",
    "pietricica": "pietricică",
    "pietrișul": "pietriș",
    "pietrișului": "pietriș",
    "pietrișuri": "pietriș",
    "pietrișurile": "pietriș",
    "pietrișurilor": "pietriș",
    "pietroasa": "pietros",
    "pietroasă": "pietros",
    "pietroase": "pietros",
    "pietroasei": "pietros",
    "pietroasele": "pietros",
    "pietroaselor": "pietros",
    "pietroși": "pietros",
    "pietroșii": "pietros",
    "pietroșilor": "pietros",
    "pietrosul": "pietros",
    "pietrosului": "pietros",
    "nemaipietruind": "pietrui",
    "nemaipietruindu": "pietrui",
    "nepietruind": "pietrui",
    "nepietruindu": "pietrui",
    "pietruia": "pietrui",
    "pietruiai": "pietrui",
    "pietruiam": "pietrui",
    "pietruiască": "pietrui",
    "pietruiați": "pietrui",
    "pietruiau": "pietrui",
    "pietruiesc": "pietrui",
    "pietruiește": "pietrui",
    "pietruiești": "pietrui",
    "pietruii": "pietrui",
    "pietruim": "pietrui",
    "pietruind": "pietrui",
    "pietruindu": "pietrui",
    "pietruiră": "pietrui",
    "pietruirăm": "pietrui",
    "pietruirăți": "pietrui",
    "pietruise": "pietrui",
    "pietruisem": "pietrui",
    "pietruiseră": "pietrui",
    "pietruiserăm": "pietrui",
    "pietruiserăți": "pietrui",
    "pietruiseși": "pietrui",
    "pietruiși": "pietrui",
    "pietruit": "pietrui",
    "pietruiți": "pietrui",
    "pietruirea": "pietruire",
    "pietruiri": "pietruire",
    "pietruirii": "pietruire",
    "pietruirile": "pietruire",
    "pietruirilor": "pietruire",
    "pietruita": "pietruit",
    "pietruită": "pietruit",
    "pietruite": "pietruit",
    "pietruitei": "pietruit",
    "pietruitele": "pietruit",
    "pietruitelor": "pietruit",
    "pietruiți": "pietruit",
    "pietruiții": "pietruit",
    "pietruiților": "pietruit",
    "pietruitul": "pietruit",
    "pietruitului": "pietruit",
    "piezișa": "pieziș",
    "piezișă": "pieziș",
    "piezișe": "pieziș",
    "piezișei": "pieziș",
    "piezișele": "pieziș",
    "piezișelor": "pieziș",
    "pieziși": "pieziș",
    "piezișii": "pieziș",
    "piezișilor": "pieziș",
    "piezișul": "pieziș",
    "piezișului": "pieziș",
    "piezoelectrica": "piezoelectric",
    "piezoelectrică": "piezoelectric",
    "piezoelectrice": "piezoelectric",
    "piezoelectricei": "piezoelectric",
    "piezoelectricele": "piezoelectric",
    "piezoelectricelor": "piezoelectric",
    "piezoelectrici": "piezoelectric",
    "piezoelectricii": "piezoelectric",
    "piezoelectricilor": "piezoelectric",
    "piezoelectricul": "piezoelectric",
    "piezoelectricului": "piezoelectric",
    "piftia": "piftie",
    "piftiei": "piftie",
    "piftii": "piftie",
    "piftiile": "piftie",
    "piftiilor": "piftie",
    "pigmenți": "pigment",
    "pigmenții": "pigment",
    "pigmenților": "pigment",
    "pigmentul": "pigment",
    "pigmentului": "pigment",
    "nemaipigmentând": "pigmenta",
    "nemaipigmentându": "pigmenta",
    "nepigmentând": "pigmenta",
    "nepigmentându": "pigmenta",
    "pigmentă": "pigmenta",
    "pigmentai": "pigmenta",
    "pigmentam": "pigmenta",
    "pigmentăm": "pigmenta",
    "pigmentând": "pigmenta",
    "pigmentându": "pigmenta",
    "pigmentară": "pigmenta",
    "pigmentarăm": "pigmenta",
    "pigmentarăți": "pigmenta",
    "pigmentase": "pigmenta",
    "pigmentasem": "pigmenta",
    "pigmentaseră": "pigmenta",
    "pigmentaserăm": "pigmenta",
    "pigmentaserăți": "pigmenta",
    "pigmentaseși": "pigmenta",
    "pigmentași": "pigmenta",
    "pigmentat": "pigmenta",
    "pigmentați": "pigmenta",
    "pigmentau": "pigmenta",
    "pigmentează": "pigmenta",
    "pigmentez": "pigmenta",
    "pigmenteze": "pigmenta",
    "pigmentezi": "pigmenta",
    "pigmentată": "pigmentat",
    "pigmentate": "pigmentat",
    "pigmentați": "pigmentat",
    "pigmentația": "pigmentație",
    "pigmentației": "pigmentație",
    "pigmentații": "pigmentație",
    "pigmentațiile": "pigmentație",
    "pigmentațiilor": "pigmentație",
    "pigmei": "pigmeu",
    "pigmeii": "pigmeu",
    "pigmeilor": "pigmeu",
    "pigmeul": "pigmeu",
    "pigmeului": "pigmeu",
    "piguleala": "piguleală",
    "piguleli": "piguleală",
    "pigulelii": "piguleală",
    "pigulelile": "piguleală",
    "pigulelilor": "piguleală",
    "nemaipigulind": "piguli",
    "nemaipigulindu": "piguli",
    "nepigulind": "piguli",
    "nepigulindu": "piguli",
    "pigulea": "piguli",
    "piguleai": "piguli",
    "piguleam": "piguli",
    "pigulească": "piguli",
    "piguleați": "piguli",
    "piguleau": "piguli",
    "pigulesc": "piguli",
    "pigulește": "piguli",
    "pigulești": "piguli",
    "pigulii": "piguli",
    "pigulim": "piguli",
    "pigulind": "piguli",
    "pigulindu": "piguli",
    "piguliră": "piguli",
    "pigulirăm": "piguli",
    "pigulirăți": "piguli",
    "pigulise": "piguli",
    "pigulisem": "piguli",
    "piguliseră": "piguli",
    "piguliserăm": "piguli",
    "piguliserăți": "piguli",
    "piguliseși": "piguli",
    "piguliși": "piguli",
    "pigulit": "piguli",
    "piguliți": "piguli",
    "pigulită": "pigulit",
    "pigulite": "pigulit",
    "piguliți": "pigulit",
    "pijamale": "pijama",
    "pijamalei": "pijama",
    "pijamalele": "pijama",
    "pijamalelor": "pijama",
    "pijamaua": "pijama",
    "pila": "pilă",
    "pile": "pilă",
    "pilei": "pilă",
    "pilele": "pilă",
    "pilelor": "pilă",
    "pilaful": "pilaf",
    "pilafului": "pilaf",
    "pilafuri": "pilaf",
    "pilafurile": "pilaf",
    "pilafurilor": "pilaf",
    "pilaștri": "pilastru",
    "pilaștrii": "pilastru",
    "pilaștrilor": "pilastru",
    "pilastrul": "pilastru",
    "pilastrului": "pilastru",
    "pilda": "pildă",
    "pilde": "pildă",
    "pildei": "pildă",
    "pildele": "pildă",
    "pildelor": "pildă",
    "pilduitoare": "pilduitor",
    "pilduitoarea": "pilduitor",
    "pilduitoarei": "pilduitor",
    "pilduitoarele": "pilduitor",
    "pilduitoarelor": "pilduitor",
    "pilduitori": "pilduitor",
    "pilduitorii": "pilduitor",
    "pilduitorilor": "pilduitor",
    "pilduitorul": "pilduitor",
    "pilduitorului": "pilduitor",
    "pileala": "pileală",
    "pileli": "pileală",
    "pilelii": "pileală",
    "pilelile": "pileală",
    "pilelilor": "pileală",
    "nemaipilind": "pili",
    "nemaipilindu": "pili",
    "nepilind": "pili",
    "nepilindu": "pili",
    "pilea": "pili",
    "pileai": "pili",
    "pileam": "pili",
    "pilească": "pili",
    "pileați": "pili",
    "pileau": "pili",
    "pilesc": "pili",
    "pilește": "pili",
    "pilești": "pili",
    "pilii": "pili",
    "pilim": "pili",
    "pilind": "pili",
    "pilindu": "pili",
    "piliră": "pili",
    "pilirăm": "pili",
    "pilirăți": "pili",
    "pilise": "pili",
    "pilisem": "pili",
    "piliseră": "pili",
    "piliserăm": "pili",
    "piliserăți": "pili",
    "piliseși": "pili",
    "piliși": "pili",
    "pilit": "pili",
    "piliți": "pili",
    "pilirea": "pilire",
    "piliri": "pilire",
    "pilirii": "pilire",
    "pilirile": "pilire",
    "pilirilor": "pilire",
    "pilită": "pilit",
    "pilite": "pilit",
    "piliți": "pilit",
    "pilitura": "pilitură",
    "pilituri": "pilitură",
    "piliturii": "pilitură",
    "piliturile": "pilitură",
    "piliturilor": "pilitură",
    "piloni": "pilon",
    "pilonii": "pilon",
    "pilonilor": "pilon",
    "pilonul": "pilon",
    "pilonului": "pilon",
    "piloasa": "pilos",
    "piloasă": "pilos",
    "piloase": "pilos",
    "piloasei": "pilos",
    "piloasele": "pilos",
    "piloaselor": "pilos",
    "piloși": "pilos",
    "piloșii": "pilos",
    "piloșilor": "pilos",
    "pilosul": "pilos",
    "pilosului": "pilos",
    "piloți": "pilot",
    "piloții": "pilot",
    "piloților": "pilot",
    "pilotul": "pilot",
    "pilotului": "pilot",
    "nemaipilotând": "pilota",
    "nemaipilotându": "pilota",
    "nepilotând": "pilota",
    "nepilotându": "pilota",
    "pilotă": "pilota",
    "pilotai": "pilota",
    "pilotam": "pilota",
    "pilotăm": "pilota",
    "pilotând": "pilota",
    "pilotându": "pilota",
    "pilotară": "pilota",
    "pilotarăm": "pilota",
    "pilotarăți": "pilota",
    "pilotase": "pilota",
    "pilotasem": "pilota",
    "pilotaseră": "pilota",
    "pilotaserăm": "pilota",
    "pilotaserăți": "pilota",
    "pilotaseși": "pilota",
    "pilotași": "pilota",
    "pilotat": "pilota",
    "pilotați": "pilota",
    "pilotau": "pilota",
    "pilotează": "pilota",
    "pilotez": "pilota",
    "piloteze": "pilota",
    "pilotezi": "pilota",
    "pilota": "pilotă",
    "pilote": "pilotă",
    "pilotei": "pilotă",
    "pilotele": "pilotă",
    "pilotelor": "pilotă",
    "pilotaje": "pilotaj",
    "pilotajele": "pilotaj",
    "pilotajelor": "pilotaj",
    "pilotajul": "pilotaj",
    "pilotajului": "pilotaj",
    "pilotată": "pilotat",
    "pilotate": "pilotat",
    "pilotați": "pilotat",
    "pilula": "pilulă",
    "pilule": "pilulă",
    "pilulei": "pilulă",
    "pilulele": "pilulă",
    "pilulelor": "pilulă",
    "pini": "pin",
    "pinii": "pin",
    "pinilor": "pin",
    "pinul": "pin",
    "pinului": "pin",
    "pinacoteca": "pinacotecă",
    "pinacoteci": "pinacotecă",
    "pinacotecii": "pinacotecă",
    "pinacotecile": "pinacotecă",
    "pinacotecilor": "pinacotecă",
    "pindarica": "pindaric",
    "pindarică": "pindaric",
    "pindarice": "pindaric",
    "pindaricei": "pindaric",
    "pindaricele": "pindaric",
    "pindaricelor": "pindaric",
    "pindarici": "pindaric",
    "pindaricii": "pindaric",
    "pindaricilor": "pindaric",
    "pindaricul": "pindaric",
    "pindaricului": "pindaric",
    "pingeaua": "pingea",
    "pingele": "pingea",
    "pingelei": "pingea",
    "pingelele": "pingea",
    "pingelelor": "pingea",
    "nemaipingelind": "pingeli",
    "nemaipingelindu": "pingeli",
    "nepingelind": "pingeli",
    "nepingelindu": "pingeli",
    "pingelea": "pingeli",
    "pingeleai": "pingeli",
    "pingeleam": "pingeli",
    "pingelească": "pingeli",
    "pingeleați": "pingeli",
    "pingeleau": "pingeli",
    "pingelesc": "pingeli",
    "pingelește": "pingeli",
    "pingelești": "pingeli",
    "pingelii": "pingeli",
    "pingelim": "pingeli",
    "pingelind": "pingeli",
    "pingelindu": "pingeli",
    "pingeliră": "pingeli",
    "pingelirăm": "pingeli",
    "pingelirăți": "pingeli",
    "pingelise": "pingeli",
    "pingelisem": "pingeli",
    "pingeliseră": "pingeli",
    "pingeliserăm": "pingeli",
    "pingeliserăți": "pingeli",
    "pingeliseși": "pingeli",
    "pingeliși": "pingeli",
    "pingelit": "pingeli",
    "pingeliți": "pingeli",
    "pingelită": "pingelit",
    "pingelite": "pingelit",
    "pingeliți": "pingelit",
    "ping-pongul": "ping-pong",
    "ping-pongului": "ping-pong",
    "ping-pongista": "ping-pongist",
    "ping-pongistă": "ping-pongist",
    "ping-pongiste": "ping-pongist",
    "ping-pongistei": "ping-pongist",
    "ping-pongistele": "ping-pongist",
    "ping-pongistelor": "ping-pongist",
    "ping-pongiști": "ping-pongist",
    "ping-pongiștii": "ping-pongist",
    "ping-pongiștilor": "ping-pongist",
    "ping-pongistul": "ping-pongist",
    "ping-pongistului": "ping-pongist",
    "pinguini": "pinguin",
    "pinguinii": "pinguin",
    "pinguinilor": "pinguin",
    "pinguinul": "pinguin",
    "pinguinului": "pinguin",
    "pinioane": "pinion",
    "pinioanele": "pinion",
    "pinioanelor": "pinion",
    "pinionul": "pinion",
    "pinionului": "pinion",
    "pinta": "pintă",
    "pinteni": "pinten",
    "pintenii": "pinten",
    "pintenilor": "pinten",
    "pintenul": "pinten",
    "pintenului": "pinten",
    "pintenata": "pintenat",
    "pintenată": "pintenat",
    "pintenate": "pintenat",
    "pintenatei": "pintenat",
    "pintenatele": "pintenat",
    "pintenatelor": "pintenat",
    "pintenați": "pintenat",
    "pintenații": "pintenat",
    "pintenaților": "pintenat",
    "pintenatul": "pintenat",
    "pintenatului": "pintenat",
    "pintenoaga": "pintenog",
    "pintenoagă": "pintenog",
    "pintenoage": "pintenog",
    "pintenoagei": "pintenog",
    "pintenoagele": "pintenog",
    "pintenoagelor": "pintenog",
    "pintenogi": "pintenog",
    "pintenogii": "pintenog",
    "pintenogilor": "pintenog",
    "pintenogul": "pintenog",
    "pintenogului": "pintenog",
    "piogena": "piogen",
    "piogenă": "piogen",
    "piogene": "piogen",
    "piogenei": "piogen",
    "piogenele": "piogen",
    "piogenelor": "piogen",
    "piogeni": "piogen",
    "piogenii": "piogen",
    "piogenilor": "piogen",
    "piogenul": "piogen",
    "piogenului": "piogen",
    "pioleți": "piolet",
    "pioleții": "piolet",
    "pioleților": "piolet",
    "pioletul": "piolet",
    "pioletului": "piolet",
    "pioni": "pion",
    "pionii": "pion",
    "pionilor": "pion",
    "pionul": "pion",
    "pionului": "pion",
    "pionieri": "pionier",
    "pionierii": "pionier",
    "pionierilor": "pionier",
    "pionierul": "pionier",
    "pionierului": "pionier",
    "pioniereasca": "pionieresc",
    "pionierească": "pionieresc",
    "pionierescul": "pionieresc",
    "pionierescului": "pionieresc",
    "pionierești": "pionieresc",
    "pioniereștii": "pionieresc",
    "pioniereștile": "pionieresc",
    "pioniereștilor": "pionieresc",
    "pioasa": "pios",
    "pioasă": "pios",
    "pioase": "pios",
    "pioasei": "pios",
    "pioasele": "pios",
    "pioaselor": "pios",
    "pioși": "pios",
    "pioșii": "pios",
    "pioșilor": "pios",
    "piosul": "pios",
    "piosului": "pios",
    "pioșenia": "pioșenie",
    "pioșeniei": "pioșenie",
    "pioșenii": "pioșenie",
    "pioșeniile": "pioșenie",
    "pioșeniilor": "pioșenie",
    "pipa": "pipă",
    "pipe": "pipă",
    "pipei": "pipă",
    "pipele": "pipă",
    "pipelor": "pipă",
    "nemaipipăind": "pipăi",
    "nemaipipăindu": "pipăi",
    "nepipăind": "pipăi",
    "nepipăindu": "pipăi",
    "pipăia": "pipăi",
    "pipăiai": "pipăi",
    "pipăiam": "pipăi",
    "pipăiați": "pipăi",
    "pipăiau": "pipăi",
    "pipăie": "pipăi",
    "pipăii": "pipăi",
    "pipăim": "pipăi",
    "pipăind": "pipăi",
    "pipăindu": "pipăi",
    "pipăiră": "pipăi",
    "pipăirăm": "pipăi",
    "pipăirăți": "pipăi",
    "pipăise": "pipăi",
    "pipăisem": "pipăi",
    "pipăiseră": "pipăi",
    "pipăiserăm": "pipăi",
    "pipăiserăți": "pipăi",
    "pipăiseși": "pipăi",
    "pipăiși": "pipăi",
    "pipăit": "pipăi",
    "pipăiți": "pipăi",
    "pipăibila": "pipăibil",
    "pipăibilă": "pipăibil",
    "pipăibile": "pipăibil",
    "pipăibilei": "pipăibil",
    "pipăibilele": "pipăibil",
    "pipăibilelor": "pipăibil",
    "pipăibili": "pipăibil",
    "pipăibilii": "pipăibil",
    "pipăibililor": "pipăibil",
    "pipăibilul": "pipăibil",
    "pipăibilului": "pipăibil",
    "pipăită": "pipăit",
    "pipăite": "pipăit",
    "pipăiți": "pipăit",
    "piperi": "piper",
    "piperii": "piper",
    "piperilor": "piper",
    "piperul": "piper",
    "piperului": "piper",
    "nemaipiperând": "pipera",
    "nemaipiperându": "pipera",
    "nepiperând": "pipera",
    "nepiperându": "pipera",
    "piperă": "pipera",
    "piperai": "pipera",
    "piperam": "pipera",
    "piperăm": "pipera",
    "piperând": "pipera",
    "piperându": "pipera",
    "piperară": "pipera",
    "piperarăm": "pipera",
    "piperarăți": "pipera",
    "piperase": "pipera",
    "piperasem": "pipera",
    "piperaseră": "pipera",
    "piperaserăm": "pipera",
    "piperaserăți": "pipera",
    "piperaseși": "pipera",
    "piperași": "pipera",
    "piperat": "pipera",
    "piperați": "pipera",
    "piperau": "pipera",
    "piperează": "pipera",
    "Piperei": "Pipera",
    "piperez": "pipera",
    "pipereze": "pipera",
    "piperezi": "pipera",
    "piperată": "piperat",
    "piperate": "piperat",
    "piperați": "piperat",
    "pipernicia": "pipernicie",
    "piperniciei": "pipernicie",
    "pipernicii": "pipernicie",
    "pipeta": "pipetă",
    "pipete": "pipetă",
    "pipetei": "pipetă",
    "pipetele": "pipetă",
    "pipetelor": "pipetă",
    "pipota": "pipotă",
    "pipote": "pipotă",
    "pipotei": "pipotă",
    "pipotele": "pipotă",
    "pipotelor": "pipotă",
    "pirul": "pir",
    "pirului": "pir",
    "piramida": "piramidă",
    "piramide": "piramidă",
    "piramidei": "piramidă",
    "piramidele": "piramidă",
    "piramidelor": "piramidă",
    "piramidala": "piramidal",
    "piramidală": "piramidal",
    "piramidale": "piramidal",
    "piramidalei": "piramidal",
    "piramidalele": "piramidal",
    "piramidalelor": "piramidal",
    "piramidali": "piramidal",
    "piramidalii": "piramidal",
    "piramidalilor": "piramidal",
    "piramidalul": "piramidal",
    "piramidalului": "piramidal",
    "piramidoane": "piramidon",
    "piramidoanele": "piramidon",
    "piramidoanelor": "piramidon",
    "piramidonul": "piramidon",
    "piramidonului": "piramidon",
    "pirați": "pirat",
    "pirații": "pirat",
    "piraților": "pirat",
    "piratul": "pirat",
    "piratului": "pirat",
    "piratereasca": "pirateresc",
    "piraterească": "pirateresc",
    "piraterescul": "pirateresc",
    "piraterescului": "pirateresc",
    "piraterești": "pirateresc",
    "piratereștii": "pirateresc",
    "piratereștile": "pirateresc",
    "piratereștilor": "pirateresc",
    "piraticeasca": "piraticesc",
    "piraticească": "piraticesc",
    "piraticescul": "piraticesc",
    "piraticescului": "piraticesc",
    "piraticești": "piraticesc",
    "piraticeștii": "piraticesc",
    "piraticeștile": "piraticesc",
    "piraticeștilor": "piraticesc",
    "piretica": "piretic",
    "piretică": "piretic",
    "piretice": "piretic",
    "pireticei": "piretic",
    "pireticele": "piretic",
    "pireticelor": "piretic",
    "piretici": "piretic",
    "pireticii": "piretic",
    "pireticilor": "piretic",
    "pireticul": "piretic",
    "pireticului": "piretic",
    "piriforma": "piriform",
    "piriformă": "piriform",
    "piriforme": "piriform",
    "piriformei": "piriform",
    "piriformele": "piriform",
    "piriformelor": "piriform",
    "piriformi": "piriform",
    "piriformii": "piriform",
    "piriformilor": "piriform",
    "piriformul": "piriform",
    "piriformului": "piriform",
    "pirita": "pirită",
    "pirite": "pirită",
    "piritei": "pirită",
    "piritele": "pirită",
    "piritelor": "pirită",
    "piritoasa": "piritos",
    "piritoasă": "piritos",
    "piritoase": "piritos",
    "piritoasei": "piritos",
    "piritoasele": "piritos",
    "piritoaselor": "piritos",
    "piritoși": "piritos",
    "piritoșii": "piritos",
    "piritoșilor": "piritos",
    "piritosul": "piritos",
    "piritosului": "piritos",
    "piroclastica": "piroclastic",
    "piroclastică": "piroclastic",
    "piroclastice": "piroclastic",
    "piroclasticei": "piroclastic",
    "piroclasticele": "piroclastic",
    "piroclasticelor": "piroclastic",
    "piroclastici": "piroclastic",
    "piroclasticii": "piroclastic",
    "piroclasticilor": "piroclastic",
    "piroclasticul": "piroclastic",
    "piroclasticului": "piroclastic",
    "pirofori": "pirofor",
    "piroforii": "pirofor",
    "piroforilor": "pirofor",
    "piroforul": "pirofor",
    "piroforului": "pirofor",
    "piroforica": "piroforic",
    "piroforică": "piroforic",
    "piroforice": "piroforic",
    "piroforicei": "piroforic",
    "piroforicele": "piroforic",
    "piroforicelor": "piroforic",
    "piroforici": "piroforic",
    "piroforicii": "piroforic",
    "piroforicilor": "piroforic",
    "piroforicul": "piroforic",
    "piroforicului": "piroforic",
    "piroga": "pirogă",
    "pirogi": "pirogă",
    "pirogii": "pirogă",
    "pirogile": "pirogă",
    "pirogilor": "pirogă",
    "pirogalica": "pirogalic",
    "pirogalică": "pirogalic",
    "pirogalice": "pirogalic",
    "pirogalicei": "pirogalic",
    "pirogalicele": "pirogalic",
    "pirogalicelor": "pirogalic",
    "pirogalici": "pirogalic",
    "pirogalicii": "pirogalic",
    "pirogalicilor": "pirogalic",
    "pirogalicul": "pirogalic",
    "pirogalicului": "pirogalic",
    "pirogenarea": "pirogenare",
    "pirogenări": "pirogenare",
    "pirogenării": "pirogenare",
    "pirogravori": "pirogravor",
    "pirogravorii": "pirogravor",
    "pirogravorilor": "pirogravor",
    "pirogravorul": "pirogravor",
    "pirogravorului": "pirogravor",
    "pirogravura": "pirogravură",
    "pirogravuri": "pirogravură",
    "pirogravurii": "pirogravură",
    "pirogravurile": "pirogravură",
    "pirogravurilor": "pirogravură",
    "piroliza": "piroliză",
    "pirolize": "piroliză",
    "pirolizei": "piroliză",
    "pirolizele": "piroliză",
    "pirolizelor": "piroliză",
    "piromani": "piroman",
    "piromanii": "piroman",
    "piromanilor": "piroman",
    "piromanul": "piroman",
    "piromanului": "piroman",
    "piromana": "piromană",
    "piromane": "piromană",
    "piromanei": "piromană",
    "piromanele": "piromană",
    "piromanelor": "piromană",
    "piromania": "piromanie",
    "piromaniei": "piromanie",
    "piromanii": "piromanie",
    "pirometrica": "pirometric",
    "pirometrică": "pirometric",
    "pirometrice": "pirometric",
    "pirometricei": "pirometric",
    "pirometricele": "pirometric",
    "pirometricelor": "pirometric",
    "pirometrici": "pirometric",
    "pirometricii": "pirometric",
    "pirometricilor": "pirometric",
    "pirometricul": "pirometric",
    "pirometricului": "pirometric",
    "pirometria": "pirometrie",
    "pirometriei": "pirometrie",
    "pirometrii": "pirometrie",
    "pirometre": "pirometru",
    "pirometrele": "pirometru",
    "pirometrelor": "pirometru",
    "pirometrul": "pirometru",
    "pirometrului": "pirometru",
    "piroane": "piron",
    "piroanele": "piron",
    "piroanelor": "piron",
    "pironul": "piron",
    "pironului": "piron",
    "nemaipironind": "pironi",
    "nemaipironindu": "pironi",
    "nepironind": "pironi",
    "nepironindu": "pironi",
    "pironea": "pironi",
    "pironeai": "pironi",
    "pironeam": "pironi",
    "pironească": "pironi",
    "pironeați": "pironi",
    "pironeau": "pironi",
    "pironesc": "pironi",
    "pironește": "pironi",
    "pironești": "pironi",
    "pironii": "pironi",
    "pironim": "pironi",
    "pironind": "pironi",
    "pironindu": "pironi",
    "pironiră": "pironi",
    "pironirăm": "pironi",
    "pironirăți": "pironi",
    "pironise": "pironi",
    "pironisem": "pironi",
    "pironiseră": "pironi",
    "pironiserăm": "pironi",
    "pironiserăți": "pironi",
    "pironiseși": "pironi",
    "pironiși": "pironi",
    "pironit": "pironi",
    "pironiți": "pironi",
    "pironită": "pironit",
    "pironite": "pironit",
    "pironiți": "pironit",
    "piroscafe": "piroscaf",
    "piroscafele": "piroscaf",
    "piroscafelor": "piroscaf",
    "piroscaful": "piroscaf",
    "piroscafului": "piroscaf",
    "piroscoape": "piroscop",
    "piroscoapele": "piroscop",
    "piroscoapelor": "piroscop",
    "piroscopul": "piroscop",
    "piroscopului": "piroscop",
    "pirosfera": "pirosferă",
    "pirosfere": "pirosferă",
    "pirosferei": "pirosferă",
    "pirostria": "pirostrie",
    "pirostriei": "pirostrie",
    "pirostrii": "pirostrie",
    "pirostriile": "pirostrie",
    "pirostriilor": "pirostrie",
    "pirotehnica": "pirotehnic",
    "pirotehnică": "pirotehnic",
    "pirotehnice": "pirotehnic",
    "pirotehnicei": "pirotehnic",
    "pirotehnicele": "pirotehnic",
    "pirotehnicelor": "pirotehnic",
    "pirotehnici": "pirotehnic",
    "pirotehnicii": "pirotehnic",
    "pirotehnicilor": "pirotehnic",
    "pirotehnicul": "pirotehnic",
    "pirotehnicului": "pirotehnic",
    "pirotehnicianul": "pirotehnician",
    "pirotehnicianului": "pirotehnician",
    "pirotehnicieni": "pirotehnician",
    "pirotehnicienii": "pirotehnician",
    "pirotehnicienilor": "pirotehnician",
    "pirotehnia": "pirotehnie",
    "pirotehniei": "pirotehnie",
    "pirotehnii": "pirotehnie",
    "pirotehniile": "pirotehnie",
    "pirotehniilor": "pirotehnie",
    "pirotermica": "pirotermic",
    "pirotermică": "pirotermic",
    "pirotermice": "pirotermic",
    "pirotermicei": "pirotermic",
    "pirotermicele": "pirotermic",
    "pirotermicelor": "pirotermic",
    "pirotermici": "pirotermic",
    "pirotermicii": "pirotermic",
    "pirotermicilor": "pirotermic",
    "pirotermicul": "pirotermic",
    "pirotermicului": "pirotermic",
    "nemaipirotind": "piroti",
    "nemaipirotindu": "piroti",
    "nepirotind": "piroti",
    "nepirotindu": "piroti",
    "pirotea": "piroti",
    "piroteai": "piroti",
    "piroteam": "piroti",
    "pirotească": "piroti",
    "piroteați": "piroti",
    "piroteau": "piroti",
    "pirotesc": "piroti",
    "pirotește": "piroti",
    "pirotești": "piroti",
    "pirotii": "piroti",
    "pirotim": "piroti",
    "pirotind": "piroti",
    "pirotindu": "piroti",
    "pirotiră": "piroti",
    "pirotirăm": "piroti",
    "pirotirăți": "piroti",
    "pirotise": "piroti",
    "pirotisem": "piroti",
    "pirotiseră": "piroti",
    "pirotiserăm": "piroti",
    "pirotiserăți": "piroti",
    "pirotiseși": "piroti",
    "pirotiși": "piroti",
    "pirotit": "piroti",
    "pirotiți": "piroti",
    "pirotită": "pirotit",
    "pirotite": "pirotit",
    "pirotiți": "pirotit",
    "pirpiria": "pirpiriu",
    "pirpirie": "pirpiriu",
    "pirpiriei": "pirpiriu",
    "pirpirii": "pirpiriu",
    "pirpiriii": "pirpiriu",
    "pirpiriile": "pirpiriu",
    "pirpiriilor": "pirpiriu",
    "pirpiriul": "pirpiriu",
    "pirpiriului": "pirpiriu",
    "pirueta": "piruetă",
    "piruete": "piruetă",
    "piruetei": "piruetă",
    "piruetele": "piruetă",
    "piruetelor": "piruetă",
    "nemaipisând": "pisa",
    "nemaipisându": "pisa",
    "nepisând": "pisa",
    "nepisându": "pisa",
    "pisă": "pisa",
    "pisai": "pisa",
    "pisam": "pisa",
    "pisăm": "pisa",
    "pisând": "pisa",
    "pisându": "pisa",
    "pisară": "pisa",
    "pisarăm": "pisa",
    "pisarăți": "pisa",
    "pisase": "pisa",
    "pisasem": "pisa",
    "pisaseră": "pisa",
    "pisaserăm": "pisa",
    "pisaserăți": "pisa",
    "pisaseși": "pisa",
    "pisași": "pisa",
    "pisat": "pisa",
    "pisați": "pisa",
    "pisau": "pisa",
    "pisează": "pisa",
    "pisez": "pisa",
    "piseze": "pisa",
    "pisezi": "pisa",
    "pișăcioasa": "pișăcios",
    "pișăcioasă": "pișăcios",
    "pișăcioase": "pișăcios",
    "pișăcioasei": "pișăcios",
    "pișăcioasele": "pișăcios",
    "pișăcioaselor": "pișăcios",
    "pișăcioși": "pișăcios",
    "pișăcioșii": "pișăcios",
    "pișăcioșilor": "pișăcios",
    "pișăciosul": "pișăcios",
    "pișăciosului": "pișăcios",
    "pisăloaga": "pisălog",
    "pisăloagă": "pisălog",
    "pisăloage": "pisălog",
    "pisăloagei": "pisălog",
    "pisăloagele": "pisălog",
    "pisăloagelor": "pisălog",
    "pisălogi": "pisălog",
    "pisălogii": "pisălog",
    "pisălogilor": "pisălog",
    "pisălogul": "pisălog",
    "pisălogului": "pisălog",
    "nemaipisălogind": "pisălogi",
    "nemaipisălogindu": "pisălogi",
    "nepisălogind": "pisălogi",
    "nepisălogindu": "pisălogi",
    "pisălogea": "pisălogi",
    "pisălogeai": "pisălogi",
    "pisălogeam": "pisălogi",
    "pisălogească": "pisălogi",
    "pisălogeați": "pisălogi",
    "pisălogeau": "pisălogi",
    "pisălogesc": "pisălogi",
    "pisălogește": "pisălogi",
    "pisălogești": "pisălogi",
    "pisălogii": "pisălogi",
    "pisălogim": "pisălogi",
    "pisălogind": "pisălogi",
    "pisălogindu": "pisălogi",
    "pisălogiră": "pisălogi",
    "pisălogirăm": "pisălogi",
    "pisălogirăți": "pisălogi",
    "pisălogise": "pisălogi",
    "pisălogisem": "pisălogi",
    "pisălogiseră": "pisălogi",
    "pisălogiserăm": "pisălogi",
    "pisălogiserăți": "pisălogi",
    "pisălogiseși": "pisălogi",
    "pisălogiși": "pisălogi",
    "pisălogit": "pisălogi",
    "pisălogiți": "pisălogi",
    "pisălogită": "pisălogit",
    "pisălogite": "pisălogit",
    "pisălogiți": "pisălogit",
    "pisată": "pisat",
    "pisate": "pisat",
    "pisați": "pisat",
    "piscul": "pisc",
    "piscului": "pisc",
    "piscuri": "pisc",
    "piscurile": "pisc",
    "piscurilor": "pisc",
    "nemaipișcând": "pișca",
    "nemaipișcându": "pișca",
    "nepișcând": "pișca",
    "nepișcându": "pișca",
    "pișc": "pișca",
    "pișcă": "pișca",
    "pișcai": "pișca",
    "pișcam": "pișca",
    "pișcăm": "pișca",
    "pișcând": "pișca",
    "pișcându": "pișca",
    "pișcară": "pișca",
    "pișcarăm": "pișca",
    "pișcarăți": "pișca",
    "pișcase": "pișca",
    "pișcasem": "pișca",
    "pișcaseră": "pișca",
    "pișcaserăm": "pișca",
    "pișcaserăți": "pișca",
    "pișcaseși": "pișca",
    "pișcași": "pișca",
    "pișcat": "pișca",
    "pișcați": "pișca",
    "pișcau": "pișca",
    "piște": "pișca",
    "piști": "pișca",
    "pișcăcioasa": "pișcăcios",
    "pișcăcioasă": "pișcăcios",
    "pișcăcioase": "pișcăcios",
    "pișcăcioasei": "pișcăcios",
    "pișcăcioasele": "pișcăcios",
    "pișcăcioaselor": "pișcăcios",
    "pișcăcioși": "pișcăcios",
    "pișcăcioșii": "pișcăcios",
    "pișcăcioșilor": "pișcăcios",
    "pișcăciosul": "pișcăcios",
    "pișcăciosului": "pișcăcios",
    "pișcată": "pișcat",
    "pișcate": "pișcat",
    "pișcați": "pișcat",
    "pișcătoare": "pișcător",
    "pișcătoarea": "pișcător",
    "pișcătoarei": "pișcător",
    "pișcătoarele": "pișcător",
    "pișcătoarelor": "pișcător",
    "pișcători": "pișcător",
    "pișcătorii": "pișcător",
    "pișcătorilor": "pișcător",
    "pișcătorul": "pișcător",
    "pișcătorului": "pișcător",
    "piscicola": "piscicol",
    "piscicolă": "piscicol",
    "piscicole": "piscicol",
    "piscicolei": "piscicol",
    "piscicolele": "piscicol",
    "piscicolelor": "piscicol",
    "piscicoli": "piscicol",
    "piscicolii": "piscicol",
    "piscicolilor": "piscicol",
    "piscicolul": "piscicol",
    "piscicolului": "piscicol",
    "piscicultori": "piscicultor",
    "piscicultorii": "piscicultor",
    "piscicultorilor": "piscicultor",
    "piscicultorul": "piscicultor",
    "piscicultorului": "piscicultor",
    "pisc.": "piscicultură",
    "piscicultura": "piscicultură",
    "pisciculturi": "piscicultură",
    "pisciculturii": "piscicultură",
    "piscina": "piscină",
    "piscine": "piscină",
    "piscinei": "piscină",
    "piscinele": "piscină",
    "piscinelor": "piscină",
    "pișcotul": "pișcot",
    "pișcotului": "pișcot",
    "pișcoturi": "pișcot",
    "pișcoturile": "pișcot",
    "pișcoturilor": "pișcot",
    "pisici": "pisic",
    "pisicii": "pisic",
    "pisicilor": "pisic",
    "pisicul": "pisic",
    "pisicului": "pisic",
    "pisica": "pisică",
    "pisici": "pisică",
    "pisicii": "pisică",
    "pisicile": "pisică",
    "pisicilor": "pisică",
    "pisiceasca": "pisicesc",
    "pisicească": "pisicesc",
    "pisicescul": "pisicesc",
    "pisicescului": "pisicesc",
    "pisicești": "pisicesc",
    "pisiceștii": "pisicesc",
    "pisiceștile": "pisicesc",
    "pisiceștilor": "pisicesc",
    "pișichera": "pișicher",
    "pișicheră": "pișicher",
    "pișichere": "pișicher",
    "pișicherei": "pișicher",
    "pișicherele": "pișicher",
    "pișicherelor": "pișicher",
    "pișicheri": "pișicher",
    "pișicherii": "pișicher",
    "pișicherilor": "pișicher",
    "pișicherul": "pișicher",
    "pișicherului": "pișicher",
    "pisoare": "pisoar",
    "pisoarele": "pisoar",
    "pisoarelor": "pisoar",
    "pisoarul": "pisoar",
    "pisoarului": "pisoar",
    "pisolitica": "pisolitic",
    "pisolitică": "pisolitic",
    "pisolitice": "pisolitic",
    "pisoliticei": "pisolitic",
    "pisoliticele": "pisolitic",
    "pisoliticelor": "pisolitic",
    "pisolitici": "pisolitic",
    "pisoliticii": "pisolitic",
    "pisoliticilor": "pisolitic",
    "pisoliticul": "pisolitic",
    "pisoliticului": "pisolitic",
    "pista": "pistă",
    "piste": "pistă",
    "pistei": "pistă",
    "pistele": "pistă",
    "pistelor": "pistă",
    "pistilul": "pistil",
    "pistilului": "pistil",
    "pistiluri": "pistil",
    "pistilurile": "pistil",
    "pistilurilor": "pistil",
    "pistofoane": "pistofon",
    "pistofoanele": "pistofon",
    "pistofoanelor": "pistofon",
    "pistofonul": "pistofon",
    "pistofonului": "pistofon",
    "pistoale": "pistol",
    "pistoalele": "pistol",
    "pistoalelor": "pistol",
    "pistolul": "pistol",
    "pistolului": "pistol",
    "pistolari": "pistolar",
    "pistolarii": "pistolar",
    "pistolarilor": "pistolar",
    "pistolarul": "pistolar",
    "pistolarului": "pistolar",
    "pistolete": "pistolet",
    "pistoletele": "pistolet",
    "pistoletelor": "pistolet",
    "pistoletul": "pistolet",
    "pistoletului": "pistolet",
    "pistoalele-mitralieră": "pistol-mitralieră",
    "pistoalelor-mitralieră": "pistol-mitralieră",
    "pistoale-mitralieră": "pistol-mitralieră",
    "pistolul-mitralieră": "pistol-mitralieră",
    "pistolului-mitralieră": "pistol-mitralieră",
    "pistoalele-portbandulă": "pistol-portbandulă",
    "pistoalelor-portbandulă": "pistol-portbandulă",
    "pistoale-portbandulă": "pistol-portbandulă",
    "pistolul-portbandulă": "pistol-portbandulă",
    "pistolului-portbandulă": "pistol-portbandulă",
    "pistoalele-rachetă": "pistol-rachetă",
    "pistoalelor-rachetă": "pistol-rachetă",
    "pistoale-rachetă": "pistol-rachetă",
    "pistolul-rachetă": "pistol-rachetă",
    "pistolului-rachetă": "pistol-rachetă",
    "pistoane": "piston",
    "pistoanele": "piston",
    "pistoanelor": "piston",
    "pistonul": "piston",
    "pistonului": "piston",
    "nemaipistonând": "pistona",
    "nemaipistonându": "pistona",
    "nepistonând": "pistona",
    "nepistonându": "pistona",
    "pistonă": "pistona",
    "pistonai": "pistona",
    "pistonam": "pistona",
    "pistonăm": "pistona",
    "pistonând": "pistona",
    "pistonându": "pistona",
    "pistonară": "pistona",
    "pistonarăm": "pistona",
    "pistonarăți": "pistona",
    "pistonase": "pistona",
    "pistonasem": "pistona",
    "pistonaseră": "pistona",
    "pistonaserăm": "pistona",
    "pistonaserăți": "pistona",
    "pistonaseși": "pistona",
    "pistonași": "pistona",
    "pistonat": "pistona",
    "pistonați": "pistona",
    "pistonau": "pistona",
    "pistonează": "pistona",
    "pistonez": "pistona",
    "pistoneze": "pistona",
    "pistonezi": "pistona",
    "pistonarea": "pistonare",
    "pistonări": "pistonare",
    "pistonării": "pistonare",
    "pistonările": "pistonare",
    "pistonărilor": "pistonare",
    "pistonată": "pistonat",
    "pistonate": "pistonat",
    "pistonați": "pistonat",
    "pistruia": "pistrui",
    "pistruie": "pistrui",
    "pistruii": "pistrui",
    "pistruilor": "pistrui",
    "pistruiul": "pistrui",
    "pistruiului": "pistrui",
    "pistruiata": "pistruiat",
    "pistruiată": "pistruiat",
    "pistruiate": "pistruiat",
    "pistruiatei": "pistruiat",
    "pistruiatele": "pistruiat",
    "pistruiatelor": "pistruiat",
    "pistruiați": "pistruiat",
    "pistruiații": "pistruiat",
    "pistruiaților": "pistruiat",
    "pistruiatul": "pistruiat",
    "pistruiatului": "pistruiat",
    "pitagoreica": "pitagoreic",
    "pitagoreică": "pitagoreic",
    "pitagoreice": "pitagoreic",
    "pitagoreicei": "pitagoreic",
    "pitagoreicele": "pitagoreic",
    "pitagoreicelor": "pitagoreic",
    "pitagoreici": "pitagoreic",
    "pitagoreicii": "pitagoreic",
    "pitagoreicilor": "pitagoreic",
    "pitagoreicul": "pitagoreic",
    "pitagoreicului": "pitagoreic",
    "pitagorica": "pitagoric",
    "pitagorică": "pitagoric",
    "pitagorice": "pitagoric",
    "pitagoricei": "pitagoric",
    "pitagoricele": "pitagoric",
    "pitagoricelor": "pitagoric",
    "pitagorici": "pitagoric",
    "pitagoricii": "pitagoric",
    "pitagoricilor": "pitagoric",
    "pitagoricul": "pitagoric",
    "pitagoricului": "pitagoric",
    "pitateria": "pitaterie",
    "pitateriei": "pitaterie",
    "pitaterii": "pitaterie",
    "pitateriile": "pitaterie",
    "pitateriilor": "pitaterie",
    "piteșteana": "piteștean",
    "piteșteană": "piteștean",
    "piteșteanul": "piteștean",
    "piteșteanului": "piteștean",
    "piteștene": "piteștean",
    "piteștenei": "piteștean",
    "piteștenele": "piteștean",
    "piteștenelor": "piteștean",
    "piteșteni": "piteștean",
    "piteștenii": "piteștean",
    "piteștenilor": "piteștean",
    "Piteștiul": "Pitești",
    "Piteștiului": "Pitești",
    "nemaipitind": "piti",
    "nemaipitindu": "piti",
    "nepitind": "piti",
    "nepitindu": "piti",
    "pitea": "piti",
    "piteai": "piti",
    "piteam": "piti",
    "pitească": "piti",
    "piteați": "piti",
    "piteau": "piti",
    "pitesc": "piti",
    "pitește": "piti",
    "pitești": "piti",
    "pitii": "piti",
    "pitim": "piti",
    "pitind": "piti",
    "pitindu": "piti",
    "pitiră": "piti",
    "pitirăm": "piti",
    "pitirăți": "piti",
    "pitise": "piti",
    "pitisem": "piti",
    "pitiseră": "piti",
    "pitiserăm": "piti",
    "pitiserăți": "piti",
    "pitiseși": "piti",
    "pitiși": "piti",
    "pitit": "piti",
    "pitiți": "piti",
    "Pitiei": "Pitia",
    "pitica": "pitic",
    "pitică": "pitic",
    "pitice": "pitic",
    "piticei": "pitic",
    "piticele": "pitic",
    "piticelor": "pitic",
    "pitici": "pitic",
    "piticii": "pitic",
    "piticilor": "pitic",
    "piticul": "pitic",
    "piticului": "pitic",
    "pițigăiai": "pițigăia",
    "pițigăiam": "pițigăia",
    "pițigăiară": "pițigăia",
    "pițigăiarăm": "pițigăia",
    "pițigăiarăți": "pițigăia",
    "pițigăiase": "pițigăia",
    "pițigăiasem": "pițigăia",
    "pițigăiaseră": "pițigăia",
    "pițigăiaserăm": "pițigăia",
    "pițigăiaserăți": "pițigăia",
    "pițigăiaseși": "pițigăia",
    "pițigăiași": "pițigăia",
    "pițigăiat": "pițigăia",
    "pițigăiați": "pițigăia",
    "pițigăiau": "pițigăia",
    "pițigăiază": "pițigăia",
    "pițigăie": "pițigăia",
    "pițigăiem": "pițigăia",
    "pițigăiez": "pițigăia",
    "pițigăieze": "pițigăia",
    "pițigăiezi": "pițigăia",
    "pițigăind": "pițigăia",
    "pițigăiata": "pițigăiat",
    "pițigăiată": "pițigăiat",
    "pițigăiate": "pițigăiat",
    "pițigăiatei": "pițigăiat",
    "pițigăiatele": "pițigăiat",
    "pițigăiatelor": "pițigăiat",
    "pițigăiați": "pițigăiat",
    "pițigăiații": "pițigăiat",
    "pițigăiaților": "pițigăiat",
    "pițigăiatul": "pițigăiat",
    "pițigăiatului": "pițigăiat",
    "pițigoii": "pițigoi",
    "pițigoilor": "pițigoi",
    "pițigoiul": "pițigoi",
    "pițigoiului": "pițigoi",
    "pitită": "pitit",
    "pitite": "pitit",
    "pitiți": "pitit",
    "pitoni": "piton",
    "pitonii": "piton",
    "pitonilor": "piton",
    "pitonul": "piton",
    "pitonului": "piton",
    "pitoreasca": "pitoresc",
    "pitorească": "pitoresc",
    "pitorescul": "pitoresc",
    "pitorescului": "pitoresc",
    "pitorești": "pitoresc",
    "pitoreștii": "pitoresc",
    "pitoreștile": "pitoresc",
    "pitoreștilor": "pitoresc",
    "pitpalaci": "pitpalac",
    "pitpalacii": "pitpalac",
    "pitpalacilor": "pitpalac",
    "pitpalacul": "pitpalac",
    "pitpalacului": "pitpalac",
    "pitrocul": "pitroc",
    "pitrocului": "pitroc",
    "pitrocuri": "pitroc",
    "pitrocurile": "pitroc",
    "pitrocurilor": "pitroc",
    "pituitara": "pituitar",
    "pituitară": "pituitar",
    "pituitare": "pituitar",
    "pituitarei": "pituitar",
    "pituitarele": "pituitar",
    "pituitarelor": "pituitar",
    "pituitari": "pituitar",
    "pituitarii": "pituitar",
    "pituitarilor": "pituitar",
    "pituitarul": "pituitar",
    "pituitarului": "pituitar",
    "pituitiva": "pituitiv",
    "pituitivă": "pituitiv",
    "pituitive": "pituitiv",
    "pituitivei": "pituitiv",
    "pituitivele": "pituitiv",
    "pituitivelor": "pituitiv",
    "pituitivi": "pituitiv",
    "pituitivii": "pituitiv",
    "pituitivilor": "pituitiv",
    "pituitivul": "pituitiv",
    "pituitivului": "pituitiv",
    "pituitoare": "pituitor",
    "pituitoarea": "pituitor",
    "pituitoarei": "pituitor",
    "pituitoarele": "pituitor",
    "pituitoarelor": "pituitor",
    "pituitori": "pituitor",
    "pituitorii": "pituitor",
    "pituitorilor": "pituitor",
    "pituitorul": "pituitor",
    "pituitorului": "pituitor",
    "pituitoasa": "pituitos",
    "pituitoasă": "pituitos",
    "pituitoase": "pituitos",
    "pituitoasei": "pituitos",
    "pituitoasele": "pituitos",
    "pituitoaselor": "pituitos",
    "pituitoși": "pituitos",
    "pituitoșii": "pituitos",
    "pituitoșilor": "pituitos",
    "pituitosul": "pituitos",
    "pituitosului": "pituitos",
    "nemaipitulând": "pitula",
    "nemaipitulându": "pitula",
    "nepitulând": "pitula",
    "nepitulându": "pitula",
    "pitulă": "pitula",
    "pitulai": "pitula",
    "pitulam": "pitula",
    "pitulăm": "pitula",
    "pitulând": "pitula",
    "pitulându": "pitula",
    "pitulară": "pitula",
    "pitularăm": "pitula",
    "pitularăți": "pitula",
    "pitulase": "pitula",
    "pitulasem": "pitula",
    "pitulaseră": "pitula",
    "pitulaserăm": "pitula",
    "pitulaserăți": "pitula",
    "pitulaseși": "pitula",
    "pitulași": "pitula",
    "pitulat": "pitula",
    "pitulați": "pitula",
    "pitulau": "pitula",
    "pitulează": "pitula",
    "pitulez": "pitula",
    "pituleze": "pitula",
    "pitulezi": "pitula",
    "pitulată": "pitulat",
    "pitulate": "pitulat",
    "pitulați": "pitulat",
    "pitulicea": "pitulice",
    "pitulici": "pitulice",
    "pitulicii": "pitulice",
    "pitulicile": "pitulice",
    "pitulicilor": "pitulice",
    "piua": "piuă",
    "pive": "piuă",
    "pivei": "piuă",
    "pivele": "piuă",
    "pivelor": "piuă",
    "nemaipiuind": "piui",
    "nemaipiuindu": "piui",
    "nepiuind": "piui",
    "nepiuindu": "piui",
    "piuia": "piui",
    "piuiau": "piui",
    "piuie": "piui",
    "piuind": "piui",
    "piuindu": "piui",
    "piuiră": "piui",
    "piuise": "piui",
    "piuiseră": "piui",
    "piuit": "piui",
    "piuită": "piuit",
    "piuite": "piuit",
    "piuiți": "piuit",
    "piuitul": "piuit",
    "piuitului": "piuit",
    "piulița": "piuliță",
    "piulițe": "piuliță",
    "piuliței": "piuliță",
    "piulițele": "piuliță",
    "piulițelor": "piuliță",
    "pivnița": "pivniță",
    "pivnițe": "pivniță",
    "pivniței": "pivniță",
    "pivnițele": "pivniță",
    "pivnițelor": "pivniță",
    "pivoți": "pivot",
    "pivoții": "pivot",
    "pivoților": "pivot",
    "pivotul": "pivot",
    "pivotului": "pivot",
    "nemaipivotând": "pivota",
    "nemaipivotându": "pivota",
    "nepivotând": "pivota",
    "nepivotându": "pivota",
    "pivotă": "pivota",
    "pivotai": "pivota",
    "pivotam": "pivota",
    "pivotăm": "pivota",
    "pivotând": "pivota",
    "pivotându": "pivota",
    "pivotară": "pivota",
    "pivotarăm": "pivota",
    "pivotarăți": "pivota",
    "pivotase": "pivota",
    "pivotasem": "pivota",
    "pivotaseră": "pivota",
    "pivotaserăm": "pivota",
    "pivotaserăți": "pivota",
    "pivotaseși": "pivota",
    "pivotași": "pivota",
    "pivotat": "pivota",
    "pivotați": "pivota",
    "pivotau": "pivota",
    "pivotează": "pivota",
    "pivotez": "pivota",
    "pivoteze": "pivota",
    "pivotezi": "pivota",
    "pivotanta": "pivotant",
    "pivotantă": "pivotant",
    "pivotante": "pivotant",
    "pivotantei": "pivotant",
    "pivotantele": "pivotant",
    "pivotantelor": "pivotant",
    "pivotanți": "pivotant",
    "pivotanții": "pivotant",
    "pivotanților": "pivotant",
    "pivotantul": "pivotant",
    "pivotantului": "pivotant",
    "pivotată": "pivotat",
    "pivotate": "pivotat",
    "pivotați": "pivotat",
    "pixul": "pix",
    "pixului": "pix",
    "pixuri": "pix",
    "pixurile": "pix",
    "pixurilor": "pix",
    "pizma": "pizmă",
    "pizme": "pizmă",
    "pizmei": "pizmă",
    "pizmăreața": "pizmăreț",
    "pizmăreață": "pizmăreț",
    "pizmărețe": "pizmăreț",
    "pizmăreței": "pizmăreț",
    "pizmărețele": "pizmăreț",
    "pizmărețelor": "pizmăreț",
    "pizmăreți": "pizmăreț",
    "pizmăreții": "pizmăreț",
    "pizmăreților": "pizmăreț",
    "pizmărețul": "pizmăreț",
    "pizmărețului": "pizmăreț",
    "nemaipizmuind": "pizmui",
    "nemaipizmuindu": "pizmui",
    "nepizmuind": "pizmui",
    "nepizmuindu": "pizmui",
    "pizmuia": "pizmui",
    "pizmuiai": "pizmui",
    "pizmuiam": "pizmui",
    "pizmuiască": "pizmui",
    "pizmuiați": "pizmui",
    "pizmuiau": "pizmui",
    "pizmuiesc": "pizmui",
    "pizmuiește": "pizmui",
    "pizmuiești": "pizmui",
    "pizmuii": "pizmui",
    "pizmuim": "pizmui",
    "pizmuind": "pizmui",
    "pizmuindu": "pizmui",
    "pizmuiră": "pizmui",
    "pizmuirăm": "pizmui",
    "pizmuirăți": "pizmui",
    "pizmuise": "pizmui",
    "pizmuisem": "pizmui",
    "pizmuiseră": "pizmui",
    "pizmuiserăm": "pizmui",
    "pizmuiserăți": "pizmui",
    "pizmuiseși": "pizmui",
    "pizmuiși": "pizmui",
    "pizmuit": "pizmui",
    "pizmuiți": "pizmui",
    "pizmuită": "pizmuit",
    "pizmuite": "pizmuit",
    "pizmuiți": "pizmuit",
    "pizmuitoare": "pizmuitor",
    "pizmuitoarea": "pizmuitor",
    "pizmuitoarei": "pizmuitor",
    "pizmuitoarele": "pizmuitor",
    "pizmuitoarelor": "pizmuitor",
    "pizmuitori": "pizmuitor",
    "pizmuitorii": "pizmuitor",
    "pizmuitorilor": "pizmuitor",
    "pizmuitorul": "pizmuitor",
    "pizmuitorului": "pizmuitor",
    "placul": "plac",
    "placului": "plac",
    "nemaiplacând": "placa",
    "nemaiplacându": "placa",
    "neplacând": "placa",
    "neplacându": "placa",
    "placă": "placa",
    "placai": "placa",
    "placam": "placa",
    "placăm": "placa",
    "placând": "placa",
    "placându": "placa",
    "placară": "placa",
    "placarăm": "placa",
    "placarăți": "placa",
    "placase": "placa",
    "placasem": "placa",
    "placaseră": "placa",
    "placaserăm": "placa",
    "placaserăți": "placa",
    "placaseși": "placa",
    "placași": "placa",
    "placat": "placa",
    "placați": "placa",
    "placau": "placa",
    "plachează": "placa",
    "plachez": "placa",
    "placheze": "placa",
    "plachezi": "placa",
    "placa": "placă",
    "plăci": "placă",
    "plăcii": "placă",
    "plăcile": "placă",
    "plăcilor": "placă",
    "placaje": "placaj",
    "placajele": "placaj",
    "placajelor": "placaj",
    "placajul": "placaj",
    "placajului": "placaj",
    "placată": "placat",
    "placate": "placat",
    "placați": "placat",
    "nemaiplăcând": "plăcea",
    "nemaiplăcându": "plăcea",
    "neplăcând": "plăcea",
    "neplăcându": "plăcea",
    "plac": "plăcea",
    "placă": "plăcea",
    "plăcând": "plăcea",
    "plăcându": "plăcea",
    "place": "plăcea",
    "plăceai": "plăcea",
    "plăceam": "plăcea",
    "plăceați": "plăcea",
    "plăceau": "plăcea",
    "plăcem": "plăcea",
    "plăceți": "plăcea",
    "placi": "plăcea",
    "plăcu": "plăcea",
    "plăcui": "plăcea",
    "plăcură": "plăcea",
    "plăcurăm": "plăcea",
    "plăcurăți": "plăcea",
    "plăcuse": "plăcea",
    "plăcusem": "plăcea",
    "plăcuseră": "plăcea",
    "plăcuserăm": "plăcea",
    "plăcuserăți": "plăcea",
    "plăcuseși": "plăcea",
    "plăcuși": "plăcea",
    "plăcut": "plăcea",
    "placenta": "placentă",
    "placente": "placentă",
    "placentei": "placentă",
    "placentele": "placentă",
    "placentelor": "placentă",
    "placentara": "placentar",
    "placentară": "placentar",
    "placentare": "placentar",
    "placentarei": "placentar",
    "placentarele": "placentar",
    "placentarelor": "placentar",
    "placentari": "placentar",
    "placentarii": "placentar",
    "placentarilor": "placentar",
    "placentarul": "placentar",
    "placentarului": "placentar",
    "plăcerea": "plăcere",
    "plăceri": "plăcere",
    "plăcerii": "plăcere",
    "plăcerile": "plăcere",
    "plăcerilor": "plăcere",
    "placheta": "plachetă",
    "plachete": "plachetă",
    "plachetei": "plachetă",
    "plachetele": "plachetă",
    "plachetelor": "plachetă",
    "placheul": "placheu",
    "placheului": "placheu",
    "placheuri": "placheu",
    "placheurile": "placheu",
    "placheurilor": "placheu",
    "plachia": "plachie",
    "plachiei": "plachie",
    "plachii": "plachie",
    "plachiile": "plachie",
    "plachiilor": "plachie",
    "placida": "placid",
    "placidă": "placid",
    "placide": "placid",
    "placidei": "placid",
    "placidele": "placid",
    "placidelor": "placid",
    "placidul": "placid",
    "placidului": "placid",
    "placizi": "placid",
    "placizii": "placid",
    "placizilor": "placid",
    "placiditatea": "placiditate",
    "placidități": "placiditate",
    "placidității": "placiditate",
    "placiditățile": "placiditate",
    "placidităților": "placiditate",
    "plăcinta": "plăcintă",
    "plăcinte": "plăcintă",
    "plăcintei": "plăcintă",
    "plăcintele": "plăcintă",
    "plăcintelor": "plăcintă",
    "plăcuta": "plăcut",
    "plăcută": "plăcut",
    "plăcute": "plăcut",
    "plăcutei": "plăcut",
    "plăcutele": "plăcut",
    "plăcutelor": "plăcut",
    "plăcuți": "plăcut",
    "plăcuții": "plăcut",
    "plăcuților": "plăcut",
    "plăcutul": "plăcut",
    "plăcutului": "plăcut",
    "plafoane": "plafon",
    "plafoanele": "plafon",
    "plafoanelor": "plafon",
    "plafonul": "plafon",
    "plafonului": "plafon",
    "nemaiplafonând": "plafona",
    "nemaiplafonându": "plafona",
    "neplafonând": "plafona",
    "neplafonându": "plafona",
    "plafonă": "plafona",
    "plafonai": "plafona",
    "plafonam": "plafona",
    "plafonăm": "plafona",
    "plafonând": "plafona",
    "plafonându": "plafona",
    "plafonară": "plafona",
    "plafonarăm": "plafona",
    "plafonarăți": "plafona",
    "plafonase": "plafona",
    "plafonasem": "plafona",
    "plafonaseră": "plafona",
    "plafonaserăm": "plafona",
    "plafonaserăți": "plafona",
    "plafonaseși": "plafona",
    "plafonași": "plafona",
    "plafonat": "plafona",
    "plafonați": "plafona",
    "plafonau": "plafona",
    "plafonează": "plafona",
    "plafonez": "plafona",
    "plafoneze": "plafona",
    "plafonezi": "plafona",
    "plafonată": "plafonat",
    "plafonate": "plafonat",
    "plafonați": "plafonat",
    "plaga": "plagă",
    "plăgi": "plagă",
    "plăgii": "plagă",
    "plăgile": "plagă",
    "plăgilor": "plagă",
    "nemaiplagiind": "plagia",
    "nemaiplagiindu": "plagia",
    "neplagiind": "plagia",
    "neplagiindu": "plagia",
    "plagiai": "plagia",
    "plagiam": "plagia",
    "plagiară": "plagia",
    "plagiarăm": "plagia",
    "plagiarăți": "plagia",
    "plagiase": "plagia",
    "plagiasem": "plagia",
    "plagiaseră": "plagia",
    "plagiaserăm": "plagia",
    "plagiaserăți": "plagia",
    "plagiaseși": "plagia",
    "plagiași": "plagia",
    "plagiat": "plagia",
    "plagiați": "plagia",
    "plagiau": "plagia",
    "plagiază": "plagia",
    "plagie": "plagia",
    "plagiem": "plagia",
    "plagiez": "plagia",
    "plagieze": "plagia",
    "plagiezi": "plagia",
    "plagiind": "plagia",
    "plagiindu": "plagia",
    "plagiată": "plagiat",
    "plagiate": "plagiat",
    "plagiatele": "plagiat",
    "plagiați": "plagiat",
    "plagiatul": "plagiat",
    "plagiatului": "plagiat",
    "plagiatorul": "plagiator",
    "plagiatorului": "plagiator",
    "plaiul": "plai",
    "plaiului": "plai",
    "plaiuri": "plai",
    "plaiurile": "plai",
    "plaiurilor": "plai",
    "plăieși": "plăieș",
    "plăieșii": "plăieș",
    "plăieșilor": "plăieș",
    "plăieșul": "plăieș",
    "plăieșului": "plăieș",
    "plaja": "plajă",
    "plaje": "plajă",
    "plajei": "plajă",
    "plajele": "plajă",
    "plajelor": "plajă",
    "plămada": "plămadă",
    "plămezi": "plămadă",
    "plămezii": "plămadă",
    "plămădeala": "plămădeală",
    "plămădeli": "plămădeală",
    "plămădelii": "plămădeală",
    "plămădelile": "plămădeală",
    "plămădelilor": "plămădeală",
    "nemaiplămădind": "plămădi",
    "nemaiplămădindu": "plămădi",
    "neplămădind": "plămădi",
    "neplămădindu": "plămădi",
    "plămădea": "plămădi",
    "plămădeai": "plămădi",
    "plămădeam": "plămădi",
    "plămădească": "plămădi",
    "plămădeați": "plămădi",
    "plămădeau": "plămădi",
    "plămădesc": "plămădi",
    "plămădește": "plămădi",
    "plămădești": "plămădi",
    "plămădii": "plămădi",
    "plămădim": "plămădi",
    "plămădind": "plămădi",
    "plămădindu": "plămădi",
    "plămădiră": "plămădi",
    "plămădirăm": "plămădi",
    "plămădirăți": "plămădi",
    "plămădise": "plămădi",
    "plămădisem": "plămădi",
    "plămădiseră": "plămădi",
    "plămădiserăm": "plămădi",
    "plămădiserăți": "plămădi",
    "plămădiseși": "plămădi",
    "plămădiși": "plămădi",
    "plămădit": "plămădi",
    "plămădiți": "plămădi",
    "plămădită": "plămădit",
    "plămădite": "plămădit",
    "plămădiți": "plămădit",
    "plămâni": "plămân",
    "plămânii": "plămân",
    "plămânilor": "plămân",
    "plămânul": "plămân",
    "plămânului": "plămân",
    "plana": "plan",
    "plană": "plan",
    "plane": "plan",
    "planei": "plan",
    "planele": "plan",
    "planelor": "plan",
    "plani": "plan",
    "planii": "plan",
    "planilor": "plan",
    "planul": "plan",
    "planului": "plan",
    "planuri": "plan",
    "planurile": "plan",
    "planurilor": "plan",
    "nemaiplanând": "plana",
    "nemaiplanându": "plana",
    "neplanând": "plana",
    "neplanându": "plana",
    "plană": "plana",
    "planai": "plana",
    "planam": "plana",
    "planăm": "plana",
    "planând": "plana",
    "planându": "plana",
    "planară": "plana",
    "planarăm": "plana",
    "planarăți": "plana",
    "planase": "plana",
    "planasem": "plana",
    "planaseră": "plana",
    "planaserăm": "plana",
    "planaserăți": "plana",
    "planaseși": "plana",
    "planași": "plana",
    "planat": "plana",
    "planați": "plana",
    "planau": "plana",
    "planează": "plana",
    "planez": "plana",
    "planeze": "plana",
    "planezi": "plana",
    "planarea": "planare",
    "planări": "planare",
    "planării": "planare",
    "planările": "planare",
    "planărilor": "planare",
    "planată": "planat",
    "planate": "planat",
    "planați": "planat",
    "planctonul": "plancton",
    "planctonului": "plancton",
    "planctonofaga": "planctonofag",
    "planctonofagă": "planctonofag",
    "planctonofage": "planctonofag",
    "planctonofagei": "planctonofag",
    "planctonofagele": "planctonofag",
    "planctonofagelor": "planctonofag",
    "planctonofagi": "planctonofag",
    "planctonofagii": "planctonofag",
    "planctonofagilor": "planctonofag",
    "planctonofagul": "planctonofag",
    "planctonofagului": "planctonofag",
    "planeta": "planetă",
    "planete": "planetă",
    "planetei": "planetă",
    "planetele": "planetă",
    "planetelor": "planetă",
    "planetara": "planetar",
    "planetară": "planetar",
    "planetare": "planetar",
    "planetarei": "planetar",
    "planetarele": "planetar",
    "planetarelor": "planetar",
    "planetari": "planetar",
    "planetarii": "planetar",
    "planetarilor": "planetar",
    "planetarul": "planetar",
    "planetarului": "planetar",
    "planetare": "planetariu",
    "planetarele": "planetariu",
    "planetarelor": "planetariu",
    "planetariul": "planetariu",
    "planetariului": "planetariu",
    "plângăcioasa": "plângăcios",
    "plângăcioasă": "plângăcios",
    "plângăcioase": "plângăcios",
    "plângăcioasei": "plângăcios",
    "plângăcioasele": "plângăcios",
    "plângăcioaselor": "plângăcios",
    "plângăcioși": "plângăcios",
    "plângăcioșii": "plângăcios",
    "plângăcioșilor": "plângăcios",
    "plângăciosul": "plângăcios",
    "plângăciosului": "plângăcios",
    "plângăreața": "plângăreț",
    "plângăreață": "plângăreț",
    "plângărețe": "plângăreț",
    "plângăreței": "plângăreț",
    "plângărețele": "plângăreț",
    "plângărețelor": "plângăreț",
    "plângăreți": "plângăreț",
    "plângăreții": "plângăreț",
    "plângăreților": "plângăreț",
    "plângărețul": "plângăreț",
    "plângărețului": "plângăreț",
    "plângătoare": "plângător",
    "plângătoarea": "plângător",
    "plângătoarei": "plângător",
    "plângătoarele": "plângător",
    "plângătoarelor": "plângător",
    "plângători": "plângător",
    "plângătorii": "plângător",
    "plângătorilor": "plângător",
    "plângătorul": "plângător",
    "plângătorului": "plângător",
    "nemaiplângând": "plânge",
    "nemaiplângându": "plânge",
    "neplângând": "plânge",
    "neplângându": "plânge",
    "plâng": "plânge",
    "plângă": "plânge",
    "plângând": "plânge",
    "plângându": "plânge",
    "plângea": "plânge",
    "plângeai": "plânge",
    "plângeam": "plânge",
    "plângeați": "plânge",
    "plângeau": "plânge",
    "plângem": "plânge",
    "plângeți": "plânge",
    "plângi": "plânge",
    "plâns": "plânge",
    "plânse": "plânge",
    "plânsei": "plânge",
    "plânseră": "plânge",
    "plânserăm": "plânge",
    "plânserăți": "plânge",
    "plânsese": "plânge",
    "plânsesem": "plânge",
    "plânseseră": "plânge",
    "plânseserăm": "plânge",
    "plânseserăți": "plânge",
    "plânseseși": "plânge",
    "plânseși": "plânge",
    "plângerea": "plângere",
    "plângeri": "plângere",
    "plângerii": "plângere",
    "plângerile": "plângere",
    "plângerilor": "plângere",
    "planica": "planic",
    "planică": "planic",
    "planice": "planic",
    "planicei": "planic",
    "planicele": "planic",
    "planicelor": "planic",
    "planici": "planic",
    "planicii": "planic",
    "planicilor": "planic",
    "planicul": "planic",
    "planicului": "planic",
    "nemaiplanificând": "planifica",
    "nemaiplanificându": "planifica",
    "neplanificând": "planifica",
    "neplanificându": "planifica",
    "planific": "planifica",
    "planifică": "planifica",
    "planificai": "planifica",
    "planificam": "planifica",
    "planificăm": "planifica",
    "planificând": "planifica",
    "planificându": "planifica",
    "planificară": "planifica",
    "planificarăm": "planifica",
    "planificarăți": "planifica",
    "planificase": "planifica",
    "planificasem": "planifica",
    "planificaseră": "planifica",
    "planificaserăm": "planifica",
    "planificaserăți": "planifica",
    "planificaseși": "planifica",
    "planificași": "planifica",
    "planificat": "planifica",
    "planificați": "planifica",
    "planificau": "planifica",
    "planifice": "planifica",
    "planifici": "planifica",
    "planificarea": "planificare",
    "planificări": "planificare",
    "planificării": "planificare",
    "planificările": "planificare",
    "planificărilor": "planificare",
    "planificată": "planificat",
    "planificate": "planificat",
    "planificați": "planificat",
    "planificatoare": "planificator",
    "planificatoarea": "planificator",
    "planificatoarei": "planificator",
    "planificatoarele": "planificator",
    "planificatoarelor": "planificator",
    "planificatori": "planificator",
    "planificatorii": "planificator",
    "planificatorilor": "planificator",
    "planificatorul": "planificator",
    "planificatorului": "planificator",
    "planimetrica": "planimetric",
    "planimetrică": "planimetric",
    "planimetrice": "planimetric",
    "planimetricei": "planimetric",
    "planimetricele": "planimetric",
    "planimetricelor": "planimetric",
    "planimetrici": "planimetric",
    "planimetricii": "planimetric",
    "planimetricilor": "planimetric",
    "planimetricul": "planimetric",
    "planimetricului": "planimetric",
    "planisferica": "planisferic",
    "planisferică": "planisferic",
    "planisferice": "planisferic",
    "planisfericei": "planisferic",
    "planisfericele": "planisferic",
    "planisfericelor": "planisferic",
    "planisferici": "planisferic",
    "planisfericii": "planisferic",
    "planisfericilor": "planisferic",
    "planisfericul": "planisferic",
    "planisfericului": "planisferic",
    "planoare": "planor",
    "planoarele": "planor",
    "planoarelor": "planor",
    "planorul": "planor",
    "planorului": "planor",
    "plânsă": "plâns",
    "plânse": "plâns",
    "plânși": "plâns",
    "plânsul": "plâns",
    "plânsului": "plâns",
    "plânsuri": "plâns",
    "plânsurile": "plâns",
    "plânsurilor": "plâns",
    "planșa": "planșă",
    "planșe": "planșă",
    "planșei": "planșă",
    "planșele": "planșă",
    "planșelor": "planșă",
    "plânsete": "plânset",
    "plânsetele": "plânset",
    "plânsetelor": "plânset",
    "plânsetul": "plânset",
    "plânsetului": "plânset",
    "planșeta": "planșetă",
    "planșete": "planșetă",
    "planșetei": "planșetă",
    "planșetele": "planșetă",
    "planșetelor": "planșetă",
    "planșee": "planșeu",
    "planșeele": "planșeu",
    "planșeelor": "planșeu",
    "planșeul": "planșeu",
    "planșeului": "planșeu",
    "nemaiplantând": "planta",
    "nemaiplantându": "planta",
    "neplantând": "planta",
    "neplantându": "planta",
    "plantă": "planta",
    "plantai": "planta",
    "plantam": "planta",
    "plantăm": "planta",
    "plantând": "planta",
    "plantându": "planta",
    "plantară": "planta",
    "plantarăm": "planta",
    "plantarăți": "planta",
    "plantase": "planta",
    "plantasem": "planta",
    "plantaseră": "planta",
    "plantaserăm": "planta",
    "plantaserăți": "planta",
    "plantaseși": "planta",
    "plantași": "planta",
    "plantat": "planta",
    "plantați": "planta",
    "plantau": "planta",
    "plantează": "planta",
    "plantez": "planta",
    "planteze": "planta",
    "plantezi": "planta",
    "planta": "plantă",
    "plante": "plantă",
    "plantei": "plantă",
    "plantele": "plantă",
    "plantelor": "plantă",
    "plantara": "plantar",
    "plantară": "plantar",
    "plantare": "plantar",
    "plantarei": "plantar",
    "plantarele": "plantar",
    "plantarelor": "plantar",
    "plantari": "plantar",
    "plantarii": "plantar",
    "plantarilor": "plantar",
    "plantarul": "plantar",
    "plantarului": "plantar",
    "plantată": "plantat",
    "plantate": "plantat",
    "plantați": "plantat",
    "plantația": "plantație",
    "plantației": "plantație",
    "plantații": "plantație",
    "plantațiile": "plantație",
    "plantațiilor": "plantație",
    "plantigrada": "plantigrad",
    "plantigradă": "plantigrad",
    "plantigrade": "plantigrad",
    "plantigradei": "plantigrad",
    "plantigradele": "plantigrad",
    "plantigradelor": "plantigrad",
    "plantigradul": "plantigrad",
    "plantigradului": "plantigrad",
    "plantigrazi": "plantigrad",
    "plantigrazii": "plantigrad",
    "plantigrazilor": "plantigrad",
    "plantoane": "planton",
    "plantoanele": "planton",
    "plantoanelor": "planton",
    "plantonul": "planton",
    "plantonului": "planton",
    "planturoasa": "planturos",
    "planturoasă": "planturos",
    "planturoase": "planturos",
    "planturoasei": "planturos",
    "planturoasele": "planturos",
    "planturoaselor": "planturos",
    "planturoși": "planturos",
    "planturoșii": "planturos",
    "planturoșilor": "planturos",
    "planturosul": "planturos",
    "planturosului": "planturos",
    "nemaiplănuind": "plănui",
    "nemaiplănuindu": "plănui",
    "neplănuind": "plănui",
    "neplănuindu": "plănui",
    "plănuia": "plănui",
    "plănuiai": "plănui",
    "plănuiam": "plănui",
    "plănuiască": "plănui",
    "plănuiați": "plănui",
    "plănuiau": "plănui",
    "plănuiesc": "plănui",
    "plănuiește": "plănui",
    "plănuiești": "plănui",
    "plănuii": "plănui",
    "plănuim": "plănui",
    "plănuind": "plănui",
    "plănuindu": "plănui",
    "plănuiră": "plănui",
    "plănuirăm": "plănui",
    "plănuirăți": "plănui",
    "plănuise": "plănui",
    "plănuisem": "plănui",
    "plănuiseră": "plănui",
    "plănuiserăm": "plănui",
    "plănuiserăți": "plănui",
    "plănuiseși": "plănui",
    "plănuiși": "plănui",
    "plănuit": "plănui",
    "plănuiți": "plănui",
    "plănuită": "plănuit",
    "plănuite": "plănuit",
    "plănuiți": "plănuit",
    "PUZ": "Planul_Urbanistic_Zonal",
    "plăpânda": "plăpând",
    "plăpândă": "plăpând",
    "plăpânde": "plăpând",
    "plăpândei": "plăpând",
    "plăpândele": "plăpând",
    "plăpândelor": "plăpând",
    "plăpândul": "plăpând",
    "plăpândului": "plăpând",
    "plăpânzi": "plăpând",
    "plăpânzii": "plăpând",
    "plăpânzilor": "plăpând",
    "plapuma": "plapumă",
    "plăpumi": "plapumă",
    "plăpumii": "plapumă",
    "plăpumile": "plapumă",
    "plăpumilor": "plapumă",
    "nemaiplasând": "plasa",
    "nemaiplasându": "plasa",
    "neplasând": "plasa",
    "neplasându": "plasa",
    "plasă": "plasa",
    "plasai": "plasa",
    "plasam": "plasa",
    "plasăm": "plasa",
    "plasând": "plasa",
    "plasându": "plasa",
    "plasară": "plasa",
    "plasarăm": "plasa",
    "plasarăți": "plasa",
    "plasase": "plasa",
    "plasasem": "plasa",
    "plasaseră": "plasa",
    "plasaserăm": "plasa",
    "plasaserăți": "plasa",
    "plasaseși": "plasa",
    "plasași": "plasa",
    "plasat": "plasa",
    "plasați": "plasa",
    "plasau": "plasa",
    "plasează": "plasa",
    "plasez": "plasa",
    "plaseze": "plasa",
    "plasezi": "plasa",
    "plasa": "plasă",
    "plase": "plasă",
    "plasei": "plasă",
    "plasele": "plasă",
    "plaselor": "plasă",
    "plasamente": "plasament",
    "plasamentele": "plasament",
    "plasamentelor": "plasament",
    "plasamentul": "plasament",
    "plasamentului": "plasament",
    "plasarea": "plasare",
    "plasări": "plasare",
    "plasării": "plasare",
    "plasările": "plasare",
    "plasărilor": "plasare",
    "plasată": "plasat",
    "plasate": "plasat",
    "plasați": "plasat",
    "plasatoarea": "plasatoare",
    "plasatoarei": "plasatoare",
    "plasatoarele": "plasatoare",
    "plasatoarelor": "plasatoare",
    "plasatori": "plasator",
    "plasatorii": "plasator",
    "plasatorilor": "plasator",
    "plasatorul": "plasator",
    "plasatorului": "plasator",
    "plasma": "plasmă",
    "plasme": "plasmă",
    "plasmei": "plasmă",
    "plasmele": "plasmă",
    "plasmelor": "plasmă",
    "plasmatica": "plasmatic",
    "plasmatică": "plasmatic",
    "plasmatice": "plasmatic",
    "plasmaticei": "plasmatic",
    "plasmaticele": "plasmatic",
    "plasmaticelor": "plasmatic",
    "plasmatici": "plasmatic",
    "plasmaticii": "plasmatic",
    "plasmaticilor": "plasmatic",
    "plasmaticul": "plasmatic",
    "plasmaticului": "plasmatic",
    "nemaiplăsmuind": "plăsmui",
    "nemaiplăsmuindu": "plăsmui",
    "neplăsmuind": "plăsmui",
    "neplăsmuindu": "plăsmui",
    "plăsmuia": "plăsmui",
    "plăsmuiai": "plăsmui",
    "plăsmuiam": "plăsmui",
    "plăsmuiască": "plăsmui",
    "plăsmuiați": "plăsmui",
    "plăsmuiau": "plăsmui",
    "plăsmuiesc": "plăsmui",
    "plăsmuiește": "plăsmui",
    "plăsmuiești": "plăsmui",
    "plăsmuii": "plăsmui",
    "plăsmuim": "plăsmui",
    "plăsmuind": "plăsmui",
    "plăsmuindu": "plăsmui",
    "plăsmuiră": "plăsmui",
    "plăsmuirăm": "plăsmui",
    "plăsmuirăți": "plăsmui",
    "plăsmuise": "plăsmui",
    "plăsmuisem": "plăsmui",
    "plăsmuiseră": "plăsmui",
    "plăsmuiserăm": "plăsmui",
    "plăsmuiserăți": "plăsmui",
    "plăsmuiseși": "plăsmui",
    "plăsmuiși": "plăsmui",
    "plăsmuit": "plăsmui",
    "plăsmuiți": "plăsmui",
    "plăsmuirea": "plăsmuire",
    "plăsmuiri": "plăsmuire",
    "plăsmuirii": "plăsmuire",
    "plăsmuirile": "plăsmuire",
    "plăsmuirilor": "plăsmuire",
    "plăsmuită": "plăsmuit",
    "plăsmuite": "plăsmuit",
    "plăsmuiți": "plăsmuit",
    "plăsmuitoare": "plăsmuitor",
    "plăsmuitoarea": "plăsmuitor",
    "plăsmuitoarei": "plăsmuitor",
    "plăsmuitoarele": "plăsmuitor",
    "plăsmuitoarelor": "plăsmuitor",
    "plăsmuitori": "plăsmuitor",
    "plăsmuitorii": "plăsmuitor",
    "plăsmuitorilor": "plăsmuitor",
    "plăsmuitorul": "plăsmuitor",
    "plăsmuitorului": "plăsmuitor",
    "plastica": "plastic",
    "plastică": "plastic",
    "plastice": "plastic",
    "plasticei": "plastic",
    "plasticele": "plastic",
    "plasticelor": "plastic",
    "plastici": "plastic",
    "plasticii": "plastic",
    "plasticilor": "plastic",
    "plasticul": "plastic",
    "plasticului": "plastic",
    "plastica": "plastică",
    "plastici": "plastică",
    "plasticii": "plastică",
    "plasticianul": "plastician",
    "plasticianului": "plastician",
    "plasticieni": "plastician",
    "plasticienii": "plastician",
    "plasticienilor": "plastician",
    "plasticitatea": "plasticitate",
    "plasticități": "plasticitate",
    "plasticității": "plasticitate",
    "nemaiplasticizând": "plasticiza",
    "nemaiplasticizându": "plasticiza",
    "neplasticizând": "plasticiza",
    "neplasticizându": "plasticiza",
    "plasticiză": "plasticiza",
    "plasticizai": "plasticiza",
    "plasticizam": "plasticiza",
    "plasticizăm": "plasticiza",
    "plasticizând": "plasticiza",
    "plasticizându": "plasticiza",
    "plasticizară": "plasticiza",
    "plasticizarăm": "plasticiza",
    "plasticizarăți": "plasticiza",
    "plasticizase": "plasticiza",
    "plasticizasem": "plasticiza",
    "plasticizaseră": "plasticiza",
    "plasticizaserăm": "plasticiza",
    "plasticizaserăți": "plasticiza",
    "plasticizaseși": "plasticiza",
    "plasticizași": "plasticiza",
    "plasticizat": "plasticiza",
    "plasticizați": "plasticiza",
    "plasticizau": "plasticiza",
    "plasticizează": "plasticiza",
    "plasticizez": "plasticiza",
    "plasticizeze": "plasticiza",
    "plasticizezi": "plasticiza",
    "plasticizată": "plasticizat",
    "plasticizate": "plasticizat",
    "plasticizați": "plasticizat",
    "plastifierea": "plastifiere",
    "plastifieri": "plastifiere",
    "plastifierii": "plastifiere",
    "plastifierile": "plastifiere",
    "plastifierilor": "plastifiere",
    "plastilina": "plastilină",
    "plastiline": "plastilină",
    "plastilinei": "plastilină",
    "plastilinele": "plastilină",
    "plastilinelor": "plastilină",
    "plastografi": "plastograf",
    "plastografii": "plastograf",
    "plastografilor": "plastograf",
    "plastograful": "plastograf",
    "plastografului": "plastograf",
    "plastografa": "plastografă",
    "plastografe": "plastografă",
    "plastografei": "plastografă",
    "plastografele": "plastografă",
    "plastografelor": "plastografă",
    "nemaiplastografiind": "plastografia",
    "nemaiplastografiindu": "plastografia",
    "neplastografiind": "plastografia",
    "neplastografiindu": "plastografia",
    "plastografiai": "plastografia",
    "plastografiam": "plastografia",
    "plastografiară": "plastografia",
    "plastografiarăm": "plastografia",
    "plastografiarăți": "plastografia",
    "plastografiase": "plastografia",
    "plastografiasem": "plastografia",
    "plastografiaseră": "plastografia",
    "plastografiaserăm": "plastografia",
    "plastografiaserăți": "plastografia",
    "plastografiaseși": "plastografia",
    "plastografiași": "plastografia",
    "plastografiat": "plastografia",
    "plastografiați": "plastografia",
    "plastografiau": "plastografia",
    "plastografiază": "plastografia",
    "plastografie": "plastografia",
    "plastografiem": "plastografia",
    "plastografiez": "plastografia",
    "plastografieze": "plastografia",
    "plastografiezi": "plastografia",
    "plastografiind": "plastografia",
    "plastografiindu": "plastografia",
    "plastografiată": "plastografiat",
    "plastografiate": "plastografiat",
    "plastografiați": "plastografiat",
    "plastografia": "plastografie",
    "plastografiei": "plastografie",
    "plastografii": "plastografie",
    "plastografiile": "plastografie",
    "plastografiilor": "plastografie",
    "plastografierea": "plastografiere",
    "plastografieri": "plastografiere",
    "plastografierii": "plastografiere",
    "plastografierile": "plastografiere",
    "plastografierilor": "plastografiere",
    "plastroane": "plastron",
    "plastroanele": "plastron",
    "plastroanelor": "plastron",
    "plastronul": "plastron",
    "plastronului": "plastron",
    "plasturele": "plasture",
    "plasturelui": "plasture",
    "plasturi": "plasture",
    "plasturii": "plasture",
    "plasturilor": "plasture",
    "plata": "plat",
    "plată": "plat",
    "plate": "plat",
    "platei": "plat",
    "platele": "plat",
    "platelor": "plat",
    "plați": "plat",
    "plații": "plat",
    "plaților": "plat",
    "platul": "plat",
    "platului": "plat",
    "plata": "plată",
    "plăți": "plată",
    "plății": "plată",
    "plățile": "plată",
    "plăților": "plată",
    "platani": "platan",
    "platanii": "platan",
    "platanilor": "platan",
    "platanul": "platan",
    "platanului": "platan",
    "platbanda": "platbandă",
    "platbande": "platbandă",
    "platbandei": "platbandă",
    "platbandele": "platbandă",
    "platbandelor": "platbandă",
    "platforma": "platformă",
    "platforme": "platformă",
    "platformei": "platformă",
    "platformele": "platformă",
    "platformelor": "platformă",
    "nemaiplătind": "plăti",
    "nemaiplătindu": "plăti",
    "neplătind": "plăti",
    "neplătindu": "plăti",
    "plătea": "plăti",
    "plăteai": "plăti",
    "plăteam": "plăti",
    "plătească": "plăti",
    "plăteați": "plăti",
    "plăteau": "plăti",
    "plătesc": "plăti",
    "plătește": "plăti",
    "plătești": "plăti",
    "plătii": "plăti",
    "plătim": "plăti",
    "plătind": "plăti",
    "plătindu": "plăti",
    "plătiră": "plăti",
    "plătirăm": "plăti",
    "plătirăți": "plăti",
    "plătise": "plăti",
    "plătisem": "plăti",
    "plătiseră": "plăti",
    "plătiserăm": "plăti",
    "plătiserăți": "plăti",
    "plătiseși": "plăti",
    "plătiși": "plăti",
    "plătit": "plăti",
    "plătiți": "plăti",
    "plătibila": "plătibil",
    "plătibilă": "plătibil",
    "plătibile": "plătibil",
    "plătibilei": "plătibil",
    "plătibilele": "plătibil",
    "plătibilelor": "plătibil",
    "plătibili": "plătibil",
    "plătibilii": "plătibil",
    "plătibililor": "plătibil",
    "plătibilul": "plătibil",
    "plătibilului": "plătibil",
    "nemaiplatinând": "platina",
    "nemaiplatinându": "platina",
    "neplatinând": "platina",
    "neplatinându": "platina",
    "platină": "platina",
    "platinai": "platina",
    "platinam": "platina",
    "platinăm": "platina",
    "platinând": "platina",
    "platinându": "platina",
    "platinară": "platina",
    "platinarăm": "platina",
    "platinarăți": "platina",
    "platinase": "platina",
    "platinasem": "platina",
    "platinaseră": "platina",
    "platinaserăm": "platina",
    "platinaserăți": "platina",
    "platinaseși": "platina",
    "platinași": "platina",
    "platinat": "platina",
    "platinați": "platina",
    "platinau": "platina",
    "platinează": "platina",
    "platinez": "platina",
    "platineze": "platina",
    "platinezi": "platina",
    "platina": "platină",
    "platine": "platină",
    "platinei": "platină",
    "platinele": "platină",
    "platinelor": "platină",
    "Pt": "platină",
    "platinată": "platinat",
    "platinate": "platinat",
    "platinați": "platinat",
    "platinica": "platinic",
    "platinică": "platinic",
    "platinice": "platinic",
    "platinicei": "platinic",
    "platinicele": "platinic",
    "platinicelor": "platinic",
    "platinici": "platinic",
    "platinicii": "platinic",
    "platinicilor": "platinic",
    "platinicul": "platinic",
    "platinicului": "platinic",
    "platinifera": "platinifer",
    "platiniferă": "platinifer",
    "platinifere": "platinifer",
    "platiniferei": "platinifer",
    "platiniferele": "platinifer",
    "platiniferelor": "platinifer",
    "platiniferi": "platinifer",
    "platiniferii": "platinifer",
    "platiniferilor": "platinifer",
    "platiniferul": "platinifer",
    "platiniferului": "platinifer",
    "platinoasa": "platinos",
    "platinoasă": "platinos",
    "platinoase": "platinos",
    "platinoasei": "platinos",
    "platinoasele": "platinos",
    "platinoaselor": "platinos",
    "platinoși": "platinos",
    "platinoșii": "platinos",
    "platinoșilor": "platinos",
    "platinosul": "platinos",
    "platinosului": "platinos",
    "plătită": "plătit",
    "plătite": "plătit",
    "plătiți": "plătit",
    "plătitoare": "plătitor",
    "plătitoarea": "plătitor",
    "plătitoarei": "plătitor",
    "plătitoarele": "plătitor",
    "plătitoarelor": "plătitor",
    "plătitori": "plătitor",
    "plătitorii": "plătitor",
    "plătitorilor": "plătitor",
    "plătitorul": "plătitor",
    "plătitorului": "plătitor",
    "platnica": "platnic",
    "platnică": "platnic",
    "platnice": "platnic",
    "platnicei": "platnic",
    "platnicele": "platnic",
    "platnicelor": "platnic",
    "platnici": "platnic",
    "platnicii": "platnic",
    "platnicilor": "platnic",
    "platnicul": "platnic",
    "platnicului": "platnic",
    "platoniana": "platonian",
    "platoniană": "platonian",
    "platonianul": "platonian",
    "platonianului": "platonian",
    "platoniene": "platonian",
    "platonienei": "platonian",
    "platonienele": "platonian",
    "platonienelor": "platonian",
    "platonieni": "platonian",
    "platonienii": "platonian",
    "platonienilor": "platonian",
    "platonica": "platonic",
    "platonică": "platonic",
    "platonice": "platonic",
    "platonicei": "platonic",
    "platonicele": "platonic",
    "platonicelor": "platonic",
    "platonici": "platonic",
    "platonicii": "platonic",
    "platonicilor": "platonic",
    "platonicul": "platonic",
    "platonicului": "platonic",
    "platoniciana": "platonician",
    "platoniciană": "platonician",
    "platonicianul": "platonician",
    "platonicianului": "platonician",
    "platoniciene": "platonician",
    "platonicienei": "platonician",
    "platonicienele": "platonician",
    "platonicienelor": "platonician",
    "platonicieni": "platonician",
    "platonicienii": "platonician",
    "platonicienilor": "platonician",
    "platonismul": "platonism",
    "platonismului": "platonism",
    "platonizanta": "platonizant",
    "platonizantă": "platonizant",
    "platonizante": "platonizant",
    "platonizantei": "platonizant",
    "platonizantele": "platonizant",
    "platonizantelor": "platonizant",
    "platonizanți": "platonizant",
    "platonizanții": "platonizant",
    "platonizanților": "platonizant",
    "platonizantul": "platonizant",
    "platonizantului": "platonizant",
    "platoșa": "platoșă",
    "platoșe": "platoșă",
    "platoșei": "platoșă",
    "platoșele": "platoșă",
    "platoșelor": "platoșă",
    "platoul": "platou",
    "platoului": "platou",
    "platouri": "platou",
    "platourile": "platou",
    "platourilor": "platou",
    "plauzibila": "plauzibil",
    "plauzibilă": "plauzibil",
    "plauzibile": "plauzibil",
    "plauzibilei": "plauzibil",
    "plauzibilele": "plauzibil",
    "plauzibilelor": "plauzibil",
    "plauzibili": "plauzibil",
    "plauzibilii": "plauzibil",
    "plauzibililor": "plauzibil",
    "plauzibilul": "plauzibil",
    "plauzibilului": "plauzibil",
    "plăvaia": "plăvai",
    "plăvaie": "plăvai",
    "plăvaiei": "plăvai",
    "plăvaiele": "plăvai",
    "plăvaielor": "plăvai",
    "plăvaii": "plăvai",
    "plăvailor": "plăvai",
    "plăvaiul": "plăvai",
    "plăvaiului": "plăvai",
    "plăvana": "plăvan",
    "plăvană": "plăvan",
    "plăvane": "plăvan",
    "plăvanei": "plăvan",
    "plăvanele": "plăvan",
    "plăvanelor": "plăvan",
    "plăvani": "plăvan",
    "plăvanii": "plăvan",
    "plăvanilor": "plăvan",
    "plăvanul": "plăvan",
    "plăvanului": "plăvan",
    "plăvița": "plăviț",
    "plăviță": "plăviț",
    "plăvițe": "plăviț",
    "plăviței": "plăviț",
    "plăvițele": "plăviț",
    "plăvițelor": "plăviț",
    "plăviți": "plăviț",
    "plăviții": "plăviț",
    "plăviților": "plăviț",
    "plăvițul": "plăviț",
    "plăvițului": "plăviț",
    "plăvia": "plăviu",
    "plăvie": "plăviu",
    "plăviei": "plăviu",
    "plăvii": "plăviu",
    "plăviii": "plăviu",
    "plăviile": "plăviu",
    "plăviilor": "plăviu",
    "plăviul": "plăviu",
    "plăviului": "plăviu",
    "pleașca": "pleașcă",
    "pleata": "pleată",
    "plete": "pleată",
    "pletei": "pleată",
    "pletele": "pleată",
    "pletelor": "pleată",
    "pleava": "pleavă",
    "pleve": "pleavă",
    "plevei": "pleavă",
    "plebea": "plebe",
    "plebei": "plebe",
    "plebeiana": "plebeian",
    "plebeiană": "plebeian",
    "plebeianul": "plebeian",
    "plebeianului": "plebeian",
    "plebeiene": "plebeian",
    "plebeienei": "plebeian",
    "plebeienele": "plebeian",
    "plebeienelor": "plebeian",
    "plebeieni": "plebeian",
    "plebeienii": "plebeian",
    "plebeienilor": "plebeian",
    "plebea": "plebeu",
    "plebee": "plebeu",
    "plebeei": "plebeu",
    "plebeele": "plebeu",
    "plebeelor": "plebeu",
    "plebei": "plebeu",
    "plebeii": "plebeu",
    "plebeile": "plebeu",
    "plebeilor": "plebeu",
    "plebeul": "plebeu",
    "plebeului": "plebeu",
    "plebiscite": "plebiscit",
    "plebiscitele": "plebiscit",
    "plebiscitelor": "plebiscit",
    "plebiscitul": "plebiscit",
    "plebiscitului": "plebiscit",
    "plebiscitara": "plebiscitar",
    "plebiscitară": "plebiscitar",
    "plebiscitare": "plebiscitar",
    "plebiscitarei": "plebiscitar",
    "plebiscitarele": "plebiscitar",
    "plebiscitarelor": "plebiscitar",
    "plebiscitari": "plebiscitar",
    "plebiscitarii": "plebiscitar",
    "plebiscitarilor": "plebiscitar",
    "plebiscitarul": "plebiscitar",
    "plebiscitarului": "plebiscitar",
    "nemaiplecând": "pleca",
    "nemaiplecându": "pleca",
    "neplecând": "pleca",
    "neplecându": "pleca",
    "pleacă": "pleca",
    "plec": "pleca",
    "plecă": "pleca",
    "plecai": "pleca",
    "plecam": "pleca",
    "plecăm": "pleca",
    "plecând": "pleca",
    "plecându": "pleca",
    "plecară": "pleca",
    "plecarăm": "pleca",
    "plecarăți": "pleca",
    "plecase": "pleca",
    "plecasem": "pleca",
    "plecaseră": "pleca",
    "plecaserăm": "pleca",
    "plecaserăți": "pleca",
    "plecaseși": "pleca",
    "plecași": "pleca",
    "plecat": "pleca",
    "plecați": "pleca",
    "plecau": "pleca",
    "plece": "pleca",
    "pleci": "pleca",
    "plecăciunea": "plecăciune",
    "plecăciuni": "plecăciune",
    "plecăciunii": "plecăciune",
    "plecăciunile": "plecăciune",
    "plecăciunilor": "plecăciune",
    "plecarea": "plecare",
    "plecări": "plecare",
    "plecării": "plecare",
    "plecările": "plecare",
    "plecărilor": "plecare",
    "plecată": "plecat",
    "plecate": "plecat",
    "plecați": "plecat",
    "plectre": "plectru",
    "plectrele": "plectru",
    "plectrelor": "plectru",
    "plectrul": "plectru",
    "plectrului": "plectru",
    "pledul": "pled",
    "pledului": "pled",
    "pleduri": "pled",
    "pledurile": "pled",
    "pledurilor": "pled",
    "nemaipledând": "pleda",
    "nemaipledându": "pleda",
    "nepledând": "pleda",
    "nepledându": "pleda",
    "pledă": "pleda",
    "pledai": "pleda",
    "pledam": "pleda",
    "pledăm": "pleda",
    "pledând": "pleda",
    "pledându": "pleda",
    "pledară": "pleda",
    "pledarăm": "pleda",
    "pledarăți": "pleda",
    "pledase": "pleda",
    "pledasem": "pleda",
    "pledaseră": "pleda",
    "pledaserăm": "pleda",
    "pledaserăți": "pleda",
    "pledaseși": "pleda",
    "pledași": "pleda",
    "pledat": "pleda",
    "pledați": "pleda",
    "pledau": "pleda",
    "pledează": "pleda",
    "pledez": "pleda",
    "pledeze": "pleda",
    "pledezi": "pleda",
    "pledanta": "pledant",
    "pledantă": "pledant",
    "pledante": "pledant",
    "pledantei": "pledant",
    "pledantele": "pledant",
    "pledantelor": "pledant",
    "pledanți": "pledant",
    "pledanții": "pledant",
    "pledanților": "pledant",
    "pledantul": "pledant",
    "pledantului": "pledant",
    "pledată": "pledat",
    "pledate": "pledat",
    "pledați": "pledat",
    "pledoaria": "pledoarie",
    "pledoariei": "pledoarie",
    "pledoarii": "pledoarie",
    "pledoariile": "pledoarie",
    "pledoariilor": "pledoarie",
    "pleiada": "pleiadă",
    "pleiade": "pleiadă",
    "pleiadei": "pleiadă",
    "pleiadele": "pleiadă",
    "pleiadelor": "pleiadă",
    "pleistocena": "pleistocen",
    "pleistocenă": "pleistocen",
    "pleistocene": "pleistocen",
    "pleistocenei": "pleistocen",
    "pleistocenele": "pleistocen",
    "pleistocenelor": "pleistocen",
    "pleistoceni": "pleistocen",
    "pleistocenii": "pleistocen",
    "pleistocenilor": "pleistocen",
    "pleistocenul": "pleistocen",
    "pleistocenului": "pleistocen",
    "plenul": "plen",
    "plenului": "plen",
    "plenuri": "plen",
    "plenurile": "plen",
    "plenurilor": "plen",
    "plenara": "plenar",
    "plenară": "plenar",
    "plenare": "plenar",
    "plenarei": "plenar",
    "plenarele": "plenar",
    "plenarelor": "plenar",
    "plenari": "plenar",
    "plenarii": "plenar",
    "plenarilor": "plenar",
    "plenarul": "plenar",
    "plenarului": "plenar",
    "plenipotenta": "plenipotent",
    "plenipotentă": "plenipotent",
    "plenipotente": "plenipotent",
    "plenipotentei": "plenipotent",
    "plenipotentele": "plenipotent",
    "plenipotentelor": "plenipotent",
    "plenipotenți": "plenipotent",
    "plenipotenții": "plenipotent",
    "plenipotenților": "plenipotent",
    "plenipotentul": "plenipotent",
    "plenipotentului": "plenipotent",
    "plenipotența": "plenipotență",
    "plenipotențe": "plenipotență",
    "plenipotenței": "plenipotență",
    "plenipotențele": "plenipotență",
    "plenipotențelor": "plenipotență",
    "plenipotențiara": "plenipotențiar",
    "plenipotențiară": "plenipotențiar",
    "plenipotențiare": "plenipotențiar",
    "plenipotențiarei": "plenipotențiar",
    "plenipotențiarele": "plenipotențiar",
    "plenipotențiarelor": "plenipotențiar",
    "plenipotențiari": "plenipotențiar",
    "plenipotențiarii": "plenipotențiar",
    "plenipotențiarilor": "plenipotențiar",
    "plenipotențiarul": "plenipotențiar",
    "plenipotențiarului": "plenipotențiar",
    "plenisona": "plenison",
    "plenisonă": "plenison",
    "plenisone": "plenison",
    "plenisonei": "plenison",
    "plenisonele": "plenison",
    "plenisonelor": "plenison",
    "plenisoni": "plenison",
    "plenisonii": "plenison",
    "plenisonilor": "plenison",
    "plenisonul": "plenison",
    "plenisonului": "plenison",
    "plenitudinea": "plenitudine",
    "plenitudini": "plenitudine",
    "plenitudinii": "plenitudine",
    "pleoapa": "pleoapă",
    "pleoape": "pleoapă",
    "pleoapei": "pleoapă",
    "pleoapele": "pleoapă",
    "pleoapelor": "pleoapă",
    "pleonasme": "pleonasm",
    "pleonasmele": "pleonasm",
    "pleonasmelor": "pleonasm",
    "pleonasmul": "pleonasm",
    "pleonasmului": "pleonasm",
    "pleonastica": "pleonastic",
    "pleonastică": "pleonastic",
    "pleonastice": "pleonastic",
    "pleonasticei": "pleonastic",
    "pleonasticele": "pleonastic",
    "pleonasticelor": "pleonastic",
    "pleonastici": "pleonastic",
    "pleonasticii": "pleonastic",
    "pleonasticilor": "pleonastic",
    "pleonasticul": "pleonastic",
    "pleonasticului": "pleonastic",
    "nemaipleoscăind": "pleoscăi",
    "nemaipleoscăindu": "pleoscăi",
    "nepleoscăind": "pleoscăi",
    "nepleoscăindu": "pleoscăi",
    "pleoscăia": "pleoscăi",
    "pleoscăiai": "pleoscăi",
    "pleoscăiam": "pleoscăi",
    "pleoscăiați": "pleoscăi",
    "pleoscăiau": "pleoscăi",
    "pleoscăie": "pleoscăi",
    "pleoscăii": "pleoscăi",
    "pleoscăim": "pleoscăi",
    "pleoscăind": "pleoscăi",
    "pleoscăindu": "pleoscăi",
    "pleoscăiră": "pleoscăi",
    "pleoscăirăm": "pleoscăi",
    "pleoscăirăți": "pleoscăi",
    "pleoscăise": "pleoscăi",
    "pleoscăisem": "pleoscăi",
    "pleoscăiseră": "pleoscăi",
    "pleoscăiserăm": "pleoscăi",
    "pleoscăiserăți": "pleoscăi",
    "pleoscăiseși": "pleoscăi",
    "pleoscăiși": "pleoscăi",
    "pleoscăit": "pleoscăi",
    "pleoscăiți": "pleoscăi",
    "pleoscăită": "pleoscăit",
    "pleoscăite": "pleoscăit",
    "pleoscăiți": "pleoscăit",
    "pleoscăitul": "pleoscăit",
    "pleoscăitului": "pleoscăit",
    "pleoscăituri": "pleoscăit",
    "pleoscăiturile": "pleoscăit",
    "pleoscăiturilor": "pleoscăit",
    "nemaipleoștind": "pleoști",
    "nemaipleoștindu": "pleoști",
    "nepleoștind": "pleoști",
    "nepleoștindu": "pleoști",
    "pleoștea": "pleoști",
    "pleoșteai": "pleoști",
    "pleoșteam": "pleoști",
    "pleoștească": "pleoști",
    "pleoșteați": "pleoști",
    "pleoșteau": "pleoști",
    "pleoștesc": "pleoști",
    "pleoștește": "pleoști",
    "pleoștești": "pleoști",
    "pleoștii": "pleoști",
    "pleoștim": "pleoști",
    "pleoștind": "pleoști",
    "pleoștindu": "pleoști",
    "pleoștiră": "pleoști",
    "pleoștirăm": "pleoști",
    "pleoștirăți": "pleoști",
    "pleoștise": "pleoști",
    "pleoștisem": "pleoști",
    "pleoștiseră": "pleoști",
    "pleoștiserăm": "pleoști",
    "pleoștiserăți": "pleoști",
    "pleoștiseși": "pleoști",
    "pleoștiși": "pleoști",
    "pleoștit": "pleoști",
    "pleoștiți": "pleoști",
    "pleoștită": "pleoștit",
    "pleoștite": "pleoștit",
    "pleoștiți": "pleoștit",
    "pleșa": "pleș",
    "pleșă": "pleș",
    "pleșe": "pleș",
    "pleșei": "pleș",
    "pleșele": "pleș",
    "pleșelor": "pleș",
    "pleși": "pleș",
    "pleșii": "pleș",
    "pleșilor": "pleș",
    "pleșul": "pleș",
    "pleșului": "pleș",
    "nemaiplescăind": "plescăi",
    "nemaiplescăindu": "plescăi",
    "neplescăind": "plescăi",
    "neplescăindu": "plescăi",
    "plescăia": "plescăi",
    "plescăiai": "plescăi",
    "plescăiam": "plescăi",
    "plescăiați": "plescăi",
    "plescăiau": "plescăi",
    "plescăie": "plescăi",
    "plescăii": "plescăi",
    "plescăim": "plescăi",
    "plescăind": "plescăi",
    "plescăindu": "plescăi",
    "plescăiră": "plescăi",
    "plescăirăm": "plescăi",
    "plescăirăți": "plescăi",
    "plescăise": "plescăi",
    "plescăisem": "plescăi",
    "plescăiseră": "plescăi",
    "plescăiserăm": "plescăi",
    "plescăiserăți": "plescăi",
    "plescăiseși": "plescăi",
    "plescăiși": "plescăi",
    "plescăit": "plescăi",
    "plescăiți": "plescăi",
    "plescăită": "plescăit",
    "plescăite": "plescăit",
    "plescăiți": "plescăit",
    "plescăitura": "plescăitură",
    "plescăituri": "plescăitură",
    "plescăiturii": "plescăitură",
    "plescăiturile": "plescăitură",
    "plescăiturilor": "plescăitură",
    "plesnete": "plesnet",
    "plesnetele": "plesnet",
    "plesnetelor": "plesnet",
    "plesnetul": "plesnet",
    "plesnetului": "plesnet",
    "nemaiplesnind": "plesni",
    "nemaiplesnindu": "plesni",
    "neplesnind": "plesni",
    "neplesnindu": "plesni",
    "plesnea": "plesni",
    "plesneai": "plesni",
    "plesneam": "plesni",
    "plesnească": "plesni",
    "plesneați": "plesni",
    "plesneau": "plesni",
    "plesnesc": "plesni",
    "plesnește": "plesni",
    "plesnești": "plesni",
    "plesnii": "plesni",
    "plesnim": "plesni",
    "plesnind": "plesni",
    "plesnindu": "plesni",
    "plesniră": "plesni",
    "plesnirăm": "plesni",
    "plesnirăți": "plesni",
    "plesnise": "plesni",
    "plesnisem": "plesni",
    "plesniseră": "plesni",
    "plesniserăm": "plesni",
    "plesniserăți": "plesni",
    "plesniseși": "plesni",
    "plesniși": "plesni",
    "plesnit": "plesni",
    "plesniți": "plesni",
    "plesnită": "plesnit",
    "plesnite": "plesnit",
    "plesniți": "plesnit",
    "pleșuva": "pleșuv",
    "pleșuvă": "pleșuv",
    "pleșuve": "pleșuv",
    "pleșuvei": "pleșuv",
    "pleșuvele": "pleșuv",
    "pleșuvelor": "pleșuv",
    "pleșuvi": "pleșuv",
    "pleșuvii": "pleșuv",
    "pleșuvilor": "pleșuv",
    "pleșuvul": "pleșuv",
    "pleșuvului": "pleșuv",
    "nemaipleșuvind": "pleșuvi",
    "nemaipleșuvindu": "pleșuvi",
    "nepleșuvind": "pleșuvi",
    "nepleșuvindu": "pleșuvi",
    "pleșuvea": "pleșuvi",
    "pleșuveai": "pleșuvi",
    "pleșuveam": "pleșuvi",
    "pleșuvească": "pleșuvi",
    "pleșuveați": "pleșuvi",
    "pleșuveau": "pleșuvi",
    "pleșuvesc": "pleșuvi",
    "pleșuvește": "pleșuvi",
    "pleșuvești": "pleșuvi",
    "pleșuvii": "pleșuvi",
    "pleșuvim": "pleșuvi",
    "pleșuvind": "pleșuvi",
    "pleșuvindu": "pleșuvi",
    "pleșuviră": "pleșuvi",
    "pleșuvirăm": "pleșuvi",
    "pleșuvirăți": "pleșuvi",
    "pleșuvise": "pleșuvi",
    "pleșuvisem": "pleșuvi",
    "pleșuviseră": "pleșuvi",
    "pleșuviserăm": "pleșuvi",
    "pleșuviserăți": "pleșuvi",
    "pleșuviseși": "pleșuvi",
    "pleșuviși": "pleșuvi",
    "pleșuvit": "pleșuvi",
    "pleșuviți": "pleșuvi",
    "pleșuvită": "pleșuvit",
    "pleșuvite": "pleșuvit",
    "pleșuviți": "pleșuvit",
    "pletorica": "pletoric",
    "pletorică": "pletoric",
    "pletorice": "pletoric",
    "pletoricei": "pletoric",
    "pletoricele": "pletoric",
    "pletoricelor": "pletoric",
    "pletorici": "pletoric",
    "pletoricii": "pletoric",
    "pletoricilor": "pletoric",
    "pletoricul": "pletoric",
    "pletoricului": "pletoric",
    "pletoasa": "pletos",
    "pletoasă": "pletos",
    "pletoase": "pletos",
    "pletoasei": "pletos",
    "pletoasele": "pletos",
    "pletoaselor": "pletos",
    "pletoși": "pletos",
    "pletoșii": "pletos",
    "pletoșilor": "pletos",
    "pletosul": "pletos",
    "pletosului": "pletos",
    "pleura": "pleură",
    "pleure": "pleură",
    "pleurei": "pleură",
    "pleurele": "pleură",
    "pleurelor": "pleură",
    "pleurala": "pleural",
    "pleurală": "pleural",
    "pleurale": "pleural",
    "pleuralei": "pleural",
    "pleuralele": "pleural",
    "pleuralelor": "pleural",
    "pleurali": "pleural",
    "pleuralii": "pleural",
    "pleuralilor": "pleural",
    "pleuralul": "pleural",
    "pleuralului": "pleural",
    "pleuritica": "pleuritic",
    "pleuritică": "pleuritic",
    "pleuritice": "pleuritic",
    "pleuriticei": "pleuritic",
    "pleuriticele": "pleuritic",
    "pleuriticelor": "pleuritic",
    "pleuritici": "pleuritic",
    "pleuriticii": "pleuritic",
    "pleuriticilor": "pleuritic",
    "pleuriticul": "pleuritic",
    "pleuriticului": "pleuritic",
    "Plevnei": "Plevna",
    "plexul": "plex",
    "plexului": "plex",
    "plexuri": "plex",
    "plexurile": "plex",
    "plexurilor": "plex",
    "pleznea": "plezni",
    "plezneai": "plezni",
    "plezneam": "plezni",
    "pleznească": "plezni",
    "plezneați": "plezni",
    "plezneau": "plezni",
    "pleznesc": "plezni",
    "pleznește": "plezni",
    "pleznești": "plezni",
    "pleznii": "plezni",
    "pleznim": "plezni",
    "pleznind": "plezni",
    "plezniră": "plezni",
    "pleznirăm": "plezni",
    "pleznirăți": "plezni",
    "pleznise": "plezni",
    "pleznisem": "plezni",
    "plezniseră": "plezni",
    "plezniserăm": "plezni",
    "plezniserăți": "plezni",
    "plezniseși": "plezni",
    "plezniși": "plezni",
    "pleznit": "plezni",
    "plezniți": "plezni",
    "pleznită": "pleznit",
    "pleznite": "pleznit",
    "plezniți": "pleznit",
    "nemaipliind": "plia",
    "nemaipliindu": "plia",
    "nepliind": "plia",
    "nepliindu": "plia",
    "pliai": "plia",
    "pliam": "plia",
    "pliară": "plia",
    "pliarăm": "plia",
    "pliarăți": "plia",
    "pliase": "plia",
    "pliasem": "plia",
    "pliaseră": "plia",
    "pliaserăm": "plia",
    "pliaserăți": "plia",
    "pliaseși": "plia",
    "pliași": "plia",
    "pliat": "plia",
    "pliați": "plia",
    "pliau": "plia",
    "pliază": "plia",
    "plie": "plia",
    "pliem": "plia",
    "pliez": "plia",
    "plieze": "plia",
    "pliezi": "plia",
    "pliind": "plia",
    "pliindu": "plia",
    "pliabila": "pliabil",
    "pliabilă": "pliabil",
    "pliabile": "pliabil",
    "pliabilei": "pliabil",
    "pliabilele": "pliabil",
    "pliabilelor": "pliabil",
    "pliabili": "pliabil",
    "pliabilii": "pliabil",
    "pliabililor": "pliabil",
    "pliabilul": "pliabil",
    "pliabilului": "pliabil",
    "plianta": "pliant",
    "pliantă": "pliant",
    "pliante": "pliant",
    "pliantei": "pliant",
    "pliantele": "pliant",
    "pliantelor": "pliant",
    "plianți": "pliant",
    "plianții": "pliant",
    "plianților": "pliant",
    "pliantul": "pliant",
    "pliantului": "pliant",
    "pliată": "pliat",
    "pliate": "pliat",
    "pliați": "pliat",
    "plicul": "plic",
    "plicului": "plic",
    "plicuri": "plic",
    "plicurile": "plic",
    "plicurilor": "plic",
    "plicticoasa": "plicticos",
    "plicticoasă": "plicticos",
    "plicticoase": "plicticos",
    "plicticoasei": "plicticos",
    "plicticoasele": "plicticos",
    "plicticoaselor": "plicticos",
    "plicticoși": "plicticos",
    "plicticoșii": "plicticos",
    "plicticoșilor": "plicticos",
    "plicticosul": "plicticos",
    "plicticosului": "plicticos",
    "plictiseala": "plictiseală",
    "plictiseli": "plictiseală",
    "plictiselii": "plictiseală",
    "plictiselile": "plictiseală",
    "plictiselilor": "plictiseală",
    "nemaiplictisind": "plictisi",
    "nemaiplictisindu": "plictisi",
    "neplictisind": "plictisi",
    "neplictisindu": "plictisi",
    "plictisea": "plictisi",
    "plictiseai": "plictisi",
    "plictiseam": "plictisi",
    "plictisească": "plictisi",
    "plictiseați": "plictisi",
    "plictiseau": "plictisi",
    "plictisesc": "plictisi",
    "plictisește": "plictisi",
    "plictisești": "plictisi",
    "plictisii": "plictisi",
    "plictisim": "plictisi",
    "plictisind": "plictisi",
    "plictisindu": "plictisi",
    "plictisiră": "plictisi",
    "plictisirăm": "plictisi",
    "plictisirăți": "plictisi",
    "plictisise": "plictisi",
    "plictisisem": "plictisi",
    "plictisiseră": "plictisi",
    "plictisiserăm": "plictisi",
    "plictisiserăți": "plictisi",
    "plictisiseși": "plictisi",
    "plictisiși": "plictisi",
    "plictisit": "plictisi",
    "plictisiți": "plictisi",
    "plictisită": "plictisit",
    "plictisite": "plictisit",
    "plictisiți": "plictisit",
    "plictisitoare": "plictisitor",
    "plictisitoarea": "plictisitor",
    "plictisitoarei": "plictisitor",
    "plictisitoarele": "plictisitor",
    "plictisitoarelor": "plictisitor",
    "plictisitori": "plictisitor",
    "plictisitorii": "plictisitor",
    "plictisitorilor": "plictisitor",
    "plictisitorul": "plictisitor",
    "plictisitorului": "plictisitor",
    "pliculețe": "pliculeț",
    "pliculețele": "pliculeț",
    "pliculețelor": "pliculeț",
    "pliculețul": "pliculeț",
    "pliculețului": "pliculeț",
    "nemaiplimbând": "plimba",
    "nemaiplimbându": "plimba",
    "neplimbând": "plimba",
    "neplimbându": "plimba",
    "plimb": "plimba",
    "plimbă": "plimba",
    "plimbai": "plimba",
    "plimbam": "plimba",
    "plimbăm": "plimba",
    "plimbând": "plimba",
    "plimbându": "plimba",
    "plimbară": "plimba",
    "plimbarăm": "plimba",
    "plimbarăți": "plimba",
    "plimbase": "plimba",
    "plimbasem": "plimba",
    "plimbaseră": "plimba",
    "plimbaserăm": "plimba",
    "plimbaserăți": "plimba",
    "plimbaseși": "plimba",
    "plimbași": "plimba",
    "plimbat": "plimba",
    "plimbați": "plimba",
    "plimbau": "plimba",
    "plimbe": "plimba",
    "plimbi": "plimba",
    "plimbarea": "plimbare",
    "plimbări": "plimbare",
    "plimbării": "plimbare",
    "plimbările": "plimbare",
    "plimbărilor": "plimbare",
    "plimbăreața": "plimbăreț",
    "plimbăreață": "plimbăreț",
    "plimbărețe": "plimbăreț",
    "plimbăreței": "plimbăreț",
    "plimbărețele": "plimbăreț",
    "plimbărețelor": "plimbăreț",
    "plimbăreți": "plimbăreț",
    "plimbăreții": "plimbăreț",
    "plimbăreților": "plimbăreț",
    "plimbărețul": "plimbăreț",
    "plimbărețului": "plimbăreț",
    "plimbată": "plimbat",
    "plimbate": "plimbat",
    "plimbați": "plimbat",
    "plina": "plin",
    "plină": "plin",
    "pline": "plin",
    "plinei": "plin",
    "plinele": "plin",
    "plinelor": "plin",
    "pline-ochi": "plin",
    "plini": "plin",
    "plinii": "plin",
    "plinilor": "plin",
    "plinul": "plin",
    "plinului": "plin",
    "plinuri": "plin",
    "plinurile": "plin",
    "plinurilor": "plin",
    "plinișoara": "plinișor",
    "plinișoară": "plinișor",
    "plinișoare": "plinișor",
    "plinișoarei": "plinișor",
    "plinișoarele": "plinișor",
    "plinișoarelor": "plinișor",
    "plinișori": "plinișor",
    "plinișorii": "plinișor",
    "plinișorilor": "plinișor",
    "plinișorul": "plinișor",
    "plinișorului": "plinișor",
    "plinta": "plintă",
    "plinte": "plintă",
    "plintei": "plintă",
    "plintele": "plintă",
    "plintelor": "plintă",
    "plinuța": "plinuț",
    "plinuță": "plinuț",
    "plinuțe": "plinuț",
    "plinuței": "plinuț",
    "plinuțele": "plinuț",
    "plinuțelor": "plinuț",
    "plinuți": "plinuț",
    "plinuții": "plinuț",
    "plinuților": "plinuț",
    "plinuțul": "plinuț",
    "plinuțului": "plinuț",
    "pliocena": "pliocen",
    "pliocenă": "pliocen",
    "pliocene": "pliocen",
    "pliocenei": "pliocen",
    "pliocenele": "pliocen",
    "pliocenelor": "pliocen",
    "plioceni": "pliocen",
    "pliocenii": "pliocen",
    "pliocenilor": "pliocen",
    "pliocenul": "pliocen",
    "pliocenului": "pliocen",
    "nemaiplisând": "plisa",
    "nemaiplisându": "plisa",
    "neplisând": "plisa",
    "neplisându": "plisa",
    "plisă": "plisa",
    "plisai": "plisa",
    "plisam": "plisa",
    "plisăm": "plisa",
    "plisând": "plisa",
    "plisându": "plisa",
    "plisară": "plisa",
    "plisarăm": "plisa",
    "plisarăți": "plisa",
    "plisase": "plisa",
    "plisasem": "plisa",
    "plisaseră": "plisa",
    "plisaserăm": "plisa",
    "plisaserăți": "plisa",
    "plisaseși": "plisa",
    "plisași": "plisa",
    "plisat": "plisa",
    "plisați": "plisa",
    "plisau": "plisa",
    "plisează": "plisa",
    "plisez": "plisa",
    "pliseze": "plisa",
    "plisezi": "plisa",
    "plisată": "plisat",
    "plisate": "plisat",
    "plisați": "plisat",
    "pliscul": "plisc",
    "pliscului": "plisc",
    "pliscuri": "plisc",
    "pliscurile": "plisc",
    "pliscurilor": "plisc",
    "plita": "plită",
    "plite": "plită",
    "plitei": "plită",
    "plitele": "plită",
    "plitelor": "plită",
    "pliul": "pliu",
    "pliului": "pliu",
    "pliuri": "pliu",
    "pliurile": "pliu",
    "pliurilor": "pliu",
    "pliurda": "pliurd",
    "pliurdă": "pliurd",
    "pliurde": "pliurd",
    "pliurdei": "pliurd",
    "pliurdele": "pliurd",
    "pliurdelor": "pliurd",
    "pliurdul": "pliurd",
    "pliurdului": "pliurd",
    "pliurzi": "pliurd",
    "pliurzii": "pliurd",
    "pliurzilor": "pliurd",
    "nemaiplivind": "plivi",
    "nemaiplivindu": "plivi",
    "neplivind": "plivi",
    "neplivindu": "plivi",
    "plivea": "plivi",
    "pliveai": "plivi",
    "pliveam": "plivi",
    "plivească": "plivi",
    "pliveați": "plivi",
    "pliveau": "plivi",
    "plivesc": "plivi",
    "plivește": "plivi",
    "plivești": "plivi",
    "plivii": "plivi",
    "plivim": "plivi",
    "plivind": "plivi",
    "plivindu": "plivi",
    "pliviră": "plivi",
    "plivirăm": "plivi",
    "plivirăți": "plivi",
    "plivise": "plivi",
    "plivisem": "plivi",
    "pliviseră": "plivi",
    "pliviserăm": "plivi",
    "pliviserăți": "plivi",
    "pliviseși": "plivi",
    "pliviși": "plivi",
    "plivit": "plivi",
    "pliviți": "plivi",
    "plivită": "plivit",
    "plivite": "plivit",
    "pliviți": "plivit",
    "ploaia": "ploaie",
    "ploi": "ploaie",
    "ploii": "ploaie",
    "ploile": "ploaie",
    "ploilor": "ploaie",
    "plocoane": "plocon",
    "plocoanele": "plocon",
    "plocoanelor": "plocon",
    "ploconul": "plocon",
    "ploconului": "plocon",
    "plodul": "plod",
    "plodului": "plod",
    "plozi": "plod",
    "plozii": "plod",
    "plozilor": "plod",
    "ploieșteana": "ploieștean",
    "ploieșteană": "ploieștean",
    "ploieșteanul": "ploieștean",
    "ploieșteanului": "ploieștean",
    "ploieștene": "ploieștean",
    "ploieștenei": "ploieștean",
    "ploieștenele": "ploieștean",
    "ploieștenelor": "ploieștean",
    "ploieșteni": "ploieștean",
    "ploieștenii": "ploieștean",
    "ploieștenilor": "ploieștean",
    "Ploieștiul": "Ploiești",
    "Ploieștiului": "Ploiești",
    "ploioasa": "ploios",
    "ploioasă": "ploios",
    "ploioase": "ploios",
    "ploioasei": "ploios",
    "ploioasele": "ploios",
    "ploioaselor": "ploios",
    "ploioși": "ploios",
    "ploioșii": "ploios",
    "ploioșilor": "ploios",
    "ploiosul": "ploios",
    "ploiosului": "ploios",
    "nemaiplombând": "plomba",
    "nemaiplombându": "plomba",
    "neplombând": "plomba",
    "neplombându": "plomba",
    "plombă": "plomba",
    "plombai": "plomba",
    "plombam": "plomba",
    "plombăm": "plomba",
    "plombând": "plomba",
    "plombându": "plomba",
    "plombară": "plomba",
    "plombarăm": "plomba",
    "plombarăți": "plomba",
    "plombase": "plomba",
    "plombasem": "plomba",
    "plombaseră": "plomba",
    "plombaserăm": "plomba",
    "plombaserăți": "plomba",
    "plombaseși": "plomba",
    "plombași": "plomba",
    "plombat": "plomba",
    "plombați": "plomba",
    "plombau": "plomba",
    "plombează": "plomba",
    "plombez": "plomba",
    "plombeze": "plomba",
    "plombezi": "plomba",
    "plomba": "plombă",
    "plombe": "plombă",
    "plombei": "plombă",
    "plombele": "plombă",
    "plombelor": "plombă",
    "plombată": "plombat",
    "plombate": "plombat",
    "plombați": "plombat",
    "nemaiplonjând": "plonja",
    "nemaiplonjându": "plonja",
    "neplonjând": "plonja",
    "neplonjându": "plonja",
    "plonjă": "plonja",
    "plonjai": "plonja",
    "plonjam": "plonja",
    "plonjăm": "plonja",
    "plonjând": "plonja",
    "plonjându": "plonja",
    "plonjară": "plonja",
    "plonjarăm": "plonja",
    "plonjarăți": "plonja",
    "plonjase": "plonja",
    "plonjasem": "plonja",
    "plonjaseră": "plonja",
    "plonjaserăm": "plonja",
    "plonjaserăți": "plonja",
    "plonjaseși": "plonja",
    "plonjași": "plonja",
    "plonjat": "plonja",
    "plonjați": "plonja",
    "plonjau": "plonja",
    "plonjează": "plonja",
    "plonjez": "plonja",
    "plonjeze": "plonja",
    "plonjezi": "plonja",
    "plonjată": "plonjat",
    "plonjate": "plonjat",
    "plonjați": "plonjat",
    "plonjoane": "plonjon",
    "plonjoanele": "plonjon",
    "plonjoanelor": "plonjon",
    "plonjonul": "plonjon",
    "plonjonului": "plonjon",
    "plopi": "plop",
    "plopii": "plop",
    "plopilor": "plop",
    "plopul": "plop",
    "plopului": "plop",
    "plosca": "ploscă",
    "ploști": "ploscă",
    "ploștii": "ploscă",
    "ploștile": "ploscă",
    "ploștilor": "ploscă",
    "ploșnița": "ploșniță",
    "ploșnițe": "ploșniță",
    "ploșniței": "ploșniță",
    "ploșnițele": "ploșniță",
    "ploșnițelor": "ploșniță",
    "plouă": "ploua",
    "plouând": "ploua",
    "plouase": "ploua",
    "plouat": "ploua",
    "plouată": "plouat",
    "plouate": "plouat",
    "plouați": "plouat",
    "plugul": "plug",
    "plugului": "plug",
    "pluguri": "plug",
    "plugurile": "plug",
    "plugurilor": "plug",
    "plugari": "plugar",
    "plugarii": "plugar",
    "plugarilor": "plugar",
    "plugarul": "plugar",
    "plugarului": "plugar",
    "plugăreasca": "plugăresc",
    "plugărească": "plugăresc",
    "plugărescul": "plugăresc",
    "plugărescului": "plugăresc",
    "plugărești": "plugăresc",
    "plugăreștii": "plugăresc",
    "plugăreștile": "plugăresc",
    "plugăreștilor": "plugăresc",
    "nemaiplugărind": "plugări",
    "nemaiplugărindu": "plugări",
    "neplugărind": "plugări",
    "neplugărindu": "plugări",
    "plugărea": "plugări",
    "plugăreai": "plugări",
    "plugăream": "plugări",
    "plugărească": "plugări",
    "plugăreați": "plugări",
    "plugăreau": "plugări",
    "plugăresc": "plugări",
    "plugărește": "plugări",
    "plugărești": "plugări",
    "plugării": "plugări",
    "plugărim": "plugări",
    "plugărind": "plugări",
    "plugărindu": "plugări",
    "plugăriră": "plugări",
    "plugărirăm": "plugări",
    "plugărirăți": "plugări",
    "plugărise": "plugări",
    "plugărisem": "plugări",
    "plugăriseră": "plugări",
    "plugăriserăm": "plugări",
    "plugăriserăți": "plugări",
    "plugăriseși": "plugări",
    "plugăriși": "plugări",
    "plugărit": "plugări",
    "plugăriți": "plugări",
    "plugărită": "plugărit",
    "plugărite": "plugărit",
    "plugăriți": "plugărit",
    "plugușoare": "plugușor",
    "plugușoarele": "plugușor",
    "plugușoarelor": "plugușor",
    "plugușorul": "plugușor",
    "plugușorului": "plugușor",
    "Pb": "plumb",
    "plumbi": "plumb",
    "plumbii": "plumb",
    "plumbilor": "plumb",
    "plumbul": "plumb",
    "plumbului": "plumb",
    "plumburi": "plumb",
    "plumburile": "plumb",
    "plumburilor": "plumb",
    "plumbica": "plumbic",
    "plumbică": "plumbic",
    "plumbice": "plumbic",
    "plumbicei": "plumbic",
    "plumbicele": "plumbic",
    "plumbicelor": "plumbic",
    "plumbici": "plumbic",
    "plumbicii": "plumbic",
    "plumbicilor": "plumbic",
    "plumbicul": "plumbic",
    "plumbicului": "plumbic",
    "plumbifera": "plumbifer",
    "plumbiferă": "plumbifer",
    "plumbifere": "plumbifer",
    "plumbiferei": "plumbifer",
    "plumbiferele": "plumbifer",
    "plumbiferelor": "plumbifer",
    "plumbiferi": "plumbifer",
    "plumbiferii": "plumbifer",
    "plumbiferilor": "plumbifer",
    "plumbiferul": "plumbifer",
    "plumbiferului": "plumbifer",
    "nemaiplumbuind": "plumbui",
    "nemaiplumbuindu": "plumbui",
    "neplumbuind": "plumbui",
    "neplumbuindu": "plumbui",
    "plumbuia": "plumbui",
    "plumbuiai": "plumbui",
    "plumbuiam": "plumbui",
    "plumbuiască": "plumbui",
    "plumbuiați": "plumbui",
    "plumbuiau": "plumbui",
    "plumbuiesc": "plumbui",
    "plumbuiește": "plumbui",
    "plumbuiești": "plumbui",
    "plumbuii": "plumbui",
    "plumbuim": "plumbui",
    "plumbuind": "plumbui",
    "plumbuindu": "plumbui",
    "plumbuiră": "plumbui",
    "plumbuirăm": "plumbui",
    "plumbuirăți": "plumbui",
    "plumbuise": "plumbui",
    "plumbuisem": "plumbui",
    "plumbuiseră": "plumbui",
    "plumbuiserăm": "plumbui",
    "plumbuiserăți": "plumbui",
    "plumbuiseși": "plumbui",
    "plumbuiși": "plumbui",
    "plumbuit": "plumbui",
    "plumbuiți": "plumbui",
    "plumbuită": "plumbuit",
    "plumbuite": "plumbuit",
    "plumbuiți": "plumbuit",
    "Plumbuitei": "Plumbuita",
    "plumburia": "plumburiu",
    "plumburie": "plumburiu",
    "plumburiei": "plumburiu",
    "plumburii": "plumburiu",
    "plumburiii": "plumburiu",
    "plumburiile": "plumburiu",
    "plumburiilor": "plumburiu",
    "plumburiul": "plumburiu",
    "plumburiului": "plumburiu",
    "pl.": "plural",
    "plurala": "plural",
    "plurală": "plural",
    "plurale": "plural",
    "pluralei": "plural",
    "pluralele": "plural",
    "pluralelor": "plural",
    "plurali": "plural",
    "pluralii": "plural",
    "pluralilor": "plural",
    "pluralul": "plural",
    "pluralului": "plural",
    "pluraluri": "plural",
    "pluralurile": "plural",
    "pluralurilor": "plural",
    "pluralismul": "pluralism",
    "pluralismului": "pluralism",
    "pluralista": "pluralist",
    "pluralistă": "pluralist",
    "pluraliste": "pluralist",
    "pluralistei": "pluralist",
    "pluralistele": "pluralist",
    "pluralistelor": "pluralist",
    "pluraliști": "pluralist",
    "pluraliștii": "pluralist",
    "pluraliștilor": "pluralist",
    "pluralistul": "pluralist",
    "pluralistului": "pluralist",
    "pluralitatea": "pluralitate",
    "pluralități": "pluralitate",
    "pluralității": "pluralitate",
    "pluralitățile": "pluralitate",
    "pluralităților": "pluralitate",
    "pluricarpelara": "pluricarpelar",
    "pluricarpelară": "pluricarpelar",
    "pluricarpelare": "pluricarpelar",
    "pluricarpelarei": "pluricarpelar",
    "pluricarpelarele": "pluricarpelar",
    "pluricarpelarelor": "pluricarpelar",
    "pluricarpelari": "pluricarpelar",
    "pluricarpelarii": "pluricarpelar",
    "pluricarpelarilor": "pluricarpelar",
    "pluricarpelarul": "pluricarpelar",
    "pluricarpelarului": "pluricarpelar",
    "pluricavitara": "pluricavitar",
    "pluricavitară": "pluricavitar",
    "pluricavitare": "pluricavitar",
    "pluricavitarei": "pluricavitar",
    "pluricavitarele": "pluricavitar",
    "pluricavitarelor": "pluricavitar",
    "pluricavitari": "pluricavitar",
    "pluricavitarii": "pluricavitar",
    "pluricavitarilor": "pluricavitar",
    "pluricavitarul": "pluricavitar",
    "pluricavitarului": "pluricavitar",
    "pluricelulara": "pluricelular",
    "pluricelulară": "pluricelular",
    "pluricelulare": "pluricelular",
    "pluricelularei": "pluricelular",
    "pluricelularele": "pluricelular",
    "pluricelularelor": "pluricelular",
    "pluricelulari": "pluricelular",
    "pluricelularii": "pluricelular",
    "pluricelularilor": "pluricelular",
    "pluricelularul": "pluricelular",
    "pluricelularului": "pluricelular",
    "pluridimensionala": "pluridimensional",
    "pluridimensională": "pluridimensional",
    "pluridimensionale": "pluridimensional",
    "pluridimensionalei": "pluridimensional",
    "pluridimensionalele": "pluridimensional",
    "pluridimensionalelor": "pluridimensional",
    "pluridimensionali": "pluridimensional",
    "pluridimensionalii": "pluridimensional",
    "pluridimensionalilor": "pluridimensional",
    "pluridimensionalul": "pluridimensional",
    "pluridimensionalului": "pluridimensional",
    "pluriflora": "pluriflor",
    "plurifloră": "pluriflor",
    "pluriflore": "pluriflor",
    "pluriflorei": "pluriflor",
    "pluriflorele": "pluriflor",
    "pluriflorelor": "pluriflor",
    "pluriflori": "pluriflor",
    "pluriflorii": "pluriflor",
    "pluriflorilor": "pluriflor",
    "pluriflorul": "pluriflor",
    "pluriflorului": "pluriflor",
    "pluriforma": "pluriform",
    "pluriformă": "pluriform",
    "pluriforme": "pluriform",
    "pluriformei": "pluriform",
    "pluriformele": "pluriform",
    "pluriformelor": "pluriform",
    "pluriformi": "pluriform",
    "pluriformii": "pluriform",
    "pluriformilor": "pluriform",
    "pluriformul": "pluriform",
    "pluriformului": "pluriform",
    "pluriglandulara": "pluriglandular",
    "pluriglandulară": "pluriglandular",
    "pluriglandulare": "pluriglandular",
    "pluriglandularei": "pluriglandular",
    "pluriglandularele": "pluriglandular",
    "pluriglandularelor": "pluriglandular",
    "pluriglandulari": "pluriglandular",
    "pluriglandularii": "pluriglandular",
    "pluriglandularilor": "pluriglandular",
    "pluriglandularul": "pluriglandular",
    "pluriglandularului": "pluriglandular",
    "plurilaterala": "plurilateral",
    "plurilaterală": "plurilateral",
    "plurilaterale": "plurilateral",
    "plurilateralei": "plurilateral",
    "plurilateralele": "plurilateral",
    "plurilateralelor": "plurilateral",
    "plurilaterali": "plurilateral",
    "plurilateralii": "plurilateral",
    "plurilateralilor": "plurilateral",
    "plurilateralul": "plurilateral",
    "plurilateralului": "plurilateral",
    "plurimilenara": "plurimilenar",
    "plurimilenară": "plurimilenar",
    "plurimilenare": "plurimilenar",
    "plurimilenarei": "plurimilenar",
    "plurimilenarele": "plurimilenar",
    "plurimilenarelor": "plurimilenar",
    "plurimilenari": "plurimilenar",
    "plurimilenarii": "plurimilenar",
    "plurimilenarilor": "plurimilenar",
    "plurimilenarul": "plurimilenar",
    "plurimilenarului": "plurimilenar",
    "plurinaționala": "plurinațional",
    "plurinațională": "plurinațional",
    "plurinaționale": "plurinațional",
    "plurinaționalei": "plurinațional",
    "plurinaționalele": "plurinațional",
    "plurinaționalelor": "plurinațional",
    "plurinaționali": "plurinațional",
    "plurinaționalii": "plurinațional",
    "plurinaționalilor": "plurinațional",
    "plurinaționalul": "plurinațional",
    "plurinaționalului": "plurinațional",
    "plurivalenta": "plurivalent",
    "plurivalentă": "plurivalent",
    "plurivalente": "plurivalent",
    "plurivalentei": "plurivalent",
    "plurivalentele": "plurivalent",
    "plurivalentelor": "plurivalent",
    "plurivalenți": "plurivalent",
    "plurivalenții": "plurivalent",
    "plurivalenților": "plurivalent",
    "plurivalentul": "plurivalent",
    "plurivalentului": "plurivalent",
    "plurivoca": "plurivoc",
    "plurivocă": "plurivoc",
    "plurivoce": "plurivoc",
    "plurivocei": "plurivoc",
    "plurivocele": "plurivoc",
    "plurivocelor": "plurivoc",
    "plurivoci": "plurivoc",
    "plurivocii": "plurivoc",
    "plurivocilor": "plurivoc",
    "plurivocul": "plurivoc",
    "plurivocului": "plurivoc",
    "plusul": "plus",
    "plusului": "plus",
    "plusuri": "plus",
    "plusurile": "plus",
    "plusurilor": "plus",
    "plușul": "pluș",
    "plușului": "pluș",
    "plușuri": "pluș",
    "plușurile": "pluș",
    "plușurilor": "pluș",
    "plusdepline": "plusdeplin",
    "pluta": "plută",
    "plute": "plută",
    "plutei": "plută",
    "plutele": "plută",
    "plutelor": "plută",
    "nemaiplutărind": "plutări",
    "nemaiplutărindu": "plutări",
    "neplutărind": "plutări",
    "neplutărindu": "plutări",
    "plutărea": "plutări",
    "plutăreai": "plutări",
    "plutăream": "plutări",
    "plutărească": "plutări",
    "plutăreați": "plutări",
    "plutăreau": "plutări",
    "plutăresc": "plutări",
    "plutărește": "plutări",
    "plutărești": "plutări",
    "plutării": "plutări",
    "plutărim": "plutări",
    "plutărind": "plutări",
    "plutărindu": "plutări",
    "plutăriră": "plutări",
    "plutărirăm": "plutări",
    "plutărirăți": "plutări",
    "plutărise": "plutări",
    "plutărisem": "plutări",
    "plutăriseră": "plutări",
    "plutăriserăm": "plutări",
    "plutăriserăți": "plutări",
    "plutăriseși": "plutări",
    "plutăriși": "plutări",
    "plutărit": "plutări",
    "plutăriți": "plutări",
    "plutărită": "plutărit",
    "plutărite": "plutărit",
    "plutăriți": "plutărit",
    "nemaiplutind": "pluti",
    "nemaiplutindu": "pluti",
    "neplutind": "pluti",
    "neplutindu": "pluti",
    "plutea": "pluti",
    "pluteai": "pluti",
    "pluteam": "pluti",
    "plutească": "pluti",
    "pluteați": "pluti",
    "pluteau": "pluti",
    "plutesc": "pluti",
    "plutește": "pluti",
    "plutești": "pluti",
    "plutii": "pluti",
    "plutim": "pluti",
    "plutind": "pluti",
    "plutindu": "pluti",
    "plutiră": "pluti",
    "plutirăm": "pluti",
    "plutirăți": "pluti",
    "plutise": "pluti",
    "plutisem": "pluti",
    "plutiseră": "pluti",
    "plutiserăm": "pluti",
    "plutiserăți": "pluti",
    "plutiseși": "pluti",
    "plutiși": "pluti",
    "plutit": "pluti",
    "plutiți": "pluti",
    "plutibila": "plutibil",
    "plutibilă": "plutibil",
    "plutibile": "plutibil",
    "plutibilei": "plutibil",
    "plutibilele": "plutibil",
    "plutibilelor": "plutibil",
    "plutibili": "plutibil",
    "plutibilii": "plutibil",
    "plutibililor": "plutibil",
    "plutibilul": "plutibil",
    "plutibilului": "plutibil",
    "plutinda": "plutind",
    "plutindă": "plutind",
    "plutinde": "plutind",
    "plutindei": "plutind",
    "plutindele": "plutind",
    "plutindelor": "plutind",
    "plutindul": "plutind",
    "plutindului": "plutind",
    "plutinzi": "plutind",
    "plutinzii": "plutind",
    "plutinzilor": "plutind",
    "plutirea": "plutire",
    "plutiri": "plutire",
    "plutirii": "plutire",
    "plutirile": "plutire",
    "plutirilor": "plutire",
    "plutită": "plutit",
    "plutite": "plutit",
    "plutiți": "plutit",
    "plutitoare": "plutitor",
    "plutitoarea": "plutitor",
    "plutitoarei": "plutitor",
    "plutitoarele": "plutitor",
    "plutitoarelor": "plutitor",
    "plutitori": "plutitor",
    "plutitorii": "plutitor",
    "plutitorilor": "plutitor",
    "plutitorul": "plutitor",
    "plutitorului": "plutitor",
    "plutocratica": "plutocratic",
    "plutocratică": "plutocratic",
    "plutocratice": "plutocratic",
    "plutocraticei": "plutocratic",
    "plutocraticele": "plutocratic",
    "plutocraticelor": "plutocratic",
    "plutocratici": "plutocratic",
    "plutocraticii": "plutocratic",
    "plutocraticilor": "plutocratic",
    "plutocraticul": "plutocratic",
    "plutocraticului": "plutocratic",
    "plutoane": "pluton",
    "plutoanele": "pluton",
    "plutoanelor": "pluton",
    "plutonul": "pluton",
    "plutonului": "pluton",
    "plutoniana": "plutonian",
    "plutoniană": "plutonian",
    "plutonianul": "plutonian",
    "plutonianului": "plutonian",
    "plutoniene": "plutonian",
    "plutonienei": "plutonian",
    "plutonienele": "plutonian",
    "plutonienelor": "plutonian",
    "plutonieni": "plutonian",
    "plutonienii": "plutonian",
    "plutonienilor": "plutonian",
    "plutonica": "plutonic",
    "plutonică": "plutonic",
    "plutonice": "plutonic",
    "plutonicei": "plutonic",
    "plutonicele": "plutonic",
    "plutonicelor": "plutonic",
    "plutonici": "plutonic",
    "plutonicii": "plutonic",
    "plutonicilor": "plutonic",
    "plutonicul": "plutonic",
    "plutonicului": "plutonic",
    "plut.": "plutonier",
    "plutonieri": "plutonier",
    "plutonierii": "plutonier",
    "plutonierilor": "plutonier",
    "plutonierul": "plutonier",
    "plutonierului": "plutonier",
    "plutoniul": "plutoniu",
    "plutoniului": "plutoniu",
    "Pu": "plutoniu",
    "nemaiplutuind": "plutui",
    "nemaiplutuindu": "plutui",
    "neplutuind": "plutui",
    "neplutuindu": "plutui",
    "plutuia": "plutui",
    "plutuiai": "plutui",
    "plutuiam": "plutui",
    "plutuiască": "plutui",
    "plutuiați": "plutui",
    "plutuiau": "plutui",
    "plutuiesc": "plutui",
    "plutuiește": "plutui",
    "plutuiești": "plutui",
    "plutuii": "plutui",
    "plutuim": "plutui",
    "plutuind": "plutui",
    "plutuindu": "plutui",
    "plutuiră": "plutui",
    "plutuirăm": "plutui",
    "plutuirăți": "plutui",
    "plutuise": "plutui",
    "plutuisem": "plutui",
    "plutuiseră": "plutui",
    "plutuiserăm": "plutui",
    "plutuiserăți": "plutui",
    "plutuiseși": "plutui",
    "plutuiși": "plutui",
    "plutuit": "plutui",
    "plutuiți": "plutui",
    "plutuită": "plutuit",
    "plutuite": "plutuit",
    "plutuiți": "plutuit",
    "pluviala": "pluvial",
    "pluvială": "pluvial",
    "pluviale": "pluvial",
    "pluvialei": "pluvial",
    "pluvialele": "pluvial",
    "pluvialelor": "pluvial",
    "pluviali": "pluvial",
    "pluvialii": "pluvial",
    "pluvialilor": "pluvial",
    "pluvialul": "pluvial",
    "pluvialului": "pluvial",
    "pluviografe": "pluviograf",
    "pluviografele": "pluviograf",
    "pluviografelor": "pluviograf",
    "pluviograful": "pluviograf",
    "pluviografului": "pluviograf",
    "pluviometrica": "pluviometric",
    "pluviometrică": "pluviometric",
    "pluviometrice": "pluviometric",
    "pluviometricei": "pluviometric",
    "pluviometricele": "pluviometric",
    "pluviometricelor": "pluviometric",
    "pluviometrici": "pluviometric",
    "pluviometricii": "pluviometric",
    "pluviometricilor": "pluviometric",
    "pluviometricul": "pluviometric",
    "pluviometricului": "pluviometric",
    "pluviometre": "pluviometru",
    "pluviometrele": "pluviometru",
    "pluviometrelor": "pluviometru",
    "pluviometrul": "pluviometru",
    "pluviometrului": "pluviometru",
    "pluvioasa": "pluvios",
    "pluvioasă": "pluvios",
    "pluvioase": "pluvios",
    "pluvioasei": "pluvios",
    "pluvioasele": "pluvios",
    "pluvioaselor": "pluvios",
    "pluvioși": "pluvios",
    "pluvioșii": "pluvios",
    "pluvioșilor": "pluvios",
    "pluviosul": "pluvios",
    "pluviosului": "pluvios",
    "pneul": "pneu",
    "pneului": "pneu",
    "pneuri": "pneu",
    "pneurile": "pneu",
    "pneurilor": "pneu",
    "pneumatica": "pneumatic",
    "pneumatică": "pneumatic",
    "pneumatice": "pneumatic",
    "pneumaticei": "pneumatic",
    "pneumaticele": "pneumatic",
    "pneumaticelor": "pneumatic",
    "pneumatici": "pneumatic",
    "pneumaticii": "pneumatic",
    "pneumaticilor": "pneumatic",
    "pneumaticul": "pneumatic",
    "pneumaticului": "pneumatic",
    "pneumatolitica": "pneumatolitic",
    "pneumatolitică": "pneumatolitic",
    "pneumatolitice": "pneumatolitic",
    "pneumatoliticei": "pneumatolitic",
    "pneumatoliticele": "pneumatolitic",
    "pneumatoliticelor": "pneumatolitic",
    "pneumatolitici": "pneumatolitic",
    "pneumatoliticii": "pneumatolitic",
    "pneumatoliticilor": "pneumatolitic",
    "pneumatoliticul": "pneumatolitic",
    "pneumatoliticului": "pneumatolitic",
    "pneumatologia": "pneumatologie",
    "pneumatologiei": "pneumatologie",
    "pneumatologii": "pneumatologie",
    "pneumatologiile": "pneumatologie",
    "pneumatologiilor": "pneumatologie",
    "pneumococi": "pneumococ",
    "pneumococii": "pneumococ",
    "pneumococilor": "pneumococ",
    "pneumococul": "pneumococ",
    "pneumococului": "pneumococ",
    "pneumococica": "pneumococic",
    "pneumococică": "pneumococic",
    "pneumococice": "pneumococic",
    "pneumococicei": "pneumococic",
    "pneumococicele": "pneumococic",
    "pneumococicelor": "pneumococic",
    "pneumococici": "pneumococic",
    "pneumococicii": "pneumococic",
    "pneumococicilor": "pneumococic",
    "pneumococicul": "pneumococic",
    "pneumococicului": "pneumococic",
    "pneumogastrica": "pneumogastric",
    "pneumogastrică": "pneumogastric",
    "pneumogastrice": "pneumogastric",
    "pneumogastricei": "pneumogastric",
    "pneumogastricele": "pneumogastric",
    "pneumogastricelor": "pneumogastric",
    "pneumogastrici": "pneumogastric",
    "pneumogastricii": "pneumogastric",
    "pneumogastricilor": "pneumogastric",
    "pneumogastricul": "pneumogastric",
    "pneumogastricului": "pneumogastric",
    "pneumonica": "pneumonic",
    "pneumonică": "pneumonic",
    "pneumonice": "pneumonic",
    "pneumonicei": "pneumonic",
    "pneumonicele": "pneumonic",
    "pneumonicelor": "pneumonic",
    "pneumonici": "pneumonic",
    "pneumonicii": "pneumonic",
    "pneumonicilor": "pneumonic",
    "pneumonicul": "pneumonic",
    "pneumonicului": "pneumonic",
    "pneumonia": "pneumonie",
    "pneumoniei": "pneumonie",
    "pneumonii": "pneumonie",
    "pneumoniile": "pneumonie",
    "pneumoniilor": "pneumonie",
    "pneumotropa": "pneumotrop",
    "pneumotropă": "pneumotrop",
    "pneumotrope": "pneumotrop",
    "pneumotropei": "pneumotrop",
    "pneumotropele": "pneumotrop",
    "pneumotropelor": "pneumotrop",
    "pneumotropi": "pneumotrop",
    "pneumotropii": "pneumotrop",
    "pneumotropilor": "pneumotrop",
    "pneumotropul": "pneumotrop",
    "pneumotropului": "pneumotrop",
    "poala": "poală",
    "poale": "poală",
    "poalei": "poală",
    "poalele": "poală",
    "poalelor": "poală",
    "poama": "poamă",
    "poame": "poamă",
    "poamei": "poamă",
    "poamele": "poamă",
    "poamelor": "poamă",
    "poansoane": "poanson",
    "poansoanele": "poanson",
    "poansoanelor": "poanson",
    "poansonul": "poanson",
    "poansonului": "poanson",
    "poanta": "poantă",
    "poante": "poantă",
    "poantei": "poantă",
    "poantele": "poantă",
    "poantelor": "poantă",
    "poantilista": "poantilist",
    "poantilistă": "poantilist",
    "poantiliste": "poantilist",
    "poantilistei": "poantilist",
    "poantilistele": "poantilist",
    "poantilistelor": "poantilist",
    "poantiliști": "poantilist",
    "poantiliștii": "poantilist",
    "poantiliștilor": "poantilist",
    "poantilistul": "poantilist",
    "poantilistului": "poantilist",
    "poarta": "poartă",
    "porți": "poartă",
    "porții": "poartă",
    "porțile": "poartă",
    "porților": "poartă",
    "nemaipocăind": "pocăi",
    "nemaipocăindu": "pocăi",
    "nepocăind": "pocăi",
    "nepocăindu": "pocăi",
    "pocăia": "pocăi",
    "pocăiai": "pocăi",
    "pocăiam": "pocăi",
    "pocăiască": "pocăi",
    "pocăiați": "pocăi",
    "pocăiau": "pocăi",
    "pocăiesc": "pocăi",
    "pocăiește": "pocăi",
    "pocăiești": "pocăi",
    "pocăii": "pocăi",
    "pocăim": "pocăi",
    "pocăind": "pocăi",
    "pocăindu": "pocăi",
    "pocăiră": "pocăi",
    "pocăirăm": "pocăi",
    "pocăirăți": "pocăi",
    "pocăise": "pocăi",
    "pocăisem": "pocăi",
    "pocăiseră": "pocăi",
    "pocăiserăm": "pocăi",
    "pocăiserăți": "pocăi",
    "pocăiseși": "pocăi",
    "pocăiși": "pocăi",
    "pocăit": "pocăi",
    "pocăiți": "pocăi",
    "pocăința": "pocăință",
    "pocăințe": "pocăință",
    "pocăinței": "pocăință",
    "pocăințele": "pocăință",
    "pocăințelor": "pocăință",
    "pocăita": "pocăit",
    "pocăită": "pocăit",
    "pocăite": "pocăit",
    "pocăitei": "pocăit",
    "pocăitele": "pocăit",
    "pocăitelor": "pocăit",
    "pocăiți": "pocăit",
    "pocăiții": "pocăit",
    "pocăiților": "pocăit",
    "pocăitul": "pocăit",
    "pocăitului": "pocăit",
    "pocale": "pocal",
    "pocalele": "pocal",
    "pocalelor": "pocal",
    "pocalul": "pocal",
    "pocalului": "pocal",
    "pochere": "pocher",
    "pocherele": "pocher",
    "pocherelor": "pocher",
    "pocherul": "pocher",
    "pocherului": "pocher",
    "nemaipocind": "poci",
    "nemaipocindu": "poci",
    "nepocind": "poci",
    "nepocindu": "poci",
    "pocea": "poci",
    "poceai": "poci",
    "poceam": "poci",
    "pocească": "poci",
    "poceați": "poci",
    "poceau": "poci",
    "pocesc": "poci",
    "pocește": "poci",
    "pocești": "poci",
    "pocii": "poci",
    "pocim": "poci",
    "pocind": "poci",
    "pocindu": "poci",
    "pociră": "poci",
    "pocirăm": "poci",
    "pocirăți": "poci",
    "pocise": "poci",
    "pocisem": "poci",
    "pociseră": "poci",
    "pociserăm": "poci",
    "pociserăți": "poci",
    "pociseși": "poci",
    "pociși": "poci",
    "pocit": "poci",
    "pociți": "poci",
    "pocinoage": "pocinog",
    "pocinoagele": "pocinog",
    "pocinoagelor": "pocinog",
    "pocinogul": "pocinog",
    "pocinogului": "pocinog",
    "pocită": "pocit",
    "pocite": "pocit",
    "pociți": "pocit",
    "pocitania": "pocitanie",
    "pocitaniei": "pocitanie",
    "pocitanii": "pocitanie",
    "pocitaniile": "pocitanie",
    "pocitaniilor": "pocitanie",
    "pociumbi": "pociumb",
    "pociumbii": "pociumb",
    "pociumbilor": "pociumb",
    "pociumbul": "pociumb",
    "pociumbului": "pociumb",
    "pocnete": "pocnet",
    "pocnetele": "pocnet",
    "pocnetelor": "pocnet",
    "pocnetul": "pocnet",
    "pocnetului": "pocnet",
    "nemaipocnind": "pocni",
    "nemaipocnindu": "pocni",
    "nepocnind": "pocni",
    "nepocnindu": "pocni",
    "pocnea": "pocni",
    "pocneai": "pocni",
    "pocneam": "pocni",
    "pocnească": "pocni",
    "pocneați": "pocni",
    "pocneau": "pocni",
    "pocnesc": "pocni",
    "pocnește": "pocni",
    "pocnești": "pocni",
    "pocnii": "pocni",
    "pocnim": "pocni",
    "pocnind": "pocni",
    "pocnindu": "pocni",
    "pocniră": "pocni",
    "pocnirăm": "pocni",
    "pocnirăți": "pocni",
    "pocnise": "pocni",
    "pocnisem": "pocni",
    "pocniseră": "pocni",
    "pocniserăm": "pocni",
    "pocniserăți": "pocni",
    "pocniseși": "pocni",
    "pocniși": "pocni",
    "pocnit": "pocni",
    "pocniți": "pocni",
    "pocnită": "pocnit",
    "pocnite": "pocnit",
    "pocniți": "pocnit",
    "pocnitura": "pocnitură",
    "pocnituri": "pocnitură",
    "pocniturii": "pocnitură",
    "pocniturile": "pocnitură",
    "pocniturilor": "pocnitură",
    "podul": "pod",
    "podului": "pod",
    "poduri": "pod",
    "podurile": "pod",
    "podurilor": "pod",
    "podeaua": "podea",
    "podele": "podea",
    "podelei": "podea",
    "podelele": "podea",
    "podelelor": "podea",
    "podgoreana": "podgorean",
    "podgoreană": "podgorean",
    "podgoreanul": "podgorean",
    "podgoreanului": "podgorean",
    "podgorene": "podgorean",
    "podgorenei": "podgorean",
    "podgorenele": "podgorean",
    "podgorenelor": "podgorean",
    "podgoreni": "podgorean",
    "podgorenii": "podgorean",
    "podgorenilor": "podgorean",
    "podgoria": "podgorie",
    "podgoriei": "podgorie",
    "podgorii": "podgorie",
    "podgoriile": "podgorie",
    "podgoriilor": "podgorie",
    "podgoria": "podgoriu",
    "podgorie": "podgoriu",
    "podgoriei": "podgoriu",
    "podgorii": "podgoriu",
    "podgoriii": "podgoriu",
    "podgoriile": "podgoriu",
    "podgoriilor": "podgoriu",
    "podgoriul": "podgoriu",
    "podgoriului": "podgoriu",
    "nemaipodind": "podi",
    "nemaipodindu": "podi",
    "nepodind": "podi",
    "nepodindu": "podi",
    "podea": "podi",
    "podeai": "podi",
    "podeam": "podi",
    "podească": "podi",
    "podeați": "podi",
    "podeau": "podi",
    "podesc": "podi",
    "podește": "podi",
    "podești": "podi",
    "podii": "podi",
    "podim": "podi",
    "podind": "podi",
    "podindu": "podi",
    "podiră": "podi",
    "podirăm": "podi",
    "podirăți": "podi",
    "podise": "podi",
    "podisem": "podi",
    "podiseră": "podi",
    "podiserăm": "podi",
    "podiserăți": "podi",
    "podiseși": "podi",
    "podiși": "podi",
    "podit": "podi",
    "podiți": "podi",
    "nemaipodidind": "podidi",
    "nemaipodidindu": "podidi",
    "nepodidind": "podidi",
    "nepodidindu": "podidi",
    "podidea": "podidi",
    "podidească": "podidi",
    "podideau": "podidi",
    "podidesc": "podidi",
    "podidește": "podidi",
    "podidind": "podidi",
    "podidindu": "podidi",
    "podidiră": "podidi",
    "podidise": "podidi",
    "podidiseră": "podidi",
    "podidit": "podidi",
    "podidită": "podidit",
    "podidite": "podidit",
    "podidiți": "podidit",
    "pod.": "podiș",
    "podișul": "podiș",
    "podișului": "podiș",
    "podișuri": "podiș",
    "podișurile": "podiș",
    "podișurilor": "podiș",
    "podită": "podit",
    "podite": "podit",
    "podiți": "podit",
    "podiumul": "podium",
    "podiumului": "podium",
    "podiumuri": "podium",
    "podiumurile": "podium",
    "podiumurilor": "podium",
    "podoaba": "podoabă",
    "podoabe": "podoabă",
    "podoabei": "podoabă",
    "podoabele": "podoabă",
    "podoabelor": "podoabă",
    "podobia": "podobie",
    "podobiei": "podobie",
    "podobii": "podobie",
    "podobiile": "podobie",
    "podobiilor": "podobie",
    "podoliana": "podolian",
    "podoliană": "podolian",
    "podolianul": "podolian",
    "podolianului": "podolian",
    "podoliene": "podolian",
    "podolienei": "podolian",
    "podolienele": "podolian",
    "podolienelor": "podolian",
    "podolieni": "podolian",
    "podolienii": "podolian",
    "podolienilor": "podolian",
    "podzolica": "podzolic",
    "podzolică": "podzolic",
    "podzolice": "podzolic",
    "podzolicei": "podzolic",
    "podzolicele": "podzolic",
    "podzolicelor": "podzolic",
    "podzolici": "podzolic",
    "podzolicii": "podzolic",
    "podzolicilor": "podzolic",
    "podzolicul": "podzolic",
    "podzolicului": "podzolic",
    "podzolita": "podzolit",
    "podzolită": "podzolit",
    "podzolite": "podzolit",
    "podzolitei": "podzolit",
    "podzolitele": "podzolit",
    "podzolitelor": "podzolit",
    "podzoliți": "podzolit",
    "podzoliții": "podzolit",
    "podzoliților": "podzolit",
    "podzolitul": "podzolit",
    "podzolitului": "podzolit",
    "poeme": "poem",
    "poemele": "poem",
    "poemelor": "poem",
    "poemul": "poem",
    "poemului": "poem",
    "poematica": "poematic",
    "poematică": "poematic",
    "poematice": "poematic",
    "poematicei": "poematic",
    "poematicele": "poematic",
    "poematicelor": "poematic",
    "poematici": "poematic",
    "poematicii": "poematic",
    "poematicilor": "poematic",
    "poematicul": "poematic",
    "poematicului": "poematic",
    "poeta": "poet",
    "poetă": "poet",
    "poete": "poet",
    "poetei": "poet",
    "poetele": "poet",
    "poetelor": "poet",
    "poeți": "poet",
    "poeții": "poet",
    "poeților": "poet",
    "poetul": "poet",
    "poetului": "poet",
    "poeta": "poetă",
    "poete": "poetă",
    "poetei": "poetă",
    "poetele": "poetă",
    "poetelor": "poetă",
    "poetica": "poetic",
    "poetică": "poetic",
    "poetice": "poetic",
    "poeticei": "poetic",
    "poeticele": "poetic",
    "poeticelor": "poetic",
    "poetici": "poetic",
    "poeticii": "poetic",
    "poeticilor": "poetic",
    "poeticul": "poetic",
    "poeticului": "poetic",
    "nemaipoetizând": "poetiza",
    "nemaipoetizându": "poetiza",
    "nepoetizând": "poetiza",
    "nepoetizându": "poetiza",
    "poetiză": "poetiza",
    "poetizai": "poetiza",
    "poetizam": "poetiza",
    "poetizăm": "poetiza",
    "poetizând": "poetiza",
    "poetizându": "poetiza",
    "poetizară": "poetiza",
    "poetizarăm": "poetiza",
    "poetizarăți": "poetiza",
    "poetizase": "poetiza",
    "poetizasem": "poetiza",
    "poetizaseră": "poetiza",
    "poetizaserăm": "poetiza",
    "poetizaserăți": "poetiza",
    "poetizaseși": "poetiza",
    "poetizași": "poetiza",
    "poetizat": "poetiza",
    "poetizați": "poetiza",
    "poetizau": "poetiza",
    "poetizează": "poetiza",
    "poetizez": "poetiza",
    "poetizeze": "poetiza",
    "poetizezi": "poetiza",
    "poetizanta": "poetizant",
    "poetizantă": "poetizant",
    "poetizante": "poetizant",
    "poetizantei": "poetizant",
    "poetizantele": "poetizant",
    "poetizantelor": "poetizant",
    "poetizanți": "poetizant",
    "poetizanții": "poetizant",
    "poetizanților": "poetizant",
    "poetizantul": "poetizant",
    "poetizantului": "poetizant",
    "poetizată": "poetizat",
    "poetizate": "poetizat",
    "poetizați": "poetizat",
    "poezia": "poezie",
    "poeziei": "poezie",
    "poezii": "poezie",
    "poeziile": "poezie",
    "poeziilor": "poezie",
    "poezioara": "poezioară",
    "poezioare": "poezioară",
    "poezioarei": "poezioară",
    "poezioarele": "poezioară",
    "poezioarelor": "poezioară",
    "pofida": "pofidă",
    "pofide": "pofidă",
    "pofidei": "pofidă",
    "pofidele": "pofidă",
    "pofidelor": "pofidă",
    "pofta": "poftă",
    "pofte": "poftă",
    "poftei": "poftă",
    "poftele": "poftă",
    "poftelor": "poftă",
    "poftăreața": "poftăreț",
    "poftăreață": "poftăreț",
    "poftărețe": "poftăreț",
    "poftăreței": "poftăreț",
    "poftărețele": "poftăreț",
    "poftărețelor": "poftăreț",
    "poftăreți": "poftăreț",
    "poftăreții": "poftăreț",
    "poftăreților": "poftăreț",
    "poftărețul": "poftăreț",
    "poftărețului": "poftăreț",
    "nemaipoftind": "pofti",
    "nemaipoftindu": "pofti",
    "nepoftind": "pofti",
    "nepoftindu": "pofti",
    "poftea": "pofti",
    "pofteai": "pofti",
    "pofteam": "pofti",
    "poftească": "pofti",
    "pofteați": "pofti",
    "pofteau": "pofti",
    "poftesc": "pofti",
    "poftește": "pofti",
    "poftești": "pofti",
    "poftii": "pofti",
    "poftim": "pofti",
    "poftind": "pofti",
    "poftindu": "pofti",
    "poftiră": "pofti",
    "poftirăm": "pofti",
    "poftirăți": "pofti",
    "poftise": "pofti",
    "poftisem": "pofti",
    "poftiseră": "pofti",
    "poftiserăm": "pofti",
    "poftiserăți": "pofti",
    "poftiseși": "pofti",
    "poftiși": "pofti",
    "poftit": "pofti",
    "poftiți": "pofti",
    "pofticioasa": "pofticioasă",
    "pofticioase": "pofticioasă",
    "pofticioasei": "pofticioasă",
    "pofticioasele": "pofticioasă",
    "pofticioaselor": "pofticioasă",
    "pofticioasa": "pofticios",
    "pofticioasă": "pofticios",
    "pofticioase": "pofticios",
    "pofticioasei": "pofticios",
    "pofticioasele": "pofticios",
    "pofticioaselor": "pofticios",
    "pofticioși": "pofticios",
    "pofticioșii": "pofticios",
    "pofticioșilor": "pofticios",
    "pofticiosul": "pofticios",
    "pofticiosului": "pofticios",
    "poftită": "poftit",
    "poftite": "poftit",
    "poftiți": "poftit",
    "poftitoare": "poftitor",
    "poftitoarea": "poftitor",
    "poftitoarei": "poftitor",
    "poftitoarele": "poftitor",
    "poftitoarelor": "poftitor",
    "poftitori": "poftitor",
    "poftitorii": "poftitor",
    "poftitorilor": "poftitor",
    "poftitorul": "poftitor",
    "poftitorului": "poftitor",
    "pogana": "pogan",
    "pogană": "pogan",
    "pogane": "pogan",
    "poganei": "pogan",
    "poganele": "pogan",
    "poganelor": "pogan",
    "pogani": "pogan",
    "poganii": "pogan",
    "poganilor": "pogan",
    "poganul": "pogan",
    "poganului": "pogan",
    "pogoane": "pogon",
    "pogoanele": "pogon",
    "pogoanelor": "pogon",
    "pogonul": "pogon",
    "pogonului": "pogon",
    "pogorârea": "pogorâre",
    "pogorâri": "pogorâre",
    "pogorârii": "pogorâre",
    "pogorârile": "pogorâre",
    "pogorârilor": "pogorâre",
    "pogorâtă": "pogorât",
    "pogorâte": "pogorât",
    "pogorâți": "pogorât",
    "nemaipogorând": "pogorî",
    "nemaipogorându": "pogorî",
    "nepogorând": "pogorî",
    "nepogorându": "pogorî",
    "pogoară": "pogorî",
    "pogoare": "pogorî",
    "pogor": "pogorî",
    "pogora": "pogorî",
    "pogorai": "pogorî",
    "pogorâi": "pogorî",
    "pogoram": "pogorî",
    "pogorâm": "pogorî",
    "pogorând": "pogorî",
    "pogorându": "pogorî",
    "pogorâră": "pogorî",
    "pogorârăm": "pogorî",
    "pogorârăți": "pogorî",
    "pogorăsc": "pogorî",
    "pogorască": "pogorî",
    "pogorâse": "pogorî",
    "pogorâsem": "pogorî",
    "pogorâseră": "pogorî",
    "pogorâserăm": "pogorî",
    "pogorâserăți": "pogorî",
    "pogorâseși": "pogorî",
    "pogorâși": "pogorî",
    "pogorăște": "pogorî",
    "pogorăști": "pogorî",
    "pogorât": "pogorî",
    "pogorați": "pogorî",
    "pogorâți": "pogorî",
    "pogorâtu": "pogorî",
    "pogorau": "pogorî",
    "pogori": "pogorî",
    "pogromista": "pogromist",
    "pogromistă": "pogromist",
    "pogromiste": "pogromist",
    "pogromistei": "pogromist",
    "pogromistele": "pogromist",
    "pogromistelor": "pogromist",
    "pogromiști": "pogromist",
    "pogromiștii": "pogromist",
    "pogromiștilor": "pogromist",
    "pogromistul": "pogromist",
    "pogromistului": "pogromist",
    "poiana": "poiană",
    "poiene": "poiană",
    "poienei": "poiană",
    "poienele": "poiană",
    "poienelor": "poiană",
    "poieni": "poiană",
    "poienii": "poiană",
    "poienile": "poiană",
    "poienilor": "poiană",
    "poiata": "poiată",
    "poieți": "poiată",
    "poieții": "poiată",
    "poiețile": "poiată",
    "poieților": "poiată",
    "poichiloterma": "poichiloterm",
    "poichilotermă": "poichiloterm",
    "poichiloterme": "poichiloterm",
    "poichilotermei": "poichiloterm",
    "poichilotermele": "poichiloterm",
    "poichilotermelor": "poichiloterm",
    "poichilotermi": "poichiloterm",
    "poichilotermii": "poichiloterm",
    "poichilotermilor": "poichiloterm",
    "poichilotermul": "poichiloterm",
    "poichilotermului": "poichiloterm",
    "poienara": "poienar",
    "poienară": "poienar",
    "poienare": "poienar",
    "poienarei": "poienar",
    "poienarele": "poienar",
    "poienarelor": "poienar",
    "poienari": "poienar",
    "poienarii": "poienar",
    "poienarilor": "poienar",
    "poienarul": "poienar",
    "poienarului": "poienar",
    "pojarul": "pojar",
    "pojarului": "pojar",
    "pojaruri": "pojar",
    "pojarurile": "pojar",
    "pojarurilor": "pojar",
    "pojghița": "pojghiță",
    "pojghițe": "pojghiță",
    "pojghiței": "pojghiță",
    "pojghițele": "pojghiță",
    "pojghițelor": "pojghiță",
    "Pojorâtei": "Pojorâta",
    "poli": "pol",
    "polii": "pol",
    "polilor": "pol",
    "polul": "pol",
    "polului": "pol",
    "polara": "polar",
    "polară": "polar",
    "polare": "polar",
    "polarei": "polar",
    "polarele": "polar",
    "polarelor": "polar",
    "polari": "polar",
    "polarii": "polar",
    "polarilor": "polar",
    "polarul": "polar",
    "polarului": "polar",
    "polarimetria": "polarimetrie",
    "polarimetriei": "polarimetrie",
    "polarimetrii": "polarimetrie",
    "polarimetre": "polarimetru",
    "polarimetrele": "polarimetru",
    "polarimetrelor": "polarimetru",
    "polarimetrul": "polarimetru",
    "polarimetrului": "polarimetru",
    "polariscoape": "polariscop",
    "polariscoapele": "polariscop",
    "polariscoapelor": "polariscop",
    "polariscopul": "polariscop",
    "polariscopului": "polariscop",
    "polaritatea": "polaritate",
    "polarități": "polaritate",
    "polarității": "polaritate",
    "polaritățile": "polaritate",
    "polarităților": "polaritate",
    "nemaipolarizând": "polariza",
    "nemaipolarizându": "polariza",
    "nepolarizând": "polariza",
    "nepolarizându": "polariza",
    "polariză": "polariza",
    "polarizai": "polariza",
    "polarizam": "polariza",
    "polarizăm": "polariza",
    "polarizând": "polariza",
    "polarizându": "polariza",
    "polarizară": "polariza",
    "polarizarăm": "polariza",
    "polarizarăți": "polariza",
    "polarizase": "polariza",
    "polarizasem": "polariza",
    "polarizaseră": "polariza",
    "polarizaserăm": "polariza",
    "polarizaserăți": "polariza",
    "polarizaseși": "polariza",
    "polarizași": "polariza",
    "polarizat": "polariza",
    "polarizați": "polariza",
    "polarizau": "polariza",
    "polarizează": "polariza",
    "polarizez": "polariza",
    "polarizeze": "polariza",
    "polarizezi": "polariza",
    "polarizabila": "polarizabil",
    "polarizabilă": "polarizabil",
    "polarizabile": "polarizabil",
    "polarizabilei": "polarizabil",
    "polarizabilele": "polarizabil",
    "polarizabilelor": "polarizabil",
    "polarizabili": "polarizabil",
    "polarizabilii": "polarizabil",
    "polarizabililor": "polarizabil",
    "polarizabilul": "polarizabil",
    "polarizabilului": "polarizabil",
    "polarizanta": "polarizant",
    "polarizantă": "polarizant",
    "polarizante": "polarizant",
    "polarizantei": "polarizant",
    "polarizantele": "polarizant",
    "polarizantelor": "polarizant",
    "polarizanți": "polarizant",
    "polarizanții": "polarizant",
    "polarizanților": "polarizant",
    "polarizantul": "polarizant",
    "polarizantului": "polarizant",
    "polarizarea": "polarizare",
    "polarizări": "polarizare",
    "polarizării": "polarizare",
    "polarizările": "polarizare",
    "polarizărilor": "polarizare",
    "polarizată": "polarizat",
    "polarizate": "polarizat",
    "polarizați": "polarizat",
    "polarizatoare": "polarizator",
    "polarizatoarea": "polarizator",
    "polarizatoarei": "polarizator",
    "polarizatoarele": "polarizator",
    "polarizatoarelor": "polarizator",
    "polarizatori": "polarizator",
    "polarizatorii": "polarizator",
    "polarizatorilor": "polarizator",
    "polarizatorul": "polarizator",
    "polarizatorului": "polarizator",
    "polarografica": "polarografic",
    "polarografică": "polarografic",
    "polarografice": "polarografic",
    "polarograficei": "polarografic",
    "polarograficele": "polarografic",
    "polarograficelor": "polarografic",
    "polarografici": "polarografic",
    "polarograficii": "polarografic",
    "polarograficilor": "polarografic",
    "polarograficul": "polarografic",
    "polarograficului": "polarografic",
    "polca": "polcă",
    "polci": "polcă",
    "polcii": "polcă",
    "polcile": "polcă",
    "polcilor": "polcă",
    "polcovniceasca": "polcovnicesc",
    "polcovnicească": "polcovnicesc",
    "polcovnicescul": "polcovnicesc",
    "polcovnicescului": "polcovnicesc",
    "polcovnicești": "polcovnicesc",
    "polcovniceștii": "polcovnicesc",
    "polcovniceștile": "polcovnicesc",
    "polcovniceștilor": "polcovnicesc",
    "poleaca": "poleac",
    "poleacă": "poleac",
    "poleace": "poleac",
    "poleacei": "poleac",
    "poleacele": "poleac",
    "poleacelor": "poleac",
    "poleaci": "poleac",
    "poleacii": "poleac",
    "poleacilor": "poleac",
    "poleacul": "poleac",
    "poleacului": "poleac",
    "nemaipoleind": "polei",
    "nemaipoleindu": "polei",
    "nepoleind": "polei",
    "nepoleindu": "polei",
    "poleia": "polei",
    "poleiai": "polei",
    "poleiam": "polei",
    "poleiască": "polei",
    "poleiați": "polei",
    "poleiau": "polei",
    "poleiesc": "polei",
    "poleiește": "polei",
    "poleiești": "polei",
    "poleii": "polei",
    "poleim": "polei",
    "poleind": "polei",
    "poleindu": "polei",
    "poleiră": "polei",
    "poleirăm": "polei",
    "poleirăți": "polei",
    "poleise": "polei",
    "poleisem": "polei",
    "poleiseră": "polei",
    "poleiserăm": "polei",
    "poleiserăți": "polei",
    "poleiseși": "polei",
    "poleiși": "polei",
    "poleit": "polei",
    "poleiți": "polei",
    "poleiul": "polei",
    "poleiului": "polei",
    "poleiala": "poleială",
    "poleieli": "poleială",
    "poleielii": "poleială",
    "poleielile": "poleială",
    "poleielilor": "poleială",
    "poleită": "poleit",
    "poleite": "poleit",
    "poleiți": "poleit",
    "polemica": "polemic",
    "polemică": "polemic",
    "polemice": "polemic",
    "polemicei": "polemic",
    "polemicele": "polemic",
    "polemicelor": "polemic",
    "polemici": "polemic",
    "polemicii": "polemic",
    "polemicilor": "polemic",
    "polemicul": "polemic",
    "polemicului": "polemic",
    "polemica": "polemică",
    "polemici": "polemică",
    "polemicii": "polemică",
    "polemicile": "polemică",
    "polemicilor": "polemică",
    "nemaipolemizând": "polemiza",
    "nemaipolemizându": "polemiza",
    "nepolemizând": "polemiza",
    "nepolemizându": "polemiza",
    "polemiză": "polemiza",
    "polemizai": "polemiza",
    "polemizam": "polemiza",
    "polemizăm": "polemiza",
    "polemizând": "polemiza",
    "polemizându": "polemiza",
    "polemizară": "polemiza",
    "polemizarăm": "polemiza",
    "polemizarăți": "polemiza",
    "polemizase": "polemiza",
    "polemizasem": "polemiza",
    "polemizaseră": "polemiza",
    "polemizaserăm": "polemiza",
    "polemizaserăți": "polemiza",
    "polemizaseși": "polemiza",
    "polemizași": "polemiza",
    "polemizat": "polemiza",
    "polemizați": "polemiza",
    "polemizau": "polemiza",
    "polemizează": "polemiza",
    "polemizez": "polemiza",
    "polemizeze": "polemiza",
    "polemizezi": "polemiza",
    "polemizată": "polemizat",
    "polemizate": "polemizat",
    "polemizați": "polemizat",
    "polenul": "polen",
    "polenului": "polen",
    "polenuri": "polen",
    "polenurile": "polen",
    "polenurilor": "polen",
    "polenica": "polenic",
    "polenică": "polenic",
    "polenice": "polenic",
    "polenicei": "polenic",
    "polenicele": "polenic",
    "polenicelor": "polenic",
    "polenici": "polenic",
    "polenicii": "polenic",
    "polenicilor": "polenic",
    "polenicul": "polenic",
    "polenicului": "polenic",
    "polenifera": "polenifer",
    "poleniferă": "polenifer",
    "polenifere": "polenifer",
    "poleniferei": "polenifer",
    "poleniferele": "polenifer",
    "poleniferelor": "polenifer",
    "poleniferi": "polenifer",
    "poleniferii": "polenifer",
    "poleniferilor": "polenifer",
    "poleniferul": "polenifer",
    "poleniferului": "polenifer",
    "nemaipolenizând": "poleniza",
    "nemaipolenizându": "poleniza",
    "nepolenizând": "poleniza",
    "nepolenizându": "poleniza",
    "poleniză": "poleniza",
    "polenizai": "poleniza",
    "polenizam": "poleniza",
    "polenizăm": "poleniza",
    "polenizând": "poleniza",
    "polenizându": "poleniza",
    "polenizară": "poleniza",
    "polenizarăm": "poleniza",
    "polenizarăți": "poleniza",
    "polenizase": "poleniza",
    "polenizasem": "poleniza",
    "polenizaseră": "poleniza",
    "polenizaserăm": "poleniza",
    "polenizaserăți": "poleniza",
    "polenizaseși": "poleniza",
    "polenizași": "poleniza",
    "polenizat": "poleniza",
    "polenizați": "poleniza",
    "polenizau": "poleniza",
    "polenizează": "poleniza",
    "polenizez": "poleniza",
    "polenizeze": "poleniza",
    "polenizezi": "poleniza",
    "polenizarea": "polenizare",
    "polenizări": "polenizare",
    "polenizării": "polenizare",
    "polenizările": "polenizare",
    "polenizărilor": "polenizare",
    "polenizată": "polenizat",
    "polenizate": "polenizat",
    "polenizați": "polenizat",
    "poliamidica": "poliamidic",
    "poliamidică": "poliamidic",
    "poliamidice": "poliamidic",
    "poliamidicei": "poliamidic",
    "poliamidicele": "poliamidic",
    "poliamidicelor": "poliamidic",
    "poliamidici": "poliamidic",
    "poliamidicii": "poliamidic",
    "poliamidicilor": "poliamidic",
    "poliamidicul": "poliamidic",
    "poliamidicului": "poliamidic",
    "poliandra": "poliandră",
    "poliandre": "poliandră",
    "poliandrei": "poliandră",
    "poliandrele": "poliandră",
    "poliandrelor": "poliandră",
    "poliarticulara": "poliarticular",
    "poliarticulară": "poliarticular",
    "poliarticulare": "poliarticular",
    "poliarticularei": "poliarticular",
    "poliarticularele": "poliarticular",
    "poliarticularelor": "poliarticular",
    "poliarticulari": "poliarticular",
    "poliarticularii": "poliarticular",
    "poliarticularilor": "poliarticular",
    "poliarticularul": "poliarticular",
    "poliarticularului": "poliarticular",
    "poliatomica": "poliatomic",
    "poliatomică": "poliatomic",
    "poliatomice": "poliatomic",
    "poliatomicei": "poliatomic",
    "poliatomicele": "poliatomic",
    "poliatomicelor": "poliatomic",
    "poliatomici": "poliatomic",
    "poliatomicii": "poliatomic",
    "poliatomicilor": "poliatomic",
    "poliatomicul": "poliatomic",
    "poliatomicului": "poliatomic",
    "polibazica": "polibazic",
    "polibazică": "polibazic",
    "polibazice": "polibazic",
    "polibazicei": "polibazic",
    "polibazicele": "polibazic",
    "polibazicelor": "polibazic",
    "polibazici": "polibazic",
    "polibazicii": "polibazic",
    "polibazicilor": "polibazic",
    "polibazicul": "polibazic",
    "polibazicului": "polibazic",
    "policandre": "policandru",
    "policandrele": "policandru",
    "policandrelor": "policandru",
    "policandrul": "policandru",
    "policandrului": "policandru",
    "policelulara": "policelular",
    "policelulară": "policelular",
    "policelulare": "policelular",
    "policelularei": "policelular",
    "policelularele": "policelular",
    "policelularelor": "policelular",
    "policelulari": "policelular",
    "policelularii": "policelular",
    "policelularilor": "policelular",
    "policelularul": "policelular",
    "policelularului": "policelular",
    "policiclica": "policiclic",
    "policiclică": "policiclic",
    "policiclice": "policiclic",
    "policiclicei": "policiclic",
    "policiclicele": "policiclic",
    "policiclicelor": "policiclic",
    "policiclici": "policiclic",
    "policiclicii": "policiclic",
    "policiclicilor": "policiclic",
    "policiclicul": "policiclic",
    "policiclicului": "policiclic",
    "policlinica": "policlinică",
    "policlinici": "policlinică",
    "policlinicii": "policlinică",
    "policlinicile": "policlinică",
    "policlinicilor": "policlinică",
    "policristalina": "policristalin",
    "policristalină": "policristalin",
    "policristaline": "policristalin",
    "policristalinei": "policristalin",
    "policristalinele": "policristalin",
    "policristalinelor": "policristalin",
    "policristalini": "policristalin",
    "policristalinii": "policristalin",
    "policristalinilor": "policristalin",
    "policristalinul": "policristalin",
    "policristalinului": "policristalin",
    "policroma": "policrom",
    "policromă": "policrom",
    "policrome": "policrom",
    "policromei": "policrom",
    "policromele": "policrom",
    "policromelor": "policrom",
    "policromi": "policrom",
    "policromii": "policrom",
    "policromilor": "policrom",
    "policromul": "policrom",
    "policromului": "policrom",
    "policromata": "policromat",
    "policromată": "policromat",
    "policromate": "policromat",
    "policromatei": "policromat",
    "policromatele": "policromat",
    "policromatelor": "policromat",
    "policromați": "policromat",
    "policromații": "policromat",
    "policromaților": "policromat",
    "policromatul": "policromat",
    "policromatului": "policromat",
    "policromia": "policromie",
    "policromiei": "policromie",
    "policromii": "policromie",
    "poliedrica": "poliedric",
    "poliedrică": "poliedric",
    "poliedrice": "poliedric",
    "poliedricei": "poliedric",
    "poliedricele": "poliedric",
    "poliedricelor": "poliedric",
    "poliedrici": "poliedric",
    "poliedricii": "poliedric",
    "poliedricilor": "poliedric",
    "poliedricul": "poliedric",
    "poliedricului": "poliedric",
    "poliedre": "poliedru",
    "poliedrele": "poliedru",
    "poliedrelor": "poliedru",
    "poliedrul": "poliedru",
    "poliedrului": "poliedru",
    "polifaga": "polifag",
    "polifagă": "polifag",
    "polifage": "polifag",
    "polifagei": "polifag",
    "polifagele": "polifag",
    "polifagelor": "polifag",
    "polifagi": "polifag",
    "polifagii": "polifag",
    "polifagilor": "polifag",
    "polifagul": "polifag",
    "polifagului": "polifag",
    "polifazata": "polifazat",
    "polifazată": "polifazat",
    "polifazate": "polifazat",
    "polifazatei": "polifazat",
    "polifazatele": "polifazat",
    "polifazatelor": "polifazat",
    "polifazați": "polifazat",
    "polifazații": "polifazat",
    "polifazaților": "polifazat",
    "polifazatul": "polifazat",
    "polifazatului": "polifazat",
    "polifonematica": "polifonematic",
    "polifonematică": "polifonematic",
    "polifonematice": "polifonematic",
    "polifonematicei": "polifonematic",
    "polifonematicele": "polifonematic",
    "polifonematicelor": "polifonematic",
    "polifonematici": "polifonematic",
    "polifonematicii": "polifonematic",
    "polifonematicilor": "polifonematic",
    "polifonematicul": "polifonematic",
    "polifonematicului": "polifonematic",
    "polifonica": "polifonic",
    "polifonică": "polifonic",
    "polifonice": "polifonic",
    "polifonicei": "polifonic",
    "polifonicele": "polifonic",
    "polifonicelor": "polifonic",
    "polifonici": "polifonic",
    "polifonicii": "polifonic",
    "polifonicilor": "polifonic",
    "polifonicul": "polifonic",
    "polifonicului": "polifonic",
    "polifonizata": "polifonizat",
    "polifonizată": "polifonizat",
    "polifonizate": "polifonizat",
    "polifonizatei": "polifonizat",
    "polifonizatele": "polifonizat",
    "polifonizatelor": "polifonizat",
    "polifonizați": "polifonizat",
    "polifonizații": "polifonizat",
    "polifonizaților": "polifonizat",
    "polifonizatul": "polifonizat",
    "polifonizatului": "polifonizat",
    "poligama": "poligam",
    "poligamă": "poligam",
    "poligame": "poligam",
    "poligamei": "poligam",
    "poligamele": "poligam",
    "poligamelor": "poligam",
    "poligami": "poligam",
    "poligamii": "poligam",
    "poligamilor": "poligam",
    "poligamul": "poligam",
    "poligamului": "poligam",
    "poligama": "poligamă",
    "poligame": "poligamă",
    "poligamei": "poligamă",
    "poligamele": "poligamă",
    "poligamelor": "poligamă",
    "poligamia": "poligamie",
    "poligamiei": "poligamie",
    "poligamii": "poligamie",
    "poliglota": "poliglot",
    "poliglotă": "poliglot",
    "poliglote": "poliglot",
    "poliglotei": "poliglot",
    "poliglotele": "poliglot",
    "poliglotelor": "poliglot",
    "poligloți": "poliglot",
    "poligloții": "poliglot",
    "poligloților": "poliglot",
    "poliglotul": "poliglot",
    "poliglotului": "poliglot",
    "poligoane": "poligon",
    "poligoanele": "poligon",
    "poligoanelor": "poligon",
    "poligonul": "poligon",
    "poligonului": "poligon",
    "poligonala": "poligonal",
    "poligonală": "poligonal",
    "poligonale": "poligonal",
    "poligonalei": "poligonal",
    "poligonalele": "poligonal",
    "poligonalelor": "poligonal",
    "poligonali": "poligonal",
    "poligonalii": "poligonal",
    "poligonalilor": "poligonal",
    "poligonalul": "poligonal",
    "poligonalului": "poligonal",
    "poligrafica": "poligrafic",
    "poligrafică": "poligrafic",
    "poligrafice": "poligrafic",
    "poligraficei": "poligrafic",
    "poligraficele": "poligrafic",
    "poligraficelor": "poligrafic",
    "poligrafici": "poligrafic",
    "poligraficii": "poligrafic",
    "poligraficilor": "poligrafic",
    "poligraficul": "poligrafic",
    "poligraficului": "poligrafic",
    "poligrafia": "poligrafie",
    "poligrafiei": "poligrafie",
    "poligrafii": "poligrafie",
    "poligrafiile": "poligrafie",
    "poligrafiilor": "poligrafie",
    "polimeri": "polimer",
    "polimerii": "polimer",
    "polimerilor": "polimer",
    "polimerul": "polimer",
    "polimerului": "polimer",
    "nemaipolimerizând": "polimeriza",
    "nemaipolimerizându": "polimeriza",
    "nepolimerizând": "polimeriza",
    "nepolimerizându": "polimeriza",
    "polimeriză": "polimeriza",
    "polimerizai": "polimeriza",
    "polimerizam": "polimeriza",
    "polimerizăm": "polimeriza",
    "polimerizând": "polimeriza",
    "polimerizându": "polimeriza",
    "polimerizară": "polimeriza",
    "polimerizarăm": "polimeriza",
    "polimerizarăți": "polimeriza",
    "polimerizase": "polimeriza",
    "polimerizasem": "polimeriza",
    "polimerizaseră": "polimeriza",
    "polimerizaserăm": "polimeriza",
    "polimerizaserăți": "polimeriza",
    "polimerizaseși": "polimeriza",
    "polimerizași": "polimeriza",
    "polimerizat": "polimeriza",
    "polimerizați": "polimeriza",
    "polimerizau": "polimeriza",
    "polimerizează": "polimeriza",
    "polimerizez": "polimeriza",
    "polimerizeze": "polimeriza",
    "polimerizezi": "polimeriza",
    "polimerizarea": "polimerizare",
    "polimerizări": "polimerizare",
    "polimerizării": "polimerizare",
    "polimerizările": "polimerizare",
    "polimerizărilor": "polimerizare",
    "polimerizată": "polimerizat",
    "polimerizate": "polimerizat",
    "polimerizați": "polimerizat",
    "polimetalica": "polimetalic",
    "polimetalică": "polimetalic",
    "polimetalice": "polimetalic",
    "polimetalicei": "polimetalic",
    "polimetalicele": "polimetalic",
    "polimetalicelor": "polimetalic",
    "polimetalici": "polimetalic",
    "polimetalicii": "polimetalic",
    "polimetalicilor": "polimetalic",
    "polimetalicul": "polimetalic",
    "polimetalicului": "polimetalic",
    "polimorfa": "polimorf",
    "polimorfă": "polimorf",
    "polimorfe": "polimorf",
    "polimorfei": "polimorf",
    "polimorfele": "polimorf",
    "polimorfelor": "polimorf",
    "polimorfi": "polimorf",
    "polimorfii": "polimorf",
    "polimorfilor": "polimorf",
    "polimorful": "polimorf",
    "polimorfului": "polimorf",
    "polimorfisme": "polimorfism",
    "polimorfismele": "polimorfism",
    "polimorfismelor": "polimorfism",
    "polimorfismul": "polimorfism",
    "polimorfismului": "polimorfism",
    "polinoame": "polinom",
    "polinoamele": "polinom",
    "polinoamelor": "polinom",
    "polinomul": "polinom",
    "polinomului": "polinom",
    "polinucleara": "polinuclear",
    "polinucleară": "polinuclear",
    "polinucleare": "polinuclear",
    "polinuclearei": "polinuclear",
    "polinuclearele": "polinuclear",
    "polinuclearelor": "polinuclear",
    "polinucleari": "polinuclear",
    "polinuclearii": "polinuclear",
    "polinuclearilor": "polinuclear",
    "polinuclearul": "polinuclear",
    "polinuclearului": "polinuclear",
    "poliomelita": "poliomelită",
    "poliomelite": "poliomelită",
    "poliomelitei": "poliomelită",
    "poliomelitele": "poliomelită",
    "poliomelitelor": "poliomelită",
    "poliomielitica": "poliomielitic",
    "poliomielitică": "poliomielitic",
    "poliomielitice": "poliomielitic",
    "poliomieliticei": "poliomielitic",
    "poliomieliticele": "poliomielitic",
    "poliomieliticelor": "poliomielitic",
    "poliomielitici": "poliomielitic",
    "poliomieliticii": "poliomielitic",
    "poliomieliticilor": "poliomielitic",
    "poliomieliticul": "poliomielitic",
    "poliomieliticului": "poliomielitic",
    "polipi": "polip",
    "polipii": "polip",
    "polipilor": "polip",
    "polipul": "polip",
    "polipului": "polip",
    "polipetala": "polipetal",
    "polipetală": "polipetal",
    "polipetale": "polipetal",
    "polipetalei": "polipetal",
    "polipetalele": "polipetal",
    "polipetalelor": "polipetal",
    "polipetali": "polipetal",
    "polipetalii": "polipetal",
    "polipetalilor": "polipetal",
    "polipetalul": "polipetal",
    "polipetalului": "polipetal",
    "poliploida": "poliploid",
    "poliploidă": "poliploid",
    "poliploide": "poliploid",
    "poliploidei": "poliploid",
    "poliploidele": "poliploid",
    "poliploidelor": "poliploid",
    "poliploidul": "poliploid",
    "poliploidului": "poliploid",
    "poliploizi": "poliploid",
    "poliploizii": "poliploid",
    "poliploizilor": "poliploid",
    "polipoda": "polipod",
    "polipodă": "polipod",
    "polipode": "polipod",
    "polipodei": "polipod",
    "polipodele": "polipod",
    "polipodelor": "polipod",
    "polipodul": "polipod",
    "polipodului": "polipod",
    "polipozi": "polipod",
    "polipozii": "polipod",
    "polipozilor": "polipod",
    "polisemantica": "polisemantic",
    "polisemantică": "polisemantic",
    "polisemantice": "polisemantic",
    "polisemanticei": "polisemantic",
    "polisemanticele": "polisemantic",
    "polisemanticelor": "polisemantic",
    "polisemantici": "polisemantic",
    "polisemanticii": "polisemantic",
    "polisemanticilor": "polisemantic",
    "polisemanticul": "polisemantic",
    "polisemanticului": "polisemantic",
    "polisemica": "polisemic",
    "polisemică": "polisemic",
    "polisemice": "polisemic",
    "polisemicei": "polisemic",
    "polisemicele": "polisemic",
    "polisemicelor": "polisemic",
    "polisemici": "polisemic",
    "polisemicii": "polisemic",
    "polisemicilor": "polisemic",
    "polisemicul": "polisemic",
    "polisemicului": "polisemic",
    "polisemia": "polisemie",
    "polisemiei": "polisemie",
    "polisemii": "polisemie",
    "polisepala": "polisepal",
    "polisepală": "polisepal",
    "polisepale": "polisepal",
    "polisepalei": "polisepal",
    "polisepalele": "polisepal",
    "polisepalelor": "polisepal",
    "polisepali": "polisepal",
    "polisepalii": "polisepal",
    "polisepalilor": "polisepal",
    "polisepalul": "polisepal",
    "polisepalului": "polisepal",
    "polisilabica": "polisilabic",
    "polisilabică": "polisilabic",
    "polisilabice": "polisilabic",
    "polisilabicei": "polisilabic",
    "polisilabicele": "polisilabic",
    "polisilabicelor": "polisilabic",
    "polisilabici": "polisilabic",
    "polisilabicii": "polisilabic",
    "polisilabicilor": "polisilabic",
    "polisilabicul": "polisilabic",
    "polisilabicului": "polisilabic",
    "polisilogisme": "polisilogism",
    "polisilogismele": "polisilogism",
    "polisilogismelor": "polisilogism",
    "polisilogismul": "polisilogism",
    "polisilogismului": "polisilogism",
    "polisintetica": "polisintetic",
    "polisintetică": "polisintetic",
    "polisintetice": "polisintetic",
    "polisinteticei": "polisintetic",
    "polisinteticele": "polisintetic",
    "polisinteticelor": "polisintetic",
    "polisintetici": "polisintetic",
    "polisinteticii": "polisintetic",
    "polisinteticilor": "polisintetic",
    "polisinteticul": "polisintetic",
    "polisinteticului": "polisintetic",
    "polisportiva": "polisportiv",
    "polisportivă": "polisportiv",
    "polisportive": "polisportiv",
    "polisportivei": "polisportiv",
    "polisportivele": "polisportiv",
    "polisportivelor": "polisportiv",
    "polisportivi": "polisportiv",
    "polisportivii": "polisportiv",
    "polisportivilor": "polisportiv",
    "polisportivul": "polisportiv",
    "polisportivului": "polisportiv",
    "polița": "poliță",
    "polițe": "poliță",
    "poliței": "poliță",
    "polițele": "poliță",
    "polițelor": "poliță",
    "poliți": "poliță",
    "polițaii": "polițai",
    "polițailor": "polițai",
    "polițaiul": "polițai",
    "polițaiului": "polițai",
    "politehnica": "politehnic",
    "politehnică": "politehnic",
    "politehnice": "politehnic",
    "politehnicei": "politehnic",
    "politehnicele": "politehnic",
    "politehnicelor": "politehnic",
    "politehnici": "politehnic",
    "politehnicii": "politehnic",
    "politehnicilor": "politehnic",
    "politehnicul": "politehnic",
    "politehnicului": "politehnic",
    "politehnica": "politehnică",
    "politehnici": "politehnică",
    "politehnicii": "politehnică",
    "politehnicile": "politehnică",
    "politehnicilor": "politehnică",
    "politeismul": "politeism",
    "politeismului": "politeism",
    "politeista": "politeist",
    "politeistă": "politeist",
    "politeiste": "politeist",
    "politeistei": "politeist",
    "politeistele": "politeist",
    "politeistelor": "politeist",
    "politeiști": "politeist",
    "politeiștii": "politeist",
    "politeiștilor": "politeist",
    "politeistul": "politeist",
    "politeistului": "politeist",
    "politețea": "politețe",
    "politeți": "politețe",
    "politeții": "politețe",
    "politețile": "politețe",
    "politeților": "politețe",
    "politețuri": "politețe",
    "politețurile": "politețe",
    "politețurilor": "politețe",
    "politica": "politic",
    "politică": "politic",
    "politice": "politic",
    "politicei": "politic",
    "politicele": "politic",
    "politicelor": "politic",
    "politici": "politic",
    "politicii": "politic",
    "politicilor": "politic",
    "politicul": "politic",
    "politicului": "politic",
    "politica": "politică",
    "politici": "politică",
    "politicii": "politică",
    "politicile": "politică",
    "politicilor": "politică",
    "politiceasca": "politicesc",
    "politicească": "politicesc",
    "politicescul": "politicesc",
    "politicescului": "politicesc",
    "politicești": "politicesc",
    "politiceștii": "politicesc",
    "politiceștile": "politicesc",
    "politiceștilor": "politicesc",
    "politicianul": "politician",
    "politicianului": "politician",
    "politicieni": "politician",
    "politicienii": "politician",
    "politicienilor": "politician",
    "politicianismul": "politicianism",
    "politicianismului": "politicianism",
    "politicianista": "politicianist",
    "politicianistă": "politicianist",
    "politicianiste": "politicianist",
    "politicianistei": "politicianist",
    "politicianistele": "politicianist",
    "politicianistelor": "politicianist",
    "politicianiști": "politicianist",
    "politicianiștii": "politicianist",
    "politicianiștilor": "politicianist",
    "politicianistul": "politicianist",
    "politicianistului": "politicianist",
    "politico-economice": "politico-economic",
    "politico-ideologice": "politico-ideologic",
    "politicoasa": "politicos",
    "politicoasă": "politicos",
    "politicoase": "politicos",
    "politicoasei": "politicos",
    "politicoasele": "politicos",
    "politicoaselor": "politicos",
    "politicoși": "politicos",
    "politicoșii": "politicos",
    "politicoșilor": "politicos",
    "politicosul": "politicos",
    "politicosului": "politicos",
    "poliția": "poliție",
    "poliției": "poliție",
    "poliții": "poliție",
    "polițiile": "poliție",
    "polițiilor": "poliție",
    "polițieneasca": "polițienesc",
    "polițienească": "polițienesc",
    "polițienescul": "polițienesc",
    "polițienescului": "polițienesc",
    "polițienești": "polițienesc",
    "polițieneștii": "polițienesc",
    "polițieneștile": "polițienesc",
    "polițieneștilor": "polițienesc",
    "polițista": "polițist",
    "polițistă": "polițist",
    "polițiste": "polițist",
    "polițistei": "polițist",
    "polițistele": "polițist",
    "polițistelor": "polițist",
    "polițiști": "polițist",
    "polițiștii": "polițist",
    "polițiștilor": "polițist",
    "polițistul": "polițist",
    "polițistului": "polițist",
    "nemaipolitizând": "politiza",
    "nemaipolitizându": "politiza",
    "nepolitizând": "politiza",
    "nepolitizându": "politiza",
    "politiză": "politiza",
    "politizai": "politiza",
    "politizam": "politiza",
    "politizăm": "politiza",
    "politizând": "politiza",
    "politizându": "politiza",
    "politizară": "politiza",
    "politizarăm": "politiza",
    "politizarăți": "politiza",
    "politizase": "politiza",
    "politizasem": "politiza",
    "politizaseră": "politiza",
    "politizaserăm": "politiza",
    "politizaserăți": "politiza",
    "politizaseși": "politiza",
    "politizași": "politiza",
    "politizat": "politiza",
    "politizați": "politiza",
    "politizau": "politiza",
    "politizează": "politiza",
    "politizez": "politiza",
    "politizeze": "politiza",
    "politizezi": "politiza",
    "politizată": "politizat",
    "politizate": "politizat",
    "politizați": "politizat",
    "polivalenta": "polivalent",
    "polivalentă": "polivalent",
    "polivalente": "polivalent",
    "polivalentei": "polivalent",
    "polivalentele": "polivalent",
    "polivalentelor": "polivalent",
    "polivalenți": "polivalent",
    "polivalenții": "polivalent",
    "polivalenților": "polivalent",
    "polivalentul": "polivalent",
    "polivalentului": "polivalent",
    "polivalența": "polivalență",
    "polivalențe": "polivalență",
    "polivalenței": "polivalență",
    "polivalențele": "polivalență",
    "polivalențelor": "polivalență",
    "polivitamina": "polivitamină",
    "polivitamine": "polivitamină",
    "polivitaminei": "polivitamină",
    "polivitaminele": "polivitamină",
    "polivitaminelor": "polivitamină",
    "polizoare": "polizor",
    "polizoarele": "polizor",
    "polizoarelor": "polizor",
    "polizorul": "polizor",
    "polizorului": "polizor",
    "Polizul": "Polizu",
    "Polizului": "Polizu",
    "poloul": "polo",
    "poloului": "polo",
    "poloboace": "poloboc",
    "poloboacele": "poloboc",
    "poloboacelor": "poloboc",
    "polobocul": "poloboc",
    "polobocului": "poloboc",
    "polologhia": "polologhie",
    "polologhiei": "polologhie",
    "polologhii": "polologhie",
    "polologhiile": "polologhie",
    "polologhiilor": "polologhie",
    "polona": "polon",
    "polonă": "polon",
    "polone": "polon",
    "polonei": "polon",
    "polonele": "polon",
    "polonelor": "polon",
    "poloni": "polon",
    "polonii": "polon",
    "polonilor": "polon",
    "polonul": "polon",
    "polonului": "polon",
    "poloneza": "polonez",
    "poloneză": "polonez",
    "poloneze": "polonez",
    "polonezei": "polonez",
    "polonezele": "polonez",
    "polonezelor": "polonez",
    "polonezi": "polonez",
    "polonezii": "polonez",
    "polonezilor": "polonez",
    "polonezul": "polonez",
    "polonezului": "polonez",
    "poloneza": "poloneză",
    "poloneze": "poloneză",
    "polonezei": "poloneză",
    "polonezele": "poloneză",
    "polonezelor": "poloneză",
    "Poloniei": "Polonia",
    "polonice": "polonic",
    "polonicele": "polonic",
    "polonicelor": "polonic",
    "polonicul": "polonic",
    "polonicului": "polonic",
    "poloniul": "poloniu",
    "poloniului": "poloniu",
    "poltrona": "poltron",
    "poltronă": "poltron",
    "poltrone": "poltron",
    "poltronei": "poltron",
    "poltronele": "poltron",
    "poltronelor": "poltron",
    "poltroni": "poltron",
    "poltronii": "poltron",
    "poltronilor": "poltron",
    "poltronul": "poltron",
    "poltronului": "poltron",
    "nemaipoluând": "polua",
    "nemaipoluându": "polua",
    "nepoluând": "polua",
    "nepoluându": "polua",
    "poluă": "polua",
    "poluai": "polua",
    "poluam": "polua",
    "poluăm": "polua",
    "poluând": "polua",
    "poluându": "polua",
    "poluară": "polua",
    "poluarăm": "polua",
    "poluarăți": "polua",
    "poluase": "polua",
    "poluasem": "polua",
    "poluaseră": "polua",
    "poluaserăm": "polua",
    "poluaserăți": "polua",
    "poluaseși": "polua",
    "poluași": "polua",
    "poluat": "polua",
    "poluați": "polua",
    "poluau": "polua",
    "poluează": "polua",
    "poluez": "polua",
    "polueze": "polua",
    "poluezi": "polua",
    "poluanta": "poluant",
    "poluantă": "poluant",
    "poluante": "poluant",
    "poluantei": "poluant",
    "poluantele": "poluant",
    "poluantelor": "poluant",
    "poluanți": "poluant",
    "poluanții": "poluant",
    "poluanților": "poluant",
    "poluantul": "poluant",
    "poluantului": "poluant",
    "poluată": "poluat",
    "poluate": "poluat",
    "poluați": "poluat",
    "Polului_Nord": "Polul_Nord",
    "poluția": "poluție",
    "poluției": "poluție",
    "poluții": "poluție",
    "poluțiile": "poluție",
    "poluțiilor": "poluție",
    "pomi": "pom",
    "pomii": "pom",
    "pomilor": "pom",
    "pomul": "pom",
    "pomului": "pom",
    "pomada": "pomadă",
    "pomezi": "pomadă",
    "pomezii": "pomadă",
    "pomezile": "pomadă",
    "pomezilor": "pomadă",
    "pomana": "pomană",
    "pomeni": "pomană",
    "pomenii": "pomană",
    "pomenile": "pomană",
    "pomenilor": "pomană",
    "pomanagii": "pomanagiu",
    "pomanagiii": "pomanagiu",
    "pomanagiilor": "pomanagiu",
    "pomanagiul": "pomanagiu",
    "pomanagiului": "pomanagiu",
    "pomelnice": "pomelnic",
    "pomelnicele": "pomelnic",
    "pomelnicelor": "pomelnic",
    "pomelnicul": "pomelnic",
    "pomelnicului": "pomelnic",
    "nemaipomenind": "pomeni",
    "nemaipomenindu": "pomeni",
    "nepomenind": "pomeni",
    "nepomenindu": "pomeni",
    "pomenea": "pomeni",
    "pomeneai": "pomeni",
    "pomeneam": "pomeni",
    "pomenească": "pomeni",
    "pomeneați": "pomeni",
    "pomeneau": "pomeni",
    "pomenesc": "pomeni",
    "pomenește": "pomeni",
    "pomenești": "pomeni",
    "pomeni'": "pomeni",
    "pomenii": "pomeni",
    "pomenim": "pomeni",
    "pomenind": "pomeni",
    "pomenindu": "pomeni",
    "pomeniră": "pomeni",
    "pomenirăm": "pomeni",
    "pomenirăți": "pomeni",
    "pomenise": "pomeni",
    "pomenisem": "pomeni",
    "pomeniseră": "pomeni",
    "pomeniserăm": "pomeni",
    "pomeniserăți": "pomeni",
    "pomeniseși": "pomeni",
    "pomeniși": "pomeni",
    "pomenit": "pomeni",
    "pomeniți": "pomeni",
    "pomenirea": "pomenire",
    "pomeniri": "pomenire",
    "pomenirii": "pomenire",
    "pomenirile": "pomenire",
    "pomenirilor": "pomenire",
    "pomeni'": "pomenit",
    "pomenita": "pomenit",
    "pomenită": "pomenit",
    "pomenite": "pomenit",
    "pomenitei": "pomenit",
    "pomenitele": "pomenit",
    "pomenitelor": "pomenit",
    "pomeniți": "pomenit",
    "pomeniții": "pomenit",
    "pomeniților": "pomenit",
    "pomenitul": "pomenit",
    "pomenitului": "pomenit",
    "pomeții": "pomeți",
    "pomeților": "pomeți",
    "pomicola": "pomicol",
    "pomicolă": "pomicol",
    "pomicole": "pomicol",
    "pomicolei": "pomicol",
    "pomicolele": "pomicol",
    "pomicolelor": "pomicol",
    "pomicoli": "pomicol",
    "pomicolii": "pomicol",
    "pomicolilor": "pomicol",
    "pomicolul": "pomicol",
    "pomicolului": "pomicol",
    "pomicultura": "pomicultură",
    "pomiculturi": "pomicultură",
    "pomiculturii": "pomicultură",
    "pomina": "pomină",
    "pomine": "pomină",
    "pominei": "pomină",
    "pomologica": "pomologic",
    "pomologică": "pomologic",
    "pomologice": "pomologic",
    "pomologicei": "pomologic",
    "pomologicele": "pomologic",
    "pomologicelor": "pomologic",
    "pomologici": "pomologic",
    "pomologicii": "pomologic",
    "pomologicilor": "pomologic",
    "pomologicul": "pomologic",
    "pomologicului": "pomologic",
    "nemaipompând": "pompa",
    "nemaipompându": "pompa",
    "nepompând": "pompa",
    "nepompându": "pompa",
    "pompă": "pompa",
    "pompai": "pompa",
    "pompam": "pompa",
    "pompăm": "pompa",
    "pompând": "pompa",
    "pompându": "pompa",
    "pompară": "pompa",
    "pomparăm": "pompa",
    "pomparăți": "pompa",
    "pompase": "pompa",
    "pompasem": "pompa",
    "pompaseră": "pompa",
    "pompaserăm": "pompa",
    "pompaserăți": "pompa",
    "pompaseși": "pompa",
    "pompași": "pompa",
    "pompat": "pompa",
    "pompați": "pompa",
    "pompau": "pompa",
    "pompează": "pompa",
    "pompez": "pompa",
    "pompeze": "pompa",
    "pompezi": "pompa",
    "pompa": "pompă",
    "pompe": "pompă",
    "pompei": "pompă",
    "pompele": "pompă",
    "pompelor": "pompă",
    "pomparea": "pompare",
    "pompări": "pompare",
    "pompării": "pompare",
    "pompările": "pompare",
    "pompărilor": "pompare",
    "pompată": "pompat",
    "pompate": "pompat",
    "pompați": "pompat",
    "pompeiana": "pompeian",
    "pompeiană": "pompeian",
    "pompeianul": "pompeian",
    "pompeianului": "pompeian",
    "pompeiene": "pompeian",
    "pompeienei": "pompeian",
    "pompeienele": "pompeian",
    "pompeienelor": "pompeian",
    "pompeieni": "pompeian",
    "pompeienii": "pompeian",
    "pompeienilor": "pompeian",
    "pompieri": "pompier",
    "pompierii": "pompier",
    "pompierilor": "pompier",
    "pompierul": "pompier",
    "pompierului": "pompier",
    "pompiereasca": "pompieresc",
    "pompierească": "pompieresc",
    "pompierescul": "pompieresc",
    "pompierescului": "pompieresc",
    "pompierești": "pompieresc",
    "pompiereștii": "pompieresc",
    "pompiereștile": "pompieresc",
    "pompiereștilor": "pompieresc",
    "pompoane": "pompon",
    "pompoanele": "pompon",
    "pompoanelor": "pompon",
    "pomponul": "pompon",
    "pomponului": "pompon",
    "pompoasa": "pompos",
    "pompoasă": "pompos",
    "pompoase": "pompos",
    "pompoasei": "pompos",
    "pompoasele": "pompos",
    "pompoaselor": "pompos",
    "pompoși": "pompos",
    "pompoșii": "pompos",
    "pompoșilor": "pompos",
    "pomposul": "pompos",
    "pomposului": "pompos",
    "poncișa": "ponciș",
    "poncișă": "ponciș",
    "poncișe": "ponciș",
    "poncișei": "ponciș",
    "poncișele": "ponciș",
    "poncișelor": "ponciș",
    "ponciși": "ponciș",
    "poncișii": "ponciș",
    "poncișilor": "ponciș",
    "poncișul": "ponciș",
    "poncișului": "ponciș",
    "ponderabila": "ponderabil",
    "ponderabilă": "ponderabil",
    "ponderabile": "ponderabil",
    "ponderabilei": "ponderabil",
    "ponderabilele": "ponderabil",
    "ponderabilelor": "ponderabil",
    "ponderabili": "ponderabil",
    "ponderabilii": "ponderabil",
    "ponderabililor": "ponderabil",
    "ponderabilul": "ponderabil",
    "ponderabilului": "ponderabil",
    "ponderala": "ponderal",
    "ponderală": "ponderal",
    "ponderale": "ponderal",
    "ponderalei": "ponderal",
    "ponderalele": "ponderal",
    "ponderalelor": "ponderal",
    "ponderali": "ponderal",
    "ponderalii": "ponderal",
    "ponderalilor": "ponderal",
    "ponderalul": "ponderal",
    "ponderalului": "ponderal",
    "ponderatoare": "ponderator",
    "ponderatoarea": "ponderator",
    "ponderatoarei": "ponderator",
    "ponderatoarele": "ponderator",
    "ponderatoarelor": "ponderator",
    "ponderatori": "ponderator",
    "ponderatorii": "ponderator",
    "ponderatorilor": "ponderator",
    "ponderatorul": "ponderator",
    "ponderatorului": "ponderator",
    "ponderea": "pondere",
    "ponderi": "pondere",
    "ponderii": "pondere",
    "ponderile": "pondere",
    "ponderilor": "pondere",
    "nemaiponegrind": "ponegri",
    "nemaiponegrindu": "ponegri",
    "neponegrind": "ponegri",
    "neponegrindu": "ponegri",
    "ponegrea": "ponegri",
    "ponegreai": "ponegri",
    "ponegream": "ponegri",
    "ponegrească": "ponegri",
    "ponegreați": "ponegri",
    "ponegreau": "ponegri",
    "ponegresc": "ponegri",
    "ponegrește": "ponegri",
    "ponegrești": "ponegri",
    "ponegrii": "ponegri",
    "ponegrim": "ponegri",
    "ponegrind": "ponegri",
    "ponegrindu": "ponegri",
    "ponegriră": "ponegri",
    "ponegrirăm": "ponegri",
    "ponegrirăți": "ponegri",
    "ponegrise": "ponegri",
    "ponegrisem": "ponegri",
    "ponegriseră": "ponegri",
    "ponegriserăm": "ponegri",
    "ponegriserăți": "ponegri",
    "ponegriseși": "ponegri",
    "ponegriși": "ponegri",
    "ponegrit": "ponegri",
    "ponegriți": "ponegri",
    "ponegrirea": "ponegrire",
    "ponegriri": "ponegrire",
    "ponegririi": "ponegrire",
    "ponegririle": "ponegrire",
    "ponegririlor": "ponegrire",
    "ponegrită": "ponegrit",
    "ponegrite": "ponegrit",
    "ponegriți": "ponegrit",
    "ponegritoare": "ponegritor",
    "ponegritoarea": "ponegritor",
    "ponegritoarei": "ponegritor",
    "ponegritoarele": "ponegritor",
    "ponegritoarelor": "ponegritor",
    "ponegritori": "ponegritor",
    "ponegritorii": "ponegritor",
    "ponegritorilor": "ponegritor",
    "ponegritorul": "ponegritor",
    "ponegritorului": "ponegritor",
    "poneii": "ponei",
    "poneilor": "ponei",
    "poneiul": "ponei",
    "poneiului": "ponei",
    "ponivoasa": "ponivos",
    "ponivoasă": "ponivos",
    "ponivoase": "ponivos",
    "ponivoasei": "ponivos",
    "ponivoasele": "ponivos",
    "ponivoaselor": "ponivos",
    "ponivoși": "ponivos",
    "ponivoșii": "ponivos",
    "ponivoșilor": "ponivos",
    "ponivosul": "ponivos",
    "ponivosului": "ponivos",
    "ponoare": "ponor",
    "ponoarele": "ponor",
    "ponoarelor": "ponor",
    "ponorul": "ponor",
    "ponorului": "ponor",
    "ponoase": "ponos",
    "ponoasele": "ponos",
    "ponoaselor": "ponos",
    "nemaiponosind": "ponosi",
    "nemaiponosindu": "ponosi",
    "neponosind": "ponosi",
    "neponosindu": "ponosi",
    "ponosea": "ponosi",
    "ponoseai": "ponosi",
    "ponoseam": "ponosi",
    "ponosească": "ponosi",
    "ponoseați": "ponosi",
    "ponoseau": "ponosi",
    "ponosesc": "ponosi",
    "ponosește": "ponosi",
    "ponosești": "ponosi",
    "ponosii": "ponosi",
    "ponosim": "ponosi",
    "ponosind": "ponosi",
    "ponosindu": "ponosi",
    "ponosiră": "ponosi",
    "ponosirăm": "ponosi",
    "ponosirăți": "ponosi",
    "ponosise": "ponosi",
    "ponosisem": "ponosi",
    "ponosiseră": "ponosi",
    "ponosiserăm": "ponosi",
    "ponosiserăți": "ponosi",
    "ponosiseși": "ponosi",
    "ponosiși": "ponosi",
    "ponosit": "ponosi",
    "ponosiți": "ponosi",
    "ponosită": "ponosit",
    "ponosite": "ponosit",
    "ponosiți": "ponosit",
    "pontul": "pont",
    "pontului": "pont",
    "ponturi": "pont",
    "ponturile": "pont",
    "ponturilor": "pont",
    "nemaipontând": "ponta",
    "nemaipontându": "ponta",
    "nepontând": "ponta",
    "nepontându": "ponta",
    "pontai": "ponta",
    "pontam": "ponta",
    "pontăm": "ponta",
    "pontând": "ponta",
    "pontându": "ponta",
    "pontară": "ponta",
    "pontarăm": "ponta",
    "pontarăți": "ponta",
    "pontase": "ponta",
    "pontasem": "ponta",
    "pontaseră": "ponta",
    "pontaserăm": "ponta",
    "pontaserăți": "ponta",
    "pontaseși": "ponta",
    "pontași": "ponta",
    "pontat": "ponta",
    "pontați": "ponta",
    "pontau": "ponta",
    "pontează": "ponta",
    "pontez": "ponta",
    "ponteze": "ponta",
    "pontezi": "ponta",
    "pontaje": "pontaj",
    "pontajele": "pontaj",
    "pontajelor": "pontaj",
    "pontajul": "pontaj",
    "pontajului": "pontaj",
    "pontată": "pontat",
    "pontate": "pontat",
    "pontați": "pontat",
    "pontatori": "pontator",
    "pontatorii": "pontator",
    "pontatorilor": "pontator",
    "pontatorul": "pontator",
    "pontatorului": "pontator",
    "ponțiana": "ponțian",
    "ponțiană": "ponțian",
    "ponțianul": "ponțian",
    "ponțianului": "ponțian",
    "ponțiene": "ponțian",
    "ponțienei": "ponțian",
    "ponțienele": "ponțian",
    "ponțienelor": "ponțian",
    "ponțieni": "ponțian",
    "ponțienii": "ponțian",
    "ponțienilor": "ponțian",
    "pontica": "pontic",
    "pontică": "pontic",
    "pontice": "pontic",
    "ponticei": "pontic",
    "ponticele": "pontic",
    "ponticelor": "pontic",
    "pontici": "pontic",
    "ponticii": "pontic",
    "ponticilor": "pontic",
    "ponticul": "pontic",
    "ponticului": "pontic",
    "pontificala": "pontifical",
    "pontificală": "pontifical",
    "pontificale": "pontifical",
    "pontificalei": "pontifical",
    "pontificalele": "pontifical",
    "pontificalelor": "pontifical",
    "pontificali": "pontifical",
    "pontificalii": "pontifical",
    "pontificalilor": "pontifical",
    "pontificalul": "pontifical",
    "pontificalului": "pontifical",
    "pontoane": "ponton",
    "pontoanele": "ponton",
    "pontoanelor": "ponton",
    "pontonul": "ponton",
    "pontonului": "ponton",
    "pontonieri": "pontonier",
    "pontonierii": "pontonier",
    "pontonierilor": "pontonier",
    "pontonierul": "pontonier",
    "pontonierului": "pontonier",
    "popa": "popă",
    "popi": "popă",
    "popii": "popă",
    "popilor": "popă",
    "popândoaca": "popândoc",
    "popândoacă": "popândoc",
    "popândoace": "popândoc",
    "popândoacei": "popândoc",
    "popândoacele": "popândoc",
    "popândoacelor": "popândoc",
    "popândoci": "popândoc",
    "popândocii": "popândoc",
    "popândocilor": "popândoc",
    "popândocul": "popândoc",
    "popândocului": "popândoc",
    "popasul": "popas",
    "popasului": "popas",
    "popasuri": "popas",
    "popasurile": "popas",
    "popasurilor": "popas",
    "popeasca": "popesc",
    "popească": "popesc",
    "popescul": "popesc",
    "popescului": "popesc",
    "popești": "popesc",
    "popeștii": "popesc",
    "popeștile": "popesc",
    "popeștilor": "popesc",
    "nemaipopind": "popi",
    "nemaipopindu": "popi",
    "nepopind": "popi",
    "nepopindu": "popi",
    "popea": "popi",
    "popeai": "popi",
    "popeam": "popi",
    "popească": "popi",
    "popeați": "popi",
    "popeau": "popi",
    "popesc": "popi",
    "popește": "popi",
    "popești": "popi",
    "popii": "popi",
    "popim": "popi",
    "popind": "popi",
    "popindu": "popi",
    "popiră": "popi",
    "popirăm": "popi",
    "popirăți": "popi",
    "popise": "popi",
    "popisem": "popi",
    "popiseră": "popi",
    "popiserăm": "popi",
    "popiserăți": "popi",
    "popiseși": "popi",
    "popiși": "popi",
    "popit": "popi",
    "popiți": "popi",
    "popice": "popic",
    "popicele": "popic",
    "popicelor": "popic",
    "popicul": "popic",
    "popicului": "popic",
    "popicari": "popicar",
    "popicarii": "popicar",
    "popicarilor": "popicar",
    "popicarul": "popicar",
    "popicarului": "popicar",
    "popicăria": "popicărie",
    "popicăriei": "popicărie",
    "popicării": "popicărie",
    "popicăriile": "popicărie",
    "popicăriilor": "popicărie",
    "popită": "popit",
    "popite": "popit",
    "popiți": "popit",
    "poplinul": "poplin",
    "poplinului": "poplin",
    "poplinuri": "poplin",
    "poplinurile": "poplin",
    "poplinurilor": "poplin",
    "popoare": "popor",
    "popoarele": "popor",
    "popoarelor": "popor",
    "poporul": "popor",
    "poporului": "popor",
    "poporala": "poporal",
    "poporală": "poporal",
    "poporale": "poporal",
    "poporalei": "poporal",
    "poporalele": "poporal",
    "poporalelor": "poporal",
    "poporali": "poporal",
    "poporalii": "poporal",
    "poporalilor": "poporal",
    "poporalul": "poporal",
    "poporalului": "poporal",
    "poporana": "poporan",
    "poporană": "poporan",
    "poporane": "poporan",
    "poporanei": "poporan",
    "poporanele": "poporan",
    "poporanelor": "poporan",
    "poporani": "poporan",
    "poporanii": "poporan",
    "poporanilor": "poporan",
    "poporanul": "poporan",
    "poporanului": "poporan",
    "poporanista": "poporanist",
    "poporanistă": "poporanist",
    "poporaniste": "poporanist",
    "poporanistei": "poporanist",
    "poporanistele": "poporanist",
    "poporanistelor": "poporanist",
    "poporaniști": "poporanist",
    "poporaniștii": "poporanist",
    "poporaniștilor": "poporanist",
    "poporanistul": "poporanist",
    "poporanistului": "poporanist",
    "poporoasa": "poporos",
    "poporoasă": "poporos",
    "poporoase": "poporos",
    "poporoasei": "poporos",
    "poporoasele": "poporos",
    "poporoaselor": "poporos",
    "poporoși": "poporos",
    "poporoșii": "poporos",
    "poporoșilor": "poporos",
    "poporosul": "poporos",
    "poporosului": "poporos",
    "nemaipoposind": "poposi",
    "nemaipoposindu": "poposi",
    "nepoposind": "poposi",
    "nepoposindu": "poposi",
    "poposea": "poposi",
    "poposeai": "poposi",
    "poposeam": "poposi",
    "poposească": "poposi",
    "poposeați": "poposi",
    "poposeau": "poposi",
    "poposesc": "poposi",
    "poposește": "poposi",
    "poposești": "poposi",
    "poposii": "poposi",
    "poposim": "poposi",
    "poposind": "poposi",
    "poposindu": "poposi",
    "poposiră": "poposi",
    "poposirăm": "poposi",
    "poposirăți": "poposi",
    "poposise": "poposi",
    "poposisem": "poposi",
    "poposiseră": "poposi",
    "poposiserăm": "poposi",
    "poposiserăți": "poposi",
    "poposiseși": "poposi",
    "poposiși": "poposi",
    "poposit": "poposi",
    "poposiți": "poposi",
    "poposită": "poposit",
    "poposite": "poposit",
    "poposiți": "poposit",
    "popritoare": "popritor",
    "popritoarea": "popritor",
    "popritoarei": "popritor",
    "popritoarele": "popritor",
    "popritoarelor": "popritor",
    "popritori": "popritor",
    "popritorii": "popritor",
    "popritorilor": "popritor",
    "popritorul": "popritor",
    "popritorului": "popritor",
    "nemaipopulând": "popula",
    "nemaipopulându": "popula",
    "nepopulând": "popula",
    "nepopulându": "popula",
    "populă": "popula",
    "populai": "popula",
    "populam": "popula",
    "populăm": "popula",
    "populând": "popula",
    "populându": "popula",
    "populară": "popula",
    "popularăm": "popula",
    "popularăți": "popula",
    "populase": "popula",
    "populasem": "popula",
    "populaseră": "popula",
    "populaserăm": "popula",
    "populaserăți": "popula",
    "populaseși": "popula",
    "populași": "popula",
    "populat": "popula",
    "populați": "popula",
    "populau": "popula",
    "populează": "popula",
    "populez": "popula",
    "populeze": "popula",
    "populezi": "popula",
    "populara": "popular",
    "populară": "popular",
    "populare": "popular",
    "popularei": "popular",
    "popularele": "popular",
    "popularelor": "popular",
    "populari": "popular",
    "popularii": "popular",
    "popularilor": "popular",
    "popularul": "popular",
    "popularului": "popular",
    "popularitatea": "popularitate",
    "popularități": "popularitate",
    "popularității": "popularitate",
    "popularitățile": "popularitate",
    "popularităților": "popularitate",
    "nemaipopularizând": "populariza",
    "nemaipopularizându": "populariza",
    "nepopularizând": "populariza",
    "nepopularizându": "populariza",
    "populariză": "populariza",
    "popularizai": "populariza",
    "popularizam": "populariza",
    "popularizăm": "populariza",
    "popularizând": "populariza",
    "popularizându": "populariza",
    "popularizară": "populariza",
    "popularizarăm": "populariza",
    "popularizarăți": "populariza",
    "popularizase": "populariza",
    "popularizasem": "populariza",
    "popularizaseră": "populariza",
    "popularizaserăm": "populariza",
    "popularizaserăți": "populariza",
    "popularizaseși": "populariza",
    "popularizași": "populariza",
    "popularizat": "populariza",
    "popularizați": "populariza",
    "popularizau": "populariza",
    "popularizează": "populariza",
    "popularizez": "populariza",
    "popularizeze": "populariza",
    "popularizezi": "populariza",
    "popularizanta": "popularizant",
    "popularizantă": "popularizant",
    "popularizante": "popularizant",
    "popularizantei": "popularizant",
    "popularizantele": "popularizant",
    "popularizantelor": "popularizant",
    "popularizanți": "popularizant",
    "popularizanții": "popularizant",
    "popularizanților": "popularizant",
    "popularizantul": "popularizant",
    "popularizantului": "popularizant",
    "popularizarea": "popularizare",
    "popularizări": "popularizare",
    "popularizării": "popularizare",
    "popularizările": "popularizare",
    "popularizărilor": "popularizare",
    "popularizată": "popularizat",
    "popularizate": "popularizat",
    "popularizați": "popularizat",
    "popularizatoare": "popularizator",
    "popularizatoarea": "popularizator",
    "popularizatoarei": "popularizator",
    "popularizatoarele": "popularizator",
    "popularizatoarelor": "popularizator",
    "popularizatori": "popularizator",
    "popularizatorii": "popularizator",
    "popularizatorilor": "popularizator",
    "popularizatorul": "popularizator",
    "popularizatorului": "popularizator",
    "populata": "populat",
    "populată": "populat",
    "populate": "populat",
    "populatei": "populat",
    "populatele": "populat",
    "populatelor": "populat",
    "populați": "populat",
    "populații": "populat",
    "populaților": "populat",
    "populatul": "populat",
    "populatului": "populat",
    "populația": "populație",
    "populației": "populație",
    "populații": "populație",
    "populațiile": "populație",
    "populațiilor": "populație",
    "populismul": "populism",
    "populismului": "populism",
    "populiste": "populist",
    "pori": "por",
    "porii": "por",
    "porilor": "por",
    "porul": "por",
    "porului": "por",
    "porci": "porc",
    "porcii": "porc",
    "porcilor": "porc",
    "porcul": "porc",
    "porcule": "porc",
    "porcului": "porc",
    "porcari": "porcar",
    "porcarii": "porcar",
    "porcarilor": "porcar",
    "porcarul": "porcar",
    "porcarului": "porcar",
    "porcăria": "porcărie",
    "porcăriei": "porcărie",
    "porcării": "porcărie",
    "porcăriile": "porcărie",
    "porcăriilor": "porcărie",
    "porceasca": "porcesc",
    "porcească": "porcesc",
    "porcescul": "porcesc",
    "porcescului": "porcesc",
    "porcești": "porcesc",
    "porceștii": "porcesc",
    "porceștile": "porcesc",
    "porceștilor": "porcesc",
    "porcina": "porcin",
    "porcină": "porcin",
    "porcine": "porcin",
    "porcinei": "porcin",
    "porcinele": "porcin",
    "porcinelor": "porcin",
    "porcini": "porcin",
    "porcinii": "porcin",
    "porcinilor": "porcin",
    "porcinul": "porcin",
    "porcinului": "porcin",
    "porcoasa": "porcos",
    "porcoasă": "porcos",
    "porcoase": "porcos",
    "porcoasei": "porcos",
    "porcoasele": "porcos",
    "porcoaselor": "porcos",
    "porcoși": "porcos",
    "porcoșii": "porcos",
    "porcoșilor": "porcos",
    "porcosul": "porcos",
    "porcosului": "porcos",
    "porecla": "poreclă",
    "porecle": "poreclă",
    "poreclei": "poreclă",
    "poreclele": "poreclă",
    "poreclelor": "poreclă",
    "nemaiporeclind": "porecli",
    "nemaiporeclindu": "porecli",
    "neporeclind": "porecli",
    "neporeclindu": "porecli",
    "poreclea": "porecli",
    "porecleai": "porecli",
    "porecleam": "porecli",
    "poreclească": "porecli",
    "porecleați": "porecli",
    "porecleau": "porecli",
    "poreclesc": "porecli",
    "poreclește": "porecli",
    "poreclești": "porecli",
    "poreclii": "porecli",
    "poreclim": "porecli",
    "poreclind": "porecli",
    "poreclindu": "porecli",
    "porecliră": "porecli",
    "poreclirăm": "porecli",
    "poreclirăți": "porecli",
    "poreclise": "porecli",
    "poreclisem": "porecli",
    "porecliseră": "porecli",
    "porecliserăm": "porecli",
    "porecliserăți": "porecli",
    "porecliseși": "porecli",
    "porecliși": "porecli",
    "poreclit": "porecli",
    "porecliți": "porecli",
    "poreclita": "poreclit",
    "poreclită": "poreclit",
    "poreclite": "poreclit",
    "poreclitei": "poreclit",
    "poreclitele": "poreclit",
    "poreclitelor": "poreclit",
    "porecliți": "poreclit",
    "porecliții": "poreclit",
    "porecliților": "poreclit",
    "poreclitul": "poreclit",
    "poreclitului": "poreclit",
    "porfirica": "porfiric",
    "porfirică": "porfiric",
    "porfirice": "porfiric",
    "porfiricei": "porfiric",
    "porfiricele": "porfiric",
    "porfiricelor": "porfiric",
    "porfirici": "porfiric",
    "porfiricii": "porfiric",
    "porfiricilor": "porfiric",
    "porfiricul": "porfiric",
    "porfiricului": "porfiric",
    "porfiria": "porfiriu",
    "porfirie": "porfiriu",
    "porfiriei": "porfiriu",
    "porfirii": "porfiriu",
    "porfiriii": "porfiriu",
    "porfiriile": "porfiriu",
    "porfiriilor": "porfiriu",
    "porfiriul": "porfiriu",
    "porfiriului": "porfiriu",
    "porifera": "porifer",
    "poriferă": "porifer",
    "porifere": "porifer",
    "poriferei": "porifer",
    "poriferele": "porifer",
    "poriferelor": "porifer",
    "poriferi": "porifer",
    "poriferii": "porifer",
    "poriferilor": "porifer",
    "poriferul": "porifer",
    "poriferului": "porifer",
    "porneala": "porneală",
    "porneli": "porneală",
    "pornelii": "porneală",
    "pornelile": "porneală",
    "pornelilor": "porneală",
    "nemaipornind": "porni",
    "nemaipornindu": "porni",
    "nepornind": "porni",
    "nepornindu": "porni",
    "pornea": "porni",
    "porneai": "porni",
    "porneam": "porni",
    "pornească": "porni",
    "porneați": "porni",
    "porneau": "porni",
    "pornesc": "porni",
    "pornește": "porni",
    "pornești": "porni",
    "pornii": "porni",
    "pornim": "porni",
    "pornind": "porni",
    "pornindu": "porni",
    "porniră": "porni",
    "pornirăm": "porni",
    "pornirăți": "porni",
    "pornise": "porni",
    "pornisem": "porni",
    "porniseră": "porni",
    "porniserăm": "porni",
    "porniserăți": "porni",
    "porniseși": "porni",
    "porniși": "porni",
    "pornit": "porni",
    "porniți": "porni",
    "pornirea": "pornire",
    "porniri": "pornire",
    "pornirii": "pornire",
    "pornirile": "pornire",
    "pornirilor": "pornire",
    "pornită": "pornit",
    "pornite": "pornit",
    "porniți": "pornit",
    "pornografi": "pornograf",
    "pornografii": "pornograf",
    "pornografilor": "pornograf",
    "pornograful": "pornograf",
    "pornografului": "pornograf",
    "pornografica": "pornografic",
    "pornografică": "pornografic",
    "pornografice": "pornografic",
    "pornograficei": "pornografic",
    "pornograficele": "pornografic",
    "pornograficelor": "pornografic",
    "pornografici": "pornografic",
    "pornograficii": "pornografic",
    "pornograficilor": "pornografic",
    "pornograficul": "pornografic",
    "pornograficului": "pornografic",
    "pornografia": "pornografie",
    "pornografiei": "pornografie",
    "pornografii": "pornografie",
    "pornografiile": "pornografie",
    "pornografiilor": "pornografie",
    "poroasa": "poros",
    "poroasă": "poros",
    "poroase": "poros",
    "poroasei": "poros",
    "poroasele": "poros",
    "poroaselor": "poros",
    "poroși": "poros",
    "poroșii": "poros",
    "poroșilor": "poros",
    "porosul": "poros",
    "porosului": "poros",
    "portul": "port",
    "portului": "port",
    "porturi": "port",
    "porturile": "port",
    "porturilor": "port",
    "portanta": "portant",
    "portantă": "portant",
    "portante": "portant",
    "portantei": "portant",
    "portantele": "portant",
    "portantelor": "portant",
    "portanți": "portant",
    "portanții": "portant",
    "portanților": "portant",
    "portantul": "portant",
    "portantului": "portant",
    "portari": "portar",
    "portarii": "portar",
    "portarilor": "portar",
    "portarul": "portar",
    "portarului": "portar",
    "portativa": "portativ",
    "portativă": "portativ",
    "portative": "portativ",
    "portativei": "portativ",
    "portativele": "portativ",
    "portativelor": "portativ",
    "portativi": "portativ",
    "portativii": "portativ",
    "portativilor": "portativ",
    "portativul": "portativ",
    "portativului": "portativ",
    "portavioane": "portavion",
    "portavioanele": "portavion",
    "portavioanelor": "portavion",
    "portavionul": "portavion",
    "portavionului": "portavion",
    "portavocele": "portavoce",
    "portavocelor": "portavoce",
    "portavocelui": "portavoce",
    "portbagaje": "portbagaj",
    "portbagajele": "portbagaj",
    "portbagajelor": "portbagaj",
    "portbagajul": "portbagaj",
    "portbagajului": "portbagaj",
    "portcheie": "portchei",
    "portcheile": "portchei",
    "portcheilor": "portchei",
    "portcheiul": "portchei",
    "portcheiului": "portchei",
    "porțelanul": "porțelan",
    "porțelanului": "porțelan",
    "porțelanuri": "porțelan",
    "porțelanurile": "porțelan",
    "porțelanurilor": "porțelan",
    "porticul": "portic",
    "porticului": "portic",
    "porticuri": "portic",
    "porticurile": "portic",
    "porticurilor": "portic",
    "porția": "porție",
    "porției": "porție",
    "porții": "porție",
    "porțiile": "porție",
    "porțiilor": "porție",
    "porționata": "porționat",
    "porționată": "porționat",
    "porționate": "porționat",
    "porționatei": "porționat",
    "porționatele": "porționat",
    "porționatelor": "porționat",
    "porționați": "porționat",
    "porționații": "porționat",
    "porționaților": "porționat",
    "porționatul": "porționat",
    "porționatului": "porționat",
    "portița": "portiță",
    "portițe": "portiță",
    "portiței": "portiță",
    "portițele": "portiță",
    "portițelor": "portiță",
    "porțiunea": "porțiune",
    "porțiuni": "porțiune",
    "porțiunii": "porțiune",
    "porțiunile": "porțiune",
    "porțiunilor": "porțiune",
    "portjartiere": "portjartier",
    "portjartierele": "portjartier",
    "portjartierelor": "portjartier",
    "portjartierul": "portjartier",
    "portjartierului": "portjartier",
    "portlandiana": "portlandian",
    "portlandiană": "portlandian",
    "portlandianul": "portlandian",
    "portlandianului": "portlandian",
    "portlandiene": "portlandian",
    "portlandienei": "portlandian",
    "portlandienele": "portlandian",
    "portlandienelor": "portlandian",
    "portlandieni": "portlandian",
    "portlandienii": "portlandian",
    "portlandienilor": "portlandian",
    "portmonee": "portmoneu",
    "portmoneele": "portmoneu",
    "portmoneelor": "portmoneu",
    "portmoneul": "portmoneu",
    "portmoneului": "portmoneu",
    "portocali": "portocal",
    "portocalii": "portocal",
    "portocalilor": "portocal",
    "portocalul": "portocal",
    "portocalului": "portocal",
    "portocala": "portocală",
    "portocale": "portocală",
    "portocalei": "portocală",
    "portocalele": "portocală",
    "portocalelor": "portocală",
    "portocalia": "portocaliu",
    "portocalie": "portocaliu",
    "portocaliei": "portocaliu",
    "portocalii": "portocaliu",
    "portocaliii": "portocaliu",
    "portocaliile": "portocaliu",
    "portocaliilor": "portocaliu",
    "portocaliul": "portocaliu",
    "portocaliului": "portocaliu",
    "portofele": "portofel",
    "portofelele": "portofel",
    "portofelelor": "portofel",
    "portofelul": "portofel",
    "portofelului": "portofel",
    "portofolii": "portofoliu",
    "portofoliile": "portofoliu",
    "portofoliilor": "portofoliu",
    "portofoliul": "portofoliu",
    "portofoliului": "portofoliu",
    "portrete": "portret",
    "portretele": "portret",
    "portretelor": "portret",
    "portretul": "portret",
    "portretului": "portret",
    "portretiști": "portretist",
    "portretiștii": "portretist",
    "portretiștilor": "portretist",
    "portretistul": "portretist",
    "portretistului": "portretist",
    "portretistica": "portretistic",
    "portretistică": "portretistic",
    "portretistice": "portretistic",
    "portretisticei": "portretistic",
    "portretisticele": "portretistic",
    "portretisticelor": "portretistic",
    "portretistici": "portretistic",
    "portretisticii": "portretistic",
    "portretisticilor": "portretistic",
    "portretisticul": "portretistic",
    "portretisticului": "portretistic",
    "nemaiportretizând": "portretiza",
    "nemaiportretizându": "portretiza",
    "neportretizând": "portretiza",
    "neportretizându": "portretiza",
    "portretiză": "portretiza",
    "portretizai": "portretiza",
    "portretizam": "portretiza",
    "portretizăm": "portretiza",
    "portretizând": "portretiza",
    "portretizându": "portretiza",
    "portretizară": "portretiza",
    "portretizarăm": "portretiza",
    "portretizarăți": "portretiza",
    "portretizase": "portretiza",
    "portretizasem": "portretiza",
    "portretizaseră": "portretiza",
    "portretizaserăm": "portretiza",
    "portretizaserăți": "portretiza",
    "portretizaseși": "portretiza",
    "portretizași": "portretiza",
    "portretizat": "portretiza",
    "portretizați": "portretiza",
    "portretizau": "portretiza",
    "portretizează": "portretiza",
    "portretizez": "portretiza",
    "portretizeze": "portretiza",
    "portretizezi": "portretiza",
    "portretizarea": "portretizare",
    "portretizări": "portretizare",
    "portretizării": "portretizare",
    "portretizările": "portretizare",
    "portretizărilor": "portretizare",
    "portretizată": "portretizat",
    "portretizate": "portretizat",
    "portretizați": "portretizat",
    "portuara": "portuar",
    "portuară": "portuar",
    "portuare": "portuar",
    "portuarei": "portuar",
    "portuarele": "portuar",
    "portuarelor": "portuar",
    "portuari": "portuar",
    "portuarii": "portuar",
    "portuarilor": "portuar",
    "portuarul": "portuar",
    "portuarului": "portuar",
    "Portugaliei": "Portugalia",
    "portugheza": "portughez",
    "portugheză": "portughez",
    "portugheze": "portughez",
    "portughezei": "portughez",
    "portughezele": "portughez",
    "portughezelor": "portughez",
    "portughezi": "portughez",
    "portughezii": "portughez",
    "portughezilor": "portughez",
    "portughezul": "portughez",
    "portughezului": "portughez",
    "portugheza": "portugheză",
    "portugheze": "portugheză",
    "portughezei": "portugheză",
    "portughezele": "portugheză",
    "portughezelor": "portugheză",
    "porumba": "porumb",
    "porumbă": "porumb",
    "porumbe": "porumb",
    "porumbei": "porumb",
    "porumbele": "porumb",
    "porumbelor": "porumb",
    "porumbi": "porumb",
    "porumbii": "porumb",
    "porumbilor": "porumb",
    "porumbul": "porumb",
    "porumbului": "porumb",
    "porumbaca": "porumbac",
    "porumbacă": "porumbac",
    "porumbace": "porumbac",
    "porumbacei": "porumbac",
    "porumbacele": "porumbac",
    "porumbacelor": "porumbac",
    "porumbaci": "porumbac",
    "porumbacii": "porumbac",
    "porumbacilor": "porumbac",
    "porumbacul": "porumbac",
    "porumbacului": "porumbac",
    "porumbei": "porumbel",
    "porumbeii": "porumbel",
    "porumbeilor": "porumbel",
    "porumbela": "porumbel",
    "porumbelă": "porumbel",
    "porumbele": "porumbel",
    "porumbelei": "porumbel",
    "porumbelele": "porumbel",
    "porumbelelor": "porumbel",
    "porumbeli": "porumbel",
    "porumbelii": "porumbel",
    "porumbelilor": "porumbel",
    "porumbelul": "porumbel",
    "porumbelului": "porumbel",
    "porunca": "poruncă",
    "porunci": "poruncă",
    "poruncii": "poruncă",
    "poruncile": "poruncă",
    "poruncilor": "poruncă",
    "nemaiporuncind": "porunci",
    "nemaiporuncindu": "porunci",
    "neporuncind": "porunci",
    "neporuncindu": "porunci",
    "poruncea": "porunci",
    "porunceai": "porunci",
    "porunceam": "porunci",
    "poruncească": "porunci",
    "porunceați": "porunci",
    "porunceau": "porunci",
    "poruncesc": "porunci",
    "poruncește": "porunci",
    "poruncești": "porunci",
    "poruncii": "porunci",
    "poruncim": "porunci",
    "poruncind": "porunci",
    "poruncindu": "porunci",
    "porunciră": "porunci",
    "poruncirăm": "porunci",
    "poruncirăți": "porunci",
    "poruncise": "porunci",
    "poruncisem": "porunci",
    "porunciseră": "porunci",
    "porunciserăm": "porunci",
    "porunciserăți": "porunci",
    "porunciseși": "porunci",
    "porunciși": "porunci",
    "poruncit": "porunci",
    "porunciți": "porunci",
    "poruncită": "poruncit",
    "poruncite": "poruncit",
    "porunciți": "poruncit",
    "poruncitoare": "poruncitor",
    "poruncitoarea": "poruncitor",
    "poruncitoarei": "poruncitor",
    "poruncitoarele": "poruncitor",
    "poruncitoarelor": "poruncitor",
    "poruncitori": "poruncitor",
    "poruncitorii": "poruncitor",
    "poruncitorilor": "poruncitor",
    "poruncitorul": "poruncitor",
    "poruncitorului": "poruncitor",
    "posaca": "posac",
    "posacă": "posac",
    "posace": "posac",
    "posacei": "posac",
    "posacele": "posac",
    "posacelor": "posac",
    "posaci": "posac",
    "posacii": "posac",
    "posacilor": "posac",
    "posacul": "posac",
    "posacului": "posac",
    "posada": "posadă",
    "posade": "posadă",
    "posadei": "posadă",
    "posadele": "posadă",
    "posadelor": "posadă",
    "nemaiposedând": "poseda",
    "nemaiposedându": "poseda",
    "neposedând": "poseda",
    "neposedându": "poseda",
    "posed": "poseda",
    "posedă": "poseda",
    "posedai": "poseda",
    "posedam": "poseda",
    "posedăm": "poseda",
    "posedând": "poseda",
    "posedându": "poseda",
    "posedară": "poseda",
    "posedarăm": "poseda",
    "posedarăți": "poseda",
    "posedase": "poseda",
    "posedasem": "poseda",
    "posedaseră": "poseda",
    "posedaserăm": "poseda",
    "posedaserăți": "poseda",
    "posedaseși": "poseda",
    "posedași": "poseda",
    "posedat": "poseda",
    "posedați": "poseda",
    "posedau": "poseda",
    "posede": "poseda",
    "posezi": "poseda",
    "posedanta": "posedant",
    "posedantă": "posedant",
    "posedante": "posedant",
    "posedantei": "posedant",
    "posedantele": "posedant",
    "posedantelor": "posedant",
    "posedanți": "posedant",
    "posedanții": "posedant",
    "posedanților": "posedant",
    "posedantul": "posedant",
    "posedantului": "posedant",
    "posedată": "posedat",
    "posedate": "posedat",
    "posedați": "posedat",
    "posesia": "posesie",
    "posesiei": "posesie",
    "posesii": "posesie",
    "posesiile": "posesie",
    "posesiilor": "posesie",
    "posesiunea": "posesiune",
    "posesiuni": "posesiune",
    "posesiunii": "posesiune",
    "posesiunile": "posesiune",
    "posesiunilor": "posesiune",
    "posesiva": "posesiv",
    "posesivă": "posesiv",
    "posesive": "posesiv",
    "posesivei": "posesiv",
    "posesivele": "posesiv",
    "posesivelor": "posesiv",
    "posesivi": "posesiv",
    "posesivii": "posesiv",
    "posesivilor": "posesiv",
    "posesivul": "posesiv",
    "posesivului": "posesiv",
    "posesoarea": "posesoare",
    "posesoarei": "posesoare",
    "posesoarele": "posesoare",
    "posesoarelor": "posesoare",
    "posesori": "posesor",
    "posesorii": "posesor",
    "posesorilor": "posesor",
    "posesorul": "posesor",
    "posesorului": "posesor",
    "posesoria": "posesoriu",
    "posesorie": "posesoriu",
    "posesoriei": "posesoriu",
    "posesorii": "posesoriu",
    "posesoriii": "posesoriu",
    "posesoriile": "posesoriu",
    "posesoriilor": "posesoriu",
    "posesoriul": "posesoriu",
    "posesoriului": "posesoriu",
    "poșeta": "poșetă",
    "poșete": "poșetă",
    "poșetei": "poșetă",
    "poșetele": "poșetă",
    "poșetelor": "poșetă",
    "posibila": "posibil",
    "posibilă": "posibil",
    "posibile": "posibil",
    "posibilei": "posibil",
    "posibilele": "posibil",
    "posibilelor": "posibil",
    "posibili": "posibil",
    "posibilii": "posibil",
    "posibililor": "posibil",
    "posibilul": "posibil",
    "posibilului": "posibil",
    "posibilitatea": "posibilitate",
    "posibilități": "posibilitate",
    "posibilității": "posibilitate",
    "posibilitățile": "posibilitate",
    "posibilităților": "posibilitate",
    "poșirca": "poșircă",
    "poșirci": "poșircă",
    "poșircii": "poșircă",
    "poșircile": "poșircă",
    "poșircilor": "poșircă",
    "posmagi": "posmag",
    "posmagii": "posmag",
    "posmagilor": "posmag",
    "posmagul": "posmag",
    "posmagului": "posmag",
    "posomorâtă": "posomorât",
    "posomorâte": "posomorât",
    "posomorâți": "posomorât",
    "nemaiposomorând": "posomorî",
    "nemaiposomorându": "posomorî",
    "neposomorând": "posomorî",
    "neposomorându": "posomorî",
    "posomora": "posomorî",
    "posomorai": "posomorî",
    "posomorâi": "posomorî",
    "posomoram": "posomorî",
    "posomorâm": "posomorî",
    "posomorând": "posomorî",
    "posomorându": "posomorî",
    "posomorâră": "posomorî",
    "posomorârăm": "posomorî",
    "posomorârăți": "posomorî",
    "posomorăsc": "posomorî",
    "posomorască": "posomorî",
    "posomorâse": "posomorî",
    "posomorâsem": "posomorî",
    "posomorâseră": "posomorî",
    "posomorâserăm": "posomorî",
    "posomorâserăți": "posomorî",
    "posomorâseși": "posomorî",
    "posomorâși": "posomorî",
    "posomorăște": "posomorî",
    "posomorăști": "posomorî",
    "posomorât": "posomorî",
    "posomorați": "posomorî",
    "posomorâți": "posomorî",
    "posomorau": "posomorî",
    "pospăiala": "pospăială",
    "pospăieli": "pospăială",
    "pospăielii": "pospăială",
    "pospăielile": "pospăială",
    "pospăielilor": "pospăială",
    "p.": "post",
    "postul": "post",
    "postului": "post",
    "posturi": "post",
    "posturile": "post",
    "posturilor": "post",
    "nemaipostând": "posta",
    "nemaipostându": "posta",
    "nepostând": "posta",
    "nepostându": "posta",
    "postă": "posta",
    "postai": "posta",
    "postam": "posta",
    "postăm": "posta",
    "postând": "posta",
    "postându": "posta",
    "postară": "posta",
    "postarăm": "posta",
    "postarăți": "posta",
    "postase": "posta",
    "postasem": "posta",
    "postaseră": "posta",
    "postaserăm": "posta",
    "postaserăți": "posta",
    "postaseși": "posta",
    "postași": "posta",
    "postat": "posta",
    "postați": "posta",
    "postau": "posta",
    "postează": "posta",
    "postez": "posta",
    "posteze": "posta",
    "postezi": "posta",
    "poșta": "poștă",
    "poște": "poștă",
    "poștei": "poștă",
    "poștele": "poștă",
    "poștelor": "poștă",
    "poștala": "poștal",
    "poștală": "poștal",
    "poștale": "poștal",
    "poștalei": "poștal",
    "poștalele": "poștal",
    "poștalelor": "poștal",
    "poștali": "poștal",
    "poștalii": "poștal",
    "poștalilor": "poștal",
    "poștalul": "poștal",
    "poștalului": "poștal",
    "postamente": "postament",
    "postamentele": "postament",
    "postamentelor": "postament",
    "postamentul": "postament",
    "postamentului": "postament",
    "poștași": "poștaș",
    "poștașii": "poștaș",
    "poștașilor": "poștaș",
    "poștașul": "poștaș",
    "poștașului": "poștaș",
    "postată": "postat",
    "postate": "postat",
    "postați": "postat",
    "postavul": "postav",
    "postavului": "postav",
    "postavuri": "postav",
    "postavurile": "postav",
    "postavurilor": "postav",
    "postbelica": "postbelic",
    "postbelică": "postbelic",
    "postbelice": "postbelic",
    "postbelicei": "postbelic",
    "postbelicele": "postbelic",
    "postbelicelor": "postbelic",
    "postbelici": "postbelic",
    "postbelicii": "postbelic",
    "postbelicilor": "postbelic",
    "postbelicul": "postbelic",
    "postbelicului": "postbelic",
    "postul-cheie": "post-cheie",
    "postului-cheie": "post-cheie",
    "posturi-cheie": "post-cheie",
    "posturile-cheie": "post-cheie",
    "posturilor-cheie": "post-cheie",
    "postdatate": "postdatat",
    "postdatați": "postdatat",
    "postdiluviana": "postdiluvian",
    "postdiluviană": "postdiluvian",
    "postdiluvianul": "postdiluvian",
    "postdiluvianului": "postdiluvian",
    "postdiluviene": "postdiluvian",
    "postdiluvienei": "postdiluvian",
    "postdiluvienele": "postdiluvian",
    "postdiluvienelor": "postdiluvian",
    "postdiluvieni": "postdiluvian",
    "postdiluvienii": "postdiluvian",
    "postdiluvienilor": "postdiluvian",
    "postelnici": "postelnic",
    "postelnicii": "postelnic",
    "postelnicilor": "postelnic",
    "postelnicul": "postelnic",
    "postelnicului": "postelnic",
    "posterioara": "posterior",
    "posterioară": "posterior",
    "posterioare": "posterior",
    "posterioarei": "posterior",
    "posterioarele": "posterior",
    "posterioarelor": "posterior",
    "posteriori": "posterior",
    "posteriorii": "posterior",
    "posteriorilor": "posterior",
    "posteriorul": "posterior",
    "posteriorului": "posterior",
    "posterioritatea": "posterioritate",
    "posteriorități": "posterioritate",
    "posteriorității": "posterioritate",
    "posteritatea": "posteritate",
    "posterități": "posteritate",
    "posterității": "posteritate",
    "posteroinferioara": "posteroinferior",
    "posteroinferioară": "posteroinferior",
    "posteroinferioare": "posteroinferior",
    "posteroinferioarei": "posteroinferior",
    "posteroinferioarele": "posteroinferior",
    "posteroinferioarelor": "posteroinferior",
    "posteroinferiori": "posteroinferior",
    "posteroinferiorii": "posteroinferior",
    "posteroinferiorilor": "posteroinferior",
    "posteroinferiorul": "posteroinferior",
    "posteroinferiorului": "posteroinferior",
    "posterolinguala": "posterolingual",
    "posterolinguală": "posterolingual",
    "posterolinguale": "posterolingual",
    "posterolingualei": "posterolingual",
    "posterolingualele": "posterolingual",
    "posterolingualelor": "posterolingual",
    "posterolinguali": "posterolingual",
    "posterolingualii": "posterolingual",
    "posterolingualilor": "posterolingual",
    "posterolingualul": "posterolingual",
    "posterolingualului": "posterolingual",
    "postfața": "postfață",
    "postfețe": "postfață",
    "postfeței": "postfață",
    "postfețele": "postfață",
    "postfețelor": "postfață",
    "postglaciara": "postglaciar",
    "postglaciară": "postglaciar",
    "postglaciare": "postglaciar",
    "postglaciarei": "postglaciar",
    "postglaciarele": "postglaciar",
    "postglaciarelor": "postglaciar",
    "postglaciari": "postglaciar",
    "postglaciarii": "postglaciar",
    "postglaciarilor": "postglaciar",
    "postglaciarul": "postglaciar",
    "postglaciarului": "postglaciar",
    "nemaipostind": "posti",
    "nemaipostindu": "posti",
    "nepostind": "posti",
    "nepostindu": "posti",
    "postea": "posti",
    "posteai": "posti",
    "posteam": "posti",
    "postească": "posti",
    "posteați": "posti",
    "posteau": "posti",
    "postesc": "posti",
    "postește": "posti",
    "postești": "posti",
    "postii": "posti",
    "postim": "posti",
    "postind": "posti",
    "postindu": "posti",
    "postiră": "posti",
    "postirăm": "posti",
    "postirăți": "posti",
    "postise": "posti",
    "postisem": "posti",
    "postiseră": "posti",
    "postiserăm": "posti",
    "postiserăți": "posti",
    "postiseși": "posti",
    "postiși": "posti",
    "postit": "posti",
    "postiți": "posti",
    "postișa": "postiș",
    "postișă": "postiș",
    "postișe": "postiș",
    "postișei": "postiș",
    "postișele": "postiș",
    "postișelor": "postiș",
    "postiși": "postiș",
    "postișii": "postiș",
    "postișilor": "postiș",
    "postișul": "postiș",
    "postișului": "postiș",
    "postită": "postit",
    "postite": "postit",
    "postiți": "postit",
    "postitori": "postitor",
    "postitorii": "postitor",
    "postitorilor": "postitor",
    "postitorul": "postitor",
    "postitorului": "postitor",
    "postliceala": "postliceal",
    "postliceală": "postliceal",
    "postliceale": "postliceal",
    "postlicealei": "postliceal",
    "postlicealele": "postliceal",
    "postlicealelor": "postliceal",
    "postliceali": "postliceal",
    "postlicealii": "postliceal",
    "postlicealilor": "postliceal",
    "postlicealul": "postliceal",
    "postlicealului": "postliceal",
    "postmeridiana": "postmeridian",
    "postmeridiană": "postmeridian",
    "postmeridianul": "postmeridian",
    "postmeridianului": "postmeridian",
    "postmeridiene": "postmeridian",
    "postmeridienei": "postmeridian",
    "postmeridienele": "postmeridian",
    "postmeridienelor": "postmeridian",
    "postmeridieni": "postmeridian",
    "postmeridienii": "postmeridian",
    "postmeridienilor": "postmeridian",
    "p.m.": "post-meridiem",
    "p.m.": "post-mortem",
    "postnatala": "postnatal",
    "postnatală": "postnatal",
    "postnatale": "postnatal",
    "postnatalei": "postnatal",
    "postnatalele": "postnatal",
    "postnatalelor": "postnatal",
    "postnatali": "postnatal",
    "postnatalii": "postnatal",
    "postnatalilor": "postnatal",
    "postnatalul": "postnatal",
    "postnatalului": "postnatal",
    "postnominala": "postnominal",
    "postnominală": "postnominal",
    "postnominale": "postnominal",
    "postnominalei": "postnominal",
    "postnominalele": "postnominal",
    "postnominalelor": "postnominal",
    "postnominali": "postnominal",
    "postnominalii": "postnominal",
    "postnominalilor": "postnominal",
    "postnominalul": "postnominal",
    "postnominalului": "postnominal",
    "postoperatoria": "postoperatoriu",
    "postoperatorie": "postoperatoriu",
    "postoperatoriei": "postoperatoriu",
    "postoperatorii": "postoperatoriu",
    "postoperatoriii": "postoperatoriu",
    "postoperatoriile": "postoperatoriu",
    "postoperatoriilor": "postoperatoriu",
    "postoperatoriul": "postoperatoriu",
    "postoperatoriului": "postoperatoriu",
    "postpalatala": "postpalatal",
    "postpalatală": "postpalatal",
    "postpalatale": "postpalatal",
    "postpalatalei": "postpalatal",
    "postpalatalele": "postpalatal",
    "postpalatalelor": "postpalatal",
    "postpalatali": "postpalatal",
    "postpalatalii": "postpalatal",
    "postpalatalilor": "postpalatal",
    "postpalatalul": "postpalatal",
    "postpalatalului": "postpalatal",
    "postpașoptista": "postpașoptist",
    "postpașoptistă": "postpașoptist",
    "postpașoptiste": "postpașoptist",
    "postpașoptistei": "postpașoptist",
    "postpașoptistele": "postpașoptist",
    "postpașoptistelor": "postpașoptist",
    "postpașoptiști": "postpașoptist",
    "postpașoptiștii": "postpașoptist",
    "postpașoptiștilor": "postpașoptist",
    "postpașoptistul": "postpașoptist",
    "postpașoptistului": "postpașoptist",
    "postrevoluționară": "postrevoluționar",
    "postșcolara": "postșcolar",
    "postșcolară": "postșcolar",
    "postșcolare": "postșcolar",
    "postșcolarei": "postșcolar",
    "postșcolarele": "postșcolar",
    "postșcolarelor": "postșcolar",
    "postșcolari": "postșcolar",
    "postșcolarii": "postșcolar",
    "postșcolarilor": "postșcolar",
    "postșcolarul": "postșcolar",
    "postșcolarului": "postșcolar",
    "P.S.": "post-scriptum",
    "posttonica": "posttonic",
    "posttonică": "posttonic",
    "posttonice": "posttonic",
    "posttonicei": "posttonic",
    "posttonicele": "posttonic",
    "posttonicelor": "posttonic",
    "posttonici": "posttonic",
    "posttonicii": "posttonic",
    "posttonicilor": "posttonic",
    "posttonicul": "posttonic",
    "posttonicului": "posttonic",
    "posttraumatica": "posttraumatic",
    "posttraumatică": "posttraumatic",
    "posttraumatice": "posttraumatic",
    "posttraumaticei": "posttraumatic",
    "posttraumaticele": "posttraumatic",
    "posttraumaticelor": "posttraumatic",
    "posttraumatici": "posttraumatic",
    "posttraumaticii": "posttraumatic",
    "posttraumaticilor": "posttraumatic",
    "posttraumaticul": "posttraumatic",
    "posttraumaticului": "posttraumatic",
    "nemaipostulând": "postula",
    "nemaipostulându": "postula",
    "nepostulând": "postula",
    "nepostulându": "postula",
    "postulă": "postula",
    "postulai": "postula",
    "postulam": "postula",
    "postulăm": "postula",
    "postulând": "postula",
    "postulându": "postula",
    "postulară": "postula",
    "postularăm": "postula",
    "postularăți": "postula",
    "postulase": "postula",
    "postulasem": "postula",
    "postulaseră": "postula",
    "postulaserăm": "postula",
    "postulaserăți": "postula",
    "postulaseși": "postula",
    "postulași": "postula",
    "postulat": "postula",
    "postulați": "postula",
    "postulau": "postula",
    "postulează": "postula",
    "postulez": "postula",
    "postuleze": "postula",
    "postulezi": "postula",
    "postulată": "postulat",
    "postulate": "postulat",
    "postulatele": "postulat",
    "postulatelor": "postulat",
    "postulați": "postulat",
    "postulatul": "postulat",
    "postulatului": "postulat",
    "postulativa": "postulativ",
    "postulativă": "postulativ",
    "postulative": "postulativ",
    "postulativei": "postulativ",
    "postulativele": "postulativ",
    "postulativelor": "postulativ",
    "postulativi": "postulativ",
    "postulativii": "postulativ",
    "postulativilor": "postulativ",
    "postulativul": "postulativ",
    "postulativului": "postulativ",
    "postuma": "postum",
    "postumă": "postum",
    "postume": "postum",
    "postumei": "postum",
    "postumele": "postum",
    "postumelor": "postum",
    "postumi": "postum",
    "postumii": "postum",
    "postumilor": "postum",
    "postumul": "postum",
    "postumului": "postum",
    "postuniversitara": "postuniversitar",
    "postuniversitară": "postuniversitar",
    "postuniversitare": "postuniversitar",
    "postuniversitarei": "postuniversitar",
    "postuniversitarele": "postuniversitar",
    "postuniversitarelor": "postuniversitar",
    "postuniversitari": "postuniversitar",
    "postuniversitarii": "postuniversitar",
    "postuniversitarilor": "postuniversitar",
    "postuniversitarul": "postuniversitar",
    "postuniversitarului": "postuniversitar",
    "postura": "postură",
    "posturi": "postură",
    "posturii": "postură",
    "posturile": "postură",
    "posturilor": "postură",
    "postverbala": "postverbal",
    "postverbală": "postverbal",
    "postverbale": "postverbal",
    "postverbalei": "postverbal",
    "postverbalele": "postverbal",
    "postverbalelor": "postverbal",
    "postverbali": "postverbal",
    "postverbalii": "postverbal",
    "postverbalilor": "postverbal",
    "postverbalul": "postverbal",
    "postverbalului": "postverbal",
    "potul": "pot",
    "potului": "pot",
    "poturi": "pot",
    "poturile": "pot",
    "poturilor": "pot",
    "potabila": "potabil",
    "potabilă": "potabil",
    "potabile": "potabil",
    "potabilei": "potabil",
    "potabilele": "potabil",
    "potabilelor": "potabil",
    "potabili": "potabil",
    "potabilii": "potabil",
    "potabililor": "potabil",
    "potabilul": "potabil",
    "potabilului": "potabil",
    "potasica": "potasic",
    "potasică": "potasic",
    "potasice": "potasic",
    "potasicei": "potasic",
    "potasicele": "potasic",
    "potasicelor": "potasic",
    "potasici": "potasic",
    "potasicii": "potasic",
    "potasicilor": "potasic",
    "potasicul": "potasic",
    "potasicului": "potasic",
    "potcașa": "potcaș",
    "potcașă": "potcaș",
    "potcașe": "potcaș",
    "potcașei": "potcaș",
    "potcașele": "potcaș",
    "potcașelor": "potcaș",
    "potcași": "potcaș",
    "potcașii": "potcaș",
    "potcașilor": "potcaș",
    "potcașul": "potcaș",
    "potcașului": "potcaș",
    "potcoava": "potcoavă",
    "potcoave": "potcoavă",
    "potcoavei": "potcoavă",
    "potcoavele": "potcoavă",
    "potcoavelor": "potcoavă",
    "potcovari": "potcovar",
    "potcovarii": "potcovar",
    "potcovarilor": "potcovar",
    "potcovarul": "potcovar",
    "potcovarului": "potcovar",
    "nemaipotcovind": "potcovi",
    "nemaipotcovindu": "potcovi",
    "nepotcovind": "potcovi",
    "nepotcovindu": "potcovi",
    "potcovea": "potcovi",
    "potcoveai": "potcovi",
    "potcoveam": "potcovi",
    "potcovească": "potcovi",
    "potcoveați": "potcovi",
    "potcoveau": "potcovi",
    "potcovesc": "potcovi",
    "potcovește": "potcovi",
    "potcovești": "potcovi",
    "potcovii": "potcovi",
    "potcovim": "potcovi",
    "potcovind": "potcovi",
    "potcovindu": "potcovi",
    "potcoviră": "potcovi",
    "potcovirăm": "potcovi",
    "potcovirăți": "potcovi",
    "potcovise": "potcovi",
    "potcovisem": "potcovi",
    "potcoviseră": "potcovi",
    "potcoviserăm": "potcovi",
    "potcoviserăți": "potcovi",
    "potcoviseși": "potcovi",
    "potcoviși": "potcovi",
    "potcovit": "potcovi",
    "potcoviți": "potcovi",
    "potcovită": "potcovit",
    "potcovite": "potcovit",
    "potcoviți": "potcovit",
    "poteca": "potecă",
    "poteci": "potecă",
    "potecii": "potecă",
    "potecile": "potecă",
    "potecilor": "potecă",
    "potecuța": "potecuță",
    "potecuțe": "potecuță",
    "potecuței": "potecuță",
    "potecuțele": "potecuță",
    "potecuțelor": "potecuță",
    "potenta": "potent",
    "potentă": "potent",
    "potente": "potent",
    "potentei": "potent",
    "potentele": "potent",
    "potentelor": "potent",
    "potenți": "potent",
    "potenții": "potent",
    "potenților": "potent",
    "potentul": "potent",
    "potentului": "potent",
    "potențiala": "potențial",
    "potențială": "potențial",
    "potențiale": "potențial",
    "potențialei": "potențial",
    "potențialele": "potențial",
    "potențialelor": "potențial",
    "potențiali": "potențial",
    "potențialii": "potențial",
    "potențialilor": "potențial",
    "potențialul": "potențial",
    "potențialului": "potențial",
    "nemaipoticnind": "poticni",
    "nemaipoticnindu": "poticni",
    "nepoticnind": "poticni",
    "nepoticnindu": "poticni",
    "poticnea": "poticni",
    "poticneai": "poticni",
    "poticneam": "poticni",
    "poticnească": "poticni",
    "poticneați": "poticni",
    "poticneau": "poticni",
    "poticnesc": "poticni",
    "poticnește": "poticni",
    "poticnești": "poticni",
    "poticnii": "poticni",
    "poticnim": "poticni",
    "poticnind": "poticni",
    "poticnindu": "poticni",
    "poticniră": "poticni",
    "poticnirăm": "poticni",
    "poticnirăți": "poticni",
    "poticnise": "poticni",
    "poticnisem": "poticni",
    "poticniseră": "poticni",
    "poticniserăm": "poticni",
    "poticniserăți": "poticni",
    "poticniseși": "poticni",
    "poticniși": "poticni",
    "poticnit": "poticni",
    "poticniți": "poticni",
    "poticnită": "poticnit",
    "poticnite": "poticnit",
    "poticniți": "poticnit",
    "potire": "potir",
    "potirele": "potir",
    "potirelor": "potir",
    "potirul": "potir",
    "potirului": "potir",
    "potlogăreasca": "potlogăresc",
    "potlogărească": "potlogăresc",
    "potlogărescul": "potlogăresc",
    "potlogărescului": "potlogăresc",
    "potlogărești": "potlogăresc",
    "potlogăreștii": "potlogăresc",
    "potlogăreștile": "potlogăresc",
    "potlogăreștilor": "potlogăresc",
    "nemaipotolind": "potoli",
    "nemaipotolindu": "potoli",
    "nepotolind": "potoli",
    "nepotolindu": "potoli",
    "potolea": "potoli",
    "potoleai": "potoli",
    "potoleam": "potoli",
    "potolească": "potoli",
    "potoleați": "potoli",
    "potoleau": "potoli",
    "potolesc": "potoli",
    "potolește": "potoli",
    "potolești": "potoli",
    "potolii": "potoli",
    "potolim": "potoli",
    "potolind": "potoli",
    "potolindu": "potoli",
    "potoliră": "potoli",
    "potolirăm": "potoli",
    "potolirăți": "potoli",
    "potolise": "potoli",
    "potolisem": "potoli",
    "potoliseră": "potoli",
    "potoliserăm": "potoli",
    "potoliserăți": "potoli",
    "potoliseși": "potoli",
    "potoliși": "potoli",
    "potolit": "potoli",
    "potoliți": "potoli",
    "potolită": "potolit",
    "potolite": "potolit",
    "potoliți": "potolit",
    "potolitoare": "potolitor",
    "potolitoarea": "potolitor",
    "potolitoarei": "potolitor",
    "potolitoarele": "potolitor",
    "potolitoarelor": "potolitor",
    "potolitori": "potolitor",
    "potolitorii": "potolitor",
    "potolitorilor": "potolitor",
    "potolitorul": "potolitor",
    "potolitorului": "potolitor",
    "potopul": "potop",
    "potopului": "potop",
    "potopuri": "potop",
    "potopurile": "potop",
    "potopurilor": "potop",
    "nemaipotopind": "potopi",
    "nemaipotopindu": "potopi",
    "nepotopind": "potopi",
    "nepotopindu": "potopi",
    "potopea": "potopi",
    "potopeai": "potopi",
    "potopeam": "potopi",
    "potopească": "potopi",
    "potopeați": "potopi",
    "potopeau": "potopi",
    "potopesc": "potopi",
    "potopește": "potopi",
    "potopești": "potopi",
    "potopii": "potopi",
    "potopim": "potopi",
    "potopind": "potopi",
    "potopindu": "potopi",
    "potopiră": "potopi",
    "potopirăm": "potopi",
    "potopirăți": "potopi",
    "potopise": "potopi",
    "potopisem": "potopi",
    "potopiseră": "potopi",
    "potopiserăm": "potopi",
    "potopiserăți": "potopi",
    "potopiseși": "potopi",
    "potopiși": "potopi",
    "potopit": "potopi",
    "potopiți": "potopi",
    "potopită": "potopit",
    "potopite": "potopit",
    "potopiți": "potopit",
    "potopitoare": "potopitor",
    "potopitoarea": "potopitor",
    "potopitoarei": "potopitor",
    "potopitoarele": "potopitor",
    "potopitoarelor": "potopitor",
    "potopitori": "potopitor",
    "potopitorii": "potopitor",
    "potopitorilor": "potopitor",
    "potopitorul": "potopitor",
    "potopitorului": "potopitor",
    "potriva": "potrivă",
    "nemaipotrivind": "potrivi",
    "nemaipotrivindu": "potrivi",
    "nepotrivind": "potrivi",
    "nepotrivindu": "potrivi",
    "potrivea": "potrivi",
    "potriveai": "potrivi",
    "potriveam": "potrivi",
    "potrivească": "potrivi",
    "potriveați": "potrivi",
    "potriveau": "potrivi",
    "potrivesc": "potrivi",
    "potrivește": "potrivi",
    "potrivești": "potrivi",
    "potrivii": "potrivi",
    "potrivim": "potrivi",
    "potrivind": "potrivi",
    "potrivindu": "potrivi",
    "potriviră": "potrivi",
    "potrivirăm": "potrivi",
    "potrivirăți": "potrivi",
    "potrivise": "potrivi",
    "potrivisem": "potrivi",
    "potriviseră": "potrivi",
    "potriviserăm": "potrivi",
    "potriviserăți": "potrivi",
    "potriviseși": "potrivi",
    "potriviși": "potrivi",
    "potrivit": "potrivi",
    "potriviți": "potrivi",
    "potrivirea": "potrivire",
    "potriviri": "potrivire",
    "potrivirii": "potrivire",
    "potrivirile": "potrivire",
    "potrivirilor": "potrivire",
    "potrivită": "potrivit",
    "potrivite": "potrivit",
    "potriviți": "potrivit",
    "potrivnica": "potrivnic",
    "potrivnică": "potrivnic",
    "potrivnice": "potrivnic",
    "potrivnicei": "potrivnic",
    "potrivnicele": "potrivnic",
    "potrivnicelor": "potrivnic",
    "potrivnici": "potrivnic",
    "potrivnicii": "potrivnic",
    "potrivnicilor": "potrivnic",
    "potrivnicul": "potrivnic",
    "potrivnicului": "potrivnic",
    "povara": "povară",
    "poveri": "povară",
    "poverii": "povară",
    "poverile": "povară",
    "poverilor": "povară",
    "nemaipovârnind": "povârni",
    "nemaipovârnindu": "povârni",
    "nepovârnind": "povârni",
    "nepovârnindu": "povârni",
    "povârnea": "povârni",
    "povârneai": "povârni",
    "povârneam": "povârni",
    "povârnească": "povârni",
    "povârneați": "povârni",
    "povârneau": "povârni",
    "povârnesc": "povârni",
    "povârnește": "povârni",
    "povârnești": "povârni",
    "povârnii": "povârni",
    "povârnim": "povârni",
    "povârnind": "povârni",
    "povârnindu": "povârni",
    "povârniră": "povârni",
    "povârnirăm": "povârni",
    "povârnirăți": "povârni",
    "povârnise": "povârni",
    "povârnisem": "povârni",
    "povârniseră": "povârni",
    "povârniserăm": "povârni",
    "povârniserăți": "povârni",
    "povârniseși": "povârni",
    "povârniși": "povârni",
    "povârnit": "povârni",
    "povârniți": "povârni",
    "povârnită": "povârnit",
    "povârnite": "povârnit",
    "povârniți": "povârnit",
    "povața": "povață",
    "povețe": "povață",
    "poveței": "povață",
    "povețele": "povață",
    "povețelor": "povață",
    "nemaipovățuind": "povățui",
    "nemaipovățuindu": "povățui",
    "nepovățuind": "povățui",
    "nepovățuindu": "povățui",
    "povățuia": "povățui",
    "povățuiai": "povățui",
    "povățuiam": "povățui",
    "povățuiască": "povățui",
    "povățuiați": "povățui",
    "povățuiau": "povățui",
    "povățuiesc": "povățui",
    "povățuiește": "povățui",
    "povățuiești": "povățui",
    "povățuii": "povățui",
    "povățuim": "povățui",
    "povățuind": "povățui",
    "povățuindu": "povățui",
    "povățuiră": "povățui",
    "povățuirăm": "povățui",
    "povățuirăți": "povățui",
    "povățuise": "povățui",
    "povățuisem": "povățui",
    "povățuiseră": "povățui",
    "povățuiserăm": "povățui",
    "povățuiserăți": "povățui",
    "povățuiseși": "povățui",
    "povățuiși": "povățui",
    "povățuit": "povățui",
    "povățuiți": "povățui",
    "povățuită": "povățuit",
    "povățuite": "povățuit",
    "povățuiți": "povățuit",
    "povestea": "poveste",
    "povești": "poveste",
    "poveștii": "poveste",
    "poveștile": "poveste",
    "poveștilor": "poveste",
    "nemaipovestind": "povesti",
    "nemaipovestindu": "povesti",
    "nepovestind": "povesti",
    "nepovestindu": "povesti",
    "povestea": "povesti",
    "povesteai": "povesti",
    "povesteam": "povesti",
    "povestească": "povesti",
    "povesteați": "povesti",
    "povesteau": "povesti",
    "povestesc": "povesti",
    "povestește": "povesti",
    "povestești": "povesti",
    "povestii": "povesti",
    "povestim": "povesti",
    "povestind": "povesti",
    "povestindu": "povesti",
    "povestiră": "povesti",
    "povestirăm": "povesti",
    "povestirăți": "povesti",
    "povestise": "povesti",
    "povestisem": "povesti",
    "povestiseră": "povesti",
    "povestiserăm": "povesti",
    "povestiserăți": "povesti",
    "povestiseși": "povesti",
    "povestiși": "povesti",
    "povestit": "povesti",
    "povestiți": "povesti",
    "povestioara": "povestioară",
    "povestioare": "povestioară",
    "povestioarei": "povestioară",
    "povestioarele": "povestioară",
    "povestioarelor": "povestioară",
    "povestirea": "povestire",
    "povestiri": "povestire",
    "povestirii": "povestire",
    "povestirile": "povestire",
    "povestirilor": "povestire",
    "povestită": "povestit",
    "povestite": "povestit",
    "povestiți": "povestit",
    "povestitoarea": "povestitoare",
    "povestitoarei": "povestitoare",
    "povestitoarele": "povestitoare",
    "povestitoarelor": "povestitoare",
    "povestitori": "povestitor",
    "povestitorii": "povestitor",
    "povestitorilor": "povestitor",
    "povestitorul": "povestitor",
    "povestitorului": "povestitor",
    "nemaipozând": "poza",
    "nemaipozându": "poza",
    "nepozând": "poza",
    "nepozându": "poza",
    "poză": "poza",
    "pozai": "poza",
    "pozam": "poza",
    "pozăm": "poza",
    "pozând": "poza",
    "pozându": "poza",
    "pozară": "poza",
    "pozarăm": "poza",
    "pozarăți": "poza",
    "pozase": "poza",
    "pozasem": "poza",
    "pozaseră": "poza",
    "pozaserăm": "poza",
    "pozaserăți": "poza",
    "pozaseși": "poza",
    "pozași": "poza",
    "pozat": "poza",
    "pozați": "poza",
    "pozau": "poza",
    "pozează": "poza",
    "pozez": "poza",
    "pozeze": "poza",
    "pozezi": "poza",
    "poza": "poză",
    "poze": "poză",
    "pozei": "poză",
    "pozele": "poză",
    "pozelor": "poză",
    "pozarea": "pozare",
    "pozări": "pozare",
    "pozările": "pozare",
    "pozărilor": "pozare",
    "pozată": "pozat",
    "pozate": "pozat",
    "pozați": "pozat",
    "poziția": "poziție",
    "poziției": "poziție",
    "poziții": "poziție",
    "pozițiile": "poziție",
    "pozițiilor": "poziție",
    "pozitiva": "pozitiv",
    "pozitivă": "pozitiv",
    "pozitive": "pozitiv",
    "pozitivei": "pozitiv",
    "pozitivele": "pozitiv",
    "pozitivelor": "pozitiv",
    "pozitivi": "pozitiv",
    "pozitivii": "pozitiv",
    "pozitivilor": "pozitiv",
    "pozitivul": "pozitiv",
    "pozitivului": "pozitiv",
    "pozitivismul": "pozitivism",
    "pozitivismului": "pozitivism",
    "pozitivista": "pozitivist",
    "pozitivistă": "pozitivist",
    "pozitiviste": "pozitivist",
    "pozitivistei": "pozitivist",
    "pozitivistele": "pozitivist",
    "pozitivistelor": "pozitivist",
    "pozitiviști": "pozitivist",
    "pozitiviștii": "pozitivist",
    "pozitiviștilor": "pozitivist",
    "pozitivistul": "pozitivist",
    "pozitivistului": "pozitivist",
    "pozitroni": "pozitron",
    "pozitronii": "pozitron",
    "pozitronilor": "pozitron",
    "pozitronul": "pozitron",
    "pozitronului": "pozitron",
    "pozna": "poznă",
    "pozne": "poznă",
    "poznei": "poznă",
    "poznele": "poznă",
    "poznelor": "poznă",
    "poznașa": "poznaș",
    "poznașă": "poznaș",
    "poznașe": "poznaș",
    "poznașei": "poznaș",
    "poznașele": "poznaș",
    "poznașelor": "poznaș",
    "poznași": "poznaș",
    "poznașii": "poznaș",
    "poznașilor": "poznaș",
    "poznașul": "poznaș",
    "poznașului": "poznaș",
    "nemaiprăbușind": "prăbuși",
    "nemaiprăbușindu": "prăbuși",
    "neprăbușind": "prăbuși",
    "neprăbușindu": "prăbuși",
    "prăbușea": "prăbuși",
    "prăbușeai": "prăbuși",
    "prăbușeam": "prăbuși",
    "prăbușească": "prăbuși",
    "prăbușeați": "prăbuși",
    "prăbușeau": "prăbuși",
    "prăbușesc": "prăbuși",
    "prăbușește": "prăbuși",
    "prăbușești": "prăbuși",
    "prăbușii": "prăbuși",
    "prăbușim": "prăbuși",
    "prăbușind": "prăbuși",
    "prăbușindu": "prăbuși",
    "prăbușiră": "prăbuși",
    "prăbușirăm": "prăbuși",
    "prăbușirăți": "prăbuși",
    "prăbușise": "prăbuși",
    "prăbușisem": "prăbuși",
    "prăbușiseră": "prăbuși",
    "prăbușiserăm": "prăbuși",
    "prăbușiserăți": "prăbuși",
    "prăbușiseși": "prăbuși",
    "prăbușiși": "prăbuși",
    "prăbușit": "prăbuși",
    "prăbușiți": "prăbuși",
    "prăbușirea": "prăbușire",
    "prăbușiri": "prăbușire",
    "prăbușirii": "prăbușire",
    "prăbușirile": "prăbușire",
    "prăbușirilor": "prăbușire",
    "prăbușită": "prăbușit",
    "prăbușite": "prăbușit",
    "prăbușiți": "prăbușit",
    "practica": "practic",
    "practică": "practic",
    "practice": "practic",
    "practicei": "practic",
    "practicele": "practic",
    "practicelor": "practic",
    "practici": "practic",
    "practicii": "practic",
    "practicilor": "practic",
    "practicul": "practic",
    "practicului": "practic",
    "nemaipracticând": "practica",
    "nemaipracticându": "practica",
    "nepracticând": "practica",
    "nepracticându": "practica",
    "practic": "practica",
    "practică": "practica",
    "practicai": "practica",
    "practicam": "practica",
    "practicăm": "practica",
    "practicând": "practica",
    "practicându": "practica",
    "practicară": "practica",
    "practicarăm": "practica",
    "practicarăți": "practica",
    "practicase": "practica",
    "practicasem": "practica",
    "practicaseră": "practica",
    "practicaserăm": "practica",
    "practicaserăți": "practica",
    "practicaseși": "practica",
    "practicași": "practica",
    "practicat": "practica",
    "practicați": "practica",
    "practicau": "practica",
    "practice": "practica",
    "practici": "practica",
    "practica": "practică",
    "practici": "practică",
    "practicii": "practică",
    "practicile": "practică",
    "practicilor": "practică",
    "practicabila": "practicabil",
    "practicabilă": "practicabil",
    "practicabile": "practicabil",
    "practicabilei": "practicabil",
    "practicabilele": "practicabil",
    "practicabilelor": "practicabil",
    "practicabili": "practicabil",
    "practicabilii": "practicabil",
    "practicabililor": "practicabil",
    "practicabilul": "practicabil",
    "practicabilului": "practicabil",
    "practicanți": "practicant",
    "practicanții": "practicant",
    "practicanților": "practicant",
    "practicantul": "practicant",
    "practicantului": "practicant",
    "practicanta": "practicantă",
    "practicante": "practicantă",
    "practicantei": "practicantă",
    "practicantele": "practicantă",
    "practicantelor": "practicantă",
    "practicarea": "practicare",
    "practicari": "practicare",
    "practicarii": "practicare",
    "practicarile": "practicare",
    "practicarilor": "practicare",
    "practicată": "practicat",
    "practicate": "practicat",
    "practicați": "practicat",
    "practicista": "practicist",
    "practicistă": "practicist",
    "practiciste": "practicist",
    "practicistei": "practicist",
    "practicistele": "practicist",
    "practicistelor": "practicist",
    "practiciști": "practicist",
    "practiciștii": "practicist",
    "practiciștilor": "practicist",
    "practicistul": "practicist",
    "practicistului": "practicist",
    "prada": "pradă",
    "prăzi": "pradă",
    "prăzii": "pradă",
    "prăzile": "pradă",
    "prăzilor": "pradă",
    "nemaiprădând": "prăda",
    "nemaiprădându": "prăda",
    "neprădând": "prăda",
    "neprădându": "prăda",
    "prad": "prăda",
    "pradă": "prăda",
    "prădă": "prăda",
    "prădai": "prăda",
    "prădam": "prăda",
    "prădăm": "prăda",
    "prădând": "prăda",
    "prădându": "prăda",
    "prădară": "prăda",
    "prădarăm": "prăda",
    "prădarăți": "prăda",
    "prădase": "prăda",
    "prădasem": "prăda",
    "prădaseră": "prăda",
    "prădaserăm": "prăda",
    "prădaserăți": "prăda",
    "prădaseși": "prăda",
    "prădași": "prăda",
    "prădat": "prăda",
    "prădați": "prăda",
    "prădau": "prăda",
    "prade": "prăda",
    "prădează": "prăda",
    "prădez": "prăda",
    "prădeze": "prăda",
    "prădezi": "prăda",
    "prazi": "prăda",
    "prădalnica": "prădalnic",
    "prădalnică": "prădalnic",
    "prădalnice": "prădalnic",
    "prădalnicei": "prădalnic",
    "prădalnicele": "prădalnic",
    "prădalnicelor": "prădalnic",
    "prădalnici": "prădalnic",
    "prădalnicii": "prădalnic",
    "prădalnicilor": "prădalnic",
    "prădalnicul": "prădalnic",
    "prădalnicului": "prădalnic",
    "prădarea": "prădare",
    "prădări": "prădare",
    "prădării": "prădare",
    "prădările": "prădare",
    "prădărilor": "prădare",
    "prădată": "prădat",
    "prădate": "prădat",
    "prădați": "prădat",
    "prădători": "prădător",
    "prădătorii": "prădător",
    "prădătorilor": "prădător",
    "prădătorul": "prădător",
    "prădătorului": "prădător",
    "praful": "praf",
    "prafului": "praf",
    "prafuri": "praf",
    "prafurile": "praf",
    "prafurilor": "praf",
    "prăfoasa": "prăfos",
    "prăfoasă": "prăfos",
    "prăfoase": "prăfos",
    "prăfoasei": "prăfos",
    "prăfoasele": "prăfos",
    "prăfoaselor": "prăfos",
    "prăfoși": "prăfos",
    "prăfoșii": "prăfos",
    "prăfoșilor": "prăfos",
    "prăfosul": "prăfos",
    "prăfosului": "prăfos",
    "nemaiprăfuind": "prăfui",
    "nemaiprăfuindu": "prăfui",
    "neprăfuind": "prăfui",
    "neprăfuindu": "prăfui",
    "prăfuia": "prăfui",
    "prăfuiai": "prăfui",
    "prăfuiam": "prăfui",
    "prăfuiască": "prăfui",
    "prăfuiați": "prăfui",
    "prăfuiau": "prăfui",
    "prăfuiesc": "prăfui",
    "prăfuiește": "prăfui",
    "prăfuiești": "prăfui",
    "prăfuii": "prăfui",
    "prăfuim": "prăfui",
    "prăfuind": "prăfui",
    "prăfuindu": "prăfui",
    "prăfuiră": "prăfui",
    "prăfuirăm": "prăfui",
    "prăfuirăți": "prăfui",
    "prăfuise": "prăfui",
    "prăfuisem": "prăfui",
    "prăfuiseră": "prăfui",
    "prăfuiserăm": "prăfui",
    "prăfuiserăți": "prăfui",
    "prăfuiseși": "prăfui",
    "prăfuiși": "prăfui",
    "prăfuit": "prăfui",
    "prăfuiți": "prăfui",
    "prăfuita": "prăfuit",
    "prăfuită": "prăfuit",
    "prăfuite": "prăfuit",
    "prăfuitei": "prăfuit",
    "prăfuitele": "prăfuit",
    "prăfuitelor": "prăfuit",
    "prăfuiți": "prăfuit",
    "prăfuiții": "prăfuit",
    "prăfuiților": "prăfuit",
    "prăfuitul": "prăfuit",
    "prăfuitului": "prăfuit",
    "prăfuria": "prăfuriu",
    "prăfurie": "prăfuriu",
    "prăfuriei": "prăfuriu",
    "prăfurii": "prăfuriu",
    "prăfuriii": "prăfuriu",
    "prăfuriile": "prăfuriu",
    "prăfuriilor": "prăfuriu",
    "prăfuriul": "prăfuriu",
    "prăfuriului": "prăfuriu",
    "prăfuroasa": "prăfuros",
    "prăfuroasă": "prăfuros",
    "prăfuroase": "prăfuros",
    "prăfuroasei": "prăfuros",
    "prăfuroasele": "prăfuros",
    "prăfuroaselor": "prăfuros",
    "prăfuroși": "prăfuros",
    "prăfuroșii": "prăfuros",
    "prăfuroșilor": "prăfuros",
    "prăfurosul": "prăfuros",
    "prăfurosului": "prăfuros",
    "pragul": "prag",
    "pragului": "prag",
    "praguri": "prag",
    "pragurile": "prag",
    "pragurilor": "prag",
    "Pragăi": "Praga",
    "pragmatica": "pragmatic",
    "pragmatică": "pragmatic",
    "pragmatice": "pragmatic",
    "pragmaticei": "pragmatic",
    "pragmaticele": "pragmatic",
    "pragmaticelor": "pragmatic",
    "pragmatici": "pragmatic",
    "pragmaticii": "pragmatic",
    "pragmaticilor": "pragmatic",
    "pragmaticul": "pragmatic",
    "pragmaticului": "pragmatic",
    "pragmatismul": "pragmatism",
    "pragmatismului": "pragmatism",
    "pragmatista": "pragmatist",
    "pragmatistă": "pragmatist",
    "pragmatiste": "pragmatist",
    "pragmatistei": "pragmatist",
    "pragmatistele": "pragmatist",
    "pragmatistelor": "pragmatist",
    "pragmatiști": "pragmatist",
    "pragmatiștii": "pragmatist",
    "pragmatiștilor": "pragmatist",
    "pragmatistul": "pragmatist",
    "pragmatistului": "pragmatist",
    "Prahovei": "Prahova",
    "prahoveana": "prahovean",
    "prahoveană": "prahovean",
    "prahoveanul": "prahovean",
    "prahoveanului": "prahovean",
    "prahovene": "prahovean",
    "prahovenei": "prahovean",
    "prahovenele": "prahovean",
    "prahovenelor": "prahovean",
    "prahoveni": "prahovean",
    "prahovenii": "prahovean",
    "prahovenilor": "prahovean",
    "prăjeala": "prăjeală",
    "prăjeli": "prăjeală",
    "prăjelii": "prăjeală",
    "prăjelile": "prăjeală",
    "prăjelilor": "prăjeală",
    "nemaiprăjind": "prăji",
    "nemaiprăjindu": "prăji",
    "neprăjind": "prăji",
    "neprăjindu": "prăji",
    "prăjea": "prăji",
    "prăjeai": "prăji",
    "prăjeam": "prăji",
    "prăjească": "prăji",
    "prăjeați": "prăji",
    "prăjeau": "prăji",
    "prăjesc": "prăji",
    "prăjește": "prăji",
    "prăjești": "prăji",
    "prăjii": "prăji",
    "prăjim": "prăji",
    "prăjind": "prăji",
    "prăjindu": "prăji",
    "prăjiră": "prăji",
    "prăjirăm": "prăji",
    "prăjirăți": "prăji",
    "prăjise": "prăji",
    "prăjisem": "prăji",
    "prăjiseră": "prăji",
    "prăjiserăm": "prăji",
    "prăjiserăți": "prăji",
    "prăjiseși": "prăji",
    "prăjiși": "prăji",
    "prăjit": "prăji",
    "prăjiți": "prăji",
    "prăjina": "prăjină",
    "prăjini": "prăjină",
    "prăjinii": "prăjină",
    "prăjinile": "prăjină",
    "prăjinilor": "prăjină",
    "prăjită": "prăjit",
    "prăjite": "prăjit",
    "prăjiți": "prăjit",
    "prăjitura": "prăjitură",
    "prăjituri": "prăjitură",
    "prăjiturii": "prăjitură",
    "prăjiturile": "prăjitură",
    "prăjiturilor": "prăjitură",
    "pralina": "pralină",
    "praline": "pralină",
    "pralinei": "pralină",
    "pralinele": "pralină",
    "pralinelor": "pralină",
    "pramatia": "pramatie",
    "pramatiei": "pramatie",
    "pramatii": "pramatie",
    "pramatiile": "pramatie",
    "pramatiilor": "pramatie",
    "prandiala": "prandial",
    "prandială": "prandial",
    "prandiale": "prandial",
    "prandialei": "prandial",
    "prandialele": "prandial",
    "prandialelor": "prandial",
    "prandiali": "prandial",
    "prandialii": "prandial",
    "prandialilor": "prandial",
    "prandialul": "prandial",
    "prandialului": "prandial",
    "prânzul": "prânz",
    "prânzului": "prânz",
    "prânzuri": "prânz",
    "prânzurile": "prânz",
    "prânzurilor": "prânz",
    "nemaiprânzind": "prânzi",
    "nemaiprânzindu": "prânzi",
    "neprânzind": "prânzi",
    "neprânzindu": "prânzi",
    "prânzea": "prânzi",
    "prânzeai": "prânzi",
    "prânzeam": "prânzi",
    "prânzească": "prânzi",
    "prânzeați": "prânzi",
    "prânzeau": "prânzi",
    "prânzesc": "prânzi",
    "prânzește": "prânzi",
    "prânzești": "prânzi",
    "prânzii": "prânzi",
    "prânzim": "prânzi",
    "prânzind": "prânzi",
    "prânzindu": "prânzi",
    "prânziră": "prânzi",
    "prânzirăm": "prânzi",
    "prânzirăți": "prânzi",
    "prânzise": "prânzi",
    "prânzisem": "prânzi",
    "prânziseră": "prânzi",
    "prânziserăm": "prânzi",
    "prânziserăți": "prânzi",
    "prânziseși": "prânzi",
    "prânziși": "prânzi",
    "prânzit": "prânzi",
    "prânziți": "prânzi",
    "prânzită": "prânzit",
    "prânzite": "prânzit",
    "prânziți": "prânzit",
    "prăpădul": "prăpăd",
    "prăpădului": "prăpăd",
    "prăpăduri": "prăpăd",
    "prăpădurile": "prăpăd",
    "prăpădurilor": "prăpăd",
    "nemaiprăpădind": "prăpădi",
    "nemaiprăpădindu": "prăpădi",
    "neprăpădind": "prăpădi",
    "neprăpădindu": "prăpădi",
    "prăpădea": "prăpădi",
    "prăpădeai": "prăpădi",
    "prăpădeam": "prăpădi",
    "prăpădească": "prăpădi",
    "prăpădeați": "prăpădi",
    "prăpădeau": "prăpădi",
    "prăpădesc": "prăpădi",
    "prăpădește": "prăpădi",
    "prăpădești": "prăpădi",
    "prăpădii": "prăpădi",
    "prăpădim": "prăpădi",
    "prăpădind": "prăpădi",
    "prăpădindu": "prăpădi",
    "prăpădiră": "prăpădi",
    "prăpădirăm": "prăpădi",
    "prăpădirăți": "prăpădi",
    "prăpădise": "prăpădi",
    "prăpădisem": "prăpădi",
    "prăpădiseră": "prăpădi",
    "prăpădiserăm": "prăpădi",
    "prăpădiserăți": "prăpădi",
    "prăpădiseși": "prăpădi",
    "prăpădiși": "prăpădi",
    "prăpădit": "prăpădi",
    "prăpădiți": "prăpădi",
    "prăpădirea": "prăpădire",
    "prăpădiri": "prăpădire",
    "prăpădirii": "prăpădire",
    "prăpădirile": "prăpădire",
    "prăpădirilor": "prăpădire",
    "prăpădită": "prăpădit",
    "prăpădite": "prăpădit",
    "prăpădiți": "prăpădit",
    "prăpăditoare": "prăpăditor",
    "prăpăditoarea": "prăpăditor",
    "prăpăditoarei": "prăpăditor",
    "prăpăditoarele": "prăpăditor",
    "prăpăditoarelor": "prăpăditor",
    "prăpăditori": "prăpăditor",
    "prăpăditorii": "prăpăditor",
    "prăpăditorilor": "prăpăditor",
    "prăpăditorul": "prăpăditor",
    "prăpăditorului": "prăpăditor",
    "prăpastia": "prăpastie",
    "prăpăstiei": "prăpastie",
    "prăpăstii": "prăpastie",
    "prăpăstiile": "prăpastie",
    "prăpăstiilor": "prăpastie",
    "prăpăstioasa": "prăpăstios",
    "prăpăstioasă": "prăpăstios",
    "prăpăstioase": "prăpăstios",
    "prăpăstioasei": "prăpăstios",
    "prăpăstioasele": "prăpăstios",
    "prăpăstioaselor": "prăpăstios",
    "prăpăstioși": "prăpăstios",
    "prăpăstioșii": "prăpăstios",
    "prăpăstioșilor": "prăpăstios",
    "prăpăstiosul": "prăpăstios",
    "prăpăstiosului": "prăpăstios",
    "prapuri": "prapur",
    "prapurii": "prapur",
    "prapurilor": "prapur",
    "prapurul": "prapur",
    "prapurului": "prapur",
    "nemaiprăsind": "prăsi",
    "nemaiprăsindu": "prăsi",
    "neprăsind": "prăsi",
    "neprăsindu": "prăsi",
    "prăsea": "prăsi",
    "prăseai": "prăsi",
    "prăseam": "prăsi",
    "prăsească": "prăsi",
    "prăseați": "prăsi",
    "prăseau": "prăsi",
    "prăsesc": "prăsi",
    "prăsește": "prăsi",
    "prăsești": "prăsi",
    "prăsii": "prăsi",
    "prăsim": "prăsi",
    "prăsind": "prăsi",
    "prăsindu": "prăsi",
    "prăsiră": "prăsi",
    "prăsirăm": "prăsi",
    "prăsirăți": "prăsi",
    "prăsise": "prăsi",
    "prăsisem": "prăsi",
    "prăsiseră": "prăsi",
    "prăsiserăm": "prăsi",
    "prăsiserăți": "prăsi",
    "prăsiseși": "prăsi",
    "prăsiși": "prăsi",
    "prăsit": "prăsi",
    "prăsiți": "prăsi",
    "nemaiprășind": "prăși",
    "nemaiprășindu": "prăși",
    "neprășind": "prăși",
    "neprășindu": "prăși",
    "prășea": "prăși",
    "prășeai": "prăși",
    "prășeam": "prăși",
    "prășească": "prăși",
    "prășeați": "prăși",
    "prășeau": "prăși",
    "prășesc": "prăși",
    "prășește": "prăși",
    "prășești": "prăși",
    "prășii": "prăși",
    "prășim": "prăși",
    "prășind": "prăși",
    "prășindu": "prăși",
    "prășiră": "prăși",
    "prășirăm": "prăși",
    "prășirăți": "prăși",
    "prășise": "prăși",
    "prășisem": "prăși",
    "prășiseră": "prăși",
    "prășiserăm": "prăși",
    "prășiserăți": "prăși",
    "prășiseși": "prăși",
    "prășiși": "prăși",
    "prășit": "prăși",
    "prășiți": "prăși",
    "prăsită": "prăsit",
    "prăsite": "prăsit",
    "prăsiți": "prăsit",
    "prășită": "prășit",
    "prășite": "prășit",
    "prășiți": "prășit",
    "prăsitoare": "prăsitor",
    "prăsitoarea": "prăsitor",
    "prăsitoarei": "prăsitor",
    "prăsitoarele": "prăsitor",
    "prăsitoarelor": "prăsitor",
    "prăsitori": "prăsitor",
    "prăsitorii": "prăsitor",
    "prăsitorilor": "prăsitor",
    "prăsitorul": "prăsitor",
    "prăsitorului": "prăsitor",
    "prășitoare": "prășitor",
    "prășitoarea": "prășitor",
    "prășitoarei": "prășitor",
    "prășitoarele": "prășitor",
    "prășitoarelor": "prășitor",
    "prășitori": "prășitor",
    "prășitorii": "prășitor",
    "prășitorilor": "prășitor",
    "prășitorul": "prășitor",
    "prășitorului": "prășitor",
    "praștia": "praștie",
    "praștiei": "praștie",
    "praștii": "praștie",
    "praștiile": "praștie",
    "praștiilor": "praștie",
    "prăvălatica": "prăvălatic",
    "prăvălatică": "prăvălatic",
    "prăvălatice": "prăvălatic",
    "prăvălaticei": "prăvălatic",
    "prăvălaticele": "prăvălatic",
    "prăvălaticelor": "prăvălatic",
    "prăvălatici": "prăvălatic",
    "prăvălaticii": "prăvălatic",
    "prăvălaticilor": "prăvălatic",
    "prăvălaticul": "prăvălatic",
    "prăvălaticului": "prăvălatic",
    "nemaiprăvălind": "prăvăli",
    "nemaiprăvălindu": "prăvăli",
    "neprăvălind": "prăvăli",
    "neprăvălindu": "prăvăli",
    "prăvale": "prăvăli",
    "prăvălea": "prăvăli",
    "prăvăleai": "prăvăli",
    "prăvăleam": "prăvăli",
    "prăvălească": "prăvăli",
    "prăvăleați": "prăvăli",
    "prăvăleau": "prăvăli",
    "prăvălesc": "prăvăli",
    "prăvălește": "prăvăli",
    "prăvălești": "prăvăli",
    "prăvălii": "prăvăli",
    "prăvălim": "prăvăli",
    "prăvălind": "prăvăli",
    "prăvălindu": "prăvăli",
    "prăvăliră": "prăvăli",
    "prăvălirăm": "prăvăli",
    "prăvălirăți": "prăvăli",
    "prăvălise": "prăvăli",
    "prăvălisem": "prăvăli",
    "prăvăliseră": "prăvăli",
    "prăvăliserăm": "prăvăli",
    "prăvăliserăți": "prăvăli",
    "prăvăliseși": "prăvăli",
    "prăvăliși": "prăvăli",
    "prăvălit": "prăvăli",
    "prăvăliți": "prăvăli",
    "prăvălia": "prăvălie",
    "prăvăliei": "prăvălie",
    "prăvălii": "prăvălie",
    "prăvăliile": "prăvălie",
    "prăvăliilor": "prăvălie",
    "prăvălioara": "prăvălioară",
    "prăvălioare": "prăvălioară",
    "prăvălioarei": "prăvălioară",
    "prăvălioarele": "prăvălioară",
    "prăvălioarelor": "prăvălioară",
    "prăvălită": "prăvălit",
    "prăvălite": "prăvălit",
    "prăvăliți": "prăvălit",
    "pravila": "pravilă",
    "pravile": "pravilă",
    "pravilei": "pravilă",
    "pravilele": "pravilă",
    "pravilelor": "pravilă",
    "pravilnica": "pravilnic",
    "pravilnică": "pravilnic",
    "pravilnice": "pravilnic",
    "pravilnicei": "pravilnic",
    "pravilnicele": "pravilnic",
    "pravilnicelor": "pravilnic",
    "pravilnici": "pravilnic",
    "pravilnicii": "pravilnic",
    "pravilnicilor": "pravilnic",
    "pravilnicul": "pravilnic",
    "pravilnicului": "pravilnic",
    "pravilniceasca": "pravilnicesc",
    "pravilnicească": "pravilnicesc",
    "pravilnicescul": "pravilnicesc",
    "pravilnicescului": "pravilnicesc",
    "pravilnicești": "pravilnicesc",
    "pravilniceștii": "pravilnicesc",
    "pravilniceștile": "pravilnicesc",
    "pravilniceștilor": "pravilnicesc",
    "praji": "praz",
    "prajii": "praz",
    "prajilor": "praz",
    "prazul": "praz",
    "prazului": "praz",
    "praznice": "praznic",
    "praznicele": "praznic",
    "praznicelor": "praznic",
    "praznicul": "praznic",
    "praznicului": "praznic",
    "nemaiprăznuind": "prăznui",
    "nemaiprăznuindu": "prăznui",
    "neprăznuind": "prăznui",
    "neprăznuindu": "prăznui",
    "prăznuia": "prăznui",
    "prăznuiai": "prăznui",
    "prăznuiam": "prăznui",
    "prăznuiască": "prăznui",
    "prăznuiați": "prăznui",
    "prăznuiau": "prăznui",
    "prăznuiesc": "prăznui",
    "prăznuiește": "prăznui",
    "prăznuiești": "prăznui",
    "prăznuii": "prăznui",
    "prăznuim": "prăznui",
    "prăznuind": "prăznui",
    "prăznuindu": "prăznui",
    "prăznuiră": "prăznui",
    "prăznuirăm": "prăznui",
    "prăznuirăți": "prăznui",
    "prăznuise": "prăznui",
    "prăznuisem": "prăznui",
    "prăznuiseră": "prăznui",
    "prăznuiserăm": "prăznui",
    "prăznuiserăți": "prăznui",
    "prăznuiseși": "prăznui",
    "prăznuiși": "prăznui",
    "prăznuit": "prăznui",
    "prăznuiți": "prăznui",
    "prăznuirea": "prăznuire",
    "prăznuiri": "prăznuire",
    "prăznuirii": "prăznuire",
    "prăznuirile": "prăznuire",
    "prăznuirilor": "prăznuire",
    "prăznuită": "prăznuit",
    "prăznuite": "prăznuit",
    "prăznuiți": "prăznuit",
    "prăzulia": "prăzuliu",
    "prăzulie": "prăzuliu",
    "prăzuliei": "prăzuliu",
    "prăzulii": "prăzuliu",
    "prăzuliii": "prăzuliu",
    "prăzuliile": "prăzuliu",
    "prăzuliilor": "prăzuliu",
    "prăzuliul": "prăzuliu",
    "prăzuliului": "prăzuliu",
    "preabuna": "preabun",
    "preabună": "preabun",
    "preabune": "preabun",
    "preabunei": "preabun",
    "preabunele": "preabun",
    "preabunelor": "preabun",
    "preabuni": "preabun",
    "preabunii": "preabun",
    "preabunilor": "preabun",
    "preabunul": "preabun",
    "preabunule": "preabun",
    "preabunului": "preabun",
    "preacinstita": "preacinstit",
    "preacinstită": "preacinstit",
    "preacinstite": "preacinstit",
    "preacinstitei": "preacinstit",
    "preacinstitele": "preacinstit",
    "preacinstitelor": "preacinstit",
    "preacinstiți": "preacinstit",
    "preacinstiții": "preacinstit",
    "preacinstiților": "preacinstit",
    "preacinstitul": "preacinstit",
    "preacinstitului": "preacinstit",
    "preacurata": "preacurat",
    "preacurată": "preacurat",
    "preacurate": "preacurat",
    "preacuratei": "preacurat",
    "preacuratele": "preacurat",
    "preacuratelor": "preacurat",
    "preacurați": "preacurat",
    "preacurații": "preacurat",
    "preacuraților": "preacurat",
    "preacuratul": "preacurat",
    "preacuratului": "preacurat",
    "preacurvia": "preacurvie",
    "preacurviei": "preacurvie",
    "preacuvioasa": "preacuvios",
    "preacuvioasă": "preacuvios",
    "preacuvioase": "preacuvios",
    "preacuvioasei": "preacuvios",
    "preacuvioasele": "preacuvios",
    "preacuvioaselor": "preacuvios",
    "preacuvioși": "preacuvios",
    "preacuvioșii": "preacuvios",
    "preacuvioșilor": "preacuvios",
    "preacuviosul": "preacuvios",
    "preacuviosului": "preacuvios",
    "preadolescenta": "preadolescent",
    "preadolescentă": "preadolescent",
    "preadolescente": "preadolescent",
    "preadolescentei": "preadolescent",
    "preadolescentele": "preadolescent",
    "preadolescentelor": "preadolescent",
    "preadolescenți": "preadolescent",
    "preadolescenții": "preadolescent",
    "preadolescenților": "preadolescent",
    "preadolescentul": "preadolescent",
    "preadolescentului": "preadolescent",
    "preafericita": "preafericit",
    "preafericită": "preafericit",
    "preafericite": "preafericit",
    "preafericitei": "preafericit",
    "preafericitele": "preafericit",
    "preafericitelor": "preafericit",
    "preafericiți": "preafericit",
    "preafericiții": "preafericit",
    "preafericiților": "preafericit",
    "preafericitul": "preafericit",
    "preafericitule": "preafericit",
    "preafericitului": "preafericit",
    "preafrumoasa": "preafrumos",
    "preafrumoasă": "preafrumos",
    "preafrumoase": "preafrumos",
    "preafrumoasei": "preafrumos",
    "preafrumoasele": "preafrumos",
    "preafrumoaselor": "preafrumos",
    "preafrumoși": "preafrumos",
    "preafrumoșii": "preafrumos",
    "preafrumoșilor": "preafrumos",
    "preafrumosul": "preafrumos",
    "preafrumosului": "preafrumos",
    "preaînalta": "preaînalt",
    "preaînaltă": "preaînalt",
    "preaînalte": "preaînalt",
    "preaînaltei": "preaînalt",
    "preaînaltele": "preaînalt",
    "preaînaltelor": "preaînalt",
    "preaînalți": "preaînalt",
    "preaînalții": "preaînalt",
    "preaînalților": "preaînalt",
    "preaînaltul": "preaînalt",
    "preaînaltului": "preaînalt",
    "preaînălțata": "preaînălțat",
    "preaînălțată": "preaînălțat",
    "preaînălțate": "preaînălțat",
    "preaînălțatei": "preaînălțat",
    "preaînălțatele": "preaînălțat",
    "preaînălțatelor": "preaînălțat",
    "preaînălțați": "preaînălțat",
    "preaînălțații": "preaînălțat",
    "preaînălțaților": "preaînălțat",
    "preaînălțatul": "preaînălțat",
    "preaînălțatului": "preaînălțat",
    "preaînțeleapta": "preaînțelept",
    "preaînțeleaptă": "preaînțelept",
    "preaînțelepte": "preaînțelept",
    "preaînțeleptei": "preaînțelept",
    "preaînțeleptele": "preaînțelept",
    "preaînțeleptelor": "preaînțelept",
    "preaînțelepți": "preaînțelept",
    "preaînțelepții": "preaînțelept",
    "preaînțelepților": "preaînțelept",
    "preaînțeleptul": "preaînțelept",
    "preaînțeleptule": "preaînțelept",
    "preaînțeleptului": "preaînțelept",
    "preaînvățata": "preaînvățat",
    "preaînvățată": "preaînvățat",
    "preaînvățate": "preaînvățat",
    "preaînvățatei": "preaînvățat",
    "preaînvățatele": "preaînvățat",
    "preaînvățatelor": "preaînvățat",
    "preaînvățați": "preaînvățat",
    "preaînvățații": "preaînvățat",
    "preaînvățaților": "preaînvățat",
    "preaînvățatul": "preaînvățat",
    "preaînvățatului": "preaînvățat",
    "preaiubita": "preaiubit",
    "preaiubită": "preaiubit",
    "preaiubite": "preaiubit",
    "preaiubitei": "preaiubit",
    "preaiubitele": "preaiubit",
    "preaiubitelor": "preaiubit",
    "preaiubiți": "preaiubit",
    "preaiubiții": "preaiubit",
    "preaiubiților": "preaiubit",
    "preaiubitul": "preaiubit",
    "preaiubitului": "preaiubit",
    "prealabila": "prealabil",
    "prealabilă": "prealabil",
    "prealabile": "prealabil",
    "prealabilei": "prealabil",
    "prealabilele": "prealabil",
    "prealabilelor": "prealabil",
    "prealabili": "prealabil",
    "prealabilii": "prealabil",
    "prealabililor": "prealabil",
    "prealabilul": "prealabil",
    "prealabilului": "prealabil",
    "prealuminata": "prealuminat",
    "prealuminată": "prealuminat",
    "prealuminate": "prealuminat",
    "prealuminatei": "prealuminat",
    "prealuminatele": "prealuminat",
    "prealuminatelor": "prealuminat",
    "prealuminați": "prealuminat",
    "prealuminații": "prealuminat",
    "prealuminaților": "prealuminat",
    "prealuminatul": "prealuminat",
    "prealuminatului": "prealuminat",
    "nemaipreamărind": "preamări",
    "nemaipreamărindu": "preamări",
    "nepreamărind": "preamări",
    "nepreamărindu": "preamări",
    "preamărea": "preamări",
    "preamăreai": "preamări",
    "preamăream": "preamări",
    "preamărească": "preamări",
    "preamăreați": "preamări",
    "preamăreau": "preamări",
    "preamăresc": "preamări",
    "preamărește": "preamări",
    "preamărești": "preamări",
    "preamării": "preamări",
    "preamărim": "preamări",
    "preamărind": "preamări",
    "preamărindu": "preamări",
    "preamăriră": "preamări",
    "preamărirăm": "preamări",
    "preamărirăți": "preamări",
    "preamărise": "preamări",
    "preamărisem": "preamări",
    "preamăriseră": "preamări",
    "preamăriserăm": "preamări",
    "preamăriserăți": "preamări",
    "preamăriseși": "preamări",
    "preamăriși": "preamări",
    "preamărit": "preamări",
    "preamăriți": "preamări",
    "preamărită": "preamărit",
    "preamărite": "preamărit",
    "preamăriți": "preamărit",
    "preambalata": "preambalat",
    "preambalată": "preambalat",
    "preambalate": "preambalat",
    "preambalatei": "preambalat",
    "preambalatele": "preambalat",
    "preambalatelor": "preambalat",
    "preambalați": "preambalat",
    "preambalații": "preambalat",
    "preambalaților": "preambalat",
    "preambalatul": "preambalat",
    "preambalatului": "preambalat",
    "preambulul": "preambul",
    "preambulului": "preambul",
    "preambuluri": "preambul",
    "preambulurile": "preambul",
    "preambulurilor": "preambul",
    "preambulara": "preambular",
    "preambulară": "preambular",
    "preambulare": "preambular",
    "preambularei": "preambular",
    "preambularele": "preambular",
    "preambularelor": "preambular",
    "preambulari": "preambular",
    "preambularii": "preambular",
    "preambularilor": "preambular",
    "preambularul": "preambular",
    "preambularului": "preambular",
    "preamilostiva": "preamilostiv",
    "preamilostivă": "preamilostiv",
    "preamilostive": "preamilostiv",
    "preamilostivei": "preamilostiv",
    "preamilostivele": "preamilostiv",
    "preamilostivelor": "preamilostiv",
    "preamilostivi": "preamilostiv",
    "preamilostivii": "preamilostiv",
    "preamilostivilor": "preamilostiv",
    "preamilostivul": "preamilostiv",
    "preamilostivului": "preamilostiv",
    "preaplecata": "preaplecat",
    "preaplecată": "preaplecat",
    "preaplecate": "preaplecat",
    "preaplecatei": "preaplecat",
    "preaplecatele": "preaplecat",
    "preaplecatelor": "preaplecat",
    "preaplecați": "preaplecat",
    "preaplecații": "preaplecat",
    "preaplecaților": "preaplecat",
    "preaplecatul": "preaplecat",
    "preaplecatului": "preaplecat",
    "preaprețioasa": "preaprețios",
    "preaprețioasă": "preaprețios",
    "preaprețioase": "preaprețios",
    "preaprețioasei": "preaprețios",
    "preaprețioasele": "preaprețios",
    "preaprețioaselor": "preaprețios",
    "preaprețioși": "preaprețios",
    "preaprețioșii": "preaprețios",
    "preaprețioșilor": "preaprețios",
    "preaprețiosul": "preaprețios",
    "preaprețiosului": "preaprețios",
    "preaputernica": "preaputernic",
    "preaputernică": "preaputernic",
    "preaputernice": "preaputernic",
    "preaputernicei": "preaputernic",
    "preaputernicele": "preaputernic",
    "preaputernicelor": "preaputernic",
    "preaputernici": "preaputernic",
    "preaputernicii": "preaputernic",
    "preaputernicilor": "preaputernic",
    "preaputernicul": "preaputernic",
    "preaputernicului": "preaputernic",
    "preasfânta": "preasfânt",
    "preasfântă": "preasfânt",
    "preasfânte": "preasfânt",
    "preasfântei": "preasfânt",
    "preasfântele": "preasfânt",
    "preasfântelor": "preasfânt",
    "preasfânți": "preasfânt",
    "preasfânții": "preasfânt",
    "preasfânților": "preasfânt",
    "preasfântul": "preasfânt",
    "preasfântului": "preasfânt",
    "preasfințita": "preasfințit",
    "preasfințită": "preasfințit",
    "preasfințite": "preasfințit",
    "preasfințitei": "preasfințit",
    "preasfințitele": "preasfințit",
    "preasfințitelor": "preasfințit",
    "preasfințiți": "preasfințit",
    "preasfințiții": "preasfințit",
    "preasfințiților": "preasfințit",
    "preasfințitul": "preasfințit",
    "preasfințitului": "preasfințit",
    "preaslăvea": "preaslăvi",
    "preaslăveai": "preaslăvi",
    "preaslăveam": "preaslăvi",
    "preaslăvească": "preaslăvi",
    "preaslăveați": "preaslăvi",
    "preaslăveau": "preaslăvi",
    "preaslăvesc": "preaslăvi",
    "preaslăvește": "preaslăvi",
    "preaslăvești": "preaslăvi",
    "preaslăvim": "preaslăvi",
    "preaslăvind": "preaslăvi",
    "preaslăvindu": "preaslăvi",
    "preaslăviră": "preaslăvi",
    "preaslăvirăm": "preaslăvi",
    "preaslăvirăți": "preaslăvi",
    "preaslăvise": "preaslăvi",
    "preaslăvisem": "preaslăvi",
    "preaslăviseră": "preaslăvi",
    "preaslăviserăm": "preaslăvi",
    "preaslăviserăți": "preaslăvi",
    "preaslăviseși": "preaslăvi",
    "preaslăviși": "preaslăvi",
    "preaslăvit": "preaslăvi",
    "preaslăviți": "preaslăvi",
    "preaslăvirea": "preaslăvire",
    "preaslăvireo": "preaslăvire",
    "preaslăviri": "preaslăvire",
    "preaslăvirii": "preaslăvire",
    "preaslăvirile": "preaslăvire",
    "preaslăvirilor": "preaslăvire",
    "preaslăvita": "preaslăvit",
    "preaslăvită": "preaslăvit",
    "preaslăvite": "preaslăvit",
    "preaslăvitei": "preaslăvit",
    "preaslăvitele": "preaslăvit",
    "preaslăvitelor": "preaslăvit",
    "preaslăviți": "preaslăvit",
    "preaslăviții": "preaslăvit",
    "preaslăviților": "preaslăvit",
    "preaslăvito": "preaslăvit",
    "preaslăvitul": "preaslăvit",
    "preaslăvitule": "preaslăvit",
    "preaslăvitului": "preaslăvit",
    "preastimata": "preastimat",
    "preastimată": "preastimat",
    "preastimate": "preastimat",
    "preastimatei": "preastimat",
    "preastimatele": "preastimat",
    "preastimatelor": "preastimat",
    "preastimați": "preastimat",
    "preastimații": "preastimat",
    "preastimaților": "preastimat",
    "preastimatul": "preastimat",
    "preastimatului": "preastimat",
    "preastrălucita": "preastrălucit",
    "preastrălucită": "preastrălucit",
    "preastrălucite": "preastrălucit",
    "preastrălucitei": "preastrălucit",
    "preastrălucitele": "preastrălucit",
    "preastrălucitelor": "preastrălucit",
    "preastrăluciți": "preastrălucit",
    "preastrăluciții": "preastrălucit",
    "preastrăluciților": "preastrălucit",
    "preastrălucitul": "preastrălucit",
    "preastrălucitului": "preastrălucit",
    "preavize": "preaviz",
    "preavizele": "preaviz",
    "preavizelor": "preaviz",
    "preavizul": "preaviz",
    "preavizului": "preaviz",
    "preavrednica": "preavrednic",
    "preavrednică": "preavrednic",
    "preavrednice": "preavrednic",
    "preavrednicei": "preavrednic",
    "preavrednicele": "preavrednic",
    "preavrednicelor": "preavrednic",
    "preavrednici": "preavrednic",
    "preavrednicii": "preavrednic",
    "preavrednicilor": "preavrednic",
    "preavrednicul": "preavrednic",
    "preavrednicului": "preavrednic",
    "preburgheza": "preburghez",
    "preburgheză": "preburghez",
    "preburgheze": "preburghez",
    "preburghezei": "preburghez",
    "preburghezele": "preburghez",
    "preburghezelor": "preburghez",
    "preburghezi": "preburghez",
    "preburghezii": "preburghez",
    "preburghezilor": "preburghez",
    "preburghezul": "preburghez",
    "preburghezului": "preburghez",
    "precăderea": "precădere",
    "precăderi": "precădere",
    "precăderii": "precădere",
    "precalculata": "precalculat",
    "precalculată": "precalculat",
    "precalculate": "precalculat",
    "precalculatei": "precalculat",
    "precalculatele": "precalculat",
    "precalculatelor": "precalculat",
    "precalculați": "precalculat",
    "precalculații": "precalculat",
    "precalculaților": "precalculat",
    "precalculatul": "precalculat",
    "precalculatului": "precalculat",
    "precambriana": "precambrian",
    "precambriană": "precambrian",
    "precambrianul": "precambrian",
    "precambrianului": "precambrian",
    "precambriene": "precambrian",
    "precambrienei": "precambrian",
    "precambrienele": "precambrian",
    "precambrienelor": "precambrian",
    "precambrieni": "precambrian",
    "precambrienii": "precambrian",
    "precambrienilor": "precambrian",
    "precapitalista": "precapitalist",
    "precapitalistă": "precapitalist",
    "precapitaliste": "precapitalist",
    "precapitalistei": "precapitalist",
    "precapitalistele": "precapitalist",
    "precapitalistelor": "precapitalist",
    "precapitaliști": "precapitalist",
    "precapitaliștii": "precapitalist",
    "precapitaliștilor": "precapitalist",
    "precapitalistul": "precapitalist",
    "precapitalistului": "precapitalist",
    "precara": "precar",
    "precară": "precar",
    "precare": "precar",
    "precarei": "precar",
    "precarele": "precar",
    "precarelor": "precar",
    "precari": "precar",
    "precarii": "precar",
    "precarilor": "precar",
    "precarul": "precar",
    "precarului": "precar",
    "precaritatea": "precaritate",
    "precarități": "precaritate",
    "precarității": "precaritate",
    "precauta": "precaut",
    "precaută": "precaut",
    "precaute": "precaut",
    "precautei": "precaut",
    "precautele": "precaut",
    "precautelor": "precaut",
    "precauți": "precaut",
    "precauții": "precaut",
    "precauților": "precaut",
    "precautul": "precaut",
    "precautului": "precaut",
    "precauția": "precauție",
    "precauției": "precauție",
    "precauții": "precauție",
    "precauțiile": "precauție",
    "precauțiilor": "precauție",
    "nemaiprecedând": "preceda",
    "nemaiprecedându": "preceda",
    "neprecedând": "preceda",
    "neprecedându": "preceda",
    "preceadă": "preceda",
    "preced": "preceda",
    "precedă": "preceda",
    "precedai": "preceda",
    "precedam": "preceda",
    "precedăm": "preceda",
    "precedând": "preceda",
    "precedându": "preceda",
    "precedară": "preceda",
    "precedarăm": "preceda",
    "precedarăți": "preceda",
    "precedase": "preceda",
    "precedasem": "preceda",
    "precedaseră": "preceda",
    "precedaserăm": "preceda",
    "precedaserăți": "preceda",
    "precedaseși": "preceda",
    "precedași": "preceda",
    "precedat": "preceda",
    "precedați": "preceda",
    "precedau": "preceda",
    "precezi": "preceda",
    "precedată": "precedat",
    "precedate": "precedat",
    "precedați": "precedat",
    "precedenta": "precedent",
    "precedentă": "precedent",
    "precedente": "precedent",
    "precedentei": "precedent",
    "precedentele": "precedent",
    "precedentelor": "precedent",
    "precedenți": "precedent",
    "precedenții": "precedent",
    "precedenților": "precedent",
    "precedentul": "precedent",
    "precedentului": "precedent",
    "precedența": "precedență",
    "precedențe": "precedență",
    "precedenței": "precedență",
    "precedențele": "precedență",
    "precedențelor": "precedență",
    "precepte": "precept",
    "preceptele": "precept",
    "preceptelor": "precept",
    "preceptul": "precept",
    "preceptului": "precept",
    "nemaiprecipitând": "precipita",
    "nemaiprecipitându": "precipita",
    "neprecipitând": "precipita",
    "neprecipitându": "precipita",
    "precipit": "precipita",
    "precipită": "precipita",
    "precipitai": "precipita",
    "precipitam": "precipita",
    "precipităm": "precipita",
    "precipitând": "precipita",
    "precipitându": "precipita",
    "precipitară": "precipita",
    "precipitarăm": "precipita",
    "precipitarăți": "precipita",
    "precipitase": "precipita",
    "precipitasem": "precipita",
    "precipitaseră": "precipita",
    "precipitaserăm": "precipita",
    "precipitaserăți": "precipita",
    "precipitaseși": "precipita",
    "precipitași": "precipita",
    "precipitat": "precipita",
    "precipitați": "precipita",
    "precipitau": "precipita",
    "precipite": "precipita",
    "precipiți": "precipita",
    "precipitabila": "precipitabil",
    "precipitabilă": "precipitabil",
    "precipitabile": "precipitabil",
    "precipitabilei": "precipitabil",
    "precipitabilele": "precipitabil",
    "precipitabilelor": "precipitabil",
    "precipitabili": "precipitabil",
    "precipitabilii": "precipitabil",
    "precipitabililor": "precipitabil",
    "precipitabilul": "precipitabil",
    "precipitabilului": "precipitabil",
    "precipitată": "precipitat",
    "precipitate": "precipitat",
    "precipitați": "precipitat",
    "precipitația": "precipitație",
    "precipitației": "precipitație",
    "precipitații": "precipitație",
    "precipitațiile": "precipitație",
    "precipitațiilor": "precipitație",
    "precisa": "precis",
    "precisă": "precis",
    "precise": "precis",
    "precisei": "precis",
    "precisele": "precis",
    "preciselor": "precis",
    "preciși": "precis",
    "precișii": "precis",
    "precișilor": "precis",
    "precisul": "precis",
    "precisului": "precis",
    "nemaiprecizând": "preciza",
    "nemaiprecizându": "preciza",
    "neprecizând": "preciza",
    "neprecizându": "preciza",
    "preciză": "preciza",
    "precizai": "preciza",
    "precizam": "preciza",
    "precizăm": "preciza",
    "precizând": "preciza",
    "precizându": "preciza",
    "precizară": "preciza",
    "precizarăm": "preciza",
    "precizarăți": "preciza",
    "precizase": "preciza",
    "precizasem": "preciza",
    "precizaseră": "preciza",
    "precizaserăm": "preciza",
    "precizaserăți": "preciza",
    "precizaseși": "preciza",
    "precizași": "preciza",
    "precizat": "preciza",
    "precizați": "preciza",
    "precizau": "preciza",
    "precizează": "preciza",
    "precizez": "preciza",
    "precizeze": "preciza",
    "precizezi": "preciza",
    "precizarea": "precizare",
    "precizări": "precizare",
    "precizării": "precizare",
    "precizările": "precizare",
    "precizărilor": "precizare",
    "precizată": "precizat",
    "precizate": "precizat",
    "precizați": "precizat",
    "precizia": "precizie",
    "preciziei": "precizie",
    "precizii": "precizie",
    "preciziile": "precizie",
    "preciziilor": "precizie",
    "preclasica": "preclasic",
    "preclasică": "preclasic",
    "preclasice": "preclasic",
    "preclasicei": "preclasic",
    "preclasicele": "preclasic",
    "preclasicelor": "preclasic",
    "preclasici": "preclasic",
    "preclasicii": "preclasic",
    "preclasicilor": "preclasic",
    "preclasicul": "preclasic",
    "preclasicului": "preclasic",
    "precomprimata": "precomprimat",
    "precomprimată": "precomprimat",
    "precomprimate": "precomprimat",
    "precomprimatei": "precomprimat",
    "precomprimatele": "precomprimat",
    "precomprimatelor": "precomprimat",
    "precomprimați": "precomprimat",
    "precomprimații": "precomprimat",
    "precomprimaților": "precomprimat",
    "precomprimatul": "precomprimat",
    "precomprimatului": "precomprimat",
    "preconceputa": "preconceput",
    "preconcepută": "preconceput",
    "preconcepute": "preconceput",
    "preconceputei": "preconceput",
    "preconceputele": "preconceput",
    "preconceputelor": "preconceput",
    "preconcepuți": "preconceput",
    "preconcepuții": "preconceput",
    "preconcepuților": "preconceput",
    "preconceputul": "preconceput",
    "preconceputului": "preconceput",
    "nemaipreconizând": "preconiza",
    "nemaipreconizându": "preconiza",
    "nepreconizând": "preconiza",
    "nepreconizându": "preconiza",
    "preconiză": "preconiza",
    "preconizai": "preconiza",
    "preconizam": "preconiza",
    "preconizăm": "preconiza",
    "preconizând": "preconiza",
    "preconizându": "preconiza",
    "preconizară": "preconiza",
    "preconizarăm": "preconiza",
    "preconizarăți": "preconiza",
    "preconizase": "preconiza",
    "preconizasem": "preconiza",
    "preconizaseră": "preconiza",
    "preconizaserăm": "preconiza",
    "preconizaserăți": "preconiza",
    "preconizaseși": "preconiza",
    "preconizași": "preconiza",
    "preconizat": "preconiza",
    "preconizați": "preconiza",
    "preconizau": "preconiza",
    "preconizează": "preconiza",
    "preconizez": "preconiza",
    "preconizeze": "preconiza",
    "preconizezi": "preconiza",
    "preconizarea": "preconizare",
    "preconizări": "preconizare",
    "preconizării": "preconizare",
    "preconizările": "preconizare",
    "preconizărilor": "preconizare",
    "preconizata": "preconizat",
    "preconizată": "preconizat",
    "preconizate": "preconizat",
    "preconizatei": "preconizat",
    "preconizatele": "preconizat",
    "preconizatelor": "preconizat",
    "preconizați": "preconizat",
    "preconizații": "preconizat",
    "preconizaților": "preconizat",
    "preconizatul": "preconizat",
    "preconizatului": "preconizat",
    "nemaiprecumpănind": "precumpăni",
    "nemaiprecumpănindu": "precumpăni",
    "neprecumpănind": "precumpăni",
    "neprecumpănindu": "precumpăni",
    "precumpănea": "precumpăni",
    "precumpăneai": "precumpăni",
    "precumpăneam": "precumpăni",
    "precumpănească": "precumpăni",
    "precumpăneați": "precumpăni",
    "precumpăneau": "precumpăni",
    "precumpănesc": "precumpăni",
    "precumpănește": "precumpăni",
    "precumpănești": "precumpăni",
    "precumpănii": "precumpăni",
    "precumpănim": "precumpăni",
    "precumpănind": "precumpăni",
    "precumpănindu": "precumpăni",
    "precumpăniră": "precumpăni",
    "precumpănirăm": "precumpăni",
    "precumpănirăți": "precumpăni",
    "precumpănise": "precumpăni",
    "precumpănisem": "precumpăni",
    "precumpăniseră": "precumpăni",
    "precumpăniserăm": "precumpăni",
    "precumpăniserăți": "precumpăni",
    "precumpăniseși": "precumpăni",
    "precumpăniși": "precumpăni",
    "precumpănit": "precumpăni",
    "precumpăniți": "precumpăni",
    "precumpănirea": "precumpănire",
    "precumpăniri": "precumpănire",
    "precumpănirii": "precumpănire",
    "precumpănirile": "precumpănire",
    "precumpănirilor": "precumpănire",
    "precumpănită": "precumpănit",
    "precumpănite": "precumpănit",
    "precumpăniți": "precumpănit",
    "precumpănitoare": "precumpănitor",
    "precumpănitoarea": "precumpănitor",
    "precumpănitoarei": "precumpănitor",
    "precumpănitoarele": "precumpănitor",
    "precumpănitoarelor": "precumpănitor",
    "precumpănitori": "precumpănitor",
    "precumpănitorii": "precumpănitor",
    "precumpănitorilor": "precumpănitor",
    "precumpănitorul": "precumpănitor",
    "precumpănitorului": "precumpănitor",
    "precupeața": "precupeață",
    "precupețe": "precupeață",
    "precupeței": "precupeață",
    "precupețele": "precupeață",
    "precupețelor": "precupeață",
    "precupeți": "precupeț",
    "precupeții": "precupeț",
    "precupeților": "precupeț",
    "precupețul": "precupeț",
    "precupețului": "precupeț",
    "nemaiprecupețind": "precupeți",
    "nemaiprecupețindu": "precupeți",
    "neprecupețind": "precupeți",
    "neprecupețindu": "precupeți",
    "precupețea": "precupeți",
    "precupețeai": "precupeți",
    "precupețeam": "precupeți",
    "precupețească": "precupeți",
    "precupețeați": "precupeți",
    "precupețeau": "precupeți",
    "precupețesc": "precupeți",
    "precupețește": "precupeți",
    "precupețești": "precupeți",
    "precupeții": "precupeți",
    "precupețim": "precupeți",
    "precupețind": "precupeți",
    "precupețindu": "precupeți",
    "precupețiră": "precupeți",
    "precupețirăm": "precupeți",
    "precupețirăți": "precupeți",
    "precupețise": "precupeți",
    "precupețisem": "precupeți",
    "precupețiseră": "precupeți",
    "precupețiserăm": "precupeți",
    "precupețiserăți": "precupeți",
    "precupețiseși": "precupeți",
    "precupețiși": "precupeți",
    "precupețit": "precupeți",
    "precupețiți": "precupeți",
    "precupețită": "precupețit",
    "precupețite": "precupețit",
    "precupețiți": "precupețit",
    "precurmătoare": "precurmător",
    "precurmătoarea": "precurmător",
    "precurmătoarei": "precurmător",
    "precurmătoarele": "precurmător",
    "precurmătoarelor": "precurmător",
    "precurmători": "precurmător",
    "precurmătorii": "precurmător",
    "precurmătorilor": "precurmător",
    "precurmătorul": "precurmător",
    "precurmătorului": "precurmător",
    "precursori": "precursor",
    "precursorii": "precursor",
    "precursorilor": "precursor",
    "precursorul": "precursor",
    "precursorului": "precursor",
    "nemaipredând": "preda",
    "nemaipredându": "preda",
    "nepredând": "preda",
    "nepredându": "preda",
    "predă": "preda",
    "predai": "preda",
    "predam": "preda",
    "predăm": "preda",
    "predând": "preda",
    "predându": "preda",
    "predară": "preda",
    "predarăm": "preda",
    "predarăți": "preda",
    "predase": "preda",
    "predasem": "preda",
    "predaseră": "preda",
    "predaserăm": "preda",
    "predaserăți": "preda",
    "predaseși": "preda",
    "predași": "preda",
    "predat": "preda",
    "predați": "preda",
    "predau": "preda",
    "predea": "preda",
    "predabila": "predabil",
    "predabilă": "predabil",
    "predabile": "predabil",
    "predabilei": "predabil",
    "predabilele": "predabil",
    "predabilelor": "predabil",
    "predabili": "predabil",
    "predabilii": "predabil",
    "predabililor": "predabil",
    "predabilul": "predabil",
    "predabilului": "predabil",
    "predarea": "predare",
    "predări": "predare",
    "predării": "predare",
    "predările": "predare",
    "predărilor": "predare",
    "predată": "predat",
    "predate": "predat",
    "predați": "predat",
    "Predealul": "Predeal",
    "Predealului": "Predeal",
    "predecesoare": "predecesor",
    "predecesoarea": "predecesor",
    "predecesoarei": "predecesor",
    "predecesoarele": "predecesor",
    "predecesoarelor": "predecesor",
    "predecesori": "predecesor",
    "predecesorii": "predecesor",
    "predecesorilor": "predecesor",
    "predecesorul": "predecesor",
    "predecesorului": "predecesor",
    "predeleana": "predelean",
    "predeleană": "predelean",
    "predeleanul": "predelean",
    "predeleanului": "predelean",
    "predelene": "predelean",
    "predelenei": "predelean",
    "predelenele": "predelean",
    "predelenelor": "predelean",
    "predeleni": "predelean",
    "predelenii": "predelean",
    "predelenilor": "predelean",
    "predestinarea": "predestinare",
    "predestinări": "predestinare",
    "predestinării": "predestinare",
    "predestinările": "predestinare",
    "predestinărilor": "predestinare",
    "predestinata": "predestinat",
    "predestinată": "predestinat",
    "predestinate": "predestinat",
    "predestinatei": "predestinat",
    "predestinatele": "predestinat",
    "predestinatelor": "predestinat",
    "predestinați": "predestinat",
    "predestinații": "predestinat",
    "predestinaților": "predestinat",
    "predestinatul": "predestinat",
    "predestinatului": "predestinat",
    "predeterminanta": "predeterminant",
    "predeterminantă": "predeterminant",
    "predeterminante": "predeterminant",
    "predeterminantei": "predeterminant",
    "predeterminantele": "predeterminant",
    "predeterminantelor": "predeterminant",
    "predeterminanți": "predeterminant",
    "predeterminanții": "predeterminant",
    "predeterminanților": "predeterminant",
    "predeterminantul": "predeterminant",
    "predeterminantului": "predeterminant",
    "predeterminata": "predeterminat",
    "predeterminată": "predeterminat",
    "predeterminate": "predeterminat",
    "predeterminatei": "predeterminat",
    "predeterminatele": "predeterminat",
    "predeterminatelor": "predeterminat",
    "predeterminați": "predeterminat",
    "predeterminații": "predeterminat",
    "predeterminaților": "predeterminat",
    "predeterminatul": "predeterminat",
    "predeterminatului": "predeterminat",
    "nemaipredicând": "predica",
    "nemaipredicându": "predica",
    "nepredicând": "predica",
    "nepredicându": "predica",
    "predic": "predica",
    "predică": "predica",
    "predicai": "predica",
    "predicam": "predica",
    "predicăm": "predica",
    "predicând": "predica",
    "predicându": "predica",
    "predicară": "predica",
    "predicarăm": "predica",
    "predicarăți": "predica",
    "predicase": "predica",
    "predicasem": "predica",
    "predicaseră": "predica",
    "predicaserăm": "predica",
    "predicaserăți": "predica",
    "predicaseși": "predica",
    "predicași": "predica",
    "predicat": "predica",
    "predicați": "predica",
    "predicau": "predica",
    "predice": "predica",
    "predici": "predica",
    "predica": "predică",
    "predici": "predică",
    "predicii": "predică",
    "predicile": "predică",
    "predicilor": "predică",
    "predicabila": "predicabil",
    "predicabilă": "predicabil",
    "predicabile": "predicabil",
    "predicabilei": "predicabil",
    "predicabilele": "predicabil",
    "predicabilelor": "predicabil",
    "predicabili": "predicabil",
    "predicabilii": "predicabil",
    "predicabililor": "predicabil",
    "predicabilul": "predicabil",
    "predicabilului": "predicabil",
    "predicată": "predicat",
    "predicate": "predicat",
    "predicatele": "predicat",
    "predicatelor": "predicat",
    "predicați": "predicat",
    "predicatul": "predicat",
    "predicatului": "predicat",
    "predicativa": "predicativ",
    "predicativă": "predicativ",
    "predicative": "predicativ",
    "predicativei": "predicativ",
    "predicativele": "predicativ",
    "predicativelor": "predicativ",
    "predicativi": "predicativ",
    "predicativii": "predicativ",
    "predicativilor": "predicativ",
    "predicativul": "predicativ",
    "predicativului": "predicativ",
    "predicatori": "predicator",
    "predicatorii": "predicator",
    "predicatorilor": "predicator",
    "predicatorul": "predicator",
    "predicatorului": "predicator",
    "predicția": "predicție",
    "predicției": "predicție",
    "predicții": "predicție",
    "predicțiile": "predicție",
    "predicțiilor": "predicție",
    "predilecta": "predilect",
    "predilectă": "predilect",
    "predilecte": "predilect",
    "predilectei": "predilect",
    "predilectele": "predilect",
    "predilectelor": "predilect",
    "predilecți": "predilect",
    "predilecții": "predilect",
    "predilecților": "predilect",
    "predilectul": "predilect",
    "predilectului": "predilect",
    "predilecția": "predilecție",
    "predilecției": "predilecție",
    "predilecții": "predilecție",
    "predilecțiile": "predilecție",
    "predilecțiilor": "predilecție",
    "predispoziția": "predispoziție",
    "predispoziției": "predispoziție",
    "predispoziții": "predispoziție",
    "predispozițiile": "predispoziție",
    "predispozițiilor": "predispoziție",
    "nemaipredispunând": "predispune",
    "nemaipredispunându": "predispune",
    "nepredispunând": "predispune",
    "nepredispunându": "predispune",
    "predispui": "predispune",
    "predispun": "predispune",
    "predispună": "predispune",
    "predispunând": "predispune",
    "predispunându": "predispune",
    "predispunea": "predispune",
    "predispuneai": "predispune",
    "predispuneam": "predispune",
    "predispuneați": "predispune",
    "predispuneau": "predispune",
    "predispunem": "predispune",
    "predispuneți": "predispune",
    "predispus": "predispune",
    "predispuse": "predispune",
    "predispusei": "predispune",
    "predispuseră": "predispune",
    "predispuserăm": "predispune",
    "predispuserăți": "predispune",
    "predispusese": "predispune",
    "predispusesem": "predispune",
    "predispuseseră": "predispune",
    "predispuseserăm": "predispune",
    "predispuseserăți": "predispune",
    "predispuseseși": "predispune",
    "predispuseși": "predispune",
    "predispusa": "predispus",
    "predispusă": "predispus",
    "predispuse": "predispus",
    "predispusei": "predispus",
    "predispusele": "predispus",
    "predispuselor": "predispus",
    "predispuși": "predispus",
    "predispușii": "predispus",
    "predispușilor": "predispus",
    "predispusul": "predispus",
    "predispusului": "predispus",
    "nemaipredominând": "predomina",
    "nemaipredominându": "predomina",
    "nepredominând": "predomina",
    "nepredominându": "predomina",
    "predomin": "predomina",
    "predomină": "predomina",
    "predominai": "predomina",
    "predominam": "predomina",
    "predominăm": "predomina",
    "predominând": "predomina",
    "predominându": "predomina",
    "predominară": "predomina",
    "predominarăm": "predomina",
    "predominarăți": "predomina",
    "predominase": "predomina",
    "predominasem": "predomina",
    "predominaseră": "predomina",
    "predominaserăm": "predomina",
    "predominaserăți": "predomina",
    "predominaseși": "predomina",
    "predominași": "predomina",
    "predominat": "predomina",
    "predominați": "predomina",
    "predominau": "predomina",
    "predomine": "predomina",
    "predomini": "predomina",
    "predominanta": "predominant",
    "predominantă": "predominant",
    "predominante": "predominant",
    "predominantei": "predominant",
    "predominantele": "predominant",
    "predominantelor": "predominant",
    "predominanți": "predominant",
    "predominanții": "predominant",
    "predominanților": "predominant",
    "predominantul": "predominant",
    "predominantului": "predominant",
    "predominarea": "predominare",
    "predominări": "predominare",
    "predominării": "predominare",
    "predominările": "predominare",
    "predominărilor": "predominare",
    "predominată": "predominat",
    "predominate": "predominat",
    "predominați": "predominat",
    "predominatoare": "predominator",
    "predominatoarea": "predominator",
    "predominatoarei": "predominator",
    "predominatoarele": "predominator",
    "predominatoarelor": "predominator",
    "predominatori": "predominator",
    "predominatorii": "predominator",
    "predominatorilor": "predominator",
    "predominatorul": "predominator",
    "predominatorului": "predominator",
    "preduceaua": "preducea",
    "preducele": "preducea",
    "preducelei": "preducea",
    "preducelele": "preducea",
    "preducelelor": "preducea",
    "preelectorala": "preelectoral",
    "preelectorală": "preelectoral",
    "preelectorale": "preelectoral",
    "preelectoralei": "preelectoral",
    "preelectoralele": "preelectoral",
    "preelectoralelor": "preelectoral",
    "preelectorali": "preelectoral",
    "preelectoralii": "preelectoral",
    "preelectoralilor": "preelectoral",
    "preelectoralul": "preelectoral",
    "preelectoralului": "preelectoral",
    "preexistenta": "preexistent",
    "preexistentă": "preexistent",
    "preexistente": "preexistent",
    "preexistentei": "preexistent",
    "preexistentele": "preexistent",
    "preexistentelor": "preexistent",
    "preexistenți": "preexistent",
    "preexistenții": "preexistent",
    "preexistenților": "preexistent",
    "preexistentul": "preexistent",
    "preexistentului": "preexistent",
    "nemaiprefabricând": "prefabrica",
    "nemaiprefabricându": "prefabrica",
    "neprefabricând": "prefabrica",
    "neprefabricându": "prefabrica",
    "prefabric": "prefabrica",
    "prefabrică": "prefabrica",
    "prefabricai": "prefabrica",
    "prefabricam": "prefabrica",
    "prefabricăm": "prefabrica",
    "prefabricând": "prefabrica",
    "prefabricându": "prefabrica",
    "prefabricară": "prefabrica",
    "prefabricarăm": "prefabrica",
    "prefabricarăți": "prefabrica",
    "prefabricase": "prefabrica",
    "prefabricasem": "prefabrica",
    "prefabricaseră": "prefabrica",
    "prefabricaserăm": "prefabrica",
    "prefabricaserăți": "prefabrica",
    "prefabricaseși": "prefabrica",
    "prefabricași": "prefabrica",
    "prefabricat": "prefabrica",
    "prefabricați": "prefabrica",
    "prefabricau": "prefabrica",
    "prefabrice": "prefabrica",
    "prefabrici": "prefabrica",
    "prefabricată": "prefabricat",
    "prefabricate": "prefabricat",
    "prefabricatele": "prefabricat",
    "prefabricatelor": "prefabricat",
    "prefabricați": "prefabricat",
    "prefabricatul": "prefabricat",
    "prefabricatului": "prefabricat",
    "prefăcătoare": "prefăcător",
    "prefăcătoarea": "prefăcător",
    "prefăcătoarei": "prefăcător",
    "prefăcătoarele": "prefăcător",
    "prefăcătoarelor": "prefăcător",
    "prefăcători": "prefăcător",
    "prefăcătorii": "prefăcător",
    "prefăcătorilor": "prefăcător",
    "prefăcătorul": "prefăcător",
    "prefăcătorului": "prefăcător",
    "prefăcătoria": "prefăcătorie",
    "prefăcătoriei": "prefăcătorie",
    "prefăcătorii": "prefăcătorie",
    "prefăcătoriile": "prefăcătorie",
    "prefăcătoriilor": "prefăcătorie",
    "nemaiprefăcând": "preface",
    "nemaiprefăcându": "preface",
    "neprefăcând": "preface",
    "neprefăcându": "preface",
    "prefă": "preface",
    "prefac": "preface",
    "prefacă": "preface",
    "prefăcând": "preface",
    "prefăcându": "preface",
    "prefăcea": "preface",
    "prefăceai": "preface",
    "prefăceam": "preface",
    "prefăceați": "preface",
    "prefăceau": "preface",
    "prefacem": "preface",
    "prefaceți": "preface",
    "prefaci": "preface",
    "prefăcu": "preface",
    "prefăcui": "preface",
    "prefăcură": "preface",
    "prefăcurăm": "preface",
    "prefăcurăți": "preface",
    "prefăcuse": "preface",
    "prefăcusem": "preface",
    "prefăcuseră": "preface",
    "prefăcuserăm": "preface",
    "prefăcuserăți": "preface",
    "prefăcuseși": "preface",
    "prefăcuși": "preface",
    "prefăcut": "preface",
    "prefacerea": "prefacere",
    "prefaceri": "prefacere",
    "prefacerii": "prefacere",
    "prefacerile": "prefacere",
    "prefacerilor": "prefacere",
    "prefăcută": "prefăcut",
    "prefăcute": "prefăcut",
    "prefăcuți": "prefăcut",
    "nemaiprefațând": "prefața",
    "nemaiprefațându": "prefața",
    "neprefațând": "prefața",
    "neprefațându": "prefața",
    "prefață": "prefața",
    "prefațai": "prefața",
    "prefațam": "prefața",
    "prefațăm": "prefața",
    "prefațând": "prefața",
    "prefațându": "prefața",
    "prefațară": "prefața",
    "prefațarăm": "prefața",
    "prefațarăți": "prefața",
    "prefațase": "prefața",
    "prefațasem": "prefața",
    "prefațaseră": "prefața",
    "prefațaserăm": "prefața",
    "prefațaserăți": "prefața",
    "prefațaseși": "prefața",
    "prefațași": "prefața",
    "prefațat": "prefața",
    "prefațați": "prefața",
    "prefațau": "prefața",
    "prefațează": "prefața",
    "prefațez": "prefața",
    "prefațeze": "prefața",
    "prefațezi": "prefața",
    "prefața": "prefață",
    "prefețe": "prefață",
    "prefeței": "prefață",
    "prefețele": "prefață",
    "prefețelor": "prefață",
    "prefațată": "prefațat",
    "prefațate": "prefațat",
    "prefațați": "prefațat",
    "prefecți": "prefect",
    "prefecții": "prefect",
    "prefecților": "prefect",
    "prefectul": "prefect",
    "prefectului": "prefect",
    "prefectorala": "prefectoral",
    "prefectorală": "prefectoral",
    "prefectorale": "prefectoral",
    "prefectoralei": "prefectoral",
    "prefectoralele": "prefectoral",
    "prefectoralelor": "prefectoral",
    "prefectorali": "prefectoral",
    "prefectoralii": "prefectoral",
    "prefectoralilor": "prefectoral",
    "prefectoralul": "prefectoral",
    "prefectoralului": "prefectoral",
    "prefectura": "prefectură",
    "prefecturi": "prefectură",
    "prefecturii": "prefectură",
    "prefecturile": "prefectură",
    "prefecturilor": "prefectură",
    "nemaipreferând": "prefera",
    "nemaipreferându": "prefera",
    "nepreferând": "prefera",
    "nepreferându": "prefera",
    "prefer": "prefera",
    "preferă": "prefera",
    "preferai": "prefera",
    "preferam": "prefera",
    "preferăm": "prefera",
    "preferând": "prefera",
    "preferându": "prefera",
    "preferară": "prefera",
    "preferarăm": "prefera",
    "preferarăți": "prefera",
    "preferase": "prefera",
    "preferasem": "prefera",
    "preferaseră": "prefera",
    "preferaserăm": "prefera",
    "preferaserăți": "prefera",
    "preferaseși": "prefera",
    "preferași": "prefera",
    "preferat": "prefera",
    "preferați": "prefera",
    "preferau": "prefera",
    "prefere": "prefera",
    "preferi": "prefera",
    "preferabila": "preferabil",
    "preferabilă": "preferabil",
    "preferabile": "preferabil",
    "preferabilei": "preferabil",
    "preferabilele": "preferabil",
    "preferabilelor": "preferabil",
    "preferabili": "preferabil",
    "preferabilii": "preferabil",
    "preferabililor": "preferabil",
    "preferabilul": "preferabil",
    "preferabilului": "preferabil",
    "preferată": "preferat",
    "preferate": "preferat",
    "preferați": "preferat",
    "preferențiala": "preferențial",
    "preferențială": "preferențial",
    "preferențiale": "preferențial",
    "preferențialei": "preferențial",
    "preferențialele": "preferențial",
    "preferențialelor": "preferențial",
    "preferențiali": "preferențial",
    "preferențialii": "preferențial",
    "preferențialilor": "preferențial",
    "preferențialul": "preferențial",
    "preferențialului": "preferențial",
    "preferința": "preferință",
    "preferințe": "preferință",
    "preferinței": "preferință",
    "preferințele": "preferință",
    "preferințelor": "preferință",
    "prefeudala": "prefeudal",
    "prefeudală": "prefeudal",
    "prefeudale": "prefeudal",
    "prefeudalei": "prefeudal",
    "prefeudalele": "prefeudal",
    "prefeudalelor": "prefeudal",
    "prefeudali": "prefeudal",
    "prefeudalii": "prefeudal",
    "prefeudalilor": "prefeudal",
    "prefeudalul": "prefeudal",
    "prefeudalului": "prefeudal",
    "nemaiprefigurând": "prefigura",
    "nemaiprefigurându": "prefigura",
    "neprefigurând": "prefigura",
    "neprefigurându": "prefigura",
    "prefigură": "prefigura",
    "prefigurai": "prefigura",
    "prefiguram": "prefigura",
    "prefigurăm": "prefigura",
    "prefigurând": "prefigura",
    "prefigurându": "prefigura",
    "prefigurară": "prefigura",
    "prefigurarăm": "prefigura",
    "prefigurarăți": "prefigura",
    "prefigurase": "prefigura",
    "prefigurasem": "prefigura",
    "prefiguraseră": "prefigura",
    "prefiguraserăm": "prefigura",
    "prefiguraserăți": "prefigura",
    "prefiguraseși": "prefigura",
    "prefigurași": "prefigura",
    "prefigurat": "prefigura",
    "prefigurați": "prefigura",
    "prefigurau": "prefigura",
    "prefigurează": "prefigura",
    "prefigurez": "prefigura",
    "prefigureze": "prefigura",
    "prefigurezi": "prefigura",
    "prefigurată": "prefigurat",
    "prefigurate": "prefigurat",
    "prefigurați": "prefigurat",
    "nemaiprefirând": "prefira",
    "nemaiprefirându": "prefira",
    "neprefirând": "prefira",
    "neprefirându": "prefira",
    "prefir": "prefira",
    "prefiră": "prefira",
    "prefirai": "prefira",
    "prefiram": "prefira",
    "prefirăm": "prefira",
    "prefirând": "prefira",
    "prefirându": "prefira",
    "prefirară": "prefira",
    "prefirarăm": "prefira",
    "prefirarăți": "prefira",
    "prefirase": "prefira",
    "prefirasem": "prefira",
    "prefiraseră": "prefira",
    "prefiraserăm": "prefira",
    "prefiraserăți": "prefira",
    "prefiraseși": "prefira",
    "prefirași": "prefira",
    "prefirat": "prefira",
    "prefirați": "prefira",
    "prefirau": "prefira",
    "prefire": "prefira",
    "prefiri": "prefira",
    "prefirată": "prefirat",
    "prefirate": "prefirat",
    "prefirați": "prefirat",
    "pref.": "prefix",
    "prefixe": "prefix",
    "prefixele": "prefix",
    "prefixelor": "prefix",
    "prefixul": "prefix",
    "prefixului": "prefix",
    "nemaiprefixând": "prefixa",
    "nemaiprefixându": "prefixa",
    "neprefixând": "prefixa",
    "neprefixându": "prefixa",
    "prefixă": "prefixa",
    "prefixai": "prefixa",
    "prefixam": "prefixa",
    "prefixăm": "prefixa",
    "prefixând": "prefixa",
    "prefixându": "prefixa",
    "prefixară": "prefixa",
    "prefixarăm": "prefixa",
    "prefixarăți": "prefixa",
    "prefixase": "prefixa",
    "prefixasem": "prefixa",
    "prefixaseră": "prefixa",
    "prefixaserăm": "prefixa",
    "prefixaserăți": "prefixa",
    "prefixaseși": "prefixa",
    "prefixași": "prefixa",
    "prefixat": "prefixa",
    "prefixați": "prefixa",
    "prefixau": "prefixa",
    "prefixează": "prefixa",
    "prefixez": "prefixa",
    "prefixeze": "prefixa",
    "prefixezi": "prefixa",
    "prefixată": "prefixat",
    "prefixate": "prefixat",
    "prefixați": "prefixat",
    "nemaipregătind": "pregăti",
    "nemaipregătindu": "pregăti",
    "nepregătind": "pregăti",
    "nepregătindu": "pregăti",
    "pregătea": "pregăti",
    "pregăteai": "pregăti",
    "pregăteam": "pregăti",
    "pregătească": "pregăti",
    "pregăteați": "pregăti",
    "pregăteau": "pregăti",
    "pregătesc": "pregăti",
    "pregătește": "pregăti",
    "pregătești": "pregăti",
    "pregătii": "pregăti",
    "pregătim": "pregăti",
    "pregătind": "pregăti",
    "pregătindu": "pregăti",
    "pregătiră": "pregăti",
    "pregătirăm": "pregăti",
    "pregătirăți": "pregăti",
    "pregătise": "pregăti",
    "pregătisem": "pregăti",
    "pregătiseră": "pregăti",
    "pregătiserăm": "pregăti",
    "pregătiserăți": "pregăti",
    "pregătiseși": "pregăti",
    "pregătiși": "pregăti",
    "pregătit": "pregăti",
    "pregătiți": "pregăti",
    "pregătirea": "pregătire",
    "pregătiri": "pregătire",
    "pregătirii": "pregătire",
    "pregătirile": "pregătire",
    "pregătirilor": "pregătire",
    "pregătită": "pregătit",
    "pregătite": "pregătit",
    "pregătiți": "pregătit",
    "pregătitoare": "pregătitor",
    "pregătitoarea": "pregătitor",
    "pregătitoarei": "pregătitor",
    "pregătitoarele": "pregătitor",
    "pregătitoarelor": "pregătitor",
    "pregătitori": "pregătitor",
    "pregătitorii": "pregătitor",
    "pregătitorilor": "pregătitor",
    "pregătitorul": "pregătitor",
    "pregătitorului": "pregătitor",
    "pregete": "preget",
    "pregetele": "preget",
    "pregetelor": "preget",
    "pregetul": "preget",
    "pregetului": "preget",
    "nemaipregetând": "pregeta",
    "nemaipregetându": "pregeta",
    "nepregetând": "pregeta",
    "nepregetându": "pregeta",
    "preget": "pregeta",
    "pregetă": "pregeta",
    "pregetai": "pregeta",
    "pregetam": "pregeta",
    "pregetăm": "pregeta",
    "pregetând": "pregeta",
    "pregetându": "pregeta",
    "pregetară": "pregeta",
    "pregetarăm": "pregeta",
    "pregetarăți": "pregeta",
    "pregetase": "pregeta",
    "pregetasem": "pregeta",
    "pregetaseră": "pregeta",
    "pregetaserăm": "pregeta",
    "pregetaserăți": "pregeta",
    "pregetaseși": "pregeta",
    "pregetași": "pregeta",
    "pregetat": "pregeta",
    "pregetați": "pregeta",
    "pregetau": "pregeta",
    "pregete": "pregeta",
    "pregeți": "pregeta",
    "pregetată": "pregetat",
    "pregetate": "pregetat",
    "pregetați": "pregetat",
    "pregnanta": "pregnant",
    "pregnantă": "pregnant",
    "pregnante": "pregnant",
    "pregnantei": "pregnant",
    "pregnantele": "pregnant",
    "pregnantelor": "pregnant",
    "pregnanți": "pregnant",
    "pregnanții": "pregnant",
    "pregnanților": "pregnant",
    "pregnantul": "pregnant",
    "pregnantului": "pregnant",
    "prehensila": "prehensil",
    "prehensilă": "prehensil",
    "prehensile": "prehensil",
    "prehensilei": "prehensil",
    "prehensilele": "prehensil",
    "prehensilelor": "prehensil",
    "prehensili": "prehensil",
    "prehensilii": "prehensil",
    "prehensililor": "prehensil",
    "prehensilul": "prehensil",
    "prehensilului": "prehensil",
    "preimperialista": "preimperialist",
    "preimperialistă": "preimperialist",
    "preimperialiste": "preimperialist",
    "preimperialistei": "preimperialist",
    "preimperialistele": "preimperialist",
    "preimperialistelor": "preimperialist",
    "preimperialiști": "preimperialist",
    "preimperialiștii": "preimperialist",
    "preimperialiștilor": "preimperialist",
    "preimperialistul": "preimperialist",
    "preimperialistului": "preimperialist",
    "preîntâmpin": "preîntâmpina",
    "preîntâmpină": "preîntâmpina",
    "preîntâmpinai": "preîntâmpina",
    "preîntâmpinam": "preîntâmpina",
    "preîntâmpinăm": "preîntâmpina",
    "preîntâmpinând": "preîntâmpina",
    "preîntâmpinarăm": "preîntâmpina",
    "preîntâmpinarăți": "preîntâmpina",
    "preîntâmpinase": "preîntâmpina",
    "preîntâmpinasem": "preîntâmpina",
    "preîntâmpinaseră": "preîntâmpina",
    "preîntâmpinaserăm": "preîntâmpina",
    "preîntâmpinaserăți": "preîntâmpina",
    "preîntâmpinaseși": "preîntâmpina",
    "preîntâmpinași": "preîntâmpina",
    "preîntâmpinat": "preîntâmpina",
    "preîntâmpinați": "preîntâmpina",
    "preîntâmpinau": "preîntâmpina",
    "preîntâmpine": "preîntâmpina",
    "preîntâmpini": "preîntâmpina",
    "preîntâmpinată": "preîntâmpinat",
    "preîntâmpinate": "preîntâmpinat",
    "preîntâmpinați": "preîntâmpinat",
    "preistorica": "preistoric",
    "preistorică": "preistoric",
    "preistorice": "preistoric",
    "preistoricei": "preistoric",
    "preistoricele": "preistoric",
    "preistoricelor": "preistoric",
    "preistorici": "preistoric",
    "preistoricii": "preistoric",
    "preistoricilor": "preistoric",
    "preistoricul": "preistoric",
    "preistoricului": "preistoric",
    "prejudecata": "prejudecată",
    "prejudecăți": "prejudecată",
    "prejudecății": "prejudecată",
    "prejudecățile": "prejudecată",
    "prejudecăților": "prejudecată",
    "nemaiprejudiciind": "prejudicia",
    "nemaiprejudiciindu": "prejudicia",
    "neprejudiciind": "prejudicia",
    "neprejudiciindu": "prejudicia",
    "prejudiciai": "prejudicia",
    "prejudiciam": "prejudicia",
    "prejudiciară": "prejudicia",
    "prejudiciarăm": "prejudicia",
    "prejudiciarăți": "prejudicia",
    "prejudiciase": "prejudicia",
    "prejudiciasem": "prejudicia",
    "prejudiciaseră": "prejudicia",
    "prejudiciaserăm": "prejudicia",
    "prejudiciaserăți": "prejudicia",
    "prejudiciaseși": "prejudicia",
    "prejudiciași": "prejudicia",
    "prejudiciat": "prejudicia",
    "prejudiciați": "prejudicia",
    "prejudiciau": "prejudicia",
    "prejudiciază": "prejudicia",
    "prejudicie": "prejudicia",
    "prejudiciem": "prejudicia",
    "prejudiciez": "prejudicia",
    "prejudicieze": "prejudicia",
    "prejudiciezi": "prejudicia",
    "prejudiciind": "prejudicia",
    "prejudiciindu": "prejudicia",
    "prejudiciabila": "prejudiciabil",
    "prejudiciabilă": "prejudiciabil",
    "prejudiciabile": "prejudiciabil",
    "prejudiciabilei": "prejudiciabil",
    "prejudiciabilele": "prejudiciabil",
    "prejudiciabilelor": "prejudiciabil",
    "prejudiciabili": "prejudiciabil",
    "prejudiciabilii": "prejudiciabil",
    "prejudiciabililor": "prejudiciabil",
    "prejudiciabilul": "prejudiciabil",
    "prejudiciabilului": "prejudiciabil",
    "prejudiciala": "prejudicial",
    "prejudicială": "prejudicial",
    "prejudiciale": "prejudicial",
    "prejudicialei": "prejudicial",
    "prejudicialele": "prejudicial",
    "prejudicialelor": "prejudicial",
    "prejudiciali": "prejudicial",
    "prejudicialii": "prejudicial",
    "prejudicialilor": "prejudicial",
    "prejudicialul": "prejudicial",
    "prejudicialului": "prejudicial",
    "prejudiciată": "prejudiciat",
    "prejudiciate": "prejudiciat",
    "prejudiciați": "prejudiciat",
    "prejudicii": "prejudiciu",
    "prejudiciile": "prejudiciu",
    "prejudiciilor": "prejudiciu",
    "prejudiciul": "prejudiciu",
    "prejudiciului": "prejudiciu",
    "prelați": "prelat",
    "prelații": "prelat",
    "prelaților": "prelat",
    "prelatul": "prelat",
    "prelatului": "prelat",
    "prelata": "prelată",
    "prelate": "prelată",
    "prelatei": "prelată",
    "prelatele": "prelată",
    "prelatelor": "prelată",
    "prelatina": "prelatin",
    "prelatină": "prelatin",
    "prelatine": "prelatin",
    "prelatinei": "prelatin",
    "prelatinele": "prelatin",
    "prelatinelor": "prelatin",
    "prelatini": "prelatin",
    "prelatinii": "prelatin",
    "prelatinilor": "prelatin",
    "prelatinul": "prelatin",
    "prelatinului": "prelatin",
    "prelegerea": "prelegere",
    "prelegeri": "prelegere",
    "prelegerii": "prelegere",
    "prelegerile": "prelegere",
    "prelegerilor": "prelegere",
    "nemaiprelevând": "preleva",
    "nemaiprelevându": "preleva",
    "neprelevând": "preleva",
    "neprelevându": "preleva",
    "prelev": "preleva",
    "prelevă": "preleva",
    "prelevai": "preleva",
    "prelevam": "preleva",
    "prelevăm": "preleva",
    "prelevând": "preleva",
    "prelevându": "preleva",
    "prelevară": "preleva",
    "prelevarăm": "preleva",
    "prelevarăți": "preleva",
    "prelevase": "preleva",
    "prelevasem": "preleva",
    "prelevaseră": "preleva",
    "prelevaserăm": "preleva",
    "prelevaserăți": "preleva",
    "prelevaseși": "preleva",
    "prelevași": "preleva",
    "prelevat": "preleva",
    "prelevați": "preleva",
    "prelevau": "preleva",
    "preleve": "preleva",
    "prelevi": "preleva",
    "prelevată": "prelevat",
    "prelevate": "prelevat",
    "prelevați": "prelevat",
    "preliminara": "preliminar",
    "preliminară": "preliminar",
    "preliminare": "preliminar",
    "preliminarei": "preliminar",
    "preliminarele": "preliminar",
    "preliminarelor": "preliminar",
    "preliminari": "preliminar",
    "preliminarii": "preliminar",
    "preliminariile": "preliminar",
    "preliminariilor": "preliminar",
    "preliminarilor": "preliminar",
    "preliminarul": "preliminar",
    "preliminarului": "preliminar",
    "nemaiprelingând": "prelinge",
    "nemaiprelingându": "prelinge",
    "neprelingând": "prelinge",
    "neprelingându": "prelinge",
    "preling": "prelinge",
    "prelingă": "prelinge",
    "prelingând": "prelinge",
    "prelingându": "prelinge",
    "prelingea": "prelinge",
    "prelingeai": "prelinge",
    "prelingeam": "prelinge",
    "prelingeați": "prelinge",
    "prelingeau": "prelinge",
    "prelingem": "prelinge",
    "prelingeți": "prelinge",
    "prelingi": "prelinge",
    "prelins": "prelinge",
    "prelinse": "prelinge",
    "prelinsei": "prelinge",
    "prelinseră": "prelinge",
    "prelinserăm": "prelinge",
    "prelinserăți": "prelinge",
    "prelinsese": "prelinge",
    "prelinsesem": "prelinge",
    "prelinseseră": "prelinge",
    "prelinseserăm": "prelinge",
    "prelinseserăți": "prelinge",
    "prelinseseși": "prelinge",
    "prelinseși": "prelinge",
    "prelinsă": "prelins",
    "prelinse": "prelins",
    "prelinși": "prelins",
    "nemaipreluând": "prelua",
    "nemaipreluându": "prelua",
    "nepreluând": "prelua",
    "nepreluându": "prelua",
    "preia": "prelua",
    "preiau": "prelua",
    "preiei": "prelua",
    "preluă": "prelua",
    "preluai": "prelua",
    "preluam": "prelua",
    "preluăm": "prelua",
    "preluând": "prelua",
    "preluându": "prelua",
    "preluară": "prelua",
    "preluarăm": "prelua",
    "preluarăți": "prelua",
    "preluase": "prelua",
    "preluasem": "prelua",
    "preluaseră": "prelua",
    "preluaserăm": "prelua",
    "preluaserăți": "prelua",
    "preluaseși": "prelua",
    "preluași": "prelua",
    "preluat": "prelua",
    "preluați": "prelua",
    "preluau": "prelua",
    "preluarea": "preluare",
    "preluări": "preluare",
    "preluării": "preluare",
    "preluările": "preluare",
    "preluărilor": "preluare",
    "preluată": "preluat",
    "preluate": "preluat",
    "preluați": "preluat",
    "nemaiprelucrând": "prelucra",
    "nemaiprelucrându": "prelucra",
    "neprelucrând": "prelucra",
    "neprelucrându": "prelucra",
    "prelucră": "prelucra",
    "prelucrai": "prelucra",
    "prelucram": "prelucra",
    "prelucrăm": "prelucra",
    "prelucrând": "prelucra",
    "prelucrându": "prelucra",
    "prelucrară": "prelucra",
    "prelucrarăm": "prelucra",
    "prelucrarăți": "prelucra",
    "prelucrase": "prelucra",
    "prelucrasem": "prelucra",
    "prelucraseră": "prelucra",
    "prelucraserăm": "prelucra",
    "prelucraserăți": "prelucra",
    "prelucraseși": "prelucra",
    "prelucrași": "prelucra",
    "prelucrat": "prelucra",
    "prelucrați": "prelucra",
    "prelucrau": "prelucra",
    "prelucrează": "prelucra",
    "prelucrez": "prelucra",
    "prelucreze": "prelucra",
    "prelucrezi": "prelucra",
    "prelucrabila": "prelucrabil",
    "prelucrabilă": "prelucrabil",
    "prelucrabile": "prelucrabil",
    "prelucrabilei": "prelucrabil",
    "prelucrabilele": "prelucrabil",
    "prelucrabilelor": "prelucrabil",
    "prelucrabili": "prelucrabil",
    "prelucrabilii": "prelucrabil",
    "prelucrabililor": "prelucrabil",
    "prelucrabilul": "prelucrabil",
    "prelucrabilului": "prelucrabil",
    "prelucrarea": "prelucrare",
    "prelucrări": "prelucrare",
    "prelucrării": "prelucrare",
    "prelucrările": "prelucrare",
    "prelucrărilor": "prelucrare",
    "prelucrată": "prelucrat",
    "prelucrate": "prelucrat",
    "prelucrați": "prelucrat",
    "prelucrătoare": "prelucrător",
    "prelucrătoarea": "prelucrător",
    "prelucrătoarei": "prelucrător",
    "prelucrătoarele": "prelucrător",
    "prelucrătoarelor": "prelucrător",
    "prelucrători": "prelucrător",
    "prelucrătorii": "prelucrător",
    "prelucrătorilor": "prelucrător",
    "prelucrătorul": "prelucrător",
    "prelucrătorului": "prelucrător",
    "preludii": "preludiu",
    "preludiile": "preludiu",
    "preludiilor": "preludiu",
    "preludiul": "preludiu",
    "preludiului": "preludiu",
    "prelunga": "prelung",
    "prelungă": "prelung",
    "prelunge": "prelung",
    "prelungei": "prelung",
    "prelungele": "prelung",
    "prelungelor": "prelung",
    "prelungi": "prelung",
    "prelungii": "prelung",
    "prelungilor": "prelung",
    "prelungul": "prelung",
    "prelungului": "prelung",
    "nemaiprelungind": "prelungi",
    "nemaiprelungindu": "prelungi",
    "neprelungind": "prelungi",
    "neprelungindu": "prelungi",
    "prelungea": "prelungi",
    "prelungeai": "prelungi",
    "prelungeam": "prelungi",
    "prelungească": "prelungi",
    "prelungeați": "prelungi",
    "prelungeau": "prelungi",
    "prelungesc": "prelungi",
    "prelungește": "prelungi",
    "prelungești": "prelungi",
    "prelungii": "prelungi",
    "prelungim": "prelungi",
    "prelungind": "prelungi",
    "prelungindu": "prelungi",
    "prelungiră": "prelungi",
    "prelungirăm": "prelungi",
    "prelungirăți": "prelungi",
    "prelungise": "prelungi",
    "prelungisem": "prelungi",
    "prelungiseră": "prelungi",
    "prelungiserăm": "prelungi",
    "prelungiserăți": "prelungi",
    "prelungiseși": "prelungi",
    "prelungiși": "prelungi",
    "prelungit": "prelungi",
    "prelungiți": "prelungi",
    "prelungirea": "prelungire",
    "prelungiri": "prelungire",
    "prelungirii": "prelungire",
    "prelungirile": "prelungire",
    "prelungirilor": "prelungire",
    "prelungită": "prelungit",
    "prelungite": "prelungit",
    "prelungiți": "prelungit",
    "premarxista": "premarxist",
    "premarxistă": "premarxist",
    "premarxiste": "premarxist",
    "premarxistei": "premarxist",
    "premarxistele": "premarxist",
    "premarxistelor": "premarxist",
    "premarxiști": "premarxist",
    "premarxiștii": "premarxist",
    "premarxiștilor": "premarxist",
    "premarxistul": "premarxist",
    "premarxistului": "premarxist",
    "prematura": "prematur",
    "prematură": "prematur",
    "premature": "prematur",
    "prematurei": "prematur",
    "prematurele": "prematur",
    "prematurelor": "prematur",
    "prematuri": "prematur",
    "prematurii": "prematur",
    "prematurilor": "prematur",
    "prematurul": "prematur",
    "prematurului": "prematur",
    "nemaipremeditând": "premedita",
    "nemaipremeditându": "premedita",
    "nepremeditând": "premedita",
    "nepremeditându": "premedita",
    "premedită": "premedita",
    "premeditai": "premedita",
    "premeditam": "premedita",
    "premedităm": "premedita",
    "premeditând": "premedita",
    "premeditându": "premedita",
    "premeditară": "premedita",
    "premeditarăm": "premedita",
    "premeditarăți": "premedita",
    "premeditase": "premedita",
    "premeditasem": "premedita",
    "premeditaseră": "premedita",
    "premeditaserăm": "premedita",
    "premeditaserăți": "premedita",
    "premeditaseși": "premedita",
    "premeditași": "premedita",
    "premeditat": "premedita",
    "premeditați": "premedita",
    "premeditau": "premedita",
    "premeditează": "premedita",
    "premeditez": "premedita",
    "premediteze": "premedita",
    "premeditezi": "premedita",
    "premeditarea": "premeditare",
    "premeditări": "premeditare",
    "premeditării": "premeditare",
    "premeditările": "premeditare",
    "premeditărilor": "premeditare",
    "premeditată": "premeditat",
    "premeditate": "premeditat",
    "premeditați": "premeditat",
    "premergătoare": "premergător",
    "premergătoarea": "premergător",
    "premergătoarei": "premergător",
    "premergătoarele": "premergător",
    "premergătoarelor": "premergător",
    "premergători": "premergător",
    "premergătorii": "premergător",
    "premergătorilor": "premergător",
    "premergătorul": "premergător",
    "premergătorului": "premergător",
    "nemaipremergând": "premerge",
    "nemaipremergându": "premerge",
    "nepremergând": "premerge",
    "nepremergându": "premerge",
    "premeargă": "premerge",
    "premerg": "premerge",
    "premergând": "premerge",
    "premergându": "premerge",
    "premergea": "premerge",
    "premergeai": "premerge",
    "premergeam": "premerge",
    "premergeați": "premerge",
    "premergeau": "premerge",
    "premergem": "premerge",
    "premergeți": "premerge",
    "premergi": "premerge",
    "premerse": "premerge",
    "premersei": "premerge",
    "premerseră": "premerge",
    "premerserăm": "premerge",
    "premerserăți": "premerge",
    "premersese": "premerge",
    "premersesem": "premerge",
    "premerseseră": "premerge",
    "premerseserăm": "premerge",
    "premerseserăți": "premerge",
    "premerseseși": "premerge",
    "premerseși": "premerge",
    "nemaipremiind": "premia",
    "nemaipremiindu": "premia",
    "nepremiind": "premia",
    "nepremiindu": "premia",
    "premiai": "premia",
    "premiam": "premia",
    "premiară": "premia",
    "premiarăm": "premia",
    "premiarăți": "premia",
    "premiase": "premia",
    "premiasem": "premia",
    "premiaseră": "premia",
    "premiaserăm": "premia",
    "premiaserăți": "premia",
    "premiaseși": "premia",
    "premiași": "premia",
    "premiat": "premia",
    "premiați": "premia",
    "premiau": "premia",
    "premiază": "premia",
    "premie": "premia",
    "premiem": "premia",
    "premiez": "premia",
    "premieze": "premia",
    "premiezi": "premia",
    "premiind": "premia",
    "premiindu": "premia",
    "premiala": "premial",
    "premială": "premial",
    "premiale": "premial",
    "premialei": "premial",
    "premialele": "premial",
    "premialelor": "premial",
    "premiali": "premial",
    "premialii": "premial",
    "premialilor": "premial",
    "premialul": "premial",
    "premialului": "premial",
    "premianți": "premiant",
    "premianții": "premiant",
    "premianților": "premiant",
    "premiantul": "premiant",
    "premiantului": "premiant",
    "premianta": "premiantă",
    "premiante": "premiantă",
    "premiantei": "premiantă",
    "premiantele": "premiantă",
    "premiantelor": "premiantă",
    "premiată": "premiat",
    "premiate": "premiat",
    "premiați": "premiat",
    "premieri": "premier",
    "premierii": "premier",
    "premierilor": "premier",
    "premierul": "premier",
    "premierului": "premier",
    "premiera": "premieră",
    "premiere": "premieră",
    "premierei": "premieră",
    "premierele": "premieră",
    "premierelor": "premieră",
    "premieri": "premieră",
    "premierii": "premieră",
    "premierile": "premieră",
    "premierilor": "premieră",
    "premierea": "premiere",
    "premieri": "premiere",
    "premierii": "premiere",
    "premierile": "premiere",
    "premierilor": "premiere",
    "premilitara": "premilitar",
    "premilitară": "premilitar",
    "premilitare": "premilitar",
    "premilitarei": "premilitar",
    "premilitarele": "premilitar",
    "premilitarelor": "premilitar",
    "premilitari": "premilitar",
    "premilitarii": "premilitar",
    "premilitarilor": "premilitar",
    "premilitarul": "premilitar",
    "premilitarului": "premilitar",
    "premisa": "premisă",
    "premise": "premisă",
    "premisei": "premisă",
    "premisele": "premisă",
    "premiselor": "premisă",
    "premii": "premiu",
    "premiile": "premiu",
    "premiilor": "premiu",
    "premiul": "premiu",
    "premiului": "premiu",
    "premolari": "premolar",
    "premolarii": "premolar",
    "premolarilor": "premolar",
    "premolarul": "premolar",
    "premolarului": "premolar",
    "premoniția": "premoniție",
    "premoniției": "premoniție",
    "premoniții": "premoniție",
    "premonițiile": "premoniție",
    "premonițiilor": "premoniție",
    "premonitoria": "premonitoriu",
    "premonitorie": "premonitoriu",
    "premonitoriei": "premonitoriu",
    "premonitorii": "premonitoriu",
    "premonitoriii": "premonitoriu",
    "premonitoriile": "premonitoriu",
    "premonitoriilor": "premonitoriu",
    "premonitoriul": "premonitoriu",
    "premonitoriului": "premonitoriu",
    "premonopolista": "premonopolist",
    "premonopolistă": "premonopolist",
    "premonopoliste": "premonopolist",
    "premonopolistei": "premonopolist",
    "premonopolistele": "premonopolist",
    "premonopolistelor": "premonopolist",
    "premonopoliști": "premonopolist",
    "premonopoliștii": "premonopolist",
    "premonopoliștilor": "premonopolist",
    "premonopolistul": "premonopolist",
    "premonopolistului": "premonopolist",
    "prenatala": "prenatal",
    "prenatală": "prenatal",
    "prenatale": "prenatal",
    "prenatalei": "prenatal",
    "prenatalele": "prenatal",
    "prenatalelor": "prenatal",
    "prenatali": "prenatal",
    "prenatalii": "prenatal",
    "prenatalilor": "prenatal",
    "prenatalul": "prenatal",
    "prenatalului": "prenatal",
    "prenotarea": "prenotare",
    "prenotări": "prenotare",
    "prenotării": "prenotare",
    "prenotările": "prenotare",
    "prenotărilor": "prenotare",
    "prenumele": "prenume",
    "prenumelor": "prenume",
    "prenumelui": "prenume",
    "nemaipreocupând": "preocupa",
    "nemaipreocupându": "preocupa",
    "nepreocupând": "preocupa",
    "nepreocupându": "preocupa",
    "preocup": "preocupa",
    "preocupă": "preocupa",
    "preocupai": "preocupa",
    "preocupam": "preocupa",
    "preocupăm": "preocupa",
    "preocupând": "preocupa",
    "preocupându": "preocupa",
    "preocupară": "preocupa",
    "preocuparăm": "preocupa",
    "preocuparăți": "preocupa",
    "preocupase": "preocupa",
    "preocupasem": "preocupa",
    "preocupaseră": "preocupa",
    "preocupaserăm": "preocupa",
    "preocupaserăți": "preocupa",
    "preocupaseși": "preocupa",
    "preocupași": "preocupa",
    "preocupat": "preocupa",
    "preocupați": "preocupa",
    "preocupau": "preocupa",
    "preocupe": "preocupa",
    "preocupi": "preocupa",
    "preocuparea": "preocupare",
    "preocupări": "preocupare",
    "preocupării": "preocupare",
    "preocupările": "preocupare",
    "preocupărilor": "preocupare",
    "preocupată": "preocupat",
    "preocupate": "preocupat",
    "preocupați": "preocupat",
    "preolimpica": "preolimpic",
    "preolimpică": "preolimpic",
    "preolimpice": "preolimpic",
    "preolimpicei": "preolimpic",
    "preolimpicele": "preolimpic",
    "preolimpicelor": "preolimpic",
    "preolimpici": "preolimpic",
    "preolimpicii": "preolimpic",
    "preolimpicilor": "preolimpic",
    "preolimpicul": "preolimpic",
    "preolimpicului": "preolimpic",
    "preopinenți": "preopinent",
    "preoți": "preot",
    "preoții": "preot",
    "preoților": "preot",
    "preotul": "preot",
    "preotului": "preot",
    "preoteasa": "preoteasă",
    "preotese": "preoteasă",
    "preotesei": "preoteasă",
    "preotesele": "preoteasă",
    "preoteselor": "preoteasă",
    "preoțeasca": "preoțesc",
    "preoțească": "preoțesc",
    "preoțescul": "preoțesc",
    "preoțescului": "preoțesc",
    "preoțești": "preoțesc",
    "preoțeștii": "preoțesc",
    "preoțeștile": "preoțesc",
    "preoțeștilor": "preoțesc",
    "preoția": "preoție",
    "preoției": "preoție",
    "preoții": "preoție",
    "preoțiile": "preoție",
    "preoțiilor": "preoție",
    "preoțimea": "preoțime",
    "preoțimi": "preoțime",
    "preoțimii": "preoțime",
    "prepalatala": "prepalatal",
    "prepalatală": "prepalatal",
    "prepalatale": "prepalatal",
    "prepalatalei": "prepalatal",
    "prepalatalele": "prepalatal",
    "prepalatalelor": "prepalatal",
    "prepalatali": "prepalatal",
    "prepalatalii": "prepalatal",
    "prepalatalilor": "prepalatal",
    "prepalatalul": "prepalatal",
    "prepalatalului": "prepalatal",
    "nemaipreparând": "prepara",
    "nemaipreparându": "prepara",
    "nepreparând": "prepara",
    "nepreparându": "prepara",
    "prepar": "prepara",
    "prepară": "prepara",
    "preparai": "prepara",
    "preparam": "prepara",
    "preparăm": "prepara",
    "preparând": "prepara",
    "preparându": "prepara",
    "preparară": "prepara",
    "prepararăm": "prepara",
    "prepararăți": "prepara",
    "preparase": "prepara",
    "preparasem": "prepara",
    "preparaseră": "prepara",
    "preparaserăm": "prepara",
    "preparaserăți": "prepara",
    "preparaseși": "prepara",
    "preparași": "prepara",
    "preparat": "prepara",
    "preparați": "prepara",
    "preparau": "prepara",
    "prepare": "prepara",
    "prepari": "prepara",
    "prepararea": "preparare",
    "preparări": "preparare",
    "preparării": "preparare",
    "preparările": "preparare",
    "preparărilor": "preparare",
    "preparată": "preparat",
    "preparate": "preparat",
    "preparatele": "preparat",
    "preparatelor": "preparat",
    "preparați": "preparat",
    "preparatul": "preparat",
    "preparatului": "preparat",
    "preparativa": "preparativă",
    "preparative": "preparativă",
    "preparativei": "preparativă",
    "preparativele": "preparativă",
    "preparativelor": "preparativă",
    "preparatoarea": "preparatoare",
    "preparatoarei": "preparatoare",
    "preparatoarele": "preparatoare",
    "preparatoarelor": "preparatoare",
    "preparatoare": "preparator",
    "preparatoarea": "preparator",
    "preparatoarei": "preparator",
    "preparatoarele": "preparator",
    "preparatoarelor": "preparator",
    "preparatori": "preparator",
    "preparatorii": "preparator",
    "preparatorilor": "preparator",
    "preparatorul": "preparator",
    "preparatorului": "preparator",
    "prepelița": "prepeliță",
    "prepelițe": "prepeliță",
    "prepeliței": "prepeliță",
    "prepelițele": "prepeliță",
    "prepelițelor": "prepeliță",
    "preponderenta": "preponderent",
    "preponderentă": "preponderent",
    "preponderente": "preponderent",
    "preponderentei": "preponderent",
    "preponderentele": "preponderent",
    "preponderentelor": "preponderent",
    "preponderenți": "preponderent",
    "preponderenții": "preponderent",
    "preponderenților": "preponderent",
    "preponderentul": "preponderent",
    "preponderentului": "preponderent",
    "preponderența": "preponderență",
    "preponderențe": "preponderență",
    "preponderenței": "preponderență",
    "preponderențele": "preponderență",
    "preponderențelor": "preponderență",
    "prepotenta": "prepotent",
    "prepotentă": "prepotent",
    "prepotente": "prepotent",
    "prepotentei": "prepotent",
    "prepotentele": "prepotent",
    "prepotentelor": "prepotent",
    "prepotenți": "prepotent",
    "prepotenții": "prepotent",
    "prepotenților": "prepotent",
    "prepotentul": "prepotent",
    "prepotentului": "prepotent",
    "prep.": "prepoziție",
    "prepoziția": "prepoziție",
    "prepoziției": "prepoziție",
    "prepoziții": "prepoziție",
    "prepozițiile": "prepoziție",
    "prepozițiilor": "prepoziție",
    "prepoziționala": "prepozițional",
    "prepozițională": "prepozițional",
    "prepoziționale": "prepozițional",
    "prepoziționalei": "prepozițional",
    "prepoziționalele": "prepozițional",
    "prepoziționalelor": "prepozițional",
    "prepoziționali": "prepozițional",
    "prepoziționalii": "prepozițional",
    "prepoziționalilor": "prepozițional",
    "prepoziționalul": "prepozițional",
    "prepoziționalului": "prepozițional",
    "prepozitiva": "prepozitiv",
    "prepozitivă": "prepozitiv",
    "prepozitive": "prepozitiv",
    "prepozitivei": "prepozitiv",
    "prepozitivele": "prepozitiv",
    "prepozitivelor": "prepozitiv",
    "prepozitivi": "prepozitiv",
    "prepozitivii": "prepozitiv",
    "prepozitivilor": "prepozitiv",
    "prepozitivul": "prepozitiv",
    "prepozitivului": "prepozitiv",
    "prepubertatea": "prepubertate",
    "prepubertăți": "prepubertate",
    "prepubertății": "prepubertate",
    "prepusa": "prepus",
    "prepusă": "prepus",
    "prepuse": "prepus",
    "prepusei": "prepus",
    "prepusele": "prepus",
    "prepuselor": "prepus",
    "prepuși": "prepus",
    "prepușii": "prepus",
    "prepușilor": "prepus",
    "prepusul": "prepus",
    "prepusului": "prepus",
    "prerevoluționara": "prerevoluționar",
    "prerevoluționară": "prerevoluționar",
    "prerevoluționare": "prerevoluționar",
    "prerevoluționarei": "prerevoluționar",
    "prerevoluționarele": "prerevoluționar",
    "prerevoluționarelor": "prerevoluționar",
    "prerevoluționari": "prerevoluționar",
    "prerevoluționarii": "prerevoluționar",
    "prerevoluționarilor": "prerevoluționar",
    "prerevoluționarul": "prerevoluționar",
    "prerevoluționarului": "prerevoluționar",
    "prerogativa": "prerogativă",
    "prerogative": "prerogativă",
    "prerogativei": "prerogativă",
    "prerogativele": "prerogativă",
    "prerogativelor": "prerogativă",
    "preromana": "preroman",
    "preromană": "preroman",
    "preromane": "preroman",
    "preromanei": "preroman",
    "preromanele": "preroman",
    "preromanelor": "preroman",
    "preromani": "preroman",
    "preromanii": "preroman",
    "preromanilor": "preroman",
    "preromanul": "preroman",
    "preromanului": "preroman",
    "preromantica": "preromantic",
    "preromantică": "preromantic",
    "preromantice": "preromantic",
    "preromanticei": "preromantic",
    "preromanticele": "preromantic",
    "preromanticelor": "preromantic",
    "preromantici": "preromantic",
    "preromanticii": "preromantic",
    "preromanticilor": "preromantic",
    "preromanticul": "preromantic",
    "preromanticului": "preromantic",
    "preșul": "preș",
    "preșului": "preș",
    "preșuri": "preș",
    "preșurile": "preș",
    "preșurilor": "preș",
    "nemaipresând": "presa",
    "nemaipresându": "presa",
    "nepresând": "presa",
    "nepresându": "presa",
    "presă": "presa",
    "presai": "presa",
    "presam": "presa",
    "presăm": "presa",
    "presând": "presa",
    "presându": "presa",
    "presară": "presa",
    "presarăm": "presa",
    "presarăți": "presa",
    "presase": "presa",
    "presasem": "presa",
    "presaseră": "presa",
    "presaserăm": "presa",
    "presaserăți": "presa",
    "presaseși": "presa",
    "presași": "presa",
    "presat": "presa",
    "presați": "presa",
    "presau": "presa",
    "presează": "presa",
    "presez": "presa",
    "preseze": "presa",
    "presezi": "presa",
    "presa": "presă",
    "prese": "presă",
    "presei": "presă",
    "presele": "presă",
    "preselor": "presă",
    "presanta": "presant",
    "presantă": "presant",
    "presante": "presant",
    "presantei": "presant",
    "presantele": "presant",
    "presantelor": "presant",
    "presanți": "presant",
    "presanții": "presant",
    "presanților": "presant",
    "presantul": "presant",
    "presantului": "presant",
    "nemaipresărând": "presăra",
    "nemaipresărându": "presăra",
    "nepresărând": "presăra",
    "nepresărându": "presăra",
    "presar": "presăra",
    "presară": "presăra",
    "presără": "presăra",
    "presărai": "presăra",
    "presăram": "presăra",
    "presărăm": "presăra",
    "presărând": "presăra",
    "presărându": "presăra",
    "presărară": "presăra",
    "presărarăm": "presăra",
    "presărarăți": "presăra",
    "presărase": "presăra",
    "presărasem": "presăra",
    "presăraseră": "presăra",
    "presăraserăm": "presăra",
    "presăraserăți": "presăra",
    "presăraseși": "presăra",
    "presărași": "presăra",
    "presărat": "presăra",
    "presărați": "presăra",
    "presărau": "presăra",
    "presare": "presăra",
    "presari": "presăra",
    "presărată": "presărat",
    "presărate": "presărat",
    "presărați": "presărat",
    "presată": "presat",
    "presate": "presat",
    "presați": "presat",
    "nemaipreschimbând": "preschimba",
    "nemaipreschimbându": "preschimba",
    "nepreschimbând": "preschimba",
    "nepreschimbându": "preschimba",
    "preschimb": "preschimba",
    "preschimbă": "preschimba",
    "preschimbai": "preschimba",
    "preschimbam": "preschimba",
    "preschimbăm": "preschimba",
    "preschimbând": "preschimba",
    "preschimbându": "preschimba",
    "preschimbară": "preschimba",
    "preschimbarăm": "preschimba",
    "preschimbarăți": "preschimba",
    "preschimbase": "preschimba",
    "preschimbasem": "preschimba",
    "preschimbaseră": "preschimba",
    "preschimbaserăm": "preschimba",
    "preschimbaserăți": "preschimba",
    "preschimbaseși": "preschimba",
    "preschimbași": "preschimba",
    "preschimbat": "preschimba",
    "preschimbați": "preschimba",
    "preschimbau": "preschimba",
    "preschimbe": "preschimba",
    "preschimbi": "preschimba",
    "preschimbarea": "preschimbare",
    "preschimbări": "preschimbare",
    "preschimbării": "preschimbare",
    "preschimbările": "preschimbare",
    "preschimbărilor": "preschimbare",
    "preschimbată": "preschimbat",
    "preschimbate": "preschimbat",
    "preschimbați": "preschimbat",
    "preșcolara": "preșcolar",
    "preșcolară": "preșcolar",
    "preșcolare": "preșcolar",
    "preșcolarei": "preșcolar",
    "preșcolarele": "preșcolar",
    "preșcolarelor": "preșcolar",
    "preșcolari": "preșcolar",
    "preșcolarii": "preșcolar",
    "preșcolarilor": "preșcolar",
    "preșcolarul": "preșcolar",
    "preșcolarului": "preșcolar",
    "nemaiprescriind": "prescrie",
    "nemaiprescriindu": "prescrie",
    "neprescriind": "prescrie",
    "neprescriindu": "prescrie",
    "prescria": "prescrie",
    "prescriai": "prescrie",
    "prescriam": "prescrie",
    "prescriați": "prescrie",
    "prescriau": "prescrie",
    "prescriem": "prescrie",
    "prescrieți": "prescrie",
    "prescrii": "prescrie",
    "prescriind": "prescrie",
    "prescriindu": "prescrie",
    "prescris": "prescrie",
    "prescrise": "prescrie",
    "prescrisei": "prescrie",
    "prescriseră": "prescrie",
    "prescriserăm": "prescrie",
    "prescriserăți": "prescrie",
    "prescrisese": "prescrie",
    "prescrisesem": "prescrie",
    "prescriseseră": "prescrie",
    "prescriseserăm": "prescrie",
    "prescriseserăți": "prescrie",
    "prescriseseși": "prescrie",
    "prescriseși": "prescrie",
    "prescriu": "prescrie",
    "prescriptibila": "prescriptibil",
    "prescriptibilă": "prescriptibil",
    "prescriptibile": "prescriptibil",
    "prescriptibilei": "prescriptibil",
    "prescriptibilele": "prescriptibil",
    "prescriptibilelor": "prescriptibil",
    "prescriptibili": "prescriptibil",
    "prescriptibilii": "prescriptibil",
    "prescriptibililor": "prescriptibil",
    "prescriptibilul": "prescriptibil",
    "prescriptibilului": "prescriptibil",
    "prescripția": "prescripție",
    "prescripției": "prescripție",
    "prescripții": "prescripție",
    "prescripțiile": "prescripție",
    "prescripțiilor": "prescripție",
    "prescrisă": "prescris",
    "prescrise": "prescris",
    "prescriși": "prescris",
    "prescura": "prescură",
    "prescuri": "prescură",
    "prescurii": "prescură",
    "prescurile": "prescură",
    "prescurilor": "prescură",
    "nemaiprescurtând": "prescurta",
    "nemaiprescurtându": "prescurta",
    "neprescurtând": "prescurta",
    "neprescurtându": "prescurta",
    "prescurtă": "prescurta",
    "prescurtai": "prescurta",
    "prescurtam": "prescurta",
    "prescurtăm": "prescurta",
    "prescurtând": "prescurta",
    "prescurtându": "prescurta",
    "prescurtară": "prescurta",
    "prescurtarăm": "prescurta",
    "prescurtarăți": "prescurta",
    "prescurtase": "prescurta",
    "prescurtasem": "prescurta",
    "prescurtaseră": "prescurta",
    "prescurtaserăm": "prescurta",
    "prescurtaserăți": "prescurta",
    "prescurtaseși": "prescurta",
    "prescurtași": "prescurta",
    "prescurtat": "prescurta",
    "prescurtați": "prescurta",
    "prescurtau": "prescurta",
    "prescurtează": "prescurta",
    "prescurtez": "prescurta",
    "prescurteze": "prescurta",
    "prescurtezi": "prescurta",
    "prescurtarea": "prescurtare",
    "prescurtări": "prescurtare",
    "prescurtării": "prescurtare",
    "prescurtările": "prescurtare",
    "prescurtărilor": "prescurtare",
    "prescurtată": "prescurtat",
    "prescurtate": "prescurtat",
    "prescurtați": "prescurtat",
    "președinta": "președintă",
    "președinte": "președintă",
    "președintei": "președintă",
    "președintele": "președintă",
    "președintelor": "președintă",
    "președintele": "președinte",
    "președintelui": "președinte",
    "președinți": "președinte",
    "președinții": "președinte",
    "președinților": "președinte",
    "președințiala": "președințial",
    "președințială": "președințial",
    "președințiale": "președințial",
    "președințialei": "președințial",
    "președințialele": "președințial",
    "președințialelor": "președințial",
    "președințiali": "președințial",
    "președințialii": "președințial",
    "președințialilor": "președințial",
    "președințialul": "președințial",
    "președințialului": "președințial",
    "președinția": "președinție",
    "președinției": "președinție",
    "președinții": "președinție",
    "președințiile": "președinție",
    "președințiilor": "președinție",
    "presentimente": "presentiment",
    "presentimentele": "presentiment",
    "presentimentelor": "presentiment",
    "presentimentul": "presentiment",
    "presentimentului": "presentiment",
    "nemaipresimțind": "presimți",
    "nemaipresimțindu": "presimți",
    "nepresimțind": "presimți",
    "nepresimțindu": "presimți",
    "presimt": "presimți",
    "presimtă": "presimți",
    "presimte": "presimți",
    "presimțea": "presimți",
    "presimțeai": "presimți",
    "presimțeam": "presimți",
    "presimțeați": "presimți",
    "presimțeau": "presimți",
    "presimții": "presimți",
    "presimțim": "presimți",
    "presimțind": "presimți",
    "presimțindu": "presimți",
    "presimțiră": "presimți",
    "presimțirăm": "presimți",
    "presimțirăți": "presimți",
    "presimțise": "presimți",
    "presimțisem": "presimți",
    "presimțiseră": "presimți",
    "presimțiserăm": "presimți",
    "presimțiserăți": "presimți",
    "presimțiseși": "presimți",
    "presimțiși": "presimți",
    "presimțit": "presimți",
    "presimțiți": "presimți",
    "presimțirea": "presimțire",
    "presimțiri": "presimțire",
    "presimțirii": "presimțire",
    "presimțirile": "presimțire",
    "presimțirilor": "presimțire",
    "presimțită": "presimțit",
    "presimțite": "presimțit",
    "presimțiți": "presimțit",
    "presiunea": "presiune",
    "presiuni": "presiune",
    "presiunii": "presiune",
    "presiunile": "presiune",
    "presiunilor": "presiune",
    "presocialista": "presocialist",
    "presocialistă": "presocialist",
    "presocialiste": "presocialist",
    "presocialistei": "presocialist",
    "presocialistele": "presocialist",
    "presocialistelor": "presocialist",
    "presocialiști": "presocialist",
    "presocialiștii": "presocialist",
    "presocialiștilor": "presocialist",
    "presocialistul": "presocialist",
    "presocialistului": "presocialist",
    "presocratica": "presocratic",
    "presocratică": "presocratic",
    "presocratice": "presocratic",
    "presocraticei": "presocratic",
    "presocraticele": "presocratic",
    "presocraticelor": "presocratic",
    "presocratici": "presocratic",
    "presocraticii": "presocratic",
    "presocraticilor": "presocratic",
    "presocraticul": "presocratic",
    "presocraticului": "presocratic",
    "prespitalicească": "prespitalicesc",
    "prespitalicești": "prespitalicesc",
    "nemaiprestând": "presta",
    "nemaiprestându": "presta",
    "neprestând": "presta",
    "neprestându": "presta",
    "prestă": "presta",
    "prestai": "presta",
    "prestam": "presta",
    "prestăm": "presta",
    "prestând": "presta",
    "prestându": "presta",
    "prestară": "presta",
    "prestarăm": "presta",
    "prestarăți": "presta",
    "prestase": "presta",
    "prestasem": "presta",
    "prestaseră": "presta",
    "prestaserăm": "presta",
    "prestaserăți": "presta",
    "prestaseși": "presta",
    "prestași": "presta",
    "prestat": "presta",
    "prestați": "presta",
    "prestau": "presta",
    "prestează": "presta",
    "prestez": "presta",
    "presteze": "presta",
    "prestezi": "presta",
    "prestanța": "prestanță",
    "prestanțe": "prestanță",
    "prestanței": "prestanță",
    "prestanțele": "prestanță",
    "prestanțelor": "prestanță",
    "prestată": "prestat",
    "prestate": "prestat",
    "prestați": "prestat",
    "prestatala": "prestatal",
    "prestatală": "prestatal",
    "prestatale": "prestatal",
    "prestatalei": "prestatal",
    "prestatalele": "prestatal",
    "prestatalelor": "prestatal",
    "prestatali": "prestatal",
    "prestatalii": "prestatal",
    "prestatalilor": "prestatal",
    "prestatalul": "prestatal",
    "prestatalului": "prestatal",
    "prestația": "prestație",
    "prestației": "prestație",
    "prestații": "prestație",
    "prestațiile": "prestație",
    "prestațiilor": "prestație",
    "prestidigitația": "prestidigitație",
    "prestidigitației": "prestidigitație",
    "prestidigitații": "prestidigitație",
    "prestidigitatori": "prestidigitator",
    "prestidigitatorii": "prestidigitator",
    "prestidigitatorilor": "prestidigitator",
    "prestidigitatorul": "prestidigitator",
    "prestidigitatorului": "prestidigitator",
    "prestigioasa": "prestigios",
    "prestigioasă": "prestigios",
    "prestigioase": "prestigios",
    "prestigioasei": "prestigios",
    "prestigioasele": "prestigios",
    "prestigioaselor": "prestigios",
    "prestigioși": "prestigios",
    "prestigioșii": "prestigios",
    "prestigioșilor": "prestigios",
    "prestigiosul": "prestigios",
    "prestigiosului": "prestigios",
    "prestigii": "prestigiu",
    "prestigiile": "prestigiu",
    "prestigiilor": "prestigiu",
    "prestigiul": "prestigiu",
    "prestigiului": "prestigiu",
    "nemaipresupunând": "presupune",
    "nemaipresupunându": "presupune",
    "nepresupunând": "presupune",
    "nepresupunându": "presupune",
    "presupui": "presupune",
    "presupun": "presupune",
    "presupună": "presupune",
    "presupunând": "presupune",
    "presupunându": "presupune",
    "presupunea": "presupune",
    "presupuneai": "presupune",
    "presupuneam": "presupune",
    "presupuneați": "presupune",
    "presupuneau": "presupune",
    "presupunem": "presupune",
    "presupuneți": "presupune",
    "presupus": "presupune",
    "presupuse": "presupune",
    "presupusei": "presupune",
    "presupuseră": "presupune",
    "presupuserăm": "presupune",
    "presupuserăți": "presupune",
    "presupusese": "presupune",
    "presupusesem": "presupune",
    "presupuseseră": "presupune",
    "presupuseserăm": "presupune",
    "presupuseserăți": "presupune",
    "presupuseseși": "presupune",
    "presupuseși": "presupune",
    "presupunerea": "presupunere",
    "presupuneri": "presupunere",
    "presupunerii": "presupunere",
    "presupunerile": "presupunere",
    "presupunerilor": "presupunere",
    "presupusa": "presupus",
    "presupusă": "presupus",
    "presupuse": "presupus",
    "presupusei": "presupus",
    "presupusele": "presupus",
    "presupuselor": "presupus",
    "presupuși": "presupus",
    "presupușii": "presupus",
    "presupușilor": "presupus",
    "presupusul": "presupus",
    "presupusului": "presupus",
    "nemaipresurizând": "presuriza",
    "nemaipresurizându": "presuriza",
    "nepresurizând": "presuriza",
    "nepresurizându": "presuriza",
    "presuriză": "presuriza",
    "presurizai": "presuriza",
    "presurizam": "presuriza",
    "presurizăm": "presuriza",
    "presurizând": "presuriza",
    "presurizându": "presuriza",
    "presurizară": "presuriza",
    "presurizarăm": "presuriza",
    "presurizarăți": "presuriza",
    "presurizase": "presuriza",
    "presurizasem": "presuriza",
    "presurizaseră": "presuriza",
    "presurizaserăm": "presuriza",
    "presurizaserăți": "presuriza",
    "presurizaseși": "presuriza",
    "presurizași": "presuriza",
    "presurizat": "presuriza",
    "presurizați": "presuriza",
    "presurizau": "presuriza",
    "presurizează": "presuriza",
    "presurizez": "presuriza",
    "presurizeze": "presuriza",
    "presurizezi": "presuriza",
    "presurizată": "presurizat",
    "presurizate": "presurizat",
    "presurizați": "presurizat",
    "prețu": "preț",
    "prețul": "preț",
    "prețului": "preț",
    "prețuri": "preț",
    "prețurile": "preț",
    "prețurilor": "preț",
    "nemaipretând": "preta",
    "nemaipretându": "preta",
    "nepretând": "preta",
    "nepretându": "preta",
    "pretă": "preta",
    "pretai": "preta",
    "pretam": "preta",
    "pretăm": "preta",
    "pretând": "preta",
    "pretându": "preta",
    "pretară": "preta",
    "pretarăm": "preta",
    "pretarăți": "preta",
    "pretase": "preta",
    "pretasem": "preta",
    "pretaseră": "preta",
    "pretaserăm": "preta",
    "pretaserăți": "preta",
    "pretaseși": "preta",
    "pretași": "preta",
    "pretat": "preta",
    "pretați": "preta",
    "pretau": "preta",
    "pretează": "preta",
    "pretez": "preta",
    "preteze": "preta",
    "pretezi": "preta",
    "pretată": "pretat",
    "pretate": "pretat",
    "pretați": "pretat",
    "pretendenți": "pretendent",
    "pretendenții": "pretendent",
    "pretendenților": "pretendent",
    "pretendentul": "pretendent",
    "pretendentului": "pretendent",
    "pretendenta": "pretendentă",
    "pretendente": "pretendentă",
    "pretendentei": "pretendentă",
    "pretendentele": "pretendentă",
    "pretendentelor": "pretendentă",
    "pretensionata": "pretensionat",
    "pretensionată": "pretensionat",
    "pretensionate": "pretensionat",
    "pretensionatei": "pretensionat",
    "pretensionatele": "pretensionat",
    "pretensionatelor": "pretensionat",
    "pretensionați": "pretensionat",
    "pretensionații": "pretensionat",
    "pretensionaților": "pretensionat",
    "pretensionatul": "pretensionat",
    "pretensionatului": "pretensionat",
    "pretenția": "pretenție",
    "pretenției": "pretenție",
    "pretenții": "pretenție",
    "pretențiile": "pretenție",
    "pretențiilor": "pretenție",
    "pretențioasa": "pretențios",
    "pretențioasă": "pretențios",
    "pretențioase": "pretențios",
    "pretențioasei": "pretențios",
    "pretențioasele": "pretențios",
    "pretențioaselor": "pretențios",
    "pretențioși": "pretențios",
    "pretențioșii": "pretențios",
    "pretențioșilor": "pretențios",
    "pretențiosul": "pretențios",
    "pretențiosului": "pretențios",
    "preterite": "preterit",
    "preteritele": "preterit",
    "preteritelor": "preterit",
    "preteritul": "preterit",
    "preteritului": "preterit",
    "pretexte": "pretext",
    "pretextele": "pretext",
    "pretextelor": "pretext",
    "pretextul": "pretext",
    "pretextului": "pretext",
    "nemaipretextând": "pretexta",
    "nemaipretextându": "pretexta",
    "nepretextând": "pretexta",
    "nepretextându": "pretexta",
    "pretextă": "pretexta",
    "pretextai": "pretexta",
    "pretextam": "pretexta",
    "pretextăm": "pretexta",
    "pretextând": "pretexta",
    "pretextându": "pretexta",
    "pretextară": "pretexta",
    "pretextarăm": "pretexta",
    "pretextarăți": "pretexta",
    "pretextase": "pretexta",
    "pretextasem": "pretexta",
    "pretextaseră": "pretexta",
    "pretextaserăm": "pretexta",
    "pretextaserăți": "pretexta",
    "pretextaseși": "pretexta",
    "pretextași": "pretexta",
    "pretextat": "pretexta",
    "pretextați": "pretexta",
    "pretextau": "pretexta",
    "pretextează": "pretexta",
    "pretextez": "pretexta",
    "pretexteze": "pretexta",
    "pretextezi": "pretexta",
    "pretextată": "pretextat",
    "pretextate": "pretextat",
    "pretextați": "pretextat",
    "pretimpuria": "pretimpuriu",
    "pretimpurie": "pretimpuriu",
    "pretimpuriei": "pretimpuriu",
    "pretimpurii": "pretimpuriu",
    "pretimpuriii": "pretimpuriu",
    "pretimpuriile": "pretimpuriu",
    "pretimpuriilor": "pretimpuriu",
    "pretimpuriul": "pretimpuriu",
    "pretimpuriului": "pretimpuriu",
    "pretini": "pretin",
    "nemaipretinzând": "pretinde",
    "nemaipretinzându": "pretinde",
    "nepretinzând": "pretinde",
    "nepretinzându": "pretinde",
    "pretind": "pretinde",
    "pretindă": "pretinde",
    "pretindea": "pretinde",
    "pretindeai": "pretinde",
    "pretindeam": "pretinde",
    "pretindeați": "pretinde",
    "pretindeau": "pretinde",
    "pretindem": "pretinde",
    "pretindeți": "pretinde",
    "pretins": "pretinde",
    "pretinzând": "pretinde",
    "pretinzându": "pretinde",
    "pretinzi": "pretinde",
    "pretinsa": "pretins",
    "pretinsă": "pretins",
    "pretinse": "pretins",
    "pretinsei": "pretins",
    "pretinsele": "pretins",
    "pretinselor": "pretins",
    "pretinși": "pretins",
    "pretinșii": "pretins",
    "pretinșilor": "pretins",
    "pretinsul": "pretins",
    "pretinsului": "pretins",
    "prețioasa": "prețios",
    "prețioasă": "prețios",
    "prețioase": "prețios",
    "prețioasei": "prețios",
    "prețioasele": "prețios",
    "prețioaselor": "prețios",
    "prețioși": "prețios",
    "prețioșii": "prețios",
    "prețioșilor": "prețios",
    "prețiosul": "prețios",
    "prețiosului": "prețios",
    "pretori": "pretor",
    "pretorii": "pretor",
    "pretorilor": "pretor",
    "pretorul": "pretor",
    "pretorului": "pretor",
    "pretoriana": "pretorian",
    "pretoriană": "pretorian",
    "pretorianul": "pretorian",
    "pretorianului": "pretorian",
    "pretoriene": "pretorian",
    "pretorienei": "pretorian",
    "pretorienele": "pretorian",
    "pretorienelor": "pretorian",
    "pretorieni": "pretorian",
    "pretorienii": "pretorian",
    "pretorienilor": "pretorian",
    "pretorii": "pretoriu",
    "pretoriile": "pretoriu",
    "pretoriilor": "pretoriu",
    "pretoriul": "pretoriu",
    "pretoriului": "pretoriu",
    "nemaiprețuind": "prețui",
    "nemaiprețuindu": "prețui",
    "neprețuind": "prețui",
    "neprețuindu": "prețui",
    "prețuia": "prețui",
    "prețuiai": "prețui",
    "prețuiam": "prețui",
    "prețuiască": "prețui",
    "prețuiați": "prețui",
    "prețuiau": "prețui",
    "prețuiesc": "prețui",
    "prețuiește": "prețui",
    "prețuiești": "prețui",
    "prețuii": "prețui",
    "prețuim": "prețui",
    "prețuind": "prețui",
    "prețuindu": "prețui",
    "prețuiră": "prețui",
    "prețuirăm": "prețui",
    "prețuirăți": "prețui",
    "prețuise": "prețui",
    "prețuisem": "prețui",
    "prețuiseră": "prețui",
    "prețuiserăm": "prețui",
    "prețuiserăți": "prețui",
    "prețuiseși": "prețui",
    "prețuiși": "prețui",
    "prețuit": "prețui",
    "prețuiți": "prețui",
    "prețuirea": "prețuire",
    "prețuiri": "prețuire",
    "prețuirii": "prețuire",
    "prețuirile": "prețuire",
    "prețuirilor": "prețuire",
    "prețuită": "prețuit",
    "prețuite": "prețuit",
    "prețuiți": "prețuit",
    "prețuitori": "prețuitor",
    "prețuitorii": "prețuitor",
    "prețuitorilor": "prețuitor",
    "prețuitorul": "prețuitor",
    "prețuitorului": "prețuitor",
    "preumblă": "preumbla",
    "preumblai": "preumbla",
    "preumblam": "preumbla",
    "preumblăm": "preumbla",
    "preumblând": "preumbla",
    "preumblară": "preumbla",
    "preumblarăm": "preumbla",
    "preumblarăți": "preumbla",
    "preumblase": "preumbla",
    "preumblasem": "preumbla",
    "preumblaseră": "preumbla",
    "preumblaserăm": "preumbla",
    "preumblaserăți": "preumbla",
    "preumblaseși": "preumbla",
    "preumblași": "preumbla",
    "preumblat": "preumbla",
    "preumblați": "preumbla",
    "preumblau": "preumbla",
    "preumble": "preumbla",
    "preumbli": "preumbla",
    "preumblu": "preumbla",
    "preumblarea": "preumblare",
    "preumblări": "preumblare",
    "preumblării": "preumblare",
    "preumblările": "preumblare",
    "preumblărilor": "preumblare",
    "preumblată": "preumblat",
    "preumblate": "preumblat",
    "preumblați": "preumblat",
    "preuniversitara": "preuniversitar",
    "preuniversitară": "preuniversitar",
    "preuniversitare": "preuniversitar",
    "preuniversitarei": "preuniversitar",
    "preuniversitarele": "preuniversitar",
    "preuniversitarelor": "preuniversitar",
    "preuniversitari": "preuniversitar",
    "preuniversitarii": "preuniversitar",
    "preuniversitarilor": "preuniversitar",
    "preuniversitarul": "preuniversitar",
    "preuniversitarului": "preuniversitar",
    "preuzinarea": "preuzinare",
    "preuzinate": "preuzinat",
    "nemaiprevalând": "prevala",
    "nemaiprevalându": "prevala",
    "neprevalând": "prevala",
    "neprevalându": "prevala",
    "prevală": "prevala",
    "prevalai": "prevala",
    "prevalam": "prevala",
    "prevalăm": "prevala",
    "prevalând": "prevala",
    "prevalându": "prevala",
    "prevalară": "prevala",
    "prevalarăm": "prevala",
    "prevalarăți": "prevala",
    "prevalase": "prevala",
    "prevalasem": "prevala",
    "prevalaseră": "prevala",
    "prevalaserăm": "prevala",
    "prevalaserăți": "prevala",
    "prevalaseși": "prevala",
    "prevalași": "prevala",
    "prevalat": "prevala",
    "prevalați": "prevala",
    "prevalau": "prevala",
    "prevalează": "prevala",
    "prevalez": "prevala",
    "prevaleze": "prevala",
    "prevalezi": "prevala",
    "prevalarea": "prevalare",
    "prevalări": "prevalare",
    "prevalării": "prevalare",
    "prevalările": "prevalare",
    "prevalărilor": "prevalare",
    "prevalată": "prevalat",
    "prevalate": "prevalat",
    "prevalați": "prevalat",
    "prevalenta": "prevalent",
    "prevalentă": "prevalent",
    "prevalente": "prevalent",
    "prevalentei": "prevalent",
    "prevalentele": "prevalent",
    "prevalentelor": "prevalent",
    "prevalenți": "prevalent",
    "prevalenții": "prevalent",
    "prevalenților": "prevalent",
    "prevalentul": "prevalent",
    "prevalentului": "prevalent",
    "prevăzătoarea": "prevăzătoare",
    "prevăzătoarei": "prevăzătoare",
    "prevăzătoarele": "prevăzătoare",
    "prevăzătoarelor": "prevăzătoare",
    "prevăzătoare": "prevăzător",
    "prevăzătoarea": "prevăzător",
    "prevăzătoarei": "prevăzător",
    "prevăzătoarele": "prevăzător",
    "prevăzătoarelor": "prevăzător",
    "prevăzători": "prevăzător",
    "prevăzătorii": "prevăzător",
    "prevăzătorilor": "prevăzător",
    "prevăzătorul": "prevăzător",
    "prevăzătorului": "prevăzător",
    "prevăzută": "prevăzut",
    "prevăzute": "prevăzut",
    "prevăzuți": "prevăzut",
    "nemaiprevăzând": "prevedea",
    "nemaiprevăzându": "prevedea",
    "neprevăzând": "prevedea",
    "neprevăzându": "prevedea",
    "prevăd": "prevedea",
    "prevadă": "prevedea",
    "prevăzând": "prevedea",
    "prevăzându": "prevedea",
    "prevăzu": "prevedea",
    "prevăzui": "prevedea",
    "prevăzură": "prevedea",
    "prevăzurăm": "prevedea",
    "prevăzurăți": "prevedea",
    "prevăzuse": "prevedea",
    "prevăzusem": "prevedea",
    "prevăzuseră": "prevedea",
    "prevăzuserăm": "prevedea",
    "prevăzuserăți": "prevedea",
    "prevăzuseși": "prevedea",
    "prevăzuși": "prevedea",
    "prevăzut": "prevedea",
    "prevede": "prevedea",
    "prevedeai": "prevedea",
    "prevedeam": "prevedea",
    "prevedeați": "prevedea",
    "prevedeau": "prevedea",
    "prevedem": "prevedea",
    "prevedeți": "prevedea",
    "prevezi": "prevedea",
    "prevederea": "prevedere",
    "prevederi": "prevedere",
    "prevederii": "prevedere",
    "prevederile": "prevedere",
    "prevederilor": "prevedere",
    "nemaiprevenind": "preveni",
    "nemaiprevenindu": "preveni",
    "neprevenind": "preveni",
    "neprevenindu": "preveni",
    "prevenea": "preveni",
    "preveneai": "preveni",
    "preveneam": "preveni",
    "preveneați": "preveni",
    "preveneau": "preveni",
    "prevenii": "preveni",
    "prevenim": "preveni",
    "prevenind": "preveni",
    "prevenindu": "preveni",
    "preveniră": "preveni",
    "prevenirăm": "preveni",
    "prevenirăți": "preveni",
    "prevenise": "preveni",
    "prevenisem": "preveni",
    "preveniseră": "preveni",
    "preveniserăm": "preveni",
    "preveniserăți": "preveni",
    "preveniseși": "preveni",
    "preveniși": "preveni",
    "prevenit": "preveni",
    "preveniți": "preveni",
    "previi": "preveni",
    "previn": "preveni",
    "prevină": "preveni",
    "previne": "preveni",
    "previno": "preveni",
    "prevenirea": "prevenire",
    "preveniri": "prevenire",
    "prevenirii": "prevenire",
    "prevenirile": "prevenire",
    "prevenirilor": "prevenire",
    "prevenită": "prevenit",
    "prevenite": "prevenit",
    "preveniți": "prevenit",
    "prevenitoare": "prevenitor",
    "prevenitoarea": "prevenitor",
    "prevenitoarei": "prevenitor",
    "prevenitoarele": "prevenitor",
    "prevenitoarelor": "prevenitor",
    "prevenitori": "prevenitor",
    "prevenitorii": "prevenitor",
    "prevenitorilor": "prevenitor",
    "prevenitorul": "prevenitor",
    "prevenitorului": "prevenitor",
    "preventiva": "preventiv",
    "preventivă": "preventiv",
    "preventive": "preventiv",
    "preventivei": "preventiv",
    "preventivele": "preventiv",
    "preventivelor": "preventiv",
    "preventivi": "preventiv",
    "preventivii": "preventiv",
    "preventivilor": "preventiv",
    "preventivul": "preventiv",
    "preventivului": "preventiv",
    "nemaiprevestind": "prevesti",
    "nemaiprevestindu": "prevesti",
    "neprevestind": "prevesti",
    "neprevestindu": "prevesti",
    "prevestea": "prevesti",
    "prevesteai": "prevesti",
    "prevesteam": "prevesti",
    "prevestească": "prevesti",
    "prevesteați": "prevesti",
    "prevesteau": "prevesti",
    "prevestesc": "prevesti",
    "prevestește": "prevesti",
    "prevestești": "prevesti",
    "prevestii": "prevesti",
    "prevestim": "prevesti",
    "prevestind": "prevesti",
    "prevestindu": "prevesti",
    "prevestiră": "prevesti",
    "prevestirăm": "prevesti",
    "prevestirăți": "prevesti",
    "prevestise": "prevesti",
    "prevestisem": "prevesti",
    "prevestiseră": "prevesti",
    "prevestiserăm": "prevesti",
    "prevestiserăți": "prevesti",
    "prevestiseși": "prevesti",
    "prevestiși": "prevesti",
    "prevestit": "prevesti",
    "prevestiți": "prevesti",
    "prevestirea": "prevestire",
    "prevestiri": "prevestire",
    "prevestirii": "prevestire",
    "prevestirile": "prevestire",
    "prevestirilor": "prevestire",
    "prevestită": "prevestit",
    "prevestite": "prevestit",
    "prevestiți": "prevestit",
    "prevestitoare": "prevestitor",
    "prevestitoarea": "prevestitor",
    "prevestitoarei": "prevestitor",
    "prevestitoarele": "prevestitor",
    "prevestitoarelor": "prevestitor",
    "prevestitori": "prevestitor",
    "prevestitorii": "prevestitor",
    "prevestitorilor": "prevestitor",
    "prevestitorul": "prevestitor",
    "prevestitorului": "prevestitor",
    "previzibila": "previzibil",
    "previzibilă": "previzibil",
    "previzibile": "previzibil",
    "previzibilei": "previzibil",
    "previzibilele": "previzibil",
    "previzibilelor": "previzibil",
    "previzibili": "previzibil",
    "previzibilii": "previzibil",
    "previzibililor": "previzibil",
    "previzibilul": "previzibil",
    "previzibilului": "previzibil",
    "previziunea": "previziune",
    "previziuni": "previziune",
    "previziunii": "previziune",
    "previziunile": "previziune",
    "previziunilor": "previziune",
    "prezbiteriana": "prezbiterian",
    "prezbiteriană": "prezbiterian",
    "prezbiterianul": "prezbiterian",
    "prezbiterianului": "prezbiterian",
    "prezbiteriene": "prezbiterian",
    "prezbiterienei": "prezbiterian",
    "prezbiterienele": "prezbiterian",
    "prezbiterienelor": "prezbiterian",
    "prezbiterieni": "prezbiterian",
    "prezbiterienii": "prezbiterian",
    "prezbiterienilor": "prezbiterian",
    "prezbiterii": "prezbiteriu",
    "prezbiteriile": "prezbiteriu",
    "prezbiteriilor": "prezbiteriu",
    "prezbiteriul": "prezbiteriu",
    "prezbiteriului": "prezbiteriu",
    "prezbitismul": "prezbitism",
    "prezbitismului": "prezbitism",
    "prez.": "prezent",
    "prezenta": "prezent",
    "prezentă": "prezent",
    "prezente": "prezent",
    "prezentei": "prezent",
    "prezentele": "prezent",
    "prezentelor": "prezent",
    "prezenți": "prezent",
    "prezenții": "prezent",
    "prezenților": "prezent",
    "prezentul": "prezent",
    "prezentului": "prezent",
    "prezenturi": "prezent",
    "prezenturile": "prezent",
    "prezenturilor": "prezent",
    "nemaiprezentând": "prezenta",
    "nemaiprezentându": "prezenta",
    "neprezentând": "prezenta",
    "neprezentându": "prezenta",
    "prezentă": "prezenta",
    "prezentai": "prezenta",
    "prezentam": "prezenta",
    "prezentăm": "prezenta",
    "prezentând": "prezenta",
    "prezentându": "prezenta",
    "prezentară": "prezenta",
    "prezentarăm": "prezenta",
    "prezentarăți": "prezenta",
    "prezentase": "prezenta",
    "prezentasem": "prezenta",
    "prezentaseră": "prezenta",
    "prezentaserăm": "prezenta",
    "prezentaserăți": "prezenta",
    "prezentaseși": "prezenta",
    "prezentași": "prezenta",
    "prezentat": "prezenta",
    "prezentați": "prezenta",
    "prezentau": "prezenta",
    "prezint": "prezenta",
    "prezintă": "prezenta",
    "prezinte": "prezenta",
    "prezinți": "prezenta",
    "prezența": "prezență",
    "prezențe": "prezență",
    "prezenței": "prezență",
    "prezențele": "prezență",
    "prezențelor": "prezență",
    "prezentabila": "prezentabil",
    "prezentabilă": "prezentabil",
    "prezentabile": "prezentabil",
    "prezentabilei": "prezentabil",
    "prezentabilele": "prezentabil",
    "prezentabilelor": "prezentabil",
    "prezentabili": "prezentabil",
    "prezentabilii": "prezentabil",
    "prezentabililor": "prezentabil",
    "prezentabilul": "prezentabil",
    "prezentabilului": "prezentabil",
    "prezentarea": "prezentare",
    "prezentări": "prezentare",
    "prezentării": "prezentare",
    "prezentările": "prezentare",
    "prezentărilor": "prezentare",
    "prezentată": "prezentat",
    "prezentate": "prezentat",
    "prezentați": "prezentat",
    "prezentatoarea": "prezentatoare",
    "prezentatoarei": "prezentatoare",
    "prezentatoarele": "prezentatoare",
    "prezentatoarelor": "prezentatoare",
    "prezentatori": "prezentator",
    "prezentatorii": "prezentator",
    "prezentatorilor": "prezentator",
    "prezentatorul": "prezentator",
    "prezentatorului": "prezentator",
    "nemaiprezervând": "prezerva",
    "nemaiprezervându": "prezerva",
    "neprezervând": "prezerva",
    "neprezervându": "prezerva",
    "prezerv": "prezerva",
    "prezervă": "prezerva",
    "prezervai": "prezerva",
    "prezervam": "prezerva",
    "prezervăm": "prezerva",
    "prezervând": "prezerva",
    "prezervându": "prezerva",
    "prezervară": "prezerva",
    "prezervarăm": "prezerva",
    "prezervarăți": "prezerva",
    "prezervase": "prezerva",
    "prezervasem": "prezerva",
    "prezervaseră": "prezerva",
    "prezervaserăm": "prezerva",
    "prezervaserăți": "prezerva",
    "prezervaseși": "prezerva",
    "prezervași": "prezerva",
    "prezervat": "prezerva",
    "prezervați": "prezerva",
    "prezervau": "prezerva",
    "prezerve": "prezerva",
    "prezervi": "prezerva",
    "prezervarea": "prezervare",
    "prezervări": "prezervare",
    "prezervării": "prezervare",
    "prezervările": "prezervare",
    "prezervărilor": "prezervare",
    "prezervată": "prezervat",
    "prezervate": "prezervat",
    "prezervați": "prezervat",
    "prezervative": "prezervativ",
    "prezervativele": "prezervativ",
    "prezervativelor": "prezervativ",
    "prezervativul": "prezervativ",
    "prezervativului": "prezervativ",
    "prezicători": "prezicător",
    "prezicătorii": "prezicător",
    "prezicătorilor": "prezicător",
    "prezicătorul": "prezicător",
    "prezicătorului": "prezicător",
    "nemaiprezicând": "prezice",
    "nemaiprezicându": "prezice",
    "neprezicând": "prezice",
    "neprezicându": "prezice",
    "prezi": "prezice",
    "prezic": "prezice",
    "prezică": "prezice",
    "prezicând": "prezice",
    "prezicându": "prezice",
    "prezicea": "prezice",
    "preziceai": "prezice",
    "preziceam": "prezice",
    "preziceați": "prezice",
    "preziceau": "prezice",
    "prezicem": "prezice",
    "preziceți": "prezice",
    "prezici": "prezice",
    "prezis": "prezice",
    "prezise": "prezice",
    "prezisei": "prezice",
    "preziseră": "prezice",
    "preziserăm": "prezice",
    "preziserăți": "prezice",
    "prezisese": "prezice",
    "prezisesem": "prezice",
    "preziseseră": "prezice",
    "preziseserăm": "prezice",
    "preziseserăți": "prezice",
    "preziseseși": "prezice",
    "preziseși": "prezice",
    "nemaiprezidând": "prezida",
    "nemaiprezidându": "prezida",
    "neprezidând": "prezida",
    "neprezidându": "prezida",
    "prezidă": "prezida",
    "prezidai": "prezida",
    "prezidam": "prezida",
    "prezidăm": "prezida",
    "prezidând": "prezida",
    "prezidându": "prezida",
    "prezidară": "prezida",
    "prezidarăm": "prezida",
    "prezidarăți": "prezida",
    "prezidase": "prezida",
    "prezidasem": "prezida",
    "prezidaseră": "prezida",
    "prezidaserăm": "prezida",
    "prezidaserăți": "prezida",
    "prezidaseși": "prezida",
    "prezidași": "prezida",
    "prezidat": "prezida",
    "prezidați": "prezida",
    "prezidau": "prezida",
    "prezidează": "prezida",
    "prezidez": "prezida",
    "prezideze": "prezida",
    "prezidezi": "prezida",
    "prezidată": "prezidat",
    "prezidate": "prezidat",
    "prezidați": "prezidat",
    "prezidenți": "prezident",
    "prezidenții": "prezident",
    "prezidenților": "prezident",
    "prezidentul": "prezident",
    "prezidentului": "prezident",
    "prezidențiala": "prezidențial",
    "prezidențială": "prezidențial",
    "prezidențiale": "prezidențial",
    "prezidențialei": "prezidențial",
    "prezidențialele": "prezidențial",
    "prezidențialelor": "prezidențial",
    "prezidențiali": "prezidențial",
    "prezidențialii": "prezidențial",
    "prezidențialilor": "prezidențial",
    "prezidențialul": "prezidențial",
    "prezidențialului": "prezidențial",
    "prezidiala": "prezidial",
    "prezidială": "prezidial",
    "prezidiale": "prezidial",
    "prezidialei": "prezidial",
    "prezidialele": "prezidial",
    "prezidialelor": "prezidial",
    "prezidiali": "prezidial",
    "prezidialii": "prezidial",
    "prezidialilor": "prezidial",
    "prezidialul": "prezidial",
    "prezidialului": "prezidial",
    "prezidii": "prezidiu",
    "prezidiile": "prezidiu",
    "prezidiilor": "prezidiu",
    "prezidiul": "prezidiu",
    "prezidiului": "prezidiu",
    "prezisă": "prezis",
    "prezise": "prezis",
    "preziși": "prezis",
    "prezile": "preziuă",
    "prezilei": "preziuă",
    "prezilele": "preziuă",
    "prezilelor": "preziuă",
    "preziua": "preziuă",
    "prezumția": "prezumție",
    "prezumției": "prezumție",
    "prezumții": "prezumție",
    "prezumțiile": "prezumție",
    "prezumțiilor": "prezumție",
    "prezumțioasa": "prezumțios",
    "prezumțioasă": "prezumțios",
    "prezumțioase": "prezumțios",
    "prezumțioasei": "prezumțios",
    "prezumțioasele": "prezumțios",
    "prezumțioaselor": "prezumțios",
    "prezumțioși": "prezumțios",
    "prezumțioșii": "prezumțios",
    "prezumțioșilor": "prezumțios",
    "prezumțiosul": "prezumțios",
    "prezumțiosului": "prezumțios",
    "prezumtiva": "prezumtiv",
    "prezumtivă": "prezumtiv",
    "prezumtive": "prezumtiv",
    "prezumtivei": "prezumtiv",
    "prezumtivele": "prezumtiv",
    "prezumtivelor": "prezumtiv",
    "prezumtivi": "prezumtiv",
    "prezumtivii": "prezumtiv",
    "prezumtivilor": "prezumtiv",
    "prezumtivul": "prezumtiv",
    "prezumtivului": "prezumtiv",
    "priana": "prian",
    "priană": "prian",
    "prianul": "prian",
    "prianului": "prian",
    "priene": "prian",
    "prienei": "prian",
    "prienele": "prian",
    "prienelor": "prian",
    "prieni": "prian",
    "prienii": "prian",
    "prienilor": "prian",
    "pribeaga": "pribeag",
    "pribeagă": "pribeag",
    "pribeagul": "pribeag",
    "pribeagului": "pribeag",
    "pribege": "pribeag",
    "pribegei": "pribeag",
    "pribegele": "pribeag",
    "pribegelor": "pribeag",
    "pribegi": "pribeag",
    "pribegii": "pribeag",
    "pribegilor": "pribeag",
    "nemaipribegind": "pribegi",
    "nemaipribegindu": "pribegi",
    "nepribegind": "pribegi",
    "nepribegindu": "pribegi",
    "pribegea": "pribegi",
    "pribegeai": "pribegi",
    "pribegeam": "pribegi",
    "pribegească": "pribegi",
    "pribegeați": "pribegi",
    "pribegeau": "pribegi",
    "pribegesc": "pribegi",
    "pribegește": "pribegi",
    "pribegești": "pribegi",
    "pribegii": "pribegi",
    "pribegim": "pribegi",
    "pribegind": "pribegi",
    "pribegindu": "pribegi",
    "pribegiră": "pribegi",
    "pribegirăm": "pribegi",
    "pribegirăți": "pribegi",
    "pribegise": "pribegi",
    "pribegisem": "pribegi",
    "pribegiseră": "pribegi",
    "pribegiserăm": "pribegi",
    "pribegiserăți": "pribegi",
    "pribegiseși": "pribegi",
    "pribegiși": "pribegi",
    "pribegit": "pribegi",
    "pribegiți": "pribegi",
    "pribegia": "pribegie",
    "pribegiei": "pribegie",
    "pribegii": "pribegie",
    "pribegiile": "pribegie",
    "pribegiilor": "pribegie",
    "pribegită": "pribegit",
    "pribegite": "pribegit",
    "pribegiți": "pribegit",
    "pribegitoare": "pribegitor",
    "pribegitoarea": "pribegitor",
    "pribegitoarei": "pribegitor",
    "pribegitoarele": "pribegitor",
    "pribegitoarelor": "pribegitor",
    "pribegitori": "pribegitor",
    "pribegitorii": "pribegitor",
    "pribegitorilor": "pribegitor",
    "pribegitorul": "pribegitor",
    "pribegitorului": "pribegitor",
    "nemaipricepând": "pricepe",
    "nemaipricepându": "pricepe",
    "nepricepând": "pricepe",
    "nepricepându": "pricepe",
    "priceapă": "pricepe",
    "pricep": "pricepe",
    "pricepând": "pricepe",
    "pricepându": "pricepe",
    "pricepea": "pricepe",
    "pricepeai": "pricepe",
    "pricepeam": "pricepe",
    "pricepeați": "pricepe",
    "pricepeau": "pricepe",
    "pricepem": "pricepe",
    "pricepeți": "pricepe",
    "pricepi": "pricepe",
    "pricepu": "pricepe",
    "pricepui": "pricepe",
    "pricepură": "pricepe",
    "pricepurăm": "pricepe",
    "pricepurăți": "pricepe",
    "pricepuse": "pricepe",
    "pricepusem": "pricepe",
    "pricepuseră": "pricepe",
    "pricepuserăm": "pricepe",
    "pricepuserăți": "pricepe",
    "pricepuseși": "pricepe",
    "pricepuși": "pricepe",
    "priceput": "pricepe",
    "priceperea": "pricepere",
    "priceperi": "pricepere",
    "priceperii": "pricepere",
    "priceperile": "pricepere",
    "priceperilor": "pricepere",
    "priceputa": "priceput",
    "pricepută": "priceput",
    "pricepute": "priceput",
    "priceputei": "priceput",
    "priceputele": "priceput",
    "priceputelor": "priceput",
    "pricepuți": "priceput",
    "pricepuții": "priceput",
    "pricepuților": "priceput",
    "priceputul": "priceput",
    "priceputului": "priceput",
    "prichindei": "prichindel",
    "prichindeii": "prichindel",
    "prichindeilor": "prichindel",
    "prichindelul": "prichindel",
    "prichindelului": "prichindel",
    "pricina": "pricină",
    "pricini": "pricină",
    "pricinii": "pricină",
    "pricinile": "pricină",
    "pricinilor": "pricină",
    "nemaipricinuind": "pricinui",
    "nemaipricinuindu": "pricinui",
    "nepricinuind": "pricinui",
    "nepricinuindu": "pricinui",
    "pricinuia": "pricinui",
    "pricinuiai": "pricinui",
    "pricinuiam": "pricinui",
    "pricinuiască": "pricinui",
    "pricinuiați": "pricinui",
    "pricinuiau": "pricinui",
    "pricinuiesc": "pricinui",
    "pricinuiește": "pricinui",
    "pricinuiești": "pricinui",
    "pricinuii": "pricinui",
    "pricinuim": "pricinui",
    "pricinuind": "pricinui",
    "pricinuindu": "pricinui",
    "pricinuiră": "pricinui",
    "pricinuirăm": "pricinui",
    "pricinuirăți": "pricinui",
    "pricinuise": "pricinui",
    "pricinuisem": "pricinui",
    "pricinuiseră": "pricinui",
    "pricinuiserăm": "pricinui",
    "pricinuiserăți": "pricinui",
    "pricinuiseși": "pricinui",
    "pricinuiși": "pricinui",
    "pricinuit": "pricinui",
    "pricinuiți": "pricinui",
    "pricinuită": "pricinuit",
    "pricinuite": "pricinuit",
    "pricinuiți": "pricinuit",
    "pricinuitoare": "pricinuitor",
    "pricinuitoarea": "pricinuitor",
    "pricinuitoarei": "pricinuitor",
    "pricinuitoarele": "pricinuitor",
    "pricinuitoarelor": "pricinuitor",
    "pricinuitori": "pricinuitor",
    "pricinuitorii": "pricinuitor",
    "pricinuitorilor": "pricinuitor",
    "pricinuitorul": "pricinuitor",
    "pricinuitorului": "pricinuitor",
    "pricomigdala": "pricomigdală",
    "pricomigdale": "pricomigdală",
    "pricomigdalei": "pricomigdală",
    "pricomigdalele": "pricomigdală",
    "pricomigdalelor": "pricomigdală",
    "pricopseala": "pricopseală",
    "pricopseli": "pricopseală",
    "pricopselii": "pricopseală",
    "pricopselile": "pricopseală",
    "pricopselilor": "pricopseală",
    "nemaipricopsind": "pricopsi",
    "nemaipricopsindu": "pricopsi",
    "nepricopsind": "pricopsi",
    "nepricopsindu": "pricopsi",
    "pricopsea": "pricopsi",
    "pricopseai": "pricopsi",
    "pricopseam": "pricopsi",
    "pricopsească": "pricopsi",
    "pricopseați": "pricopsi",
    "pricopseau": "pricopsi",
    "pricopsesc": "pricopsi",
    "pricopsește": "pricopsi",
    "pricopsești": "pricopsi",
    "pricopsii": "pricopsi",
    "pricopsim": "pricopsi",
    "pricopsind": "pricopsi",
    "pricopsindu": "pricopsi",
    "pricopsiră": "pricopsi",
    "pricopsirăm": "pricopsi",
    "pricopsirăți": "pricopsi",
    "pricopsise": "pricopsi",
    "pricopsisem": "pricopsi",
    "pricopsiseră": "pricopsi",
    "pricopsiserăm": "pricopsi",
    "pricopsiserăți": "pricopsi",
    "pricopsiseși": "pricopsi",
    "pricopsiși": "pricopsi",
    "pricopsit": "pricopsi",
    "pricopsiți": "pricopsi",
    "pricopsită": "pricopsit",
    "pricopsite": "pricopsit",
    "pricopsiți": "pricopsit",
    "nemaiprididind": "prididi",
    "nemaiprididindu": "prididi",
    "neprididind": "prididi",
    "neprididindu": "prididi",
    "prididea": "prididi",
    "pridideai": "prididi",
    "pridideam": "prididi",
    "prididească": "prididi",
    "pridideați": "prididi",
    "pridideau": "prididi",
    "prididesc": "prididi",
    "prididește": "prididi",
    "prididești": "prididi",
    "prididii": "prididi",
    "prididim": "prididi",
    "prididind": "prididi",
    "prididindu": "prididi",
    "prididiră": "prididi",
    "prididirăm": "prididi",
    "prididirăți": "prididi",
    "prididise": "prididi",
    "prididisem": "prididi",
    "prididiseră": "prididi",
    "prididiserăm": "prididi",
    "prididiserăți": "prididi",
    "prididiseși": "prididi",
    "prididiși": "prididi",
    "prididit": "prididi",
    "prididiți": "prididi",
    "prididită": "prididit",
    "prididite": "prididit",
    "prididiți": "prididit",
    "pridvoare": "pridvor",
    "pridvoarele": "pridvor",
    "pridvoarelor": "pridvor",
    "pridvorul": "pridvor",
    "pridvorului": "pridvor",
    "prielnica": "prielnic",
    "prielnică": "prielnic",
    "prielnice": "prielnic",
    "prielnicei": "prielnic",
    "prielnicele": "prielnic",
    "prielnicelor": "prielnic",
    "prielnici": "prielnic",
    "prielnicii": "prielnic",
    "prielnicilor": "prielnic",
    "prielnicul": "prielnic",
    "prielnicului": "prielnic",
    "prietene": "prieten",
    "prieteni": "prieten",
    "prietenii": "prieten",
    "prietenilor": "prieten",
    "prietenul": "prieten",
    "prietenului": "prieten",
    "prietena": "prietenă",
    "prietene": "prietenă",
    "prietenei": "prietenă",
    "prietenele": "prietenă",
    "prietenelor": "prietenă",
    "prieteneasca": "prietenesc",
    "prietenească": "prietenesc",
    "prietenescul": "prietenesc",
    "prietenescului": "prietenesc",
    "prietenești": "prietenesc",
    "prieteneștii": "prietenesc",
    "prieteneștile": "prietenesc",
    "prieteneștilor": "prietenesc",
    "prietenia": "prietenie",
    "prieteniei": "prietenie",
    "prietenii": "prietenie",
    "prieteniile": "prietenie",
    "prieteniilor": "prietenie",
    "prietenoasa": "prietenos",
    "prietenoasă": "prietenos",
    "prietenoase": "prietenos",
    "prietenoasei": "prietenos",
    "prietenoasele": "prietenos",
    "prietenoaselor": "prietenos",
    "prietenoși": "prietenos",
    "prietenoșii": "prietenos",
    "prietenoșilor": "prietenos",
    "prietenosul": "prietenos",
    "prietenosului": "prietenos",
    "prigoana": "prigoană",
    "prigoane": "prigoană",
    "prigoanei": "prigoană",
    "prigoanele": "prigoană",
    "prigoanelor": "prigoană",
    "nemaiprigonind": "prigoni",
    "nemaiprigonindu": "prigoni",
    "neprigonind": "prigoni",
    "neprigonindu": "prigoni",
    "prigonea": "prigoni",
    "prigoneai": "prigoni",
    "prigoneam": "prigoni",
    "prigonească": "prigoni",
    "prigoneați": "prigoni",
    "prigoneau": "prigoni",
    "prigonesc": "prigoni",
    "prigonește": "prigoni",
    "prigonești": "prigoni",
    "prigonii": "prigoni",
    "prigonim": "prigoni",
    "prigonind": "prigoni",
    "prigonindu": "prigoni",
    "prigoniră": "prigoni",
    "prigonirăm": "prigoni",
    "prigonirăți": "prigoni",
    "prigonise": "prigoni",
    "prigonisem": "prigoni",
    "prigoniseră": "prigoni",
    "prigoniserăm": "prigoni",
    "prigoniserăți": "prigoni",
    "prigoniseși": "prigoni",
    "prigoniși": "prigoni",
    "prigonit": "prigoni",
    "prigoniți": "prigoni",
    "prigonită": "prigonit",
    "prigonite": "prigonit",
    "prigoniți": "prigonit",
    "prigonitoare": "prigonitor",
    "prigonitoarea": "prigonitor",
    "prigonitoarei": "prigonitor",
    "prigonitoarele": "prigonitor",
    "prigonitoarelor": "prigonitor",
    "prigonitori": "prigonitor",
    "prigonitorii": "prigonitor",
    "prigonitorilor": "prigonitor",
    "prigonitorul": "prigonitor",
    "prigonitorului": "prigonitor",
    "prigoria": "prigorie",
    "prigoriei": "prigorie",
    "prigorii": "prigorie",
    "prigoriile": "prigorie",
    "prigoriilor": "prigorie",
    "prihana": "prihană",
    "prihane": "prihană",
    "prihanei": "prihană",
    "prihanele": "prihană",
    "prihanelor": "prihană",
    "pria": "prii",
    "priască": "prii",
    "priau": "prii",
    "priesc": "prii",
    "priește": "prii",
    "priii": "prii",
    "priim": "prii",
    "priind": "prii",
    "priindu": "prii",
    "priiră": "prii",
    "priirăm": "prii",
    "priirăți": "prii",
    "priise": "prii",
    "priisem": "prii",
    "priiseră": "prii",
    "priiserăm": "prii",
    "priiserăți": "prii",
    "priiseși": "prii",
    "priiși": "prii",
    "priit": "prii",
    "priiți": "prii",
    "priitu": "prii",
    "priirea": "priire",
    "priiri": "priire",
    "priirii": "priire",
    "priirile": "priire",
    "priirilor": "priire",
    "priită": "priit",
    "priite": "priit",
    "priiți": "priit",
    "prilejul": "prilej",
    "prilejului": "prilej",
    "prilejuri": "prilej",
    "prilejurile": "prilej",
    "prilejurilor": "prilej",
    "nemaiprilejuind": "prilejui",
    "nemaiprilejuindu": "prilejui",
    "neprilejuind": "prilejui",
    "neprilejuindu": "prilejui",
    "prilejuia": "prilejui",
    "prilejuiai": "prilejui",
    "prilejuiam": "prilejui",
    "prilejuiască": "prilejui",
    "prilejuiați": "prilejui",
    "prilejuiau": "prilejui",
    "prilejuiesc": "prilejui",
    "prilejuiește": "prilejui",
    "prilejuiești": "prilejui",
    "prilejuii": "prilejui",
    "prilejuim": "prilejui",
    "prilejuind": "prilejui",
    "prilejuindu": "prilejui",
    "prilejuiră": "prilejui",
    "prilejuirăm": "prilejui",
    "prilejuirăți": "prilejui",
    "prilejuise": "prilejui",
    "prilejuisem": "prilejui",
    "prilejuiseră": "prilejui",
    "prilejuiserăm": "prilejui",
    "prilejuiserăți": "prilejui",
    "prilejuiseși": "prilejui",
    "prilejuiși": "prilejui",
    "prilejuit": "prilejui",
    "prilejuiți": "prilejui",
    "prilejuită": "prilejuit",
    "prilejuite": "prilejuit",
    "prilejuiți": "prilejuit",
    "prima": "prim",
    "primă": "prim",
    "prime": "prim",
    "primei": "prim",
    "primele": "prim",
    "primelor": "prim",
    "primi": "prim",
    "primii": "prim",
    "primilor": "prim",
    "primul": "prim",
    "primului": "prim",
    "nemaiprimând": "prima",
    "nemaiprimându": "prima",
    "neprimând": "prima",
    "neprimându": "prima",
    "primă": "prima",
    "primai": "prima",
    "primam": "prima",
    "primăm": "prima",
    "primând": "prima",
    "primându": "prima",
    "primară": "prima",
    "primarăm": "prima",
    "primarăți": "prima",
    "primase": "prima",
    "primasem": "prima",
    "primaseră": "prima",
    "primaserăm": "prima",
    "primaserăți": "prima",
    "primaseși": "prima",
    "primași": "prima",
    "primat": "prima",
    "primați": "prima",
    "primau": "prima",
    "primează": "prima",
    "primez": "prima",
    "primeze": "prima",
    "primezi": "prima",
    "prima": "primă",
    "prime": "primă",
    "primei": "primă",
    "primele": "primă",
    "primelor": "primă",
    "primadona": "primadonă",
    "primadone": "primadonă",
    "primadonei": "primadonă",
    "primadonele": "primadonă",
    "primadonelor": "primadonă",
    "primara": "primar",
    "primară": "primar",
    "primare": "primar",
    "primarei": "primar",
    "primarele": "primar",
    "primarelor": "primar",
    "primari": "primar",
    "primarii": "primar",
    "primarilor": "primar",
    "primarul": "primar",
    "primarului": "primar",
    "primăria": "primărie",
    "primăriei": "primărie",
    "primării": "primărie",
    "primăriile": "primărie",
    "primăriilor": "primărie",
    "primasul": "primas",
    "primasului": "primas",
    "primasuri": "primas",
    "primasurile": "primas",
    "primasurilor": "primas",
    "primata": "primat",
    "primată": "primat",
    "primate": "primat",
    "primatei": "primat",
    "primatele": "primat",
    "primatelor": "primat",
    "primați": "primat",
    "primații": "primat",
    "primaților": "primat",
    "primatul": "primat",
    "primatului": "primat",
    "primăvara": "primăvară",
    "primăveri": "primăvară",
    "primăverii": "primăvară",
    "primăverile": "primăvară",
    "primăverilor": "primăvară",
    "primăvăratica": "primăvăratic",
    "primăvăratică": "primăvăratic",
    "primăvăratice": "primăvăratic",
    "primăvăraticei": "primăvăratic",
    "primăvăraticele": "primăvăratic",
    "primăvăraticelor": "primăvăratic",
    "primăvăratici": "primăvăratic",
    "primăvăraticii": "primăvăratic",
    "primăvăraticilor": "primăvăratic",
    "primăvăraticul": "primăvăratic",
    "primăvăraticului": "primăvăratic",
    "primăvăroasa": "primăvăros",
    "primăvăroasă": "primăvăros",
    "primăvăroase": "primăvăros",
    "primăvăroasei": "primăvăros",
    "primăvăroasele": "primăvăros",
    "primăvăroaselor": "primăvăros",
    "primăvăroși": "primăvăros",
    "primăvăroșii": "primăvăros",
    "primăvăroșilor": "primăvăros",
    "primăvărosul": "primăvăros",
    "primăvărosului": "primăvăros",
    "primejdia": "primejdie",
    "primejdiei": "primejdie",
    "primejdii": "primejdie",
    "primejdiile": "primejdie",
    "primejdiilor": "primejdie",
    "primejdioasa": "primejdios",
    "primejdioasă": "primejdios",
    "primejdioase": "primejdios",
    "primejdioasei": "primejdios",
    "primejdioasele": "primejdios",
    "primejdioaselor": "primejdios",
    "primejdioși": "primejdios",
    "primejdioșii": "primejdios",
    "primejdioșilor": "primejdios",
    "primejdiosul": "primejdios",
    "primejdiosului": "primejdios",
    "nemaiprimejduind": "primejdui",
    "nemaiprimejduindu": "primejdui",
    "neprimejduind": "primejdui",
    "neprimejduindu": "primejdui",
    "primejduia": "primejdui",
    "primejduiai": "primejdui",
    "primejduiam": "primejdui",
    "primejduiască": "primejdui",
    "primejduiați": "primejdui",
    "primejduiau": "primejdui",
    "primejduiesc": "primejdui",
    "primejduiește": "primejdui",
    "primejduiești": "primejdui",
    "primejduii": "primejdui",
    "primejduim": "primejdui",
    "primejduind": "primejdui",
    "primejduindu": "primejdui",
    "primejduiră": "primejdui",
    "primejduirăm": "primejdui",
    "primejduirăți": "primejdui",
    "primejduise": "primejdui",
    "primejduisem": "primejdui",
    "primejduiseră": "primejdui",
    "primejduiserăm": "primejdui",
    "primejduiserăți": "primejdui",
    "primejduiseși": "primejdui",
    "primejduiși": "primejdui",
    "primejduit": "primejdui",
    "primejduiți": "primejdui",
    "primejduită": "primejduit",
    "primejduite": "primejduit",
    "primejduiți": "primejduit",
    "primeneala": "primeneală",
    "primeneli": "primeneală",
    "primenelii": "primeneală",
    "primenelile": "primeneală",
    "primenelilor": "primeneală",
    "nemaiprimenind": "primeni",
    "nemaiprimenindu": "primeni",
    "neprimenind": "primeni",
    "neprimenindu": "primeni",
    "primenea": "primeni",
    "primeneai": "primeni",
    "primeneam": "primeni",
    "primenească": "primeni",
    "primeneați": "primeni",
    "primeneau": "primeni",
    "primenesc": "primeni",
    "primenește": "primeni",
    "primenești": "primeni",
    "primenii": "primeni",
    "primenim": "primeni",
    "primenind": "primeni",
    "primenindu": "primeni",
    "primeniră": "primeni",
    "primenirăm": "primeni",
    "primenirăți": "primeni",
    "primenise": "primeni",
    "primenisem": "primeni",
    "primeniseră": "primeni",
    "primeniserăm": "primeni",
    "primeniserăți": "primeni",
    "primeniseși": "primeni",
    "primeniși": "primeni",
    "primenit": "primeni",
    "primeniți": "primeni",
    "primenita": "primenit",
    "primenită": "primenit",
    "primenite": "primenit",
    "primenitei": "primenit",
    "primenitele": "primenit",
    "primenitelor": "primenit",
    "primeniți": "primenit",
    "primeniții": "primenit",
    "primeniților": "primenit",
    "primenitul": "primenit",
    "primenitului": "primenit",
    "nemaiprimind": "primi",
    "nemaiprimindu": "primi",
    "neprimind": "primi",
    "neprimindu": "primi",
    "primea": "primi",
    "primeai": "primi",
    "primeam": "primi",
    "primească": "primi",
    "primeați": "primi",
    "primeau": "primi",
    "primesc": "primi",
    "primește": "primi",
    "primești": "primi",
    "primii": "primi",
    "primim": "primi",
    "primind": "primi",
    "primindu": "primi",
    "primiră": "primi",
    "primirăm": "primi",
    "primirăți": "primi",
    "primise": "primi",
    "primisem": "primi",
    "primiseră": "primi",
    "primiserăm": "primi",
    "primiserăți": "primi",
    "primiseși": "primi",
    "primiși": "primi",
    "primit": "primi",
    "primiți": "primi",
    "primirea": "primire",
    "primiri": "primire",
    "primirii": "primire",
    "primirile": "primire",
    "primirilor": "primire",
    "primită": "primit",
    "primite": "primit",
    "primiți": "primit",
    "primitiva": "primitiv",
    "primitivă": "primitiv",
    "primitive": "primitiv",
    "primitivei": "primitiv",
    "primitivele": "primitiv",
    "primitivelor": "primitiv",
    "primitivi": "primitiv",
    "primitivii": "primitiv",
    "primitivilor": "primitiv",
    "primitivul": "primitiv",
    "primitivului": "primitiv",
    "primitivismul": "primitivism",
    "primitivismului": "primitivism",
    "primitivitatea": "primitivitate",
    "primitivități": "primitivitate",
    "primitivității": "primitivitate",
    "primitoare": "primitor",
    "primitoarea": "primitor",
    "primitoarei": "primitor",
    "primitoarele": "primitor",
    "primitoarelor": "primitor",
    "primitori": "primitor",
    "primitorii": "primitor",
    "primitorilor": "primitor",
    "primitorul": "primitor",
    "primitorului": "primitor",
    "prim-miniștri": "prim-ministru",
    "prim-miniștrii": "prim-ministru",
    "prim-miniștrilor": "prim-ministru",
    "prim-ministrul": "prim-ministru",
    "prim-ministrului": "prim-ministru",
    "primul-ministru": "prim-ministru",
    "primului-ministru": "prim-ministru",
    "primogenitura": "primogenitură",
    "primogenituri": "primogenitură",
    "primogeniturii": "primogenitură",
    "primordiala": "primordial",
    "primordială": "primordial",
    "primordiale": "primordial",
    "primordialei": "primordial",
    "primordialele": "primordial",
    "primordialelor": "primordial",
    "primordiali": "primordial",
    "primordialii": "primordial",
    "primordialilor": "primordial",
    "primordialul": "primordial",
    "primordialului": "primordial",
    "primordialitatea": "primordialitate",
    "primordialități": "primordialitate",
    "primordialității": "primordialitate",
    "prim-planul": "prim-plan",
    "prim-planului": "prim-plan",
    "prim-planuri": "prim-plan",
    "prim-planurile": "prim-plan",
    "prim-planurilor": "prim-plan",
    "prim-pretori": "prim-pretor",
    "prim-pretorilor": "prim-pretor",
    "prim-pretorul": "prim-pretor",
    "prim-pretorului": "prim-pretor",
    "prim-procurori": "prim-procuror",
    "prim-procurorilor": "prim-procuror",
    "prim-procurorul": "prim-procuror",
    "prim-procurorului": "prim-procuror",
    "primii-secretari": "prim-secretar",
    "primilor-secretari": "prim-secretar",
    "primi-secretari": "prim-secretar",
    "primul-secretar": "prim-secretar",
    "primului-secretar": "prim-secretar",
    "primusul": "primus",
    "primusului": "primus",
    "primusuri": "primus",
    "primusurile": "primus",
    "primusurilor": "primus",
    "prim-viceprim-miniștri": "prim-viceprim-ministru",
    "prim-viceprim-miniștrii": "prim-viceprim-ministru",
    "prim-viceprim-miniștrilor": "prim-viceprim-ministru",
    "prim-viceprim-ministrul": "prim-viceprim-ministru",
    "prim-viceprim-ministrului": "prim-viceprim-ministru",
    "pân": "prin",
    "pân-": "prin",
    "princiara": "princiar",
    "princiară": "princiar",
    "princiare": "princiar",
    "princiarei": "princiar",
    "princiarele": "princiar",
    "princiarelor": "princiar",
    "princiari": "princiar",
    "princiarii": "princiar",
    "princiarilor": "princiar",
    "princiarul": "princiar",
    "princiarului": "princiar",
    "princ.": "principal",
    "principala": "principal",
    "principală": "principal",
    "principale": "principal",
    "principalei": "principal",
    "principalele": "principal",
    "principalelor": "principal",
    "principali": "principal",
    "principalii": "principal",
    "principalilor": "principal",
    "principalul": "principal",
    "principalului": "principal",
    "principate": "principat",
    "principatele": "principat",
    "principatelor": "principat",
    "principatul": "principat",
    "principatului": "principat",
    "principele": "principe",
    "principelui": "principe",
    "principi": "principe",
    "principii": "principe",
    "principilor": "principe",
    "principiala": "principial",
    "principială": "principial",
    "principiale": "principial",
    "principialei": "principial",
    "principialele": "principial",
    "principialelor": "principial",
    "principiali": "principial",
    "principialii": "principial",
    "principialilor": "principial",
    "principialul": "principial",
    "principialului": "principial",
    "principialitatea": "principialitate",
    "principialități": "principialitate",
    "principialității": "principialitate",
    "principii": "principiu",
    "principiile": "principiu",
    "principiilor": "principiu",
    "principiul": "principiu",
    "principiului": "principiu",
    "nemaiprinzând": "prinde",
    "nemaiprinzându": "prinde",
    "neprinzând": "prinde",
    "neprinzându": "prinde",
    "prind": "prinde",
    "prindă": "prinde",
    "prindea": "prinde",
    "prindeai": "prinde",
    "prindeam": "prinde",
    "prindeați": "prinde",
    "prindeau": "prinde",
    "prindem": "prinde",
    "prindeți": "prinde",
    "prins": "prinde",
    "prinse": "prinde",
    "prinsei": "prinde",
    "prinseră": "prinde",
    "prinserăm": "prinde",
    "prinserăți": "prinde",
    "prinsese": "prinde",
    "prinsesem": "prinde",
    "prinseseră": "prinde",
    "prinseserăm": "prinde",
    "prinseserăți": "prinde",
    "prinseseși": "prinde",
    "prinseși": "prinde",
    "prinzând": "prinde",
    "prinzându": "prinde",
    "prinzi": "prinde",
    "prinosul": "prinos",
    "prinosului": "prinos",
    "prinosuri": "prinos",
    "prinosurile": "prinos",
    "prinosurilor": "prinos",
    "prinsa": "prins",
    "prinsă": "prins",
    "prinse": "prins",
    "prinsei": "prins",
    "prinsele": "prins",
    "prinselor": "prins",
    "prinși": "prins",
    "prinșii": "prins",
    "prinșilor": "prins",
    "prinsul": "prins",
    "prinsului": "prins",
    "prinsoarea": "prinsoare",
    "prinsori": "prinsoare",
    "prinsorii": "prinsoare",
    "prinsorile": "prinsoare",
    "prinsorilor": "prinsoare",
    "prinți": "prinț",
    "prinții": "prinț",
    "prinților": "prinț",
    "prințul": "prinț",
    "prințului": "prinț",
    "prințesa": "prințesă",
    "prințese": "prințesă",
    "prințesei": "prințesă",
    "prințesele": "prințesă",
    "prințeselor": "prințesă",
    "printr-": "printru",
    "prinzătoare": "prinzător",
    "prinzătoarea": "prinzător",
    "prinzătoarei": "prinzător",
    "prinzătoarele": "prinzător",
    "prinzătoarelor": "prinzător",
    "prinzători": "prinzător",
    "prinzătorii": "prinzător",
    "prinzătorilor": "prinzător",
    "prinzătorul": "prinzător",
    "prinzătorului": "prinzător",
    "prioara": "prior",
    "prioară": "prior",
    "prioare": "prior",
    "prioarei": "prior",
    "prioarele": "prior",
    "prioarelor": "prior",
    "priori": "prior",
    "priorii": "prior",
    "priorilor": "prior",
    "priorul": "prior",
    "priorului": "prior",
    "prioritatea": "prioritate",
    "priorități": "prioritate",
    "priorității": "prioritate",
    "prioritățile": "prioritate",
    "priorităților": "prioritate",
    "pripa": "pripă",
    "pripe": "pripă",
    "pripei": "pripă",
    "pripele": "pripă",
    "pripelor": "pripă",
    "nemaipripășind": "pripăși",
    "nemaipripășindu": "pripăși",
    "nepripășind": "pripăși",
    "nepripășindu": "pripăși",
    "pripășea": "pripăși",
    "pripășeai": "pripăși",
    "pripășeam": "pripăși",
    "pripășească": "pripăși",
    "pripășeați": "pripăși",
    "pripășeau": "pripăși",
    "pripășesc": "pripăși",
    "pripășește": "pripăși",
    "pripășești": "pripăși",
    "pripășii": "pripăși",
    "pripășim": "pripăși",
    "pripășind": "pripăși",
    "pripășindu": "pripăși",
    "pripășiră": "pripăși",
    "pripășirăm": "pripăși",
    "pripășirăți": "pripăși",
    "pripășise": "pripăși",
    "pripășisem": "pripăși",
    "pripășiseră": "pripăși",
    "pripășiserăm": "pripăși",
    "pripășiserăți": "pripăși",
    "pripășiseși": "pripăși",
    "pripășiși": "pripăși",
    "pripășit": "pripăși",
    "pripășiți": "pripăși",
    "pripășită": "pripășit",
    "pripășite": "pripășit",
    "pripășiți": "pripășit",
    "pripeala": "pripeală",
    "pripeli": "pripeală",
    "pripelii": "pripeală",
    "pripelile": "pripeală",
    "pripelilor": "pripeală",
    "nemaipripind": "pripi",
    "nemaipripindu": "pripi",
    "nepripind": "pripi",
    "nepripindu": "pripi",
    "pripea": "pripi",
    "pripeai": "pripi",
    "pripeam": "pripi",
    "pripească": "pripi",
    "pripeați": "pripi",
    "pripeau": "pripi",
    "pripesc": "pripi",
    "pripește": "pripi",
    "pripești": "pripi",
    "pripii": "pripi",
    "pripim": "pripi",
    "pripind": "pripi",
    "pripindu": "pripi",
    "pripiră": "pripi",
    "pripirăm": "pripi",
    "pripirăți": "pripi",
    "pripise": "pripi",
    "pripisem": "pripi",
    "pripiseră": "pripi",
    "pripiserăm": "pripi",
    "pripiserăți": "pripi",
    "pripiseși": "pripi",
    "pripiși": "pripi",
    "pripit": "pripi",
    "pripiți": "pripi",
    "pripită": "pripit",
    "pripite": "pripit",
    "pripiți": "pripit",
    "pripoane": "pripon",
    "pripoanele": "pripon",
    "pripoanelor": "pripon",
    "priponul": "pripon",
    "priponului": "pripon",
    "nemaipriponind": "priponi",
    "nemaipriponindu": "priponi",
    "nepriponind": "priponi",
    "nepriponindu": "priponi",
    "priponea": "priponi",
    "priponeai": "priponi",
    "priponeam": "priponi",
    "priponească": "priponi",
    "priponeați": "priponi",
    "priponeau": "priponi",
    "priponesc": "priponi",
    "priponește": "priponi",
    "priponești": "priponi",
    "priponii": "priponi",
    "priponim": "priponi",
    "priponind": "priponi",
    "priponindu": "priponi",
    "priponiră": "priponi",
    "priponirăm": "priponi",
    "priponirăți": "priponi",
    "priponise": "priponi",
    "priponisem": "priponi",
    "priponiseră": "priponi",
    "priponiserăm": "priponi",
    "priponiserăți": "priponi",
    "priponiseși": "priponi",
    "priponiși": "priponi",
    "priponit": "priponi",
    "priponiți": "priponi",
    "priponită": "priponit",
    "priponite": "priponit",
    "priponiți": "priponit",
    "pripoare": "pripor",
    "pripoarele": "pripor",
    "pripoarelor": "pripor",
    "priporul": "pripor",
    "priporului": "pripor",
    "priporoasa": "priporos",
    "priporoasă": "priporos",
    "priporoase": "priporos",
    "priporoasei": "priporos",
    "priporoasele": "priporos",
    "priporoaselor": "priporos",
    "priporoși": "priporos",
    "priporoșii": "priporos",
    "priporoșilor": "priporos",
    "priporosul": "priporos",
    "priporosului": "priporos",
    "prisaca": "prisacă",
    "prisăci": "prisacă",
    "prisăcii": "prisacă",
    "prisăcile": "prisacă",
    "prisăcilor": "prisacă",
    "prisăcari": "prisăcar",
    "prisăcarii": "prisăcar",
    "prisăcarilor": "prisăcar",
    "prisăcarul": "prisăcar",
    "prisăcarului": "prisăcar",
    "prislopul": "prislop",
    "prislopului": "prislop",
    "prislopuri": "prislop",
    "prislopurile": "prislop",
    "prislopurilor": "prislop",
    "prisma": "prismă",
    "prisme": "prismă",
    "prismei": "prismă",
    "prismele": "prismă",
    "prismelor": "prismă",
    "prismatica": "prismatic",
    "prismatică": "prismatic",
    "prismatice": "prismatic",
    "prismaticei": "prismatic",
    "prismaticele": "prismatic",
    "prismaticelor": "prismatic",
    "prismatici": "prismatic",
    "prismaticii": "prismatic",
    "prismaticilor": "prismatic",
    "prismaticul": "prismatic",
    "prismaticului": "prismatic",
    "prișnițe": "prișniț",
    "prișnițele": "prișniț",
    "prișnițelor": "prișniț",
    "prișnițul": "prișniț",
    "prișnițului": "prișniț",
    "prisosul": "prisos",
    "prisosului": "prisos",
    "prisosuri": "prisos",
    "prisosurile": "prisos",
    "prisosurilor": "prisos",
    "nemaiprisosind": "prisosi",
    "nemaiprisosindu": "prisosi",
    "neprisosind": "prisosi",
    "neprisosindu": "prisosi",
    "prisosea": "prisosi",
    "prisoseai": "prisosi",
    "prisoseam": "prisosi",
    "prisosească": "prisosi",
    "prisoseați": "prisosi",
    "prisoseau": "prisosi",
    "prisosesc": "prisosi",
    "prisosește": "prisosi",
    "prisosești": "prisosi",
    "prisosii": "prisosi",
    "prisosim": "prisosi",
    "prisosind": "prisosi",
    "prisosindu": "prisosi",
    "prisosiră": "prisosi",
    "prisosirăm": "prisosi",
    "prisosirăți": "prisosi",
    "prisosise": "prisosi",
    "prisosisem": "prisosi",
    "prisosiseră": "prisosi",
    "prisosiserăm": "prisosi",
    "prisosiserăți": "prisosi",
    "prisosiseși": "prisosi",
    "prisosiși": "prisosi",
    "prisosit": "prisosi",
    "prisosiți": "prisosi",
    "prisosința": "prisosință",
    "prisosințe": "prisosință",
    "prisosinței": "prisosință",
    "prisosințele": "prisosință",
    "prisosințelor": "prisosință",
    "prisosită": "prisosit",
    "prisosite": "prisosit",
    "prisosiți": "prisosit",
    "prisositoare": "prisositor",
    "prisositoarea": "prisositor",
    "prisositoarei": "prisositor",
    "prisositoarele": "prisositor",
    "prisositoarelor": "prisositor",
    "prisositori": "prisositor",
    "prisositorii": "prisositor",
    "prisositorilor": "prisositor",
    "prisositorul": "prisositor",
    "prisositorului": "prisositor",
    "prispa": "prispă",
    "prispe": "prispă",
    "prispei": "prispă",
    "prispele": "prispă",
    "prispelor": "prispă",
    "pristolul": "pristol",
    "pristolului": "pristol",
    "pristoluri": "pristol",
    "pristolurile": "pristol",
    "pristolurilor": "pristol",
    "pritoaca": "pritoacă",
    "pritoace": "pritoacă",
    "pritoacei": "pritoacă",
    "pritoacele": "pritoacă",
    "pritoacelor": "pritoacă",
    "nemaipritocind": "pritoci",
    "nemaipritocindu": "pritoci",
    "nepritocind": "pritoci",
    "nepritocindu": "pritoci",
    "pritocea": "pritoci",
    "pritoceai": "pritoci",
    "pritoceam": "pritoci",
    "pritocească": "pritoci",
    "pritoceați": "pritoci",
    "pritoceau": "pritoci",
    "pritocesc": "pritoci",
    "pritocește": "pritoci",
    "pritocești": "pritoci",
    "pritocii": "pritoci",
    "pritocim": "pritoci",
    "pritocind": "pritoci",
    "pritocindu": "pritoci",
    "pritociră": "pritoci",
    "pritocirăm": "pritoci",
    "pritocirăți": "pritoci",
    "pritocise": "pritoci",
    "pritocisem": "pritoci",
    "pritociseră": "pritoci",
    "pritociserăm": "pritoci",
    "pritociserăți": "pritoci",
    "pritociseși": "pritoci",
    "pritociși": "pritoci",
    "pritocit": "pritoci",
    "pritociți": "pritoci",
    "pritocită": "pritocit",
    "pritocite": "pritocit",
    "pritociți": "pritocit",
    "nemaiprivând": "priva",
    "nemaiprivându": "priva",
    "neprivând": "priva",
    "neprivându": "priva",
    "privă": "priva",
    "privai": "priva",
    "privam": "priva",
    "privăm": "priva",
    "privând": "priva",
    "privându": "priva",
    "privară": "priva",
    "privarăm": "priva",
    "privarăți": "priva",
    "privase": "priva",
    "privasem": "priva",
    "privaseră": "priva",
    "privaserăm": "priva",
    "privaserăți": "priva",
    "privaseși": "priva",
    "privași": "priva",
    "privat": "priva",
    "privați": "priva",
    "privau": "priva",
    "privează": "priva",
    "privez": "priva",
    "priveze": "priva",
    "privezi": "priva",
    "privarea": "privare",
    "privări": "privare",
    "privării": "privare",
    "privările": "privare",
    "privărilor": "privare",
    "privata": "privat",
    "privată": "privat",
    "private": "privat",
    "privatei": "privat",
    "privatele": "privat",
    "privatelor": "privat",
    "privați": "privat",
    "privații": "privat",
    "privaților": "privat",
    "privatul": "privat",
    "privatului": "privat",
    "privata": "privată",
    "private": "privată",
    "privatei": "privată",
    "privatele": "privată",
    "privatelor": "privată",
    "privațiunea": "privațiune",
    "privațiuni": "privațiune",
    "privațiunii": "privațiune",
    "privațiunile": "privațiune",
    "privațiunilor": "privațiune",
    "privativa": "privativ",
    "privativă": "privativ",
    "privative": "privativ",
    "privativei": "privativ",
    "privativele": "privativ",
    "privativelor": "privativ",
    "privativi": "privativ",
    "privativii": "privativ",
    "privativilor": "privativ",
    "privativul": "privativ",
    "privativului": "privativ",
    "privatiză": "privatiza",
    "privatizai": "privatiza",
    "privatizam": "privatiza",
    "privatizăm": "privatiza",
    "privatizând": "privatiza",
    "privatizându": "privatiza",
    "privatizară": "privatiza",
    "privatizarăm": "privatiza",
    "privatizarăți": "privatiza",
    "privatizase": "privatiza",
    "privatizasem": "privatiza",
    "privatizaseră": "privatiza",
    "privatizaserăm": "privatiza",
    "privatizaserăți": "privatiza",
    "privatizaseși": "privatiza",
    "privatizași": "privatiza",
    "privatizat": "privatiza",
    "privatizați": "privatiza",
    "privatizau": "privatiza",
    "privatizează": "privatiza",
    "privatizez": "privatiza",
    "privatizeze": "privatiza",
    "privatizezi": "privatiza",
    "privatizarea": "privatizare",
    "privatizări": "privatizare",
    "privatizării": "privatizare",
    "privatizările": "privatizare",
    "privatizărilor": "privatizare",
    "privatizată": "privatizat",
    "privatizate": "privatizat",
    "privatizați": "privatizat",
    "priveghe": "priveghea",
    "privegheai": "priveghea",
    "privegheam": "priveghea",
    "privegheară": "priveghea",
    "priveghearăm": "priveghea",
    "priveghearăți": "priveghea",
    "priveghease": "priveghea",
    "privegheasem": "priveghea",
    "privegheaseră": "priveghea",
    "privegheaserăm": "priveghea",
    "privegheaserăți": "priveghea",
    "privegheaseși": "priveghea",
    "privegheași": "priveghea",
    "privegheat": "priveghea",
    "privegheați": "priveghea",
    "privegheau": "priveghea",
    "priveghează": "priveghea",
    "priveghem": "priveghea",
    "priveghez": "priveghea",
    "privegheze": "priveghea",
    "priveghezi": "priveghea",
    "priveghind": "priveghea",
    "privegheată": "privegheat",
    "privegheate": "privegheat",
    "privegheați": "privegheat",
    "privegherea": "priveghere",
    "privegheri": "priveghere",
    "privegherii": "priveghere",
    "privegherile": "priveghere",
    "privegherilor": "priveghere",
    "priveghiul": "priveghi",
    "priveghiului": "priveghi",
    "priveghiuri": "priveghi",
    "priveghiurile": "priveghi",
    "priveghiurilor": "priveghi",
    "priveliștea": "priveliște",
    "priveliștei": "priveliște",
    "priveliști": "priveliște",
    "priveliștii": "priveliște",
    "priveliștile": "priveliște",
    "priveliștilor": "priveliște",
    "nemaiprivind": "privi",
    "nemaiprivindu": "privi",
    "neprivind": "privi",
    "neprivindu": "privi",
    "privea": "privi",
    "priveai": "privi",
    "priveam": "privi",
    "privească": "privi",
    "priveați": "privi",
    "priveau": "privi",
    "privesc": "privi",
    "privește": "privi",
    "privești": "privi",
    "privii": "privi",
    "privim": "privi",
    "privind": "privi",
    "privindu": "privi",
    "priviră": "privi",
    "privirăm": "privi",
    "privirăți": "privi",
    "privise": "privi",
    "privisem": "privi",
    "priviseră": "privi",
    "priviserăm": "privi",
    "priviserăți": "privi",
    "priviseși": "privi",
    "priviși": "privi",
    "privit": "privi",
    "priviți": "privi",
    "privighetoarea": "privighetoare",
    "privighetorei": "privighetoare",
    "privighetori": "privighetoare",
    "privighetorile": "privighetoare",
    "privighetorilor": "privighetoare",
    "nemaiprivilegiind": "privilegia",
    "nemaiprivilegiindu": "privilegia",
    "neprivilegiind": "privilegia",
    "neprivilegiindu": "privilegia",
    "privilegiai": "privilegia",
    "privilegiam": "privilegia",
    "privilegiară": "privilegia",
    "privilegiarăm": "privilegia",
    "privilegiarăți": "privilegia",
    "privilegiase": "privilegia",
    "privilegiasem": "privilegia",
    "privilegiaseră": "privilegia",
    "privilegiaserăm": "privilegia",
    "privilegiaserăți": "privilegia",
    "privilegiaseși": "privilegia",
    "privilegiași": "privilegia",
    "privilegiat": "privilegia",
    "privilegiați": "privilegia",
    "privilegiau": "privilegia",
    "privilegiază": "privilegia",
    "privilegie": "privilegia",
    "privilegiem": "privilegia",
    "privilegiez": "privilegia",
    "privilegieze": "privilegia",
    "privilegiezi": "privilegia",
    "privilegiind": "privilegia",
    "privilegiindu": "privilegia",
    "privilegiata": "privilegiat",
    "privilegiată": "privilegiat",
    "privilegiate": "privilegiat",
    "privilegiatei": "privilegiat",
    "privilegiatele": "privilegiat",
    "privilegiatelor": "privilegiat",
    "privilegiați": "privilegiat",
    "privilegiații": "privilegiat",
    "privilegiaților": "privilegiat",
    "privilegiatul": "privilegiat",
    "privilegiatului": "privilegiat",
    "privilegiata": "privilegiată",
    "privilegiate": "privilegiată",
    "privilegiatei": "privilegiată",
    "privilegiatele": "privilegiată",
    "privilegiatelor": "privilegiată",
    "privilegii": "privilegiu",
    "privilegiile": "privilegiu",
    "privilegiilor": "privilegiu",
    "privilegiul": "privilegiu",
    "privilegiului": "privilegiu",
    "privința": "privință",
    "privințe": "privință",
    "privinței": "privință",
    "privințele": "privință",
    "privințelor": "privință",
    "privirea": "privire",
    "priviri": "privire",
    "privirii": "privire",
    "privirile": "privire",
    "privirilor": "privire",
    "privită": "privit",
    "privite": "privit",
    "priviți": "privit",
    "privitul": "privit",
    "privitului": "privit",
    "privitoare": "privitor",
    "privitoarea": "privitor",
    "privitoarei": "privitor",
    "privitoarele": "privitor",
    "privitoarelor": "privitor",
    "privitori": "privitor",
    "privitorii": "privitor",
    "privitorilor": "privitor",
    "privitorul": "privitor",
    "privitorului": "privitor",
    "nemaiprizând": "priza",
    "nemaiprizându": "priza",
    "neprizând": "priza",
    "neprizându": "priza",
    "priză": "priza",
    "prizai": "priza",
    "prizam": "priza",
    "prizăm": "priza",
    "prizând": "priza",
    "prizându": "priza",
    "prizară": "priza",
    "prizarăm": "priza",
    "prizarăți": "priza",
    "prizase": "priza",
    "prizasem": "priza",
    "prizaseră": "priza",
    "prizaserăm": "priza",
    "prizaserăți": "priza",
    "prizaseși": "priza",
    "prizași": "priza",
    "prizat": "priza",
    "prizați": "priza",
    "prizau": "priza",
    "prizează": "priza",
    "prizez": "priza",
    "prizeze": "priza",
    "prizezi": "priza",
    "priza": "priză",
    "prize": "priză",
    "prizei": "priză",
    "prizele": "priză",
    "prizelor": "priză",
    "prizata": "prizat",
    "prizată": "prizat",
    "prizate": "prizat",
    "prizatei": "prizat",
    "prizatele": "prizat",
    "prizatelor": "prizat",
    "prizați": "prizat",
    "prizații": "prizat",
    "prizaților": "prizat",
    "prizatul": "prizat",
    "prizatului": "prizat",
    "prizonieri": "prizonier",
    "prizonierii": "prizonier",
    "prizonierilor": "prizonier",
    "prizonierul": "prizonier",
    "prizonierului": "prizonier",
    "prizonieratul": "prizonierat",
    "prizonieratului": "prizonierat",
    "p.t.": "pro_tempore",
    "proaspăta": "proaspăt",
    "proaspătă": "proaspăt",
    "proaspătul": "proaspăt",
    "proaspătului": "proaspăt",
    "proaspete": "proaspăt",
    "proaspetei": "proaspăt",
    "proaspetele": "proaspăt",
    "proaspetelor": "proaspăt",
    "proaspeți": "proaspăt",
    "proaspeții": "proaspăt",
    "proaspeților": "proaspăt",
    "proba": "prob",
    "probă": "prob",
    "probe": "prob",
    "probei": "prob",
    "probele": "prob",
    "probelor": "prob",
    "probi": "prob",
    "probii": "prob",
    "probilor": "prob",
    "probul": "prob",
    "probului": "prob",
    "nemaiprobând": "proba",
    "nemaiprobându": "proba",
    "neprobând": "proba",
    "neprobându": "proba",
    "probă": "proba",
    "probai": "proba",
    "probam": "proba",
    "probăm": "proba",
    "probând": "proba",
    "probându": "proba",
    "probară": "proba",
    "probarăm": "proba",
    "probarăți": "proba",
    "probase": "proba",
    "probasem": "proba",
    "probaseră": "proba",
    "probaserăm": "proba",
    "probaserăți": "proba",
    "probaseși": "proba",
    "probași": "proba",
    "probat": "proba",
    "probați": "proba",
    "probau": "proba",
    "probează": "proba",
    "probez": "proba",
    "probeze": "proba",
    "probezi": "proba",
    "proba": "probă",
    "probe": "probă",
    "probei": "probă",
    "probele": "probă",
    "probelor": "probă",
    "probabila": "probabil",
    "probabilă": "probabil",
    "probabile": "probabil",
    "probabilei": "probabil",
    "probabilele": "probabil",
    "probabilelor": "probabil",
    "probabili": "probabil",
    "probabilii": "probabil",
    "probabililor": "probabil",
    "probabilul": "probabil",
    "probabilului": "probabil",
    "probabilista": "probabilist",
    "probabilistă": "probabilist",
    "probabiliste": "probabilist",
    "probabilistei": "probabilist",
    "probabilistele": "probabilist",
    "probabilistelor": "probabilist",
    "probabiliști": "probabilist",
    "probabiliștii": "probabilist",
    "probabiliștilor": "probabilist",
    "probabilistul": "probabilist",
    "probabilistului": "probabilist",
    "probabilitatea": "probabilitate",
    "probabilități": "probabilitate",
    "probabilității": "probabilitate",
    "probabilitățile": "probabilitate",
    "probabilităților": "probabilitate",
    "probanta": "probant",
    "probantă": "probant",
    "probante": "probant",
    "probantei": "probant",
    "probantele": "probant",
    "probantelor": "probant",
    "probanți": "probant",
    "probanții": "probant",
    "probanților": "probant",
    "probantul": "probant",
    "probantului": "probant",
    "probarea": "probare",
    "probări": "probare",
    "probării": "probare",
    "probările": "probare",
    "probărilor": "probare",
    "probată": "probat",
    "probate": "probat",
    "probați": "probat",
    "probatoria": "probatoriu",
    "probatorie": "probatoriu",
    "probatoriei": "probatoriu",
    "probatorii": "probatoriu",
    "probatoriii": "probatoriu",
    "probatoriile": "probatoriu",
    "probatoriilor": "probatoriu",
    "probatoriul": "probatoriu",
    "probatoriului": "probatoriu",
    "probitatea": "probitate",
    "probități": "probitate",
    "probității": "probitate",
    "probitățile": "probitate",
    "probităților": "probitate",
    "problema": "problemă",
    "probleme": "problemă",
    "problemei": "problemă",
    "problemele": "problemă",
    "problemelor": "problemă",
    "problematica": "problematic",
    "problematică": "problematic",
    "problematice": "problematic",
    "problematicei": "problematic",
    "problematicele": "problematic",
    "problematicelor": "problematic",
    "problematici": "problematic",
    "problematicii": "problematic",
    "problematicilor": "problematic",
    "problematicul": "problematic",
    "problematicului": "problematic",
    "problematica": "problematică",
    "problematice": "problematică",
    "problematicei": "problematică",
    "problematicele": "problematică",
    "problematicelor": "problematică",
    "nemaiprocedând": "proceda",
    "nemaiprocedându": "proceda",
    "neprocedând": "proceda",
    "neprocedându": "proceda",
    "neprocedează": "proceda",
    "procedă": "proceda",
    "procedai": "proceda",
    "procedam": "proceda",
    "procedăm": "proceda",
    "procedând": "proceda",
    "procedându": "proceda",
    "procedară": "proceda",
    "procedarăm": "proceda",
    "procedarăți": "proceda",
    "procedase": "proceda",
    "procedasem": "proceda",
    "procedaseră": "proceda",
    "procedaserăm": "proceda",
    "procedaserăți": "proceda",
    "procedaseși": "proceda",
    "procedași": "proceda",
    "procedat": "proceda",
    "procedați": "proceda",
    "procedau": "proceda",
    "procedează": "proceda",
    "procedez": "proceda",
    "procedeze": "proceda",
    "procedezi": "proceda",
    "procedată": "procedat",
    "procedate": "procedat",
    "procedați": "procedat",
    "procedee": "procedeu",
    "procedeele": "procedeu",
    "procedeelor": "procedeu",
    "procedeul": "procedeu",
    "procedeului": "procedeu",
    "procedura": "procedură",
    "proceduri": "procedură",
    "procedurii": "procedură",
    "procedurile": "procedură",
    "procedurilor": "procedură",
    "procedurala": "procedural",
    "procedurală": "procedural",
    "procedurale": "procedural",
    "proceduralei": "procedural",
    "proceduralele": "procedural",
    "proceduralelor": "procedural",
    "procedurali": "procedural",
    "proceduralii": "procedural",
    "proceduralilor": "procedural",
    "proceduralul": "procedural",
    "proceduralului": "procedural",
    "procente": "procent",
    "procentele": "procent",
    "procentelor": "procent",
    "procentul": "procent",
    "procentului": "procent",
    "procentaje": "procentaj",
    "procentajele": "procentaj",
    "procentajelor": "procentaj",
    "procentajul": "procentaj",
    "procentajului": "procentaj",
    "procentuala": "procentual",
    "procentuală": "procentual",
    "procentuale": "procentual",
    "procentualei": "procentual",
    "procentualele": "procentual",
    "procentualelor": "procentual",
    "procentuali": "procentual",
    "procentualii": "procentual",
    "procentualilor": "procentual",
    "procentualul": "procentual",
    "procentualului": "procentual",
    "procese": "proces",
    "procesele": "proces",
    "proceselor": "proces",
    "procesul": "proces",
    "procesului": "proces",
    "procesă": "procesa",
    "procesai": "procesa",
    "procesam": "procesa",
    "procesăm": "procesa",
    "procesând": "procesa",
    "procesându": "procesa",
    "procesară": "procesa",
    "procesarăm": "procesa",
    "procesarăți": "procesa",
    "procesase": "procesa",
    "procesasem": "procesa",
    "procesaseră": "procesa",
    "procesaserăm": "procesa",
    "procesaserăți": "procesa",
    "procesaseși": "procesa",
    "procesași": "procesa",
    "procesat": "procesa",
    "procesați": "procesa",
    "procesau": "procesa",
    "procesează": "procesa",
    "procesez": "procesa",
    "proceseze": "procesa",
    "procesezi": "procesa",
    "procesarea": "procesare",
    "procesări": "procesare",
    "procesării": "procesare",
    "procesările": "procesare",
    "procesărilor": "procesare",
    "procesata": "procesat",
    "procesată": "procesat",
    "procesate": "procesat",
    "procesatei": "procesat",
    "procesatele": "procesat",
    "procesatelor": "procesat",
    "procesați": "procesat",
    "procesații": "procesat",
    "procesaților": "procesat",
    "procesatul": "procesat",
    "procesatului": "procesat",
    "procesionala": "procesional",
    "procesională": "procesional",
    "procesionale": "procesional",
    "procesionalei": "procesional",
    "procesionalele": "procesional",
    "procesionalelor": "procesional",
    "procesionali": "procesional",
    "procesionalii": "procesional",
    "procesionalilor": "procesional",
    "procesionalul": "procesional",
    "procesionalului": "procesional",
    "procesiunea": "procesiune",
    "procesiuni": "procesiune",
    "procesiunii": "procesiune",
    "procesiunile": "procesiune",
    "procesiunilor": "procesiune",
    "procesuala": "procesual",
    "procesuală": "procesual",
    "procesuale": "procesual",
    "procesualei": "procesual",
    "procesualele": "procesual",
    "procesualelor": "procesual",
    "procesuali": "procesual",
    "procesualii": "procesual",
    "procesualilor": "procesual",
    "procesualul": "procesual",
    "procesualului": "procesual",
    "procesul-verbal": "proces-verbal",
    "nemaiproclamând": "proclama",
    "nemaiproclamându": "proclama",
    "neproclamând": "proclama",
    "neproclamându": "proclama",
    "proclam": "proclama",
    "proclamă": "proclama",
    "proclamai": "proclama",
    "proclamam": "proclama",
    "proclamăm": "proclama",
    "proclamând": "proclama",
    "proclamându": "proclama",
    "proclamară": "proclama",
    "proclamarăm": "proclama",
    "proclamarăți": "proclama",
    "proclamase": "proclama",
    "proclamasem": "proclama",
    "proclamaseră": "proclama",
    "proclamaserăm": "proclama",
    "proclamaserăți": "proclama",
    "proclamaseși": "proclama",
    "proclamași": "proclama",
    "proclamat": "proclama",
    "proclamați": "proclama",
    "proclamau": "proclama",
    "proclame": "proclama",
    "proclami": "proclama",
    "proclamată": "proclamat",
    "proclamate": "proclamat",
    "proclamați": "proclamat",
    "proclamația": "proclamație",
    "proclamației": "proclamație",
    "proclamații": "proclamație",
    "proclamațiile": "proclamație",
    "proclamațiilor": "proclamație",
    "procleta": "proclet",
    "procletă": "proclet",
    "proclete": "proclet",
    "procletei": "proclet",
    "procletele": "proclet",
    "procletelor": "proclet",
    "procleți": "proclet",
    "procleții": "proclet",
    "procleților": "proclet",
    "procletul": "proclet",
    "procletului": "proclet",
    "proclitica": "proclitic",
    "proclitică": "proclitic",
    "proclitice": "proclitic",
    "procliticei": "proclitic",
    "procliticele": "proclitic",
    "procliticelor": "proclitic",
    "proclitici": "proclitic",
    "procliticii": "proclitic",
    "procliticilor": "proclitic",
    "procliticul": "proclitic",
    "procliticului": "proclitic",
    "proconsuli": "proconsul",
    "proconsulii": "proconsul",
    "proconsulilor": "proconsul",
    "proconsulul": "proconsul",
    "proconsulului": "proconsul",
    "proconsulara": "proconsular",
    "proconsulară": "proconsular",
    "proconsulare": "proconsular",
    "proconsularei": "proconsular",
    "proconsularele": "proconsular",
    "proconsularelor": "proconsular",
    "proconsulari": "proconsular",
    "proconsularii": "proconsular",
    "proconsularilor": "proconsular",
    "proconsularul": "proconsular",
    "proconsularului": "proconsular",
    "nemaiprocreind": "procrea",
    "nemaiprocreindu": "procrea",
    "neprocreind": "procrea",
    "neprocreindu": "procrea",
    "procreai": "procrea",
    "procream": "procrea",
    "procreară": "procrea",
    "procrearăm": "procrea",
    "procrearăți": "procrea",
    "procrease": "procrea",
    "procreasem": "procrea",
    "procreaseră": "procrea",
    "procreaserăm": "procrea",
    "procreaserăți": "procrea",
    "procreaseși": "procrea",
    "procreași": "procrea",
    "procreat": "procrea",
    "procreați": "procrea",
    "procreau": "procrea",
    "procree": "procrea",
    "procreează": "procrea",
    "procreem": "procrea",
    "procreez": "procrea",
    "procreeze": "procrea",
    "procreezi": "procrea",
    "procreind": "procrea",
    "procreindu": "procrea",
    "procrearea": "procreare",
    "procreări": "procreare",
    "procreării": "procreare",
    "procreările": "procreare",
    "procreărilor": "procreare",
    "procreată": "procreat",
    "procreate": "procreat",
    "procreați": "procreat",
    "procreația": "procreație",
    "procreației": "procreație",
    "procreații": "procreație",
    "procreațiile": "procreație",
    "procreațiilor": "procreație",
    "procreatoare": "procreator",
    "procreatoarea": "procreator",
    "procreatoarei": "procreator",
    "procreatoarele": "procreator",
    "procreatoarelor": "procreator",
    "procreatori": "procreator",
    "procreatorii": "procreator",
    "procreatorilor": "procreator",
    "procreatorul": "procreator",
    "procreatorului": "procreator",
    "nemaiprocurând": "procura",
    "nemaiprocurându": "procura",
    "neprocurând": "procura",
    "neprocurându": "procura",
    "neprocurat": "procura",
    "procur": "procura",
    "procură": "procura",
    "procurai": "procura",
    "procuram": "procura",
    "procurăm": "procura",
    "procurând": "procura",
    "procurându": "procura",
    "procurară": "procura",
    "procurarăm": "procura",
    "procurarăți": "procura",
    "procurase": "procura",
    "procurasem": "procura",
    "procuraseră": "procura",
    "procuraserăm": "procura",
    "procuraserăți": "procura",
    "procuraseși": "procura",
    "procurași": "procura",
    "procurat": "procura",
    "procurați": "procura",
    "procurau": "procura",
    "procure": "procura",
    "procuri": "procura",
    "procura": "procură",
    "procuri": "procură",
    "procurii": "procură",
    "procurile": "procură",
    "procurilor": "procură",
    "procurată": "procurat",
    "procurate": "procurat",
    "procurați": "procurat",
    "procuratori": "procurator",
    "procuratorii": "procurator",
    "procuratorilor": "procurator",
    "procuratorul": "procurator",
    "procuratorului": "procurator",
    "procuratura": "procuratură",
    "procuraturi": "procuratură",
    "procuraturii": "procuratură",
    "procuraturile": "procuratură",
    "procuraturilor": "procuratură",
    "procurori": "procuror",
    "procurorii": "procuror",
    "procurorilor": "procuror",
    "procurorul": "procuror",
    "procurorului": "procuror",
    "prodecani": "prodecan",
    "prodecanii": "prodecan",
    "prodecanilor": "prodecan",
    "prodecanul": "prodecan",
    "prodecanului": "prodecan",
    "prodigioasa": "prodigios",
    "prodigioasă": "prodigios",
    "prodigioase": "prodigios",
    "prodigioasei": "prodigios",
    "prodigioasele": "prodigios",
    "prodigioaselor": "prodigios",
    "prodigioși": "prodigios",
    "prodigioșii": "prodigios",
    "prodigioșilor": "prodigios",
    "prodigiosul": "prodigios",
    "prodigiosului": "prodigios",
    "producătoare": "producător",
    "producătoarea": "producător",
    "producătoarei": "producător",
    "producătoarele": "producător",
    "producătoarelor": "producător",
    "producători": "producător",
    "producătorii": "producător",
    "producătorilor": "producător",
    "producătorul": "producător",
    "producătorului": "producător",
    "produ": "produce",
    "produc": "produce",
    "producă": "produce",
    "producând": "produce",
    "producându": "produce",
    "producea": "produce",
    "produceai": "produce",
    "produceam": "produce",
    "produceați": "produce",
    "produceau": "produce",
    "producem": "produce",
    "produceți": "produce",
    "produci": "produce",
    "produs": "produce",
    "produse": "produce",
    "produsei": "produce",
    "produseră": "produce",
    "produserăm": "produce",
    "produserăți": "produce",
    "produsese": "produce",
    "produsesem": "produce",
    "produseseră": "produce",
    "produseserăm": "produce",
    "produseserăți": "produce",
    "produseseși": "produce",
    "produseși": "produce",
    "produsu": "produce",
    "producerea": "producere",
    "produceri": "producere",
    "producerii": "producere",
    "producerile": "producere",
    "producerilor": "producere",
    "producte": "product",
    "productele": "product",
    "productelor": "product",
    "productul": "product",
    "productului": "product",
    "productibila": "productibil",
    "productibilă": "productibil",
    "productibile": "productibil",
    "productibilei": "productibil",
    "productibilele": "productibil",
    "productibilelor": "productibil",
    "productibili": "productibil",
    "productibilii": "productibil",
    "productibililor": "productibil",
    "productibilul": "productibil",
    "productibilului": "productibil",
    "prod.": "producție",
    "producția": "producție",
    "producției": "producție",
    "producții": "producție",
    "producțiile": "producție",
    "producțiilor": "producție",
    "productiva": "productiv",
    "productivă": "productiv",
    "productive": "productiv",
    "productivei": "productiv",
    "productivele": "productiv",
    "productivelor": "productiv",
    "productivi": "productiv",
    "productivii": "productiv",
    "productivilor": "productiv",
    "productivul": "productiv",
    "productivului": "productiv",
    "productivitatea": "productivitate",
    "productivități": "productivitate",
    "productivității": "productivitate",
    "productivitățile": "productivitate",
    "productivităților": "productivitate",
    "produsă": "produs",
    "produse": "produs",
    "produsele": "produs",
    "produselor": "produs",
    "produși": "produs",
    "produsul": "produs",
    "produsului": "produs",
    "PIB": "produs_intern_brut",
    "prod.": "produse",
    "proeminenta": "proeminent",
    "proeminentă": "proeminent",
    "proeminente": "proeminent",
    "proeminentei": "proeminent",
    "proeminentele": "proeminent",
    "proeminentelor": "proeminent",
    "proeminenți": "proeminent",
    "proeminenții": "proeminent",
    "proeminenților": "proeminent",
    "proeminentul": "proeminent",
    "proeminentului": "proeminent",
    "proeminența": "proeminență",
    "proeminențe": "proeminență",
    "proeminenței": "proeminență",
    "proeminențele": "proeminență",
    "proeminențelor": "proeminență",
    "profana": "profan",
    "profană": "profan",
    "profane": "profan",
    "profanei": "profan",
    "profanele": "profan",
    "profanelor": "profan",
    "profani": "profan",
    "profanii": "profan",
    "profanilor": "profan",
    "profanul": "profan",
    "profanului": "profan",
    "nemaiprofanând": "profana",
    "nemaiprofanându": "profana",
    "neprofanând": "profana",
    "neprofanându": "profana",
    "profană": "profana",
    "profanai": "profana",
    "profanam": "profana",
    "profanăm": "profana",
    "profanând": "profana",
    "profanându": "profana",
    "profanară": "profana",
    "profanarăm": "profana",
    "profanarăți": "profana",
    "profanase": "profana",
    "profanasem": "profana",
    "profanaseră": "profana",
    "profanaserăm": "profana",
    "profanaserăți": "profana",
    "profanaseși": "profana",
    "profanași": "profana",
    "profanat": "profana",
    "profanați": "profana",
    "profanau": "profana",
    "profanează": "profana",
    "profanez": "profana",
    "profaneze": "profana",
    "profanezi": "profana",
    "profanată": "profanat",
    "profanate": "profanat",
    "profanați": "profanat",
    "profanatoare": "profanator",
    "profanatoarea": "profanator",
    "profanatoarei": "profanator",
    "profanatoarele": "profanator",
    "profanatoarelor": "profanator",
    "profanatori": "profanator",
    "profanatorii": "profanator",
    "profanatorilor": "profanator",
    "profanatorul": "profanator",
    "profanatorului": "profanator",
    "profascista": "profascist",
    "profascistă": "profascist",
    "profasciste": "profascist",
    "profascistei": "profascist",
    "profascistele": "profascist",
    "profascistelor": "profascist",
    "profasciști": "profascist",
    "profasciștii": "profascist",
    "profasciștilor": "profascist",
    "profascistul": "profascist",
    "profascistului": "profascist",
    "profeminista": "profeminist",
    "profeministă": "profeminist",
    "profeministe": "profeminist",
    "profeministei": "profeminist",
    "profeministele": "profeminist",
    "profeministelor": "profeminist",
    "profeminiști": "profeminist",
    "profeminiștii": "profeminist",
    "profeminiștilor": "profeminist",
    "profeministul": "profeminist",
    "profeministului": "profeminist",
    "nemaiproferând": "profera",
    "nemaiproferându": "profera",
    "neproferând": "profera",
    "neproferându": "profera",
    "proferă": "profera",
    "proferai": "profera",
    "proferam": "profera",
    "proferăm": "profera",
    "proferând": "profera",
    "proferându": "profera",
    "proferară": "profera",
    "proferarăm": "profera",
    "proferarăți": "profera",
    "proferase": "profera",
    "proferasem": "profera",
    "proferaseră": "profera",
    "proferaserăm": "profera",
    "proferaserăți": "profera",
    "proferaseși": "profera",
    "proferași": "profera",
    "proferat": "profera",
    "proferați": "profera",
    "proferau": "profera",
    "proferează": "profera",
    "proferez": "profera",
    "profereze": "profera",
    "proferezi": "profera",
    "proferată": "proferat",
    "proferate": "proferat",
    "proferați": "proferat",
    "nemaiprofesând": "profesa",
    "nemaiprofesându": "profesa",
    "neprofesând": "profesa",
    "neprofesându": "profesa",
    "profesă": "profesa",
    "profesai": "profesa",
    "profesam": "profesa",
    "profesăm": "profesa",
    "profesând": "profesa",
    "profesându": "profesa",
    "profesară": "profesa",
    "profesarăm": "profesa",
    "profesarăți": "profesa",
    "profesase": "profesa",
    "profesasem": "profesa",
    "profesaseră": "profesa",
    "profesaserăm": "profesa",
    "profesaserăți": "profesa",
    "profesaseși": "profesa",
    "profesași": "profesa",
    "profesat": "profesa",
    "profesați": "profesa",
    "profesau": "profesa",
    "profesează": "profesa",
    "profesez": "profesa",
    "profeseze": "profesa",
    "profesezi": "profesa",
    "profesată": "profesat",
    "profesate": "profesat",
    "profesați": "profesat",
    "profesia": "profesie",
    "profesiei": "profesie",
    "profesii": "profesie",
    "profesiile": "profesie",
    "profesiilor": "profesie",
    "profesionala": "profesional",
    "profesională": "profesional",
    "profesionale": "profesional",
    "profesionalei": "profesional",
    "profesionalele": "profesional",
    "profesionalelor": "profesional",
    "profesionali": "profesional",
    "profesionalii": "profesional",
    "profesionalilor": "profesional",
    "profesionalul": "profesional",
    "profesionalului": "profesional",
    "profesionalismul": "profesionalism",
    "profesionalismului": "profesionalism",
    "profesionismul": "profesionism",
    "profesionismului": "profesionism",
    "profesionista": "profesionist",
    "profesionistă": "profesionist",
    "profesioniste": "profesionist",
    "profesionistei": "profesionist",
    "profesionistele": "profesionist",
    "profesionistelor": "profesionist",
    "profesioniști": "profesionist",
    "profesioniștii": "profesionist",
    "profesioniștilor": "profesionist",
    "profesionistul": "profesionist",
    "profesionistului": "profesionist",
    "profesionista": "profesionistă",
    "profesioniste": "profesionistă",
    "profesionistei": "profesionistă",
    "profesionistele": "profesionistă",
    "profesionistelor": "profesionistă",
    "profesiunea": "profesiune",
    "profesiuni": "profesiune",
    "profesiunii": "profesiune",
    "profesiunile": "profesiune",
    "profesiunilor": "profesiune",
    "profesoara": "profesoară",
    "profesoare": "profesoară",
    "profesoarei": "profesoară",
    "profesoarele": "profesoară",
    "profesoarelor": "profesoară",
    "prof.": "profesor",
    "profesori": "profesor",
    "profesorii": "profesor",
    "profesorilor": "profesor",
    "profesorul": "profesor",
    "profesorului": "profesor",
    "profesorala": "profesoral",
    "profesorală": "profesoral",
    "profesorale": "profesoral",
    "profesoralei": "profesoral",
    "profesoralele": "profesoral",
    "profesoralelor": "profesoral",
    "profesorali": "profesoral",
    "profesoralii": "profesoral",
    "profesoralilor": "profesoral",
    "profesoralul": "profesoral",
    "profesoralului": "profesoral",
    "profeți": "profet",
    "profeții": "profet",
    "profeților": "profet",
    "profetul": "profet",
    "profetului": "profet",
    "profeta": "profetă",
    "profete": "profetă",
    "profetei": "profetă",
    "profetele": "profetă",
    "profetelor": "profetă",
    "nemaiprofețind": "profeți",
    "nemaiprofețindu": "profeți",
    "neprofețind": "profeți",
    "neprofețindu": "profeți",
    "profețea": "profeți",
    "profețeai": "profeți",
    "profețeam": "profeți",
    "profețească": "profeți",
    "profețeați": "profeți",
    "profețeau": "profeți",
    "profețesc": "profeți",
    "profețește": "profeți",
    "profețești": "profeți",
    "profeții": "profeți",
    "profețim": "profeți",
    "profețind": "profeți",
    "profețindu": "profeți",
    "profețiră": "profeți",
    "profețirăm": "profeți",
    "profețirăți": "profeți",
    "profețise": "profeți",
    "profețisem": "profeți",
    "profețiseră": "profeți",
    "profețiserăm": "profeți",
    "profețiserăți": "profeți",
    "profețiseși": "profeți",
    "profețiși": "profeți",
    "profețit": "profeți",
    "profețiți": "profeți",
    "profetica": "profetic",
    "profetică": "profetic",
    "profetice": "profetic",
    "profeticei": "profetic",
    "profeticele": "profetic",
    "profeticelor": "profetic",
    "profetici": "profetic",
    "profeticii": "profetic",
    "profeticilor": "profetic",
    "profeticul": "profetic",
    "profeticului": "profetic",
    "profeția": "profeție",
    "profeției": "profeție",
    "profeții": "profeție",
    "profețiile": "profeție",
    "profețiilor": "profeție",
    "profețită": "profețit",
    "profețite": "profețit",
    "profețiți": "profețit",
    "nemaiprofetizând": "profetiza",
    "nemaiprofetizându": "profetiza",
    "neprofetizând": "profetiza",
    "neprofetizându": "profetiza",
    "profetiză": "profetiza",
    "profetizai": "profetiza",
    "profetizam": "profetiza",
    "profetizăm": "profetiza",
    "profetizând": "profetiza",
    "profetizându": "profetiza",
    "profetizară": "profetiza",
    "profetizarăm": "profetiza",
    "profetizarăți": "profetiza",
    "profetizase": "profetiza",
    "profetizasem": "profetiza",
    "profetizaseră": "profetiza",
    "profetizaserăm": "profetiza",
    "profetizaserăți": "profetiza",
    "profetizaseși": "profetiza",
    "profetizași": "profetiza",
    "profetizat": "profetiza",
    "profetizați": "profetiza",
    "profetizau": "profetiza",
    "profetizează": "profetiza",
    "profetizez": "profetiza",
    "profetizeze": "profetiza",
    "profetizezi": "profetiza",
    "profetizată": "profetizat",
    "profetizate": "profetizat",
    "profetizați": "profetizat",
    "profile": "profil",
    "profilele": "profil",
    "profilelor": "profil",
    "profilul": "profil",
    "profilului": "profil",
    "profiluri": "profil",
    "profilurile": "profil",
    "nemaiprofilând": "profila",
    "nemaiprofilându": "profila",
    "neprofilând": "profila",
    "neprofilându": "profila",
    "profilă": "profila",
    "profilai": "profila",
    "profilam": "profila",
    "profilăm": "profila",
    "profilând": "profila",
    "profilându": "profila",
    "profilară": "profila",
    "profilarăm": "profila",
    "profilarăți": "profila",
    "profilase": "profila",
    "profilasem": "profila",
    "profilaseră": "profila",
    "profilaserăm": "profila",
    "profilaserăți": "profila",
    "profilaseși": "profila",
    "profilași": "profila",
    "profilat": "profila",
    "profilați": "profila",
    "profilau": "profila",
    "profilează": "profila",
    "profilez": "profila",
    "profileze": "profila",
    "profilezi": "profila",
    "profilactica": "profilactic",
    "profilactică": "profilactic",
    "profilactice": "profilactic",
    "profilacticei": "profilactic",
    "profilacticele": "profilactic",
    "profilacticelor": "profilactic",
    "profilactici": "profilactic",
    "profilacticii": "profilactic",
    "profilacticilor": "profilactic",
    "profilacticul": "profilactic",
    "profilacticului": "profilactic",
    "profilată": "profilat",
    "profilate": "profilat",
    "profilați": "profilat",
    "profilaxia": "profilaxie",
    "profilaxiei": "profilaxie",
    "profilaxii": "profilaxie",
    "profira": "profir",
    "profiră": "profir",
    "profire": "profir",
    "profirei": "profir",
    "profirele": "profir",
    "profirelor": "profir",
    "profiri": "profir",
    "profirii": "profir",
    "profirilor": "profir",
    "profirul": "profir",
    "profirului": "profir",
    "profiria": "profiriu",
    "profirie": "profiriu",
    "profiriei": "profiriu",
    "profirii": "profiriu",
    "profiriii": "profiriu",
    "profiriile": "profiriu",
    "profiriilor": "profiriu",
    "profiriul": "profiriu",
    "profiriului": "profiriu",
    "profitul": "profit",
    "profitului": "profit",
    "profituri": "profit",
    "profiturile": "profit",
    "profiturilor": "profit",
    "nemaiprofitând": "profita",
    "nemaiprofitându": "profita",
    "neprofitând": "profita",
    "neprofitându": "profita",
    "profit": "profita",
    "profită": "profita",
    "profitai": "profita",
    "profitam": "profita",
    "profităm": "profita",
    "profitând": "profita",
    "profitându": "profita",
    "profitară": "profita",
    "profitarăm": "profita",
    "profitarăți": "profita",
    "profitase": "profita",
    "profitasem": "profita",
    "profitaseră": "profita",
    "profitaserăm": "profita",
    "profitaserăți": "profita",
    "profitaseși": "profita",
    "profitași": "profita",
    "profitat": "profita",
    "profitați": "profita",
    "profitau": "profita",
    "profite": "profita",
    "profiți": "profita",
    "profitabila": "profitabil",
    "profitabilă": "profitabil",
    "profitabile": "profitabil",
    "profitabilei": "profitabil",
    "profitabilele": "profitabil",
    "profitabilelor": "profitabil",
    "profitabili": "profitabil",
    "profitabilii": "profitabil",
    "profitabililor": "profitabil",
    "profitabilul": "profitabil",
    "profitabilului": "profitabil",
    "profitată": "profitat",
    "profitate": "profitat",
    "profitați": "profitat",
    "profitoare": "profitor",
    "profitoarea": "profitor",
    "profitoarei": "profitor",
    "profitoarele": "profitor",
    "profitoarelor": "profitor",
    "profitori": "profitor",
    "profitorii": "profitor",
    "profitorilor": "profitor",
    "profitorul": "profitor",
    "profitorului": "profitor",
    "profunda": "profund",
    "profundă": "profund",
    "profunde": "profund",
    "profundei": "profund",
    "profundele": "profund",
    "profundelor": "profund",
    "profundul": "profund",
    "profundului": "profund",
    "profunzi": "profund",
    "profunzii": "profund",
    "profunzilor": "profund",
    "profunzimea": "profunzime",
    "profunzimi": "profunzime",
    "profunzimii": "profunzime",
    "profunzimile": "profunzime",
    "profunzimilor": "profunzime",
    "progenitura": "progenitură",
    "progenituri": "progenitură",
    "progeniturii": "progenitură",
    "progeniturile": "progenitură",
    "progeniturilor": "progenitură",
    "progesteronul": "progesteron",
    "progesteronului": "progesteron",
    "prognoza": "prognoză",
    "prognoze": "prognoză",
    "prognozei": "prognoză",
    "prognozele": "prognoză",
    "prognozelor": "prognoză",
    "programe": "program",
    "programele": "program",
    "programelor": "program",
    "programul": "program",
    "programului": "program",
    "nemaiprogramând": "programa",
    "nemaiprogramându": "programa",
    "neprogramând": "programa",
    "neprogramându": "programa",
    "programă": "programa",
    "programai": "programa",
    "programam": "programa",
    "programăm": "programa",
    "programând": "programa",
    "programându": "programa",
    "programară": "programa",
    "programarăm": "programa",
    "programarăți": "programa",
    "programase": "programa",
    "programasem": "programa",
    "programaseră": "programa",
    "programaserăm": "programa",
    "programaserăți": "programa",
    "programaseși": "programa",
    "programași": "programa",
    "programat": "programa",
    "programați": "programa",
    "programau": "programa",
    "programează": "programa",
    "programez": "programa",
    "programeze": "programa",
    "programezi": "programa",
    "programa": "programă",
    "programe": "programă",
    "programei": "programă",
    "programele": "programă",
    "programelor": "programă",
    "programarea": "programare",
    "programări": "programare",
    "programării": "programare",
    "programările": "programare",
    "programărilor": "programare",
    "programată": "programat",
    "programate": "programat",
    "programați": "programat",
    "programatica": "programatic",
    "programatică": "programatic",
    "programatice": "programatic",
    "programaticei": "programatic",
    "programaticele": "programatic",
    "programaticelor": "programatic",
    "programatici": "programatic",
    "programaticii": "programatic",
    "programaticilor": "programatic",
    "programaticul": "programatic",
    "programaticului": "programatic",
    "programatoare": "programator",
    "programatoarea": "programator",
    "programatoarei": "programator",
    "programatoarele": "programator",
    "programatoarelor": "programator",
    "programatori": "programator",
    "programatorii": "programator",
    "programatorilor": "programator",
    "programatorul": "programator",
    "programatorului": "programator",
    "progrese": "progres",
    "progresele": "progres",
    "progreselor": "progres",
    "progresul": "progres",
    "progresului": "progres",
    "nemaiprogresând": "progresa",
    "nemaiprogresându": "progresa",
    "neprogresând": "progresa",
    "neprogresându": "progresa",
    "progresă": "progresa",
    "progresai": "progresa",
    "progresam": "progresa",
    "progresăm": "progresa",
    "progresând": "progresa",
    "progresându": "progresa",
    "progresară": "progresa",
    "progresarăm": "progresa",
    "progresarăți": "progresa",
    "progresase": "progresa",
    "progresasem": "progresa",
    "progresaseră": "progresa",
    "progresaserăm": "progresa",
    "progresaserăți": "progresa",
    "progresaseși": "progresa",
    "progresași": "progresa",
    "progresat": "progresa",
    "progresați": "progresa",
    "progresau": "progresa",
    "progresează": "progresa",
    "progresez": "progresa",
    "progreseze": "progresa",
    "progresezi": "progresa",
    "progresată": "progresat",
    "progresate": "progresat",
    "progresați": "progresat",
    "progresia": "progresie",
    "progresiei": "progresie",
    "progresii": "progresie",
    "progresiile": "progresie",
    "progresiilor": "progresie",
    "progresista": "progresist",
    "progresistă": "progresist",
    "progresiste": "progresist",
    "progresistei": "progresist",
    "progresistele": "progresist",
    "progresistelor": "progresist",
    "progresiști": "progresist",
    "progresiștii": "progresist",
    "progresiștilor": "progresist",
    "progresistul": "progresist",
    "progresistului": "progresist",
    "progresiva": "progresiv",
    "progresivă": "progresiv",
    "progresive": "progresiv",
    "progresivei": "progresiv",
    "progresivele": "progresiv",
    "progresivelor": "progresiv",
    "progresivi": "progresiv",
    "progresivii": "progresiv",
    "progresivilor": "progresiv",
    "progresivul": "progresiv",
    "progresivului": "progresiv",
    "nemaiprohibind": "prohibi",
    "nemaiprohibindu": "prohibi",
    "neprohibind": "prohibi",
    "neprohibindu": "prohibi",
    "prohibea": "prohibi",
    "prohibeai": "prohibi",
    "prohibeam": "prohibi",
    "prohibească": "prohibi",
    "prohibeați": "prohibi",
    "prohibeau": "prohibi",
    "prohibesc": "prohibi",
    "prohibește": "prohibi",
    "prohibești": "prohibi",
    "prohibii": "prohibi",
    "prohibim": "prohibi",
    "prohibind": "prohibi",
    "prohibindu": "prohibi",
    "prohibiră": "prohibi",
    "prohibirăm": "prohibi",
    "prohibirăți": "prohibi",
    "prohibise": "prohibi",
    "prohibisem": "prohibi",
    "prohibiseră": "prohibi",
    "prohibiserăm": "prohibi",
    "prohibiserăți": "prohibi",
    "prohibiseși": "prohibi",
    "prohibiși": "prohibi",
    "prohibit": "prohibi",
    "prohibiți": "prohibi",
    "prohibită": "prohibit",
    "prohibite": "prohibit",
    "prohibiți": "prohibit",
    "prohibiția": "prohibiție",
    "prohibiției": "prohibiție",
    "prohibiții": "prohibiție",
    "prohibițiile": "prohibiție",
    "prohibițiilor": "prohibiție",
    "prohibiționista": "prohibiționist",
    "prohibiționistă": "prohibiționist",
    "prohibiționiste": "prohibiționist",
    "prohibiționistei": "prohibiționist",
    "prohibiționistele": "prohibiționist",
    "prohibiționistelor": "prohibiționist",
    "prohibiționiști": "prohibiționist",
    "prohibiționiștii": "prohibiționist",
    "prohibiționiștilor": "prohibiționist",
    "prohibiționistul": "prohibiționist",
    "prohibiționistului": "prohibiționist",
    "prohibitiva": "prohibitiv",
    "prohibitivă": "prohibitiv",
    "prohibitive": "prohibitiv",
    "prohibitivei": "prohibitiv",
    "prohibitivele": "prohibitiv",
    "prohibitivelor": "prohibitiv",
    "prohibitivi": "prohibitiv",
    "prohibitivii": "prohibitiv",
    "prohibitivilor": "prohibitiv",
    "prohibitivul": "prohibitiv",
    "prohibitivului": "prohibitiv",
    "prohibitoria": "prohibitoriu",
    "prohibitorie": "prohibitoriu",
    "prohibitoriei": "prohibitoriu",
    "prohibitorii": "prohibitoriu",
    "prohibitoriii": "prohibitoriu",
    "prohibitoriile": "prohibitoriu",
    "prohibitoriilor": "prohibitoriu",
    "prohibitoriul": "prohibitoriu",
    "prohibitoriului": "prohibitoriu",
    "prohodul": "prohod",
    "prohodului": "prohod",
    "prohoduri": "prohod",
    "prohodurile": "prohod",
    "prohodurilor": "prohod",
    "nemaiprohodind": "prohodi",
    "nemaiprohodindu": "prohodi",
    "neprohodind": "prohodi",
    "neprohodindu": "prohodi",
    "prohodea": "prohodi",
    "prohodeai": "prohodi",
    "prohodeam": "prohodi",
    "prohodească": "prohodi",
    "prohodeați": "prohodi",
    "prohodeau": "prohodi",
    "prohodesc": "prohodi",
    "prohodește": "prohodi",
    "prohodești": "prohodi",
    "prohodii": "prohodi",
    "prohodim": "prohodi",
    "prohodind": "prohodi",
    "prohodindu": "prohodi",
    "prohodiră": "prohodi",
    "prohodirăm": "prohodi",
    "prohodirăți": "prohodi",
    "prohodise": "prohodi",
    "prohodisem": "prohodi",
    "prohodiseră": "prohodi",
    "prohodiserăm": "prohodi",
    "prohodiserăți": "prohodi",
    "prohodiseși": "prohodi",
    "prohodiși": "prohodi",
    "prohodit": "prohodi",
    "prohodiți": "prohodi",
    "prohodită": "prohodit",
    "prohodite": "prohodit",
    "prohodiți": "prohodit",
    "proiecte": "proiect",
    "proiectele": "proiect",
    "proiectelor": "proiect",
    "proiectul": "proiect",
    "proiectului": "proiect",
    "nemaiproiectând": "proiecta",
    "nemaiproiectându": "proiecta",
    "neproiectând": "proiecta",
    "neproiectându": "proiecta",
    "proiectă": "proiecta",
    "proiectai": "proiecta",
    "proiectam": "proiecta",
    "proiectăm": "proiecta",
    "proiectând": "proiecta",
    "proiectându": "proiecta",
    "proiectară": "proiecta",
    "proiectarăm": "proiecta",
    "proiectarăți": "proiecta",
    "proiectase": "proiecta",
    "proiectasem": "proiecta",
    "proiectaseră": "proiecta",
    "proiectaserăm": "proiecta",
    "proiectaserăți": "proiecta",
    "proiectaseși": "proiecta",
    "proiectași": "proiecta",
    "proiectat": "proiecta",
    "proiectați": "proiecta",
    "proiectau": "proiecta",
    "proiectează": "proiecta",
    "proiectez": "proiecta",
    "proiecteze": "proiecta",
    "proiectezi": "proiecta",
    "proiectanta": "proiectant",
    "proiectantă": "proiectant",
    "proiectante": "proiectant",
    "proiectantei": "proiectant",
    "proiectantele": "proiectant",
    "proiectantelor": "proiectant",
    "proiectanți": "proiectant",
    "proiectanții": "proiectant",
    "proiectanților": "proiectant",
    "proiectantul": "proiectant",
    "proiectantului": "proiectant",
    "proiectarea": "proiectare",
    "proiectări": "proiectare",
    "proiectării": "proiectare",
    "proiectările": "proiectare",
    "proiectărilor": "proiectare",
    "proiectată": "proiectat",
    "proiectate": "proiectat",
    "proiectați": "proiectat",
    "proiecția": "proiecție",
    "proiecției": "proiecție",
    "proiecții": "proiecție",
    "proiecțiile": "proiecție",
    "proiecțiilor": "proiecție",
    "proiectile": "proiectil",
    "proiectilele": "proiectil",
    "proiectilelor": "proiectil",
    "proiectilul": "proiectil",
    "proiectilului": "proiectil",
    "proiectoare": "proiector",
    "proiectoarele": "proiector",
    "proiectoarelor": "proiector",
    "proiectorul": "proiector",
    "proiectorului": "proiector",
    "proli": "prol",
    "prolii": "prol",
    "prolilor": "prol",
    "prolul": "prol",
    "proletara": "proletar",
    "proletară": "proletar",
    "proletare": "proletar",
    "proletarei": "proletar",
    "proletarele": "proletar",
    "proletarelor": "proletar",
    "proletari": "proletar",
    "proletarii": "proletar",
    "proletarilor": "proletar",
    "proletarul": "proletar",
    "proletarului": "proletar",
    "proletariatul": "proletariat",
    "proletariatului": "proletariat",
    "nemaiproletarizând": "proletariza",
    "nemaiproletarizându": "proletariza",
    "neproletarizând": "proletariza",
    "neproletarizându": "proletariza",
    "proletariză": "proletariza",
    "proletarizai": "proletariza",
    "proletarizam": "proletariza",
    "proletarizăm": "proletariza",
    "proletarizând": "proletariza",
    "proletarizându": "proletariza",
    "proletarizară": "proletariza",
    "proletarizarăm": "proletariza",
    "proletarizarăți": "proletariza",
    "proletarizase": "proletariza",
    "proletarizasem": "proletariza",
    "proletarizaseră": "proletariza",
    "proletarizaserăm": "proletariza",
    "proletarizaserăți": "proletariza",
    "proletarizaseși": "proletariza",
    "proletarizași": "proletariza",
    "proletarizat": "proletariza",
    "proletarizați": "proletariza",
    "proletarizau": "proletariza",
    "proletarizează": "proletariza",
    "proletarizez": "proletariza",
    "proletarizeze": "proletariza",
    "proletarizezi": "proletariza",
    "proletarizată": "proletarizat",
    "proletarizate": "proletarizat",
    "proletarizați": "proletarizat",
    "nemaiproliferând": "prolifera",
    "nemaiproliferându": "prolifera",
    "neproliferând": "prolifera",
    "neproliferându": "prolifera",
    "proliferă": "prolifera",
    "proliferând": "prolifera",
    "proliferându": "prolifera",
    "proliferară": "prolifera",
    "proliferase": "prolifera",
    "proliferaseră": "prolifera",
    "proliferat": "prolifera",
    "proliferau": "prolifera",
    "proliferează": "prolifera",
    "prolifereze": "prolifera",
    "proliferarea": "proliferare",
    "proliferări": "proliferare",
    "proliferării": "proliferare",
    "proliferările": "proliferare",
    "proliferărilor": "proliferare",
    "proliferată": "proliferat",
    "proliferate": "proliferat",
    "proliferați": "proliferat",
    "prolifica": "prolific",
    "prolifică": "prolific",
    "prolifice": "prolific",
    "prolificei": "prolific",
    "prolificele": "prolific",
    "prolificelor": "prolific",
    "prolifici": "prolific",
    "prolificii": "prolific",
    "prolificilor": "prolific",
    "prolificul": "prolific",
    "prolificului": "prolific",
    "prologul": "prolog",
    "prologului": "prolog",
    "prologuri": "prolog",
    "prologurile": "prolog",
    "prologurilor": "prolog",
    "promenada": "promenadă",
    "promenade": "promenadă",
    "promenadei": "promenadă",
    "promenadele": "promenadă",
    "promenadelor": "promenadă",
    "prometeiana": "prometeian",
    "prometeiană": "prometeian",
    "prometeianul": "prometeian",
    "prometeianului": "prometeian",
    "prometeiene": "prometeian",
    "prometeienei": "prometeian",
    "prometeienele": "prometeian",
    "prometeienelor": "prometeian",
    "prometeieni": "prometeian",
    "prometeienii": "prometeian",
    "prometeienilor": "prometeian",
    "prometeica": "prometeic",
    "prometeică": "prometeic",
    "prometeice": "prometeic",
    "prometeicei": "prometeic",
    "prometeicele": "prometeic",
    "prometeicelor": "prometeic",
    "prometeici": "prometeic",
    "prometeicii": "prometeic",
    "prometeicilor": "prometeic",
    "prometeicul": "prometeic",
    "prometeicului": "prometeic",
    "Pm": "promețiu",
    "promisă": "promis",
    "promise": "promis",
    "promiși": "promis",
    "promiscuitatea": "promiscuitate",
    "promiscuități": "promiscuitate",
    "promiscuității": "promiscuitate",
    "promiscua": "promiscuu",
    "promiscuă": "promiscuu",
    "promiscue": "promiscuu",
    "promiscuei": "promiscuu",
    "promiscuele": "promiscuu",
    "promiscuelor": "promiscuu",
    "promiscui": "promiscuu",
    "promiscuii": "promiscuu",
    "promiscuilor": "promiscuu",
    "promiscuul": "promiscuu",
    "promiscuului": "promiscuu",
    "promisiunea": "promisiune",
    "promisiuni": "promisiune",
    "promisiunii": "promisiune",
    "promisiunile": "promisiune",
    "promisiunilor": "promisiune",
    "promisoria": "promisoriu",
    "promisorie": "promisoriu",
    "promisoriei": "promisoriu",
    "promisorii": "promisoriu",
    "promisoriii": "promisoriu",
    "promisoriile": "promisoriu",
    "promisoriilor": "promisoriu",
    "promisoriul": "promisoriu",
    "promisoriului": "promisoriu",
    "promițătoare": "promițător",
    "promițătoarea": "promițător",
    "promițătoarei": "promițător",
    "promițătoarele": "promițător",
    "promițătoarelor": "promițător",
    "promițători": "promițător",
    "promițătorii": "promițător",
    "promițătorilor": "promițător",
    "promițătorul": "promițător",
    "promițătorului": "promițător",
    "nemaipromițând": "promite",
    "nemaipromițându": "promite",
    "nepromițând": "promite",
    "nepromițându": "promite",
    "promis": "promite",
    "promise": "promite",
    "promisei": "promite",
    "promiseră": "promite",
    "promiserăm": "promite",
    "promiserăți": "promite",
    "promisese": "promite",
    "promisesem": "promite",
    "promiseseră": "promite",
    "promiseserăm": "promite",
    "promiseserăți": "promite",
    "promiseseși": "promite",
    "promiseși": "promite",
    "promit": "promite",
    "promită": "promite",
    "promițând": "promite",
    "promițându": "promite",
    "promitea": "promite",
    "promiteai": "promite",
    "promiteam": "promite",
    "promiteați": "promite",
    "promiteau": "promite",
    "promitem": "promite",
    "promiteți": "promite",
    "promiți": "promite",
    "promontorii": "promontoriu",
    "promontoriile": "promontoriu",
    "promontoriilor": "promontoriu",
    "promontoriul": "promontoriu",
    "promontoriului": "promontoriu",
    "promoroaca": "promoroacă",
    "promoroace": "promoroacă",
    "promoroacei": "promoroacă",
    "promoția": "promoție",
    "promoției": "promoție",
    "promoții": "promoție",
    "promoțiile": "promoție",
    "promoțiilor": "promoție",
    "promoționale": "promoțional",
    "promoționali": "promoțional",
    "promotori": "promotor",
    "promotorii": "promotor",
    "promotorilor": "promotor",
    "promotorul": "promotor",
    "promotorului": "promotor",
    "nemaipromovând": "promova",
    "nemaipromovându": "promova",
    "nepromovând": "promova",
    "nepromovându": "promova",
    "promovă": "promova",
    "promovai": "promova",
    "promovam": "promova",
    "promovăm": "promova",
    "promovând": "promova",
    "promovându": "promova",
    "promovară": "promova",
    "promovarăm": "promova",
    "promovarăți": "promova",
    "promovase": "promova",
    "promovasem": "promova",
    "promovaseră": "promova",
    "promovaserăm": "promova",
    "promovaserăți": "promova",
    "promovaseși": "promova",
    "promovași": "promova",
    "promovat": "promova",
    "promovați": "promova",
    "promovau": "promova",
    "promovează": "promova",
    "promovez": "promova",
    "promoveze": "promova",
    "promovezi": "promova",
    "promovarea": "promovare",
    "promovări": "promovare",
    "promovării": "promovare",
    "promovările": "promovare",
    "promovărilor": "promovare",
    "promovată": "promovat",
    "promovate": "promovat",
    "promovați": "promovat",
    "prompta": "prompt",
    "promptă": "prompt",
    "prompte": "prompt",
    "promptei": "prompt",
    "promptele": "prompt",
    "promptelor": "prompt",
    "prompți": "prompt",
    "prompții": "prompt",
    "prompților": "prompt",
    "promptul": "prompt",
    "promptului": "prompt",
    "promptitudinea": "promptitudine",
    "promptitudini": "promptitudine",
    "promptitudinii": "promptitudine",
    "nemaipromulgând": "promulga",
    "nemaipromulgându": "promulga",
    "nepromulgând": "promulga",
    "nepromulgându": "promulga",
    "promulg": "promulga",
    "promulgă": "promulga",
    "promulgai": "promulga",
    "promulgam": "promulga",
    "promulgăm": "promulga",
    "promulgând": "promulga",
    "promulgându": "promulga",
    "promulgară": "promulga",
    "promulgarăm": "promulga",
    "promulgarăți": "promulga",
    "promulgase": "promulga",
    "promulgasem": "promulga",
    "promulgaseră": "promulga",
    "promulgaserăm": "promulga",
    "promulgaserăți": "promulga",
    "promulgaseși": "promulga",
    "promulgași": "promulga",
    "promulgat": "promulga",
    "promulgați": "promulga",
    "promulgau": "promulga",
    "promulge": "promulga",
    "promulgi": "promulga",
    "promulgarea": "promulgare",
    "promulgări": "promulgare",
    "promulgării": "promulgare",
    "promulgările": "promulgare",
    "promulgărilor": "promulgare",
    "promulgată": "promulgat",
    "promulgate": "promulgat",
    "promulgați": "promulgat",
    "promulgatoare": "promulgator",
    "promulgatoarea": "promulgator",
    "promulgatoarei": "promulgator",
    "promulgatoarele": "promulgator",
    "promulgatoarelor": "promulgator",
    "promulgatori": "promulgator",
    "promulgatorii": "promulgator",
    "promulgatorilor": "promulgator",
    "promulgatorul": "promulgator",
    "promulgatorului": "promulgator",
    "pronaosul": "pronaos",
    "pronaosului": "pronaos",
    "pronaosuri": "pronaos",
    "pronaosurile": "pronaos",
    "pronaosurilor": "pronaos",
    "pronia": "pronie",
    "proniei": "pronie",
    "pronii": "pronie",
    "proniile": "pronie",
    "proniilor": "pronie",
    "pronominala": "pronominal",
    "pronominală": "pronominal",
    "pronominale": "pronominal",
    "pronominalei": "pronominal",
    "pronominalele": "pronominal",
    "pronominalelor": "pronominal",
    "pronominali": "pronominal",
    "pronominalii": "pronominal",
    "pronominalilor": "pronominal",
    "pronominalul": "pronominal",
    "pronominalului": "pronominal",
    "pronosticul": "pronostic",
    "pronosticului": "pronostic",
    "pronosticuri": "pronostic",
    "pronosticurile": "pronostic",
    "pronosticurilor": "pronostic",
    "nemaipronosticând": "pronostica",
    "nemaipronosticându": "pronostica",
    "nepronosticând": "pronostica",
    "nepronosticându": "pronostica",
    "pronostică": "pronostica",
    "pronosticai": "pronostica",
    "pronosticam": "pronostica",
    "pronosticăm": "pronostica",
    "pronosticând": "pronostica",
    "pronosticându": "pronostica",
    "pronosticară": "pronostica",
    "pronosticarăm": "pronostica",
    "pronosticarăți": "pronostica",
    "pronosticase": "pronostica",
    "pronosticasem": "pronostica",
    "pronosticaseră": "pronostica",
    "pronosticaserăm": "pronostica",
    "pronosticaserăți": "pronostica",
    "pronosticaseși": "pronostica",
    "pronosticași": "pronostica",
    "pronosticat": "pronostica",
    "pronosticați": "pronostica",
    "pronosticau": "pronostica",
    "pronostichează": "pronostica",
    "pronostichez": "pronostica",
    "pronosticheze": "pronostica",
    "pronostichezi": "pronostica",
    "pronosticată": "pronosticat",
    "pronosticate": "pronosticat",
    "pronosticați": "pronosticat",
    "pr.": "pronume",
    "pronumele": "pronume",
    "pronumelor": "pronume",
    "pronumelui": "pronume",
    "nemaipronunțând": "pronunța",
    "nemaipronunțându": "pronunța",
    "nepronunțând": "pronunța",
    "nepronunțându": "pronunța",
    "pronunț": "pronunța",
    "pronunță": "pronunța",
    "pronunțai": "pronunța",
    "pronunțam": "pronunța",
    "pronunțăm": "pronunța",
    "pronunțând": "pronunța",
    "pronunțându": "pronunța",
    "pronunțară": "pronunța",
    "pronunțarăm": "pronunța",
    "pronunțarăți": "pronunța",
    "pronunțase": "pronunța",
    "pronunțasem": "pronunța",
    "pronunțaseră": "pronunța",
    "pronunțaserăm": "pronunța",
    "pronunțaserăți": "pronunța",
    "pronunțaseși": "pronunța",
    "pronunțași": "pronunța",
    "pronunțat": "pronunța",
    "pronunțați": "pronunța",
    "pronunțau": "pronunța",
    "pronunțe": "pronunța",
    "pronunți": "pronunța",
    "pronunțarea": "pronunțare",
    "pronunțări": "pronunțare",
    "pronunțării": "pronunțare",
    "pronunțată": "pronunțat",
    "pronunțate": "pronunțat",
    "pronunțați": "pronunțat",
    "pronunția": "pronunție",
    "pronunției": "pronunție",
    "pronunții": "pronunție",
    "pronunțiile": "pronunție",
    "pronunțiilor": "pronunție",
    "prooccidentală": "prooccidental",
    "nemaipropagând": "propaga",
    "nemaipropagându": "propaga",
    "nepropagând": "propaga",
    "nepropagându": "propaga",
    "propag": "propaga",
    "propagă": "propaga",
    "propagai": "propaga",
    "propagam": "propaga",
    "propagăm": "propaga",
    "propagând": "propaga",
    "propagându": "propaga",
    "propagară": "propaga",
    "propagarăm": "propaga",
    "propagarăți": "propaga",
    "propagase": "propaga",
    "propagasem": "propaga",
    "propagaseră": "propaga",
    "propagaserăm": "propaga",
    "propagaserăți": "propaga",
    "propagaseși": "propaga",
    "propagași": "propaga",
    "propagat": "propaga",
    "propagați": "propaga",
    "propagau": "propaga",
    "propage": "propaga",
    "propagi": "propaga",
    "propaganda": "propagandă",
    "propagande": "propagandă",
    "propagandei": "propagandă",
    "propagandele": "propagandă",
    "propagandelor": "propagandă",
    "propagandistica": "propagandistic",
    "propagandistică": "propagandistic",
    "propagandistice": "propagandistic",
    "propagandisticei": "propagandistic",
    "propagandisticele": "propagandistic",
    "propagandisticelor": "propagandistic",
    "propagandistici": "propagandistic",
    "propagandisticii": "propagandistic",
    "propagandisticilor": "propagandistic",
    "propagandisticul": "propagandistic",
    "propagandisticului": "propagandistic",
    "propagată": "propagat",
    "propagate": "propagat",
    "propagați": "propagat",
    "propagatoare": "propagator",
    "propagatoarea": "propagator",
    "propagatoarei": "propagator",
    "propagatoarele": "propagator",
    "propagatoarelor": "propagator",
    "propagatori": "propagator",
    "propagatorii": "propagator",
    "propagatorilor": "propagator",
    "propagatorul": "propagator",
    "propagatorului": "propagator",
    "propanul": "propan",
    "propanului": "propan",
    "nemaipropășind": "propăși",
    "nemaipropășindu": "propăși",
    "nepropășind": "propăși",
    "nepropășindu": "propăși",
    "propășea": "propăși",
    "propășeai": "propăși",
    "propășeam": "propăși",
    "propășească": "propăși",
    "propășeați": "propăși",
    "propășeau": "propăși",
    "propășesc": "propăși",
    "propășește": "propăși",
    "propășești": "propăși",
    "propășii": "propăși",
    "propășim": "propăși",
    "propășind": "propăși",
    "propășindu": "propăși",
    "propășiră": "propăși",
    "propășirăm": "propăși",
    "propășirăți": "propăși",
    "propășise": "propăși",
    "propășisem": "propăși",
    "propășiseră": "propăși",
    "propășiserăm": "propăși",
    "propășiserăți": "propăși",
    "propășiseși": "propăși",
    "propășiși": "propăși",
    "propășit": "propăși",
    "propășiți": "propăși",
    "propășirea": "propășire",
    "propășiri": "propășire",
    "propășirii": "propășire",
    "propășirile": "propășire",
    "propășirilor": "propășire",
    "propășită": "propășit",
    "propășite": "propășit",
    "propășiți": "propășit",
    "propășitoare": "propășitor",
    "propășitoarea": "propășitor",
    "propășitoarei": "propășitor",
    "propășitoarele": "propășitor",
    "propășitoarelor": "propășitor",
    "propășitori": "propășitor",
    "propășitorii": "propășitor",
    "propășitorilor": "propășitor",
    "propășitorul": "propășitor",
    "propășitorului": "propășitor",
    "propileele": "propilee",
    "propileelor": "propilee",
    "propionica": "propionic",
    "propionică": "propionic",
    "propionice": "propionic",
    "propionicei": "propionic",
    "propionicele": "propionic",
    "propionicelor": "propionic",
    "propionici": "propionic",
    "propionicii": "propionic",
    "propionicilor": "propionic",
    "propionicul": "propionic",
    "propionicului": "propionic",
    "proporția": "proporție",
    "proporției": "proporție",
    "proporții": "proporție",
    "proporțiile": "proporție",
    "proporțiilor": "proporție",
    "nemaiproporționând": "proporționa",
    "nemaiproporționându": "proporționa",
    "neproporționând": "proporționa",
    "neproporționându": "proporționa",
    "proporționă": "proporționa",
    "proporționai": "proporționa",
    "proporționam": "proporționa",
    "proporționăm": "proporționa",
    "proporționând": "proporționa",
    "proporționându": "proporționa",
    "proporționară": "proporționa",
    "proporționarăm": "proporționa",
    "proporționarăți": "proporționa",
    "proporționase": "proporționa",
    "proporționasem": "proporționa",
    "proporționaseră": "proporționa",
    "proporționaserăm": "proporționa",
    "proporționaserăți": "proporționa",
    "proporționaseși": "proporționa",
    "proporționași": "proporționa",
    "proporționat": "proporționa",
    "proporționați": "proporționa",
    "proporționau": "proporționa",
    "proporționează": "proporționa",
    "proporționez": "proporționa",
    "proporționeze": "proporționa",
    "proporționezi": "proporționa",
    "proporționala": "proporțional",
    "proporțională": "proporțional",
    "proporționale": "proporțional",
    "proporționalei": "proporțional",
    "proporționalele": "proporțional",
    "proporționalelor": "proporțional",
    "proporționali": "proporțional",
    "proporționalii": "proporțional",
    "proporționalilor": "proporțional",
    "proporționalul": "proporțional",
    "proporționalului": "proporțional",
    "proporționalitatea": "proporționalitate",
    "proporționalități": "proporționalitate",
    "proporționalității": "proporționalitate",
    "proporționalitățile": "proporționalitate",
    "proporționalităților": "proporționalitate",
    "proporționată": "proporționat",
    "proporționate": "proporționat",
    "proporționați": "proporționat",
    "nemaipropovăduind": "propovădui",
    "nemaipropovăduindu": "propovădui",
    "nepropovăduind": "propovădui",
    "nepropovăduindu": "propovădui",
    "propovăduia": "propovădui",
    "propovăduiai": "propovădui",
    "propovăduiam": "propovădui",
    "propovăduiască": "propovădui",
    "propovăduiați": "propovădui",
    "propovăduiau": "propovădui",
    "propovăduiesc": "propovădui",
    "propovăduiește": "propovădui",
    "propovăduiești": "propovădui",
    "propovăduii": "propovădui",
    "propovăduim": "propovădui",
    "propovăduind": "propovădui",
    "propovăduindu": "propovădui",
    "propovăduiră": "propovădui",
    "propovăduirăm": "propovădui",
    "propovăduirăți": "propovădui",
    "propovăduise": "propovădui",
    "propovăduisem": "propovădui",
    "propovăduiseră": "propovădui",
    "propovăduiserăm": "propovădui",
    "propovăduiserăți": "propovădui",
    "propovăduiseși": "propovădui",
    "propovăduiși": "propovădui",
    "propovăduit": "propovădui",
    "propovăduiți": "propovădui",
    "propovăduirea": "propovăduire",
    "propovăduiri": "propovăduire",
    "propovăduirii": "propovăduire",
    "propovăduită": "propovăduit",
    "propovăduite": "propovăduit",
    "propovăduiți": "propovăduit",
    "propovăduitori": "propovăduitor",
    "propovăduitorii": "propovăduitor",
    "propovăduitorilor": "propovăduitor",
    "propovăduitorul": "propovăduitor",
    "propovăduitorului": "propovăduitor",
    "propoziția": "propoziție",
    "propoziției": "propoziție",
    "propoziții": "propoziție",
    "propozițiile": "propoziție",
    "propozițiilor": "propoziție",
    "proprietari": "proprietar",
    "proprietarii": "proprietar",
    "proprietarilor": "proprietar",
    "proprietarul": "proprietar",
    "proprietarului": "proprietar",
    "proprietăreasca": "proprietăresc",
    "proprietărească": "proprietăresc",
    "proprietărescul": "proprietăresc",
    "proprietărescului": "proprietăresc",
    "proprietărești": "proprietăresc",
    "proprietăreștii": "proprietăresc",
    "proprietăreștile": "proprietăresc",
    "proprietăreștilor": "proprietăresc",
    "proprietatea": "proprietate",
    "proprietăți": "proprietate",
    "proprietății": "proprietate",
    "proprietățile": "proprietate",
    "proprietăților": "proprietate",
    "propria": "propriu",
    "proprie": "propriu",
    "propriei": "propriu",
    "proprii": "propriu",
    "propriii": "propriu",
    "propriile": "propriu",
    "propriilor": "propriu",
    "propriul": "propriu",
    "propriului": "propriu",
    "propriu-zisă": "propriu-zis",
    "propriu-zise": "propriu-zis",
    "propriu-ziși": "propriu-zis",
    "propteaua": "proptea",
    "proptele": "proptea",
    "proptelei": "proptea",
    "proptelele": "proptea",
    "proptelelor": "proptea",
    "nemaiproptind": "propti",
    "nemaiproptindu": "propti",
    "neproptind": "propti",
    "neproptindu": "propti",
    "proptea": "propti",
    "propteai": "propti",
    "propteam": "propti",
    "proptească": "propti",
    "propteați": "propti",
    "propteau": "propti",
    "proptesc": "propti",
    "proptește": "propti",
    "proptești": "propti",
    "proptii": "propti",
    "proptim": "propti",
    "proptind": "propti",
    "proptindu": "propti",
    "proptiră": "propti",
    "proptirăm": "propti",
    "proptirăți": "propti",
    "proptise": "propti",
    "proptisem": "propti",
    "proptiseră": "propti",
    "proptiserăm": "propti",
    "proptiserăți": "propti",
    "proptiseși": "propti",
    "proptiși": "propti",
    "proptit": "propti",
    "proptiți": "propti",
    "proptită": "proptit",
    "proptite": "proptit",
    "proptiți": "proptit",
    "proptitoare": "proptitor",
    "proptitoarea": "proptitor",
    "proptitoarei": "proptitor",
    "proptitoarele": "proptitor",
    "proptitoarelor": "proptitor",
    "proptitori": "proptitor",
    "proptitorii": "proptitor",
    "proptitorilor": "proptitor",
    "proptitorul": "proptitor",
    "proptitorului": "proptitor",
    "nemaipropulsând": "propulsa",
    "nemaipropulsându": "propulsa",
    "nepropulsând": "propulsa",
    "nepropulsându": "propulsa",
    "propulsă": "propulsa",
    "propulsai": "propulsa",
    "propulsam": "propulsa",
    "propulsăm": "propulsa",
    "propulsând": "propulsa",
    "propulsându": "propulsa",
    "propulsară": "propulsa",
    "propulsarăm": "propulsa",
    "propulsarăți": "propulsa",
    "propulsase": "propulsa",
    "propulsasem": "propulsa",
    "propulsaseră": "propulsa",
    "propulsaserăm": "propulsa",
    "propulsaserăți": "propulsa",
    "propulsaseși": "propulsa",
    "propulsași": "propulsa",
    "propulsat": "propulsa",
    "propulsați": "propulsa",
    "propulsau": "propulsa",
    "propulsează": "propulsa",
    "propulsez": "propulsa",
    "propulseze": "propulsa",
    "propulsezi": "propulsa",
    "propulsată": "propulsat",
    "propulsate": "propulsat",
    "propulsați": "propulsat",
    "propulsia": "propulsie",
    "propulsiei": "propulsie",
    "propulsii": "propulsie",
    "propulsiile": "propulsie",
    "propulsiilor": "propulsie",
    "propulsiva": "propulsiv",
    "propulsivă": "propulsiv",
    "propulsive": "propulsiv",
    "propulsivei": "propulsiv",
    "propulsivele": "propulsiv",
    "propulsivelor": "propulsiv",
    "propulsivi": "propulsiv",
    "propulsivii": "propulsiv",
    "propulsivilor": "propulsiv",
    "propulsivul": "propulsiv",
    "propulsivului": "propulsiv",
    "propunătoare": "propunător",
    "propunătoarea": "propunător",
    "propunătoarei": "propunător",
    "propunătoarele": "propunător",
    "propunătoarelor": "propunător",
    "propunători": "propunător",
    "propunătorii": "propunător",
    "propunătorilor": "propunător",
    "propunătorul": "propunător",
    "propunătorului": "propunător",
    "nemaipropunând": "propune",
    "nemaipropunându": "propune",
    "nepropunând": "propune",
    "nepropunându": "propune",
    "propui": "propune",
    "propun": "propune",
    "propună": "propune",
    "propunând": "propune",
    "propunându": "propune",
    "propunea": "propune",
    "propuneai": "propune",
    "propuneam": "propune",
    "propuneați": "propune",
    "propuneau": "propune",
    "propunem": "propune",
    "propuneți": "propune",
    "propus": "propune",
    "propuse": "propune",
    "propusei": "propune",
    "propuseră": "propune",
    "propuserăm": "propune",
    "propuserăți": "propune",
    "propusese": "propune",
    "propusesem": "propune",
    "propuseseră": "propune",
    "propuseserăm": "propune",
    "propuseserăți": "propune",
    "propuseseși": "propune",
    "propuseși": "propune",
    "propunerea": "propunere",
    "propuneri": "propunere",
    "propunerii": "propunere",
    "propunerile": "propunere",
    "propunerilor": "propunere",
    "propusa": "propus",
    "propusă": "propus",
    "propuse": "propus",
    "propusei": "propus",
    "propusele": "propus",
    "propuselor": "propus",
    "propuși": "propus",
    "propușii": "propus",
    "propușilor": "propus",
    "propusul": "propus",
    "propusului": "propus",
    "prora": "proră",
    "prore": "proră",
    "prorei": "proră",
    "prorele": "proră",
    "prorelor": "proră",
    "prorectori": "prorector",
    "prorectorii": "prorector",
    "prorectorilor": "prorector",
    "prorectorul": "prorector",
    "prorectorului": "prorector",
    "proroci": "proroc",
    "prorocii": "proroc",
    "prorocilor": "proroc",
    "prorocul": "proroc",
    "prorocului": "proroc",
    "proroceasca": "prorocesc",
    "prorocească": "prorocesc",
    "prorocescul": "prorocesc",
    "prorocescului": "prorocesc",
    "prorocești": "prorocesc",
    "proroceștii": "prorocesc",
    "proroceștile": "prorocesc",
    "proroceștilor": "prorocesc",
    "nemaiprorocind": "proroci",
    "nemaiprorocindu": "proroci",
    "neprorocind": "proroci",
    "neprorocindu": "proroci",
    "prorocea": "proroci",
    "proroceai": "proroci",
    "proroceam": "proroci",
    "prorocească": "proroci",
    "proroceați": "proroci",
    "proroceau": "proroci",
    "prorocesc": "proroci",
    "prorocește": "proroci",
    "prorocești": "proroci",
    "prorocii": "proroci",
    "prorocim": "proroci",
    "prorocind": "proroci",
    "prorocindu": "proroci",
    "prorociră": "proroci",
    "prorocirăm": "proroci",
    "prorocirăți": "proroci",
    "prorocise": "proroci",
    "prorocisem": "proroci",
    "prorociseră": "proroci",
    "prorociserăm": "proroci",
    "prorociserăți": "proroci",
    "prorociseși": "proroci",
    "prorociși": "proroci",
    "prorocit": "proroci",
    "prorociți": "proroci",
    "prorocia": "prorocie",
    "prorociei": "prorocie",
    "prorocii": "prorocie",
    "prorociile": "prorocie",
    "prorociilor": "prorocie",
    "prorocirea": "prorocire",
    "prorociri": "prorocire",
    "prorocirii": "prorocire",
    "prorocirile": "prorocire",
    "prorocirilor": "prorocire",
    "prorocită": "prorocit",
    "prorocite": "prorocit",
    "prorociți": "prorocit",
    "prorocitoare": "prorocitor",
    "prorocitoarea": "prorocitor",
    "prorocitoarei": "prorocitor",
    "prorocitoarele": "prorocitor",
    "prorocitoarelor": "prorocitor",
    "prorocitori": "prorocitor",
    "prorocitorii": "prorocitor",
    "prorocitorilor": "prorocitor",
    "prorocitorul": "prorocitor",
    "prorocitorului": "prorocitor",
    "proscomidia": "proscomidie",
    "proscomidiei": "proscomidie",
    "proscomidii": "proscomidie",
    "proscomidiile": "proscomidie",
    "proscomidiilor": "proscomidie",
    "nemaiproscriind": "proscrie",
    "nemaiproscriindu": "proscrie",
    "neproscriind": "proscrie",
    "neproscriindu": "proscrie",
    "proscria": "proscrie",
    "proscriai": "proscrie",
    "proscriam": "proscrie",
    "proscriați": "proscrie",
    "proscriau": "proscrie",
    "proscriem": "proscrie",
    "proscrieți": "proscrie",
    "proscrii": "proscrie",
    "proscriind": "proscrie",
    "proscriindu": "proscrie",
    "proscris": "proscrie",
    "proscrise": "proscrie",
    "proscrisei": "proscrie",
    "proscriseră": "proscrie",
    "proscriserăm": "proscrie",
    "proscriserăți": "proscrie",
    "proscrisese": "proscrie",
    "proscrisesem": "proscrie",
    "proscriseseră": "proscrie",
    "proscriseserăm": "proscrie",
    "proscriseserăți": "proscrie",
    "proscriseseși": "proscrie",
    "proscriseși": "proscrie",
    "proscriu": "proscrie",
    "proscripția": "proscripție",
    "proscripției": "proscripție",
    "proscripții": "proscripție",
    "proscripțiile": "proscripție",
    "proscripțiilor": "proscripție",
    "proscrisa": "proscris",
    "proscrisă": "proscris",
    "proscrise": "proscris",
    "proscrisei": "proscris",
    "proscrisele": "proscris",
    "proscriselor": "proscris",
    "proscriși": "proscris",
    "proscrișii": "proscris",
    "proscrișilor": "proscris",
    "proscrisul": "proscris",
    "proscrisului": "proscris",
    "nemaiproslăvind": "proslăvi",
    "nemaiproslăvindu": "proslăvi",
    "neproslăvind": "proslăvi",
    "neproslăvindu": "proslăvi",
    "proslăvea": "proslăvi",
    "proslăveai": "proslăvi",
    "proslăveam": "proslăvi",
    "proslăvească": "proslăvi",
    "proslăveați": "proslăvi",
    "proslăveau": "proslăvi",
    "proslăvesc": "proslăvi",
    "proslăvește": "proslăvi",
    "proslăvești": "proslăvi",
    "proslăvii": "proslăvi",
    "proslăvim": "proslăvi",
    "proslăvind": "proslăvi",
    "proslăvindu": "proslăvi",
    "proslăviră": "proslăvi",
    "proslăvirăm": "proslăvi",
    "proslăvirăți": "proslăvi",
    "proslăvise": "proslăvi",
    "proslăvisem": "proslăvi",
    "proslăviseră": "proslăvi",
    "proslăviserăm": "proslăvi",
    "proslăviserăți": "proslăvi",
    "proslăviseși": "proslăvi",
    "proslăviși": "proslăvi",
    "proslăvit": "proslăvi",
    "proslăviți": "proslăvi",
    "proslăvită": "proslăvit",
    "proslăvite": "proslăvit",
    "proslăviți": "proslăvit",
    "proslăvitoarea": "proslăvitoare",
    "proslăvitoarei": "proslăvitoare",
    "proslăvitoarele": "proslăvitoare",
    "proslăvitoarelor": "proslăvitoare",
    "proslăvitori": "proslăvitor",
    "proslăvitorii": "proslăvitor",
    "proslăvitorilor": "proslăvitor",
    "proslăvitorul": "proslăvitor",
    "proslăvitorului": "proslăvitor",
    "prosoape": "prosop",
    "prosoapele": "prosop",
    "prosoapelor": "prosop",
    "prosopul": "prosop",
    "prosopului": "prosop",
    "prospecte": "prospect",
    "prospectele": "prospect",
    "prospectelor": "prospect",
    "prospectul": "prospect",
    "prospectului": "prospect",
    "nemaiprospectând": "prospecta",
    "nemaiprospectându": "prospecta",
    "neprospectând": "prospecta",
    "neprospectându": "prospecta",
    "prospectă": "prospecta",
    "prospectai": "prospecta",
    "prospectam": "prospecta",
    "prospectăm": "prospecta",
    "prospectând": "prospecta",
    "prospectându": "prospecta",
    "prospectară": "prospecta",
    "prospectarăm": "prospecta",
    "prospectarăți": "prospecta",
    "prospectase": "prospecta",
    "prospectasem": "prospecta",
    "prospectaseră": "prospecta",
    "prospectaserăm": "prospecta",
    "prospectaserăți": "prospecta",
    "prospectaseși": "prospecta",
    "prospectași": "prospecta",
    "prospectat": "prospecta",
    "prospectați": "prospecta",
    "prospectau": "prospecta",
    "prospectează": "prospecta",
    "prospectez": "prospecta",
    "prospecteze": "prospecta",
    "prospectezi": "prospecta",
    "prospectată": "prospectat",
    "prospectate": "prospectat",
    "prospectați": "prospectat",
    "prospecțiunea": "prospecțiune",
    "prospecțiuni": "prospecțiune",
    "prospecțiunii": "prospecțiune",
    "prospecțiunile": "prospecțiune",
    "prospecțiunilor": "prospecțiune",
    "prospectiva": "prospectivă",
    "prospective": "prospectivă",
    "prospectivei": "prospectivă",
    "prospectivele": "prospectivă",
    "prospectivelor": "prospectivă",
    "prospera": "prosper",
    "prosperă": "prosper",
    "prospere": "prosper",
    "prosperei": "prosper",
    "prosperele": "prosper",
    "prosperelor": "prosper",
    "prosperi": "prosper",
    "prosperii": "prosper",
    "prosperilor": "prosper",
    "prosperul": "prosper",
    "prosperului": "prosper",
    "nemaiprosperând": "prospera",
    "nemaiprosperându": "prospera",
    "neprosperând": "prospera",
    "neprosperându": "prospera",
    "prosper": "prospera",
    "prosperă": "prospera",
    "prosperai": "prospera",
    "prosperam": "prospera",
    "prosperăm": "prospera",
    "prosperând": "prospera",
    "prosperându": "prospera",
    "prosperară": "prospera",
    "prosperarăm": "prospera",
    "prosperarăți": "prospera",
    "prosperase": "prospera",
    "prosperasem": "prospera",
    "prosperaseră": "prospera",
    "prosperaserăm": "prospera",
    "prosperaserăți": "prospera",
    "prosperaseși": "prospera",
    "prosperași": "prospera",
    "prosperat": "prospera",
    "prosperați": "prospera",
    "prosperau": "prospera",
    "prospere": "prospera",
    "prosperi": "prospera",
    "prosperată": "prosperat",
    "prosperate": "prosperat",
    "prosperați": "prosperat",
    "prosperitatea": "prosperitate",
    "prosperități": "prosperitate",
    "prosperității": "prosperitate",
    "prospețimea": "prospețime",
    "prospețimi": "prospețime",
    "prospețimii": "prospețime",
    "proasta": "prost",
    "proastă": "prost",
    "proaste": "prost",
    "proastei": "prost",
    "proastele": "prost",
    "proastelor": "prost",
    "proști": "prost",
    "proștii": "prost",
    "proștilor": "prost",
    "prostul": "prost",
    "prostului": "prost",
    "prostana": "prostan",
    "prostană": "prostan",
    "prostane": "prostan",
    "prostanei": "prostan",
    "prostanele": "prostan",
    "prostanelor": "prostan",
    "prostani": "prostan",
    "prostanii": "prostan",
    "prostanilor": "prostan",
    "prostanul": "prostan",
    "prostanului": "prostan",
    "prostănaca": "prostănac",
    "prostănacă": "prostănac",
    "prostănace": "prostănac",
    "prostănacei": "prostănac",
    "prostănacele": "prostănac",
    "prostănacelor": "prostănac",
    "prostănaci": "prostănac",
    "prostănacii": "prostănac",
    "prostănacilor": "prostănac",
    "prostănacul": "prostănac",
    "prostănacului": "prostănac",
    "prostata": "prostată",
    "prostate": "prostată",
    "prostatei": "prostată",
    "prostatele": "prostată",
    "prostatelor": "prostată",
    "prostatica": "prostatic",
    "prostatică": "prostatic",
    "prostatice": "prostatic",
    "prostaticei": "prostatic",
    "prostaticele": "prostatic",
    "prostaticelor": "prostatic",
    "prostatici": "prostatic",
    "prostaticii": "prostatic",
    "prostaticilor": "prostatic",
    "prostaticul": "prostatic",
    "prostaticului": "prostatic",
    "nemaiprosternând": "prosterna",
    "nemaiprosternându": "prosterna",
    "neprosternând": "prosterna",
    "neprosternându": "prosterna",
    "prostern": "prosterna",
    "prosternă": "prosterna",
    "prosternai": "prosterna",
    "prosternam": "prosterna",
    "prosternăm": "prosterna",
    "prosternând": "prosterna",
    "prosternându": "prosterna",
    "prosternară": "prosterna",
    "prosternarăm": "prosterna",
    "prosternarăți": "prosterna",
    "prosternase": "prosterna",
    "prosternasem": "prosterna",
    "prosternaseră": "prosterna",
    "prosternaserăm": "prosterna",
    "prosternaserăți": "prosterna",
    "prosternaseși": "prosterna",
    "prosternași": "prosterna",
    "prosternat": "prosterna",
    "prosternați": "prosterna",
    "prosternau": "prosterna",
    "prosterne": "prosterna",
    "prosterni": "prosterna",
    "prosternată": "prosternat",
    "prosternate": "prosternat",
    "prosternați": "prosternat",
    "prosteasca": "prostesc",
    "prostească": "prostesc",
    "prostescul": "prostesc",
    "prostescului": "prostesc",
    "prostești": "prostesc",
    "prosteștii": "prostesc",
    "prosteștile": "prostesc",
    "prosteștilor": "prostesc",
    "nemaiprostind": "prosti",
    "nemaiprostindu": "prosti",
    "neprostind": "prosti",
    "neprostindu": "prosti",
    "prostea": "prosti",
    "prosteai": "prosti",
    "prosteam": "prosti",
    "prostească": "prosti",
    "prosteați": "prosti",
    "prosteau": "prosti",
    "prostesc": "prosti",
    "prostește": "prosti",
    "prostești": "prosti",
    "prostii": "prosti",
    "prostim": "prosti",
    "prostind": "prosti",
    "prostindu": "prosti",
    "prostiră": "prosti",
    "prostirăm": "prosti",
    "prostirăți": "prosti",
    "prostise": "prosti",
    "prostisem": "prosti",
    "prostiseră": "prosti",
    "prostiserăm": "prosti",
    "prostiserăți": "prosti",
    "prostiseși": "prosti",
    "prostiși": "prosti",
    "prostit": "prosti",
    "prostiți": "prosti",
    "prostia": "prostie",
    "prostiei": "prostie",
    "prostii": "prostie",
    "prostiile": "prostie",
    "prostiilor": "prostie",
    "prostioara": "prostioară",
    "prostioare": "prostioară",
    "prostioarei": "prostioară",
    "prostioarele": "prostioară",
    "prostioarelor": "prostioară",
    "prostirea": "prostire",
    "prostiri": "prostire",
    "prostirii": "prostire",
    "prostirile": "prostire",
    "prostirilor": "prostire",
    "prostită": "prostit",
    "prostite": "prostit",
    "prostiți": "prostit",
    "nemaiprostituând": "prostitua",
    "nemaiprostituându": "prostitua",
    "neprostituând": "prostitua",
    "neprostituându": "prostitua",
    "prostituă": "prostitua",
    "prostituai": "prostitua",
    "prostituam": "prostitua",
    "prostituăm": "prostitua",
    "prostituând": "prostitua",
    "prostituându": "prostitua",
    "prostituară": "prostitua",
    "prostituarăm": "prostitua",
    "prostituarăți": "prostitua",
    "prostituase": "prostitua",
    "prostituasem": "prostitua",
    "prostituaseră": "prostitua",
    "prostituaserăm": "prostitua",
    "prostituaserăți": "prostitua",
    "prostituaseși": "prostitua",
    "prostituași": "prostitua",
    "prostituat": "prostitua",
    "prostituați": "prostitua",
    "prostituau": "prostitua",
    "prostituează": "prostitua",
    "prostituez": "prostitua",
    "prostitueze": "prostitua",
    "prostituezi": "prostitua",
    "prostituată": "prostituat",
    "prostituate": "prostituat",
    "prostituați": "prostituat",
    "prostituata": "prostituată",
    "prostituate": "prostituată",
    "prostituatei": "prostituată",
    "prostituatele": "prostituată",
    "prostituatelor": "prostituată",
    "prostituția": "prostituție",
    "prostituției": "prostituție",
    "prostituții": "prostituție",
    "prostovana": "prostovan",
    "prostovană": "prostovan",
    "prostovane": "prostovan",
    "prostovanei": "prostovan",
    "prostovanele": "prostovan",
    "prostovanelor": "prostovan",
    "prostovani": "prostovan",
    "prostovanii": "prostovan",
    "prostovanilor": "prostovan",
    "prostovanul": "prostovan",
    "prostovanului": "prostovan",
    "prostrata": "prostrat",
    "prostrată": "prostrat",
    "prostrate": "prostrat",
    "prostratei": "prostrat",
    "prostratele": "prostrat",
    "prostratelor": "prostrat",
    "prostrați": "prostrat",
    "prostrații": "prostrat",
    "prostraților": "prostrat",
    "prostratul": "prostrat",
    "prostratului": "prostrat",
    "protagoniști": "protagonist",
    "protagoniștii": "protagonist",
    "protagoniștilor": "protagonist",
    "protagonistul": "protagonist",
    "protagonistului": "protagonist",
    "protagonista": "protagonistă",
    "protagoniste": "protagonistă",
    "protagonistei": "protagonistă",
    "protagonistele": "protagonistă",
    "protagonistelor": "protagonistă",
    "proțapul": "proțap",
    "proțapului": "proțap",
    "proțapuri": "proțap",
    "proțapurile": "proțap",
    "proțapurilor": "proțap",
    "nemaiproțăpind": "proțăpi",
    "nemaiproțăpindu": "proțăpi",
    "neproțăpind": "proțăpi",
    "neproțăpindu": "proțăpi",
    "proțăpea": "proțăpi",
    "proțăpeai": "proțăpi",
    "proțăpeam": "proțăpi",
    "proțăpească": "proțăpi",
    "proțăpeați": "proțăpi",
    "proțăpeau": "proțăpi",
    "proțăpesc": "proțăpi",
    "proțăpește": "proțăpi",
    "proțăpești": "proțăpi",
    "proțăpii": "proțăpi",
    "proțăpim": "proțăpi",
    "proțăpind": "proțăpi",
    "proțăpindu": "proțăpi",
    "proțăpiră": "proțăpi",
    "proțăpirăm": "proțăpi",
    "proțăpirăți": "proțăpi",
    "proțăpise": "proțăpi",
    "proțăpisem": "proțăpi",
    "proțăpiseră": "proțăpi",
    "proțăpiserăm": "proțăpi",
    "proțăpiserăți": "proțăpi",
    "proțăpiseși": "proțăpi",
    "proțăpiși": "proțăpi",
    "proțăpit": "proțăpi",
    "proțăpiți": "proțăpi",
    "proțăpită": "proțăpit",
    "proțăpite": "proțăpit",
    "proțăpiți": "proțăpit",
    "protaza": "protază",
    "protaze": "protază",
    "protazei": "protază",
    "protazele": "protază",
    "protazelor": "protază",
    "protecția": "protecție",
    "protecției": "protecție",
    "protecții": "protecție",
    "protecțiile": "protecție",
    "protecțiilor": "protecție",
    "protecționismul": "protecționism",
    "protecționismului": "protecționism",
    "protecționista": "protecționist",
    "protecționistă": "protecționist",
    "protecționiste": "protecționist",
    "protecționistei": "protecționist",
    "protecționistele": "protecționist",
    "protecționistelor": "protecționist",
    "protecționiști": "protecționist",
    "protecționiștii": "protecționist",
    "protecționiștilor": "protecționist",
    "protecționistul": "protecționist",
    "protecționistului": "protecționist",
    "protectoare": "protector",
    "protectoarea": "protector",
    "protectoarei": "protector",
    "protectoarele": "protector",
    "protectoarelor": "protector",
    "protectori": "protector",
    "protectorii": "protector",
    "protectorilor": "protector",
    "protectorul": "protector",
    "protectorului": "protector",
    "protectorate": "protectorat",
    "protectoratele": "protectorat",
    "protectoratelor": "protectorat",
    "protectoratul": "protectorat",
    "protectoratului": "protectorat",
    "proteguita": "proteguit",
    "proteguită": "proteguit",
    "proteguite": "proteguit",
    "proteguitei": "proteguit",
    "proteguitele": "proteguit",
    "proteguitelor": "proteguit",
    "proteguiți": "proteguit",
    "proteguiții": "proteguit",
    "proteguiților": "proteguit",
    "proteguitul": "proteguit",
    "proteguitului": "proteguit",
    "proteguitoare": "proteguitor",
    "proteguitoarea": "proteguitor",
    "proteguitoarei": "proteguitor",
    "proteguitoarele": "proteguitor",
    "proteguitoarelor": "proteguitor",
    "proteguitori": "proteguitor",
    "proteguitorii": "proteguitor",
    "proteguitorilor": "proteguitor",
    "proteguitorul": "proteguitor",
    "proteguitorului": "proteguitor",
    "proteica": "proteic",
    "proteică": "proteic",
    "proteice": "proteic",
    "proteicei": "proteic",
    "proteicele": "proteic",
    "proteicelor": "proteic",
    "proteici": "proteic",
    "proteicii": "proteic",
    "proteicilor": "proteic",
    "proteicul": "proteic",
    "proteicului": "proteic",
    "proteina": "proteină",
    "proteine": "proteină",
    "proteinei": "proteină",
    "proteinele": "proteină",
    "proteinelor": "proteină",
    "proteinica": "proteinic",
    "proteinică": "proteinic",
    "proteinice": "proteinic",
    "proteinicei": "proteinic",
    "proteinicele": "proteinic",
    "proteinicelor": "proteinic",
    "proteinici": "proteinic",
    "proteinicii": "proteinic",
    "proteinicilor": "proteinic",
    "proteinicul": "proteinic",
    "proteinicului": "proteinic",
    "nemaiprotejând": "proteja",
    "nemaiprotejându": "proteja",
    "neprotejând": "proteja",
    "neprotejându": "proteja",
    "protejă": "proteja",
    "protejai": "proteja",
    "protejam": "proteja",
    "protejăm": "proteja",
    "protejând": "proteja",
    "protejându": "proteja",
    "protejară": "proteja",
    "protejarăm": "proteja",
    "protejarăți": "proteja",
    "protejase": "proteja",
    "protejasem": "proteja",
    "protejaseră": "proteja",
    "protejaserăm": "proteja",
    "protejaserăți": "proteja",
    "protejaseși": "proteja",
    "protejași": "proteja",
    "protejat": "proteja",
    "protejați": "proteja",
    "protejau": "proteja",
    "protejează": "proteja",
    "protejez": "proteja",
    "protejeze": "proteja",
    "protejezi": "proteja",
    "protejarea": "protejare",
    "protejări": "protejare",
    "protejării": "protejare",
    "protejările": "protejare",
    "protejărilor": "protejare",
    "protejată": "protejat",
    "protejate": "protejat",
    "protejați": "protejat",
    "proterozoica": "proterozoic",
    "proterozoică": "proterozoic",
    "proterozoice": "proterozoic",
    "proterozoicei": "proterozoic",
    "proterozoicele": "proterozoic",
    "proterozoicelor": "proterozoic",
    "proterozoici": "proterozoic",
    "proterozoicii": "proterozoic",
    "proterozoicilor": "proterozoic",
    "proterozoicul": "proterozoic",
    "proterozoicului": "proterozoic",
    "proteste": "protest",
    "protestele": "protest",
    "protestelor": "protest",
    "protestul": "protest",
    "protestului": "protest",
    "nemaiprotestând": "protesta",
    "nemaiprotestându": "protesta",
    "neprotestând": "protesta",
    "neprotestându": "protesta",
    "protestă": "protesta",
    "protestai": "protesta",
    "protestam": "protesta",
    "protestăm": "protesta",
    "protestând": "protesta",
    "protestându": "protesta",
    "protestară": "protesta",
    "protestarăm": "protesta",
    "protestarăți": "protesta",
    "protestase": "protesta",
    "protestasem": "protesta",
    "protestaseră": "protesta",
    "protestaserăm": "protesta",
    "protestaserăți": "protesta",
    "protestaseși": "protesta",
    "protestași": "protesta",
    "protestat": "protesta",
    "protestați": "protesta",
    "protestau": "protesta",
    "protestează": "protesta",
    "protestez": "protesta",
    "protesteze": "protesta",
    "protestezi": "protesta",
    "protestanta": "protestant",
    "protestantă": "protestant",
    "protestante": "protestant",
    "protestantei": "protestant",
    "protestantele": "protestant",
    "protestantelor": "protestant",
    "protestanți": "protestant",
    "protestanții": "protestant",
    "protestanților": "protestant",
    "protestantul": "protestant",
    "protestantului": "protestant",
    "protestată": "protestat",
    "protestate": "protestat",
    "protestați": "protestat",
    "protestatara": "protestatar",
    "protestatară": "protestatar",
    "protestatare": "protestatar",
    "protestatarei": "protestatar",
    "protestatarele": "protestatar",
    "protestatarelor": "protestatar",
    "protestatari": "protestatar",
    "protestatarii": "protestatar",
    "protestatarilor": "protestatar",
    "protestatarul": "protestatar",
    "protestatarului": "protestatar",
    "protetica": "protetic",
    "protetică": "protetic",
    "protetice": "protetic",
    "proteticei": "protetic",
    "proteticele": "protetic",
    "proteticelor": "protetic",
    "protetici": "protetic",
    "proteticii": "protetic",
    "proteticilor": "protetic",
    "proteticul": "protetic",
    "proteticului": "protetic",
    "proteza": "proteză",
    "proteze": "proteză",
    "protezei": "proteză",
    "protezele": "proteză",
    "protezelor": "proteză",
    "protidica": "protidic",
    "protidică": "protidic",
    "protidice": "protidic",
    "protidicei": "protidic",
    "protidicele": "protidic",
    "protidicelor": "protidic",
    "protidici": "protidic",
    "protidicii": "protidic",
    "protidicilor": "protidic",
    "protidicul": "protidic",
    "protidicului": "protidic",
    "protipendada": "protipendadă",
    "protipendade": "protipendadă",
    "protipendadei": "protipendadă",
    "protipendadele": "protipendadă",
    "protipendadelor": "protipendadă",
    "protocoale": "protocol",
    "protocoalele": "protocol",
    "protocoalelor": "protocol",
    "protocolul": "protocol",
    "protocolului": "protocol",
    "protocolara": "protocolar",
    "protocolară": "protocolar",
    "protocolare": "protocolar",
    "protocolarei": "protocolar",
    "protocolarele": "protocolar",
    "protocolarelor": "protocolar",
    "protocolari": "protocolar",
    "protocolarii": "protocolar",
    "protocolarilor": "protocolar",
    "protocolarul": "protocolar",
    "protocolarului": "protocolar",
    "protocronismul": "protocronism",
    "protocronismului": "protocronism",
    "protoierei": "protoiereu",
    "protoiereii": "protoiereu",
    "protoiereilor": "protoiereu",
    "protoiereul": "protoiereu",
    "protoiereului": "protoiereu",
    "protoieria": "protoierie",
    "protoieriei": "protoierie",
    "protoierii": "protoierie",
    "protoieriile": "protoierie",
    "protoieriilor": "protoierie",
    "protoni": "proton",
    "protonii": "proton",
    "protonilor": "proton",
    "protonul": "proton",
    "protonului": "proton",
    "protonica": "protonic",
    "protonică": "protonic",
    "protonice": "protonic",
    "protonicei": "protonic",
    "protonicele": "protonic",
    "protonicelor": "protonic",
    "protonici": "protonic",
    "protonicii": "protonic",
    "protonicilor": "protonic",
    "protonicul": "protonic",
    "protonicului": "protonic",
    "protoplasma": "protoplasmă",
    "protoplasme": "protoplasmă",
    "protoplasmei": "protoplasmă",
    "protoplasmatica": "protoplasmatic",
    "protoplasmatică": "protoplasmatic",
    "protoplasmatice": "protoplasmatic",
    "protoplasmaticei": "protoplasmatic",
    "protoplasmaticele": "protoplasmatic",
    "protoplasmaticelor": "protoplasmatic",
    "protoplasmatici": "protoplasmatic",
    "protoplasmaticii": "protoplasmatic",
    "protoplasmaticilor": "protoplasmatic",
    "protoplasmaticul": "protoplasmatic",
    "protoplasmaticului": "protoplasmatic",
    "protopopi": "protopop",
    "protopopii": "protopop",
    "protopopilor": "protopop",
    "protopopul": "protopop",
    "protopopului": "protopop",
    "protopopeasca": "protopopesc",
    "protopopească": "protopopesc",
    "protopopescul": "protopopesc",
    "protopopescului": "protopopesc",
    "protopopești": "protopopesc",
    "protopopeștii": "protopopesc",
    "protopopeștile": "protopopesc",
    "protopopeștilor": "protopopesc",
    "protopopia": "protopopie",
    "protopopiei": "protopopie",
    "protopopii": "protopopie",
    "protopopiile": "protopopie",
    "protopopiilor": "protopopie",
    "protosingheli": "protosinghel",
    "protosinghelii": "protosinghel",
    "protosinghelilor": "protosinghel",
    "protosinghelul": "protosinghel",
    "protosinghelului": "protosinghel",
    "prototipul": "prototip",
    "prototipului": "prototip",
    "prototipuri": "prototip",
    "prototipurile": "prototip",
    "prototipurilor": "prototip",
    "prototipica": "prototipic",
    "prototipică": "prototipic",
    "prototipice": "prototipic",
    "prototipicei": "prototipic",
    "prototipicele": "prototipic",
    "prototipicelor": "prototipic",
    "prototipici": "prototipic",
    "prototipicii": "prototipic",
    "prototipicilor": "prototipic",
    "prototipicul": "prototipic",
    "prototipicului": "prototipic",
    "protozoare": "protozoar",
    "protozoarele": "protozoar",
    "protozoarelor": "protozoar",
    "protozoarul": "protozoar",
    "protozoarului": "protozoar",
    "protuberanta": "protuberant",
    "protuberantă": "protuberant",
    "protuberante": "protuberant",
    "protuberantei": "protuberant",
    "protuberantele": "protuberant",
    "protuberantelor": "protuberant",
    "protuberanți": "protuberant",
    "protuberanții": "protuberant",
    "protuberanților": "protuberant",
    "protuberantul": "protuberant",
    "protuberantului": "protuberant",
    "protuberanța": "protuberanță",
    "protuberanțe": "protuberanță",
    "protuberanței": "protuberanță",
    "protuberanțele": "protuberanță",
    "protuberanțelor": "protuberanță",
    "prova": "provă",
    "prove": "provă",
    "provei": "provă",
    "provele": "provă",
    "provelor": "provă",
    "nemaiprovenind": "proveni",
    "nemaiprovenindu": "proveni",
    "neprovenind": "proveni",
    "neprovenindu": "proveni",
    "provenea": "proveni",
    "proveneai": "proveni",
    "proveneam": "proveni",
    "proveneați": "proveni",
    "proveneau": "proveni",
    "provenii": "proveni",
    "provenim": "proveni",
    "provenind": "proveni",
    "provenindu": "proveni",
    "proveniră": "proveni",
    "provenirăm": "proveni",
    "provenirăți": "proveni",
    "provenise": "proveni",
    "provenisem": "proveni",
    "proveniseră": "proveni",
    "proveniserăm": "proveni",
    "proveniserăți": "proveni",
    "proveniseși": "proveni",
    "proveniși": "proveni",
    "provenit": "proveni",
    "proveniți": "proveni",
    "provii": "proveni",
    "provin": "proveni",
    "provină": "proveni",
    "provine": "proveni",
    "provino": "proveni",
    "proveniența": "proveniență",
    "proveniențe": "proveniență",
    "provenienței": "proveniență",
    "proveniențele": "proveniență",
    "proveniențelor": "proveniență",
    "provenită": "provenit",
    "provenite": "provenit",
    "proveniți": "provenit",
    "proverbe": "proverb",
    "proverbele": "proverb",
    "proverbelor": "proverb",
    "proverbul": "proverb",
    "proverbului": "proverb",
    "proverbiala": "proverbial",
    "proverbială": "proverbial",
    "proverbiale": "proverbial",
    "proverbialei": "proverbial",
    "proverbialele": "proverbial",
    "proverbialelor": "proverbial",
    "proverbiali": "proverbial",
    "proverbialii": "proverbial",
    "proverbialilor": "proverbial",
    "proverbialul": "proverbial",
    "proverbialului": "proverbial",
    "providența": "providență",
    "providențe": "providență",
    "providenței": "providență",
    "providențele": "providență",
    "providențelor": "providență",
    "providențiala": "providențial",
    "providențială": "providențial",
    "providențiale": "providențial",
    "providențialei": "providențial",
    "providențialele": "providențial",
    "providențialelor": "providențial",
    "providențiali": "providențial",
    "providențialii": "providențial",
    "providențialilor": "providențial",
    "providențialul": "providențial",
    "providențialului": "providențial",
    "provinciala": "provincial",
    "provincială": "provincial",
    "provinciale": "provincial",
    "provincialei": "provincial",
    "provincialele": "provincial",
    "provincialelor": "provincial",
    "provinciali": "provincial",
    "provincialii": "provincial",
    "provincialilor": "provincial",
    "provincialul": "provincial",
    "provincialului": "provincial",
    "provinciala": "provincială",
    "provinciale": "provincială",
    "provincialei": "provincială",
    "provincialele": "provincială",
    "provincialelor": "provincială",
    "provincialisme": "provincialism",
    "provincialismele": "provincialism",
    "provincialismelor": "provincialism",
    "provincialismul": "provincialism",
    "provincialismului": "provincialism",
    "provincialista": "provincialist",
    "provincialistă": "provincialist",
    "provincialiste": "provincialist",
    "provincialistei": "provincialist",
    "provincialistele": "provincialist",
    "provincialistelor": "provincialist",
    "provincialiști": "provincialist",
    "provincialiștii": "provincialist",
    "provincialiștilor": "provincialist",
    "provincialistul": "provincialist",
    "provincialistului": "provincialist",
    "provincia": "provincie",
    "provinciei": "provincie",
    "provincii": "provincie",
    "provinciile": "provincie",
    "provinciilor": "provincie",
    "provizia": "provizie",
    "proviziei": "provizie",
    "provizii": "provizie",
    "proviziile": "provizie",
    "proviziilor": "provizie",
    "provizioane": "provizion",
    "provizioanele": "provizion",
    "provizioanelor": "provizion",
    "provizionul": "provizion",
    "provizionului": "provizion",
    "provizorate": "provizorat",
    "provizoratele": "provizorat",
    "provizoratelor": "provizorat",
    "provizoratul": "provizorat",
    "provizoratului": "provizorat",
    "provizoria": "provizoriu",
    "provizorie": "provizoriu",
    "provizoriei": "provizoriu",
    "provizorii": "provizoriu",
    "provizoriii": "provizoriu",
    "provizoriile": "provizoriu",
    "provizoriilor": "provizoriu",
    "provizoriul": "provizoriu",
    "provizoriului": "provizoriu",
    "nemaiprovocând": "provoca",
    "nemaiprovocându": "provoca",
    "neprovocând": "provoca",
    "neprovocându": "provoca",
    "provoacă": "provoca",
    "provoace": "provoca",
    "provoc": "provoca",
    "provocă": "provoca",
    "provocai": "provoca",
    "provocam": "provoca",
    "provocăm": "provoca",
    "provocând": "provoca",
    "provocându": "provoca",
    "provocară": "provoca",
    "provocarăm": "provoca",
    "provocarăți": "provoca",
    "provocase": "provoca",
    "provocasem": "provoca",
    "provocaseră": "provoca",
    "provocaserăm": "provoca",
    "provocaserăți": "provoca",
    "provocaseși": "provoca",
    "provocași": "provoca",
    "provocat": "provoca",
    "provocați": "provoca",
    "provocau": "provoca",
    "provoci": "provoca",
    "provocanta": "provocant",
    "provocantă": "provocant",
    "provocante": "provocant",
    "provocantei": "provocant",
    "provocantele": "provocant",
    "provocantelor": "provocant",
    "provocanți": "provocant",
    "provocanții": "provocant",
    "provocanților": "provocant",
    "provocantul": "provocant",
    "provocantului": "provocant",
    "provocarea": "provocare",
    "provocări": "provocare",
    "provocării": "provocare",
    "provocările": "provocare",
    "provocărilor": "provocare",
    "provocată": "provocat",
    "provocate": "provocat",
    "provocați": "provocat",
    "provocatoare": "provocator",
    "provocatoarea": "provocator",
    "provocatoarei": "provocator",
    "provocatoarele": "provocator",
    "provocatoarelor": "provocator",
    "provocatori": "provocator",
    "provocatorii": "provocator",
    "provocatorilor": "provocator",
    "provocatorul": "provocator",
    "provocatorului": "provocator",
    "proxeneți": "proxenet",
    "proxeneții": "proxenet",
    "proxeneților": "proxenet",
    "proxenetul": "proxenet",
    "proxenetului": "proxenet",
    "proxenetismul": "proxenetism",
    "proxenetismului": "proxenetism",
    "proxima": "proxim",
    "proximă": "proxim",
    "proxime": "proxim",
    "proximei": "proxim",
    "proximele": "proxim",
    "proximelor": "proxim",
    "proximi": "proxim",
    "proximii": "proxim",
    "proximilor": "proxim",
    "proximul": "proxim",
    "proximului": "proxim",
    "proximitatea": "proximitate",
    "proximități": "proximitate",
    "proximității": "proximitate",
    "proximitățile": "proximitate",
    "proximităților": "proximitate",
    "proza": "proză",
    "proze": "proză",
    "prozei": "proză",
    "prozele": "proză",
    "prozelor": "proză",
    "prozaica": "prozaic",
    "prozaică": "prozaic",
    "prozaice": "prozaic",
    "prozaicei": "prozaic",
    "prozaicele": "prozaic",
    "prozaicelor": "prozaic",
    "prozaici": "prozaic",
    "prozaicii": "prozaic",
    "prozaicilor": "prozaic",
    "prozaicul": "prozaic",
    "prozaicului": "prozaic",
    "prozaismul": "prozaism",
    "prozaismului": "prozaism",
    "prozatoarea": "prozatoare",
    "prozatoarei": "prozatoare",
    "prozatoarele": "prozatoare",
    "prozatoarelor": "prozatoare",
    "prozatori": "prozator",
    "prozatorii": "prozator",
    "prozatorilor": "prozator",
    "prozatorul": "prozator",
    "prozatorului": "prozator",
    "prozeliți": "prozelit",
    "prozeliții": "prozelit",
    "prozeliților": "prozelit",
    "prozelitul": "prozelit",
    "prozelitului": "prozelit",
    "prozelitica": "prozelitic",
    "prozelitică": "prozelitic",
    "prozelitice": "prozelitic",
    "prozeliticei": "prozelitic",
    "prozeliticele": "prozelitic",
    "prozeliticelor": "prozelitic",
    "prozelitici": "prozelitic",
    "prozeliticii": "prozelitic",
    "prozeliticilor": "prozelitic",
    "prozeliticul": "prozelitic",
    "prozeliticului": "prozelitic",
    "prozodica": "prozodic",
    "prozodică": "prozodic",
    "prozodice": "prozodic",
    "prozodicei": "prozodic",
    "prozodicele": "prozodic",
    "prozodicelor": "prozodic",
    "prozodici": "prozodic",
    "prozodicii": "prozodic",
    "prozodicilor": "prozodic",
    "prozodicul": "prozodic",
    "prozodicului": "prozodic",
    "prozodia": "prozodie",
    "prozodiei": "prozodie",
    "prozodii": "prozodie",
    "prozodiile": "prozodie",
    "prozodiilor": "prozodie",
    "prudenta": "prudent",
    "prudentă": "prudent",
    "prudente": "prudent",
    "prudentei": "prudent",
    "prudentele": "prudent",
    "prudentelor": "prudent",
    "prudenți": "prudent",
    "prudenții": "prudent",
    "prudenților": "prudent",
    "prudentul": "prudent",
    "prudentului": "prudent",
    "prudența": "prudență",
    "prudențe": "prudență",
    "prudenței": "prudență",
    "prudențială": "prudențial",
    "pruni": "prun",
    "prunii": "prun",
    "prunilor": "prun",
    "prunul": "prun",
    "prunului": "prun",
    "pruna": "prună",
    "prune": "prună",
    "prunei": "prună",
    "prunele": "prună",
    "prunelor": "prună",
    "prunci": "prunc",
    "pruncii": "prunc",
    "pruncilor": "prunc",
    "pruncul": "prunc",
    "pruncului": "prunc",
    "prunca": "pruncă",
    "prunce": "pruncă",
    "pruncei": "pruncă",
    "pruncele": "pruncă",
    "pruncelor": "pruncă",
    "prunceasca": "pruncesc",
    "pruncească": "pruncesc",
    "pruncescul": "pruncesc",
    "pruncescului": "pruncesc",
    "pruncești": "pruncesc",
    "prunceștii": "pruncesc",
    "prunceștile": "pruncesc",
    "prunceștilor": "pruncesc",
    "pruncia": "pruncie",
    "prunciei": "pruncie",
    "pruncii": "pruncie",
    "prunciile": "pruncie",
    "prunciilor": "pruncie",
    "pruncuciderea": "pruncucidere",
    "pruncucideri": "pruncucidere",
    "pruncuciderii": "pruncucidere",
    "pruncuciderile": "pruncucidere",
    "pruncuciderilor": "pruncucidere",
    "pruncucigașa": "pruncucigaș",
    "pruncucigașă": "pruncucigaș",
    "pruncucigașe": "pruncucigaș",
    "pruncucigașei": "pruncucigaș",
    "pruncucigașele": "pruncucigaș",
    "pruncucigașelor": "pruncucigaș",
    "pruncucigași": "pruncucigaș",
    "pruncucigașii": "pruncucigaș",
    "pruncucigașilor": "pruncucigaș",
    "pruncucigașul": "pruncucigaș",
    "pruncucigașului": "pruncucigaș",
    "prundul": "prund",
    "prundului": "prund",
    "prunduri": "prund",
    "prundurile": "prund",
    "prundurilor": "prund",
    "prundoasa": "prundos",
    "prundoasă": "prundos",
    "prundoase": "prundos",
    "prundoasei": "prundos",
    "prundoasele": "prundos",
    "prundoaselor": "prundos",
    "prundoși": "prundos",
    "prundoșii": "prundos",
    "prundoșilor": "prundos",
    "prundosul": "prundos",
    "prundosului": "prundos",
    "nemaiprunduind": "prundui",
    "nemaiprunduindu": "prundui",
    "neprunduind": "prundui",
    "neprunduindu": "prundui",
    "prunduia": "prundui",
    "prunduiai": "prundui",
    "prunduiam": "prundui",
    "prunduiască": "prundui",
    "prunduiați": "prundui",
    "prunduiau": "prundui",
    "prunduiesc": "prundui",
    "prunduiește": "prundui",
    "prunduiești": "prundui",
    "prunduii": "prundui",
    "prunduim": "prundui",
    "prunduind": "prundui",
    "prunduindu": "prundui",
    "prunduiră": "prundui",
    "prunduirăm": "prundui",
    "prunduirăți": "prundui",
    "prunduise": "prundui",
    "prunduisem": "prundui",
    "prunduiseră": "prundui",
    "prunduiserăm": "prundui",
    "prunduiserăți": "prundui",
    "prunduiseși": "prundui",
    "prunduiși": "prundui",
    "prunduit": "prundui",
    "prunduiți": "prundui",
    "prunduită": "prunduit",
    "prunduite": "prunduit",
    "prunduiți": "prunduit",
    "pruritul": "prurit",
    "pruritului": "prurit",
    "prusaca": "prusac",
    "prusacă": "prusac",
    "prusace": "prusac",
    "prusacei": "prusac",
    "prusacele": "prusac",
    "prusacelor": "prusac",
    "prusaci": "prusac",
    "prusacii": "prusac",
    "prusacilor": "prusac",
    "prusacul": "prusac",
    "prusacului": "prusac",
    "prusaca": "prusacă",
    "prusace": "prusacă",
    "prusacei": "prusacă",
    "prusacele": "prusacă",
    "prusacelor": "prusacă",
    "prusăceasca": "prusăcesc",
    "prusăcească": "prusăcesc",
    "prusăcescul": "prusăcesc",
    "prusăcescului": "prusăcesc",
    "prusăcești": "prusăcesc",
    "prusăceștii": "prusăcesc",
    "prusăceștile": "prusăcesc",
    "prusăceștilor": "prusăcesc",
    "Prusiei": "Prusia",
    "prusiana": "prusian",
    "prusiană": "prusian",
    "prusianul": "prusian",
    "prusianului": "prusian",
    "prusiene": "prusian",
    "prusienei": "prusian",
    "prusienele": "prusian",
    "prusienelor": "prusian",
    "prusieni": "prusian",
    "prusienii": "prusian",
    "prusienilor": "prusian",
    "Prutul": "Prut",
    "Prutului": "Prut",
    "psalmi": "psalm",
    "psalmii": "psalm",
    "psalmilor": "psalm",
    "psalmul": "psalm",
    "psalmului": "psalm",
    "psalmica": "psalmic",
    "psalmică": "psalmic",
    "psalmice": "psalmic",
    "psalmicei": "psalmic",
    "psalmicele": "psalmic",
    "psalmicelor": "psalmic",
    "psalmici": "psalmic",
    "psalmicii": "psalmic",
    "psalmicilor": "psalmic",
    "psalmicul": "psalmic",
    "psalmicului": "psalmic",
    "psalmiști": "psalmist",
    "psalmiștii": "psalmist",
    "psalmiștilor": "psalmist",
    "psalmistul": "psalmist",
    "psalmistului": "psalmist",
    "nemaipsalmodiind": "psalmodia",
    "nemaipsalmodiindu": "psalmodia",
    "nepsalmodiind": "psalmodia",
    "nepsalmodiindu": "psalmodia",
    "psalmodiai": "psalmodia",
    "psalmodiam": "psalmodia",
    "psalmodiară": "psalmodia",
    "psalmodiarăm": "psalmodia",
    "psalmodiarăți": "psalmodia",
    "psalmodiase": "psalmodia",
    "psalmodiasem": "psalmodia",
    "psalmodiaseră": "psalmodia",
    "psalmodiaserăm": "psalmodia",
    "psalmodiaserăți": "psalmodia",
    "psalmodiaseși": "psalmodia",
    "psalmodiași": "psalmodia",
    "psalmodiat": "psalmodia",
    "psalmodiați": "psalmodia",
    "psalmodiau": "psalmodia",
    "psalmodiază": "psalmodia",
    "psalmodie": "psalmodia",
    "psalmodiem": "psalmodia",
    "psalmodiez": "psalmodia",
    "psalmodieze": "psalmodia",
    "psalmodiezi": "psalmodia",
    "psalmodiind": "psalmodia",
    "psalmodiindu": "psalmodia",
    "psalmodiată": "psalmodiat",
    "psalmodiate": "psalmodiat",
    "psalmodiați": "psalmodiat",
    "psalmodica": "psalmodic",
    "psalmodică": "psalmodic",
    "psalmodice": "psalmodic",
    "psalmodicei": "psalmodic",
    "psalmodicele": "psalmodic",
    "psalmodicelor": "psalmodic",
    "psalmodici": "psalmodic",
    "psalmodicii": "psalmodic",
    "psalmodicilor": "psalmodic",
    "psalmodicul": "psalmodic",
    "psalmodicului": "psalmodic",
    "psalmodia": "psalmodie",
    "psalmodiei": "psalmodie",
    "psalmodii": "psalmodie",
    "psalmodiile": "psalmodie",
    "psalmodiilor": "psalmodie",
    "psalmodierea": "psalmodiere",
    "psalmodieri": "psalmodiere",
    "psalmodierii": "psalmodiere",
    "psalmodierile": "psalmodiere",
    "psalmodierilor": "psalmodiere",
    "psalți": "psalt",
    "psalții": "psalt",
    "psalților": "psalt",
    "psaltul": "psalt",
    "psaltului": "psalt",
    "psaltica": "psaltic",
    "psaltică": "psaltic",
    "psaltice": "psaltic",
    "psalticei": "psaltic",
    "psalticele": "psaltic",
    "psalticelor": "psaltic",
    "psaltici": "psaltic",
    "psalticii": "psaltic",
    "psalticilor": "psaltic",
    "psalticul": "psaltic",
    "psalticului": "psaltic",
    "psaltira": "psaltire",
    "psaltirei": "psaltire",
    "psaltiri": "psaltire",
    "psaltirile": "psaltire",
    "psaltirilor": "psaltire",
    "pseudonime": "pseudonim",
    "pseudonimele": "pseudonim",
    "pseudonimelor": "pseudonim",
    "pseudonimul": "pseudonim",
    "pseudonimului": "pseudonim",
    "pseudopode": "pseudopod",
    "pseudopodele": "pseudopod",
    "pseudopodelor": "pseudopod",
    "pseudopodul": "pseudopod",
    "pseudopodului": "pseudopod",
    "psihanaliști": "psihanalist",
    "psihanaliștii": "psihanalist",
    "psihanaliștilor": "psihanalist",
    "psihanalistul": "psihanalist",
    "psihanalistului": "psihanalist",
    "psihanalista": "psihanalistă",
    "psihanaliste": "psihanalistă",
    "psihanalistei": "psihanalistă",
    "psihanalistele": "psihanalistă",
    "psihanalistelor": "psihanalistă",
    "psihanalitica": "psihanalitic",
    "psihanalitică": "psihanalitic",
    "psihanalitice": "psihanalitic",
    "psihanaliticei": "psihanalitic",
    "psihanaliticele": "psihanalitic",
    "psihanaliticelor": "psihanalitic",
    "psihanalitici": "psihanalitic",
    "psihanaliticii": "psihanalitic",
    "psihanaliticilor": "psihanalitic",
    "psihanaliticul": "psihanalitic",
    "psihanaliticului": "psihanalitic",
    "psihanalizezi": "psihanaliza",
    "psihanaliza": "psihanaliză",
    "psihanalize": "psihanaliză",
    "psihanalizei": "psihanaliză",
    "psihanalizele": "psihanaliză",
    "psihanalizelor": "psihanaliză",
    "psihanalizabila": "psihanalizabil",
    "psihanalizabilă": "psihanalizabil",
    "psihanalizabile": "psihanalizabil",
    "psihanalizabilei": "psihanalizabil",
    "psihanalizabilele": "psihanalizabil",
    "psihanalizabilelor": "psihanalizabil",
    "psihanalizabili": "psihanalizabil",
    "psihanalizabilii": "psihanalizabil",
    "psihanalizabililor": "psihanalizabil",
    "psihanalizabilul": "psihanalizabil",
    "psihanalizabilului": "psihanalizabil",
    "psihiatrica": "psihiatric",
    "psihiatrică": "psihiatric",
    "psihiatrice": "psihiatric",
    "psihiatricei": "psihiatric",
    "psihiatricele": "psihiatric",
    "psihiatricelor": "psihiatric",
    "psihiatrici": "psihiatric",
    "psihiatricii": "psihiatric",
    "psihiatricilor": "psihiatric",
    "psihiatricul": "psihiatric",
    "psihiatricului": "psihiatric",
    "psihiatria": "psihiatrie",
    "psihiatriei": "psihiatrie",
    "psihiatrii": "psihiatrie",
    "psihiatri": "psihiatru",
    "psihiatrii": "psihiatru",
    "psihiatrilor": "psihiatru",
    "psihiatrul": "psihiatru",
    "psihiatrului": "psihiatru",
    "psihica": "psihic",
    "psihică": "psihic",
    "psihice": "psihic",
    "psihicei": "psihic",
    "psihicele": "psihic",
    "psihicelor": "psihic",
    "psihici": "psihic",
    "psihicii": "psihic",
    "psihicilor": "psihic",
    "psihicul": "psihic",
    "psihicului": "psihic",
    "psihofizica": "psihofizic",
    "psihofizică": "psihofizic",
    "psihofizice": "psihofizic",
    "psihofizicei": "psihofizic",
    "psihofizicele": "psihofizic",
    "psihofizicelor": "psihofizic",
    "psihofizici": "psihofizic",
    "psihofizicii": "psihofizic",
    "psihofizicilor": "psihofizic",
    "psihofizicul": "psihofizic",
    "psihofizicului": "psihofizic",
    "psihofiziologica": "psihofiziologic",
    "psihofiziologică": "psihofiziologic",
    "psihofiziologice": "psihofiziologic",
    "psihofiziologicei": "psihofiziologic",
    "psihofiziologicele": "psihofiziologic",
    "psihofiziologicelor": "psihofiziologic",
    "psihofiziologici": "psihofiziologic",
    "psihofiziologicii": "psihofiziologic",
    "psihofiziologicilor": "psihofiziologic",
    "psihofiziologicul": "psihofiziologic",
    "psihofiziologicului": "psihofiziologic",
    "psihogena": "psihogen",
    "psihogenă": "psihogen",
    "psihogene": "psihogen",
    "psihogenei": "psihogen",
    "psihogenele": "psihogen",
    "psihogenelor": "psihogen",
    "psihogeni": "psihogen",
    "psihogenii": "psihogen",
    "psihogenilor": "psihogen",
    "psihogenul": "psihogen",
    "psihogenului": "psihogen",
    "psiholingvistica": "psiholingvistic",
    "psiholingvistică": "psiholingvistic",
    "psiholingvistice": "psiholingvistic",
    "psiholingvisticei": "psiholingvistic",
    "psiholingvisticele": "psiholingvistic",
    "psiholingvisticelor": "psiholingvistic",
    "psiholingvistici": "psiholingvistic",
    "psiholingvisticii": "psiholingvistic",
    "psiholingvisticilor": "psiholingvistic",
    "psiholingvisticul": "psiholingvistic",
    "psiholingvisticului": "psiholingvistic",
    "psihologi": "psiholog",
    "psihologii": "psiholog",
    "psihologilor": "psiholog",
    "psihologul": "psiholog",
    "psihologului": "psiholog",
    "psihologica": "psihologic",
    "psihologică": "psihologic",
    "psihologice": "psihologic",
    "psihologicei": "psihologic",
    "psihologicele": "psihologic",
    "psihologicelor": "psihologic",
    "psihologici": "psihologic",
    "psihologicii": "psihologic",
    "psihologicilor": "psihologic",
    "psihologicul": "psihologic",
    "psihologicului": "psihologic",
    "psih.": "psihologie",
    "psihologia": "psihologie",
    "psihologiei": "psihologie",
    "psihologii": "psihologie",
    "psihologista": "psihologist",
    "psihologistă": "psihologist",
    "psihologiste": "psihologist",
    "psihologistei": "psihologist",
    "psihologistele": "psihologist",
    "psihologistelor": "psihologist",
    "psihologiști": "psihologist",
    "psihologiștii": "psihologist",
    "psihologiștilor": "psihologist",
    "psihologistul": "psihologist",
    "psihologistului": "psihologist",
    "psihologizanta": "psihologizant",
    "psihologizantă": "psihologizant",
    "psihologizante": "psihologizant",
    "psihologizantei": "psihologizant",
    "psihologizantele": "psihologizant",
    "psihologizantelor": "psihologizant",
    "psihologizanți": "psihologizant",
    "psihologizanții": "psihologizant",
    "psihologizanților": "psihologizant",
    "psihologizantul": "psihologizant",
    "psihologizantului": "psihologizant",
    "psihomotoare": "psihomotor",
    "psihomotoarea": "psihomotor",
    "psihomotoarei": "psihomotor",
    "psihomotoarele": "psihomotor",
    "psihomotoarelor": "psihomotor",
    "psihomotori": "psihomotor",
    "psihomotorii": "psihomotor",
    "psihomotorilor": "psihomotor",
    "psihomotorul": "psihomotor",
    "psihomotorului": "psihomotor",
    "psihopați": "psihopat",
    "psihopații": "psihopat",
    "psihopaților": "psihopat",
    "psihopatul": "psihopat",
    "psihopatului": "psihopat",
    "psihopatica": "psihopatic",
    "psihopatică": "psihopatic",
    "psihopatice": "psihopatic",
    "psihopaticei": "psihopatic",
    "psihopaticele": "psihopatic",
    "psihopaticelor": "psihopatic",
    "psihopatici": "psihopatic",
    "psihopaticii": "psihopatic",
    "psihopaticilor": "psihopatic",
    "psihopaticul": "psihopatic",
    "psihopaticului": "psihopatic",
    "psihopatia": "psihopatie",
    "psihopatiei": "psihopatie",
    "psihopatii": "psihopatie",
    "psihopatiile": "psihopatie",
    "psihopatiilor": "psihopatie",
    "psihopatologica": "psihopatologic",
    "psihopatologică": "psihopatologic",
    "psihopatologice": "psihopatologic",
    "psihopatologicei": "psihopatologic",
    "psihopatologicele": "psihopatologic",
    "psihopatologicelor": "psihopatologic",
    "psihopatologici": "psihopatologic",
    "psihopatologicii": "psihopatologic",
    "psihopatologicilor": "psihopatologic",
    "psihopatologicul": "psihopatologic",
    "psihopatologicului": "psihopatologic",
    "psihoterapica": "psihoterapic",
    "psihoterapică": "psihoterapic",
    "psihoterapice": "psihoterapic",
    "psihoterapicei": "psihoterapic",
    "psihoterapicele": "psihoterapic",
    "psihoterapicelor": "psihoterapic",
    "psihoterapici": "psihoterapic",
    "psihoterapicii": "psihoterapic",
    "psihoterapicilor": "psihoterapic",
    "psihoterapicul": "psihoterapic",
    "psihoterapicului": "psihoterapic",
    "psihoterapia": "psihoterapie",
    "psihoterapiei": "psihoterapie",
    "psihoterapii": "psihoterapie",
    "psihotonica": "psihotonic",
    "psihotonică": "psihotonic",
    "psihotonice": "psihotonic",
    "psihotonicei": "psihotonic",
    "psihotonicele": "psihotonic",
    "psihotonicelor": "psihotonic",
    "psihotonici": "psihotonic",
    "psihotonicii": "psihotonic",
    "psihotonicilor": "psihotonic",
    "psihotonicul": "psihotonic",
    "psihotonicului": "psihotonic",
    "psihoza": "psihoză",
    "psihoze": "psihoză",
    "psihozei": "psihoză",
    "psihozele": "psihoză",
    "psihozelor": "psihoză",
    "psoriazisul": "psoriazis",
    "psoriazisului": "psoriazis",
    "ptolemeica": "ptolemeic",
    "ptolemeică": "ptolemeic",
    "ptolemeice": "ptolemeic",
    "ptolemeicei": "ptolemeic",
    "ptolemeicele": "ptolemeic",
    "ptolemeicelor": "ptolemeic",
    "ptolemeici": "ptolemeic",
    "ptolemeicii": "ptolemeic",
    "ptolemeicilor": "ptolemeic",
    "ptolemeicul": "ptolemeic",
    "ptolemeicului": "ptolemeic",
    "pubera": "puber",
    "puberă": "puber",
    "pubere": "puber",
    "puberei": "puber",
    "puberele": "puber",
    "puberelor": "puber",
    "puberi": "puber",
    "puberii": "puber",
    "puberilor": "puber",
    "puberul": "puber",
    "puberului": "puber",
    "puberala": "puberal",
    "puberală": "puberal",
    "puberale": "puberal",
    "puberalei": "puberal",
    "puberalele": "puberal",
    "puberalelor": "puberal",
    "puberali": "puberal",
    "puberalii": "puberal",
    "puberalilor": "puberal",
    "puberalul": "puberal",
    "puberalului": "puberal",
    "pubertatea": "pubertate",
    "pubertăți": "pubertate",
    "pubertății": "pubertate",
    "pubescenta": "pubescent",
    "pubescentă": "pubescent",
    "pubescente": "pubescent",
    "pubescentei": "pubescent",
    "pubescentele": "pubescent",
    "pubescentelor": "pubescent",
    "pubescenți": "pubescent",
    "pubescenții": "pubescent",
    "pubescenților": "pubescent",
    "pubescentul": "pubescent",
    "pubescentului": "pubescent",
    "pubiana": "pubian",
    "pubiană": "pubian",
    "pubianul": "pubian",
    "pubianului": "pubian",
    "pubiene": "pubian",
    "pubienei": "pubian",
    "pubienele": "pubian",
    "pubienelor": "pubian",
    "pubieni": "pubian",
    "pubienii": "pubian",
    "pubienilor": "pubian",
    "pubise": "pubis",
    "pubisele": "pubis",
    "pubiselor": "pubis",
    "pubisul": "pubis",
    "pubisului": "pubis",
    "publica": "public",
    "publică": "public",
    "publice": "public",
    "publicei": "public",
    "publicele": "public",
    "publicelor": "public",
    "publici": "public",
    "publicii": "public",
    "publicilor": "public",
    "publicul": "public",
    "publicului": "public",
    "nemaipublicând": "publica",
    "nemaipublicându": "publica",
    "nepublicând": "publica",
    "nepublicându": "publica",
    "public": "publica",
    "publică": "publica",
    "publicai": "publica",
    "publicam": "publica",
    "publicăm": "publica",
    "publicând": "publica",
    "publicându": "publica",
    "publicară": "publica",
    "publicarăm": "publica",
    "publicarăți": "publica",
    "publicase": "publica",
    "publicasem": "publica",
    "publicaseră": "publica",
    "publicaserăm": "publica",
    "publicaserăți": "publica",
    "publicaseși": "publica",
    "publicași": "publica",
    "publicat": "publica",
    "publicați": "publica",
    "publicau": "publica",
    "publice": "publica",
    "publici": "publica",
    "publicabila": "publicabil",
    "publicabilă": "publicabil",
    "publicabile": "publicabil",
    "publicabilei": "publicabil",
    "publicabilele": "publicabil",
    "publicabilelor": "publicabil",
    "publicabili": "publicabil",
    "publicabilii": "publicabil",
    "publicabililor": "publicabil",
    "publicabilul": "publicabil",
    "publicabilului": "publicabil",
    "publicarea": "publicare",
    "publicări": "publicare",
    "publicării": "publicare",
    "publicările": "publicare",
    "publicărilor": "publicare",
    "publicată": "publicat",
    "publicate": "publicat",
    "publicați": "publicat",
    "publicația": "publicație",
    "publicației": "publicație",
    "publicații": "publicație",
    "publicațiile": "publicație",
    "publicațiilor": "publicație",
    "publiciști": "publicist",
    "publiciștii": "publicist",
    "publiciștilor": "publicist",
    "publicistul": "publicist",
    "publicistului": "publicist",
    "publicista": "publicistă",
    "publiciste": "publicistă",
    "publicistei": "publicistă",
    "publicistele": "publicistă",
    "publicistelor": "publicistă",
    "publicistica": "publicistic",
    "publicistică": "publicistic",
    "publicistice": "publicistic",
    "publicisticei": "publicistic",
    "publicisticele": "publicistic",
    "publicisticelor": "publicistic",
    "publicistici": "publicistic",
    "publicisticii": "publicistic",
    "publicisticilor": "publicistic",
    "publicisticul": "publicistic",
    "publicisticului": "publicistic",
    "publicitara": "publicitar",
    "publicitară": "publicitar",
    "publicitare": "publicitar",
    "publicitarei": "publicitar",
    "publicitarele": "publicitar",
    "publicitarelor": "publicitar",
    "publicitari": "publicitar",
    "publicitarii": "publicitar",
    "publicitarilor": "publicitar",
    "publicitarul": "publicitar",
    "publicitarului": "publicitar",
    "publicitatea": "publicitate",
    "publicități": "publicitate",
    "publicității": "publicitate",
    "publicitățile": "publicitate",
    "publicităților": "publicitate",
    "pucul": "puc",
    "pucului": "puc",
    "pucuri": "puc",
    "pucurile": "puc",
    "pucurilor": "puc",
    "puchina": "puchină",
    "puchini": "puchină",
    "puchinii": "puchină",
    "puchinile": "puchină",
    "puchinilor": "puchină",
    "puchinoasa": "puchinos",
    "puchinoasă": "puchinos",
    "puchinoase": "puchinos",
    "puchinoasei": "puchinos",
    "puchinoasele": "puchinos",
    "puchinoaselor": "puchinos",
    "puchinoși": "puchinos",
    "puchinoșii": "puchinos",
    "puchinoșilor": "puchinos",
    "puchinosul": "puchinos",
    "puchinosului": "puchinos",
    "puchioasa": "puchios",
    "puchioasă": "puchios",
    "puchioase": "puchios",
    "puchioasei": "puchios",
    "puchioasele": "puchios",
    "puchioaselor": "puchios",
    "puchioși": "puchios",
    "puchioșii": "puchios",
    "puchioșilor": "puchios",
    "puchiosul": "puchios",
    "puchiosului": "puchios",
    "puciul": "puci",
    "puciului": "puci",
    "puciuri": "puci",
    "puciurile": "puci",
    "puciurilor": "puci",
    "pucioasa": "pucios",
    "pucioasă": "pucios",
    "pucioase": "pucios",
    "pucioasei": "pucios",
    "pucioasele": "pucios",
    "pucioaselor": "pucios",
    "pucioși": "pucios",
    "pucioșii": "pucios",
    "pucioșilor": "pucios",
    "puciosul": "pucios",
    "puciosului": "pucios",
    "pudul": "pud",
    "pudului": "pud",
    "puduri": "pud",
    "pudurile": "pud",
    "pudurilor": "pud",
    "pudeli": "pudel",
    "pudelii": "pudel",
    "pudelilor": "pudel",
    "pudelul": "pudel",
    "pudelului": "pudel",
    "pudibonderia": "pudibonderie",
    "pudibonderiei": "pudibonderie",
    "pudica": "pudic",
    "pudică": "pudic",
    "pudice": "pudic",
    "pudicei": "pudic",
    "pudicele": "pudic",
    "pudicelor": "pudic",
    "pudici": "pudic",
    "pudicii": "pudic",
    "pudicilor": "pudic",
    "pudicul": "pudic",
    "pudicului": "pudic",
    "pudicitatea": "pudicitate",
    "pudicități": "pudicitate",
    "pudicității": "pudicitate",
    "pudingul": "puding",
    "pudingului": "puding",
    "pudinguri": "puding",
    "pudingurile": "puding",
    "pudingurilor": "puding",
    "pudoarea": "pudoare",
    "pudori": "pudoare",
    "pudorii": "pudoare",
    "nemaipudrând": "pudra",
    "nemaipudrându": "pudra",
    "nepudrând": "pudra",
    "nepudrându": "pudra",
    "pudră": "pudra",
    "pudrai": "pudra",
    "pudram": "pudra",
    "pudrăm": "pudra",
    "pudrând": "pudra",
    "pudrându": "pudra",
    "pudrară": "pudra",
    "pudrarăm": "pudra",
    "pudrarăți": "pudra",
    "pudrase": "pudra",
    "pudrasem": "pudra",
    "pudraseră": "pudra",
    "pudraserăm": "pudra",
    "pudraserăți": "pudra",
    "pudraseși": "pudra",
    "pudrași": "pudra",
    "pudrat": "pudra",
    "pudrați": "pudra",
    "pudrau": "pudra",
    "pudrează": "pudra",
    "pudrez": "pudra",
    "pudreze": "pudra",
    "pudrezi": "pudra",
    "pudra": "pudră",
    "pudre": "pudră",
    "pudrei": "pudră",
    "pudrele": "pudră",
    "pudrelor": "pudră",
    "pudrată": "pudrat",
    "pudrate": "pudrat",
    "pudrați": "pudrat",
    "pudriera": "pudrieră",
    "pudriere": "pudrieră",
    "pudrierei": "pudrieră",
    "pudrierele": "pudrieră",
    "pudrierelor": "pudrieră",
    "puericultura": "puericultură",
    "puericulturi": "puericultură",
    "puericulturii": "puericultură",
    "puerila": "pueril",
    "puerilă": "pueril",
    "puerile": "pueril",
    "puerilei": "pueril",
    "puerilele": "pueril",
    "puerilelor": "pueril",
    "puerili": "pueril",
    "puerilii": "pueril",
    "puerililor": "pueril",
    "puerilul": "pueril",
    "puerilului": "pueril",
    "puful": "puf",
    "pufului": "puf",
    "pufuri": "puf",
    "pufurile": "puf",
    "pufurilor": "puf",
    "nemaipufăind": "pufăi",
    "nemaipufăindu": "pufăi",
    "nepufăind": "pufăi",
    "nepufăindu": "pufăi",
    "pufăia": "pufăi",
    "pufăiai": "pufăi",
    "pufăiam": "pufăi",
    "pufăiați": "pufăi",
    "pufăiau": "pufăi",
    "pufăie": "pufăi",
    "pufăii": "pufăi",
    "pufăim": "pufăi",
    "pufăind": "pufăi",
    "pufăindu": "pufăi",
    "pufăiră": "pufăi",
    "pufăirăm": "pufăi",
    "pufăirăți": "pufăi",
    "pufăise": "pufăi",
    "pufăisem": "pufăi",
    "pufăiseră": "pufăi",
    "pufăiserăm": "pufăi",
    "pufăiserăți": "pufăi",
    "pufăiseși": "pufăi",
    "pufăiși": "pufăi",
    "pufăit": "pufăi",
    "pufăiți": "pufăi",
    "pufăită": "pufăit",
    "pufăite": "pufăit",
    "pufăiți": "pufăit",
    "pufăitul": "pufăit",
    "pufăitului": "pufăit",
    "nemaipufnind": "pufni",
    "nemaipufnindu": "pufni",
    "nepufnind": "pufni",
    "nepufnindu": "pufni",
    "pufnea": "pufni",
    "pufneai": "pufni",
    "pufneam": "pufni",
    "pufnească": "pufni",
    "pufneați": "pufni",
    "pufneau": "pufni",
    "pufnesc": "pufni",
    "pufnește": "pufni",
    "pufnești": "pufni",
    "pufnii": "pufni",
    "pufnim": "pufni",
    "pufnind": "pufni",
    "pufnindu": "pufni",
    "pufniră": "pufni",
    "pufnirăm": "pufni",
    "pufnirăți": "pufni",
    "pufnise": "pufni",
    "pufnisem": "pufni",
    "pufniseră": "pufni",
    "pufniserăm": "pufni",
    "pufniserăți": "pufni",
    "pufniseși": "pufni",
    "pufniși": "pufni",
    "pufnit": "pufni",
    "pufniți": "pufni",
    "pufnită": "pufnit",
    "pufnite": "pufnit",
    "pufniți": "pufnit",
    "pufoaica": "pufoaică",
    "pufoaice": "pufoaică",
    "pufoaicei": "pufoaică",
    "pufoaicele": "pufoaică",
    "pufoaicelor": "pufoaică",
    "pufoasa": "pufos",
    "pufoasă": "pufos",
    "pufoase": "pufos",
    "pufoasei": "pufos",
    "pufoasele": "pufos",
    "pufoaselor": "pufos",
    "pufoși": "pufos",
    "pufoșii": "pufos",
    "pufoșilor": "pufos",
    "pufosul": "pufos",
    "pufosului": "pufos",
    "pugilatul": "pugilat",
    "pugilatului": "pugilat",
    "pugilismul": "pugilism",
    "pugilismului": "pugilism",
    "pugiliști": "pugilist",
    "pugiliștii": "pugilist",
    "pugiliștilor": "pugilist",
    "pugilistul": "pugilist",
    "pugilistului": "pugilist",
    "pugilistica": "pugilistic",
    "pugilistică": "pugilistic",
    "pugilistice": "pugilistic",
    "pugilisticei": "pugilistic",
    "pugilisticele": "pugilistic",
    "pugilisticelor": "pugilistic",
    "pugilistici": "pugilistic",
    "pugilisticii": "pugilistic",
    "pugilisticilor": "pugilistic",
    "pugilisticul": "pugilistic",
    "pugilisticului": "pugilistic",
    "puhava": "puhav",
    "puhavă": "puhav",
    "puhave": "puhav",
    "puhavei": "puhav",
    "puhavele": "puhav",
    "puhavelor": "puhav",
    "puhavi": "puhav",
    "puhavii": "puhav",
    "puhavilor": "puhav",
    "puhavul": "puhav",
    "puhavului": "puhav",
    "nemaipuhăvind": "puhăvi",
    "nemaipuhăvindu": "puhăvi",
    "nepuhăvind": "puhăvi",
    "nepuhăvindu": "puhăvi",
    "puhăvea": "puhăvi",
    "puhăveai": "puhăvi",
    "puhăveam": "puhăvi",
    "puhăvească": "puhăvi",
    "puhăveați": "puhăvi",
    "puhăveau": "puhăvi",
    "puhăvesc": "puhăvi",
    "puhăvește": "puhăvi",
    "puhăvești": "puhăvi",
    "puhăvii": "puhăvi",
    "puhăvim": "puhăvi",
    "puhăvind": "puhăvi",
    "puhăvindu": "puhăvi",
    "puhăviră": "puhăvi",
    "puhăvirăm": "puhăvi",
    "puhăvirăți": "puhăvi",
    "puhăvise": "puhăvi",
    "puhăvisem": "puhăvi",
    "puhăviseră": "puhăvi",
    "puhăviserăm": "puhăvi",
    "puhăviserăți": "puhăvi",
    "puhăviseși": "puhăvi",
    "puhăviși": "puhăvi",
    "puhăvit": "puhăvi",
    "puhăviți": "puhăvi",
    "puhăvită": "puhăvit",
    "puhăvite": "puhăvit",
    "puhăviți": "puhăvit",
    "puhoiul": "puhoi",
    "puhoiului": "puhoi",
    "puhoiuri": "puhoi",
    "puhoiurile": "puhoi",
    "puhoiurilor": "puhoi",
    "puii": "pui",
    "puilor": "pui",
    "puiul": "pui",
    "puiului": "pui",
    "puica": "puică",
    "puici": "puică",
    "puicii": "puică",
    "puicile": "puică",
    "puicilor": "puică",
    "puieți": "puiet",
    "puieții": "puiet",
    "puieților": "puiet",
    "puietul": "puiet",
    "puietului": "puiet",
    "puioasa": "puios",
    "puioasă": "puios",
    "puioase": "puios",
    "puioasei": "puios",
    "puioasele": "puios",
    "puioaselor": "puios",
    "puioși": "puios",
    "puioșii": "puios",
    "puioșilor": "puios",
    "puiosul": "puios",
    "puiosului": "puios",
    "puiuți": "puiuț",
    "puiuții": "puiuț",
    "puiuților": "puiuț",
    "puiuțul": "puiuț",
    "puiuțului": "puiuț",
    "pulul": "pul",
    "pulului": "pul",
    "puluri": "pul",
    "pulurile": "pul",
    "pulurilor": "pul",
    "pulberăria": "pulberărie",
    "pulberăriei": "pulberărie",
    "pulberării": "pulberărie",
    "pulberăriile": "pulberărie",
    "pulberăriilor": "pulberărie",
    "pulberea": "pulbere",
    "pulberi": "pulbere",
    "pulberii": "pulbere",
    "pulberile": "pulbere",
    "pulberilor": "pulbere",
    "pulberoasa": "pulberos",
    "pulberoasă": "pulberos",
    "pulberoase": "pulberos",
    "pulberoasei": "pulberos",
    "pulberoasele": "pulberos",
    "pulberoaselor": "pulberos",
    "pulberoși": "pulberos",
    "pulberoșii": "pulberos",
    "pulberoșilor": "pulberos",
    "pulberosul": "pulberos",
    "pulberosului": "pulberos",
    "pulmoni": "pulmon",
    "pulmonii": "pulmon",
    "pulmonilor": "pulmon",
    "pulmonul": "pulmon",
    "pulmonului": "pulmon",
    "pulmonara": "pulmonar",
    "pulmonară": "pulmonar",
    "pulmonare": "pulmonar",
    "pulmonarei": "pulmonar",
    "pulmonarele": "pulmonar",
    "pulmonarelor": "pulmonar",
    "pulmonari": "pulmonar",
    "pulmonarii": "pulmonar",
    "pulmonarilor": "pulmonar",
    "pulmonarul": "pulmonar",
    "pulmonarului": "pulmonar",
    "pulovere": "pulover",
    "puloverele": "pulover",
    "puloverelor": "pulover",
    "puloverul": "pulover",
    "puloverului": "pulover",
    "pulpa": "pulpă",
    "pulpe": "pulpă",
    "pulpei": "pulpă",
    "pulpele": "pulpă",
    "pulpelor": "pulpă",
    "pulpana": "pulpană",
    "pulpane": "pulpană",
    "pulpanei": "pulpană",
    "pulpanele": "pulpană",
    "pulpanelor": "pulpană",
    "pulpoasa": "pulpos",
    "pulpoasă": "pulpos",
    "pulpoase": "pulpos",
    "pulpoasei": "pulpos",
    "pulpoasele": "pulpos",
    "pulpoaselor": "pulpos",
    "pulpoși": "pulpos",
    "pulpoșii": "pulpos",
    "pulpoșilor": "pulpos",
    "pulposul": "pulpos",
    "pulposului": "pulpos",
    "pulsul": "puls",
    "pulsului": "puls",
    "pulsuri": "puls",
    "pulsurile": "puls",
    "pulsurilor": "puls",
    "nemaipulsând": "pulsa",
    "nemaipulsându": "pulsa",
    "nepulsând": "pulsa",
    "nepulsându": "pulsa",
    "pulsă": "pulsa",
    "pulsai": "pulsa",
    "pulsam": "pulsa",
    "pulsăm": "pulsa",
    "pulsând": "pulsa",
    "pulsându": "pulsa",
    "pulsară": "pulsa",
    "pulsarăm": "pulsa",
    "pulsarăți": "pulsa",
    "pulsase": "pulsa",
    "pulsasem": "pulsa",
    "pulsaseră": "pulsa",
    "pulsaserăm": "pulsa",
    "pulsaserăți": "pulsa",
    "pulsaseși": "pulsa",
    "pulsași": "pulsa",
    "pulsat": "pulsa",
    "pulsați": "pulsa",
    "pulsau": "pulsa",
    "pulsează": "pulsa",
    "pulsez": "pulsa",
    "pulseze": "pulsa",
    "pulsezi": "pulsa",
    "pulsată": "pulsat",
    "pulsate": "pulsat",
    "pulsați": "pulsat",
    "pulsația": "pulsație",
    "pulsației": "pulsație",
    "pulsații": "pulsație",
    "pulsațiile": "pulsație",
    "pulsațiilor": "pulsație",
    "pulsatila": "pulsatil",
    "pulsatilă": "pulsatil",
    "pulsatile": "pulsatil",
    "pulsatilei": "pulsatil",
    "pulsatilele": "pulsatil",
    "pulsatilelor": "pulsatil",
    "pulsatili": "pulsatil",
    "pulsatilii": "pulsatil",
    "pulsatililor": "pulsatil",
    "pulsatilul": "pulsatil",
    "pulsatilului": "pulsatil",
    "pultacea": "pultaceu",
    "pultacee": "pultaceu",
    "pultaceei": "pultaceu",
    "pultaceele": "pultaceu",
    "pultaceelor": "pultaceu",
    "pultacei": "pultaceu",
    "pultaceii": "pultaceu",
    "pultaceilor": "pultaceu",
    "pultaceul": "pultaceu",
    "pultaceului": "pultaceu",
    "nemaipulverizând": "pulveriza",
    "nemaipulverizându": "pulveriza",
    "nepulverizând": "pulveriza",
    "nepulverizându": "pulveriza",
    "pulveriză": "pulveriza",
    "pulverizai": "pulveriza",
    "pulverizam": "pulveriza",
    "pulverizăm": "pulveriza",
    "pulverizând": "pulveriza",
    "pulverizându": "pulveriza",
    "pulverizară": "pulveriza",
    "pulverizarăm": "pulveriza",
    "pulverizarăți": "pulveriza",
    "pulverizase": "pulveriza",
    "pulverizasem": "pulveriza",
    "pulverizaseră": "pulveriza",
    "pulverizaserăm": "pulveriza",
    "pulverizaserăți": "pulveriza",
    "pulverizaseși": "pulveriza",
    "pulverizași": "pulveriza",
    "pulverizat": "pulveriza",
    "pulverizați": "pulveriza",
    "pulverizau": "pulveriza",
    "pulverizează": "pulveriza",
    "pulverizez": "pulveriza",
    "pulverizeze": "pulveriza",
    "pulverizezi": "pulveriza",
    "pulverizabila": "pulverizabil",
    "pulverizabilă": "pulverizabil",
    "pulverizabile": "pulverizabil",
    "pulverizabilei": "pulverizabil",
    "pulverizabilele": "pulverizabil",
    "pulverizabilelor": "pulverizabil",
    "pulverizabili": "pulverizabil",
    "pulverizabilii": "pulverizabil",
    "pulverizabililor": "pulverizabil",
    "pulverizabilul": "pulverizabil",
    "pulverizabilului": "pulverizabil",
    "pulverizarea": "pulverizare",
    "pulverizări": "pulverizare",
    "pulverizării": "pulverizare",
    "pulverizările": "pulverizare",
    "pulverizărilor": "pulverizare",
    "pulverizată": "pulverizat",
    "pulverizate": "pulverizat",
    "pulverizați": "pulverizat",
    "pulverizatoare": "pulverizator",
    "pulverizatoarele": "pulverizator",
    "pulverizatoarelor": "pulverizator",
    "pulverizatorul": "pulverizator",
    "pulverizatorului": "pulverizator",
    "pulverulenta": "pulverulent",
    "pulverulentă": "pulverulent",
    "pulverulente": "pulverulent",
    "pulverulentei": "pulverulent",
    "pulverulentele": "pulverulent",
    "pulverulentelor": "pulverulent",
    "pulverulenți": "pulverulent",
    "pulverulenții": "pulverulent",
    "pulverulenților": "pulverulent",
    "pulverulentul": "pulverulent",
    "pulverulentului": "pulverulent",
    "pulv.": "pulvis",
    "pumni": "pumn",
    "pumnii": "pumn",
    "pumnilor": "pumn",
    "pumnul": "pumn",
    "pumnului": "pumn",
    "pumnale": "pumnal",
    "pumnalele": "pumnal",
    "pumnalelor": "pumnal",
    "pumnalul": "pumnal",
    "pumnalului": "pumnal",
    "punciul": "punci",
    "punciului": "punci",
    "punciuri": "punci",
    "punciurile": "punci",
    "punciurilor": "punci",
    "puncte": "punct",
    "punctele": "punct",
    "punctelor": "punct",
    "punctul": "punct",
    "punctului": "punct",
    "nemaipunctând": "puncta",
    "nemaipunctându": "puncta",
    "nepunctând": "puncta",
    "nepunctându": "puncta",
    "punctă": "puncta",
    "punctai": "puncta",
    "punctam": "puncta",
    "punctăm": "puncta",
    "punctând": "puncta",
    "punctându": "puncta",
    "punctară": "puncta",
    "punctarăm": "puncta",
    "punctarăți": "puncta",
    "punctase": "puncta",
    "punctasem": "puncta",
    "punctaseră": "puncta",
    "punctaserăm": "puncta",
    "punctaserăți": "puncta",
    "punctaseși": "puncta",
    "punctași": "puncta",
    "punctat": "puncta",
    "punctați": "puncta",
    "punctau": "puncta",
    "punctează": "puncta",
    "punctez": "puncta",
    "puncteze": "puncta",
    "punctezi": "puncta",
    "punctaje": "punctaj",
    "punctajele": "punctaj",
    "punctajelor": "punctaj",
    "punctajul": "punctaj",
    "punctajului": "punctaj",
    "punctată": "punctat",
    "punctate": "punctat",
    "punctați": "punctat",
    "p": "puncte",
    "puncția": "puncție",
    "puncției": "puncție",
    "puncții": "puncție",
    "puncțiile": "puncție",
    "puncțiilor": "puncție",
    "punctiforma": "punctiform",
    "punctiformă": "punctiform",
    "punctiforme": "punctiform",
    "punctiformei": "punctiform",
    "punctiformele": "punctiform",
    "punctiformelor": "punctiform",
    "punctiformi": "punctiform",
    "punctiformii": "punctiform",
    "punctiformilor": "punctiform",
    "punctiformul": "punctiform",
    "punctiformului": "punctiform",
    "punctuala": "punctual",
    "punctuală": "punctual",
    "punctuale": "punctual",
    "punctualei": "punctual",
    "punctualele": "punctual",
    "punctualelor": "punctual",
    "punctuali": "punctual",
    "punctualii": "punctual",
    "punctualilor": "punctual",
    "punctualul": "punctual",
    "punctualului": "punctual",
    "punctualitatea": "punctualitate",
    "punctualități": "punctualitate",
    "punctualității": "punctualitate",
    "punctuația": "punctuație",
    "punctuației": "punctuație",
    "punctuații": "punctuație",
    "nemaipunând": "pune",
    "nemaipunându": "pune",
    "nepunând": "pune",
    "nepunându": "pune",
    "pui": "pune",
    "pun": "pune",
    "pună": "pune",
    "punând": "pune",
    "punându": "pune",
    "punea": "pune",
    "puneai": "pune",
    "puneam": "pune",
    "puneați": "pune",
    "puneau": "pune",
    "punem": "pune",
    "puneți": "pune",
    "pus": "pune",
    "puse": "pune",
    "pusei": "pune",
    "puseră": "pune",
    "puserăm": "pune",
    "puserăți": "pune",
    "pusese": "pune",
    "pusesem": "pune",
    "puseseră": "pune",
    "puseserăm": "pune",
    "puseserăți": "pune",
    "puseseși": "pune",
    "puseși": "pune",
    "punerea": "punere",
    "puneri": "punere",
    "punerii": "punere",
    "punerile": "punere",
    "punerilor": "punere",
    "punga": "pungă",
    "pungi": "pungă",
    "pungii": "pungă",
    "pungile": "pungă",
    "pungilor": "pungă",
    "nemaipungălind": "pungăli",
    "nemaipungălindu": "pungăli",
    "nepungălind": "pungăli",
    "nepungălindu": "pungăli",
    "pungălea": "pungăli",
    "pungăleai": "pungăli",
    "pungăleam": "pungăli",
    "pungălească": "pungăli",
    "pungăleați": "pungăli",
    "pungăleau": "pungăli",
    "pungălesc": "pungăli",
    "pungălește": "pungăli",
    "pungălești": "pungăli",
    "pungălii": "pungăli",
    "pungălim": "pungăli",
    "pungălind": "pungăli",
    "pungălindu": "pungăli",
    "pungăliră": "pungăli",
    "pungălirăm": "pungăli",
    "pungălirăți": "pungăli",
    "pungălise": "pungăli",
    "pungălisem": "pungăli",
    "pungăliseră": "pungăli",
    "pungăliserăm": "pungăli",
    "pungăliserăți": "pungăli",
    "pungăliseși": "pungăli",
    "pungăliși": "pungăli",
    "pungălit": "pungăli",
    "pungăliți": "pungăli",
    "pungălită": "pungălit",
    "pungălite": "pungălit",
    "pungăliți": "pungălit",
    "pungași": "pungaș",
    "pungașii": "pungaș",
    "pungașilor": "pungaș",
    "pungașul": "pungaș",
    "pungașului": "pungaș",
    "pungășeasca": "pungășesc",
    "pungășească": "pungășesc",
    "pungășescul": "pungășesc",
    "pungășescului": "pungășesc",
    "pungășești": "pungășesc",
    "pungășeștii": "pungășesc",
    "pungășeștile": "pungășesc",
    "pungășeștilor": "pungășesc",
    "nemaipungășind": "pungăși",
    "nemaipungășindu": "pungăși",
    "nepungășind": "pungăși",
    "nepungășindu": "pungăși",
    "pungășea": "pungăși",
    "pungășeai": "pungăși",
    "pungășeam": "pungăși",
    "pungășească": "pungăși",
    "pungășeați": "pungăși",
    "pungășeau": "pungăși",
    "pungășesc": "pungăși",
    "pungășește": "pungăși",
    "pungășești": "pungăși",
    "pungășii": "pungăși",
    "pungășim": "pungăși",
    "pungășind": "pungăși",
    "pungășindu": "pungăși",
    "pungășiră": "pungăși",
    "pungășirăm": "pungăși",
    "pungășirăți": "pungăși",
    "pungășise": "pungăși",
    "pungășisem": "pungăși",
    "pungășiseră": "pungăși",
    "pungășiserăm": "pungăși",
    "pungășiserăți": "pungăși",
    "pungășiseși": "pungăși",
    "pungășiși": "pungăși",
    "pungășit": "pungăși",
    "pungășiți": "pungăși",
    "pungășia": "pungășie",
    "pungășiei": "pungășie",
    "pungășii": "pungășie",
    "pungășiile": "pungășie",
    "pungășiilor": "pungășie",
    "pungășită": "pungășit",
    "pungășite": "pungășit",
    "pungășiți": "pungășit",
    "punibila": "punibil",
    "punibilă": "punibil",
    "punibile": "punibil",
    "punibilei": "punibil",
    "punibilele": "punibil",
    "punibilelor": "punibil",
    "punibili": "punibil",
    "punibilii": "punibil",
    "punibililor": "punibil",
    "punibilul": "punibil",
    "punibilului": "punibil",
    "punica": "punic",
    "punică": "punic",
    "punice": "punic",
    "punicei": "punic",
    "punicele": "punic",
    "punicelor": "punic",
    "punici": "punic",
    "punicii": "punic",
    "punicilor": "punic",
    "punicul": "punic",
    "punicului": "punic",
    "punitiva": "punitiv",
    "punitivă": "punitiv",
    "punitive": "punitiv",
    "punitivei": "punitiv",
    "punitivele": "punitiv",
    "punitivelor": "punitiv",
    "punitivi": "punitiv",
    "punitivii": "punitiv",
    "punitivilor": "punitiv",
    "punitivul": "punitiv",
    "punitivului": "punitiv",
    "puntea": "punte",
    "punți": "punte",
    "punții": "punte",
    "punțile": "punte",
    "punților": "punte",
    "nemaipupând": "pupa",
    "nemaipupându": "pupa",
    "nepupând": "pupa",
    "nepupându": "pupa",
    "pup": "pupa",
    "pupă": "pupa",
    "pupai": "pupa",
    "pupam": "pupa",
    "pupăm": "pupa",
    "pupând": "pupa",
    "pupându": "pupa",
    "pupară": "pupa",
    "puparăm": "pupa",
    "puparăți": "pupa",
    "pupase": "pupa",
    "pupasem": "pupa",
    "pupaseră": "pupa",
    "pupaserăm": "pupa",
    "pupaserăți": "pupa",
    "pupaseși": "pupa",
    "pupași": "pupa",
    "pupat": "pupa",
    "pupați": "pupa",
    "pupau": "pupa",
    "pupe": "pupa",
    "pupi": "pupa",
    "pupa": "pupă",
    "pupe": "pupă",
    "pupei": "pupă",
    "pupele": "pupă",
    "pupelor": "pupă",
    "pupăcioasa": "pupăcios",
    "pupăcioasă": "pupăcios",
    "pupăcioase": "pupăcios",
    "pupăcioasei": "pupăcios",
    "pupăcioasele": "pupăcios",
    "pupăcioaselor": "pupăcios",
    "pupăcioși": "pupăcios",
    "pupăcioșii": "pupăcios",
    "pupăcioșilor": "pupăcios",
    "pupăciosul": "pupăcios",
    "pupăciosului": "pupăcios",
    "pupată": "pupat",
    "pupate": "pupat",
    "pupați": "pupat",
    "pupatul": "pupat",
    "pupatului": "pupat",
    "pupătura": "pupătură",
    "pupături": "pupătură",
    "pupăturii": "pupătură",
    "pupăturile": "pupătură",
    "pupăturilor": "pupătură",
    "pupăza": "pupăză",
    "pupeze": "pupăză",
    "pupezei": "pupăză",
    "pupezele": "pupăză",
    "pupezelor": "pupăză",
    "pupila": "pupilă",
    "pupile": "pupilă",
    "pupilei": "pupilă",
    "pupilele": "pupilă",
    "pupilelor": "pupilă",
    "pupilara": "pupilar",
    "pupilară": "pupilar",
    "pupilare": "pupilar",
    "pupilarei": "pupilar",
    "pupilarele": "pupilar",
    "pupilarelor": "pupilar",
    "pupilari": "pupilar",
    "pupilarii": "pupilar",
    "pupilarilor": "pupilar",
    "pupilarul": "pupilar",
    "pupilarului": "pupilar",
    "pupincurismului": "pupincurism",
    "pupitre": "pupitru",
    "pupitrele": "pupitru",
    "pupitrelor": "pupitru",
    "pupitrul": "pupitru",
    "pupitrului": "pupitru",
    "pura": "pur",
    "pură": "pur",
    "pure": "pur",
    "purei": "pur",
    "purele": "pur",
    "purelor": "pur",
    "puri": "pur",
    "purii": "pur",
    "purilor": "pur",
    "purul": "pur",
    "purului": "pur",
    "purceadă": "purcede",
    "purced": "purcede",
    "purcedea": "purcede",
    "purcedeai": "purcede",
    "purcedeam": "purcede",
    "purcedeați": "purcede",
    "purcedeau": "purcede",
    "purcedem": "purcede",
    "purcedeți": "purcede",
    "purces": "purcede",
    "purcese": "purcede",
    "purcesei": "purcede",
    "purceseră": "purcede",
    "purceserăm": "purcede",
    "purceserăți": "purcede",
    "purcesese": "purcede",
    "purcesesem": "purcede",
    "purceseseră": "purcede",
    "purceseserăm": "purcede",
    "purceseserăți": "purcede",
    "purceseseși": "purcede",
    "purceseși": "purcede",
    "purcezând": "purcede",
    "purcezi": "purcede",
    "purcei": "purcel",
    "purceii": "purcel",
    "purceilor": "purcel",
    "purcelul": "purcel",
    "purcelului": "purcel",
    "purceasă": "purces",
    "purcese": "purces",
    "purceși": "purces",
    "purgația": "purgație",
    "purgației": "purgație",
    "purgații": "purgație",
    "purgațiile": "purgație",
    "purgațiilor": "purgație",
    "purgativa": "purgativ",
    "purgativă": "purgativ",
    "purgative": "purgativ",
    "purgativei": "purgativ",
    "purgativele": "purgativ",
    "purgativelor": "purgativ",
    "purgativi": "purgativ",
    "purgativii": "purgativ",
    "purgativilor": "purgativ",
    "purgativul": "purgativ",
    "purgativului": "purgativ",
    "purgatorii": "purgatoriu",
    "purgatoriile": "purgatoriu",
    "purgatoriilor": "purgatoriu",
    "purgatoriul": "purgatoriu",
    "purgatoriului": "purgatoriu",
    "puricele": "purice",
    "puricelui": "purice",
    "purici": "purice",
    "puricii": "purice",
    "puricilor": "purice",
    "puricoasa": "puricos",
    "puricoasă": "puricos",
    "puricoase": "puricos",
    "puricoasei": "puricos",
    "puricoasele": "puricos",
    "puricoaselor": "puricos",
    "puricoși": "puricos",
    "puricoșii": "puricos",
    "puricoșilor": "puricos",
    "puricosul": "puricos",
    "puricosului": "puricos",
    "nemaipurificând": "purifica",
    "nemaipurificându": "purifica",
    "nepurificând": "purifica",
    "nepurificându": "purifica",
    "purific": "purifica",
    "purifică": "purifica",
    "purificai": "purifica",
    "purificam": "purifica",
    "purificăm": "purifica",
    "purificând": "purifica",
    "purificându": "purifica",
    "purificară": "purifica",
    "purificarăm": "purifica",
    "purificarăți": "purifica",
    "purificase": "purifica",
    "purificasem": "purifica",
    "purificaseră": "purifica",
    "purificaserăm": "purifica",
    "purificaserăți": "purifica",
    "purificaseși": "purifica",
    "purificași": "purifica",
    "purificat": "purifica",
    "purificați": "purifica",
    "purificau": "purifica",
    "purifice": "purifica",
    "purifici": "purifica",
    "purificarea": "purificare",
    "purificări": "purificare",
    "purificării": "purificare",
    "purificările": "purificare",
    "purificărilor": "purificare",
    "purificată": "purificat",
    "purificate": "purificat",
    "purificați": "purificat",
    "purificatoare": "purificator",
    "purificatoarea": "purificator",
    "purificatoarei": "purificator",
    "purificatoarele": "purificator",
    "purificatoarelor": "purificator",
    "purificatori": "purificator",
    "purificatorii": "purificator",
    "purificatorilor": "purificator",
    "purificatorul": "purificator",
    "purificatorului": "purificator",
    "purismul": "purism",
    "purismului": "purism",
    "purista": "purist",
    "puristă": "purist",
    "puriste": "purist",
    "puristei": "purist",
    "puristele": "purist",
    "puristelor": "purist",
    "puriști": "purist",
    "puriștii": "purist",
    "puriștilor": "purist",
    "puristul": "purist",
    "puristului": "purist",
    "purista": "puristă",
    "puriste": "puristă",
    "puristei": "puristă",
    "puristele": "puristă",
    "puristelor": "puristă",
    "puritana": "puritan",
    "puritană": "puritan",
    "puritane": "puritan",
    "puritanei": "puritan",
    "puritanele": "puritan",
    "puritanelor": "puritan",
    "puritani": "puritan",
    "puritanii": "puritan",
    "puritanilor": "puritan",
    "puritanul": "puritan",
    "puritanului": "puritan",
    "puritana": "puritană",
    "puritane": "puritană",
    "puritanei": "puritană",
    "puritanele": "puritană",
    "puritanelor": "puritană",
    "puritanisme": "puritanism",
    "puritanismele": "puritanism",
    "puritanismelor": "puritanism",
    "puritanismul": "puritanism",
    "puritanismului": "puritanism",
    "puritatea": "puritate",
    "purități": "puritate",
    "purității": "puritate",
    "purjarea": "purjare",
    "purjări": "purjare",
    "purjării": "purjare",
    "purjările": "purjare",
    "purjărilor": "purjare",
    "nemaipuroiind": "puroia",
    "nemaipuroiindu": "puroia",
    "nepuroiind": "puroia",
    "nepuroiindu": "puroia",
    "puroiară": "puroia",
    "puroiase": "puroia",
    "puroiaseră": "puroia",
    "puroiat": "puroia",
    "puroiau": "puroia",
    "puroiază": "puroia",
    "puroie": "puroia",
    "puroieze": "puroia",
    "puroiind": "puroia",
    "puroiindu": "puroia",
    "puroiată": "puroiat",
    "puroiate": "puroiat",
    "puroiați": "puroiat",
    "puroioasa": "puroios",
    "puroioasă": "puroios",
    "puroioase": "puroios",
    "puroioasei": "puroios",
    "puroioasele": "puroios",
    "puroioaselor": "puroios",
    "puroioși": "puroios",
    "puroioșii": "puroios",
    "puroioșilor": "puroios",
    "puroiosul": "puroios",
    "puroiosului": "puroios",
    "purpura": "purpură",
    "purpuri": "purpură",
    "purpurii": "purpură",
    "purpurile": "purpură",
    "purpurilor": "purpură",
    "purpurata": "purpurat",
    "purpurată": "purpurat",
    "purpurate": "purpurat",
    "purpuratei": "purpurat",
    "purpuratele": "purpurat",
    "purpuratelor": "purpurat",
    "purpurați": "purpurat",
    "purpurații": "purpurat",
    "purpuraților": "purpurat",
    "purpuratul": "purpurat",
    "purpuratului": "purpurat",
    "purpuria": "purpuriu",
    "purpurie": "purpuriu",
    "purpuriei": "purpuriu",
    "purpurii": "purpuriu",
    "purpuriii": "purpuriu",
    "purpuriile": "purpuriu",
    "purpuriilor": "purpuriu",
    "purpuriul": "purpuriu",
    "purpuriului": "purpuriu",
    "purpuroasa": "purpuros",
    "purpuroasă": "purpuros",
    "purpuroase": "purpuros",
    "purpuroasei": "purpuros",
    "purpuroasele": "purpuros",
    "purpuroaselor": "purpuros",
    "purpuroși": "purpuros",
    "purpuroșii": "purpuros",
    "purpuroșilor": "purpuros",
    "purpurosul": "purpuros",
    "purpurosului": "purpuros",
    "nemaipurtând": "purta",
    "nemaipurtându": "purta",
    "nepurtând": "purta",
    "nepurtându": "purta",
    "poartă": "purta",
    "poarte": "purta",
    "port": "purta",
    "porți": "purta",
    "purtă": "purta",
    "purtai": "purta",
    "purtam": "purta",
    "purtăm": "purta",
    "purtând": "purta",
    "purtându": "purta",
    "purtară": "purta",
    "purtarăm": "purta",
    "purtarăți": "purta",
    "purtase": "purta",
    "purtasem": "purta",
    "purtaseră": "purta",
    "purtaserăm": "purta",
    "purtaserăți": "purta",
    "purtaseși": "purta",
    "purtași": "purta",
    "purtat": "purta",
    "purtați": "purta",
    "purtau": "purta",
    "purtabila": "purtabil",
    "purtabilă": "purtabil",
    "purtabile": "purtabil",
    "purtabilei": "purtabil",
    "purtabilele": "purtabil",
    "purtabilelor": "purtabil",
    "purtabili": "purtabil",
    "purtabilii": "purtabil",
    "purtabililor": "purtabil",
    "purtabilul": "purtabil",
    "purtabilului": "purtabil",
    "purtarea": "purtare",
    "purtări": "purtare",
    "purtării": "purtare",
    "purtările": "purtare",
    "purtărilor": "purtare",
    "purtăreața": "purtăreț",
    "purtăreață": "purtăreț",
    "purtărețe": "purtăreț",
    "purtăreței": "purtăreț",
    "purtărețele": "purtăreț",
    "purtărețelor": "purtăreț",
    "purtăreți": "purtăreț",
    "purtăreții": "purtăreț",
    "purtăreților": "purtăreț",
    "purtărețul": "purtăreț",
    "purtărețului": "purtăreț",
    "purtată": "purtat",
    "purtate": "purtat",
    "purtați": "purtat",
    "purtatul": "purtat",
    "purtatului": "purtat",
    "purtătoarea": "purtătoare",
    "purtătoarei": "purtătoare",
    "purtătoarele": "purtătoare",
    "purtătoarelor": "purtătoare",
    "purtătoare": "purtător",
    "purtătoarea": "purtător",
    "purtătoarei": "purtător",
    "purtătoarele": "purtător",
    "purtătoarelor": "purtător",
    "purtători": "purtător",
    "purtătorii": "purtător",
    "purtătorilor": "purtător",
    "purtătorul": "purtător",
    "purtătorului": "purtător",
    "purulenta": "purulent",
    "purulentă": "purulent",
    "purulente": "purulent",
    "purulentei": "purulent",
    "purulentele": "purulent",
    "purulentelor": "purulent",
    "purulenți": "purulent",
    "purulenții": "purulent",
    "purulenților": "purulent",
    "purulentul": "purulent",
    "purulentului": "purulent",
    "pusă": "pus",
    "puse": "pus",
    "puși": "pus",
    "pușca": "pușcă",
    "puști": "pușcă",
    "puștii": "pușcă",
    "puștile": "pușcă",
    "puștilor": "pușcă",
    "pușca-mitralieră": "pușcă-mitralieră",
    "puștii-mitraliere": "pușcă-mitralieră",
    "puștile-mitraliere": "pușcă-mitralieră",
    "puștilor-mitraliere": "pușcă-mitralieră",
    "puști-mitraliere": "pușcă-mitralieră",
    "pușcăriași": "pușcăriaș",
    "pușcăriașii": "pușcăriaș",
    "pușcăriașilor": "pușcăriaș",
    "pușcăriașul": "pușcăriaș",
    "pușcăriașului": "pușcăriaș",
    "pușcăriașa": "pușcăriașă",
    "pușcăriașe": "pușcăriașă",
    "pușcăriașei": "pușcăriașă",
    "pușcăriașele": "pușcăriașă",
    "pușcăriașelor": "pușcăriașă",
    "pușcăria": "pușcărie",
    "pușcăriei": "pușcărie",
    "pușcării": "pușcărie",
    "pușcăriile": "pușcărie",
    "pușcăriilor": "pușcărie",
    "pușcași": "pușcaș",
    "pușcașii": "pușcaș",
    "pușcașilor": "pușcaș",
    "pușcașul": "pușcaș",
    "pușcașului": "pușcaș",
    "pușculița": "pușculiță",
    "pușculițe": "pușculiță",
    "pușculiței": "pușculiță",
    "pușculițele": "pușculiță",
    "pușculițelor": "pușculiță",
    "puseul": "puseu",
    "puseului": "puseu",
    "puseuri": "puseu",
    "puseurile": "puseu",
    "puseurilor": "puseu",
    "pușlamale": "pușlama",
    "pușlamalei": "pușlama",
    "pușlamalele": "pușlama",
    "pușlamalelor": "pușlama",
    "pușlamaua": "pușlama",
    "pusta": "pustă",
    "puste": "pustă",
    "pustei": "pustă",
    "pustele": "pustă",
    "pustelor": "pustă",
    "puștani": "puștan",
    "puștanii": "puștan",
    "puștanilor": "puștan",
    "puștanul": "puștan",
    "puștanului": "puștan",
    "puștii": "puști",
    "puștilor": "puști",
    "puștiul": "puști",
    "puștiule": "puști",
    "puștiului": "puști",
    "pustietatea": "pustietate",
    "pustietăți": "pustietate",
    "pustietății": "pustietate",
    "pustietățile": "pustietate",
    "pustietăților": "pustietate",
    "nemaipustiind": "pustii",
    "nemaipustiindu": "pustii",
    "nepustiind": "pustii",
    "nepustiindu": "pustii",
    "pustiască": "pustii",
    "pustiea": "pustii",
    "pustieai": "pustii",
    "pustieam": "pustii",
    "pustieați": "pustii",
    "pustieau": "pustii",
    "pustiesc": "pustii",
    "pustiește": "pustii",
    "pustiești": "pustii",
    "pustiii": "pustii",
    "pustiim": "pustii",
    "pustiind": "pustii",
    "pustiindu": "pustii",
    "pustiiră": "pustii",
    "pustiirăm": "pustii",
    "pustiirăți": "pustii",
    "pustiise": "pustii",
    "pustiisem": "pustii",
    "pustiiseră": "pustii",
    "pustiiserăm": "pustii",
    "pustiiserăți": "pustii",
    "pustiiseși": "pustii",
    "pustiiși": "pustii",
    "pustiit": "pustii",
    "pustiiți": "pustii",
    "pustiirea": "pustiire",
    "pustiiri": "pustiire",
    "pustiirii": "pustiire",
    "pustiirile": "pustiire",
    "pustiirilor": "pustiire",
    "pustiită": "pustiit",
    "pustiite": "pustiit",
    "pustiiți": "pustiit",
    "pustiitoare": "pustiitor",
    "pustiitoarea": "pustiitor",
    "pustiitoarei": "pustiitor",
    "pustiitoarele": "pustiitor",
    "pustiitoarelor": "pustiitor",
    "pustiitori": "pustiitor",
    "pustiitorii": "pustiitor",
    "pustiitorilor": "pustiitor",
    "pustiitorul": "pustiitor",
    "pustiitorului": "pustiitor",
    "pustia": "pustiu",
    "pustie": "pustiu",
    "pustiei": "pustiu",
    "pustii": "pustiu",
    "pustiii": "pustiu",
    "pustiile": "pustiu",
    "pustiilor": "pustiu",
    "pustiul": "pustiu",
    "pustiului": "pustiu",
    "pustiuri": "pustiu",
    "pustiurile": "pustiu",
    "pustiurilor": "pustiu",
    "pustnici": "pustnic",
    "pustnicii": "pustnic",
    "pustnicilor": "pustnic",
    "pustnicul": "pustnic",
    "pustnicului": "pustnic",
    "pustnica": "pustnică",
    "pustnice": "pustnică",
    "pustnicei": "pustnică",
    "pustnicele": "pustnică",
    "pustnicelor": "pustnică",
    "pustniceasca": "pustnicesc",
    "pustnicească": "pustnicesc",
    "pustnicescul": "pustnicesc",
    "pustnicescului": "pustnicesc",
    "pustnicești": "pustnicesc",
    "pustniceștii": "pustnicesc",
    "pustniceștile": "pustnicesc",
    "pustniceștilor": "pustnicesc",
    "pustnicia": "pustnicie",
    "pustniciei": "pustnicie",
    "pustnicii": "pustnicie",
    "pustniciile": "pustnicie",
    "pustniciilor": "pustnicie",
    "puștoaica": "puștoaică",
    "puștoaice": "puștoaică",
    "puștoaicei": "puștoaică",
    "puștoaicele": "puștoaică",
    "puștoaicelor": "puștoaică",
    "pustula": "pustulă",
    "pustule": "pustulă",
    "pustulei": "pustulă",
    "pustulele": "pustulă",
    "pustulelor": "pustulă",
    "pustuloasa": "pustulos",
    "pustuloasă": "pustulos",
    "pustuloase": "pustulos",
    "pustuloasei": "pustulos",
    "pustuloasele": "pustulos",
    "pustuloaselor": "pustulos",
    "pustuloși": "pustulos",
    "pustuloșii": "pustulos",
    "pustuloșilor": "pustulos",
    "pustulosul": "pustulos",
    "pustulosului": "pustulos",
    "puțul": "puț",
    "puțului": "puț",
    "puțuri": "puț",
    "puțurile": "puț",
    "puțurilor": "puț",
    "nemaiputând": "putea",
    "nemaiputându": "putea",
    "neputând": "putea",
    "neputându": "putea",
    "po'": "putea",
    "poată": "putea",
    "poate": "putea",
    "pot": "putea",
    "poți": "putea",
    "putând": "putea",
    "putându": "putea",
    "puteai": "putea",
    "puteam": "putea",
    "puteați": "putea",
    "puteau": "putea",
    "putem": "putea",
    "puteți": "putea",
    "putu": "putea",
    "putui": "putea",
    "putură": "putea",
    "puturăm": "putea",
    "puturăți": "putea",
    "putuse": "putea",
    "putusem": "putea",
    "putuseră": "putea",
    "putuserăm": "putea",
    "putuserăți": "putea",
    "putuseși": "putea",
    "putuși": "putea",
    "putut": "putea",
    "puterea": "putere",
    "puteri": "putere",
    "puterii": "putere",
    "puterile": "putere",
    "puterilor": "putere",
    "puternica": "puternic",
    "puternică": "puternic",
    "puternice": "puternic",
    "puternicei": "puternic",
    "puternicele": "puternic",
    "puternicelor": "puternic",
    "puternici": "puternic",
    "puternicii": "puternic",
    "puternicilor": "puternic",
    "puternicul": "puternic",
    "puternicului": "puternic",
    "nemaipuțind": "puți",
    "nemaipuțindu": "puți",
    "nepuțind": "puți",
    "nepuțindu": "puți",
    "put": "puți",
    "pută": "puți",
    "pute": "puți",
    "puțea": "puți",
    "puțeai": "puți",
    "puțeam": "puți",
    "puțeați": "puți",
    "puțeau": "puți",
    "puții": "puți",
    "puțim": "puți",
    "puțind": "puți",
    "puțindu": "puți",
    "puțiră": "puți",
    "puțirăm": "puți",
    "puțirăți": "puți",
    "puțise": "puți",
    "puțisem": "puți",
    "puțiseră": "puți",
    "puțiserăm": "puți",
    "puțiserăți": "puți",
    "puțiseși": "puți",
    "puțiși": "puți",
    "puțit": "puți",
    "puțiți": "puți",
    "puțina": "puțin",
    "puțină": "puțin",
    "puține": "puțin",
    "puținei": "puțin",
    "puținele": "puțin",
    "puținelor": "puțin",
    "puțini": "puțin",
    "puținii": "puțin",
    "puținilor": "puțin",
    "puținul": "puțin",
    "puținului": "puțin",
    "puținuri": "puțin",
    "puținurile": "puțin",
    "puținurilor": "puțin",
    "putina": "putină",
    "putini": "putină",
    "putinii": "putină",
    "putinile": "putină",
    "putinilor": "putină",
    "puținătatea": "puținătate",
    "puținătăți": "puținătate",
    "puținătății": "puținătate",
    "putincioasa": "putincios",
    "putincioasă": "putincios",
    "putincioase": "putincios",
    "putincioasei": "putincios",
    "putincioasele": "putincios",
    "putincioaselor": "putincios",
    "putincioși": "putincios",
    "putincioșii": "putincios",
    "putincioșilor": "putincios",
    "putinciosul": "putincios",
    "putinciosului": "putincios",
    "puținea": "puținel",
    "puțineaua": "puținel",
    "puținei": "puținel",
    "puțineii": "puținel",
    "puțineilor": "puținel",
    "puținele": "puținel",
    "puținelei": "puținel",
    "puținelele": "puținel",
    "puținelelor": "puținel",
    "puținelul": "puținel",
    "puținelului": "puținel",
    "puținica": "puținel",
    "puținică": "puținel",
    "putința": "putință",
    "putințe": "putință",
    "putinței": "putință",
    "putințele": "putință",
    "putințelor": "putință",
    "puțintea": "puțintel",
    "puținteaua": "puțintel",
    "puțintei": "puțintel",
    "puținteii": "puțintel",
    "puținteilor": "puțintel",
    "puțintele": "puțintel",
    "puțintelei": "puțintel",
    "puțintelele": "puțintel",
    "puțintelelor": "puțintel",
    "puțintelul": "puțintel",
    "puțintelului": "puțintel",
    "puțintica": "puțintel",
    "puțintică": "puțintel",
    "puțită": "puțit",
    "puțite": "puțit",
    "puțiți": "puțit",
    "Putnei": "Putna",
    "putoarea": "putoare",
    "putori": "putoare",
    "putorii": "putoare",
    "putorile": "putoare",
    "putorilor": "putoare",
    "putreda": "putred",
    "putredă": "putred",
    "putrede": "putred",
    "putredei": "putred",
    "putredele": "putred",
    "putredelor": "putred",
    "putredul": "putred",
    "putredului": "putred",
    "putrezi": "putred",
    "putrezii": "putred",
    "putrezilor": "putred",
    "putrefacția": "putrefacție",
    "putrefacției": "putrefacție",
    "putrefacții": "putrefacție",
    "putrefacțiile": "putrefacție",
    "putrefacțiilor": "putrefacție",
    "putrefiabila": "putrefiabil",
    "putrefiabilă": "putrefiabil",
    "putrefiabile": "putrefiabil",
    "putrefiabilei": "putrefiabil",
    "putrefiabilele": "putrefiabil",
    "putrefiabilelor": "putrefiabil",
    "putrefiabili": "putrefiabil",
    "putrefiabilii": "putrefiabil",
    "putrefiabililor": "putrefiabil",
    "putrefiabilul": "putrefiabil",
    "putrefiabilului": "putrefiabil",
    "putregaiul": "putregai",
    "putregaiului": "putregai",
    "putregaiuri": "putregai",
    "putregaiurile": "putregai",
    "putregaiurilor": "putregai",
    "putregăioasa": "putregăios",
    "putregăioasă": "putregăios",
    "putregăioase": "putregăios",
    "putregăioasei": "putregăios",
    "putregăioasele": "putregăios",
    "putregăioaselor": "putregăios",
    "putregăioși": "putregăios",
    "putregăioșii": "putregăios",
    "putregăioșilor": "putregăios",
    "putregăiosul": "putregăios",
    "putregăiosului": "putregăios",
    "putrescenta": "putrescent",
    "putrescentă": "putrescent",
    "putrescente": "putrescent",
    "putrescentei": "putrescent",
    "putrescentele": "putrescent",
    "putrescentelor": "putrescent",
    "putrescenți": "putrescent",
    "putrescenții": "putrescent",
    "putrescenților": "putrescent",
    "putrescentul": "putrescent",
    "putrescentului": "putrescent",
    "putrescibila": "putrescibil",
    "putrescibilă": "putrescibil",
    "putrescibile": "putrescibil",
    "putrescibilei": "putrescibil",
    "putrescibilele": "putrescibil",
    "putrescibilelor": "putrescibil",
    "putrescibili": "putrescibil",
    "putrescibilii": "putrescibil",
    "putrescibililor": "putrescibil",
    "putrescibilul": "putrescibil",
    "putrescibilului": "putrescibil",
    "nemaiputrezind": "putrezi",
    "nemaiputrezindu": "putrezi",
    "neputrezind": "putrezi",
    "neputrezindu": "putrezi",
    "putrezea": "putrezi",
    "putrezeai": "putrezi",
    "putrezeam": "putrezi",
    "putrezească": "putrezi",
    "putrezeați": "putrezi",
    "putrezeau": "putrezi",
    "putrezesc": "putrezi",
    "putrezește": "putrezi",
    "putrezești": "putrezi",
    "putrezii": "putrezi",
    "putrezim": "putrezi",
    "putrezind": "putrezi",
    "putrezindu": "putrezi",
    "putreziră": "putrezi",
    "putrezirăm": "putrezi",
    "putrezirăți": "putrezi",
    "putrezise": "putrezi",
    "putrezisem": "putrezi",
    "putreziseră": "putrezi",
    "putreziserăm": "putrezi",
    "putreziserăți": "putrezi",
    "putreziseși": "putrezi",
    "putreziși": "putrezi",
    "putrezit": "putrezi",
    "putreziți": "putrezi",
    "putreziciunea": "putreziciune",
    "putreziciuni": "putreziciune",
    "putreziciunii": "putreziciune",
    "putreziciunile": "putreziciune",
    "putreziciunilor": "putreziciune",
    "putrezirea": "putrezire",
    "putreziri": "putrezire",
    "putrezirii": "putrezire",
    "putrezirile": "putrezire",
    "putrezirilor": "putrezire",
    "putrezită": "putrezit",
    "putrezite": "putrezit",
    "putreziți": "putrezit",
    "puturoasa": "puturos",
    "puturoasă": "puturos",
    "puturoase": "puturos",
    "puturoasei": "puturos",
    "puturoasele": "puturos",
    "puturoaselor": "puturos",
    "puturoși": "puturos",
    "puturoșii": "puturos",
    "puturoșilor": "puturos",
    "puturosul": "puturos",
    "puturosului": "puturos",
    "puturoșenia": "puturoșenie",
    "puturoșeniei": "puturoșenie",
    "puturoșenii": "puturoșenie",
    "puturoșeniile": "puturoșenie",
    "puturoșeniilor": "puturoșenie",
    "putută": "putut",
    "putute": "putut",
    "putuți": "putut",
    "puzderia": "puzderie",
    "puzderiei": "puzderie",
    "puzderii": "puzderie",
    "puzderiile": "puzderie",
    "puzderiilor": "puzderie",
    "pythagoreica": "pythagoreic",
    "pythagoreică": "pythagoreic",
    "pythagoreice": "pythagoreic",
    "pythagoreicei": "pythagoreic",
    "pythagoreicele": "pythagoreic",
    "pythagoreicelor": "pythagoreic",
    "pythagoreici": "pythagoreic",
    "pythagoreicii": "pythagoreic",
    "pythagoreicilor": "pythagoreic",
    "pythagoreicul": "pythagoreic",
    "pythagoreicului": "pythagoreic",
    "pythagoricii": "pythagoric",
    "quasi-instinctivă": "quasi-instinctiv",
    "quasi-universală": "quasi-universal",
    "rabana": "rabană",
    "rabane": "rabană",
    "rabanei": "rabană",
    "rabanele": "rabană",
    "rabanelor": "rabană",
    "rabatoare": "rabator",
    "rabatoarele": "rabator",
    "rabatoarelor": "rabator",
    "rabatorul": "rabator",
    "rabatorului": "rabator",
    "nemairăbdând": "răbda",
    "nemairăbdându": "răbda",
    "nerăbdând": "răbda",
    "nerăbdându": "răbda",
    "rabd": "răbda",
    "rabdă": "răbda",
    "răbdă": "răbda",
    "răbdai": "răbda",
    "răbdam": "răbda",
    "răbdăm": "răbda",
    "răbdând": "răbda",
    "răbdându": "răbda",
    "răbdară": "răbda",
    "răbdarăm": "răbda",
    "răbdarăți": "răbda",
    "răbdase": "răbda",
    "răbdasem": "răbda",
    "răbdaseră": "răbda",
    "răbdaserăm": "răbda",
    "răbdaserăți": "răbda",
    "răbdaseși": "răbda",
    "răbdași": "răbda",
    "răbdat": "răbda",
    "răbdați": "răbda",
    "răbdau": "răbda",
    "rabde": "răbda",
    "rabzi": "răbda",
    "răbdarea": "răbdare",
    "răbdări": "răbdare",
    "răbdării": "răbdare",
    "răbdările": "răbdare",
    "răbdărilor": "răbdare",
    "răbdată": "răbdat",
    "răbdate": "răbdat",
    "răbdați": "răbdat",
    "răbdătoare": "răbdător",
    "răbdătoarea": "răbdător",
    "răbdătoarei": "răbdător",
    "răbdătoarele": "răbdător",
    "răbdătoarelor": "răbdător",
    "răbdători": "răbdător",
    "răbdătorii": "răbdător",
    "răbdătorilor": "răbdător",
    "răbdătorul": "răbdător",
    "răbdătorului": "răbdător",
    "rabdomanția": "rabdomanție",
    "rabdomanției": "rabdomanție",
    "rabdomanții": "rabdomanție",
    "rabdomanțiile": "rabdomanție",
    "rabdomanțiilor": "rabdomanție",
    "rabia": "rabie",
    "rabiei": "rabie",
    "rabii": "rabie",
    "rabini": "rabin",
    "rabinii": "rabin",
    "rabinilor": "rabin",
    "rabinul": "rabin",
    "rabinului": "rabin",
    "rabinica": "rabinic",
    "rabinică": "rabinic",
    "rabinice": "rabinic",
    "rabinicei": "rabinic",
    "rabinicele": "rabinic",
    "rabinicelor": "rabinic",
    "rabinici": "rabinic",
    "rabinicii": "rabinic",
    "rabinicilor": "rabinic",
    "rabinicul": "rabinic",
    "rabinicului": "rabinic",
    "rabla": "rablă",
    "rable": "rablă",
    "rablei": "rablă",
    "rablele": "rablă",
    "rablelor": "rablă",
    "nemairablagind": "rablagi",
    "nemairablagindu": "rablagi",
    "nerablagind": "rablagi",
    "nerablagindu": "rablagi",
    "rablagea": "rablagi",
    "rablageai": "rablagi",
    "rablageam": "rablagi",
    "rablagească": "rablagi",
    "rablageați": "rablagi",
    "rablageau": "rablagi",
    "rablagesc": "rablagi",
    "rablagește": "rablagi",
    "rablagești": "rablagi",
    "rablagii": "rablagi",
    "rablagim": "rablagi",
    "rablagind": "rablagi",
    "rablagindu": "rablagi",
    "rablagiră": "rablagi",
    "rablagirăm": "rablagi",
    "rablagirăți": "rablagi",
    "rablagise": "rablagi",
    "rablagisem": "rablagi",
    "rablagiseră": "rablagi",
    "rablagiserăm": "rablagi",
    "rablagiserăți": "rablagi",
    "rablagiseși": "rablagi",
    "rablagiși": "rablagi",
    "rablagit": "rablagi",
    "rablagiți": "rablagi",
    "rablagita": "rablagit",
    "rablagită": "rablagit",
    "rablagite": "rablagit",
    "rablagitei": "rablagit",
    "rablagitele": "rablagit",
    "rablagitelor": "rablagit",
    "rablagiți": "rablagit",
    "rablagiții": "rablagit",
    "rablagiților": "rablagit",
    "rablagito": "rablagit",
    "rablagitul": "rablagit",
    "rablagitule": "rablagit",
    "rablagitului": "rablagit",
    "răbojul": "răboj",
    "răbojului": "răboj",
    "răbojuri": "răboj",
    "răbojurile": "răboj",
    "răbojurilor": "răboj",
    "nemairabotând": "rabota",
    "nemairabotându": "rabota",
    "nerabotând": "rabota",
    "nerabotându": "rabota",
    "rabotă": "rabota",
    "rabotai": "rabota",
    "rabotam": "rabota",
    "rabotăm": "rabota",
    "rabotând": "rabota",
    "rabotându": "rabota",
    "rabotară": "rabota",
    "rabotarăm": "rabota",
    "rabotarăți": "rabota",
    "rabotase": "rabota",
    "rabotasem": "rabota",
    "rabotaseră": "rabota",
    "rabotaserăm": "rabota",
    "rabotaserăți": "rabota",
    "rabotaseși": "rabota",
    "rabotași": "rabota",
    "rabotat": "rabota",
    "rabotați": "rabota",
    "rabotau": "rabota",
    "rabotează": "rabota",
    "rabotez": "rabota",
    "raboteze": "rabota",
    "rabotezi": "rabota",
    "rabotarea": "rabotare",
    "rabotareo": "rabotare",
    "rabotări": "rabotare",
    "rabotării": "rabotare",
    "rabotările": "rabotare",
    "rabotărilor": "rabotare",
    "rabotată": "rabotat",
    "rabotate": "rabotat",
    "rabotați": "rabotat",
    "raboteza": "raboteză",
    "raboteze": "raboteză",
    "rabotezei": "raboteză",
    "rabotezele": "raboteză",
    "rabotezelor": "raboteză",
    "nemairăbufnind": "răbufni",
    "nemairăbufnindu": "răbufni",
    "nerăbufnind": "răbufni",
    "nerăbufnindu": "răbufni",
    "răbufnea": "răbufni",
    "răbufneai": "răbufni",
    "răbufneam": "răbufni",
    "răbufnească": "răbufni",
    "răbufneați": "răbufni",
    "răbufneau": "răbufni",
    "răbufnesc": "răbufni",
    "răbufnește": "răbufni",
    "răbufnești": "răbufni",
    "răbufnii": "răbufni",
    "răbufnim": "răbufni",
    "răbufnind": "răbufni",
    "răbufnindu": "răbufni",
    "răbufniră": "răbufni",
    "răbufnirăm": "răbufni",
    "răbufnirăți": "răbufni",
    "răbufnise": "răbufni",
    "răbufnisem": "răbufni",
    "răbufniseră": "răbufni",
    "răbufniserăm": "răbufni",
    "răbufniserăți": "răbufni",
    "răbufniseși": "răbufni",
    "răbufniși": "răbufni",
    "răbufnit": "răbufni",
    "răbufniți": "răbufni",
    "răbufnirea": "răbufnire",
    "răbufnireo": "răbufnire",
    "răbufniri": "răbufnire",
    "răbufnirii": "răbufnire",
    "răbufnirile": "răbufnire",
    "răbufnirilor": "răbufnire",
    "răbufnită": "răbufnit",
    "răbufnite": "răbufnit",
    "răbufniți": "răbufnit",
    "răbufnitura": "răbufnitură",
    "răbufnituri": "răbufnitură",
    "răbufniturii": "răbufnitură",
    "răbufniturile": "răbufnitură",
    "răbufniturilor": "răbufnitură",
    "răbufnituro": "răbufnitură",
    "raci": "rac",
    "racii": "rac",
    "racilor": "rac",
    "racul": "rac",
    "racului": "rac",
    "râca": "râcă",
    "râci": "râcă",
    "râcii": "râcă",
    "nemairâcâind": "râcâi",
    "nemairâcâindu": "râcâi",
    "nerâcâind": "râcâi",
    "nerâcâindu": "râcâi",
    "râcâia": "râcâi",
    "râcâiai": "râcâi",
    "râcâiam": "râcâi",
    "râcâiați": "râcâi",
    "râcâiau": "râcâi",
    "râcâie": "râcâi",
    "râcâii": "râcâi",
    "râcâim": "râcâi",
    "râcâind": "râcâi",
    "râcâindu": "râcâi",
    "râcâiră": "râcâi",
    "râcâirăm": "râcâi",
    "râcâirăți": "râcâi",
    "râcâise": "râcâi",
    "râcâisem": "râcâi",
    "râcâiseră": "râcâi",
    "râcâiserăm": "râcâi",
    "râcâiserăți": "râcâi",
    "râcâiseși": "râcâi",
    "râcâiși": "râcâi",
    "râcâit": "râcâi",
    "râcâiți": "râcâi",
    "râcâită": "râcâit",
    "râcâite": "râcâit",
    "râcâiți": "râcâit",
    "răcani": "răcan",
    "răcanii": "răcan",
    "răcanilor": "răcan",
    "răcanul": "răcan",
    "răcanului": "răcan",
    "răceala": "răceală",
    "răceli": "răceală",
    "răcelii": "răceală",
    "răcelile": "răceală",
    "răcelilor": "răceală",
    "racheta": "rachetă",
    "rachete": "rachetă",
    "rachetei": "rachetă",
    "rachetele": "rachetă",
    "rachetelor": "rachetă",
    "rachetodromul": "rachetodrom",
    "rachetodromului": "rachetodrom",
    "rachetodromuri": "rachetodrom",
    "rachetodromurile": "rachetodrom",
    "rachetodromurilor": "rachetodrom",
    "rachiașe": "rachiaș",
    "rachiașele": "rachiaș",
    "rachiașelor": "rachiaș",
    "rachiașul": "rachiaș",
    "rachiașului": "rachiaș",
    "răchita": "răchită",
    "răchite": "răchită",
    "răchitei": "răchită",
    "răchitele": "răchită",
    "răchitelor": "răchită",
    "răchitii": "răchită",
    "rachiul": "rachiu",
    "rachiului": "rachiu",
    "rachiuri": "rachiu",
    "rachiurile": "rachiu",
    "rachiurilor": "rachiu",
    "nemairăcind": "răci",
    "nemairăcindu": "răci",
    "nerăcind": "răci",
    "nerăcindu": "răci",
    "răcea": "răci",
    "răceai": "răci",
    "răceam": "răci",
    "răcească": "răci",
    "răceați": "răci",
    "răceau": "răci",
    "răcesc": "răci",
    "răcește": "răci",
    "răcești": "răci",
    "răcii": "răci",
    "răcim": "răci",
    "răcind": "răci",
    "răcindu": "răci",
    "răciră": "răci",
    "răcirăm": "răci",
    "răcirăți": "răci",
    "răcise": "răci",
    "răcisem": "răci",
    "răciseră": "răci",
    "răciserăm": "răci",
    "răciserăți": "răci",
    "răciseși": "răci",
    "răciși": "răci",
    "răcit": "răci",
    "răciți": "răci",
    "racila": "racilă",
    "racile": "racilă",
    "racilei": "racilă",
    "racilele": "racilă",
    "racilelor": "racilă",
    "răcirea": "răcire",
    "răcireo": "răcire",
    "răciri": "răcire",
    "răcirii": "răcire",
    "răcirile": "răcire",
    "răcirilor": "răcire",
    "răcita": "răcit",
    "răcită": "răcit",
    "răcite": "răcit",
    "răcitei": "răcit",
    "răcitele": "răcit",
    "răcitelor": "răcit",
    "răciți": "răcit",
    "răciții": "răcit",
    "răciților": "răcit",
    "răcito": "răcit",
    "răcitul": "răcit",
    "răcitule": "răcit",
    "răcitului": "răcit",
    "racla": "raclă",
    "racle": "raclă",
    "raclei": "raclă",
    "raclele": "raclă",
    "raclelor": "raclă",
    "racleta": "racletă",
    "raclete": "racletă",
    "racletei": "racletă",
    "racletele": "racletă",
    "racletelor": "racletă",
    "răcnete": "răcnet",
    "răcnetele": "răcnet",
    "răcnetelor": "răcnet",
    "răcnetul": "răcnet",
    "răcnetului": "răcnet",
    "nemairăcnind": "răcni",
    "nemairăcnindu": "răcni",
    "nerăcnind": "răcni",
    "nerăcnindu": "răcni",
    "răcnea": "răcni",
    "răcneai": "răcni",
    "răcneam": "răcni",
    "răcnească": "răcni",
    "răcneați": "răcni",
    "răcneau": "răcni",
    "răcnesc": "răcni",
    "răcnește": "răcni",
    "răcnești": "răcni",
    "răcnii": "răcni",
    "răcnim": "răcni",
    "răcnind": "răcni",
    "răcnindu": "răcni",
    "răcniră": "răcni",
    "răcnirăm": "răcni",
    "răcnirăți": "răcni",
    "răcnise": "răcni",
    "răcnisem": "răcni",
    "răcniseră": "răcni",
    "răcniserăm": "răcni",
    "răcniserăți": "răcni",
    "răcniseși": "răcni",
    "răcniși": "răcni",
    "răcnit": "răcni",
    "răcniți": "răcni",
    "răcnirea": "răcnire",
    "răcniri": "răcnire",
    "răcnirii": "răcnire",
    "răcnirile": "răcnire",
    "răcnirilor": "răcnire",
    "răcnită": "răcnit",
    "răcnite": "răcnit",
    "răcniți": "răcnit",
    "răcoarea": "răcoare",
    "răcori": "răcoare",
    "răcorii": "răcoare",
    "răcorile": "răcoare",
    "răcorilor": "răcoare",
    "racolarea": "racolare",
    "racolări": "racolare",
    "racolării": "racolare",
    "racolările": "racolare",
    "racolărilor": "racolare",
    "racordul": "racord",
    "racordului": "racord",
    "racorduri": "racord",
    "racordurile": "racord",
    "racordurilor": "racord",
    "nemairacordând": "racorda",
    "nemairacordându": "racorda",
    "neracordând": "racorda",
    "neracordându": "racorda",
    "racordă": "racorda",
    "racordai": "racorda",
    "racordam": "racorda",
    "racordăm": "racorda",
    "racordând": "racorda",
    "racordându": "racorda",
    "racordară": "racorda",
    "racordarăm": "racorda",
    "racordarăți": "racorda",
    "racordase": "racorda",
    "racordasem": "racorda",
    "racordaseră": "racorda",
    "racordaserăm": "racorda",
    "racordaserăți": "racorda",
    "racordaseși": "racorda",
    "racordași": "racorda",
    "racordat": "racorda",
    "racordați": "racorda",
    "racordau": "racorda",
    "racordează": "racorda",
    "racordez": "racorda",
    "racordeze": "racorda",
    "racordezi": "racorda",
    "racordarea": "racordare",
    "racordareo": "racordare",
    "racordări": "racordare",
    "racordării": "racordare",
    "racordările": "racordare",
    "racordărilor": "racordare",
    "racordată": "racordat",
    "racordate": "racordat",
    "racordați": "racordat",
    "nemairăcorind": "răcori",
    "nemairăcorindu": "răcori",
    "nerăcorind": "răcori",
    "nerăcorindu": "răcori",
    "răcorea": "răcori",
    "răcoreai": "răcori",
    "răcoream": "răcori",
    "răcorească": "răcori",
    "răcoreați": "răcori",
    "răcoreau": "răcori",
    "răcoresc": "răcori",
    "răcorește": "răcori",
    "răcorești": "răcori",
    "răcorii": "răcori",
    "răcorim": "răcori",
    "răcorind": "răcori",
    "răcorindu": "răcori",
    "răcoriră": "răcori",
    "răcorirăm": "răcori",
    "răcorirăți": "răcori",
    "răcorise": "răcori",
    "răcorisem": "răcori",
    "răcoriseră": "răcori",
    "răcoriserăm": "răcori",
    "răcoriserăți": "răcori",
    "răcoriseși": "răcori",
    "răcoriși": "răcori",
    "răcorit": "răcori",
    "răcoriți": "răcori",
    "răcorită": "răcorit",
    "răcorite": "răcorit",
    "răcoriți": "răcorit",
    "răcoroasa": "răcoros",
    "răcoroasă": "răcoros",
    "răcoroase": "răcoros",
    "răcoroasei": "răcoros",
    "răcoroasele": "răcoros",
    "răcoroaselor": "răcoros",
    "răcoroși": "răcoros",
    "răcoroșii": "răcoros",
    "răcoroșilor": "răcoros",
    "răcorosul": "răcoros",
    "răcorosului": "răcoros",
    "răculeți": "răculeț",
    "răculeții": "răculeț",
    "răculeților": "răculeț",
    "răculețul": "răculeț",
    "răculețului": "răculeț",
    "răcușori": "răcușor",
    "răcușorii": "răcușor",
    "răcușorilor": "răcușor",
    "răcușorul": "răcușor",
    "răcușorului": "răcușor",
    "rada": "radă",
    "rade": "radă",
    "radei": "radă",
    "radele": "radă",
    "radelor": "radă",
    "rădăcina": "rădăcină",
    "rădăcini": "rădăcină",
    "rădăcinii": "rădăcină",
    "rădăcinile": "rădăcină",
    "rădăcinilor": "rădăcină",
    "rădăcinoasa": "rădăcinoasă",
    "rădăcinoase": "rădăcinoasă",
    "rădăcinoasei": "rădăcinoasă",
    "rădăcinoasele": "rădăcinoasă",
    "rădăcinoaselor": "rădăcinoasă",
    "rădăcinoasa": "rădăcinos",
    "rădăcinoasă": "rădăcinos",
    "rădăcinoase": "rădăcinos",
    "rădăcinoasei": "rădăcinos",
    "rădăcinoasele": "rădăcinos",
    "rădăcinoaselor": "rădăcinos",
    "rădăcinoși": "rădăcinos",
    "rădăcinoșii": "rădăcinos",
    "rădăcinoșilor": "rădăcinos",
    "rădăcinosul": "rădăcinos",
    "rădăcinosului": "rădăcinos",
    "radare": "radar",
    "radarele": "radar",
    "radarelor": "radar",
    "radarul": "radar",
    "radarului": "radar",
    "rad": "rade",
    "radă": "rade",
    "rădea": "rade",
    "rădeai": "rade",
    "rădeam": "rade",
    "rădeați": "rade",
    "rădeau": "rade",
    "radem": "rade",
    "radeți": "rade",
    "ras": "rade",
    "rase": "rade",
    "răsei": "rade",
    "raseră": "rade",
    "raserăm": "rade",
    "raserăți": "rade",
    "răsese": "rade",
    "răsesem": "rade",
    "răseseră": "rade",
    "răseserăm": "rade",
    "răseserăți": "rade",
    "răseseși": "rade",
    "răseși": "rade",
    "rasu": "rade",
    "răzând": "rade",
    "răzându": "rade",
    "razi": "rade",
    "nemairâzând": "râde",
    "nemairâzându": "râde",
    "nerâzând": "râde",
    "nerâzându": "râde",
    "râd": "râde",
    "râdă": "râde",
    "râdea": "râde",
    "râdeai": "râde",
    "râdeam": "râde",
    "râdeați": "râde",
    "râdeau": "râde",
    "râdem": "râde",
    "râdeți": "râde",
    "râs": "râde",
    "râse": "râde",
    "râsei": "râde",
    "râseră": "râde",
    "râserăm": "râde",
    "râserăți": "râde",
    "râsese": "râde",
    "râsesem": "râde",
    "râseseră": "râde",
    "râseserăm": "râde",
    "râseserăți": "râde",
    "râseseși": "râde",
    "râseși": "râde",
    "râzând": "râde",
    "râzându": "râde",
    "râzi": "râde",
    "nemairadiind": "radia",
    "nemairadiindu": "radia",
    "neradiind": "radia",
    "neradiindu": "radia",
    "radiai": "radia",
    "radiam": "radia",
    "radiară": "radia",
    "radiarăm": "radia",
    "radiarăți": "radia",
    "radiase": "radia",
    "radiasem": "radia",
    "radiaseră": "radia",
    "radiaserăm": "radia",
    "radiaserăți": "radia",
    "radiaseși": "radia",
    "radiași": "radia",
    "radiat": "radia",
    "radiați": "radia",
    "radiau": "radia",
    "radiază": "radia",
    "radie": "radia",
    "radiem": "radia",
    "radiez": "radia",
    "radieze": "radia",
    "radiezi": "radia",
    "radiind": "radia",
    "radiindu": "radia",
    "radiala": "radial",
    "radială": "radial",
    "radiale": "radial",
    "radialei": "radial",
    "radialele": "radial",
    "radialelor": "radial",
    "radiali": "radial",
    "radialii": "radial",
    "radialilor": "radial",
    "radialul": "radial",
    "radialului": "radial",
    "rad.": "radian",
    "radiani": "radian",
    "radianii": "radian",
    "radianilor": "radian",
    "radianul": "radian",
    "radianului": "radian",
    "radianta": "radiant",
    "radiantă": "radiant",
    "radiante": "radiant",
    "radiantei": "radiant",
    "radiantele": "radiant",
    "radiantelor": "radiant",
    "radianți": "radiant",
    "radianții": "radiant",
    "radianților": "radiant",
    "radiantul": "radiant",
    "radiantului": "radiant",
    "radiara": "radiar",
    "radiară": "radiar",
    "radiare": "radiar",
    "radiarei": "radiar",
    "radiarele": "radiar",
    "radiarelor": "radiar",
    "radiari": "radiar",
    "radiarii": "radiar",
    "radiarilor": "radiar",
    "radiarul": "radiar",
    "radiarului": "radiar",
    "radiată": "radiat",
    "radiate": "radiat",
    "radiați": "radiat",
    "radiația": "radiație",
    "radiației": "radiație",
    "radiații": "radiație",
    "radiațiile": "radiație",
    "radiațiilor": "radiație",
    "radiatoare": "radiator",
    "radiatoarele": "radiator",
    "radiatoarelor": "radiator",
    "radiatorul": "radiator",
    "radiatorului": "radiator",
    "rad.": "radical",
    "radicala": "radical",
    "radicală": "radical",
    "radicale": "radical",
    "radicalei": "radical",
    "radicalele": "radical",
    "radicalelor": "radical",
    "radicali": "radical",
    "radicalii": "radical",
    "radicalilor": "radical",
    "radicalul": "radical",
    "radicalului": "radical",
    "radicalisme": "radicalism",
    "radicalismele": "radicalism",
    "radicalismelor": "radicalism",
    "radicalismul": "radicalism",
    "radicalismului": "radicalism",
    "radicaliză": "radicaliza",
    "radicalizai": "radicaliza",
    "radicalizam": "radicaliza",
    "radicalizăm": "radicaliza",
    "radicalizând": "radicaliza",
    "radicalizându": "radicaliza",
    "radicalizară": "radicaliza",
    "radicalizarăm": "radicaliza",
    "radicalizarăți": "radicaliza",
    "radicalizase": "radicaliza",
    "radicalizasem": "radicaliza",
    "radicalizaseră": "radicaliza",
    "radicalizaserăm": "radicaliza",
    "radicalizaserăți": "radicaliza",
    "radicalizaseși": "radicaliza",
    "radicalizași": "radicaliza",
    "radicalizat": "radicaliza",
    "radicalizați": "radicaliza",
    "radicalizau": "radicaliza",
    "radicalizează": "radicaliza",
    "radicalizez": "radicaliza",
    "radicalizeze": "radicaliza",
    "radicalizezi": "radicaliza",
    "radicalizarea": "radicalizare",
    "radicalizări": "radicalizare",
    "radicalizării": "radicalizare",
    "radicalizările": "radicalizare",
    "radicalizărilor": "radicalizare",
    "radicalizata": "radicalizat",
    "radicalizată": "radicalizat",
    "radicalizate": "radicalizat",
    "radicalizatei": "radicalizat",
    "radicalizatele": "radicalizat",
    "radicalizatelor": "radicalizat",
    "radicalizați": "radicalizat",
    "radicalizații": "radicalizat",
    "radicalizaților": "radicalizat",
    "radicalizato": "radicalizat",
    "radicalizatul": "radicalizat",
    "radicalizatule": "radicalizat",
    "radicalizatului": "radicalizat",
    "radical-socialiști": "radical-socialist",
    "radical-socialiștii": "radical-socialist",
    "radical-socialiștilor": "radical-socialist",
    "radical-socialistul": "radical-socialist",
    "radical-socialistului": "radical-socialist",
    "radicația": "radicație",
    "radicației": "radicație",
    "radicații": "radicație",
    "radicațiile": "radicație",
    "radicațiilor": "radicație",
    "radicela": "radicelă",
    "radicele": "radicelă",
    "radicelei": "radicelă",
    "radicelele": "radicelă",
    "radicelelor": "radicelă",
    "radiera": "radieră",
    "radiere": "radieră",
    "radierei": "radieră",
    "radierele": "radieră",
    "radierelor": "radieră",
    "radierea": "radiere",
    "radieri": "radiere",
    "radierii": "radiere",
    "radierile": "radiere",
    "radierilor": "radiere",
    "radioul": "radio",
    "radioului": "radio",
    "radiouri": "radio",
    "radiourile": "radio",
    "radiourilor": "radio",
    "radioactiva": "radioactiv",
    "radioactivă": "radioactiv",
    "radioactive": "radioactiv",
    "radioactivei": "radioactiv",
    "radioactivele": "radioactiv",
    "radioactivelor": "radioactiv",
    "radioactivi": "radioactiv",
    "radioactivii": "radioactiv",
    "radioactivilor": "radioactiv",
    "radioactivul": "radioactiv",
    "radioactivului": "radioactiv",
    "radioactivitatea": "radioactivitate",
    "radioactivități": "radioactivitate",
    "radioactivității": "radioactivitate",
    "radioactivitățile": "radioactivitate",
    "radioactivităților": "radioactivitate",
    "radioamatori": "radioamator",
    "radioamatorii": "radioamator",
    "radioamatorilor": "radioamator",
    "radioamatorul": "radioamator",
    "radioamatorului": "radioamator",
    "radioamplificarea": "radioamplificare",
    "radioamplificări": "radioamplificare",
    "radioamplificării": "radioamplificare",
    "radioamplificările": "radioamplificare",
    "radioamplificărilor": "radioamplificare",
    "radioastronomia": "radioastronomie",
    "radioastronomii": "radioastronomie",
    "radioastronomiile": "radioastronomie",
    "radioastronomiilor": "radioastronomie",
    "radiobaliza": "radiobaliză",
    "radiobalize": "radiobaliză",
    "radiobalizei": "radiobaliză",
    "radiobalizele": "radiobaliză",
    "radiobalizelor": "radiobaliză",
    "radiocomunicația": "radiocomunicație",
    "radiocomunicației": "radiocomunicație",
    "radiocomunicații": "radiocomunicație",
    "radiocomunicațiile": "radiocomunicație",
    "radiocomunicațiilor": "radiocomunicație",
    "radiodifuziunea": "radiodifuziune",
    "radiodifuziuni": "radiodifuziune",
    "radiodifuziunii": "radiodifuziune",
    "radiodifuziunile": "radiodifuziune",
    "radiodifuziunilor": "radiodifuziune",
    "radioelectrica": "radioelectric",
    "radioelectrică": "radioelectric",
    "radioelectrice": "radioelectric",
    "radioelectricei": "radioelectric",
    "radioelectricele": "radioelectric",
    "radioelectricelor": "radioelectric",
    "radioelectrici": "radioelectric",
    "radioelectricii": "radioelectric",
    "radioelectricilor": "radioelectric",
    "radioelectricul": "radioelectric",
    "radioelectricului": "radioelectric",
    "radioelectricitatea": "radioelectricitate",
    "radioelectricități": "radioelectricitate",
    "radioelectricității": "radioelectricitate",
    "radioelectricitățile": "radioelectricitate",
    "radioelectricităților": "radioelectricitate",
    "radioelemente": "radioelement",
    "radioelementele": "radioelement",
    "radioelementelor": "radioelement",
    "radioelementul": "radioelement",
    "radioelementului": "radioelement",
    "radioemisia": "radioemisie",
    "radioemisiei": "radioemisie",
    "radioemisii": "radioemisie",
    "radioemisiile": "radioemisie",
    "radioemisiilor": "radioemisie",
    "radioemițătoare": "radioemițător",
    "radioemițătoarele": "radioemițător",
    "radioemițătoarelor": "radioemițător",
    "radioemițătorul": "radioemițător",
    "radioemițătorului": "radioemițător",
    "radiofonica": "radiofonic",
    "radiofonică": "radiofonic",
    "radiofonice": "radiofonic",
    "radiofonicei": "radiofonic",
    "radiofonicele": "radiofonic",
    "radiofonicelor": "radiofonic",
    "radiofonici": "radiofonic",
    "radiofonicii": "radiofonic",
    "radiofonicilor": "radiofonic",
    "radiofonicul": "radiofonic",
    "radiofonicului": "radiofonic",
    "radiofonia": "radiofonie",
    "radiofoniei": "radiofonie",
    "radiofonii": "radiofonie",
    "radiofoniile": "radiofonie",
    "radiofoniilor": "radiofonie",
    "radiofrecvența": "radiofrecvență",
    "radiofrecvențe": "radiofrecvență",
    "radiofrecvenței": "radiofrecvență",
    "radiofrecvențele": "radiofrecvență",
    "radiofrecvențelor": "radiofrecvență",
    "radiografica": "radiografic",
    "radiografică": "radiografic",
    "radiografice": "radiografic",
    "radiograficei": "radiografic",
    "radiograficele": "radiografic",
    "radiograficelor": "radiografic",
    "radiografici": "radiografic",
    "radiograficii": "radiografic",
    "radiograficilor": "radiografic",
    "radiograficul": "radiografic",
    "radiograficului": "radiografic",
    "radiografia": "radiografie",
    "radiografiei": "radiografie",
    "radiografii": "radiografie",
    "radiografiile": "radiografie",
    "radiografiilor": "radiografie",
    "radiografierea": "radiografiere",
    "radiografieri": "radiografiere",
    "radiografierii": "radiografiere",
    "radiografierile": "radiografiere",
    "radiografierilor": "radiografiere",
    "radiograma": "radiogramă",
    "radiograme": "radiogramă",
    "radiogramei": "radiogramă",
    "radiogramele": "radiogramă",
    "radiogramelor": "radiogramă",
    "radiojurnale": "radiojurnal",
    "radiojurnalele": "radiojurnal",
    "radiojurnalelor": "radiojurnal",
    "radiojurnalul": "radiojurnal",
    "radiojurnalului": "radiojurnal",
    "radiolocația": "radiolocație",
    "radiolocației": "radiolocație",
    "radiolocații": "radiolocație",
    "radiolocațiile": "radiolocație",
    "radiolocațiilor": "radiolocație",
    "radiologi": "radiolog",
    "radiologii": "radiolog",
    "radiologilor": "radiolog",
    "radiologul": "radiolog",
    "radiologului": "radiolog",
    "radiologa": "radiologă",
    "radiologe": "radiologă",
    "radiologei": "radiologă",
    "radiologele": "radiologă",
    "radiologelor": "radiologă",
    "radiologia": "radiologie",
    "radiologiei": "radiologie",
    "radiologii": "radiologie",
    "radiologiile": "radiologie",
    "radiologiilor": "radiologie",
    "radiometalografia": "radiometalografie",
    "radiometalografiei": "radiometalografie",
    "radiometalografii": "radiometalografie",
    "radiometalografiile": "radiometalografie",
    "radiometalografiilor": "radiometalografie",
    "radiometre": "radiometru",
    "radiometrele": "radiometru",
    "radiometrelor": "radiometru",
    "radiometrul": "radiometru",
    "radiometrului": "radiometru",
    "radionavigația": "radionavigație",
    "radionavigației": "radionavigație",
    "radionavigații": "radionavigație",
    "radionavigațiile": "radionavigație",
    "radionavigațiilor": "radionavigație",
    "radioreceptoare": "radioreceptor",
    "radioreceptoarele": "radioreceptor",
    "radioreceptoarelor": "radioreceptor",
    "radioreceptorul": "radioreceptor",
    "radioreceptorului": "radioreceptor",
    "radiorelee": "radioreleu",
    "radioreleele": "radioreleu",
    "radioreleelor": "radioreleu",
    "radioreleul": "radioreleu",
    "radioreleului": "radioreleu",
    "radioasa": "radios",
    "radioasă": "radios",
    "radioase": "radios",
    "radioasei": "radios",
    "radioasele": "radios",
    "radioaselor": "radios",
    "radioși": "radios",
    "radioșii": "radios",
    "radioșilor": "radios",
    "radiosul": "radios",
    "radiosului": "radios",
    "radioscopica": "radioscopic",
    "radioscopică": "radioscopic",
    "radioscopice": "radioscopic",
    "radioscopicei": "radioscopic",
    "radioscopicele": "radioscopic",
    "radioscopicelor": "radioscopic",
    "radioscopici": "radioscopic",
    "radioscopicii": "radioscopic",
    "radioscopicilor": "radioscopic",
    "radioscopicul": "radioscopic",
    "radioscopicului": "radioscopic",
    "radioscopia": "radioscopie",
    "radioscopiei": "radioscopie",
    "radioscopii": "radioscopie",
    "radioscopiile": "radioscopie",
    "radioscopiilor": "radioscopie",
    "radiotelegrafica": "radiotelegrafic",
    "radiotelegrafică": "radiotelegrafic",
    "radiotelegrafice": "radiotelegrafic",
    "radiotelegraficei": "radiotelegrafic",
    "radiotelegraficele": "radiotelegrafic",
    "radiotelegraficelor": "radiotelegrafic",
    "radiotelegrafici": "radiotelegrafic",
    "radiotelegraficii": "radiotelegrafic",
    "radiotelegraficilor": "radiotelegrafic",
    "radiotelegraficul": "radiotelegrafic",
    "radiotelegraficului": "radiotelegrafic",
    "Radio-Televiziunea": "Radio-Televiziune",
    "radiotransmisiunea": "radiotransmisiune",
    "radiotransmisiuni": "radiotransmisiune",
    "radiotransmisiunii": "radiotransmisiune",
    "radiotransmisiunile": "radiotransmisiune",
    "radiotransmisiunilor": "radiotransmisiune",
    "radiounda": "radioundă",
    "radiounde": "radioundă",
    "radioundei": "radioundă",
    "radioundele": "radioundă",
    "radioundelor": "radioundă",
    "R": "radiu",
    "radiul": "radiu",
    "radiului": "radiu",
    "radiusul": "radius",
    "radiusului": "radius",
    "radiusuri": "radius",
    "radiusurile": "radius",
    "radiusurilor": "radius",
    "rafala": "rafală",
    "rafale": "rafală",
    "rafalei": "rafală",
    "rafalele": "rafală",
    "rafalelor": "rafală",
    "rafia": "rafie",
    "rafiei": "rafie",
    "rafii": "rafie",
    "rafiile": "rafie",
    "rafiilor": "rafie",
    "nemairafinând": "rafina",
    "nemairafinându": "rafina",
    "nerafinând": "rafina",
    "nerafinându": "rafina",
    "rafină": "rafina",
    "rafinai": "rafina",
    "rafinam": "rafina",
    "rafinăm": "rafina",
    "rafinând": "rafina",
    "rafinându": "rafina",
    "rafinară": "rafina",
    "rafinarăm": "rafina",
    "rafinarăți": "rafina",
    "rafinase": "rafina",
    "rafinasem": "rafina",
    "rafinaseră": "rafina",
    "rafinaserăm": "rafina",
    "rafinaserăți": "rafina",
    "rafinaseși": "rafina",
    "rafinași": "rafina",
    "rafinat": "rafina",
    "rafinați": "rafina",
    "rafinau": "rafina",
    "rafinează": "rafina",
    "rafinez": "rafina",
    "rafineze": "rafina",
    "rafinezi": "rafina",
    "rafinamente": "rafinament",
    "rafinamentele": "rafinament",
    "rafinamentelor": "rafinament",
    "rafinamentul": "rafinament",
    "rafinamentului": "rafinament",
    "rafinarea": "rafinare",
    "rafinareo": "rafinare",
    "rafinări": "rafinare",
    "rafinării": "rafinare",
    "rafinările": "rafinare",
    "rafinărilor": "rafinare",
    "rafinăria": "rafinărie",
    "rafinăriei": "rafinărie",
    "rafinării": "rafinărie",
    "rafinăriile": "rafinărie",
    "rafinăriilor": "rafinărie",
    "rafinata": "rafinat",
    "rafinată": "rafinat",
    "rafinate": "rafinat",
    "rafinatei": "rafinat",
    "rafinatele": "rafinat",
    "rafinatelor": "rafinat",
    "rafinați": "rafinat",
    "rafinații": "rafinat",
    "rafinaților": "rafinat",
    "rafinato": "rafinat",
    "rafinatul": "rafinat",
    "rafinatule": "rafinat",
    "rafinatului": "rafinat",
    "raftul": "raft",
    "raftului": "raft",
    "rafturi": "raft",
    "rafturile": "raft",
    "rafturilor": "raft",
    "nemairăfuind": "răfui",
    "nemairăfuindu": "răfui",
    "nerăfuind": "răfui",
    "nerăfuindu": "răfui",
    "răfuia": "răfui",
    "răfuiai": "răfui",
    "răfuiam": "răfui",
    "răfuiască": "răfui",
    "răfuiați": "răfui",
    "răfuiau": "răfui",
    "răfuiesc": "răfui",
    "răfuiește": "răfui",
    "răfuiești": "răfui",
    "răfuii": "răfui",
    "răfuim": "răfui",
    "răfuind": "răfui",
    "răfuindu": "răfui",
    "răfuiră": "răfui",
    "răfuirăm": "răfui",
    "răfuirăți": "răfui",
    "răfuise": "răfui",
    "răfuisem": "răfui",
    "răfuiseră": "răfui",
    "răfuiserăm": "răfui",
    "răfuiserăți": "răfui",
    "răfuiseși": "răfui",
    "răfuiși": "răfui",
    "răfuit": "răfui",
    "răfuiți": "răfui",
    "răfuiala": "răfuială",
    "răfuialo": "răfuială",
    "răfuieli": "răfuială",
    "răfuielii": "răfuială",
    "răfuielile": "răfuială",
    "răfuielilor": "răfuială",
    "răfuită": "răfuit",
    "răfuite": "răfuit",
    "răfuiți": "răfuit",
    "nemairâgâind": "râgâi",
    "nemairâgâindu": "râgâi",
    "nerâgâind": "râgâi",
    "nerâgâindu": "râgâi",
    "râgâia": "râgâi",
    "râgâiai": "râgâi",
    "râgâiam": "râgâi",
    "râgâiați": "râgâi",
    "râgâiau": "râgâi",
    "râgâie": "râgâi",
    "râgâii": "râgâi",
    "râgâim": "râgâi",
    "râgâind": "râgâi",
    "râgâindu": "râgâi",
    "râgâiră": "râgâi",
    "râgâirăm": "râgâi",
    "râgâirăți": "râgâi",
    "râgâise": "râgâi",
    "râgâisem": "râgâi",
    "râgâiseră": "râgâi",
    "râgâiserăm": "râgâi",
    "râgâiserăți": "râgâi",
    "râgâiseși": "râgâi",
    "râgâiși": "râgâi",
    "râgâit": "râgâi",
    "râgâiți": "râgâi",
    "râgâiala": "râgâială",
    "râgâieli": "râgâială",
    "râgâielii": "râgâială",
    "râgâielile": "râgâială",
    "râgâielilor": "râgâială",
    "râgâită": "râgâit",
    "râgâite": "râgâit",
    "râgâiți": "râgâit",
    "răgazul": "răgaz",
    "răgazului": "răgaz",
    "răgazuri": "răgaz",
    "răgazurile": "răgaz",
    "răgazurilor": "răgaz",
    "nemairăgând": "rage",
    "nemairăgându": "rage",
    "nerăgând": "rage",
    "nerăgându": "rage",
    "rag": "rage",
    "ragă": "rage",
    "răgând": "rage",
    "răgându": "rage",
    "răgea": "rage",
    "răgeai": "rage",
    "răgeam": "rage",
    "răgeați": "rage",
    "răgeau": "rage",
    "ragem": "rage",
    "rageți": "rage",
    "ragi": "rage",
    "răgete": "răget",
    "răgetele": "răget",
    "răgetelor": "răget",
    "răgetul": "răget",
    "răgetului": "răget",
    "răgilat": "răgila",
    "răgilata": "răgilat",
    "răgilată": "răgilat",
    "răgilate": "răgilat",
    "răgilatei": "răgilat",
    "răgilatele": "răgilat",
    "răgilatelor": "răgilat",
    "răgilați": "răgilat",
    "răgilații": "răgilat",
    "răgilaților": "răgilat",
    "răgilatul": "răgilat",
    "răgilatului": "răgilat",
    "raglane": "raglan",
    "raglanele": "raglan",
    "raglanelor": "raglan",
    "raglanul": "raglan",
    "raglanului": "raglan",
    "nemairăgușind": "răguși",
    "nemairăgușindu": "răguși",
    "nerăgușind": "răguși",
    "nerăgușindu": "răguși",
    "răgușea": "răguși",
    "răgușeai": "răguși",
    "răgușeam": "răguși",
    "răgușească": "răguși",
    "răgușeați": "răguși",
    "răgușeau": "răguși",
    "răgușesc": "răguși",
    "răgușește": "răguși",
    "răgușești": "răguși",
    "răgușii": "răguși",
    "răgușim": "răguși",
    "răgușind": "răguși",
    "răgușindu": "răguși",
    "răgușiră": "răguși",
    "răgușirăm": "răguși",
    "răgușirăți": "răguși",
    "răgușise": "răguși",
    "răgușisem": "răguși",
    "răgușiseră": "răguși",
    "răgușiserăm": "răguși",
    "răgușiserăți": "răguși",
    "răgușiseși": "răguși",
    "răgușiși": "răguși",
    "răgușit": "răguși",
    "răgușiți": "răguși",
    "răgușita": "răgușit",
    "răgușită": "răgușit",
    "răgușite": "răgușit",
    "răgușitei": "răgușit",
    "răgușitele": "răgușit",
    "răgușitelor": "răgușit",
    "răgușiți": "răgușit",
    "răgușiții": "răgușit",
    "răgușiților": "răgușit",
    "răgușito": "răgușit",
    "răgușitul": "răgușit",
    "răgușitule": "răgușit",
    "răgușitului": "răgușit",
    "rahatul": "rahat",
    "rahatului": "rahat",
    "rahaturi": "rahat",
    "rahaturile": "rahat",
    "rahaturilor": "rahat",
    "rahianestezia": "rahianestezie",
    "rahianesteziei": "rahianestezie",
    "rahianestezii": "rahianestezie",
    "rahianesteziile": "rahianestezie",
    "rahianesteziilor": "rahianestezie",
    "rahidiana": "rahidian",
    "rahidiană": "rahidian",
    "rahidianul": "rahidian",
    "rahidianului": "rahidian",
    "rahidiene": "rahidian",
    "rahidienei": "rahidian",
    "rahidienele": "rahidian",
    "rahidienelor": "rahidian",
    "rahidieni": "rahidian",
    "rahidienii": "rahidian",
    "rahidienilor": "rahidian",
    "rahitica": "rahitic",
    "rahitică": "rahitic",
    "rahitice": "rahitic",
    "rahiticei": "rahitic",
    "rahiticele": "rahitic",
    "rahiticelor": "rahitic",
    "rahitici": "rahitic",
    "rahiticii": "rahitic",
    "rahiticilor": "rahitic",
    "rahiticul": "rahitic",
    "rahiticului": "rahitic",
    "rahitisme": "rahitism",
    "rahitismele": "rahitism",
    "rahitismelor": "rahitism",
    "rahitismul": "rahitism",
    "rahitismului": "rahitism",
    "Rahovei": "Rahova",
    "raiul": "rai",
    "raiului": "rai",
    "raiuri": "rai",
    "raiurile": "rai",
    "raiurilor": "rai",
    "raidul": "raid",
    "raidului": "raid",
    "raiduri": "raid",
    "raidurile": "raid",
    "raidurilor": "raid",
    "raidul-anchetă": "raid-anchetă",
    "raidului-anchetă": "raid-anchetă",
    "raiduri-anchetă": "raid-anchetă",
    "raidurile-anchetă": "raid-anchetă",
    "raidurilor-anchetă": "raid-anchetă",
    "raioane": "raion",
    "raioanele": "raion",
    "raioanelor": "raion",
    "raionul": "raion",
    "raionului": "raion",
    "raionala": "raional",
    "raională": "raional",
    "raionale": "raional",
    "raionalei": "raional",
    "raionalele": "raional",
    "raionalelor": "raional",
    "raionali": "raional",
    "raionalii": "raional",
    "raionalilor": "raional",
    "raionalul": "raional",
    "raionalului": "raional",
    "râioasa": "râios",
    "râioasă": "râios",
    "râioase": "râios",
    "râioasei": "râios",
    "râioasele": "râios",
    "râioaselor": "râios",
    "râioși": "râios",
    "râioșii": "râios",
    "râioșilor": "râios",
    "râiosul": "râios",
    "râiosului": "râios",
    "raita": "raită",
    "raite": "raită",
    "raitei": "raită",
    "raitele": "raită",
    "raitelor": "raită",
    "rajahi": "rajah",
    "rajahii": "rajah",
    "rajahilor": "rajah",
    "rajahul": "rajah",
    "rajahului": "rajah",
    "ralantiul": "ralanti",
    "ralantiului": "ralanti",
    "ralantiuri": "ralanti",
    "ralantiurile": "ralanti",
    "ralantiurilor": "ralanti",
    "nemairaliind": "ralia",
    "nemairaliindu": "ralia",
    "neraliind": "ralia",
    "neraliindu": "ralia",
    "raliai": "ralia",
    "raliam": "ralia",
    "raliară": "ralia",
    "raliarăm": "ralia",
    "raliarăți": "ralia",
    "raliase": "ralia",
    "raliasem": "ralia",
    "raliaseră": "ralia",
    "raliaserăm": "ralia",
    "raliaserăți": "ralia",
    "raliaseși": "ralia",
    "raliași": "ralia",
    "raliat": "ralia",
    "raliați": "ralia",
    "raliau": "ralia",
    "raliază": "ralia",
    "ralie": "ralia",
    "raliem": "ralia",
    "raliez": "ralia",
    "ralieze": "ralia",
    "raliezi": "ralia",
    "raliind": "ralia",
    "raliindu": "ralia",
    "raliată": "raliat",
    "raliate": "raliat",
    "raliați": "raliat",
    "ralierea": "raliere",
    "raliereo": "raliere",
    "ralieri": "raliere",
    "ralierii": "raliere",
    "ralierile": "raliere",
    "ralierilor": "raliere",
    "raliul": "raliu",
    "raliului": "raliu",
    "raliuri": "raliu",
    "raliurile": "raliu",
    "raliurilor": "raliu",
    "ramul": "ram",
    "ramului": "ram",
    "ramuri": "ram",
    "ramurile": "ram",
    "ramurilor": "ram",
    "rama": "ramă",
    "rame": "ramă",
    "ramei": "ramă",
    "ramele": "ramă",
    "ramelor": "ramă",
    "nemairâmând": "râma",
    "nemairâmându": "râma",
    "nerâmând": "râma",
    "nerâmându": "râma",
    "râm": "râma",
    "râmă": "râma",
    "râmai": "râma",
    "râmam": "râma",
    "râmăm": "râma",
    "râmând": "râma",
    "râmându": "râma",
    "râmară": "râma",
    "râmarăm": "râma",
    "râmarăți": "râma",
    "râmase": "râma",
    "râmasem": "râma",
    "râmaseră": "râma",
    "râmaserăm": "râma",
    "râmaserăți": "râma",
    "râmaseși": "râma",
    "râmași": "râma",
    "râmat": "râma",
    "râmați": "râma",
    "râmau": "râma",
    "râme": "râma",
    "râmi": "râma",
    "râma": "râmă",
    "râme": "râmă",
    "râmei": "râmă",
    "râmele": "râmă",
    "râmelor": "râmă",
    "nemairămânând": "rămâne",
    "nemairămânându": "rămâne",
    "nerămânând": "rămâne",
    "nerămânându": "rămâne",
    "rămâi": "rămâne",
    "rămân": "rămâne",
    "rămână": "rămâne",
    "rămânând": "rămâne",
    "rămânându": "rămâne",
    "rămânea": "rămâne",
    "rămâneai": "rămâne",
    "rămâneam": "rămâne",
    "rămâneați": "rămâne",
    "rămâneau": "rămâne",
    "rămânem": "rămâne",
    "rămâneți": "rămâne",
    "rămas": "rămâne",
    "rămase": "rămâne",
    "rămaseră": "rămâne",
    "rămaserăm": "rămâne",
    "rămaserăți": "rămâne",
    "rămăsese": "rămâne",
    "rămăsesem": "rămâne",
    "rămăseseră": "rămâne",
    "rămăseserăm": "rămâne",
    "rămăseserăți": "rămâne",
    "rămăseseși": "rămâne",
    "rămânerea": "rămânere",
    "rămânereo": "rămânere",
    "rămâneri": "rămânere",
    "rămânerii": "rămânere",
    "rămânerile": "rămânere",
    "rămânerilor": "rămânere",
    "rămasa": "rămas",
    "rămasă": "rămas",
    "rămase": "rămas",
    "rămasei": "rămas",
    "rămasele": "rămas",
    "rămaselor": "rămas",
    "rămași": "rămas",
    "rămașii": "rămas",
    "rămașilor": "rămas",
    "rămasul": "rămas",
    "rămasului": "rămas",
    "rămasuri": "rămas",
    "rămasurile": "rămas",
    "rămasurilor": "rămas",
    "rămășagul": "rămășag",
    "rămășagului": "rămășag",
    "rămășaguri": "rămășag",
    "rămășagurile": "rămășag",
    "rămășagurilor": "rămășag",
    "rămășița": "rămășiță",
    "rămășițe": "rămășiță",
    "rămășiței": "rămășiță",
    "rămășițele": "rămășiță",
    "rămășițelor": "rămășiță",
    "râmată": "râmat",
    "râmate": "râmat",
    "râmați": "râmat",
    "râmători": "râmător",
    "râmătorii": "râmător",
    "râmătorilor": "râmător",
    "râmătorul": "râmător",
    "râmătorului": "râmător",
    "ramazanul": "ramazan",
    "ramazanului": "ramazan",
    "nemairambleiind": "rambleia",
    "nemairambleiindu": "rambleia",
    "nerambleiind": "rambleia",
    "nerambleiindu": "rambleia",
    "rambleiai": "rambleia",
    "rambleiam": "rambleia",
    "rambleiară": "rambleia",
    "rambleiarăm": "rambleia",
    "rambleiarăți": "rambleia",
    "rambleiase": "rambleia",
    "rambleiasem": "rambleia",
    "rambleiaseră": "rambleia",
    "rambleiaserăm": "rambleia",
    "rambleiaserăți": "rambleia",
    "rambleiaseși": "rambleia",
    "rambleiași": "rambleia",
    "rambleiat": "rambleia",
    "rambleiați": "rambleia",
    "rambleiau": "rambleia",
    "rambleiază": "rambleia",
    "rambleie": "rambleia",
    "rambleiem": "rambleia",
    "rambleiez": "rambleia",
    "rambleieze": "rambleia",
    "rambleiezi": "rambleia",
    "rambleind": "rambleia",
    "rambleindu": "rambleia",
    "rambleiată": "rambleiat",
    "rambleiate": "rambleiat",
    "rambleiați": "rambleiat",
    "rambleierea": "rambleiere",
    "rambleiereo": "rambleiere",
    "rambleieri": "rambleiere",
    "rambleierii": "rambleiere",
    "rambleierile": "rambleiere",
    "rambleierilor": "rambleiere",
    "rambleul": "rambleu",
    "rambleului": "rambleu",
    "rambleuri": "rambleu",
    "rambleurile": "rambleu",
    "rambleurilor": "rambleu",
    "rambursul": "ramburs",
    "rambursului": "ramburs",
    "rambursuri": "ramburs",
    "rambursurile": "ramburs",
    "rambursurilor": "ramburs",
    "nemairambursând": "rambursa",
    "nemairambursându": "rambursa",
    "nerambursând": "rambursa",
    "nerambursându": "rambursa",
    "rambursă": "rambursa",
    "rambursai": "rambursa",
    "rambursam": "rambursa",
    "rambursăm": "rambursa",
    "rambursând": "rambursa",
    "rambursându": "rambursa",
    "rambursară": "rambursa",
    "rambursarăm": "rambursa",
    "rambursarăți": "rambursa",
    "rambursase": "rambursa",
    "rambursasem": "rambursa",
    "rambursaseră": "rambursa",
    "rambursaserăm": "rambursa",
    "rambursaserăți": "rambursa",
    "rambursaseși": "rambursa",
    "rambursași": "rambursa",
    "rambursat": "rambursa",
    "rambursați": "rambursa",
    "rambursau": "rambursa",
    "rambursează": "rambursa",
    "rambursez": "rambursa",
    "ramburseze": "rambursa",
    "rambursezi": "rambursa",
    "rambursarea": "rambursare",
    "rambursareo": "rambursare",
    "rambursări": "rambursare",
    "rambursării": "rambursare",
    "rambursările": "rambursare",
    "rambursărilor": "rambursare",
    "rambursată": "rambursat",
    "rambursate": "rambursat",
    "rambursați": "rambursat",
    "nemairamificând": "ramifica",
    "nemairamificându": "ramifica",
    "neramificând": "ramifica",
    "neramificându": "ramifica",
    "ramific": "ramifica",
    "ramifică": "ramifica",
    "ramificai": "ramifica",
    "ramificam": "ramifica",
    "ramificăm": "ramifica",
    "ramificând": "ramifica",
    "ramificându": "ramifica",
    "ramificară": "ramifica",
    "ramificarăm": "ramifica",
    "ramificarăți": "ramifica",
    "ramificase": "ramifica",
    "ramificasem": "ramifica",
    "ramificaseră": "ramifica",
    "ramificaserăm": "ramifica",
    "ramificaserăți": "ramifica",
    "ramificaseși": "ramifica",
    "ramificași": "ramifica",
    "ramificat": "ramifica",
    "ramificați": "ramifica",
    "ramificau": "ramifica",
    "ramifice": "ramifica",
    "ramifici": "ramifica",
    "ramificarea": "ramificare",
    "ramificareo": "ramificare",
    "ramificări": "ramificare",
    "ramificării": "ramificare",
    "ramificările": "ramificare",
    "ramificărilor": "ramificare",
    "ramificată": "ramificat",
    "ramificate": "ramificat",
    "ramificați": "ramificat",
    "ramificația": "ramificație",
    "ramificației": "ramificație",
    "ramificații": "ramificație",
    "ramificațiile": "ramificație",
    "ramificațiilor": "ramificație",
    "Rm.": "Râmnicu",
    "Râmnicului": "Râmnicul",
    "nemairamolind": "ramoli",
    "nemairamolindu": "ramoli",
    "neramolind": "ramoli",
    "neramolindu": "ramoli",
    "ramolea": "ramoli",
    "ramoleai": "ramoli",
    "ramoleam": "ramoli",
    "ramolească": "ramoli",
    "ramoleați": "ramoli",
    "ramoleau": "ramoli",
    "ramolesc": "ramoli",
    "ramolește": "ramoli",
    "ramolești": "ramoli",
    "ramolii": "ramoli",
    "ramolim": "ramoli",
    "ramolind": "ramoli",
    "ramolindu": "ramoli",
    "ramoliră": "ramoli",
    "ramolirăm": "ramoli",
    "ramolirăți": "ramoli",
    "ramolise": "ramoli",
    "ramolisem": "ramoli",
    "ramoliseră": "ramoli",
    "ramoliserăm": "ramoli",
    "ramoliserăți": "ramoli",
    "ramoliseși": "ramoli",
    "ramoliși": "ramoli",
    "ramolit": "ramoli",
    "ramoliți": "ramoli",
    "ramolirea": "ramolire",
    "ramolireo": "ramolire",
    "ramoliri": "ramolire",
    "ramolirii": "ramolire",
    "ramolirile": "ramolire",
    "ramolirilor": "ramolire",
    "ramolita": "ramolit",
    "ramolită": "ramolit",
    "ramolite": "ramolit",
    "ramolitei": "ramolit",
    "ramolitele": "ramolit",
    "ramolitelor": "ramolit",
    "ramoliți": "ramolit",
    "ramoliții": "ramolit",
    "ramoliților": "ramolit",
    "ramolitul": "ramolit",
    "ramolitului": "ramolit",
    "rampa": "rampă",
    "rampe": "rampă",
    "rampei": "rampă",
    "rampele": "rampă",
    "rampelor": "rampă",
    "ramura": "ramură",
    "ramuri": "ramură",
    "ramurii": "ramură",
    "ramurile": "ramură",
    "ramurilor": "ramură",
    "rămurele": "rămurică",
    "rămurelei": "rămurică",
    "rămurelele": "rămurică",
    "rămurelelor": "rămurică",
    "rămurica": "rămurică",
    "rămurișul": "rămuriș",
    "rămurișului": "rămuriș",
    "rămurișuri": "rămuriș",
    "rămurișurile": "rămuriș",
    "rămurișurilor": "rămuriș",
    "rămuroasa": "rămuros",
    "rămuroasă": "rămuros",
    "rămuroase": "rămuros",
    "rămuroasei": "rămuros",
    "rămuroasele": "rămuros",
    "rămuroaselor": "rămuros",
    "rămuroși": "rămuros",
    "rămuroșii": "rămuros",
    "rămuroșilor": "rămuros",
    "rămurosul": "rămuros",
    "rămurosului": "rămuros",
    "rana": "rană",
    "răni": "rană",
    "rănii": "rană",
    "rănile": "rană",
    "rănilor": "rană",
    "rânceda": "rânced",
    "râncedă": "rânced",
    "râncede": "rânced",
    "râncedei": "rânced",
    "râncedele": "rânced",
    "râncedelor": "rânced",
    "râncedul": "rânced",
    "râncedului": "rânced",
    "râncezi": "rânced",
    "râncezii": "rânced",
    "râncezilor": "rânced",
    "râncezeli": "râncezeală",
    "râncezelii": "râncezeală",
    "râncezelile": "râncezeală",
    "râncezelilor": "râncezeală",
    "nemairâncezind": "râncezi",
    "nemairâncezindu": "râncezi",
    "nerâncezind": "râncezi",
    "nerâncezindu": "râncezi",
    "râncezea": "râncezi",
    "râncezească": "râncezi",
    "râncezeau": "râncezi",
    "râncezesc": "râncezi",
    "râncezește": "râncezi",
    "râncezind": "râncezi",
    "râncezindu": "râncezi",
    "rânceziră": "râncezi",
    "râncezise": "râncezi",
    "rânceziseră": "râncezi",
    "râncezit": "râncezi",
    "râncezită": "râncezit",
    "râncezite": "râncezit",
    "rânceziți": "râncezit",
    "ranchiuna": "ranchiună",
    "ranchiune": "ranchiună",
    "ranchiunei": "ranchiună",
    "ranchiunele": "ranchiună",
    "ranchiunelor": "ranchiună",
    "ranchiunoasa": "ranchiunos",
    "ranchiunoasă": "ranchiunos",
    "ranchiunoase": "ranchiunos",
    "ranchiunoasei": "ranchiunos",
    "ranchiunoasele": "ranchiunos",
    "ranchiunoaselor": "ranchiunos",
    "ranchiunoși": "ranchiunos",
    "ranchiunoșii": "ranchiunos",
    "ranchiunoșilor": "ranchiunos",
    "ranchiunosul": "ranchiunos",
    "ranchiunosului": "ranchiunos",
    "r.": "rând",
    "rându": "rând",
    "rândul": "rând",
    "rândului": "rând",
    "rânduri": "rând",
    "rândurile": "rând",
    "rândurilor": "rând",
    "randamente": "randament",
    "randamentele": "randament",
    "randamentelor": "randament",
    "randamentul": "randament",
    "randamentului": "randament",
    "rândași": "rândaș",
    "rândașii": "rândaș",
    "rândașilor": "rândaș",
    "rândașul": "rândaș",
    "rândașului": "rândaș",
    "nemairânduind": "rândui",
    "nemairânduindu": "rândui",
    "nerânduind": "rândui",
    "nerânduindu": "rândui",
    "rânduia": "rândui",
    "rânduiai": "rândui",
    "rânduiam": "rândui",
    "rânduiască": "rândui",
    "rânduiați": "rândui",
    "rânduiau": "rândui",
    "rânduiesc": "rândui",
    "rânduiește": "rândui",
    "rânduiești": "rândui",
    "rânduii": "rândui",
    "rânduim": "rândui",
    "rânduind": "rândui",
    "rânduindu": "rândui",
    "rânduiră": "rândui",
    "rânduirăm": "rândui",
    "rânduirăți": "rândui",
    "rânduise": "rândui",
    "rânduisem": "rândui",
    "rânduiseră": "rândui",
    "rânduiserăm": "rândui",
    "rânduiserăți": "rândui",
    "rânduiseși": "rândui",
    "rânduiși": "rândui",
    "rânduit": "rândui",
    "rânduiți": "rândui",
    "rânduiala": "rânduială",
    "rânduieli": "rânduială",
    "rânduielii": "rânduială",
    "rânduielile": "rânduială",
    "rânduielilor": "rânduială",
    "rânduirea": "rânduire",
    "rânduiri": "rânduire",
    "rânduirii": "rânduire",
    "rânduirile": "rânduire",
    "rânduirilor": "rânduire",
    "rânduită": "rânduit",
    "rânduite": "rânduit",
    "rânduiți": "rânduit",
    "rânduneaua": "rândunea",
    "rândunele": "rândunea",
    "rândunelele": "rândunea",
    "rândunelelor": "rândunea",
    "rândunica": "rândunică",
    "rândunici": "rândunică",
    "rândunicii": "rândunică",
    "rândunicile": "rândunică",
    "rândunicilor": "rândunică",
    "ranfortul": "ranfort",
    "ranfortului": "ranfort",
    "ranforturi": "ranfort",
    "ranforturile": "ranfort",
    "ranforturilor": "ranfort",
    "rangul": "rang",
    "rangului": "rang",
    "ranguri": "rang",
    "rangurile": "rang",
    "rangurilor": "rang",
    "ranga": "rangă",
    "răngi": "rangă",
    "răngii": "rangă",
    "răngile": "rangă",
    "răngilor": "rangă",
    "nemairânind": "râni",
    "nemairânindu": "râni",
    "nerânind": "râni",
    "nerânindu": "râni",
    "rânea": "râni",
    "râneai": "râni",
    "râneam": "râni",
    "rânească": "râni",
    "râneați": "râni",
    "râneau": "râni",
    "rânesc": "râni",
    "rânește": "râni",
    "rânești": "râni",
    "rânii": "râni",
    "rânim": "râni",
    "rânind": "râni",
    "rânindu": "râni",
    "râniră": "râni",
    "rânirăm": "râni",
    "rânirăți": "râni",
    "rânise": "râni",
    "rânisem": "râni",
    "râniseră": "râni",
    "râniserăm": "râni",
    "râniserăți": "râni",
    "râniseși": "râni",
    "râniși": "râni",
    "rânit": "râni",
    "râniți": "râni",
    "nemairănind": "răni",
    "nemairănindu": "răni",
    "nerănind": "răni",
    "nerănindu": "răni",
    "rănea": "răni",
    "răneai": "răni",
    "răneam": "răni",
    "rănească": "răni",
    "răneați": "răni",
    "răneau": "răni",
    "rănesc": "răni",
    "rănește": "răni",
    "rănești": "răni",
    "rănii": "răni",
    "rănim": "răni",
    "rănind": "răni",
    "rănindu": "răni",
    "răniră": "răni",
    "rănirăm": "răni",
    "rănirăți": "răni",
    "rănise": "răni",
    "rănisem": "răni",
    "răniseră": "răni",
    "răniserăm": "răni",
    "răniserăți": "răni",
    "răniseși": "răni",
    "răniși": "răni",
    "rănit": "răni",
    "răniți": "răni",
    "rănitu": "răni",
    "rânită": "rânit",
    "rânite": "rânit",
    "râniți": "rânit",
    "rănita": "rănit",
    "rănită": "rănit",
    "rănite": "rănit",
    "rănitei": "rănit",
    "rănitele": "rănit",
    "rănitelor": "rănit",
    "răniți": "rănit",
    "răniții": "rănit",
    "răniților": "rănit",
    "rănitul": "rănit",
    "rănitului": "rănit",
    "ranița": "raniță",
    "ranițe": "raniță",
    "raniței": "raniță",
    "ranițele": "raniță",
    "ranițelor": "raniță",
    "rânjete": "rânjet",
    "rânjetele": "rânjet",
    "rânjetelor": "rânjet",
    "rânjetul": "rânjet",
    "rânjetului": "rânjet",
    "nemairânjind": "rânji",
    "nemairânjindu": "rânji",
    "nerânjind": "rânji",
    "nerânjindu": "rânji",
    "rânjea": "rânji",
    "rânjeai": "rânji",
    "rânjeam": "rânji",
    "rânjească": "rânji",
    "rânjeați": "rânji",
    "rânjeau": "rânji",
    "rânjesc": "rânji",
    "rânjește": "rânji",
    "rânjești": "rânji",
    "rânjii": "rânji",
    "rânjim": "rânji",
    "rânjind": "rânji",
    "rânjindu": "rânji",
    "rânjiră": "rânji",
    "rânjirăm": "rânji",
    "rânjirăți": "rânji",
    "rânjise": "rânji",
    "rânjisem": "rânji",
    "rânjiseră": "rânji",
    "rânjiserăm": "rânji",
    "rânjiserăți": "rânji",
    "rânjiseși": "rânji",
    "rânjiși": "rânji",
    "rânjit": "rânji",
    "rânjiți": "rânji",
    "rânjită": "rânjit",
    "rânjite": "rânjit",
    "rânjiți": "rânjit",
    "rântașul": "rântaș",
    "rântașului": "rântaș",
    "rântașuri": "rântaș",
    "rântașurile": "rântaș",
    "rântașurilor": "rântaș",
    "râpa": "râpă",
    "râpe": "râpă",
    "râpei": "râpă",
    "râpele": "râpă",
    "râpelor": "râpă",
    "rapacea": "rapace",
    "rapacei": "rapace",
    "rapacele": "rapace",
    "rapacelor": "rapace",
    "rapacelui": "rapace",
    "rapaci": "rapace",
    "rapacii": "rapace",
    "rapacilor": "rapace",
    "rapacitatea": "rapacitate",
    "rapacități": "rapacitate",
    "rapacității": "rapacitate",
    "rapacitățile": "rapacitate",
    "rapacităților": "rapacitate",
    "răpăia": "răpăi",
    "răpăiai": "răpăi",
    "răpăiam": "răpăi",
    "răpăiați": "răpăi",
    "răpăiau": "răpăi",
    "răpăie": "răpăi",
    "răpăii": "răpăi",
    "răpăim": "răpăi",
    "răpăind": "răpăi",
    "răpăindu": "răpăi",
    "răpăiră": "răpăi",
    "răpăirăm": "răpăi",
    "răpăirăți": "răpăi",
    "răpăise": "răpăi",
    "răpăisem": "răpăi",
    "răpăiseră": "răpăi",
    "răpăiserăm": "răpăi",
    "răpăiserăți": "răpăi",
    "răpăiseși": "răpăi",
    "răpăiși": "răpăi",
    "răpăit": "răpăi",
    "răpăiți": "răpăi",
    "răpăitu": "răpăi",
    "răpăiala": "răpăială",
    "răpăieli": "răpăială",
    "răpăielii": "răpăială",
    "răpăielile": "răpăială",
    "răpăielilor": "răpăială",
    "răpăită": "răpăit",
    "răpăite": "răpăit",
    "răpăiți": "răpăit",
    "rapănul": "rapăn",
    "rapănului": "rapăn",
    "răpănoasa": "răpănos",
    "răpănoasă": "răpănos",
    "răpănoase": "răpănos",
    "răpănoasei": "răpănos",
    "răpănoasele": "răpănos",
    "răpănoaselor": "răpănos",
    "răpănoși": "răpănos",
    "răpănoșii": "răpănos",
    "răpănoșilor": "răpănos",
    "răpănosul": "răpănos",
    "răpănosului": "răpănos",
    "răpciuga": "răpciugă",
    "răpciuge": "răpciugă",
    "răpciugei": "răpciugă",
    "răpciugele": "răpciugă",
    "răpciugelor": "răpciugă",
    "răpciugoasa": "răpciugos",
    "răpciugoasă": "răpciugos",
    "răpciugoase": "răpciugos",
    "răpciugoasei": "răpciugos",
    "răpciugoasele": "răpciugos",
    "răpciugoaselor": "răpciugos",
    "răpciugoși": "răpciugos",
    "răpciugoșii": "răpciugos",
    "răpciugoșilor": "răpciugos",
    "răpciugosul": "răpciugos",
    "răpciugosului": "răpciugos",
    "rapelul": "rapel",
    "rapelului": "rapel",
    "rapeluri": "rapel",
    "rapelurile": "rapel",
    "rapelurilor": "rapel",
    "nemairăpind": "răpi",
    "nemairăpindu": "răpi",
    "nerăpind": "răpi",
    "nerăpindu": "răpi",
    "răpea": "răpi",
    "răpeai": "răpi",
    "răpeam": "răpi",
    "răpească": "răpi",
    "răpeați": "răpi",
    "răpeau": "răpi",
    "răpesc": "răpi",
    "răpește": "răpi",
    "răpești": "răpi",
    "răpii": "răpi",
    "răpim": "răpi",
    "răpind": "răpi",
    "răpindu": "răpi",
    "răpiră": "răpi",
    "răpirăm": "răpi",
    "răpirăți": "răpi",
    "răpise": "răpi",
    "răpisem": "răpi",
    "răpiseră": "răpi",
    "răpiserăm": "răpi",
    "răpiserăți": "răpi",
    "răpiseși": "răpi",
    "răpiși": "răpi",
    "răpit": "răpi",
    "răpiți": "răpi",
    "rapida": "rapid",
    "rapidă": "rapid",
    "rapide": "rapid",
    "rapidei": "rapid",
    "rapidele": "rapid",
    "rapidelor": "rapid",
    "rapidul": "rapid",
    "Rapidului": "Rapid",
    "rapizi": "rapid",
    "rapizii": "rapid",
    "rapizilor": "rapid",
    "rapiditatea": "rapiditate",
    "rapidități": "rapiditate",
    "rapidității": "rapiditate",
    "rapiditățile": "rapiditate",
    "rapidităților": "rapiditate",
    "răpirea": "răpire",
    "răpiri": "răpire",
    "răpirii": "răpire",
    "răpirile": "răpire",
    "răpirilor": "răpire",
    "răpită": "răpit",
    "răpite": "răpit",
    "răpiți": "răpit",
    "rapița": "rapiță",
    "rapițe": "rapiță",
    "rapiței": "rapiță",
    "rapițele": "rapiță",
    "rapițelor": "rapiță",
    "rapoarte": "raport",
    "rapoartele": "raport",
    "rapoartelor": "raport",
    "raportul": "raport",
    "raportului": "raport",
    "raporturi": "raport",
    "raporturile": "raport",
    "raporturilor": "raport",
    "nemairaportând": "raporta",
    "nemairaportându": "raporta",
    "neraportând": "raporta",
    "neraportându": "raporta",
    "raportă": "raporta",
    "raportai": "raporta",
    "raportam": "raporta",
    "raportăm": "raporta",
    "raportând": "raporta",
    "raportându": "raporta",
    "raportară": "raporta",
    "raportarăm": "raporta",
    "raportarăți": "raporta",
    "raportase": "raporta",
    "raportasem": "raporta",
    "raportaseră": "raporta",
    "raportaserăm": "raporta",
    "raportaserăți": "raporta",
    "raportaseși": "raporta",
    "raportași": "raporta",
    "raportat": "raporta",
    "raportați": "raporta",
    "raportau": "raporta",
    "raportează": "raporta",
    "raportez": "raporta",
    "raporteze": "raporta",
    "raportezi": "raporta",
    "raportată": "raportat",
    "raportate": "raportat",
    "raportați": "raportat",
    "raportoare": "raportor",
    "raportoarele": "raportor",
    "raportoarelor": "raportor",
    "raportorul": "raportor",
    "raportorului": "raportor",
    "nemairăposând": "răposa",
    "nemairăposându": "răposa",
    "nerăposând": "răposa",
    "nerăposându": "răposa",
    "răposă": "răposa",
    "răposai": "răposa",
    "răposam": "răposa",
    "răposăm": "răposa",
    "răposând": "răposa",
    "răposându": "răposa",
    "răposară": "răposa",
    "răposarăm": "răposa",
    "răposarăți": "răposa",
    "răposase": "răposa",
    "răposasem": "răposa",
    "răposaseră": "răposa",
    "răposaserăm": "răposa",
    "răposaserăți": "răposa",
    "răposaseși": "răposa",
    "răposași": "răposa",
    "răposat": "răposa",
    "răposați": "răposa",
    "răposau": "răposa",
    "răposează": "răposa",
    "răposez": "răposa",
    "răposeze": "răposa",
    "răposezi": "răposa",
    "răposata": "răposat",
    "răposată": "răposat",
    "răposate": "răposat",
    "răposatei": "răposat",
    "răposatele": "răposat",
    "răposatelor": "răposat",
    "răposați": "răposat",
    "răposații": "răposat",
    "răposaților": "răposat",
    "răposatul": "răposat",
    "răposatului": "răposat",
    "rapsodul": "rapsod",
    "rapsodului": "rapsod",
    "rapsozi": "rapsod",
    "rapsozii": "rapsod",
    "rapsozilor": "rapsod",
    "rapsodia": "rapsodie",
    "rapsodiei": "rapsodie",
    "rapsodii": "rapsodie",
    "rapsodiile": "rapsodie",
    "rapsodiilor": "rapsodie",
    "nemairăpunând": "răpune",
    "nemairăpunându": "răpune",
    "nerăpunând": "răpune",
    "nerăpunându": "răpune",
    "răpui": "răpune",
    "răpun": "răpune",
    "răpună": "răpune",
    "răpunând": "răpune",
    "răpunându": "răpune",
    "răpunea": "răpune",
    "răpuneai": "răpune",
    "răpuneam": "răpune",
    "răpuneați": "răpune",
    "răpuneau": "răpune",
    "răpunem": "răpune",
    "răpuneți": "răpune",
    "răpus": "răpune",
    "răpuse": "răpune",
    "răpusei": "răpune",
    "răpuseră": "răpune",
    "răpuserăm": "răpune",
    "răpuserăți": "răpune",
    "răpusese": "răpune",
    "răpusesem": "răpune",
    "răpuseseră": "răpune",
    "răpuseserăm": "răpune",
    "răpuseserăți": "răpune",
    "răpuseseși": "răpune",
    "răpuseși": "răpune",
    "răpunerea": "răpunere",
    "răpunereo": "răpunere",
    "răpuneri": "răpunere",
    "răpunerii": "răpunere",
    "răpunerile": "răpunere",
    "răpunerilor": "răpunere",
    "răpusa": "răpus",
    "răpusă": "răpus",
    "răpuse": "răpus",
    "răpusei": "răpus",
    "răpusele": "răpus",
    "răpuselor": "răpus",
    "răpuși": "răpus",
    "răpușii": "răpus",
    "răpușilor": "răpus",
    "răpuso": "răpus",
    "răpusul": "răpus",
    "răpusule": "răpus",
    "răpusului": "răpus",
    "rara": "rar",
    "rară": "rar",
    "rare": "rar",
    "rarei": "rar",
    "rarele": "rar",
    "rarelor": "rar",
    "rari": "rar",
    "rarii": "rar",
    "rarilor": "rar",
    "rarul": "rar",
    "rarului": "rar",
    "Rarăul": "Rarău",
    "Rarăului": "Rarău",
    "nemairarefiind": "rarefia",
    "nemairarefiindu": "rarefia",
    "nerarefiind": "rarefia",
    "nerarefiindu": "rarefia",
    "rarefiai": "rarefia",
    "rarefiam": "rarefia",
    "rarefiară": "rarefia",
    "rarefiarăm": "rarefia",
    "rarefiarăți": "rarefia",
    "rarefiase": "rarefia",
    "rarefiasem": "rarefia",
    "rarefiaseră": "rarefia",
    "rarefiaserăm": "rarefia",
    "rarefiaserăți": "rarefia",
    "rarefiaseși": "rarefia",
    "rarefiași": "rarefia",
    "rarefiat": "rarefia",
    "rarefiați": "rarefia",
    "rarefiau": "rarefia",
    "rarefiază": "rarefia",
    "rarefie": "rarefia",
    "rarefiem": "rarefia",
    "rarefiez": "rarefia",
    "rarefieze": "rarefia",
    "rarefiezi": "rarefia",
    "rarefiind": "rarefia",
    "rarefiindu": "rarefia",
    "rarefiata": "rarefiat",
    "rarefiată": "rarefiat",
    "rarefiate": "rarefiat",
    "rarefiatei": "rarefiat",
    "rarefiatele": "rarefiat",
    "rarefiatelor": "rarefiat",
    "rarefiați": "rarefiat",
    "rarefiații": "rarefiat",
    "rarefiaților": "rarefiat",
    "rarefiato": "rarefiat",
    "rarefiatul": "rarefiat",
    "rarefiatule": "rarefiat",
    "rarefiatului": "rarefiat",
    "rarefierea": "rarefiere",
    "rarefiereo": "rarefiere",
    "rarefieri": "rarefiere",
    "rarefierii": "rarefiere",
    "rarefierile": "rarefiere",
    "rarefierilor": "rarefiere",
    "nemairărind": "rări",
    "nemairărindu": "rări",
    "nerărind": "rări",
    "nerărindu": "rări",
    "rărea": "rări",
    "răreai": "rări",
    "răream": "rări",
    "rărească": "rări",
    "răreați": "rări",
    "răreau": "rări",
    "răresc": "rări",
    "rărește": "rări",
    "rărești": "rări",
    "rării": "rări",
    "rărim": "rări",
    "rărind": "rări",
    "rărindu": "rări",
    "răriră": "rări",
    "rărirăm": "rări",
    "rărirăți": "rări",
    "rărise": "rări",
    "rărisem": "rări",
    "răriseră": "rări",
    "răriserăm": "rări",
    "răriserăți": "rări",
    "răriseși": "rări",
    "răriși": "rări",
    "rărit": "rări",
    "răriți": "rări",
    "rarificata": "rarificat",
    "rarificată": "rarificat",
    "rarificate": "rarificat",
    "rarificatei": "rarificat",
    "rarificatele": "rarificat",
    "rarificatelor": "rarificat",
    "rarificați": "rarificat",
    "rarificații": "rarificat",
    "rarificaților": "rarificat",
    "rarificatul": "rarificat",
    "rarificatului": "rarificat",
    "rarisima": "rarisim",
    "rarisimă": "rarisim",
    "rarisime": "rarisim",
    "rarisimei": "rarisim",
    "rarisimele": "rarisim",
    "rarisimelor": "rarisim",
    "rarisimi": "rarisim",
    "rarisimii": "rarisim",
    "rarisimilor": "rarisim",
    "rarisimul": "rarisim",
    "rarisimului": "rarisim",
    "rariștea": "rariște",
    "rariști": "rariște",
    "rariștii": "rariște",
    "rariștile": "rariște",
    "rariștilor": "rariște",
    "rărită": "rărit",
    "rărite": "rărit",
    "răriți": "rărit",
    "nemairărițând": "rărița",
    "nemairărițându": "rărița",
    "nerărițând": "rărița",
    "nerărițându": "rărița",
    "răriță": "rărița",
    "rărițai": "rărița",
    "rărițam": "rărița",
    "rărițăm": "rărița",
    "rărițând": "rărița",
    "rărițându": "rărița",
    "rărițară": "rărița",
    "rărițarăm": "rărița",
    "rărițarăți": "rărița",
    "rărițase": "rărița",
    "rărițasem": "rărița",
    "rărițaseră": "rărița",
    "rărițaserăm": "rărița",
    "rărițaserăți": "rărița",
    "rărițaseși": "rărița",
    "rărițași": "rărița",
    "rărițat": "rărița",
    "rărițați": "rărița",
    "rărițau": "rărița",
    "rărițează": "rărița",
    "rărițez": "rărița",
    "rărițeze": "rărița",
    "rărițezi": "rărița",
    "rărițată": "rărițat",
    "rărițate": "rărițat",
    "rărițați": "rărițat",
    "raritatea": "raritate",
    "rarități": "raritate",
    "rarității": "raritate",
    "raritățile": "raritate",
    "rarităților": "raritate",
    "rărunchii": "rărunchi",
    "rărunchilor": "rărunchi",
    "rărunchiul": "rărunchi",
    "rărunchiului": "rărunchi",
    "rasa": "ras",
    "rasă": "ras",
    "rase": "ras",
    "rasei": "ras",
    "rasele": "ras",
    "raselor": "ras",
    "rași": "ras",
    "rașii": "ras",
    "rașilor": "ras",
    "rasul": "ras",
    "rasului": "ras",
    "rasuri": "ras",
    "rasurile": "ras",
    "rasurilor": "ras",
    "râsă": "râs",
    "râse": "râs",
    "râși": "râs",
    "râsul": "râs",
    "râsului": "râs",
    "râsuri": "râs",
    "râsurile": "râs",
    "râsurilor": "râs",
    "rasa": "rasă",
    "rase": "rasă",
    "rasei": "rasă",
    "rasele": "rasă",
    "raselor": "rasă",
    "răsadul": "răsad",
    "răsadului": "răsad",
    "răsaduri": "răsad",
    "răsadurile": "răsad",
    "răsadurilor": "răsad",
    "nemairăsădind": "răsădi",
    "nemairăsădindu": "răsădi",
    "nerăsădind": "răsădi",
    "nerăsădindu": "răsădi",
    "răsădea": "răsădi",
    "răsădeai": "răsădi",
    "răsădeam": "răsădi",
    "răsădească": "răsădi",
    "răsădeați": "răsădi",
    "răsădeau": "răsădi",
    "răsădesc": "răsădi",
    "răsădește": "răsădi",
    "răsădești": "răsădi",
    "răsădii": "răsădi",
    "răsădim": "răsădi",
    "răsădind": "răsădi",
    "răsădindu": "răsădi",
    "răsădiră": "răsădi",
    "răsădirăm": "răsădi",
    "răsădirăți": "răsădi",
    "răsădise": "răsădi",
    "răsădisem": "răsădi",
    "răsădiseră": "răsădi",
    "răsădiserăm": "răsădi",
    "răsădiserăți": "răsădi",
    "răsădiseși": "răsădi",
    "răsădiși": "răsădi",
    "răsădit": "răsădi",
    "răsădiți": "răsădi",
    "răsădirea": "răsădire",
    "răsădireo": "răsădire",
    "răsădiri": "răsădire",
    "răsădirii": "răsădire",
    "răsădirile": "răsădire",
    "răsădirilor": "răsădire",
    "răsădită": "răsădit",
    "răsădite": "răsădit",
    "răsădiți": "răsădit",
    "nemairăsărind": "răsări",
    "nemairăsărindu": "răsări",
    "nerăsărind": "răsări",
    "nerăsărindu": "răsări",
    "răsar": "răsări",
    "răsară": "răsări",
    "răsare": "răsări",
    "răsărea": "răsări",
    "răsăreai": "răsări",
    "răsăream": "răsări",
    "răsăreați": "răsări",
    "răsăreau": "răsări",
    "răsari": "răsări",
    "răsării": "răsări",
    "răsărim": "răsări",
    "răsărind": "răsări",
    "răsărindu": "răsări",
    "răsăriră": "răsări",
    "răsărirăm": "răsări",
    "răsărirăți": "răsări",
    "răsărise": "răsări",
    "răsărisem": "răsări",
    "răsăriseră": "răsări",
    "răsăriserăm": "răsări",
    "răsăriserăți": "răsări",
    "răsăriseși": "răsări",
    "răsăriși": "răsări",
    "răsărit": "răsări",
    "răsăriți": "răsări",
    "răsărirea": "răsărire",
    "răsărireo": "răsărire",
    "răsăriri": "răsărire",
    "răsăririi": "răsărire",
    "răsăririle": "răsărire",
    "răsăririlor": "răsărire",
    "răsărita": "răsărit",
    "răsărită": "răsărit",
    "răsărite": "răsărit",
    "răsăritei": "răsărit",
    "răsăritele": "răsărit",
    "răsăritelor": "răsărit",
    "răsăriți": "răsărit",
    "răsăriții": "răsărit",
    "răsăriților": "răsărit",
    "răsărito": "răsărit",
    "răsăritul": "răsărit",
    "răsăritule": "răsărit",
    "răsăritului": "răsărit",
    "răsărituri": "răsărit",
    "răsăriturile": "răsărit",
    "răsăriturilor": "răsărit",
    "răsăriteana": "răsăritean",
    "răsăriteană": "răsăritean",
    "răsăriteanul": "răsăritean",
    "răsăriteanului": "răsăritean",
    "răsăritene": "răsăritean",
    "răsăritenei": "răsăritean",
    "răsăritenele": "răsăritean",
    "răsăritenelor": "răsăritean",
    "răsăriteni": "răsăritean",
    "răsăritenii": "răsăritean",
    "răsăritenilor": "răsăritean",
    "răsăriteanca": "răsăriteancă",
    "răsăritence": "răsăriteancă",
    "răsăritencei": "răsăriteancă",
    "răsăritencele": "răsăriteancă",
    "răsăritencelor": "răsăriteancă",
    "nemairașchetând": "rașcheta",
    "nemairașchetându": "rașcheta",
    "nerașchetând": "rașcheta",
    "nerașchetându": "rașcheta",
    "rașchetă": "rașcheta",
    "rașchetai": "rașcheta",
    "rașchetam": "rașcheta",
    "rașchetăm": "rașcheta",
    "rașchetând": "rașcheta",
    "rașchetându": "rașcheta",
    "rașchetară": "rașcheta",
    "rașchetarăm": "rașcheta",
    "rașchetarăți": "rașcheta",
    "rașchetase": "rașcheta",
    "rașchetasem": "rașcheta",
    "rașchetaseră": "rașcheta",
    "rașchetaserăm": "rașcheta",
    "rașchetaserăți": "rașcheta",
    "rașchetaseși": "rașcheta",
    "rașchetași": "rașcheta",
    "rașchetat": "rașcheta",
    "rașchetați": "rașcheta",
    "rașchetau": "rașcheta",
    "rașchetează": "rașcheta",
    "rașchetez": "rașcheta",
    "rașcheteze": "rașcheta",
    "rașchetezi": "rașcheta",
    "rașcheta": "rașchetă",
    "rașchete": "rașchetă",
    "rașchetei": "rașchetă",
    "rașchetele": "rașchetă",
    "rașchetelor": "rașchetă",
    "rașchetarea": "rașchetare",
    "rașchetareo": "rașchetare",
    "rașchetări": "rașchetare",
    "rașchetării": "rașchetare",
    "rașchetările": "rașchetare",
    "rașchetărilor": "rașchetare",
    "rașchetata": "rașchetat",
    "rașchetată": "rașchetat",
    "rașchetate": "rașchetat",
    "rașchetatele": "rașchetat",
    "rașchetatelor": "rașchetat",
    "rașchetați": "rașchetat",
    "rașchetații": "rașchetat",
    "rașchetaților": "rașchetat",
    "rașchetato": "rașchetat",
    "rașchetatul": "rașchetat",
    "rașchetatule": "rașchetat",
    "rașchetatului": "rașchetat",
    "nemairășchiind": "rășchia",
    "nemairășchiindu": "rășchia",
    "nerășchiind": "rășchia",
    "nerășchiindu": "rășchia",
    "rășchiai": "rășchia",
    "rășchiam": "rășchia",
    "rășchiară": "rășchia",
    "rășchiarăm": "rășchia",
    "rășchiarăți": "rășchia",
    "rășchiase": "rășchia",
    "rășchiasem": "rășchia",
    "rășchiaseră": "rășchia",
    "rășchiaserăm": "rășchia",
    "rășchiaserăți": "rășchia",
    "rășchiaseși": "rășchia",
    "rășchiași": "rășchia",
    "rășchiat": "rășchia",
    "rășchiați": "rășchia",
    "rășchiau": "rășchia",
    "rășchiază": "rășchia",
    "rășchie": "rășchia",
    "rășchiem": "rășchia",
    "rășchiez": "rășchia",
    "rășchieze": "rășchia",
    "rășchiezi": "rășchia",
    "rășchiind": "rășchia",
    "rășchiindu": "rășchia",
    "rășchiata": "rășchiat",
    "rășchiată": "rășchiat",
    "rășchiate": "rășchiat",
    "rășchiatei": "rășchiat",
    "rășchiatele": "rășchiat",
    "rășchiatelor": "rășchiat",
    "rășchiați": "rășchiat",
    "rășchiații": "rășchiat",
    "rășchiaților": "rășchiat",
    "rășchiato": "rășchiat",
    "rășchiatul": "rășchiat",
    "rășchiatule": "rășchiat",
    "rășchiatului": "rășchiat",
    "rășchiră": "rășchira",
    "rășchirai": "rășchira",
    "rășchiram": "rășchira",
    "rășchirăm": "rășchira",
    "rășchirând": "rășchira",
    "rășchirându": "rășchira",
    "rășchirară": "rășchira",
    "rășchirarăm": "rășchira",
    "rășchirarăți": "rășchira",
    "rășchirase": "rășchira",
    "rășchirasem": "rășchira",
    "rășchiraseră": "rășchira",
    "rășchiraserăm": "rășchira",
    "rășchiraserăți": "rășchira",
    "rășchiraseși": "rășchira",
    "rășchirași": "rășchira",
    "rășchirat": "rășchira",
    "rășchirați": "rășchira",
    "rășchiratu": "rășchira",
    "rășchirau": "rășchira",
    "rășchirează": "rășchira",
    "rășchirez": "rășchira",
    "rășchireze": "rășchira",
    "rășchirezi": "rășchira",
    "rășchirarea": "rășchirare",
    "rășchirareo": "rășchirare",
    "rășchirări": "rășchirare",
    "rășchirării": "rășchirare",
    "rășchirările": "rășchirare",
    "rășchirărilor": "rășchirare",
    "rășchirată": "rășchirat",
    "rășchirate": "rășchirat",
    "rășchirați": "rășchirat",
    "răscitea": "răsciti",
    "răsciteai": "răsciti",
    "răsciteam": "răsciti",
    "răscitească": "răsciti",
    "răsciteați": "răsciti",
    "răsciteau": "răsciti",
    "răscitesc": "răsciti",
    "răscitește": "răsciti",
    "răscitești": "răsciti",
    "răscitii": "răsciti",
    "răscitim": "răsciti",
    "răscitind": "răsciti",
    "răscitindu": "răsciti",
    "răscitiră": "răsciti",
    "răscitirăm": "răsciti",
    "răscitirăți": "răsciti",
    "răscitise": "răsciti",
    "răscitisem": "răsciti",
    "răscitiseră": "răsciti",
    "răscitiserăm": "răsciti",
    "răscitiserăți": "răsciti",
    "răscitiseși": "răsciti",
    "răscitiși": "răsciti",
    "răscitit": "răsciti",
    "răscitiți": "răsciti",
    "răscititu": "răsciti",
    "răscitită": "răscitit",
    "răscitite": "răscitit",
    "răscitiți": "răscitit",
    "nemairăscocând": "răscoace",
    "nemairăscocându": "răscoace",
    "nerăscocând": "răscoace",
    "nerăscocându": "răscoace",
    "răscoacă": "răscoace",
    "răscoacem": "răscoace",
    "răscoaceți": "răscoace",
    "răscoc": "răscoace",
    "răscocând": "răscoace",
    "răscocându": "răscoace",
    "răscocea": "răscoace",
    "răscoceai": "răscoace",
    "răscoceam": "răscoace",
    "răscoceați": "răscoace",
    "răscoceau": "răscoace",
    "răscoci": "răscoace",
    "răscopt": "răscoace",
    "răscoala": "răscoală",
    "răscoale": "răscoală",
    "răscoalei": "răscoală",
    "răscoalele": "răscoală",
    "răscoalelor": "răscoală",
    "nemairăscolind": "răscoli",
    "nemairăscolindu": "răscoli",
    "nerăscolind": "răscoli",
    "nerăscolindu": "răscoli",
    "răscolea": "răscoli",
    "răscoleai": "răscoli",
    "răscoleam": "răscoli",
    "răscolească": "răscoli",
    "răscoleați": "răscoli",
    "răscoleau": "răscoli",
    "răscolesc": "răscoli",
    "răscolește": "răscoli",
    "răscolești": "răscoli",
    "răscolii": "răscoli",
    "răscolim": "răscoli",
    "răscolind": "răscoli",
    "răscolindu": "răscoli",
    "răscoliră": "răscoli",
    "răscolirăm": "răscoli",
    "răscolirăți": "răscoli",
    "răscolise": "răscoli",
    "răscolisem": "răscoli",
    "răscoliseră": "răscoli",
    "răscoliserăm": "răscoli",
    "răscoliserăți": "răscoli",
    "răscoliseși": "răscoli",
    "răscoliși": "răscoli",
    "răscolit": "răscoli",
    "răscoliți": "răscoli",
    "răscolitu": "răscoli",
    "răscolirea": "răscolire",
    "răscolireo": "răscolire",
    "răscoliri": "răscolire",
    "răscolirii": "răscolire",
    "răscolirile": "răscolire",
    "răscolirilor": "răscolire",
    "răscolită": "răscolit",
    "răscolite": "răscolit",
    "răscoliți": "răscolit",
    "răscoapta": "răscopt",
    "răscoaptă": "răscopt",
    "răscoapte": "răscopt",
    "răscoaptei": "răscopt",
    "răscoaptele": "răscopt",
    "răscoaptelor": "răscopt",
    "răscopți": "răscopt",
    "răscopții": "răscopt",
    "răscopților": "răscopt",
    "răscoptul": "răscopt",
    "răscoptului": "răscopt",
    "nemairăscroind": "răscroi",
    "nemairăscroindu": "răscroi",
    "nerăscroind": "răscroi",
    "nerăscroindu": "răscroi",
    "răscroia": "răscroi",
    "răscroiai": "răscroi",
    "răscroiam": "răscroi",
    "răscroiască": "răscroi",
    "răscroiați": "răscroi",
    "răscroiau": "răscroi",
    "răscroiesc": "răscroi",
    "răscroiește": "răscroi",
    "răscroiești": "răscroi",
    "răscroii": "răscroi",
    "răscroim": "răscroi",
    "răscroind": "răscroi",
    "răscroindu": "răscroi",
    "răscroiră": "răscroi",
    "răscroirăm": "răscroi",
    "răscroirăți": "răscroi",
    "răscroise": "răscroi",
    "răscroisem": "răscroi",
    "răscroiseră": "răscroi",
    "răscroiserăm": "răscroi",
    "răscroiserăți": "răscroi",
    "răscroiseși": "răscroi",
    "răscroiși": "răscroi",
    "răscroit": "răscroi",
    "răscroiți": "răscroi",
    "răscroiala": "răscroială",
    "răscroieli": "răscroială",
    "răscroielii": "răscroială",
    "răscroielile": "răscroială",
    "răscroielilor": "răscroială",
    "răscroita": "răscroit",
    "răscroită": "răscroit",
    "răscroite": "răscroit",
    "răscroitei": "răscroit",
    "răscroitele": "răscroit",
    "răscroitelor": "răscroit",
    "răscroiți": "răscroit",
    "răscroiții": "răscroit",
    "răscroiților": "răscroit",
    "răscroito": "răscroit",
    "răscroitul": "răscroit",
    "răscroitule": "răscroit",
    "răscroitului": "răscroit",
    "răscroitura": "răscroitură",
    "răscroituri": "răscroitură",
    "răscroiturii": "răscroitură",
    "răscroiturile": "răscroitură",
    "răscroiturilor": "răscroitură",
    "răscroituro": "răscroitură",
    "răscrucea": "răscruce",
    "răscruci": "răscruce",
    "răscrucii": "răscruce",
    "răscrucile": "răscruce",
    "răscrucilor": "răscruce",
    "nemairăsculând": "răscula",
    "nemairăsculându": "răscula",
    "nerăsculând": "răscula",
    "nerăsculându": "răscula",
    "răscoală": "răscula",
    "răscoale": "răscula",
    "răscol": "răscula",
    "răscoli": "răscula",
    "răsculă": "răscula",
    "răsculai": "răscula",
    "răsculam": "răscula",
    "răsculăm": "răscula",
    "răsculând": "răscula",
    "răsculându": "răscula",
    "răsculară": "răscula",
    "răscularăm": "răscula",
    "răscularăți": "răscula",
    "răsculase": "răscula",
    "răsculasem": "răscula",
    "răsculaseră": "răscula",
    "răsculaserăm": "răscula",
    "răsculaserăți": "răscula",
    "răsculaseși": "răscula",
    "răsculași": "răscula",
    "răsculat": "răscula",
    "răsculați": "răscula",
    "răsculau": "răscula",
    "răsculată": "răsculat",
    "răsculate": "răsculat",
    "răsculați": "răsculat",
    "nemairăscumpărând": "răscumpăra",
    "nemairăscumpărându": "răscumpăra",
    "nerăscumpărând": "răscumpăra",
    "nerăscumpărându": "răscumpăra",
    "răscumpăr": "răscumpăra",
    "răscumpără": "răscumpăra",
    "răscumpărai": "răscumpăra",
    "răscumpăram": "răscumpăra",
    "răscumpărăm": "răscumpăra",
    "răscumpărând": "răscumpăra",
    "răscumpărându": "răscumpăra",
    "răscumpărară": "răscumpăra",
    "răscumpărarăm": "răscumpăra",
    "răscumpărarăți": "răscumpăra",
    "răscumpărase": "răscumpăra",
    "răscumpărasem": "răscumpăra",
    "răscumpăraseră": "răscumpăra",
    "răscumpăraserăm": "răscumpăra",
    "răscumpăraserăți": "răscumpăra",
    "răscumpăraseși": "răscumpăra",
    "răscumpărași": "răscumpăra",
    "răscumpărat": "răscumpăra",
    "răscumpărați": "răscumpăra",
    "răscumpărau": "răscumpăra",
    "răscumpere": "răscumpăra",
    "răscumperi": "răscumpăra",
    "răscumpărabila": "răscumpărabil",
    "răscumpărabilă": "răscumpărabil",
    "răscumpărabile": "răscumpărabil",
    "răscumpărabilei": "răscumpărabil",
    "răscumpărabilele": "răscumpărabil",
    "răscumpărabilelor": "răscumpărabil",
    "răscumpărabili": "răscumpărabil",
    "răscumpărabilii": "răscumpărabil",
    "răscumpărabililor": "răscumpărabil",
    "răscumpărabilo": "răscumpărabil",
    "răscumpărabilul": "răscumpărabil",
    "răscumpărabilule": "răscumpărabil",
    "răscumpărabilului": "răscumpărabil",
    "răscumpărarea": "răscumpărare",
    "răscumpărări": "răscumpărare",
    "răscumpărării": "răscumpărare",
    "răscumpărările": "răscumpărare",
    "răscumpărărilor": "răscumpărare",
    "răscumpărată": "răscumpărat",
    "răscumpărate": "răscumpărat",
    "răscumpărați": "răscumpărat",
    "răscunoscuta": "răscunoscut",
    "răscunoscută": "răscunoscut",
    "răscunoscute": "răscunoscut",
    "răscunoscutei": "răscunoscut",
    "răscunoscutele": "răscunoscut",
    "răscunoscutelor": "răscunoscut",
    "răscunoscuți": "răscunoscut",
    "răscunoscuții": "răscunoscut",
    "răscunoscuților": "răscunoscut",
    "răscunoscutul": "răscunoscut",
    "răscunoscutului": "răscunoscut",
    "râsete": "râset",
    "râsetele": "râset",
    "râsetelor": "râset",
    "râsetul": "râset",
    "râsetului": "râset",
    "răsfățul": "răsfăț",
    "răsfățului": "răsfăț",
    "răsfățuri": "răsfăț",
    "răsfățurile": "răsfăț",
    "răsfățurilor": "răsfăț",
    "nemairăsfățând": "răsfăța",
    "nemairăsfățându": "răsfăța",
    "nerăsfățând": "răsfăța",
    "nerăsfățându": "răsfăța",
    "răsfăț": "răsfăța",
    "răsfață": "răsfăța",
    "răsfăță": "răsfăța",
    "răsfățai": "răsfăța",
    "răsfățam": "răsfăța",
    "răsfățăm": "răsfăța",
    "răsfățând": "răsfăța",
    "răsfățându": "răsfăța",
    "răsfățară": "răsfăța",
    "răsfățarăm": "răsfăța",
    "răsfățarăți": "răsfăța",
    "răsfățase": "răsfăța",
    "răsfățasem": "răsfăța",
    "răsfățaseră": "răsfăța",
    "răsfățaserăm": "răsfăța",
    "răsfățaserăți": "răsfăța",
    "răsfățaseși": "răsfăța",
    "răsfățași": "răsfăța",
    "răsfățat": "răsfăța",
    "răsfățați": "răsfăța",
    "răsfățau": "răsfăța",
    "răsfețe": "răsfăța",
    "răsfeți": "răsfăța",
    "răsfățată": "răsfățat",
    "răsfățate": "răsfățat",
    "răsfățați": "răsfățat",
    "nemairăsfirând": "răsfira",
    "nemairăsfirându": "răsfira",
    "nerăsfirând": "răsfira",
    "nerăsfirându": "răsfira",
    "răsfir": "răsfira",
    "răsfiră": "răsfira",
    "răsfirai": "răsfira",
    "răsfiram": "răsfira",
    "răsfirăm": "răsfira",
    "răsfirând": "răsfira",
    "răsfirându": "răsfira",
    "răsfirară": "răsfira",
    "răsfirarăm": "răsfira",
    "răsfirarăți": "răsfira",
    "răsfirase": "răsfira",
    "răsfirasem": "răsfira",
    "răsfiraseră": "răsfira",
    "răsfiraserăm": "răsfira",
    "răsfiraserăți": "răsfira",
    "răsfiraseși": "răsfira",
    "răsfirași": "răsfira",
    "răsfirat": "răsfira",
    "răsfirați": "răsfira",
    "răsfirau": "răsfira",
    "răsfire": "răsfira",
    "răsfiri": "răsfira",
    "răsfirarea": "răsfirare",
    "răsfirareo": "răsfirare",
    "răsfirări": "răsfirare",
    "răsfirării": "răsfirare",
    "răsfirările": "răsfirare",
    "răsfirărilor": "răsfirare",
    "răsfirata": "răsfirat",
    "răsfirată": "răsfirat",
    "răsfirate": "răsfirat",
    "răsfiratei": "răsfirat",
    "răsfiratele": "răsfirat",
    "răsfiratelor": "răsfirat",
    "răsfirați": "răsfirat",
    "răsfirații": "răsfirat",
    "răsfiraților": "răsfirat",
    "răsfirato": "răsfirat",
    "răsfiratul": "răsfirat",
    "răsfiratule": "răsfirat",
    "răsfiratului": "răsfirat",
    "nemairăsfoind": "răsfoi",
    "nemairăsfoindu": "răsfoi",
    "nerăsfoind": "răsfoi",
    "nerăsfoindu": "răsfoi",
    "răsfoia": "răsfoi",
    "răsfoiai": "răsfoi",
    "răsfoiam": "răsfoi",
    "răsfoiască": "răsfoi",
    "răsfoiați": "răsfoi",
    "răsfoiau": "răsfoi",
    "răsfoiesc": "răsfoi",
    "răsfoiește": "răsfoi",
    "răsfoiești": "răsfoi",
    "răsfoii": "răsfoi",
    "răsfoim": "răsfoi",
    "răsfoind": "răsfoi",
    "răsfoindu": "răsfoi",
    "răsfoiră": "răsfoi",
    "răsfoirăm": "răsfoi",
    "răsfoirăți": "răsfoi",
    "răsfoise": "răsfoi",
    "răsfoisem": "răsfoi",
    "răsfoiseră": "răsfoi",
    "răsfoiserăm": "răsfoi",
    "răsfoiserăți": "răsfoi",
    "răsfoiseși": "răsfoi",
    "răsfoiși": "răsfoi",
    "răsfoit": "răsfoi",
    "răsfoiți": "răsfoi",
    "răsfoiala": "răsfoială",
    "răsfoialo": "răsfoială",
    "răsfoieli": "răsfoială",
    "răsfoielii": "răsfoială",
    "răsfoielile": "răsfoială",
    "răsfoielilor": "răsfoială",
    "răsfoirea": "răsfoire",
    "răsfoireo": "răsfoire",
    "răsfoiri": "răsfoire",
    "răsfoirii": "răsfoire",
    "răsfoirile": "răsfoire",
    "răsfoirilor": "răsfoire",
    "răsfoita": "răsfoit",
    "răsfoită": "răsfoit",
    "răsfoite": "răsfoit",
    "răsfoitei": "răsfoit",
    "răsfoitele": "răsfoit",
    "răsfoitelor": "răsfoit",
    "răsfoiți": "răsfoit",
    "răsfoiții": "răsfoit",
    "răsfoiților": "răsfoit",
    "răsfoito": "răsfoit",
    "răsfoitul": "răsfoit",
    "răsfoitule": "răsfoit",
    "răsfoitului": "răsfoit",
    "nemairăsfrângând": "răsfrânge",
    "nemairăsfrângându": "răsfrânge",
    "nerăsfrângând": "răsfrânge",
    "nerăsfrângându": "răsfrânge",
    "răsfrâng": "răsfrânge",
    "răsfrângă": "răsfrânge",
    "răsfrângând": "răsfrânge",
    "răsfrângându": "răsfrânge",
    "răsfrângea": "răsfrânge",
    "răsfrângeai": "răsfrânge",
    "răsfrângeam": "răsfrânge",
    "răsfrângeați": "răsfrânge",
    "răsfrângeau": "răsfrânge",
    "răsfrângem": "răsfrânge",
    "răsfrângeți": "răsfrânge",
    "răsfrângi": "răsfrânge",
    "răsfrânse": "răsfrânge",
    "răsfrânsei": "răsfrânge",
    "răsfrânseră": "răsfrânge",
    "răsfrânserăm": "răsfrânge",
    "răsfrânserăți": "răsfrânge",
    "răsfrânsese": "răsfrânge",
    "răsfrânsesem": "răsfrânge",
    "răsfrânseseră": "răsfrânge",
    "răsfrânseserăm": "răsfrânge",
    "răsfrânseserăți": "răsfrânge",
    "răsfrânseseși": "răsfrânge",
    "răsfrânseși": "răsfrânge",
    "răsfrânt": "răsfrânge",
    "răsfrângerea": "răsfrângere",
    "răsfrângereo": "răsfrângere",
    "răsfrângeri": "răsfrângere",
    "răsfrângerii": "răsfrângere",
    "răsfrângerile": "răsfrângere",
    "răsfrângerilor": "răsfrângere",
    "răsfrânta": "răsfrânt",
    "răsfrântă": "răsfrânt",
    "răsfrânte": "răsfrânt",
    "răsfrântei": "răsfrânt",
    "răsfrântele": "răsfrânt",
    "răsfrântelor": "răsfrânt",
    "răsfrânți": "răsfrânt",
    "răsfrânții": "răsfrânt",
    "răsfrânților": "răsfrânt",
    "răsfrântul": "răsfrânt",
    "răsfrântului": "răsfrânt",
    "rasiala": "rasial",
    "rasială": "rasial",
    "rasiale": "rasial",
    "rasialei": "rasial",
    "rasialele": "rasial",
    "rasialelor": "rasial",
    "rasiali": "rasial",
    "rasialii": "rasial",
    "rasialilor": "rasial",
    "rasialul": "rasial",
    "rasialului": "rasial",
    "rășina": "rășină",
    "rășini": "rășină",
    "rășinii": "rășină",
    "rășinile": "rășină",
    "rășinilor": "rășină",
    "rășinoasa": "rășinos",
    "rășinoasă": "rășinos",
    "rășinoase": "rășinos",
    "rășinoasei": "rășinos",
    "rășinoasele": "rășinos",
    "rășinoaselor": "rășinos",
    "rășinoși": "rășinos",
    "rășinoșii": "rășinos",
    "rășinoșilor": "rășinos",
    "rășinosul": "rășinos",
    "rășinosului": "rășinos",
    "rasismul": "rasism",
    "rasismului": "rasism",
    "rasista": "rasist",
    "rasistă": "rasist",
    "rasiste": "rasist",
    "rasistei": "rasist",
    "rasistele": "rasist",
    "rasistelor": "rasist",
    "rasiști": "rasist",
    "rasiștii": "rasist",
    "rasiștilor": "rasist",
    "rasistul": "rasist",
    "rasistului": "rasist",
    "rasista": "rasistă",
    "rasiste": "rasistă",
    "rasistei": "rasistă",
    "rasistele": "rasistă",
    "rasistelor": "rasistă",
    "răsmodificat": "răsmodifica",
    "răsmodificată": "răsmodificat",
    "nemairâșnind": "râșni",
    "nemairâșnindu": "râșni",
    "nerâșnind": "râșni",
    "nerâșnindu": "râșni",
    "râșnea": "râșni",
    "râșneai": "râșni",
    "râșneam": "râșni",
    "râșnească": "râșni",
    "râșneați": "râșni",
    "râșneau": "râșni",
    "râșnesc": "râșni",
    "râșnește": "râșni",
    "râșnești": "râșni",
    "râșnii": "râșni",
    "râșnim": "râșni",
    "râșnind": "râșni",
    "râșnindu": "râșni",
    "râșniră": "râșni",
    "râșnirăm": "râșni",
    "râșnirăți": "râșni",
    "râșnise": "râșni",
    "râșnisem": "râșni",
    "râșniseră": "râșni",
    "râșniserăm": "râșni",
    "râșniserăți": "râșni",
    "râșniseși": "râșni",
    "râșniși": "râșni",
    "râșnit": "râșni",
    "râșniți": "râșni",
    "râșnită": "râșnit",
    "râșnite": "râșnit",
    "râșniți": "râșnit",
    "râșnița": "râșniță",
    "râșnițe": "râșniță",
    "râșniței": "râșniță",
    "râșnițele": "râșniță",
    "râșnițelor": "râșniță",
    "rasolul": "rasol",
    "rasolului": "rasol",
    "rasoluri": "rasol",
    "rasolurile": "rasol",
    "rasolurilor": "rasol",
    "rasoleala": "rasoleală",
    "rasoleli": "rasoleală",
    "rasolelii": "rasoleală",
    "rasolelile": "rasoleală",
    "rasolelilor": "rasoleală",
    "nemairasolind": "rasoli",
    "nemairasolindu": "rasoli",
    "nerasolind": "rasoli",
    "nerasolindu": "rasoli",
    "rasolea": "rasoli",
    "rasoleai": "rasoli",
    "rasoleam": "rasoli",
    "rasolească": "rasoli",
    "rasoleați": "rasoli",
    "rasoleau": "rasoli",
    "rasolesc": "rasoli",
    "rasolește": "rasoli",
    "rasolești": "rasoli",
    "rasolii": "rasoli",
    "rasolim": "rasoli",
    "rasolind": "rasoli",
    "rasolindu": "rasoli",
    "rasoliră": "rasoli",
    "rasolirăm": "rasoli",
    "rasolirăți": "rasoli",
    "rasolise": "rasoli",
    "rasolisem": "rasoli",
    "rasoliseră": "rasoli",
    "rasoliserăm": "rasoli",
    "rasoliserăți": "rasoli",
    "rasoliseși": "rasoli",
    "rasoliși": "rasoli",
    "rasolit": "rasoli",
    "rasoliți": "rasoli",
    "rasolita": "rasolit",
    "rasolită": "rasolit",
    "rasolite": "rasolit",
    "rasolitei": "rasolit",
    "rasolitele": "rasolit",
    "rasolitelor": "rasolit",
    "rasoliți": "rasolit",
    "rasoliții": "rasolit",
    "rasoliților": "rasolit",
    "rasolito": "rasolit",
    "rasolitul": "rasolit",
    "rasolitule": "rasolit",
    "rasolitului": "rasolit",
    "nemairășpăluind": "rășpălui",
    "nemairășpăluindu": "rășpălui",
    "nerășpăluind": "rășpălui",
    "nerășpăluindu": "rășpălui",
    "rășpăluia": "rășpălui",
    "rășpăluiai": "rășpălui",
    "rășpăluiam": "rășpălui",
    "rășpăluiască": "rășpălui",
    "rășpăluiați": "rășpălui",
    "rășpăluiau": "rășpălui",
    "rășpăluiesc": "rășpălui",
    "rășpăluiește": "rășpălui",
    "rășpăluiești": "rășpălui",
    "rășpăluii": "rășpălui",
    "rășpăluim": "rășpălui",
    "rășpăluind": "rășpălui",
    "rășpăluindu": "rășpălui",
    "rășpăluiră": "rășpălui",
    "rășpăluirăm": "rășpălui",
    "rășpăluirăți": "rășpălui",
    "rășpăluise": "rășpălui",
    "rășpăluisem": "rășpălui",
    "rășpăluiseră": "rășpălui",
    "rășpăluiserăm": "rășpălui",
    "rășpăluiserăți": "rășpălui",
    "rășpăluiseși": "rășpălui",
    "rășpăluiși": "rășpălui",
    "rășpăluit": "rășpălui",
    "rășpăluiți": "rășpălui",
    "rășpăluită": "rășpăluit",
    "rășpăluite": "rășpăluit",
    "rășpăluiți": "rășpăluit",
    "nemairăspândind": "răspândi",
    "nemairăspândindu": "răspândi",
    "nerăspândind": "răspândi",
    "nerăspândindu": "răspândi",
    "răspândea": "răspândi",
    "răspândeai": "răspândi",
    "răspândeam": "răspândi",
    "răspândească": "răspândi",
    "răspândeați": "răspândi",
    "răspândeau": "răspândi",
    "răspândesc": "răspândi",
    "răspândește": "răspândi",
    "răspândești": "răspândi",
    "răspândii": "răspândi",
    "răspândim": "răspândi",
    "răspândind": "răspândi",
    "răspândindu": "răspândi",
    "răspândiră": "răspândi",
    "răspândirăm": "răspândi",
    "răspândirăți": "răspândi",
    "răspândise": "răspândi",
    "răspândisem": "răspândi",
    "răspândiseră": "răspândi",
    "răspândiserăm": "răspândi",
    "răspândiserăți": "răspândi",
    "răspândiseși": "răspândi",
    "răspândiși": "răspândi",
    "răspândit": "răspândi",
    "răspândiți": "răspândi",
    "răspândirea": "răspândire",
    "răspândireo": "răspândire",
    "răspândiri": "răspândire",
    "răspândirii": "răspândire",
    "răspândirile": "răspândire",
    "răspândirilor": "răspândire",
    "răspândita": "răspândit",
    "răspândită": "răspândit",
    "răspândite": "răspândit",
    "răspânditei": "răspândit",
    "răspânditele": "răspândit",
    "răspânditelor": "răspândit",
    "răspândiți": "răspândit",
    "răspândiții": "răspândit",
    "răspândiților": "răspândit",
    "răspândito": "răspândit",
    "răspânditul": "răspândit",
    "răspânditule": "răspândit",
    "răspânditului": "răspândit",
    "răspântia": "răspântie",
    "răspântiei": "răspântie",
    "răspântii": "răspântie",
    "răspântiile": "răspântie",
    "răspântiilor": "răspântie",
    "rașpele": "rașpel",
    "rașpelele": "rașpel",
    "rașpelelor": "rașpel",
    "rașpelul": "rașpel",
    "rașpelului": "rașpel",
    "nemairăspicând": "răspica",
    "nemairăspicându": "răspica",
    "nerăspicând": "răspica",
    "nerăspicându": "răspica",
    "răspic": "răspica",
    "răspică": "răspica",
    "răspicai": "răspica",
    "răspicam": "răspica",
    "răspicăm": "răspica",
    "răspicând": "răspica",
    "răspicându": "răspica",
    "răspicară": "răspica",
    "răspicarăm": "răspica",
    "răspicarăți": "răspica",
    "răspicase": "răspica",
    "răspicasem": "răspica",
    "răspicaseră": "răspica",
    "răspicaserăm": "răspica",
    "răspicaserăți": "răspica",
    "răspicaseși": "răspica",
    "răspicași": "răspica",
    "răspicat": "răspica",
    "răspicați": "răspica",
    "răspicau": "răspica",
    "răspice": "răspica",
    "răspici": "răspica",
    "răspicarea": "răspicare",
    "răspicareo": "răspicare",
    "răspicări": "răspicare",
    "răspicării": "răspicare",
    "răspicările": "răspicare",
    "răspicărilor": "răspicare",
    "răspicata": "răspicat",
    "răspicată": "răspicat",
    "răspicate": "răspicat",
    "răspicatei": "răspicat",
    "răspicatele": "răspicat",
    "răspicatelor": "răspicat",
    "răspicați": "răspicat",
    "răspicații": "răspicat",
    "răspicaților": "răspicat",
    "răspicato": "răspicat",
    "răspicatul": "răspicat",
    "răspicatule": "răspicat",
    "răspicatului": "răspicat",
    "răsplata": "răsplată",
    "răsplăți": "răsplată",
    "răsplății": "răsplată",
    "răsplățile": "răsplată",
    "răsplăților": "răsplată",
    "nemairăsplătind": "răsplăti",
    "nemairăsplătindu": "răsplăti",
    "nerăsplătind": "răsplăti",
    "nerăsplătindu": "răsplăti",
    "răsplătea": "răsplăti",
    "răsplăteai": "răsplăti",
    "răsplăteam": "răsplăti",
    "răsplătească": "răsplăti",
    "răsplăteați": "răsplăti",
    "răsplăteau": "răsplăti",
    "răsplătesc": "răsplăti",
    "răsplătește": "răsplăti",
    "răsplătești": "răsplăti",
    "răsplătii": "răsplăti",
    "răsplătim": "răsplăti",
    "răsplătind": "răsplăti",
    "răsplătindu": "răsplăti",
    "răsplătiră": "răsplăti",
    "răsplătirăm": "răsplăti",
    "răsplătirăți": "răsplăti",
    "răsplătise": "răsplăti",
    "răsplătisem": "răsplăti",
    "răsplătiseră": "răsplăti",
    "răsplătiserăm": "răsplăti",
    "răsplătiserăți": "răsplăti",
    "răsplătiseși": "răsplăti",
    "răsplătiși": "răsplăti",
    "răsplătit": "răsplăti",
    "răsplătiți": "răsplăti",
    "răsplătirea": "răsplătire",
    "răsplătireo": "răsplătire",
    "răsplătiri": "răsplătire",
    "răsplătirii": "răsplătire",
    "răsplătirile": "răsplătire",
    "răsplătirilor": "răsplătire",
    "răsplătită": "răsplătit",
    "răsplătite": "răsplătit",
    "răsplătiți": "răsplătit",
    "nemairăspopind": "răspopi",
    "nemairăspopindu": "răspopi",
    "nerăspopind": "răspopi",
    "nerăspopindu": "răspopi",
    "răspopea": "răspopi",
    "răspopeai": "răspopi",
    "răspopeam": "răspopi",
    "răspopească": "răspopi",
    "răspopeați": "răspopi",
    "răspopeau": "răspopi",
    "răspopesc": "răspopi",
    "răspopește": "răspopi",
    "răspopești": "răspopi",
    "răspopii": "răspopi",
    "răspopim": "răspopi",
    "răspopind": "răspopi",
    "răspopindu": "răspopi",
    "răspopiră": "răspopi",
    "răspopirăm": "răspopi",
    "răspopirăți": "răspopi",
    "răspopise": "răspopi",
    "răspopisem": "răspopi",
    "răspopiseră": "răspopi",
    "răspopiserăm": "răspopi",
    "răspopiserăți": "răspopi",
    "răspopiseși": "răspopi",
    "răspopiși": "răspopi",
    "răspopit": "răspopi",
    "răspopiți": "răspopi",
    "răspopita": "răspopit",
    "răspopită": "răspopit",
    "răspopite": "răspopit",
    "răspopitei": "răspopit",
    "răspopitele": "răspopit",
    "răspopitelor": "răspopit",
    "răspopiți": "răspopit",
    "răspopiții": "răspopit",
    "răspopiților": "răspopit",
    "răspopitul": "răspopit",
    "răspopitului": "răspopit",
    "nemairăspunzând": "răspunde",
    "nemairăspunzându": "răspunde",
    "nerăspunzând": "răspunde",
    "nerăspunzându": "răspunde",
    "răspund": "răspunde",
    "răspundă": "răspunde",
    "răspundea": "răspunde",
    "răspundeai": "răspunde",
    "răspundeam": "răspunde",
    "răspundeați": "răspunde",
    "răspundeau": "răspunde",
    "răspundem": "răspunde",
    "răspundeți": "răspunde",
    "răspuns": "răspunde",
    "răspunse": "răspunde",
    "răspunsei": "răspunde",
    "răspunseră": "răspunde",
    "răspunserăm": "răspunde",
    "răspunserăți": "răspunde",
    "răspunsese": "răspunde",
    "răspunsesem": "răspunde",
    "răspunseseră": "răspunde",
    "răspunseserăm": "răspunde",
    "răspunseserăți": "răspunde",
    "răspunseseși": "răspunde",
    "răspunseși": "răspunde",
    "răspunzând": "răspunde",
    "răspunzându": "răspunde",
    "răspunzi": "răspunde",
    "răspunderea": "răspundere",
    "răspunderi": "răspundere",
    "răspunderii": "răspundere",
    "răspunderile": "răspundere",
    "răspunderilor": "răspundere",
    "răspunsă": "răspuns",
    "răspunse": "răspuns",
    "răspunși": "răspuns",
    "răspunsul": "răspuns",
    "răspunsului": "răspuns",
    "răspunsuri": "răspuns",
    "răspunsurile": "răspuns",
    "răspunsurilor": "răspuns",
    "răspunzătoare": "răspunzător",
    "răspunzătoarea": "răspunzător",
    "răspunzătoarei": "răspunzător",
    "răspunzătoarele": "răspunzător",
    "răspunzătoarelor": "răspunzător",
    "răspunzători": "răspunzător",
    "răspunzătorii": "răspunzător",
    "răspunzătorilor": "răspunzător",
    "răspunzătorul": "răspunzător",
    "răspunzătorului": "răspunzător",
    "răsputerea": "răsputere",
    "răsputeri": "răsputere",
    "răsputerii": "răsputere",
    "răsputerile": "răsputere",
    "răsputerilor": "răsputere",
    "nemairăstălmăcind": "răstălmăci",
    "nemairăstălmăcindu": "răstălmăci",
    "nerăstălmăcind": "răstălmăci",
    "nerăstălmăcindu": "răstălmăci",
    "răstălmăcea": "răstălmăci",
    "răstălmăceai": "răstălmăci",
    "răstălmăceam": "răstălmăci",
    "răstălmăcească": "răstălmăci",
    "răstălmăceați": "răstălmăci",
    "răstălmăceau": "răstălmăci",
    "răstălmăcesc": "răstălmăci",
    "răstălmăcește": "răstălmăci",
    "răstălmăcești": "răstălmăci",
    "răstălmăcii": "răstălmăci",
    "răstălmăcim": "răstălmăci",
    "răstălmăcind": "răstălmăci",
    "răstălmăcindu": "răstălmăci",
    "răstălmăciră": "răstălmăci",
    "răstălmăcirăm": "răstălmăci",
    "răstălmăcirăți": "răstălmăci",
    "răstălmăcise": "răstălmăci",
    "răstălmăcisem": "răstălmăci",
    "răstălmăciseră": "răstălmăci",
    "răstălmăciserăm": "răstălmăci",
    "răstălmăciserăți": "răstălmăci",
    "răstălmăciseși": "răstălmăci",
    "răstălmăciși": "răstălmăci",
    "răstălmăcit": "răstălmăci",
    "răstălmăciți": "răstălmăci",
    "răstălmăcită": "răstălmăcit",
    "răstălmăcite": "răstălmăcit",
    "răstălmăciți": "răstălmăcit",
    "rastele": "rastel",
    "rastelele": "rastel",
    "rastelelor": "rastel",
    "rastelul": "rastel",
    "rastelului": "rastel",
    "rastere": "raster",
    "rasterele": "raster",
    "rasterelor": "raster",
    "rasterul": "raster",
    "rasterului": "raster",
    "nemairăstind": "răsti",
    "nemairăstindu": "răsti",
    "nerăstind": "răsti",
    "nerăstindu": "răsti",
    "răstea": "răsti",
    "răsteai": "răsti",
    "răsteam": "răsti",
    "răstească": "răsti",
    "răsteați": "răsti",
    "răsteau": "răsti",
    "răstesc": "răsti",
    "răstește": "răsti",
    "răstești": "răsti",
    "răstii": "răsti",
    "răstim": "răsti",
    "răstind": "răsti",
    "răstindu": "răsti",
    "răstiră": "răsti",
    "răstirăm": "răsti",
    "răstirăți": "răsti",
    "răstise": "răsti",
    "răstisem": "răsti",
    "răstiseră": "răsti",
    "răstiserăm": "răsti",
    "răstiserăți": "răsti",
    "răstiseși": "răsti",
    "răstiși": "răsti",
    "răstit": "răsti",
    "răstiți": "răsti",
    "nemairăstignind": "răstigni",
    "nemairăstignindu": "răstigni",
    "nerăstignind": "răstigni",
    "nerăstignindu": "răstigni",
    "răstignea": "răstigni",
    "răstigneai": "răstigni",
    "răstigneam": "răstigni",
    "răstignească": "răstigni",
    "răstigneați": "răstigni",
    "răstigneau": "răstigni",
    "răstignesc": "răstigni",
    "răstignește": "răstigni",
    "răstignești": "răstigni",
    "răstignii": "răstigni",
    "răstignim": "răstigni",
    "răstignind": "răstigni",
    "răstignindu": "răstigni",
    "răstigniră": "răstigni",
    "răstignirăm": "răstigni",
    "răstignirăți": "răstigni",
    "răstignise": "răstigni",
    "răstignisem": "răstigni",
    "răstigniseră": "răstigni",
    "răstigniserăm": "răstigni",
    "răstigniserăți": "răstigni",
    "răstigniseși": "răstigni",
    "răstigniși": "răstigni",
    "răstignit": "răstigni",
    "răstigniți": "răstigni",
    "răstignirea": "răstignire",
    "răstigniri": "răstignire",
    "răstignirii": "răstignire",
    "răstignirile": "răstignire",
    "răstignirilor": "răstignire",
    "răstignită": "răstignit",
    "răstignite": "răstignit",
    "răstigniți": "răstignit",
    "răstimpul": "răstimp",
    "răstimpului": "răstimp",
    "răstimpuri": "răstimp",
    "răstimpurile": "răstimp",
    "răstimpurilor": "răstimp",
    "răstită": "răstit",
    "răstite": "răstit",
    "răstiți": "răstit",
    "nemairăstocind": "răstoci",
    "nemairăstocindu": "răstoci",
    "nerăstocind": "răstoci",
    "nerăstocindu": "răstoci",
    "răstocea": "răstoci",
    "răstoceai": "răstoci",
    "răstoceam": "răstoci",
    "răstocească": "răstoci",
    "răstoceați": "răstoci",
    "răstoceau": "răstoci",
    "răstocesc": "răstoci",
    "răstocește": "răstoci",
    "răstocești": "răstoci",
    "răstocii": "răstoci",
    "răstocim": "răstoci",
    "răstocind": "răstoci",
    "răstocindu": "răstoci",
    "răstociră": "răstoci",
    "răstocirăm": "răstoci",
    "răstocirăți": "răstoci",
    "răstocise": "răstoci",
    "răstocisem": "răstoci",
    "răstociseră": "răstoci",
    "răstociserăm": "răstoci",
    "răstociserăți": "răstoci",
    "răstociseși": "răstoci",
    "răstociși": "răstoci",
    "răstocit": "răstoci",
    "răstociți": "răstoci",
    "răstocită": "răstocit",
    "răstocite": "răstocit",
    "răstociți": "răstocit",
    "nemairăsturnând": "răsturna",
    "nemairăsturnându": "răsturna",
    "nerăsturnând": "răsturna",
    "nerăsturnându": "răsturna",
    "răstoarnă": "răsturna",
    "răstoarne": "răsturna",
    "răstorn": "răsturna",
    "răstorni": "răsturna",
    "răsturnă": "răsturna",
    "răsturnai": "răsturna",
    "răsturnam": "răsturna",
    "răsturnăm": "răsturna",
    "răsturnând": "răsturna",
    "răsturnându": "răsturna",
    "răsturnară": "răsturna",
    "răsturnarăm": "răsturna",
    "răsturnarăți": "răsturna",
    "răsturnase": "răsturna",
    "răsturnasem": "răsturna",
    "răsturnaseră": "răsturna",
    "răsturnaserăm": "răsturna",
    "răsturnaserăți": "răsturna",
    "răsturnaseși": "răsturna",
    "răsturnași": "răsturna",
    "răsturnat": "răsturna",
    "răsturnați": "răsturna",
    "răsturnau": "răsturna",
    "răsturnarea": "răsturnare",
    "răsturnări": "răsturnare",
    "răsturnării": "răsturnare",
    "răsturnările": "răsturnare",
    "răsturnărilor": "răsturnare",
    "răsturnată": "răsturnat",
    "răsturnate": "răsturnat",
    "răsturnați": "răsturnat",
    "nemairăsucind": "răsuci",
    "nemairăsucindu": "răsuci",
    "nerăsucind": "răsuci",
    "nerăsucindu": "răsuci",
    "răsucea": "răsuci",
    "răsuceai": "răsuci",
    "răsuceam": "răsuci",
    "răsucească": "răsuci",
    "răsuceați": "răsuci",
    "răsuceau": "răsuci",
    "răsucesc": "răsuci",
    "răsucește": "răsuci",
    "răsucești": "răsuci",
    "răsucii": "răsuci",
    "răsucim": "răsuci",
    "răsucind": "răsuci",
    "răsucindu": "răsuci",
    "răsuciră": "răsuci",
    "răsucirăm": "răsuci",
    "răsucirăți": "răsuci",
    "răsucise": "răsuci",
    "răsucisem": "răsuci",
    "răsuciseră": "răsuci",
    "răsuciserăm": "răsuci",
    "răsuciserăți": "răsuci",
    "răsuciseși": "răsuci",
    "răsuciși": "răsuci",
    "răsucit": "răsuci",
    "răsuciți": "răsuci",
    "răsucirea": "răsucire",
    "răsuciri": "răsucire",
    "răsucirii": "răsucire",
    "răsucirile": "răsucire",
    "răsucirilor": "răsucire",
    "răsucită": "răsucit",
    "răsucite": "răsucit",
    "răsuciți": "răsucit",
    "nemairăsuflând": "răsufla",
    "nemairăsuflându": "răsufla",
    "nerăsuflând": "răsufla",
    "nerăsuflându": "răsufla",
    "răsuflă": "răsufla",
    "răsuflai": "răsufla",
    "răsuflam": "răsufla",
    "răsuflăm": "răsufla",
    "răsuflând": "răsufla",
    "răsuflându": "răsufla",
    "răsuflară": "răsufla",
    "răsuflarăm": "răsufla",
    "răsuflarăți": "răsufla",
    "răsuflase": "răsufla",
    "răsuflasem": "răsufla",
    "răsuflaseră": "răsufla",
    "răsuflaserăm": "răsufla",
    "răsuflaserăți": "răsufla",
    "răsuflaseși": "răsufla",
    "răsuflași": "răsufla",
    "răsuflat": "răsufla",
    "răsuflați": "răsufla",
    "răsuflau": "răsufla",
    "răsufle": "răsufla",
    "răsufli": "răsufla",
    "răsuflu": "răsufla",
    "răsuflarea": "răsuflare",
    "răsuflareo": "răsuflare",
    "răsuflări": "răsuflare",
    "răsuflării": "răsuflare",
    "răsuflările": "răsuflare",
    "răsuflărilor": "răsuflare",
    "răsuflata": "răsuflat",
    "răsuflată": "răsuflat",
    "răsuflate": "răsuflat",
    "răsuflatei": "răsuflat",
    "răsuflatele": "răsuflat",
    "răsuflatelor": "răsuflat",
    "răsuflați": "răsuflat",
    "răsuflații": "răsuflat",
    "răsuflaților": "răsuflat",
    "răsuflato": "răsuflat",
    "răsuflatul": "răsuflat",
    "răsuflatule": "răsuflat",
    "răsuflatului": "răsuflat",
    "nemairăsunând": "răsuna",
    "nemairăsunându": "răsuna",
    "nerăsunând": "răsuna",
    "nerăsunându": "răsuna",
    "răsună": "răsuna",
    "răsunând": "răsuna",
    "răsunându": "răsuna",
    "răsunară": "răsuna",
    "răsunase": "răsuna",
    "răsunaseră": "răsuna",
    "răsunat": "răsuna",
    "răsunau": "răsuna",
    "răsune": "răsuna",
    "răsunarea": "răsunare",
    "răsunareo": "răsunare",
    "răsunări": "răsunare",
    "răsunării": "răsunare",
    "răsunările": "răsunare",
    "răsunărilor": "răsunare",
    "răsunată": "răsunat",
    "răsunate": "răsunat",
    "răsunați": "răsunat",
    "răsunătoare": "răsunător",
    "răsunătoarea": "răsunător",
    "răsunătoarei": "răsunător",
    "răsunătoarele": "răsunător",
    "răsunătoarelor": "răsunător",
    "răsunători": "răsunător",
    "răsunătorii": "răsunător",
    "răsunătorilor": "răsunător",
    "răsunătorul": "răsunător",
    "răsunătorului": "răsunător",
    "răsunete": "răsunet",
    "răsunetele": "răsunet",
    "răsunetelor": "răsunet",
    "răsunetul": "răsunet",
    "răsunetului": "răsunet",
    "răsuria": "răsuriu",
    "răsurie": "răsuriu",
    "răsuriei": "răsuriu",
    "răsurii": "răsuriu",
    "răsuriii": "răsuriu",
    "răsuriile": "răsuriu",
    "răsuriilor": "răsuriu",
    "răsuriul": "răsuriu",
    "răsuriului": "răsuriu",
    "râtul": "rât",
    "râtului": "rât",
    "râturi": "rât",
    "râturile": "rât",
    "râturilor": "rât",
    "nemairatând": "rata",
    "nemairatându": "rata",
    "neratând": "rata",
    "neratându": "rata",
    "rată": "rata",
    "ratai": "rata",
    "ratam": "rata",
    "ratăm": "rata",
    "ratând": "rata",
    "ratându": "rata",
    "ratară": "rata",
    "ratarăm": "rata",
    "ratarăți": "rata",
    "ratase": "rata",
    "ratasem": "rata",
    "rataseră": "rata",
    "rataserăm": "rata",
    "rataserăți": "rata",
    "rataseși": "rata",
    "ratași": "rata",
    "ratat": "rata",
    "ratați": "rata",
    "ratau": "rata",
    "ratează": "rata",
    "ratez": "rata",
    "rateze": "rata",
    "ratezi": "rata",
    "rata": "rată",
    "rate": "rată",
    "ratei": "rată",
    "ratele": "rată",
    "ratelor": "rată",
    "rața": "rață",
    "rațe": "rață",
    "raței": "rață",
    "rațele": "rață",
    "rațelor": "rață",
    "nemairătăcind": "rătăci",
    "nemairătăcindu": "rătăci",
    "nerătăcind": "rătăci",
    "nerătăcindu": "rătăci",
    "rătăcea": "rătăci",
    "rătăceai": "rătăci",
    "rătăceam": "rătăci",
    "rătăcească": "rătăci",
    "rătăceați": "rătăci",
    "rătăceau": "rătăci",
    "rătăcesc": "rătăci",
    "rătăcește": "rătăci",
    "rătăcești": "rătăci",
    "rătăcii": "rătăci",
    "rătăcim": "rătăci",
    "rătăcind": "rătăci",
    "rătăcindu": "rătăci",
    "rătăciră": "rătăci",
    "rătăcirăm": "rătăci",
    "rătăcirăți": "rătăci",
    "rătăcise": "rătăci",
    "rătăcisem": "rătăci",
    "rătăciseră": "rătăci",
    "rătăciserăm": "rătăci",
    "rătăciserăți": "rătăci",
    "rătăciseși": "rătăci",
    "rătăciși": "rătăci",
    "rătăcit": "rătăci",
    "rătăciți": "rătăci",
    "rătăcirea": "rătăcire",
    "rătăciri": "rătăcire",
    "rătăcirii": "rătăcire",
    "rătăcirile": "rătăcire",
    "rătăcirilor": "rătăcire",
    "rătăcită": "rătăcit",
    "rătăcite": "rătăcit",
    "rătăciți": "rătăcit",
    "rătăcitori": "rătăcitor",
    "rătăcitorii": "rătăcitor",
    "rătăcitorilor": "rătăcitor",
    "rătăcitorul": "rătăcitor",
    "rătăcitorului": "rătăcitor",
    "ratarea": "ratare",
    "ratareo": "ratare",
    "ratări": "ratare",
    "ratării": "ratare",
    "ratările": "ratare",
    "ratărilor": "ratare",
    "ratata": "ratat",
    "ratată": "ratat",
    "ratate": "ratat",
    "ratatei": "ratat",
    "ratatele": "ratat",
    "ratatelor": "ratat",
    "ratați": "ratat",
    "ratații": "ratat",
    "rataților": "ratat",
    "ratato": "ratat",
    "ratatul": "ratat",
    "ratatule": "ratat",
    "ratatului": "ratat",
    "ratata": "ratată",
    "ratate": "ratată",
    "ratatei": "ratată",
    "ratatele": "ratată",
    "ratatelor": "ratată",
    "ratato": "ratată",
    "rateul": "rateu",
    "rateului": "rateu",
    "rateuri": "rateu",
    "rateurile": "rateu",
    "rateurilor": "rateu",
    "rația": "rație",
    "rației": "rație",
    "rații": "rație",
    "rațiile": "rație",
    "rațiilor": "rație",
    "nemairatificând": "ratifica",
    "nemairatificându": "ratifica",
    "neratificând": "ratifica",
    "neratificându": "ratifica",
    "ratific": "ratifica",
    "ratifică": "ratifica",
    "ratificai": "ratifica",
    "ratificam": "ratifica",
    "ratificăm": "ratifica",
    "ratificând": "ratifica",
    "ratificându": "ratifica",
    "ratificară": "ratifica",
    "ratificarăm": "ratifica",
    "ratificarăți": "ratifica",
    "ratificase": "ratifica",
    "ratificasem": "ratifica",
    "ratificaseră": "ratifica",
    "ratificaserăm": "ratifica",
    "ratificaserăți": "ratifica",
    "ratificaseși": "ratifica",
    "ratificași": "ratifica",
    "ratificat": "ratifica",
    "ratificați": "ratifica",
    "ratificau": "ratifica",
    "ratifice": "ratifica",
    "ratifici": "ratifica",
    "ratificarea": "ratificare",
    "ratificareo": "ratificare",
    "ratificări": "ratificare",
    "ratificării": "ratificare",
    "ratificările": "ratificare",
    "ratificărilor": "ratificare",
    "ratificata": "ratificat",
    "ratificată": "ratificat",
    "ratificate": "ratificat",
    "ratificatei": "ratificat",
    "ratificatele": "ratificat",
    "ratificatelor": "ratificat",
    "ratificați": "ratificat",
    "ratificații": "ratificat",
    "ratificaților": "ratificat",
    "ratificato": "ratificat",
    "ratificatul": "ratificat",
    "ratificatule": "ratificat",
    "ratificatului": "ratificat",
    "nemairaționând": "raționa",
    "nemairaționându": "raționa",
    "neraționând": "raționa",
    "neraționându": "raționa",
    "raționă": "raționa",
    "raționai": "raționa",
    "raționam": "raționa",
    "raționăm": "raționa",
    "raționând": "raționa",
    "raționându": "raționa",
    "raționară": "raționa",
    "raționarăm": "raționa",
    "raționarăți": "raționa",
    "raționase": "raționa",
    "raționasem": "raționa",
    "raționaseră": "raționa",
    "raționaserăm": "raționa",
    "raționaserăți": "raționa",
    "raționaseși": "raționa",
    "raționași": "raționa",
    "raționați": "raționa",
    "raționau": "raționa",
    "raționează": "raționa",
    "raționez": "raționa",
    "raționeze": "raționa",
    "raționezi": "raționa",
    "raționala": "rațional",
    "rațională": "rațional",
    "raționale": "rațional",
    "raționalei": "rațional",
    "raționalele": "rațional",
    "raționalelor": "rațional",
    "raționali": "rațional",
    "raționalii": "rațional",
    "raționalilor": "rațional",
    "raționalul": "rațional",
    "raționalului": "rațional",
    "raționalismul": "raționalism",
    "raționalismului": "raționalism",
    "raționalista": "raționalist",
    "raționalistă": "raționalist",
    "raționaliste": "raționalist",
    "raționalistei": "raționalist",
    "raționalistele": "raționalist",
    "raționalistelor": "raționalist",
    "raționaliști": "raționalist",
    "raționaliștii": "raționalist",
    "raționaliștilor": "raționalist",
    "raționalistul": "raționalist",
    "raționalistului": "raționalist",
    "raționalista": "raționalistă",
    "raționaliste": "raționalistă",
    "raționalistei": "raționalistă",
    "raționalistele": "raționalistă",
    "raționalistelor": "raționalistă",
    "nemairaționalizând": "raționaliza",
    "nemairaționalizându": "raționaliza",
    "neraționalizând": "raționaliza",
    "neraționalizându": "raționaliza",
    "raționaliză": "raționaliza",
    "raționalizai": "raționaliza",
    "raționalizam": "raționaliza",
    "raționalizăm": "raționaliza",
    "raționalizând": "raționaliza",
    "raționalizându": "raționaliza",
    "raționalizară": "raționaliza",
    "raționalizarăm": "raționaliza",
    "raționalizarăți": "raționaliza",
    "raționalizase": "raționaliza",
    "raționalizasem": "raționaliza",
    "raționalizaseră": "raționaliza",
    "raționalizaserăm": "raționaliza",
    "raționalizaserăți": "raționaliza",
    "raționalizaseși": "raționaliza",
    "raționalizași": "raționaliza",
    "raționalizat": "raționaliza",
    "raționalizați": "raționaliza",
    "raționalizau": "raționaliza",
    "raționalizează": "raționaliza",
    "raționalizez": "raționaliza",
    "raționalizeze": "raționaliza",
    "raționalizezi": "raționaliza",
    "raționalizarea": "raționalizare",
    "raționalizări": "raționalizare",
    "raționalizării": "raționalizare",
    "raționalizările": "raționalizare",
    "raționalizărilor": "raționalizare",
    "raționalizata": "raționalizat",
    "raționalizată": "raționalizat",
    "raționalizate": "raționalizat",
    "raționalizatei": "raționalizat",
    "raționalizatele": "raționalizat",
    "raționalizatelor": "raționalizat",
    "raționalizați": "raționalizat",
    "raționalizații": "raționalizat",
    "raționalizaților": "raționalizat",
    "raționalizato": "raționalizat",
    "raționalizatul": "raționalizat",
    "raționalizatule": "raționalizat",
    "raționalizatului": "raționalizat",
    "raționamente": "raționament",
    "raționamentele": "raționament",
    "raționamentelor": "raționament",
    "raționamentul": "raționament",
    "raționamentului": "raționament",
    "raționarea": "raționare",
    "raționări": "raționare",
    "raționării": "raționare",
    "raționările": "raționare",
    "raționărilor": "raționare",
    "rațiunea": "rațiune",
    "rațiuni": "rațiune",
    "rațiunii": "rațiune",
    "rațiunile": "rațiune",
    "rațiunilor": "rațiune",
    "rățoia": "rățoi",
    "rățoiai": "rățoi",
    "rățoiam": "rățoi",
    "rățoiască": "rățoi",
    "rățoiați": "rățoi",
    "rățoiau": "rățoi",
    "rățoiesc": "rățoi",
    "rățoiește": "rățoi",
    "rățoiești": "rățoi",
    "rățoii": "rățoi",
    "rățoilor": "rățoi",
    "rățoim": "rățoi",
    "rățoind": "rățoi",
    "rățoindu": "rățoi",
    "rățoiră": "rățoi",
    "rățoirăm": "rățoi",
    "rățoirăți": "rățoi",
    "rățoise": "rățoi",
    "rățoisem": "rățoi",
    "rățoiseră": "rățoi",
    "rățoiserăm": "rățoi",
    "rățoiserăți": "rățoi",
    "rățoiseși": "rățoi",
    "rățoiși": "rățoi",
    "rățoit": "rățoi",
    "rățoiți": "rățoi",
    "rățoitu": "rățoi",
    "rățoiul": "rățoi",
    "rățoiului": "rățoi",
    "rățoită": "rățoit",
    "rățoite": "rățoit",
    "rățoiți": "rățoit",
    "râul": "râu",
    "râului": "râu",
    "râuri": "râu",
    "râurile": "râu",
    "râurilor": "râu",
    "răi": "rău",
    "răii": "rău",
    "răilor": "rău",
    "răul": "rău",
    "răului": "rău",
    "rea": "rău",
    "reaua": "rău",
    "rele": "rău",
    "relei": "rău",
    "relele": "rău",
    "relelor": "rău",
    "răufăcătoarea": "răufăcătoare",
    "răufăcătoarei": "răufăcătoare",
    "răufăcătoarele": "răufăcătoare",
    "răufăcătoarelor": "răufăcătoare",
    "răufăcătoareo": "răufăcătoare",
    "răufăcătoare": "răufăcător",
    "răufăcătoarea": "răufăcător",
    "răufăcătoarei": "răufăcător",
    "răufăcătoarele": "răufăcător",
    "răufăcătoarelor": "răufăcător",
    "răufăcători": "răufăcător",
    "răufăcătorii": "răufăcător",
    "răufăcătorilor": "răufăcător",
    "răufăcătorul": "răufăcător",
    "răufăcătorului": "răufăcător",
    "râulețe": "râuleț",
    "râulețele": "râuleț",
    "râulețelor": "râuleț",
    "râulețul": "râuleț",
    "râulețului": "râuleț",
    "rău-platnica": "rău-platnic",
    "rău-platnică": "rău-platnic",
    "rău-platnice": "rău-platnic",
    "rău-platnicei": "rău-platnic",
    "rău-platnicele": "rău-platnic",
    "rău-platnicelor": "rău-platnic",
    "rău-platnici": "rău-platnic",
    "rău-platnicii": "rău-platnic",
    "rău-platnicilor": "rău-platnic",
    "rău-platnicul": "rău-platnic",
    "rău-platnicului": "rău-platnic",
    "rău-platnica": "rău-platnică",
    "rău-platnice": "rău-platnică",
    "rău-platnicei": "rău-platnică",
    "rău-platnicele": "rău-platnică",
    "rău-platnicelor": "rău-platnică",
    "răutăcioasa": "răutăcios",
    "răutăcioasă": "răutăcios",
    "răutăcioase": "răutăcios",
    "răutăcioasei": "răutăcios",
    "răutăcioasele": "răutăcios",
    "răutăcioaselor": "răutăcios",
    "răutăcioși": "răutăcios",
    "răutăcioșii": "răutăcios",
    "răutăcioșilor": "răutăcios",
    "răutăciosul": "răutăcios",
    "răutăciosului": "răutăcios",
    "răutatea": "răutate",
    "răutăți": "răutate",
    "răutății": "răutate",
    "răutățile": "răutate",
    "răutăților": "răutate",
    "rău-venită": "rău-venit",
    "răuvoitoarea": "răuvoitoare",
    "răuvoitoarei": "răuvoitoare",
    "răuvoitoarele": "răuvoitoare",
    "răuvoitoarelor": "răuvoitoare",
    "răuvoitoare": "răuvoitor",
    "răuvoitoarea": "răuvoitor",
    "răuvoitoarei": "răuvoitor",
    "răuvoitoarele": "răuvoitor",
    "răuvoitoarelor": "răuvoitor",
    "răuvoitori": "răuvoitor",
    "răuvoitorii": "răuvoitor",
    "răuvoitorilor": "răuvoitor",
    "răuvoitorul": "răuvoitor",
    "răuvoitorului": "răuvoitor",
    "ravagii": "ravagiu",
    "ravagiile": "ravagiu",
    "ravagiilor": "ravagiu",
    "ravagiul": "ravagiu",
    "ravagiului": "ravagiu",
    "răvașe": "răvaș",
    "răvașele": "răvaș",
    "răvașelor": "răvaș",
    "răvașul": "răvaș",
    "răvașului": "răvaș",
    "nemairăvășind": "răvăși",
    "nemairăvășindu": "răvăși",
    "nerăvășind": "răvăși",
    "nerăvășindu": "răvăși",
    "răvășea": "răvăși",
    "răvășeai": "răvăși",
    "răvășeam": "răvăși",
    "răvășească": "răvăși",
    "răvășeați": "răvăși",
    "răvășeau": "răvăși",
    "răvășesc": "răvăși",
    "răvășește": "răvăși",
    "răvășești": "răvăși",
    "răvășii": "răvăși",
    "răvășim": "răvăși",
    "răvășind": "răvăși",
    "răvășindu": "răvăși",
    "răvășiră": "răvăși",
    "răvășirăm": "răvăși",
    "răvășirăți": "răvăși",
    "răvășise": "răvăși",
    "răvășisem": "răvăși",
    "răvășiseră": "răvăși",
    "răvășiserăm": "răvăși",
    "răvășiserăți": "răvăși",
    "răvășiseși": "răvăși",
    "răvășiși": "răvăși",
    "răvășit": "răvăși",
    "răvășiți": "răvăși",
    "răvășită": "răvășit",
    "răvășite": "răvășit",
    "răvășiți": "răvășit",
    "ravena": "ravenă",
    "ravene": "ravenă",
    "ravenei": "ravenă",
    "ravenele": "ravenă",
    "ravenelor": "ravenă",
    "râvna": "râvnă",
    "râvne": "râvnă",
    "râvnei": "râvnă",
    "râvnele": "râvnă",
    "râvnelor": "râvnă",
    "nemairâvnind": "râvni",
    "nemairâvnindu": "râvni",
    "nerâvnind": "râvni",
    "nerâvnindu": "râvni",
    "râvnea": "râvni",
    "râvneai": "râvni",
    "râvneam": "râvni",
    "râvnească": "râvni",
    "râvneați": "râvni",
    "râvneau": "râvni",
    "râvnesc": "râvni",
    "râvnește": "râvni",
    "râvnești": "râvni",
    "râvnii": "râvni",
    "râvnim": "râvni",
    "râvnind": "râvni",
    "râvnindu": "râvni",
    "râvniră": "râvni",
    "râvnirăm": "râvni",
    "râvnirăți": "râvni",
    "râvnise": "râvni",
    "râvnisem": "râvni",
    "râvniseră": "râvni",
    "râvniserăm": "râvni",
    "râvniserăți": "râvni",
    "râvniseși": "râvni",
    "râvniși": "râvni",
    "râvnit": "râvni",
    "râvniți": "râvni",
    "râvnirea": "râvnire",
    "râvniri": "râvnire",
    "râvnirii": "râvnire",
    "râvnirile": "râvnire",
    "râvnirilor": "râvnire",
    "râvnită": "râvnit",
    "râvnite": "râvnit",
    "râvniți": "râvnit",
    "râvnitoare": "râvnitor",
    "râvnitoarea": "râvnitor",
    "râvnitoarei": "râvnitor",
    "râvnitoarele": "râvnitor",
    "râvnitoarelor": "râvnitor",
    "râvnitoareo": "râvnitor",
    "râvnitori": "râvnitor",
    "râvnitorii": "râvnitor",
    "râvnitorilor": "râvnitor",
    "râvnitorul": "râvnitor",
    "râvnitorule": "râvnitor",
    "râvnitorului": "râvnitor",
    "razul": "raz",
    "razului": "raz",
    "razuri": "raz",
    "razurile": "raz",
    "razurilor": "raz",
    "raza": "rază",
    "raze": "rază",
    "razei": "rază",
    "razele": "rază",
    "razelor": "rază",
    "razanta": "razant",
    "razantă": "razant",
    "razante": "razant",
    "razantei": "razant",
    "razantele": "razant",
    "razantelor": "razant",
    "razanți": "razant",
    "razanții": "razant",
    "razanților": "razant",
    "razantul": "razant",
    "razantului": "razant",
    "răzătoarea": "răzătoare",
    "răzători": "răzătoare",
    "răzătorii": "răzătoare",
    "răzătorile": "răzătoare",
    "răzătorilor": "răzătoare",
    "râzătoare": "râzător",
    "râzătoarea": "râzător",
    "râzătoarei": "râzător",
    "râzătoarele": "râzător",
    "râzătoarelor": "râzător",
    "râzători": "râzător",
    "râzătorii": "râzător",
    "râzătorilor": "râzător",
    "râzătorul": "râzător",
    "râzătorului": "râzător",
    "răzbătătoare": "răzbătător",
    "răzbătătoarea": "răzbătător",
    "răzbătătoarei": "răzbătător",
    "răzbătătoarele": "răzbătător",
    "răzbătătoarelor": "răzbătător",
    "răzbătători": "răzbătător",
    "răzbătătorii": "răzbătător",
    "răzbătătorilor": "răzbătător",
    "răzbătătorul": "răzbătător",
    "răzbătătorului": "răzbătător",
    "nemairăzbătând": "răzbate",
    "nemairăzbătându": "răzbate",
    "nerăzbătând": "răzbate",
    "nerăzbătându": "răzbate",
    "răzbat": "răzbate",
    "răzbată": "răzbate",
    "răzbătând": "răzbate",
    "răzbătându": "răzbate",
    "răzbătea": "răzbate",
    "răzbăteai": "răzbate",
    "răzbăteam": "răzbate",
    "răzbăteați": "răzbate",
    "răzbăteau": "răzbate",
    "răzbatem": "răzbate",
    "răzbateți": "răzbate",
    "răzbați": "răzbate",
    "răzbătu": "răzbate",
    "răzbătui": "răzbate",
    "răzbătură": "răzbate",
    "răzbăturăm": "răzbate",
    "răzbăturăți": "răzbate",
    "răzbătuse": "răzbate",
    "răzbătusem": "răzbate",
    "răzbătuseră": "răzbate",
    "răzbătuserăm": "răzbate",
    "răzbătuserăți": "răzbate",
    "răzbătuseși": "răzbate",
    "răzbătuși": "răzbate",
    "răzbătut": "răzbate",
    "răzbătută": "răzbătut",
    "răzbătute": "răzbătut",
    "răzbătuți": "răzbătut",
    "nemairăzbind": "răzbi",
    "nemairăzbindu": "răzbi",
    "nerăzbind": "răzbi",
    "nerăzbindu": "răzbi",
    "răzbea": "răzbi",
    "răzbeai": "răzbi",
    "răzbeam": "răzbi",
    "răzbească": "răzbi",
    "răzbeați": "răzbi",
    "răzbeau": "răzbi",
    "răzbesc": "răzbi",
    "răzbește": "răzbi",
    "răzbești": "răzbi",
    "răzbii": "răzbi",
    "răzbim": "răzbi",
    "răzbind": "răzbi",
    "răzbindu": "răzbi",
    "răzbiră": "răzbi",
    "răzbirăm": "răzbi",
    "răzbirăți": "răzbi",
    "răzbise": "răzbi",
    "răzbisem": "răzbi",
    "răzbiseră": "răzbi",
    "răzbiserăm": "răzbi",
    "răzbiserăți": "răzbi",
    "răzbiseși": "răzbi",
    "răzbiși": "răzbi",
    "răzbit": "răzbi",
    "răzbiți": "răzbi",
    "răzbită": "răzbit",
    "răzbite": "răzbit",
    "răzbiți": "răzbit",
    "nemairăzboind": "război",
    "nemairăzboindu": "război",
    "nerăzboind": "război",
    "nerăzboindu": "război",
    "războaie": "război",
    "războaiele": "război",
    "războaielor": "război",
    "războia": "război",
    "războiai": "război",
    "războiam": "război",
    "războiască": "război",
    "războiați": "război",
    "războiau": "război",
    "războiesc": "război",
    "războiește": "război",
    "războiești": "război",
    "războii": "război",
    "războim": "război",
    "războind": "război",
    "războindu": "război",
    "războiră": "război",
    "războirăm": "război",
    "războirăți": "război",
    "războise": "război",
    "războisem": "război",
    "războiseră": "război",
    "războiserăm": "război",
    "războiserăți": "război",
    "războiseși": "război",
    "războiși": "război",
    "războit": "război",
    "războiți": "război",
    "războiul": "război",
    "războiului": "război",
    "războinica": "războinic",
    "războinică": "războinic",
    "războinice": "războinic",
    "războinicei": "războinic",
    "războinicele": "războinic",
    "războinicelor": "războinic",
    "războinici": "războinic",
    "războinicii": "războinic",
    "războinicilor": "războinic",
    "războinicul": "războinic",
    "războinicului": "războinic",
    "războinica": "războinică",
    "războinice": "războinică",
    "războinicei": "războinică",
    "războinicele": "războinică",
    "războinicelor": "războinică",
    "războită": "războit",
    "războite": "războit",
    "războiți": "războit",
    "nemairăzbunând": "răzbuna",
    "nemairăzbunându": "răzbuna",
    "nerăzbunând": "răzbuna",
    "nerăzbunându": "răzbuna",
    "răzbun": "răzbuna",
    "răzbună": "răzbuna",
    "răzbunai": "răzbuna",
    "răzbunam": "răzbuna",
    "răzbunăm": "răzbuna",
    "răzbunând": "răzbuna",
    "răzbunându": "răzbuna",
    "răzbunară": "răzbuna",
    "răzbunarăm": "răzbuna",
    "răzbunarăți": "răzbuna",
    "răzbunase": "răzbuna",
    "răzbunasem": "răzbuna",
    "răzbunaseră": "răzbuna",
    "răzbunaserăm": "răzbuna",
    "răzbunaserăți": "răzbuna",
    "răzbunaseși": "răzbuna",
    "răzbunași": "răzbuna",
    "răzbunat": "răzbuna",
    "răzbunați": "răzbuna",
    "răzbunau": "răzbuna",
    "răzbune": "răzbuna",
    "răzbuni": "răzbuna",
    "răzbunarea": "răzbunare",
    "răzbunareo": "răzbunare",
    "răzbunări": "răzbunare",
    "răzbunării": "răzbunare",
    "răzbunările": "răzbunare",
    "răzbunărilor": "răzbunare",
    "răzbunata": "răzbunat",
    "răzbunată": "răzbunat",
    "răzbunate": "răzbunat",
    "răzbunatei": "răzbunat",
    "răzbunatele": "răzbunat",
    "răzbunatelor": "răzbunat",
    "răzbunați": "răzbunat",
    "răzbunații": "răzbunat",
    "răzbunaților": "răzbunat",
    "răzbunato": "răzbunat",
    "răzbunatul": "răzbunat",
    "răzbunatule": "răzbunat",
    "răzbunatului": "răzbunat",
    "răzbunătoare": "răzbunător",
    "răzbunătoarea": "răzbunător",
    "răzbunătoarei": "răzbunător",
    "răzbunătoarele": "răzbunător",
    "răzbunătoarelor": "răzbunător",
    "răzbunători": "răzbunător",
    "răzbunătorii": "răzbunător",
    "răzbunătorilor": "răzbunător",
    "răzbunătorul": "răzbunător",
    "răzbunătorului": "răzbunător",
    "răzeși": "răzeș",
    "răzeșii": "răzeș",
    "răzeșilor": "răzeș",
    "răzeșul": "răzeș",
    "răzeșului": "răzeș",
    "răzeșeasca": "răzeșesc",
    "răzeșească": "răzeșesc",
    "răzeșescul": "răzeșesc",
    "răzeșescului": "răzeșesc",
    "răzeșești": "răzeșesc",
    "răzeșeștii": "răzeșesc",
    "răzeșeștile": "răzeșesc",
    "răzeșeștilor": "răzeșesc",
    "nemairăzgâiind": "răzgâia",
    "nemairăzgâiindu": "răzgâia",
    "nerăzgâiind": "răzgâia",
    "nerăzgâiindu": "răzgâia",
    "răzgâi": "răzgâia",
    "răzgâiai": "răzgâia",
    "răzgâiam": "răzgâia",
    "răzgâiară": "răzgâia",
    "răzgâiarăm": "răzgâia",
    "răzgâiarăți": "răzgâia",
    "răzgâiase": "răzgâia",
    "răzgâiasem": "răzgâia",
    "răzgâiaseră": "răzgâia",
    "răzgâiaserăm": "răzgâia",
    "răzgâiaserăți": "răzgâia",
    "răzgâiaseși": "răzgâia",
    "răzgâiași": "răzgâia",
    "răzgâiat": "răzgâia",
    "răzgâiați": "răzgâia",
    "răzgâiau": "răzgâia",
    "răzgâie": "răzgâia",
    "răzgâiem": "răzgâia",
    "răzgâind": "răzgâia",
    "răzgâindu": "răzgâia",
    "răzgâiala": "răzgâială",
    "răzgâialo": "răzgâială",
    "răzgâieli": "răzgâială",
    "răzgâielii": "răzgâială",
    "răzgâielile": "răzgâială",
    "răzgâielilor": "răzgâială",
    "răzgâiata": "răzgâiat",
    "răzgâiată": "răzgâiat",
    "răzgâiate": "răzgâiat",
    "răzgâiatei": "răzgâiat",
    "răzgâiatele": "răzgâiat",
    "răzgâiatelor": "răzgâiat",
    "răzgâiați": "răzgâiat",
    "răzgâiații": "răzgâiat",
    "răzgâiaților": "răzgâiat",
    "răzgâiato": "răzgâiat",
    "răzgâiatul": "răzgâiat",
    "răzgâiatule": "răzgâiat",
    "răzgâiatului": "răzgâiat",
    "răzgâierea": "răzgâiere",
    "răzgâiereo": "răzgâiere",
    "răzgâieri": "răzgâiere",
    "răzgâierii": "răzgâiere",
    "răzgâierile": "răzgâiere",
    "răzgâierilor": "răzgâiere",
    "nemairăzgândind": "răzgândi",
    "nemairăzgândindu": "răzgândi",
    "nerăzgândind": "răzgândi",
    "nerăzgândindu": "răzgândi",
    "răzgândea": "răzgândi",
    "răzgândeai": "răzgândi",
    "răzgândeam": "răzgândi",
    "răzgândească": "răzgândi",
    "răzgândeați": "răzgândi",
    "răzgândeau": "răzgândi",
    "răzgândesc": "răzgândi",
    "răzgândește": "răzgândi",
    "răzgândești": "răzgândi",
    "răzgândii": "răzgândi",
    "răzgândim": "răzgândi",
    "răzgândind": "răzgândi",
    "răzgândindu": "răzgândi",
    "răzgândiră": "răzgândi",
    "răzgândirăm": "răzgândi",
    "răzgândirăți": "răzgândi",
    "răzgândise": "răzgândi",
    "răzgândisem": "răzgândi",
    "răzgândiseră": "răzgândi",
    "răzgândiserăm": "răzgândi",
    "răzgândiserăți": "răzgândi",
    "răzgândiseși": "răzgândi",
    "răzgândiși": "răzgândi",
    "răzgândit": "răzgândi",
    "răzgândiți": "răzgândi",
    "răzgândirea": "răzgândire",
    "răzgândireo": "răzgândire",
    "răzgândiri": "răzgândire",
    "răzgândirii": "răzgândire",
    "răzgândirile": "răzgândire",
    "răzgândirilor": "răzgândire",
    "răzgândită": "răzgândit",
    "răzgândite": "răzgândit",
    "răzgândiți": "răzgândit",
    "razia": "razie",
    "raziei": "razie",
    "razii": "razie",
    "raziile": "razie",
    "raziilor": "razie",
    "răzleața": "răzleț",
    "răzleață": "răzleț",
    "răzlețe": "răzleț",
    "răzleței": "răzleț",
    "răzlețele": "răzleț",
    "răzlețelor": "răzleț",
    "răzleți": "răzleț",
    "răzleții": "răzleț",
    "răzleților": "răzleț",
    "răzlețul": "răzleț",
    "răzlețului": "răzleț",
    "nemairăzlețind": "răzleți",
    "nemairăzlețindu": "răzleți",
    "nerăzlețind": "răzleți",
    "nerăzlețindu": "răzleți",
    "răzlețea": "răzleți",
    "răzlețeai": "răzleți",
    "răzlețeam": "răzleți",
    "răzlețească": "răzleți",
    "răzlețeați": "răzleți",
    "răzlețeau": "răzleți",
    "răzlețesc": "răzleți",
    "răzlețește": "răzleți",
    "răzlețești": "răzleți",
    "răzleții": "răzleți",
    "răzlețim": "răzleți",
    "răzlețind": "răzleți",
    "răzlețindu": "răzleți",
    "răzlețiră": "răzleți",
    "răzlețirăm": "răzleți",
    "răzlețirăți": "răzleți",
    "răzlețise": "răzleți",
    "răzlețisem": "răzleți",
    "răzlețiseră": "răzleți",
    "răzlețiserăm": "răzleți",
    "răzlețiserăți": "răzleți",
    "răzlețiseși": "răzleți",
    "răzlețiși": "răzleți",
    "răzlețit": "răzleți",
    "răzlețiți": "răzleți",
    "răzlețită": "răzlețit",
    "răzlețite": "răzlețit",
    "răzlețiți": "răzlețit",
    "răzmerița": "răzmeriță",
    "răzmerițe": "răzmeriță",
    "răzmeriței": "răzmeriță",
    "răzmerițele": "răzmeriță",
    "răzmerițelor": "răzmeriță",
    "răzoare": "răzor",
    "răzoarele": "răzor",
    "răzoarelor": "răzor",
    "răzorul": "răzor",
    "răzorului": "răzor",
    "nemairăzuind": "răzui",
    "nemairăzuindu": "răzui",
    "nerăzuind": "răzui",
    "nerăzuindu": "răzui",
    "răzuia": "răzui",
    "răzuiai": "răzui",
    "răzuiam": "răzui",
    "răzuiască": "răzui",
    "răzuiați": "răzui",
    "răzuiau": "răzui",
    "răzuiesc": "răzui",
    "răzuiește": "răzui",
    "răzuiești": "răzui",
    "răzuii": "răzui",
    "răzuim": "răzui",
    "răzuind": "răzui",
    "răzuindu": "răzui",
    "răzuiră": "răzui",
    "răzuirăm": "răzui",
    "răzuirăți": "răzui",
    "răzuise": "răzui",
    "răzuisem": "răzui",
    "răzuiseră": "răzui",
    "răzuiserăm": "răzui",
    "răzuiserăți": "răzui",
    "răzuiseși": "răzui",
    "răzuiși": "răzui",
    "răzuit": "răzui",
    "răzuiți": "răzui",
    "răzuiala": "răzuială",
    "răzuialo": "răzuială",
    "răzuieli": "răzuială",
    "răzuielii": "răzuială",
    "răzuielile": "răzuială",
    "răzuielilor": "răzuială",
    "răzuirea": "răzuire",
    "răzuireo": "răzuire",
    "răzuiri": "răzuire",
    "răzuirii": "răzuire",
    "răzuirile": "răzuire",
    "răzuirilor": "răzuire",
    "răzuita": "răzuit",
    "răzuită": "răzuit",
    "răzuite": "răzuit",
    "răzuitei": "răzuit",
    "răzuitele": "răzuit",
    "răzuitelor": "răzuit",
    "răzuiți": "răzuit",
    "răzuiții": "răzuit",
    "răzuiților": "răzuit",
    "răzuito": "răzuit",
    "răzuitul": "răzuit",
    "răzuitule": "răzuit",
    "răzuitului": "răzuit",
    "nemairăzvrătind": "răzvrăti",
    "nemairăzvrătindu": "răzvrăti",
    "nerăzvrătind": "răzvrăti",
    "nerăzvrătindu": "răzvrăti",
    "răzvrătea": "răzvrăti",
    "răzvrăteai": "răzvrăti",
    "răzvrăteam": "răzvrăti",
    "răzvrătească": "răzvrăti",
    "răzvrăteați": "răzvrăti",
    "răzvrăteau": "răzvrăti",
    "răzvrătesc": "răzvrăti",
    "răzvrătește": "răzvrăti",
    "răzvrătești": "răzvrăti",
    "răzvrătii": "răzvrăti",
    "răzvrătim": "răzvrăti",
    "răzvrătind": "răzvrăti",
    "răzvrătindu": "răzvrăti",
    "răzvrătiră": "răzvrăti",
    "răzvrătirăm": "răzvrăti",
    "răzvrătirăți": "răzvrăti",
    "răzvrătise": "răzvrăti",
    "răzvrătisem": "răzvrăti",
    "răzvrătiseră": "răzvrăti",
    "răzvrătiserăm": "răzvrăti",
    "răzvrătiserăți": "răzvrăti",
    "răzvrătiseși": "răzvrăti",
    "răzvrătiși": "răzvrăti",
    "răzvrătit": "răzvrăti",
    "răzvrătiți": "răzvrăti",
    "răzvrătirea": "răzvrătire",
    "răzvrătireo": "răzvrătire",
    "răzvrătiri": "răzvrătire",
    "răzvrătirii": "răzvrătire",
    "răzvrătirile": "răzvrătire",
    "răzvrătirilor": "răzvrătire",
    "răzvrătită": "răzvrătit",
    "răzvrătite": "răzvrătit",
    "răzvrătiți": "răzvrătit",
    "nemaireabilitând": "reabilita",
    "nemaireabilitându": "reabilita",
    "nereabilitând": "reabilita",
    "nereabilitându": "reabilita",
    "reabilită": "reabilita",
    "reabilitai": "reabilita",
    "reabilitam": "reabilita",
    "reabilităm": "reabilita",
    "reabilitând": "reabilita",
    "reabilitându": "reabilita",
    "reabilitară": "reabilita",
    "reabilitarăm": "reabilita",
    "reabilitarăți": "reabilita",
    "reabilitase": "reabilita",
    "reabilitasem": "reabilita",
    "reabilitaseră": "reabilita",
    "reabilitaserăm": "reabilita",
    "reabilitaserăți": "reabilita",
    "reabilitaseși": "reabilita",
    "reabilitași": "reabilita",
    "reabilitat": "reabilita",
    "reabilitați": "reabilita",
    "reabilitau": "reabilita",
    "reabilitează": "reabilita",
    "reabilitez": "reabilita",
    "reabiliteze": "reabilita",
    "reabilitezi": "reabilita",
    "reabilitarea": "reabilitare",
    "reabilitareo": "reabilitare",
    "reabilitări": "reabilitare",
    "reabilitării": "reabilitare",
    "reabilitările": "reabilitare",
    "reabilitărilor": "reabilitare",
    "reabilitata": "reabilitat",
    "reabilitată": "reabilitat",
    "reabilitate": "reabilitat",
    "reabilitatei": "reabilitat",
    "reabilitatele": "reabilitat",
    "reabilitatelor": "reabilitat",
    "reabilitați": "reabilitat",
    "reabilitații": "reabilitat",
    "reabilitaților": "reabilitat",
    "reabilitato": "reabilitat",
    "reabilitatul": "reabilitat",
    "reabilitatule": "reabilitat",
    "reabilitatului": "reabilitat",
    "reactanți": "reactant",
    "reactanții": "reactant",
    "reactanților": "reactant",
    "reactantul": "reactant",
    "reactantului": "reactant",
    "reactanța": "reactanță",
    "reactanțe": "reactanță",
    "reactanței": "reactanță",
    "reactanțele": "reactanță",
    "reactanțelor": "reactanță",
    "reacția": "reacție",
    "reacției": "reacție",
    "reacții": "reacție",
    "reacțiile": "reacție",
    "reacțiilor": "reacție",
    "nemaireacționând": "reacționa",
    "nemaireacționându": "reacționa",
    "nereacționând": "reacționa",
    "nereacționându": "reacționa",
    "reacționă": "reacționa",
    "reacționai": "reacționa",
    "reacționam": "reacționa",
    "reacționăm": "reacționa",
    "reacționând": "reacționa",
    "reacționându": "reacționa",
    "reacționară": "reacționa",
    "reacționarăm": "reacționa",
    "reacționarăți": "reacționa",
    "reacționase": "reacționa",
    "reacționasem": "reacționa",
    "reacționaseră": "reacționa",
    "reacționaserăm": "reacționa",
    "reacționaserăți": "reacționa",
    "reacționaseși": "reacționa",
    "reacționași": "reacționa",
    "reacționat": "reacționa",
    "reacționați": "reacționa",
    "reacționau": "reacționa",
    "reacționează": "reacționa",
    "reacționez": "reacționa",
    "reacționeze": "reacționa",
    "reacționezi": "reacționa",
    "reacționara": "reacționar",
    "reacționară": "reacționar",
    "reacționare": "reacționar",
    "reacționarei": "reacționar",
    "reacționarele": "reacționar",
    "reacționarelor": "reacționar",
    "reacționari": "reacționar",
    "reacționarii": "reacționar",
    "reacționarilor": "reacționar",
    "reacționarul": "reacționar",
    "reacționarului": "reacționar",
    "reacționată": "reacționat",
    "reacționate": "reacționat",
    "reacționați": "reacționat",
    "reacțiunea": "reacțiune",
    "reacțiuni": "reacțiune",
    "reacțiunii": "reacțiune",
    "reacțiunile": "reacțiune",
    "reacțiunilor": "reacțiune",
    "reactiva": "reactiv",
    "reactivă": "reactiv",
    "reactive": "reactiv",
    "reactivei": "reactiv",
    "reactivele": "reactiv",
    "reactivelor": "reactiv",
    "reactivi": "reactiv",
    "reactivii": "reactiv",
    "reactivilor": "reactiv",
    "reactivul": "reactiv",
    "reactivului": "reactiv",
    "nemaireactivând": "reactiva",
    "nemaireactivându": "reactiva",
    "nereactivând": "reactiva",
    "nereactivându": "reactiva",
    "reactivă": "reactiva",
    "reactivai": "reactiva",
    "reactivam": "reactiva",
    "reactivăm": "reactiva",
    "reactivând": "reactiva",
    "reactivându": "reactiva",
    "reactivară": "reactiva",
    "reactivarăm": "reactiva",
    "reactivarăți": "reactiva",
    "reactivase": "reactiva",
    "reactivasem": "reactiva",
    "reactivaseră": "reactiva",
    "reactivaserăm": "reactiva",
    "reactivaserăți": "reactiva",
    "reactivaseși": "reactiva",
    "reactivași": "reactiva",
    "reactivat": "reactiva",
    "reactivați": "reactiva",
    "reactivau": "reactiva",
    "reactivează": "reactiva",
    "reactivez": "reactiva",
    "reactiveze": "reactiva",
    "reactivezi": "reactiva",
    "reactivarea": "reactivare",
    "reactivareo": "reactivare",
    "reactivări": "reactivare",
    "reactivării": "reactivare",
    "reactivările": "reactivare",
    "reactivărilor": "reactivare",
    "reactivată": "reactivat",
    "reactivate": "reactivat",
    "reactivați": "reactivat",
    "reactivitatea": "reactivitate",
    "reactivități": "reactivitate",
    "reactivității": "reactivitate",
    "reactivitățile": "reactivitate",
    "reactivităților": "reactivitate",
    "reactoare": "reactor",
    "reactoarele": "reactor",
    "reactoarelor": "reactor",
    "reactorul": "reactor",
    "reactorului": "reactor",
    "nemaireactualizând": "reactualiza",
    "nemaireactualizându": "reactualiza",
    "nereactualizând": "reactualiza",
    "nereactualizându": "reactualiza",
    "reactualiză": "reactualiza",
    "reactualizai": "reactualiza",
    "reactualizam": "reactualiza",
    "reactualizăm": "reactualiza",
    "reactualizând": "reactualiza",
    "reactualizându": "reactualiza",
    "reactualizară": "reactualiza",
    "reactualizarăm": "reactualiza",
    "reactualizarăți": "reactualiza",
    "reactualizase": "reactualiza",
    "reactualizasem": "reactualiza",
    "reactualizaseră": "reactualiza",
    "reactualizaserăm": "reactualiza",
    "reactualizaserăți": "reactualiza",
    "reactualizaseși": "reactualiza",
    "reactualizași": "reactualiza",
    "reactualizat": "reactualiza",
    "reactualizați": "reactualiza",
    "reactualizau": "reactualiza",
    "reactualizează": "reactualiza",
    "reactualizez": "reactualiza",
    "reactualizeze": "reactualiza",
    "reactualizezi": "reactualiza",
    "reactualizarea": "reactualizare",
    "reactualizareo": "reactualizare",
    "reactualizări": "reactualizare",
    "reactualizării": "reactualizare",
    "reactualizările": "reactualizare",
    "reactualizărilor": "reactualizare",
    "reactualizată": "reactualizat",
    "reactualizate": "reactualizat",
    "reactualizați": "reactualizat",
    "nemaireaducând": "readuce",
    "nemaireaducându": "readuce",
    "nereaducând": "readuce",
    "nereaducându": "readuce",
    "readu": "readuce",
    "readuc": "readuce",
    "readucă": "readuce",
    "readucând": "readuce",
    "readucându": "readuce",
    "readucea": "readuce",
    "readuceai": "readuce",
    "readuceam": "readuce",
    "readuceați": "readuce",
    "readuceau": "readuce",
    "readucem": "readuce",
    "readuceți": "readuce",
    "readuci": "readuce",
    "readus": "readuce",
    "readuse": "readuce",
    "readusei": "readuce",
    "readuseră": "readuce",
    "readuserăm": "readuce",
    "readuserăți": "readuce",
    "readusese": "readuce",
    "readusesem": "readuce",
    "readuseseră": "readuce",
    "readuseserăm": "readuce",
    "readuseserăți": "readuce",
    "readuseseși": "readuce",
    "readuseși": "readuce",
    "readucerea": "readucere",
    "readucereo": "readucere",
    "readuceri": "readucere",
    "readucerii": "readucere",
    "readucerile": "readucere",
    "readucerilor": "readucere",
    "readusă": "readus",
    "readuse": "readus",
    "readuși": "readus",
    "nemaireafirmând": "reafirma",
    "nemaireafirmându": "reafirma",
    "nereafirmând": "reafirma",
    "nereafirmându": "reafirma",
    "reafirm": "reafirma",
    "reafirmă": "reafirma",
    "reafirmai": "reafirma",
    "reafirmam": "reafirma",
    "reafirmăm": "reafirma",
    "reafirmând": "reafirma",
    "reafirmându": "reafirma",
    "reafirmară": "reafirma",
    "reafirmarăm": "reafirma",
    "reafirmarăți": "reafirma",
    "reafirmase": "reafirma",
    "reafirmasem": "reafirma",
    "reafirmaseră": "reafirma",
    "reafirmaserăm": "reafirma",
    "reafirmaserăți": "reafirma",
    "reafirmaseși": "reafirma",
    "reafirmași": "reafirma",
    "reafirmat": "reafirma",
    "reafirmați": "reafirma",
    "reafirmau": "reafirma",
    "reafirme": "reafirma",
    "reafirmi": "reafirma",
    "reafirmarea": "reafirmare",
    "reafirmareo": "reafirmare",
    "reafirmări": "reafirmare",
    "reafirmării": "reafirmare",
    "reafirmările": "reafirmare",
    "reafirmărilor": "reafirmare",
    "reafirmată": "reafirmat",
    "reafirmate": "reafirmat",
    "reafirmați": "reafirmat",
    "reajustarea": "reajustare",
    "reajustări": "reajustare",
    "reajustării": "reajustare",
    "reajustările": "reajustare",
    "reajustărilor": "reajustare",
    "reala": "real",
    "reală": "real",
    "reale": "real",
    "realei": "real",
    "realele": "real",
    "realelor": "real",
    "reali": "real",
    "realii": "real",
    "realilor": "real",
    "realul": "real",
    "realului": "real",
    "nemairealegând": "realege",
    "nemairealegându": "realege",
    "nerealegând": "realege",
    "nerealegându": "realege",
    "realeagă": "realege",
    "realeg": "realege",
    "realegând": "realege",
    "realegându": "realege",
    "realegea": "realege",
    "realegeai": "realege",
    "realegeam": "realege",
    "realegeați": "realege",
    "realegeau": "realege",
    "realegem": "realege",
    "realegeți": "realege",
    "realegi": "realege",
    "realese": "realege",
    "realesei": "realege",
    "realeseră": "realege",
    "realeserăm": "realege",
    "realeserăți": "realege",
    "realesese": "realege",
    "realesesem": "realege",
    "realeseseră": "realege",
    "realeseserăm": "realege",
    "realeseserăți": "realege",
    "realeseseși": "realege",
    "realeseși": "realege",
    "nemairealiniând": "realinia",
    "nemairealiniându": "realinia",
    "nerealiniând": "realinia",
    "nerealiniându": "realinia",
    "realiniai": "realinia",
    "realiniam": "realinia",
    "realiniară": "realinia",
    "realiniarăm": "realinia",
    "realiniarăți": "realinia",
    "realiniase": "realinia",
    "realiniasem": "realinia",
    "realiniaseră": "realinia",
    "realiniaserăm": "realinia",
    "realiniaserăți": "realinia",
    "realiniaseși": "realinia",
    "realiniași": "realinia",
    "realiniat": "realinia",
    "realiniați": "realinia",
    "realiniau": "realinia",
    "realiniază": "realinia",
    "realinie": "realinia",
    "realiniem": "realinia",
    "realiniez": "realinia",
    "realinieze": "realinia",
    "realiniezi": "realinia",
    "realiniind": "realinia",
    "realiniindu": "realinia",
    "realiniată": "realiniat",
    "realiniate": "realiniat",
    "realiniați": "realiniat",
    "realinierea": "realiniere",
    "realiniereo": "realiniere",
    "realinieri": "realiniere",
    "realinierii": "realiniere",
    "realinierile": "realiniere",
    "realinierilor": "realiniere",
    "nemairealipind": "realipi",
    "nemairealipindu": "realipi",
    "nerealipind": "realipi",
    "nerealipindu": "realipi",
    "realipea": "realipi",
    "realipeai": "realipi",
    "realipeam": "realipi",
    "realipească": "realipi",
    "realipeați": "realipi",
    "realipeau": "realipi",
    "realipesc": "realipi",
    "realipește": "realipi",
    "realipești": "realipi",
    "realipii": "realipi",
    "realipim": "realipi",
    "realipind": "realipi",
    "realipindu": "realipi",
    "realipiră": "realipi",
    "realipirăm": "realipi",
    "realipirăți": "realipi",
    "realipise": "realipi",
    "realipisem": "realipi",
    "realipiseră": "realipi",
    "realipiserăm": "realipi",
    "realipiserăți": "realipi",
    "realipiseși": "realipi",
    "realipiși": "realipi",
    "realipit": "realipi",
    "realipiți": "realipi",
    "realipirea": "realipire",
    "realipireo": "realipire",
    "realipiri": "realipire",
    "realipirii": "realipire",
    "realipirile": "realipire",
    "realipirilor": "realipire",
    "realipită": "realipit",
    "realipite": "realipit",
    "realipiți": "realipit",
    "realismul": "realism",
    "realismului": "realism",
    "realista": "realist",
    "realistă": "realist",
    "realiste": "realist",
    "realistei": "realist",
    "realistele": "realist",
    "realistelor": "realist",
    "realiști": "realist",
    "realiștii": "realist",
    "realiștilor": "realist",
    "realistul": "realist",
    "realistului": "realist",
    "realista": "realistă",
    "realiste": "realistă",
    "realistei": "realistă",
    "realistele": "realistă",
    "realistelor": "realistă",
    "realist-pragmatică": "realist-pragmatic",
    "realitatea": "realitate",
    "realități": "realitate",
    "realității": "realitate",
    "realitățile": "realitate",
    "realităților": "realitate",
    "nemairealizând": "realiza",
    "nemairealizându": "realiza",
    "nerealizând": "realiza",
    "nerealizându": "realiza",
    "realiză": "realiza",
    "realizai": "realiza",
    "realizam": "realiza",
    "realizăm": "realiza",
    "realizând": "realiza",
    "realizându": "realiza",
    "realizară": "realiza",
    "realizarăm": "realiza",
    "realizarăți": "realiza",
    "realizase": "realiza",
    "realizasem": "realiza",
    "realizaseră": "realiza",
    "realizaserăm": "realiza",
    "realizaserăți": "realiza",
    "realizaseși": "realiza",
    "realizași": "realiza",
    "realizat": "realiza",
    "realizați": "realiza",
    "realizau": "realiza",
    "realizează": "realiza",
    "realizez": "realiza",
    "realizeze": "realiza",
    "realizezi": "realiza",
    "realizabila": "realizabil",
    "realizabilă": "realizabil",
    "realizabile": "realizabil",
    "realizabilei": "realizabil",
    "realizabilele": "realizabil",
    "realizabilelor": "realizabil",
    "realizabili": "realizabil",
    "realizabilii": "realizabil",
    "realizabililor": "realizabil",
    "realizabilo": "realizabil",
    "realizabilul": "realizabil",
    "realizabilule": "realizabil",
    "realizabilului": "realizabil",
    "realizarea": "realizare",
    "realizareo": "realizare",
    "realizări": "realizare",
    "realizării": "realizare",
    "realizările": "realizare",
    "realizărilor": "realizare",
    "realizata": "realizat",
    "realizată": "realizat",
    "realizate": "realizat",
    "realizatei": "realizat",
    "realizați": "realizat",
    "realizatoarea": "realizatoare",
    "realizatoarei": "realizatoare",
    "realizatoarele": "realizatoare",
    "realizatoarelor": "realizatoare",
    "realizatoareo": "realizatoare",
    "realizatoare": "realizator",
    "realizatoarea": "realizator",
    "realizatoarei": "realizator",
    "realizatoarele": "realizator",
    "realizatoarelor": "realizator",
    "realizatori": "realizator",
    "realizatorii": "realizator",
    "realizatorilor": "realizator",
    "realizatorul": "realizator",
    "realizatorule": "realizator",
    "realizatorului": "realizator",
    "realocată": "realocat",
    "realocate": "realocat",
    "realocați": "realocat",
    "reamenajă": "reamenaja",
    "reamenajai": "reamenaja",
    "reamenajam": "reamenaja",
    "reamenajăm": "reamenaja",
    "reamenajând": "reamenaja",
    "reamenajându": "reamenaja",
    "reamenajară": "reamenaja",
    "reamenajarăm": "reamenaja",
    "reamenajarăți": "reamenaja",
    "reamenajase": "reamenaja",
    "reamenajasem": "reamenaja",
    "reamenajaseră": "reamenaja",
    "reamenajaserăm": "reamenaja",
    "reamenajaserăți": "reamenaja",
    "reamenajaseși": "reamenaja",
    "reamenajași": "reamenaja",
    "reamenajat": "reamenaja",
    "reamenajați": "reamenaja",
    "reamenajatu": "reamenaja",
    "reamenajau": "reamenaja",
    "reamenajează": "reamenaja",
    "reamenajez": "reamenaja",
    "reamenajeze": "reamenaja",
    "reamenajezi": "reamenaja",
    "reamenajarea": "reamenajare",
    "reamenajări": "reamenajare",
    "reamenajării": "reamenajare",
    "reamenajările": "reamenajare",
    "reamenajată": "reamenajat",
    "reamenajate": "reamenajat",
    "reamenajați": "reamenajat",
    "nemaireamintind": "reaminti",
    "nemaireamintindu": "reaminti",
    "nereamintind": "reaminti",
    "nereamintindu": "reaminti",
    "reamintea": "reaminti",
    "reaminteai": "reaminti",
    "reaminteam": "reaminti",
    "reamintească": "reaminti",
    "reaminteați": "reaminti",
    "reaminteau": "reaminti",
    "reamintesc": "reaminti",
    "reamintește": "reaminti",
    "reamintești": "reaminti",
    "reamintii": "reaminti",
    "reamintim": "reaminti",
    "reamintind": "reaminti",
    "reamintindu": "reaminti",
    "reamintiră": "reaminti",
    "reamintirăm": "reaminti",
    "reamintirăți": "reaminti",
    "reamintise": "reaminti",
    "reamintisem": "reaminti",
    "reamintiseră": "reaminti",
    "reamintiserăm": "reaminti",
    "reamintiserăți": "reaminti",
    "reamintiseși": "reaminti",
    "reamintiși": "reaminti",
    "reamintit": "reaminti",
    "reamintiți": "reaminti",
    "reamintită": "reamintit",
    "reamintite": "reamintit",
    "reamintiți": "reamintit",
    "reanaliză": "reanaliza",
    "reanalizai": "reanaliza",
    "reanalizam": "reanaliza",
    "reanalizăm": "reanaliza",
    "reanalizând": "reanaliza",
    "reanalizându": "reanaliza",
    "reanalizară": "reanaliza",
    "reanalizarăm": "reanaliza",
    "reanalizarăți": "reanaliza",
    "reanalizase": "reanaliza",
    "reanalizasem": "reanaliza",
    "reanalizaseră": "reanaliza",
    "reanalizaserăm": "reanaliza",
    "reanalizaserăți": "reanaliza",
    "reanalizaseși": "reanaliza",
    "reanalizași": "reanaliza",
    "reanalizat": "reanaliza",
    "reanalizați": "reanaliza",
    "reanalizatu": "reanaliza",
    "reanalizau": "reanaliza",
    "reanalizează": "reanaliza",
    "reanalizez": "reanaliza",
    "reanalizeze": "reanaliza",
    "reanalizezi": "reanaliza",
    "reanalizarea": "reanalizare",
    "reanalizări": "reanalizare",
    "reanalizării": "reanalizare",
    "reanalizările": "reanalizare",
    "reanalizată": "reanalizat",
    "reanalizate": "reanalizat",
    "reanalizați": "reanalizat",
    "nemaireangajând": "reangaja",
    "nemaireangajându": "reangaja",
    "nereangajând": "reangaja",
    "nereangajându": "reangaja",
    "reangajă": "reangaja",
    "reangajai": "reangaja",
    "reangajam": "reangaja",
    "reangajăm": "reangaja",
    "reangajând": "reangaja",
    "reangajându": "reangaja",
    "reangajară": "reangaja",
    "reangajarăm": "reangaja",
    "reangajarăți": "reangaja",
    "reangajase": "reangaja",
    "reangajasem": "reangaja",
    "reangajaseră": "reangaja",
    "reangajaserăm": "reangaja",
    "reangajaserăți": "reangaja",
    "reangajaseși": "reangaja",
    "reangajași": "reangaja",
    "reangajat": "reangaja",
    "reangajați": "reangaja",
    "reangajau": "reangaja",
    "reangajează": "reangaja",
    "reangajez": "reangaja",
    "reangajeze": "reangaja",
    "reangajezi": "reangaja",
    "reangajarea": "reangajare",
    "reangajareo": "reangajare",
    "reangajări": "reangajare",
    "reangajării": "reangajare",
    "reangajările": "reangajare",
    "reangajărilor": "reangajare",
    "reangajată": "reangajat",
    "reangajate": "reangajat",
    "reangajați": "reangajat",
    "nemaireanimând": "reanima",
    "nemaireanimându": "reanima",
    "nereanimând": "reanima",
    "nereanimându": "reanima",
    "reanim": "reanima",
    "reanimă": "reanima",
    "reanimai": "reanima",
    "reanimam": "reanima",
    "reanimăm": "reanima",
    "reanimând": "reanima",
    "reanimându": "reanima",
    "reanimară": "reanima",
    "reanimarăm": "reanima",
    "reanimarăți": "reanima",
    "reanimase": "reanima",
    "reanimasem": "reanima",
    "reanimaseră": "reanima",
    "reanimaserăm": "reanima",
    "reanimaserăți": "reanima",
    "reanimaseși": "reanima",
    "reanimași": "reanima",
    "reanimat": "reanima",
    "reanimați": "reanima",
    "reanimau": "reanima",
    "reanime": "reanima",
    "reanimi": "reanima",
    "reanimarea": "reanimare",
    "reanimareo": "reanimare",
    "reanimări": "reanimare",
    "reanimării": "reanimare",
    "reanimările": "reanimare",
    "reanimărilor": "reanimare",
    "reanimată": "reanimat",
    "reanimate": "reanimat",
    "reanimați": "reanimat",
    "nemaireapărând": "reapărea",
    "nemaireapărându": "reapărea",
    "nereapărând": "reapărea",
    "nereapărându": "reapărea",
    "reapar": "reapărea",
    "reapară": "reapărea",
    "reapărând": "reapărea",
    "reapărându": "reapărea",
    "reapare": "reapărea",
    "reapăreai": "reapărea",
    "reapăream": "reapărea",
    "reapăreați": "reapărea",
    "reapăreau": "reapărea",
    "reapărem": "reapărea",
    "reapăreți": "reapărea",
    "reapari": "reapărea",
    "reapăru": "reapărea",
    "reapărui": "reapărea",
    "reapărură": "reapărea",
    "reapărurăm": "reapărea",
    "reapărurăți": "reapărea",
    "reapăruse": "reapărea",
    "reapărusem": "reapărea",
    "reapăruseră": "reapărea",
    "reapăruserăm": "reapărea",
    "reapăruserăți": "reapărea",
    "reapăruseși": "reapărea",
    "reapăruși": "reapărea",
    "reapărut": "reapărea",
    "reapărută": "reapărut",
    "reapărute": "reapărut",
    "reapăruți": "reapărut",
    "reaprind": "reaprinde",
    "reaprindă": "reaprinde",
    "reaprindea": "reaprinde",
    "reaprindeai": "reaprinde",
    "reaprindeam": "reaprinde",
    "reaprindeați": "reaprinde",
    "reaprindeau": "reaprinde",
    "reaprindem": "reaprinde",
    "reaprindeți": "reaprinde",
    "reaprins": "reaprinde",
    "reaprinse": "reaprinde",
    "reaprinsei": "reaprinde",
    "reaprinseră": "reaprinde",
    "reaprinserăm": "reaprinde",
    "reaprinserăți": "reaprinde",
    "reaprinsese": "reaprinde",
    "reaprinsesem": "reaprinde",
    "reaprinseseră": "reaprinde",
    "reaprinseserăm": "reaprinde",
    "reaprinseserăți": "reaprinde",
    "reaprinseseși": "reaprinde",
    "reaprinseși": "reaprinde",
    "reaprinsu": "reaprinde",
    "reaprinderea": "reaprindere",
    "reaprinderi": "reaprindere",
    "reaprinderii": "reaprindere",
    "reaprinderile": "reaprindere",
    "reaprinsa": "reaprins",
    "reaprinsă": "reaprins",
    "reaprinse": "reaprins",
    "reaprinsei": "reaprins",
    "reaprinsele": "reaprins",
    "reaprinselor": "reaprins",
    "reaprinși": "reaprins",
    "reaprinșii": "reaprins",
    "reaprinșilor": "reaprins",
    "reaprinsul": "reaprins",
    "reaprinsului": "reaprins",
    "reapropierea": "reapropiere",
    "reapropieri": "reapropiere",
    "reapropierii": "reapropiere",
    "reapropierile": "reapropiere",
    "reapropierilor": "reapropiere",
    "rearanjă": "rearanja",
    "rearanjai": "rearanja",
    "rearanjam": "rearanja",
    "rearanjăm": "rearanja",
    "rearanjând": "rearanja",
    "rearanjându": "rearanja",
    "rearanjară": "rearanja",
    "rearanjarăm": "rearanja",
    "rearanjarăți": "rearanja",
    "rearanjase": "rearanja",
    "rearanjasem": "rearanja",
    "rearanjaseră": "rearanja",
    "rearanjaserăm": "rearanja",
    "rearanjaserăți": "rearanja",
    "rearanjaseși": "rearanja",
    "rearanjași": "rearanja",
    "rearanjat": "rearanja",
    "rearanjați": "rearanja",
    "rearanjatu": "rearanja",
    "rearanjau": "rearanja",
    "rearanjează": "rearanja",
    "rearanjez": "rearanja",
    "rearanjeze": "rearanja",
    "rearanjezi": "rearanja",
    "rearanjată": "rearanjat",
    "rearanjate": "rearanjat",
    "rearanjați": "rearanjat",
    "nemaireașezaând": "reașeza",
    "nemaireașezaându": "reașeza",
    "nereașezaând": "reașeza",
    "nereașezaându": "reașeza",
    "reașeză": "reașeza",
    "reașezai": "reașeza",
    "reașezam": "reașeza",
    "reașezăm": "reașeza",
    "reașezând": "reașeza",
    "reașezându": "reașeza",
    "reașezară": "reașeza",
    "reașezarăm": "reașeza",
    "reașezarăți": "reașeza",
    "reașezase": "reașeza",
    "reașezasem": "reașeza",
    "reașezaseră": "reașeza",
    "reașezaserăm": "reașeza",
    "reașezaserăți": "reașeza",
    "reașezaseși": "reașeza",
    "reașezași": "reașeza",
    "reașezat": "reașeza",
    "reașezați": "reașeza",
    "reașezau": "reașeza",
    "reașeze": "reașeza",
    "reașezarea": "reașezare",
    "reașezări": "reașezare",
    "reașezării": "reașezare",
    "reașezările": "reașezare",
    "reașezărilor": "reașezare",
    "reașezată": "reașezat",
    "reașezate": "reașezat",
    "reașezați": "reașezat",
    "reasfaltă": "reasfalta",
    "reasfaltai": "reasfalta",
    "reasfaltam": "reasfalta",
    "reasfaltăm": "reasfalta",
    "reasfaltând": "reasfalta",
    "reasfaltându": "reasfalta",
    "reasfaltară": "reasfalta",
    "reasfaltarăm": "reasfalta",
    "reasfaltarăți": "reasfalta",
    "reasfaltase": "reasfalta",
    "reasfaltasem": "reasfalta",
    "reasfaltaseră": "reasfalta",
    "reasfaltaserăm": "reasfalta",
    "reasfaltaserăți": "reasfalta",
    "reasfaltaseși": "reasfalta",
    "reasfaltași": "reasfalta",
    "reasfaltat": "reasfalta",
    "reasfaltați": "reasfalta",
    "reasfaltau": "reasfalta",
    "reasfaltează": "reasfalta",
    "reasfaltez": "reasfalta",
    "reasfalteze": "reasfalta",
    "reasfaltezi": "reasfalta",
    "reasfaltarea": "reasfaltare",
    "reasfaltări": "reasfaltare",
    "reasfaltării": "reasfaltare",
    "reasfaltările": "reasfaltare",
    "reasfaltărilor": "reasfaltare",
    "reasfaltata": "reasfaltat",
    "reasfaltată": "reasfaltat",
    "reasfaltate": "reasfaltat",
    "reasfaltatei": "reasfaltat",
    "reasfaltatele": "reasfaltat",
    "reasfaltatelor": "reasfaltat",
    "reasfaltați": "reasfaltat",
    "reasfaltații": "reasfaltat",
    "reasfaltaților": "reasfaltat",
    "reasfaltato": "reasfaltat",
    "reasfaltatul": "reasfaltat",
    "reasfaltatule": "reasfaltat",
    "reasfaltatului": "reasfaltat",
    "reavăna": "reavăn",
    "reavănă": "reavăn",
    "reavănul": "reavăn",
    "reavănului": "reavăn",
    "revene": "reavăn",
    "revenei": "reavăn",
    "revenele": "reavăn",
    "revenelor": "reavăn",
    "reveni": "reavăn",
    "revenii": "reavăn",
    "revenilor": "reavăn",
    "reazeme": "reazem",
    "reazemele": "reazem",
    "reazemelor": "reazem",
    "reazemul": "reazem",
    "reazemului": "reazem",
    "rebarbativa": "rebarbativ",
    "rebarbativă": "rebarbativ",
    "rebarbative": "rebarbativ",
    "rebarbativei": "rebarbativ",
    "rebarbativele": "rebarbativ",
    "rebarbativelor": "rebarbativ",
    "rebarbativi": "rebarbativ",
    "rebarbativii": "rebarbativ",
    "rebarbativilor": "rebarbativ",
    "rebarbativul": "rebarbativ",
    "rebarbativului": "rebarbativ",
    "rebegeala": "rebegeală",
    "rebegealo": "rebegeală",
    "rebegeli": "rebegeală",
    "rebegelii": "rebegeală",
    "rebegelile": "rebegeală",
    "rebegelilor": "rebegeală",
    "nemairebegind": "rebegi",
    "nemairebegindu": "rebegi",
    "nerebegind": "rebegi",
    "nerebegindu": "rebegi",
    "rebegea": "rebegi",
    "rebegeai": "rebegi",
    "rebegeam": "rebegi",
    "rebegească": "rebegi",
    "rebegeați": "rebegi",
    "rebegeau": "rebegi",
    "rebegesc": "rebegi",
    "rebegește": "rebegi",
    "rebegești": "rebegi",
    "rebegii": "rebegi",
    "rebegim": "rebegi",
    "rebegind": "rebegi",
    "rebegindu": "rebegi",
    "rebegiră": "rebegi",
    "rebegirăm": "rebegi",
    "rebegirăți": "rebegi",
    "rebegise": "rebegi",
    "rebegisem": "rebegi",
    "rebegiseră": "rebegi",
    "rebegiserăm": "rebegi",
    "rebegiserăți": "rebegi",
    "rebegiseși": "rebegi",
    "rebegiși": "rebegi",
    "rebegit": "rebegi",
    "rebegiți": "rebegi",
    "rebegită": "rebegit",
    "rebegite": "rebegit",
    "rebegiți": "rebegit",
    "rebela": "rebel",
    "rebelă": "rebel",
    "rebele": "rebel",
    "rebelei": "rebel",
    "rebelele": "rebel",
    "rebelelor": "rebel",
    "rebeli": "rebel",
    "rebelii": "rebel",
    "rebelilor": "rebel",
    "rebelul": "rebel",
    "rebelului": "rebel",
    "rebeliunea": "rebeliune",
    "rebeliuni": "rebeliune",
    "rebeliunii": "rebeliune",
    "rebeliunile": "rebeliune",
    "rebeliunilor": "rebeliune",
    "rebotezarea": "rebotezare",
    "rebotezări": "rebotezare",
    "rebotezării": "rebotezare",
    "rebotezările": "rebotezare",
    "rebrevetarea": "rebrevetare",
    "rebrevetări": "rebrevetare",
    "rebrevetării": "rebrevetare",
    "rebrevetările": "rebrevetare",
    "rebrevetărilor": "rebrevetare",
    "rebusul": "rebus",
    "rebusului": "rebus",
    "rebusuri": "rebus",
    "rebusurile": "rebus",
    "rebusurilor": "rebus",
    "rebutul": "rebut",
    "rebutului": "rebut",
    "rebuturi": "rebut",
    "rebuturile": "rebut",
    "rebuturilor": "rebut",
    "nemairebutând": "rebuta",
    "nemairebutându": "rebuta",
    "nerebutând": "rebuta",
    "nerebutându": "rebuta",
    "rebută": "rebuta",
    "rebutai": "rebuta",
    "rebutam": "rebuta",
    "rebutăm": "rebuta",
    "rebutând": "rebuta",
    "rebutându": "rebuta",
    "rebutară": "rebuta",
    "rebutarăm": "rebuta",
    "rebutarăți": "rebuta",
    "rebutase": "rebuta",
    "rebutasem": "rebuta",
    "rebutaseră": "rebuta",
    "rebutaserăm": "rebuta",
    "rebutaserăți": "rebuta",
    "rebutaseși": "rebuta",
    "rebutași": "rebuta",
    "rebutat": "rebuta",
    "rebutați": "rebuta",
    "rebutau": "rebuta",
    "rebutează": "rebuta",
    "rebutez": "rebuta",
    "rebuteze": "rebuta",
    "rebutezi": "rebuta",
    "rebutarea": "rebutare",
    "rebutareo": "rebutare",
    "rebutări": "rebutare",
    "rebutării": "rebutare",
    "rebutările": "rebutare",
    "rebutărilor": "rebutare",
    "rebutata": "rebutat",
    "rebutată": "rebutat",
    "rebutate": "rebutat",
    "rebutatei": "rebutat",
    "rebutatele": "rebutat",
    "rebutatelor": "rebutat",
    "rebutați": "rebutat",
    "rebutații": "rebutat",
    "rebutaților": "rebutat",
    "rebutato": "rebutat",
    "rebutatul": "rebutat",
    "rebutatule": "rebutat",
    "rebutatului": "rebutat",
    "recalcitranta": "recalcitrant",
    "recalcitrantă": "recalcitrant",
    "recalcitrante": "recalcitrant",
    "recalcitrantei": "recalcitrant",
    "recalcitrantele": "recalcitrant",
    "recalcitrantelor": "recalcitrant",
    "recalcitranți": "recalcitrant",
    "recalcitranții": "recalcitrant",
    "recalcitranților": "recalcitrant",
    "recalcitrantul": "recalcitrant",
    "recalcitrantului": "recalcitrant",
    "recalcitranța": "recalcitranță",
    "recalcitranțe": "recalcitranță",
    "recalcitranței": "recalcitranță",
    "recalcitranțele": "recalcitranță",
    "recalcitranțelor": "recalcitranță",
    "nemairecalculând": "recalcula",
    "nemairecalculându": "recalcula",
    "nerecalculând": "recalcula",
    "nerecalculându": "recalcula",
    "recalculă": "recalcula",
    "recalculai": "recalcula",
    "recalculam": "recalcula",
    "recalculăm": "recalcula",
    "recalculând": "recalcula",
    "recalculându": "recalcula",
    "recalculară": "recalcula",
    "recalcularăm": "recalcula",
    "recalcularăți": "recalcula",
    "recalculase": "recalcula",
    "recalculasem": "recalcula",
    "recalculaseră": "recalcula",
    "recalculaserăm": "recalcula",
    "recalculaserăți": "recalcula",
    "recalculaseși": "recalcula",
    "recalculași": "recalcula",
    "recalculat": "recalcula",
    "recalculați": "recalcula",
    "recalculau": "recalcula",
    "recalculează": "recalcula",
    "recalculez": "recalcula",
    "recalculeze": "recalcula",
    "recalculezi": "recalcula",
    "recalcularea": "recalculare",
    "recalculareo": "recalculare",
    "recalculări": "recalculare",
    "recalculării": "recalculare",
    "recalculările": "recalculare",
    "recalculărilor": "recalculare",
    "recalculată": "recalculat",
    "recalculate": "recalculat",
    "recalculați": "recalculat",
    "nemairecalificând": "recalifica",
    "nemairecalificându": "recalifica",
    "nerecalificând": "recalifica",
    "nerecalificându": "recalifica",
    "recalific": "recalifica",
    "recalifică": "recalifica",
    "recalificai": "recalifica",
    "recalificam": "recalifica",
    "recalificăm": "recalifica",
    "recalificând": "recalifica",
    "recalificându": "recalifica",
    "recalificară": "recalifica",
    "recalificarăm": "recalifica",
    "recalificarăți": "recalifica",
    "recalificase": "recalifica",
    "recalificasem": "recalifica",
    "recalificaseră": "recalifica",
    "recalificaserăm": "recalifica",
    "recalificaserăți": "recalifica",
    "recalificaseși": "recalifica",
    "recalificași": "recalifica",
    "recalificat": "recalifica",
    "recalificați": "recalifica",
    "recalificau": "recalifica",
    "recalifice": "recalifica",
    "recalifici": "recalifica",
    "recalificarea": "recalificare",
    "recalificareo": "recalificare",
    "recalificări": "recalificare",
    "recalificării": "recalificare",
    "recalificările": "recalificare",
    "recalificărilor": "recalificare",
    "recalificată": "recalificat",
    "recalificate": "recalificat",
    "recalificați": "recalificat",
    "nemairecăpătând": "recăpăta",
    "nemairecăpătându": "recăpăta",
    "nerecăpătând": "recăpăta",
    "nerecăpătându": "recăpăta",
    "recapăt": "recăpăta",
    "recapătă": "recăpăta",
    "recăpătă": "recăpăta",
    "recăpătai": "recăpăta",
    "recăpătam": "recăpăta",
    "recăpătăm": "recăpăta",
    "recăpătând": "recăpăta",
    "recăpătându": "recăpăta",
    "recăpătară": "recăpăta",
    "recăpătarăm": "recăpăta",
    "recăpătarăți": "recăpăta",
    "recăpătase": "recăpăta",
    "recăpătasem": "recăpăta",
    "recăpătaseră": "recăpăta",
    "recăpătaserăm": "recăpăta",
    "recăpătaserăți": "recăpăta",
    "recăpătaseși": "recăpăta",
    "recăpătași": "recăpăta",
    "recăpătat": "recăpăta",
    "recăpătați": "recăpăta",
    "recăpătau": "recăpăta",
    "recapete": "recăpăta",
    "recapeți": "recăpăta",
    "recăpătarea": "recăpătare",
    "recăpătareo": "recăpătare",
    "recăpătări": "recăpătare",
    "recăpătării": "recăpătare",
    "recăpătările": "recăpătare",
    "recăpătărilor": "recăpătare",
    "recăpătată": "recăpătat",
    "recăpătate": "recăpătat",
    "recăpătați": "recăpătat",
    "nemairecapitulând": "recapitula",
    "nemairecapitulându": "recapitula",
    "nerecapitulând": "recapitula",
    "nerecapitulându": "recapitula",
    "recapitulă": "recapitula",
    "recapitulai": "recapitula",
    "recapitulam": "recapitula",
    "recapitulăm": "recapitula",
    "recapitulând": "recapitula",
    "recapitulându": "recapitula",
    "recapitulară": "recapitula",
    "recapitularăm": "recapitula",
    "recapitularăți": "recapitula",
    "recapitulase": "recapitula",
    "recapitulasem": "recapitula",
    "recapitulaseră": "recapitula",
    "recapitulaserăm": "recapitula",
    "recapitulaserăți": "recapitula",
    "recapitulaseși": "recapitula",
    "recapitulași": "recapitula",
    "recapitulat": "recapitula",
    "recapitulați": "recapitula",
    "recapitulau": "recapitula",
    "recapitulează": "recapitula",
    "recapitulez": "recapitula",
    "recapituleze": "recapitula",
    "recapitulezi": "recapitula",
    "recapitularea": "recapitulare",
    "recapitulareo": "recapitulare",
    "recapitulări": "recapitulare",
    "recapitulării": "recapitulare",
    "recapitulările": "recapitulare",
    "recapitulărilor": "recapitulare",
    "recapitulată": "recapitulat",
    "recapitulate": "recapitulat",
    "recapitulați": "recapitulat",
    "recapitulativa": "recapitulativ",
    "recapitulativă": "recapitulativ",
    "recapitulative": "recapitulativ",
    "recapitulativei": "recapitulativ",
    "recapitulativele": "recapitulativ",
    "recapitulativelor": "recapitulativ",
    "recapitulativi": "recapitulativ",
    "recapitulativii": "recapitulativ",
    "recapitulativilor": "recapitulativ",
    "recapitulativul": "recapitulativ",
    "recapitulativului": "recapitulativ",
    "nemairecăsătorind": "recăsători",
    "nemairecăsătorindu": "recăsători",
    "nerecăsătorind": "recăsători",
    "nerecăsătorindu": "recăsători",
    "recăsătorea": "recăsători",
    "recăsătoreai": "recăsători",
    "recăsătoream": "recăsători",
    "recăsătorească": "recăsători",
    "recăsătoreați": "recăsători",
    "recăsătoreau": "recăsători",
    "recăsătoresc": "recăsători",
    "recăsătorește": "recăsători",
    "recăsătorești": "recăsători",
    "recăsătorii": "recăsători",
    "recăsătorim": "recăsători",
    "recăsătorind": "recăsători",
    "recăsătorindu": "recăsători",
    "recăsătoriră": "recăsători",
    "recăsătorirăm": "recăsători",
    "recăsătorirăți": "recăsători",
    "recăsătorise": "recăsători",
    "recăsătorisem": "recăsători",
    "recăsătoriseră": "recăsători",
    "recăsătoriserăm": "recăsători",
    "recăsătoriserăți": "recăsători",
    "recăsătoriseși": "recăsători",
    "recăsătoriși": "recăsători",
    "recăsătorit": "recăsători",
    "recăsătoriți": "recăsători",
    "recăsătorita": "recăsătorit",
    "recăsătorită": "recăsătorit",
    "recăsătorite": "recăsătorit",
    "recăsătoritei": "recăsătorit",
    "recăsătoritele": "recăsătorit",
    "recăsătoritelor": "recăsătorit",
    "recăsătoriți": "recăsătorit",
    "recăsătoriții": "recăsătorit",
    "recăsătoriților": "recăsătorit",
    "recăsătoritul": "recăsătorit",
    "recăsătoritului": "recăsătorit",
    "nemairecâștigând": "recâștiga",
    "nemairecâștigându": "recâștiga",
    "nerecâștigând": "recâștiga",
    "nerecâștigându": "recâștiga",
    "recâștig": "recâștiga",
    "recâștigă": "recâștiga",
    "recâștigai": "recâștiga",
    "recâștigam": "recâștiga",
    "recâștigăm": "recâștiga",
    "recâștigând": "recâștiga",
    "recâștigându": "recâștiga",
    "recâștigară": "recâștiga",
    "recâștigarăm": "recâștiga",
    "recâștigarăți": "recâștiga",
    "recâștigase": "recâștiga",
    "recâștigasem": "recâștiga",
    "recâștigaseră": "recâștiga",
    "recâștigaserăm": "recâștiga",
    "recâștigaserăți": "recâștiga",
    "recâștigaseși": "recâștiga",
    "recâștigași": "recâștiga",
    "recâștigat": "recâștiga",
    "recâștigați": "recâștiga",
    "recâștigau": "recâștiga",
    "recâștige": "recâștiga",
    "recâștigi": "recâștiga",
    "recâștigată": "recâștigat",
    "recâștigate": "recâștigat",
    "recâștigați": "recâștigat",
    "recea": "rece",
    "recele": "rece",
    "recelui": "rece",
    "reci": "rece",
    "recii": "rece",
    "recile": "rece",
    "recilor": "rece",
    "recensământul": "recensământ",
    "recensământului": "recensământ",
    "recensământuri": "recensământ",
    "recensământurile": "recensământ",
    "recensământurilor": "recensământ",
    "recensăminte": "recensământ",
    "recensămintele": "recensământ",
    "recensămintelor": "recensământ",
    "recenta": "recent",
    "recentă": "recent",
    "recente": "recent",
    "recentei": "recent",
    "recentele": "recent",
    "recentelor": "recent",
    "recenți": "recent",
    "recenții": "recent",
    "recenților": "recent",
    "recentul": "recent",
    "recentului": "recent",
    "nemairecenzând": "recenza",
    "nemairecenzându": "recenza",
    "nerecenzând": "recenza",
    "nerecenzându": "recenza",
    "recenză": "recenza",
    "recenzai": "recenza",
    "recenzam": "recenza",
    "recenzăm": "recenza",
    "recenzând": "recenza",
    "recenzându": "recenza",
    "recenzară": "recenza",
    "recenzarăm": "recenza",
    "recenzarăți": "recenza",
    "recenzase": "recenza",
    "recenzasem": "recenza",
    "recenzaseră": "recenza",
    "recenzaserăm": "recenza",
    "recenzaserăți": "recenza",
    "recenzaseși": "recenza",
    "recenzași": "recenza",
    "recenzat": "recenza",
    "recenzați": "recenza",
    "recenzau": "recenza",
    "recenzează": "recenza",
    "recenzez": "recenza",
    "recenzeze": "recenza",
    "recenzezi": "recenza",
    "recenzată": "recenzat",
    "recenzate": "recenzat",
    "recenzați": "recenzat",
    "recenzia": "recenzie",
    "recenziei": "recenzie",
    "recenzii": "recenzie",
    "recenziile": "recenzie",
    "recenziilor": "recenzie",
    "nemaireceptând": "recepta",
    "nemaireceptându": "recepta",
    "nereceptând": "recepta",
    "nereceptându": "recepta",
    "receptă": "recepta",
    "receptai": "recepta",
    "receptam": "recepta",
    "receptăm": "recepta",
    "receptând": "recepta",
    "receptându": "recepta",
    "receptară": "recepta",
    "receptarăm": "recepta",
    "receptarăți": "recepta",
    "receptase": "recepta",
    "receptasem": "recepta",
    "receptaseră": "recepta",
    "receptaserăm": "recepta",
    "receptaserăți": "recepta",
    "receptaseși": "recepta",
    "receptași": "recepta",
    "receptat": "recepta",
    "receptați": "recepta",
    "receptau": "recepta",
    "receptează": "recepta",
    "receptez": "recepta",
    "recepteze": "recepta",
    "receptezi": "recepta",
    "receptacule": "receptacul",
    "receptaculele": "receptacul",
    "receptaculelor": "receptacul",
    "receptaculul": "receptacul",
    "receptaculului": "receptacul",
    "receptarea": "receptare",
    "receptată": "receptat",
    "receptate": "receptat",
    "receptați": "receptat",
    "recepția": "recepție",
    "recepției": "recepție",
    "recepții": "recepție",
    "recepțiile": "recepție",
    "recepțiilor": "recepție",
    "nemairecepționând": "recepționa",
    "nemairecepționându": "recepționa",
    "nerecepționând": "recepționa",
    "nerecepționându": "recepționa",
    "recepționă": "recepționa",
    "recepționai": "recepționa",
    "recepționam": "recepționa",
    "recepționăm": "recepționa",
    "recepționând": "recepționa",
    "recepționându": "recepționa",
    "recepționară": "recepționa",
    "recepționarăm": "recepționa",
    "recepționarăți": "recepționa",
    "recepționase": "recepționa",
    "recepționasem": "recepționa",
    "recepționaseră": "recepționa",
    "recepționaserăm": "recepționa",
    "recepționaserăți": "recepționa",
    "recepționaseși": "recepționa",
    "recepționași": "recepționa",
    "recepționat": "recepționa",
    "recepționați": "recepționa",
    "recepționau": "recepționa",
    "recepționează": "recepționa",
    "recepționez": "recepționa",
    "recepționeze": "recepționa",
    "recepționezi": "recepționa",
    "recepționarea": "recepționare",
    "recepționareo": "recepționare",
    "recepționări": "recepționare",
    "recepționării": "recepționare",
    "recepționările": "recepționare",
    "recepționărilor": "recepționare",
    "recepționată": "recepționat",
    "recepționate": "recepționat",
    "recepționați": "recepționat",
    "recepționeri": "recepționer",
    "recepționerii": "recepționer",
    "recepționerilor": "recepționer",
    "recepționerul": "recepționer",
    "recepționerului": "recepționer",
    "recepționera": "recepționeră",
    "recepționere": "recepționeră",
    "recepționerei": "recepționeră",
    "recepționerele": "recepționeră",
    "recepționerelor": "recepționeră",
    "receptiva": "receptiv",
    "receptivă": "receptiv",
    "receptive": "receptiv",
    "receptivei": "receptiv",
    "receptivele": "receptiv",
    "receptivelor": "receptiv",
    "receptivi": "receptiv",
    "receptivii": "receptiv",
    "receptivilor": "receptiv",
    "receptivul": "receptiv",
    "receptivului": "receptiv",
    "receptivitatea": "receptivitate",
    "receptivități": "receptivitate",
    "receptivității": "receptivitate",
    "receptivitățile": "receptivitate",
    "receptivităților": "receptivitate",
    "receptoare": "receptor",
    "receptoarea": "receptor",
    "receptoarei": "receptor",
    "receptoarele": "receptor",
    "receptoarelor": "receptor",
    "receptori": "receptor",
    "receptorii": "receptor",
    "receptorilor": "receptor",
    "receptorul": "receptor",
    "receptorului": "receptor",
    "recesiunea": "recesiune",
    "recesiuni": "recesiune",
    "recesiunii": "recesiune",
    "recesiunile": "recesiune",
    "recesiunilor": "recesiune",
    "nemairechemând": "rechema",
    "nemairechemându": "rechema",
    "nerechemând": "rechema",
    "nerechemându": "rechema",
    "recheamă": "rechema",
    "rechem": "rechema",
    "rechemă": "rechema",
    "rechemai": "rechema",
    "rechemam": "rechema",
    "rechemăm": "rechema",
    "rechemând": "rechema",
    "rechemându": "rechema",
    "rechemară": "rechema",
    "rechemarăm": "rechema",
    "rechemarăți": "rechema",
    "rechemase": "rechema",
    "rechemasem": "rechema",
    "rechemaseră": "rechema",
    "rechemaserăm": "rechema",
    "rechemaserăți": "rechema",
    "rechemaseși": "rechema",
    "rechemași": "rechema",
    "rechemat": "rechema",
    "rechemați": "rechema",
    "rechemau": "rechema",
    "recheme": "rechema",
    "rechemi": "rechema",
    "rechemarea": "rechemare",
    "rechemareo": "rechemare",
    "rechemări": "rechemare",
    "rechemării": "rechemare",
    "rechemările": "rechemare",
    "rechemărilor": "rechemare",
    "rechemata": "rechemat",
    "rechemată": "rechemat",
    "rechemate": "rechemat",
    "rechematei": "rechemat",
    "rechematele": "rechemat",
    "rechematelor": "rechemat",
    "rechemați": "rechemat",
    "rechemații": "rechemat",
    "rechemaților": "rechemat",
    "rechemato": "rechemat",
    "rechematul": "rechemat",
    "rechematule": "rechemat",
    "rechematului": "rechemat",
    "rechini": "rechin",
    "rechinii": "rechin",
    "rechinilor": "rechin",
    "rechinul": "rechin",
    "rechinului": "rechin",
    "rechizitele": "rechizite",
    "rechizitelor": "rechizite",
    "rechiziția": "rechiziție",
    "rechiziției": "rechiziție",
    "rechiziții": "rechiziție",
    "rechizițiile": "rechiziție",
    "rechizițiilor": "rechiziție",
    "nemairechiziționând": "rechiziționa",
    "nemairechiziționându": "rechiziționa",
    "nerechiziționând": "rechiziționa",
    "nerechiziționându": "rechiziționa",
    "rechiziționă": "rechiziționa",
    "rechiziționai": "rechiziționa",
    "rechiziționam": "rechiziționa",
    "rechiziționăm": "rechiziționa",
    "rechiziționând": "rechiziționa",
    "rechiziționându": "rechiziționa",
    "rechiziționară": "rechiziționa",
    "rechiziționarăm": "rechiziționa",
    "rechiziționarăți": "rechiziționa",
    "rechiziționase": "rechiziționa",
    "rechiziționasem": "rechiziționa",
    "rechiziționaseră": "rechiziționa",
    "rechiziționaserăm": "rechiziționa",
    "rechiziționaserăți": "rechiziționa",
    "rechiziționaseși": "rechiziționa",
    "rechiziționași": "rechiziționa",
    "rechiziționat": "rechiziționa",
    "rechiziționați": "rechiziționa",
    "rechiziționau": "rechiziționa",
    "rechiziționează": "rechiziționa",
    "rechiziționez": "rechiziționa",
    "rechiziționeze": "rechiziționa",
    "rechiziționezi": "rechiziționa",
    "rechiziționarea": "rechiziționare",
    "rechiziționareo": "rechiziționare",
    "rechiziționări": "rechiziționare",
    "rechiziționării": "rechiziționare",
    "rechiziționările": "rechiziționare",
    "rechiziționărilor": "rechiziționare",
    "rechiziționată": "rechiziționat",
    "rechiziționate": "rechiziționat",
    "rechiziționați": "rechiziționat",
    "rechizitorii": "rechizitoriu",
    "rechizitoriile": "rechizitoriu",
    "rechizitoriilor": "rechizitoriu",
    "rechizitoriul": "rechizitoriu",
    "rechizitoriului": "rechizitoriu",
    "nemaireciclând": "recicla",
    "nemaireciclându": "recicla",
    "nereciclând": "recicla",
    "nereciclându": "recicla",
    "reciclă": "recicla",
    "reciclai": "recicla",
    "reciclam": "recicla",
    "reciclăm": "recicla",
    "reciclând": "recicla",
    "reciclându": "recicla",
    "reciclară": "recicla",
    "reciclarăm": "recicla",
    "reciclarăți": "recicla",
    "reciclase": "recicla",
    "reciclasem": "recicla",
    "reciclaseră": "recicla",
    "reciclaserăm": "recicla",
    "reciclaserăți": "recicla",
    "reciclaseși": "recicla",
    "reciclași": "recicla",
    "reciclat": "recicla",
    "reciclați": "recicla",
    "reciclau": "recicla",
    "reciclează": "recicla",
    "reciclez": "recicla",
    "recicleze": "recicla",
    "reciclezi": "recicla",
    "reciclarea": "reciclare",
    "reciclări": "reciclare",
    "reciclării": "reciclare",
    "reciclările": "reciclare",
    "reciclărilor": "reciclare",
    "reciclată": "reciclat",
    "reciclate": "reciclat",
    "reciclați": "reciclat",
    "nemairecidivând": "recidiva",
    "nemairecidivându": "recidiva",
    "nerecidivând": "recidiva",
    "nerecidivându": "recidiva",
    "recidivă": "recidiva",
    "recidivai": "recidiva",
    "recidivam": "recidiva",
    "recidivăm": "recidiva",
    "recidivând": "recidiva",
    "recidivându": "recidiva",
    "recidivară": "recidiva",
    "recidivarăm": "recidiva",
    "recidivarăți": "recidiva",
    "recidivase": "recidiva",
    "recidivasem": "recidiva",
    "recidivaseră": "recidiva",
    "recidivaserăm": "recidiva",
    "recidivaserăți": "recidiva",
    "recidivaseși": "recidiva",
    "recidivași": "recidiva",
    "recidivat": "recidiva",
    "recidivați": "recidiva",
    "recidivau": "recidiva",
    "recidivează": "recidiva",
    "recidivez": "recidiva",
    "recidiveze": "recidiva",
    "recidivezi": "recidiva",
    "recidiva": "recidivă",
    "recidive": "recidivă",
    "recidivei": "recidivă",
    "recidivele": "recidivă",
    "recidivelor": "recidivă",
    "recidivată": "recidivat",
    "recidivate": "recidivat",
    "recidivați": "recidivat",
    "recidivista": "recidivist",
    "recidivistă": "recidivist",
    "recidiviste": "recidivist",
    "recidivistei": "recidivist",
    "recidivistele": "recidivist",
    "recidivistelor": "recidivist",
    "recidiviști": "recidivist",
    "recidiviștii": "recidivist",
    "recidiviștilor": "recidivist",
    "recidivistul": "recidivist",
    "recidivistule": "recidivist",
    "recidivistului": "recidivist",
    "recidivista": "recidivistă",
    "recidiviste": "recidivistă",
    "recidivistei": "recidivistă",
    "recidivistele": "recidivistă",
    "recidivistelor": "recidivistă",
    "recidivisto": "recidivistă",
    "reciful": "recif",
    "recifului": "recif",
    "recifuri": "recif",
    "recifurile": "recif",
    "recifurilor": "recif",
    "recipiente": "recipient",
    "recipientele": "recipient",
    "recipientelor": "recipient",
    "recipientul": "recipient",
    "recipientului": "recipient",
    "recipisa": "recipisă",
    "recipise": "recipisă",
    "recipisei": "recipisă",
    "recipisele": "recipisă",
    "recipiselor": "recipisă",
    "recipr.": "reciproc",
    "reciproca": "reciproc",
    "reciprocă": "reciproc",
    "reciproce": "reciproc",
    "reciprocei": "reciproc",
    "reciprocele": "reciproc",
    "reciprocelor": "reciproc",
    "reciproci": "reciproc",
    "reciprocii": "reciproc",
    "reciprocilor": "reciproc",
    "reciprocul": "reciproc",
    "reciprocului": "reciproc",
    "reciproca": "reciprocă",
    "reciproce": "reciprocă",
    "reciprocei": "reciprocă",
    "reciprocele": "reciprocă",
    "reciprocelor": "reciprocă",
    "reciprocitatea": "reciprocitate",
    "reciprocități": "reciprocitate",
    "reciprocității": "reciprocitate",
    "reciprocitățile": "reciprocitate",
    "reciprocităților": "reciprocitate",
    "recirculația": "recirculație",
    "recirculației": "recirculație",
    "recirculații": "recirculație",
    "recirculațiile": "recirculație",
    "recirculațiilor": "recirculație",
    "nemairecitând": "recita",
    "nemairecitându": "recita",
    "nerecitând": "recita",
    "nerecitându": "recita",
    "recit": "recita",
    "recită": "recita",
    "recitai": "recita",
    "recitam": "recita",
    "recităm": "recita",
    "recitând": "recita",
    "recitându": "recita",
    "recitară": "recita",
    "recitarăm": "recita",
    "recitarăți": "recita",
    "recitase": "recita",
    "recitasem": "recita",
    "recitaseră": "recita",
    "recitaserăm": "recita",
    "recitaserăți": "recita",
    "recitaseși": "recita",
    "recitași": "recita",
    "recitat": "recita",
    "recitați": "recita",
    "recitau": "recita",
    "recite": "recita",
    "reciți": "recita",
    "recitalul": "recital",
    "recitalului": "recital",
    "recitaluri": "recital",
    "recitalurile": "recital",
    "recitalurilor": "recital",
    "recitarea": "recitare",
    "recitareo": "recitare",
    "recitări": "recitare",
    "recitării": "recitare",
    "recitările": "recitare",
    "recitărilor": "recitare",
    "recitată": "recitat",
    "recitate": "recitat",
    "recitați": "recitat",
    "recitatoarea": "recitatoare",
    "recitatoarei": "recitatoare",
    "recitatoarele": "recitatoare",
    "recitatoarelor": "recitatoare",
    "recitatoareo": "recitatoare",
    "recitatori": "recitator",
    "recitatorii": "recitator",
    "recitatorilor": "recitator",
    "recitatorul": "recitator",
    "recitatorule": "recitator",
    "recitatorului": "recitator",
    "nemairecitind": "reciti",
    "nemairecitindu": "reciti",
    "nerecitind": "reciti",
    "nerecitindu": "reciti",
    "recitea": "reciti",
    "reciteai": "reciti",
    "reciteam": "reciti",
    "recitească": "reciti",
    "reciteați": "reciti",
    "reciteau": "reciti",
    "recitesc": "reciti",
    "recitește": "reciti",
    "recitești": "reciti",
    "recitii": "reciti",
    "recitim": "reciti",
    "recitind": "reciti",
    "recitindu": "reciti",
    "recitiră": "reciti",
    "recitirăm": "reciti",
    "recitirăți": "reciti",
    "recitise": "reciti",
    "recitisem": "reciti",
    "recitiseră": "reciti",
    "recitiserăm": "reciti",
    "recitiserăți": "reciti",
    "recitiseși": "reciti",
    "recitiși": "reciti",
    "recitit": "reciti",
    "recitiți": "reciti",
    "recitirea": "recitire",
    "recitireo": "recitire",
    "recitiri": "recitire",
    "recitirii": "recitire",
    "recitirile": "recitire",
    "recitirilor": "recitire",
    "recitită": "recitit",
    "recitite": "recitit",
    "recitiți": "recitit",
    "nemaireclădind": "reclădi",
    "nemaireclădindu": "reclădi",
    "nereclădind": "reclădi",
    "nereclădindu": "reclădi",
    "reclădea": "reclădi",
    "reclădeai": "reclădi",
    "reclădeam": "reclădi",
    "reclădească": "reclădi",
    "reclădeați": "reclădi",
    "reclădeau": "reclădi",
    "reclădesc": "reclădi",
    "reclădește": "reclădi",
    "reclădești": "reclădi",
    "reclădii": "reclădi",
    "reclădim": "reclădi",
    "reclădind": "reclădi",
    "reclădindu": "reclădi",
    "reclădiră": "reclădi",
    "reclădirăm": "reclădi",
    "reclădirăți": "reclădi",
    "reclădise": "reclădi",
    "reclădisem": "reclădi",
    "reclădiseră": "reclădi",
    "reclădiserăm": "reclădi",
    "reclădiserăți": "reclădi",
    "reclădiseși": "reclădi",
    "reclădiși": "reclădi",
    "reclădit": "reclădi",
    "reclădiți": "reclădi",
    "reclădirea": "reclădire",
    "reclădireo": "reclădire",
    "reclădiri": "reclădire",
    "reclădirii": "reclădire",
    "reclădirile": "reclădire",
    "reclădirilor": "reclădire",
    "reclădită": "reclădit",
    "reclădite": "reclădit",
    "reclădiți": "reclădit",
    "nemaireclamând": "reclama",
    "nemaireclamându": "reclama",
    "nereclamând": "reclama",
    "nereclamându": "reclama",
    "reclam": "reclama",
    "reclamă": "reclama",
    "reclamai": "reclama",
    "reclamam": "reclama",
    "reclamăm": "reclama",
    "reclamând": "reclama",
    "reclamându": "reclama",
    "reclamară": "reclama",
    "reclamarăm": "reclama",
    "reclamarăți": "reclama",
    "reclamase": "reclama",
    "reclamasem": "reclama",
    "reclamaseră": "reclama",
    "reclamaserăm": "reclama",
    "reclamaserăți": "reclama",
    "reclamaseși": "reclama",
    "reclamași": "reclama",
    "reclamat": "reclama",
    "reclamați": "reclama",
    "reclamau": "reclama",
    "reclame": "reclama",
    "reclami": "reclama",
    "reclama": "reclamă",
    "reclame": "reclamă",
    "reclamei": "reclamă",
    "reclamele": "reclamă",
    "reclamelor": "reclamă",
    "reclamarea": "reclamare",
    "reclamareo": "reclamare",
    "reclamări": "reclamare",
    "reclamării": "reclamare",
    "reclamările": "reclamare",
    "reclamărilor": "reclamare",
    "reclamată": "reclamat",
    "reclamate": "reclamat",
    "reclamați": "reclamat",
    "reclamația": "reclamație",
    "reclamației": "reclamație",
    "reclamații": "reclamație",
    "reclamațiile": "reclamație",
    "reclamațiilor": "reclamație",
    "reclasificarea": "reclasificare",
    "reclasificări": "reclasificare",
    "reclasificării": "reclasificare",
    "reclasificările": "reclasificare",
    "reclasificărilor": "reclasificare",
    "recluziunea": "recluziune",
    "recluziuni": "recluziune",
    "recluziunii": "recluziune",
    "recluziunile": "recluziune",
    "recluziunilor": "recluziune",
    "nemairecocând": "recoace",
    "nemairecocându": "recoace",
    "nerecocând": "recoace",
    "nerecocându": "recoace",
    "recoacă": "recoace",
    "recoacem": "recoace",
    "recoaceți": "recoace",
    "recoapse": "recoace",
    "recoapseră": "recoace",
    "recoapserăm": "recoace",
    "recoapserăți": "recoace",
    "recoc": "recoace",
    "recocând": "recoace",
    "recocându": "recoace",
    "recocea": "recoace",
    "recoceai": "recoace",
    "recoceam": "recoace",
    "recoceați": "recoace",
    "recoceau": "recoace",
    "recoci": "recoace",
    "recopsei": "recoace",
    "recopsese": "recoace",
    "recopsesem": "recoace",
    "recopseseră": "recoace",
    "recopseserăm": "recoace",
    "recopseserăți": "recoace",
    "recopseseși": "recoace",
    "recopseși": "recoace",
    "recopt": "recoace",
    "recoacerea": "recoacere",
    "recoacereo": "recoacere",
    "recoaceri": "recoacere",
    "recoacerii": "recoacere",
    "recoacerile": "recoacere",
    "recoacerilor": "recoacere",
    "nemairecoltând": "recolta",
    "nemairecoltându": "recolta",
    "nerecoltând": "recolta",
    "nerecoltându": "recolta",
    "recoltă": "recolta",
    "recoltai": "recolta",
    "recoltam": "recolta",
    "recoltăm": "recolta",
    "recoltând": "recolta",
    "recoltându": "recolta",
    "recoltară": "recolta",
    "recoltarăm": "recolta",
    "recoltarăți": "recolta",
    "recoltase": "recolta",
    "recoltasem": "recolta",
    "recoltaseră": "recolta",
    "recoltaserăm": "recolta",
    "recoltaserăți": "recolta",
    "recoltaseși": "recolta",
    "recoltași": "recolta",
    "recoltat": "recolta",
    "recoltați": "recolta",
    "recoltau": "recolta",
    "recoltează": "recolta",
    "recoltez": "recolta",
    "recolteze": "recolta",
    "recoltezi": "recolta",
    "recolta": "recoltă",
    "recolte": "recoltă",
    "recoltei": "recoltă",
    "recoltele": "recoltă",
    "recoltelor": "recoltă",
    "recoltabila": "recoltabil",
    "recoltabilă": "recoltabil",
    "recoltabile": "recoltabil",
    "recoltabilei": "recoltabil",
    "recoltabilele": "recoltabil",
    "recoltabilelor": "recoltabil",
    "recoltabili": "recoltabil",
    "recoltabilii": "recoltabil",
    "recoltabililor": "recoltabil",
    "recoltabilo": "recoltabil",
    "recoltabilul": "recoltabil",
    "recoltabilule": "recoltabil",
    "recoltabilului": "recoltabil",
    "recoltarea": "recoltare",
    "recoltareo": "recoltare",
    "recoltări": "recoltare",
    "recoltării": "recoltare",
    "recoltările": "recoltare",
    "recoltărilor": "recoltare",
    "recoltata": "recoltat",
    "recoltată": "recoltat",
    "recoltate": "recoltat",
    "recoltatei": "recoltat",
    "recoltatele": "recoltat",
    "recoltatelor": "recoltat",
    "recoltați": "recoltat",
    "recoltații": "recoltat",
    "recoltaților": "recoltat",
    "recoltato": "recoltat",
    "recoltatul": "recoltat",
    "recoltatule": "recoltat",
    "recoltatului": "recoltat",
    "nemairecomandând": "recomanda",
    "nemairecomandându": "recomanda",
    "nerecomandând": "recomanda",
    "nerecomandându": "recomanda",
    "recomand": "recomanda",
    "recomandă": "recomanda",
    "recomandai": "recomanda",
    "recomandam": "recomanda",
    "recomandăm": "recomanda",
    "recomandând": "recomanda",
    "recomandându": "recomanda",
    "recomandară": "recomanda",
    "recomandarăm": "recomanda",
    "recomandarăți": "recomanda",
    "recomandase": "recomanda",
    "recomandasem": "recomanda",
    "recomandaseră": "recomanda",
    "recomandaserăm": "recomanda",
    "recomandaserăți": "recomanda",
    "recomandaseși": "recomanda",
    "recomandași": "recomanda",
    "recomandat": "recomanda",
    "recomandați": "recomanda",
    "recomandau": "recomanda",
    "recomande": "recomanda",
    "recomanzi": "recomanda",
    "recomandabila": "recomandabil",
    "recomandabilă": "recomandabil",
    "recomandabile": "recomandabil",
    "recomandabilei": "recomandabil",
    "recomandabilele": "recomandabil",
    "recomandabilelor": "recomandabil",
    "recomandabili": "recomandabil",
    "recomandabilii": "recomandabil",
    "recomandabililor": "recomandabil",
    "recomandabilo": "recomandabil",
    "recomandabilul": "recomandabil",
    "recomandabilule": "recomandabil",
    "recomandabilului": "recomandabil",
    "recomandarea": "recomandare",
    "recomandareo": "recomandare",
    "recomandări": "recomandare",
    "recomandării": "recomandare",
    "recomandările": "recomandare",
    "recomandărilor": "recomandare",
    "recomandată": "recomandat",
    "recomandate": "recomandat",
    "recomandați": "recomandat",
    "recomandata": "recomandată",
    "recomandate": "recomandată",
    "recomandatei": "recomandată",
    "recomandatele": "recomandată",
    "recomandatelor": "recomandată",
    "recomandația": "recomandație",
    "recomandației": "recomandație",
    "recomandații": "recomandație",
    "recomandațiile": "recomandație",
    "recomandațiilor": "recomandație",
    "nemairecompensând": "recompensa",
    "nemairecompensându": "recompensa",
    "nerecompensând": "recompensa",
    "nerecompensându": "recompensa",
    "recompensă": "recompensa",
    "recompensai": "recompensa",
    "recompensam": "recompensa",
    "recompensăm": "recompensa",
    "recompensând": "recompensa",
    "recompensându": "recompensa",
    "recompensară": "recompensa",
    "recompensarăm": "recompensa",
    "recompensarăți": "recompensa",
    "recompensase": "recompensa",
    "recompensasem": "recompensa",
    "recompensaseră": "recompensa",
    "recompensaserăm": "recompensa",
    "recompensaserăți": "recompensa",
    "recompensaseși": "recompensa",
    "recompensași": "recompensa",
    "recompensat": "recompensa",
    "recompensați": "recompensa",
    "recompensau": "recompensa",
    "recompensează": "recompensa",
    "recompensez": "recompensa",
    "recompenseze": "recompensa",
    "recompensezi": "recompensa",
    "recompensa": "recompensă",
    "recompense": "recompensă",
    "recompensei": "recompensă",
    "recompensele": "recompensă",
    "recompenselor": "recompensă",
    "recompensată": "recompensat",
    "recompensate": "recompensat",
    "recompensați": "recompensat",
    "nemairecompunând": "recompune",
    "nemairecompunându": "recompune",
    "nerecompunând": "recompune",
    "nerecompunându": "recompune",
    "recompui": "recompune",
    "recompun": "recompune",
    "recompună": "recompune",
    "recompunând": "recompune",
    "recompunându": "recompune",
    "recompunea": "recompune",
    "recompuneai": "recompune",
    "recompuneam": "recompune",
    "recompuneați": "recompune",
    "recompuneau": "recompune",
    "recompunem": "recompune",
    "recompuneți": "recompune",
    "recompus": "recompune",
    "recompuse": "recompune",
    "recompusei": "recompune",
    "recompuseră": "recompune",
    "recompuserăm": "recompune",
    "recompuserăți": "recompune",
    "recompusese": "recompune",
    "recompusesem": "recompune",
    "recompuseseră": "recompune",
    "recompuseserăm": "recompune",
    "recompuseserăți": "recompune",
    "recompuseseși": "recompune",
    "recompuseși": "recompune",
    "recompusu": "recompune",
    "recompunerea": "recompunere",
    "recompunereo": "recompunere",
    "recompuneri": "recompunere",
    "recompunerii": "recompunere",
    "recompunerile": "recompunere",
    "recompunerilor": "recompunere",
    "recompusă": "recompus",
    "recompuse": "recompus",
    "recompuși": "recompus",
    "nemaireconciliind": "reconcilia",
    "nemaireconciliindu": "reconcilia",
    "nereconciliind": "reconcilia",
    "nereconciliindu": "reconcilia",
    "reconciliai": "reconcilia",
    "reconciliam": "reconcilia",
    "reconciliară": "reconcilia",
    "reconciliarăm": "reconcilia",
    "reconciliarăți": "reconcilia",
    "reconciliase": "reconcilia",
    "reconciliasem": "reconcilia",
    "reconciliaseră": "reconcilia",
    "reconciliaserăm": "reconcilia",
    "reconciliaserăți": "reconcilia",
    "reconciliaseși": "reconcilia",
    "reconciliași": "reconcilia",
    "reconciliat": "reconcilia",
    "reconciliați": "reconcilia",
    "reconciliau": "reconcilia",
    "reconciliază": "reconcilia",
    "reconcilie": "reconcilia",
    "reconciliem": "reconcilia",
    "reconciliez": "reconcilia",
    "reconcilieze": "reconcilia",
    "reconciliezi": "reconcilia",
    "reconciliind": "reconcilia",
    "reconciliindu": "reconcilia",
    "reconciliabila": "reconciliabil",
    "reconciliabilă": "reconciliabil",
    "reconciliabile": "reconciliabil",
    "reconciliabilei": "reconciliabil",
    "reconciliabilele": "reconciliabil",
    "reconciliabilelor": "reconciliabil",
    "reconciliabili": "reconciliabil",
    "reconciliabilii": "reconciliabil",
    "reconciliabililor": "reconciliabil",
    "reconciliabilo": "reconciliabil",
    "reconciliabilul": "reconciliabil",
    "reconciliabilule": "reconciliabil",
    "reconciliabilului": "reconciliabil",
    "reconciliată": "reconciliat",
    "reconciliate": "reconciliat",
    "reconciliați": "reconciliat",
    "reconcilierea": "reconciliere",
    "reconciliereo": "reconciliere",
    "reconcilieri": "reconciliere",
    "reconcilierii": "reconciliere",
    "reconcilierile": "reconciliere",
    "reconcilierilor": "reconciliere",
    "nemairecondiționând": "recondiționa",
    "nemairecondiționându": "recondiționa",
    "nerecondiționând": "recondiționa",
    "nerecondiționându": "recondiționa",
    "recondiționă": "recondiționa",
    "recondiționai": "recondiționa",
    "recondiționam": "recondiționa",
    "recondiționăm": "recondiționa",
    "recondiționând": "recondiționa",
    "recondiționându": "recondiționa",
    "recondiționară": "recondiționa",
    "recondiționarăm": "recondiționa",
    "recondiționarăți": "recondiționa",
    "recondiționase": "recondiționa",
    "recondiționasem": "recondiționa",
    "recondiționaseră": "recondiționa",
    "recondiționaserăm": "recondiționa",
    "recondiționaserăți": "recondiționa",
    "recondiționaseși": "recondiționa",
    "recondiționași": "recondiționa",
    "recondiționat": "recondiționa",
    "recondiționați": "recondiționa",
    "recondiționau": "recondiționa",
    "recondiționează": "recondiționa",
    "recondiționez": "recondiționa",
    "recondiționeze": "recondiționa",
    "recondiționezi": "recondiționa",
    "recondiționarea": "recondiționare",
    "recondiționareo": "recondiționare",
    "recondiționări": "recondiționare",
    "recondiționării": "recondiționare",
    "recondiționările": "recondiționare",
    "recondiționărilor": "recondiționare",
    "recondiționată": "recondiționat",
    "recondiționate": "recondiționat",
    "recondiționați": "recondiționat",
    "nemaireconfirmând": "reconfirma",
    "nemaireconfirmându": "reconfirma",
    "nereconfirmând": "reconfirma",
    "nereconfirmându": "reconfirma",
    "reconfirm": "reconfirma",
    "reconfirmă": "reconfirma",
    "reconfirmai": "reconfirma",
    "reconfirmam": "reconfirma",
    "reconfirmăm": "reconfirma",
    "reconfirmând": "reconfirma",
    "reconfirmându": "reconfirma",
    "reconfirmară": "reconfirma",
    "reconfirmarăm": "reconfirma",
    "reconfirmarăți": "reconfirma",
    "reconfirmase": "reconfirma",
    "reconfirmasem": "reconfirma",
    "reconfirmaseră": "reconfirma",
    "reconfirmaserăm": "reconfirma",
    "reconfirmaserăți": "reconfirma",
    "reconfirmaseși": "reconfirma",
    "reconfirmași": "reconfirma",
    "reconfirmat": "reconfirma",
    "reconfirmați": "reconfirma",
    "reconfirmau": "reconfirma",
    "reconfirme": "reconfirma",
    "reconfirmi": "reconfirma",
    "reconfirmarea": "reconfirmare",
    "reconfirmareo": "reconfirmare",
    "reconfirmări": "reconfirmare",
    "reconfirmării": "reconfirmare",
    "reconfirmările": "reconfirmare",
    "reconfirmărilor": "reconfirmare",
    "reconfirmată": "reconfirmat",
    "reconfirmate": "reconfirmat",
    "reconfirmați": "reconfirmat",
    "nemaireconfortând": "reconforta",
    "nemaireconfortându": "reconforta",
    "nereconfortând": "reconforta",
    "nereconfortându": "reconforta",
    "reconfortă": "reconforta",
    "reconfortai": "reconforta",
    "reconfortam": "reconforta",
    "reconfortăm": "reconforta",
    "reconfortând": "reconforta",
    "reconfortându": "reconforta",
    "reconfortară": "reconforta",
    "reconfortarăm": "reconforta",
    "reconfortarăți": "reconforta",
    "reconfortase": "reconforta",
    "reconfortasem": "reconforta",
    "reconfortaseră": "reconforta",
    "reconfortaserăm": "reconforta",
    "reconfortaserăți": "reconforta",
    "reconfortaseși": "reconforta",
    "reconfortași": "reconforta",
    "reconfortat": "reconforta",
    "reconfortați": "reconforta",
    "reconfortau": "reconforta",
    "reconfortează": "reconforta",
    "reconfortez": "reconforta",
    "reconforteze": "reconforta",
    "reconfortezi": "reconforta",
    "reconfortanta": "reconfortant",
    "reconfortantă": "reconfortant",
    "reconfortante": "reconfortant",
    "reconfortantei": "reconfortant",
    "reconfortantele": "reconfortant",
    "reconfortantelor": "reconfortant",
    "reconfortanți": "reconfortant",
    "reconfortanții": "reconfortant",
    "reconfortanților": "reconfortant",
    "reconfortantul": "reconfortant",
    "reconfortantului": "reconfortant",
    "reconfortarea": "reconfortare",
    "reconfortareo": "reconfortare",
    "reconfortări": "reconfortare",
    "reconfortării": "reconfortare",
    "reconfortările": "reconfortare",
    "reconfortărilor": "reconfortare",
    "reconfortată": "reconfortat",
    "reconfortate": "reconfortat",
    "reconfortați": "reconfortat",
    "nemaireconsiderând": "reconsidera",
    "nemaireconsiderându": "reconsidera",
    "nereconsiderând": "reconsidera",
    "nereconsiderându": "reconsidera",
    "reconsider": "reconsidera",
    "reconsideră": "reconsidera",
    "reconsiderai": "reconsidera",
    "reconsideram": "reconsidera",
    "reconsiderăm": "reconsidera",
    "reconsiderând": "reconsidera",
    "reconsiderându": "reconsidera",
    "reconsiderară": "reconsidera",
    "reconsiderarăm": "reconsidera",
    "reconsiderarăți": "reconsidera",
    "reconsiderase": "reconsidera",
    "reconsiderasem": "reconsidera",
    "reconsideraseră": "reconsidera",
    "reconsideraserăm": "reconsidera",
    "reconsideraserăți": "reconsidera",
    "reconsideraseși": "reconsidera",
    "reconsiderași": "reconsidera",
    "reconsiderat": "reconsidera",
    "reconsiderați": "reconsidera",
    "reconsiderau": "reconsidera",
    "reconsidere": "reconsidera",
    "reconsideri": "reconsidera",
    "reconsiderarea": "reconsiderare",
    "reconsiderareo": "reconsiderare",
    "reconsiderări": "reconsiderare",
    "reconsiderării": "reconsiderare",
    "reconsiderările": "reconsiderare",
    "reconsiderărilor": "reconsiderare",
    "reconsiderată": "reconsiderat",
    "reconsiderate": "reconsiderat",
    "reconsiderați": "reconsiderat",
    "nemaireconstituind": "reconstitui",
    "nemaireconstituindu": "reconstitui",
    "nereconstituind": "reconstitui",
    "nereconstituindu": "reconstitui",
    "reconstituia": "reconstitui",
    "reconstituiai": "reconstitui",
    "reconstituiam": "reconstitui",
    "reconstituiați": "reconstitui",
    "reconstituiau": "reconstitui",
    "reconstituie": "reconstitui",
    "reconstituii": "reconstitui",
    "reconstituim": "reconstitui",
    "reconstituind": "reconstitui",
    "reconstituindu": "reconstitui",
    "reconstituiră": "reconstitui",
    "reconstituirăm": "reconstitui",
    "reconstituirăți": "reconstitui",
    "reconstituise": "reconstitui",
    "reconstituisem": "reconstitui",
    "reconstituiseră": "reconstitui",
    "reconstituiserăm": "reconstitui",
    "reconstituiserăți": "reconstitui",
    "reconstituiseși": "reconstitui",
    "reconstituiși": "reconstitui",
    "reconstituit": "reconstitui",
    "reconstituiți": "reconstitui",
    "reconstituirea": "reconstituire",
    "reconstituireo": "reconstituire",
    "reconstituiri": "reconstituire",
    "reconstituirii": "reconstituire",
    "reconstituirile": "reconstituire",
    "reconstituirilor": "reconstituire",
    "reconstituită": "reconstituit",
    "reconstituite": "reconstituit",
    "reconstituiți": "reconstituit",
    "reconstrucția": "reconstrucție",
    "reconstrucției": "reconstrucție",
    "reconstrucții": "reconstrucție",
    "reconstrucțiile": "reconstrucție",
    "reconstrucțiilor": "reconstrucție",
    "nemaireconstruind": "reconstrui",
    "nemaireconstruindu": "reconstrui",
    "nereconstruind": "reconstrui",
    "nereconstruindu": "reconstrui",
    "reconstruia": "reconstrui",
    "reconstruiai": "reconstrui",
    "reconstruiam": "reconstrui",
    "reconstruiască": "reconstrui",
    "reconstruiați": "reconstrui",
    "reconstruiau": "reconstrui",
    "reconstruiesc": "reconstrui",
    "reconstruiește": "reconstrui",
    "reconstruiești": "reconstrui",
    "reconstruii": "reconstrui",
    "reconstruim": "reconstrui",
    "reconstruind": "reconstrui",
    "reconstruindu": "reconstrui",
    "reconstruiră": "reconstrui",
    "reconstruirăm": "reconstrui",
    "reconstruirăți": "reconstrui",
    "reconstruise": "reconstrui",
    "reconstruisem": "reconstrui",
    "reconstruiseră": "reconstrui",
    "reconstruiserăm": "reconstrui",
    "reconstruiserăți": "reconstrui",
    "reconstruiseși": "reconstrui",
    "reconstruiși": "reconstrui",
    "reconstruit": "reconstrui",
    "reconstruiți": "reconstrui",
    "reconstruirea": "reconstruire",
    "reconstruireo": "reconstruire",
    "reconstruiri": "reconstruire",
    "reconstruirii": "reconstruire",
    "reconstruirile": "reconstruire",
    "reconstruirilor": "reconstruire",
    "reconstruită": "reconstruit",
    "reconstruite": "reconstruit",
    "reconstruiți": "reconstruit",
    "reconvenționala": "reconvențional",
    "reconvențională": "reconvențional",
    "reconvenționale": "reconvențional",
    "reconvenționalei": "reconvențional",
    "reconvenționalele": "reconvențional",
    "reconvenționalelor": "reconvențional",
    "reconvenționali": "reconvențional",
    "reconvenționalii": "reconvențional",
    "reconvenționalilor": "reconvențional",
    "reconvenționalul": "reconvențional",
    "reconvenționalului": "reconvențional",
    "reconversia": "reconversie",
    "reconversiei": "reconversie",
    "reconversii": "reconversie",
    "reconversiile": "reconversie",
    "reconversiilor": "reconversie",
    "recoaptă": "recopt",
    "recopte": "recopt",
    "recopți": "recopt",
    "recordul": "record",
    "recordului": "record",
    "recorduri": "record",
    "recordurile": "record",
    "recordurilor": "record",
    "recordmanul": "recordman",
    "recordmanului": "recordman",
    "recordmeni": "recordman",
    "recordmenii": "recordman",
    "recordmenilor": "recordman",
    "nemairecreind": "recrea",
    "nemairecreindu": "recrea",
    "nerecreind": "recrea",
    "nerecreindu": "recrea",
    "recreai": "recrea",
    "recream": "recrea",
    "recreăm": "recrea",
    "recreară": "recrea",
    "recrearăm": "recrea",
    "recrearăți": "recrea",
    "recrease": "recrea",
    "recreasem": "recrea",
    "recreaseră": "recrea",
    "recreaserăm": "recrea",
    "recreaserăți": "recrea",
    "recreaseși": "recrea",
    "recreași": "recrea",
    "recreat": "recrea",
    "recreați": "recrea",
    "recreau": "recrea",
    "recree": "recrea",
    "recreează": "recrea",
    "recreez": "recrea",
    "recreeze": "recrea",
    "recreezi": "recrea",
    "recreind": "recrea",
    "recreindu": "recrea",
    "recrearea": "recreare",
    "recreareo": "recreare",
    "recreări": "recreare",
    "recreării": "recreare",
    "recreările": "recreare",
    "recreărilor": "recreare",
    "recreata": "recreat",
    "recreată": "recreat",
    "recreate": "recreat",
    "recreatei": "recreat",
    "recreatele": "recreat",
    "recreatelor": "recreat",
    "recreați": "recreat",
    "recreații": "recreat",
    "recreaților": "recreat",
    "recreato": "recreat",
    "recreatul": "recreat",
    "recreatule": "recreat",
    "recreatului": "recreat",
    "recreația": "recreație",
    "recreației": "recreație",
    "recreații": "recreație",
    "recreațiile": "recreație",
    "recreațiilor": "recreație",
    "recreativa": "recreativ",
    "recreativă": "recreativ",
    "recreative": "recreativ",
    "recreativei": "recreativ",
    "recreativele": "recreativ",
    "recreativelor": "recreativ",
    "recreativi": "recreativ",
    "recreativii": "recreativ",
    "recreativilor": "recreativ",
    "recreativul": "recreativ",
    "recreativului": "recreativ",
    "recreerea": "recreere",
    "recreeri": "recreere",
    "recreerii": "recreere",
    "recreerile": "recreere",
    "recreerilor": "recreere",
    "recrudescenta": "recrudescent",
    "recrudescentă": "recrudescent",
    "recrudescente": "recrudescent",
    "recrudescentei": "recrudescent",
    "recrudescentele": "recrudescent",
    "recrudescentelor": "recrudescent",
    "recrudescenți": "recrudescent",
    "recrudescenții": "recrudescent",
    "recrudescenților": "recrudescent",
    "recrudescentul": "recrudescent",
    "recrudescentului": "recrudescent",
    "recrudescența": "recrudescență",
    "recrudescențe": "recrudescență",
    "recrudescenței": "recrudescență",
    "recrudescențele": "recrudescență",
    "recrudescențelor": "recrudescență",
    "recruți": "recrut",
    "recruții": "recrut",
    "recruților": "recrut",
    "recrutul": "recrut",
    "recrutului": "recrut",
    "nemairecrutând": "recruta",
    "nemairecrutându": "recruta",
    "nerecrutând": "recruta",
    "nerecrutându": "recruta",
    "recrută": "recruta",
    "recrutai": "recruta",
    "recrutam": "recruta",
    "recrutăm": "recruta",
    "recrutând": "recruta",
    "recrutându": "recruta",
    "recrutară": "recruta",
    "recrutarăm": "recruta",
    "recrutarăți": "recruta",
    "recrutase": "recruta",
    "recrutasem": "recruta",
    "recrutaseră": "recruta",
    "recrutaserăm": "recruta",
    "recrutaserăți": "recruta",
    "recrutaseși": "recruta",
    "recrutași": "recruta",
    "recrutat": "recruta",
    "recrutați": "recruta",
    "recrutau": "recruta",
    "recrutează": "recruta",
    "recrutez": "recruta",
    "recruteze": "recruta",
    "recrutezi": "recruta",
    "recrutarea": "recrutare",
    "recrutareo": "recrutare",
    "recrutări": "recrutare",
    "recrutării": "recrutare",
    "recrutările": "recrutare",
    "recrutărilor": "recrutare",
    "recrutată": "recrutat",
    "recrutate": "recrutat",
    "recrutați": "recrutat",
    "rectul": "rect",
    "rectului": "rect",
    "recturi": "rect",
    "recturile": "rect",
    "recturilor": "rect",
    "rectala": "rectal",
    "rectală": "rectal",
    "rectale": "rectal",
    "rectalei": "rectal",
    "rectalele": "rectal",
    "rectalelor": "rectal",
    "rectali": "rectal",
    "rectalii": "rectal",
    "rectalilor": "rectal",
    "rectalul": "rectal",
    "rectalului": "rectal",
    "nemairectificând": "rectifica",
    "nemairectificându": "rectifica",
    "nerectificând": "rectifica",
    "nerectificându": "rectifica",
    "rectific": "rectifica",
    "rectifică": "rectifica",
    "rectificai": "rectifica",
    "rectificam": "rectifica",
    "rectificăm": "rectifica",
    "rectificând": "rectifica",
    "rectificându": "rectifica",
    "rectificară": "rectifica",
    "rectificarăm": "rectifica",
    "rectificarăți": "rectifica",
    "rectificase": "rectifica",
    "rectificasem": "rectifica",
    "rectificaseră": "rectifica",
    "rectificaserăm": "rectifica",
    "rectificaserăți": "rectifica",
    "rectificaseși": "rectifica",
    "rectificași": "rectifica",
    "rectificat": "rectifica",
    "rectificați": "rectifica",
    "rectificau": "rectifica",
    "rectifice": "rectifica",
    "rectifici": "rectifica",
    "rectificabila": "rectificabil",
    "rectificabilă": "rectificabil",
    "rectificabile": "rectificabil",
    "rectificabilei": "rectificabil",
    "rectificabilele": "rectificabil",
    "rectificabilelor": "rectificabil",
    "rectificabili": "rectificabil",
    "rectificabilii": "rectificabil",
    "rectificabililor": "rectificabil",
    "rectificabilo": "rectificabil",
    "rectificabilul": "rectificabil",
    "rectificabilule": "rectificabil",
    "rectificabilului": "rectificabil",
    "rectificarea": "rectificare",
    "rectificareo": "rectificare",
    "rectificări": "rectificare",
    "rectificării": "rectificare",
    "rectificările": "rectificare",
    "rectificărilor": "rectificare",
    "rectificată": "rectificat",
    "rectificate": "rectificat",
    "rectificați": "rectificat",
    "rectiliniaritatea": "rectiliniaritate",
    "rectiliniarități": "rectiliniaritate",
    "rectiliniarității": "rectiliniaritate",
    "rectilinia": "rectiliniu",
    "rectilinie": "rectiliniu",
    "rectiliniei": "rectiliniu",
    "rectilinii": "rectiliniu",
    "rectiliniii": "rectiliniu",
    "rectiliniile": "rectiliniu",
    "rectiliniilor": "rectiliniu",
    "rectiliniul": "rectiliniu",
    "rectiliniului": "rectiliniu",
    "rectori": "rector",
    "rectorii": "rector",
    "rectorilor": "rector",
    "rectorul": "rector",
    "rectorului": "rector",
    "rectorate": "rectorat",
    "rectoratele": "rectorat",
    "rectoratelor": "rectorat",
    "rectoratul": "rectorat",
    "rectoratului": "rectorat",
    "nemairecucerind": "recuceri",
    "nemairecucerindu": "recuceri",
    "nerecucerind": "recuceri",
    "nerecucerindu": "recuceri",
    "recucerea": "recuceri",
    "recucereai": "recuceri",
    "recuceream": "recuceri",
    "recucerească": "recuceri",
    "recucereați": "recuceri",
    "recucereau": "recuceri",
    "recuceresc": "recuceri",
    "recucerește": "recuceri",
    "recucerești": "recuceri",
    "recucerii": "recuceri",
    "recucerim": "recuceri",
    "recucerind": "recuceri",
    "recucerindu": "recuceri",
    "recuceriră": "recuceri",
    "recucerirăm": "recuceri",
    "recucerirăți": "recuceri",
    "recucerise": "recuceri",
    "recucerisem": "recuceri",
    "recuceriseră": "recuceri",
    "recuceriserăm": "recuceri",
    "recuceriserăți": "recuceri",
    "recuceriseși": "recuceri",
    "recuceriși": "recuceri",
    "recucerit": "recuceri",
    "recuceriți": "recuceri",
    "recucerirea": "recucerire",
    "recucerireo": "recucerire",
    "recuceriri": "recucerire",
    "recuceririi": "recucerire",
    "recuceririle": "recucerire",
    "recuceririlor": "recucerire",
    "recucerita": "recucerit",
    "recucerită": "recucerit",
    "recucerite": "recucerit",
    "recuceritei": "recucerit",
    "recuceritele": "recucerit",
    "recuceritelor": "recucerit",
    "recuceriți": "recucerit",
    "recuceriții": "recucerit",
    "recuceriților": "recucerit",
    "recucerito": "recucerit",
    "recuceritul": "recucerit",
    "recuceritule": "recucerit",
    "recuceritului": "recucerit",
    "reculul": "recul",
    "reculului": "recul",
    "reculuri": "recul",
    "reculurile": "recul",
    "reculurilor": "recul",
    "nemaireculegând": "reculege",
    "nemaireculegându": "reculege",
    "nereculegând": "reculege",
    "nereculegându": "reculege",
    "reculeagă": "reculege",
    "reculeg": "reculege",
    "reculegând": "reculege",
    "reculegându": "reculege",
    "reculegea": "reculege",
    "reculegeai": "reculege",
    "reculegeam": "reculege",
    "reculegeați": "reculege",
    "reculegeau": "reculege",
    "reculegem": "reculege",
    "reculegeți": "reculege",
    "reculegi": "reculege",
    "reculese": "reculege",
    "reculesei": "reculege",
    "reculeseră": "reculege",
    "reculeserăm": "reculege",
    "reculeserăți": "reculege",
    "reculesese": "reculege",
    "reculesesem": "reculege",
    "reculeseseră": "reculege",
    "reculeseserăm": "reculege",
    "reculeseserăți": "reculege",
    "reculeseseși": "reculege",
    "reculeseși": "reculege",
    "reculegerea": "reculegere",
    "reculegereo": "reculegere",
    "reculegeri": "reculegere",
    "reculegerii": "reculegere",
    "reculegerile": "reculegere",
    "reculegerilor": "reculegere",
    "nemairecunoscând": "recunoaște",
    "nemairecunoscându": "recunoaște",
    "nerecunoscând": "recunoaște",
    "nerecunoscându": "recunoaște",
    "recunoască": "recunoaște",
    "recunoaștem": "recunoaște",
    "recunoașteți": "recunoaște",
    "recunosc": "recunoaște",
    "recunoscând": "recunoaște",
    "recunoscându": "recunoaște",
    "recunoscu": "recunoaște",
    "recunoscui": "recunoaște",
    "recunoscură": "recunoaște",
    "recunoscurăm": "recunoaște",
    "recunoscurăți": "recunoaște",
    "recunoscuse": "recunoaște",
    "recunoscusem": "recunoaște",
    "recunoscuseră": "recunoaște",
    "recunoscuserăm": "recunoaște",
    "recunoscuserăți": "recunoaște",
    "recunoscuseși": "recunoaște",
    "recunoscuși": "recunoaște",
    "recunoscut": "recunoaște",
    "recunoștea": "recunoaște",
    "recunoșteai": "recunoaște",
    "recunoșteam": "recunoaște",
    "recunoșteați": "recunoaște",
    "recunoșteau": "recunoaște",
    "recunoști": "recunoaște",
    "recunoașterea": "recunoaștere",
    "recunoașteri": "recunoaștere",
    "recunoașterii": "recunoaștere",
    "recunoașterile": "recunoaștere",
    "recunoașterilor": "recunoaștere",
    "recunoscătoare": "recunoscător",
    "recunoscătoarea": "recunoscător",
    "recunoscătoarei": "recunoscător",
    "recunoscătoarele": "recunoscător",
    "recunoscătoarelor": "recunoscător",
    "recunoscători": "recunoscător",
    "recunoscătorii": "recunoscător",
    "recunoscătorilor": "recunoscător",
    "recunoscătorul": "recunoscător",
    "recunoscătorului": "recunoscător",
    "recunoscuta": "recunoscut",
    "recunoscută": "recunoscut",
    "recunoscute": "recunoscut",
    "recunoscutei": "recunoscut",
    "recunoscutele": "recunoscut",
    "recunoscutelor": "recunoscut",
    "recunoscuți": "recunoscut",
    "recunoscuții": "recunoscut",
    "recunoscuților": "recunoscut",
    "recunoscutul": "recunoscut",
    "recunoscutului": "recunoscut",
    "recunoștința": "recunoștință",
    "recunoștințe": "recunoștință",
    "recunoștinței": "recunoștință",
    "recunoștințele": "recunoștință",
    "recunoștințelor": "recunoștință",
    "nemairecuperând": "recupera",
    "nemairecuperându": "recupera",
    "nerecuperând": "recupera",
    "nerecuperându": "recupera",
    "recuperă": "recupera",
    "recuperai": "recupera",
    "recuperam": "recupera",
    "recuperăm": "recupera",
    "recuperând": "recupera",
    "recuperându": "recupera",
    "recuperară": "recupera",
    "recuperarăm": "recupera",
    "recuperarăți": "recupera",
    "recuperase": "recupera",
    "recuperasem": "recupera",
    "recuperaseră": "recupera",
    "recuperaserăm": "recupera",
    "recuperaserăți": "recupera",
    "recuperaseși": "recupera",
    "recuperași": "recupera",
    "recuperat": "recupera",
    "recuperați": "recupera",
    "recuperau": "recupera",
    "recuperează": "recupera",
    "recuperez": "recupera",
    "recupereze": "recupera",
    "recuperezi": "recupera",
    "recuperabila": "recuperabil",
    "recuperabilă": "recuperabil",
    "recuperabile": "recuperabil",
    "recuperabilei": "recuperabil",
    "recuperabilele": "recuperabil",
    "recuperabilelor": "recuperabil",
    "recuperabili": "recuperabil",
    "recuperabilii": "recuperabil",
    "recuperabililor": "recuperabil",
    "recuperabilo": "recuperabil",
    "recuperabilul": "recuperabil",
    "recuperabilule": "recuperabil",
    "recuperabilului": "recuperabil",
    "recuperarea": "recuperare",
    "recuperareo": "recuperare",
    "recuperări": "recuperare",
    "recuperării": "recuperare",
    "recuperările": "recuperare",
    "recuperărilor": "recuperare",
    "recuperată": "recuperat",
    "recuperate": "recuperat",
    "recuperați": "recuperat",
    "recurenta": "recurent",
    "recurentă": "recurent",
    "recurente": "recurent",
    "recurentei": "recurent",
    "recurentele": "recurent",
    "recurentelor": "recurent",
    "recurenți": "recurent",
    "recurenții": "recurent",
    "recurenților": "recurent",
    "recurentul": "recurent",
    "recurentului": "recurent",
    "nemairecurgând": "recurge",
    "nemairecurgându": "recurge",
    "nerecurgând": "recurge",
    "nerecurgându": "recurge",
    "recurg": "recurge",
    "recurgă": "recurge",
    "recurgând": "recurge",
    "recurgându": "recurge",
    "recurgea": "recurge",
    "recurgeai": "recurge",
    "recurgeam": "recurge",
    "recurgeați": "recurge",
    "recurgeau": "recurge",
    "recurgem": "recurge",
    "recurgeți": "recurge",
    "recurgi": "recurge",
    "recurs": "recurge",
    "recurse": "recurge",
    "recursei": "recurge",
    "recurseră": "recurge",
    "recurserăm": "recurge",
    "recurserăți": "recurge",
    "recursese": "recurge",
    "recursesem": "recurge",
    "recurseseră": "recurge",
    "recurseserăm": "recurge",
    "recurseserăți": "recurge",
    "recurseseși": "recurge",
    "recurseși": "recurge",
    "recurgerea": "recurgere",
    "recurgereo": "recurgere",
    "recurgeri": "recurgere",
    "recurgerii": "recurgere",
    "recurgerile": "recurgere",
    "recurgerilor": "recurgere",
    "recursă": "recurs",
    "recurse": "recurs",
    "recurși": "recurs",
    "recursul": "recurs",
    "recursului": "recurs",
    "recursuri": "recurs",
    "recursurile": "recurs",
    "recursurilor": "recurs",
    "nemairecuzând": "recuza",
    "nemairecuzându": "recuza",
    "nerecuzând": "recuza",
    "nerecuzându": "recuza",
    "recuz": "recuza",
    "recuză": "recuza",
    "recuzai": "recuza",
    "recuzam": "recuza",
    "recuzăm": "recuza",
    "recuzând": "recuza",
    "recuzându": "recuza",
    "recuzară": "recuza",
    "recuzarăm": "recuza",
    "recuzarăți": "recuza",
    "recuzase": "recuza",
    "recuzasem": "recuza",
    "recuzaseră": "recuza",
    "recuzaserăm": "recuza",
    "recuzaserăți": "recuza",
    "recuzaseși": "recuza",
    "recuzași": "recuza",
    "recuzat": "recuza",
    "recuzați": "recuza",
    "recuzau": "recuza",
    "recuze": "recuza",
    "recuzi": "recuza",
    "recuzată": "recuzat",
    "recuzate": "recuzat",
    "recuzați": "recuzat",
    "recuzita": "recuzită",
    "recuzite": "recuzită",
    "recuzitei": "recuzită",
    "recuzitele": "recuzită",
    "recuzitelor": "recuzită",
    "recviemul": "recviem",
    "recviemului": "recviem",
    "recviemuri": "recviem",
    "recviemurile": "recviem",
    "recviemurilor": "recviem",
    "nemairedând": "reda",
    "nemairedându": "reda",
    "neredând": "reda",
    "neredându": "reda",
    "redă": "reda",
    "redai": "reda",
    "redam": "reda",
    "redăm": "reda",
    "redând": "reda",
    "redându": "reda",
    "redară": "reda",
    "redarăm": "reda",
    "redarăți": "reda",
    "redase": "reda",
    "redasem": "reda",
    "redaseră": "reda",
    "redaserăm": "reda",
    "redaserăți": "reda",
    "redaseși": "reda",
    "redași": "reda",
    "redat": "reda",
    "redați": "reda",
    "redau": "reda",
    "redea": "reda",
    "nemairedactând": "redacta",
    "nemairedactându": "redacta",
    "neredactând": "redacta",
    "neredactându": "redacta",
    "redactă": "redacta",
    "redactai": "redacta",
    "redactam": "redacta",
    "redactăm": "redacta",
    "redactând": "redacta",
    "redactându": "redacta",
    "redactară": "redacta",
    "redactarăm": "redacta",
    "redactarăți": "redacta",
    "redactase": "redacta",
    "redactasem": "redacta",
    "redactaseră": "redacta",
    "redactaserăm": "redacta",
    "redactaserăți": "redacta",
    "redactaseși": "redacta",
    "redactași": "redacta",
    "redactat": "redacta",
    "redactați": "redacta",
    "redactau": "redacta",
    "redactează": "redacta",
    "redactez": "redacta",
    "redacteze": "redacta",
    "redactezi": "redacta",
    "redactarea": "redactare",
    "redactareo": "redactare",
    "redactări": "redactare",
    "redactării": "redactare",
    "redactările": "redactare",
    "redactărilor": "redactare",
    "redactată": "redactat",
    "redactate": "redactat",
    "redactați": "redactat",
    "redacția": "redacție",
    "redacției": "redacție",
    "redacții": "redacție",
    "redacțiile": "redacție",
    "redacțiilor": "redacție",
    "redacționala": "redacțional",
    "redacțională": "redacțional",
    "redacționale": "redacțional",
    "redacționalei": "redacțional",
    "redacționalele": "redacțional",
    "redacționalelor": "redacțional",
    "redacționali": "redacțional",
    "redacționalii": "redacțional",
    "redacționalilor": "redacțional",
    "redacționalul": "redacțional",
    "redacționalului": "redacțional",
    "redactori": "redactor",
    "redactorii": "redactor",
    "redactorilor": "redactor",
    "redactorul": "redactor",
    "redactorului": "redactor",
    "redarea": "redare",
    "redareo": "redare",
    "redări": "redare",
    "redării": "redare",
    "redările": "redare",
    "redărilor": "redare",
    "redată": "redat",
    "redate": "redat",
    "redați": "redat",
    "redefinea": "redefini",
    "redefineai": "redefini",
    "redefineam": "redefini",
    "redefinească": "redefini",
    "redefineați": "redefini",
    "redefineau": "redefini",
    "redefinesc": "redefini",
    "redefinește": "redefini",
    "redefinești": "redefini",
    "redefiniși": "redefini",
    "redefinit": "redefini",
    "redefiniți": "redefini",
    "redefinită": "redefinit",
    "redefinite": "redefinit",
    "redefiniți": "redefinit",
    "nemairedeschizând": "redeschide",
    "nemairedeschizându": "redeschide",
    "neredeschizând": "redeschide",
    "neredeschizându": "redeschide",
    "redeschid": "redeschide",
    "redeschidă": "redeschide",
    "redeschidea": "redeschide",
    "redeschideai": "redeschide",
    "redeschideam": "redeschide",
    "redeschideați": "redeschide",
    "redeschideau": "redeschide",
    "redeschidem": "redeschide",
    "redeschideți": "redeschide",
    "redeschis": "redeschide",
    "redeschise": "redeschide",
    "redeschisei": "redeschide",
    "redeschiseră": "redeschide",
    "redeschiserăm": "redeschide",
    "redeschiserăți": "redeschide",
    "redeschisese": "redeschide",
    "redeschisesem": "redeschide",
    "redeschiseseră": "redeschide",
    "redeschiseserăm": "redeschide",
    "redeschiseserăți": "redeschide",
    "redeschiseseși": "redeschide",
    "redeschiseși": "redeschide",
    "redeschizând": "redeschide",
    "redeschizându": "redeschide",
    "redeschizi": "redeschide",
    "redeschiderea": "redeschidere",
    "redeschidereo": "redeschidere",
    "redeschideri": "redeschidere",
    "redeschiderii": "redeschidere",
    "redeschiderile": "redeschidere",
    "redeschiderilor": "redeschidere",
    "redeschisa": "redeschis",
    "redeschisă": "redeschis",
    "redeschise": "redeschis",
    "redeschisei": "redeschis",
    "redeschisele": "redeschis",
    "redeschiselor": "redeschis",
    "redeschiși": "redeschis",
    "redeschișii": "redeschis",
    "redeschișilor": "redeschis",
    "redeschisul": "redeschis",
    "redeschisului": "redeschis",
    "nemairedescoperind": "redescoperi",
    "nemairedescoperindu": "redescoperi",
    "neredescoperind": "redescoperi",
    "neredescoperindu": "redescoperi",
    "redescopăr": "redescoperi",
    "redescoperă": "redescoperi",
    "redescopere": "redescoperi",
    "redescoperea": "redescoperi",
    "redescopereai": "redescoperi",
    "redescopeream": "redescoperi",
    "redescopereați": "redescoperi",
    "redescopereau": "redescoperi",
    "redescoperii": "redescoperi",
    "redescoperim": "redescoperi",
    "redescoperind": "redescoperi",
    "redescoperindu": "redescoperi",
    "redescoperiră": "redescoperi",
    "redescoperirăm": "redescoperi",
    "redescoperirăți": "redescoperi",
    "redescoperise": "redescoperi",
    "redescoperisem": "redescoperi",
    "redescoperiseră": "redescoperi",
    "redescoperiserăm": "redescoperi",
    "redescoperiserăți": "redescoperi",
    "redescoperiseși": "redescoperi",
    "redescoperiși": "redescoperi",
    "redescoperit": "redescoperi",
    "redescoperiți": "redescoperi",
    "redescoperirea": "redescoperire",
    "redescoperireo": "redescoperire",
    "redescoperiri": "redescoperire",
    "redescoperirii": "redescoperire",
    "redescoperirile": "redescoperire",
    "redescoperirilor": "redescoperire",
    "redescoperită": "redescoperit",
    "redescoperite": "redescoperit",
    "redescoperiți": "redescoperit",
    "nemairedeșteptând": "redeștepta",
    "nemairedeșteptându": "redeștepta",
    "neredeșteptând": "redeștepta",
    "neredeșteptându": "redeștepta",
    "redeșteaptă": "redeștepta",
    "redeștept": "redeștepta",
    "redeșteptă": "redeștepta",
    "redeșteptai": "redeștepta",
    "redeșteptam": "redeștepta",
    "redeșteptăm": "redeștepta",
    "redeșteptând": "redeștepta",
    "redeșteptându": "redeștepta",
    "redeșteptară": "redeștepta",
    "redeșteptarăm": "redeștepta",
    "redeșteptarăți": "redeștepta",
    "redeșteptase": "redeștepta",
    "redeșteptasem": "redeștepta",
    "redeșteptaseră": "redeștepta",
    "redeșteptaserăm": "redeștepta",
    "redeșteptaserăți": "redeștepta",
    "redeșteptaseși": "redeștepta",
    "redeșteptași": "redeștepta",
    "redeșteptat": "redeștepta",
    "redeșteptați": "redeștepta",
    "redeșteptau": "redeștepta",
    "redeștepte": "redeștepta",
    "redeștepți": "redeștepta",
    "redeșteptarea": "redeșteptare",
    "redeșteptareo": "redeșteptare",
    "redeșteptări": "redeșteptare",
    "redeșteptării": "redeșteptare",
    "redeșteptările": "redeșteptare",
    "redeșteptărilor": "redeșteptare",
    "redeșteptată": "redeșteptat",
    "redeșteptate": "redeșteptat",
    "redeșteptați": "redeșteptat",
    "redetaliai": "redetalia",
    "redetaliam": "redetalia",
    "redetaliară": "redetalia",
    "redetaliarăm": "redetalia",
    "redetaliarăți": "redetalia",
    "redetaliase": "redetalia",
    "redetaliasem": "redetalia",
    "redetaliaseră": "redetalia",
    "redetaliaserăm": "redetalia",
    "redetaliaserăți": "redetalia",
    "redetaliaseși": "redetalia",
    "redetaliași": "redetalia",
    "redetaliat": "redetalia",
    "redetaliați": "redetalia",
    "redetaliatu": "redetalia",
    "redetaliau": "redetalia",
    "redetaliază": "redetalia",
    "redetalie": "redetalia",
    "redetaliem": "redetalia",
    "redetaliez": "redetalia",
    "redetalieze": "redetalia",
    "redetaliezi": "redetalia",
    "redetaliind": "redetalia",
    "redetaliindu": "redetalia",
    "redetaliată": "redetaliat",
    "redetaliate": "redetaliat",
    "redetaliați": "redetaliat",
    "nemairedevenind": "redeveni",
    "nemairedevenindu": "redeveni",
    "neredevenind": "redeveni",
    "neredevenindu": "redeveni",
    "redevenea": "redeveni",
    "redeveneai": "redeveni",
    "redeveneam": "redeveni",
    "redeveneați": "redeveni",
    "redeveneau": "redeveni",
    "redevenii": "redeveni",
    "redevenim": "redeveni",
    "redevenind": "redeveni",
    "redevenindu": "redeveni",
    "redeveniră": "redeveni",
    "redevenirăm": "redeveni",
    "redevenirăți": "redeveni",
    "redevenise": "redeveni",
    "redevenisem": "redeveni",
    "redeveniseră": "redeveni",
    "redeveniserăm": "redeveni",
    "redeveniserăți": "redeveni",
    "redeveniseși": "redeveni",
    "redeveniși": "redeveni",
    "redevenit": "redeveni",
    "redeveniți": "redeveni",
    "redevin": "redeveni",
    "redevină": "redeveni",
    "redevine": "redeveni",
    "redevenită": "redevenit",
    "redevenite": "redevenit",
    "redeveniți": "redevenit",
    "redingota": "redingotă",
    "redingote": "redingotă",
    "redingotei": "redingotă",
    "redingotele": "redingotă",
    "redingotelor": "redingotă",
    "redirijă": "redirija",
    "redirijai": "redirija",
    "redirijam": "redirija",
    "redirijăm": "redirija",
    "redirijând": "redirija",
    "redirijându": "redirija",
    "redirijară": "redirija",
    "redirijarăm": "redirija",
    "redirijarăți": "redirija",
    "redirijase": "redirija",
    "redirijasem": "redirija",
    "redirijaseră": "redirija",
    "redirijaserăm": "redirija",
    "redirijaserăți": "redirija",
    "redirijaseși": "redirija",
    "redirijași": "redirija",
    "redirijat": "redirija",
    "redirijați": "redirija",
    "redirijau": "redirija",
    "redirijează": "redirija",
    "redirijez": "redirija",
    "redirijeze": "redirija",
    "redirijezi": "redirija",
    "redirijarea": "redirijare",
    "redirijări": "redirijare",
    "redirijării": "redirijare",
    "redirijările": "redirijare",
    "redirijărilor": "redirijare",
    "redirijata": "redirijat",
    "redirijată": "redirijat",
    "redirijate": "redirijat",
    "redirijatei": "redirijat",
    "redirijatele": "redirijat",
    "redirijatelor": "redirijat",
    "redirijați": "redirijat",
    "redirijații": "redirijat",
    "redirijaților": "redirijat",
    "redirijato": "redirijat",
    "redirijatul": "redirijat",
    "redirijatule": "redirijat",
    "redirijatului": "redirijat",
    "nemairediscutând": "rediscuta",
    "nemairediscutându": "rediscuta",
    "nerediscutând": "rediscuta",
    "nerediscutându": "rediscuta",
    "rediscut": "rediscuta",
    "rediscută": "rediscuta",
    "rediscutai": "rediscuta",
    "rediscutam": "rediscuta",
    "rediscutăm": "rediscuta",
    "rediscutând": "rediscuta",
    "rediscutându": "rediscuta",
    "rediscutară": "rediscuta",
    "rediscutarăm": "rediscuta",
    "rediscutarăți": "rediscuta",
    "rediscutase": "rediscuta",
    "rediscutasem": "rediscuta",
    "rediscutaseră": "rediscuta",
    "rediscutaserăm": "rediscuta",
    "rediscutaserăți": "rediscuta",
    "rediscutaseși": "rediscuta",
    "rediscutași": "rediscuta",
    "rediscutat": "rediscuta",
    "rediscutați": "rediscuta",
    "rediscutau": "rediscuta",
    "rediscute": "rediscuta",
    "rediscuți": "rediscuta",
    "rediscutarea": "rediscutare",
    "rediscutareo": "rediscutare",
    "rediscutări": "rediscutare",
    "rediscutării": "rediscutare",
    "rediscutările": "rediscutare",
    "rediscutărilor": "rediscutare",
    "rediscutată": "rediscutat",
    "rediscutate": "rediscutat",
    "rediscutați": "rediscutat",
    "nemairedistribuind": "redistribui",
    "nemairedistribuindu": "redistribui",
    "neredistribuind": "redistribui",
    "neredistribuindu": "redistribui",
    "redistribuia": "redistribui",
    "redistribuiai": "redistribui",
    "redistribuiam": "redistribui",
    "redistribuiați": "redistribui",
    "redistribuiau": "redistribui",
    "redistribuie": "redistribui",
    "redistribuii": "redistribui",
    "redistribuim": "redistribui",
    "redistribuind": "redistribui",
    "redistribuindu": "redistribui",
    "redistribuiră": "redistribui",
    "redistribuirăm": "redistribui",
    "redistribuirăți": "redistribui",
    "redistribuise": "redistribui",
    "redistribuisem": "redistribui",
    "redistribuiseră": "redistribui",
    "redistribuiserăm": "redistribui",
    "redistribuiserăți": "redistribui",
    "redistribuiseși": "redistribui",
    "redistribuiși": "redistribui",
    "redistribuit": "redistribui",
    "redistribuiți": "redistribui",
    "redistribuirea": "redistribuire",
    "redistribuireo": "redistribuire",
    "redistribuiri": "redistribuire",
    "redistribuirii": "redistribuire",
    "redistribuirile": "redistribuire",
    "redistribuirilor": "redistribuire",
    "redistribuită": "redistribuit",
    "redistribuite": "redistribuit",
    "redistribuiți": "redistribuit",
    "nemairedobândind": "redobândi",
    "nemairedobândindu": "redobândi",
    "neredobândind": "redobândi",
    "neredobândindu": "redobândi",
    "redobândea": "redobândi",
    "redobândeai": "redobândi",
    "redobândeam": "redobândi",
    "redobândească": "redobândi",
    "redobândeați": "redobândi",
    "redobândeau": "redobândi",
    "redobândesc": "redobândi",
    "redobândește": "redobândi",
    "redobândești": "redobândi",
    "redobândii": "redobândi",
    "redobândim": "redobândi",
    "redobândind": "redobândi",
    "redobândindu": "redobândi",
    "redobândiră": "redobândi",
    "redobândirăm": "redobândi",
    "redobândirăți": "redobândi",
    "redobândise": "redobândi",
    "redobândisem": "redobândi",
    "redobândiseră": "redobândi",
    "redobândiserăm": "redobândi",
    "redobândiserăți": "redobândi",
    "redobândiseși": "redobândi",
    "redobândiși": "redobândi",
    "redobândit": "redobândi",
    "redobândiți": "redobândi",
    "redobândirea": "redobândire",
    "redobândireo": "redobândire",
    "redobândiri": "redobândire",
    "redobândirii": "redobândire",
    "redobândirile": "redobândire",
    "redobândirilor": "redobândire",
    "redobândită": "redobândit",
    "redobândite": "redobândit",
    "redobândiți": "redobândit",
    "nemairedresând": "redresa",
    "nemairedresându": "redresa",
    "neredresând": "redresa",
    "neredresându": "redresa",
    "redresă": "redresa",
    "redresai": "redresa",
    "redresam": "redresa",
    "redresăm": "redresa",
    "redresând": "redresa",
    "redresându": "redresa",
    "redresară": "redresa",
    "redresarăm": "redresa",
    "redresarăți": "redresa",
    "redresase": "redresa",
    "redresasem": "redresa",
    "redresaseră": "redresa",
    "redresaserăm": "redresa",
    "redresaserăți": "redresa",
    "redresaseși": "redresa",
    "redresași": "redresa",
    "redresat": "redresa",
    "redresați": "redresa",
    "redresau": "redresa",
    "redresează": "redresa",
    "redresez": "redresa",
    "redreseze": "redresa",
    "redresezi": "redresa",
    "redresarea": "redresare",
    "redresareo": "redresare",
    "redresări": "redresare",
    "redresării": "redresare",
    "redresările": "redresare",
    "redresărilor": "redresare",
    "redresata": "redresat",
    "redresată": "redresat",
    "redresate": "redresat",
    "redresatei": "redresat",
    "redresatele": "redresat",
    "redresatelor": "redresat",
    "redresați": "redresat",
    "redresații": "redresat",
    "redresaților": "redresat",
    "redresato": "redresat",
    "redresatul": "redresat",
    "redresatule": "redresat",
    "redresatului": "redresat",
    "redresoare": "redresor",
    "redresoarea": "redresor",
    "redresoarei": "redresor",
    "redresoarele": "redresor",
    "redresoarelor": "redresor",
    "redresori": "redresor",
    "redresorii": "redresor",
    "redresorilor": "redresor",
    "redresorul": "redresor",
    "redresorului": "redresor",
    "nemaireducând": "reduce",
    "nemaireducându": "reduce",
    "nereducând": "reduce",
    "nereducându": "reduce",
    "redu": "reduce",
    "reduc": "reduce",
    "reducă": "reduce",
    "reducând": "reduce",
    "reducându": "reduce",
    "reducea": "reduce",
    "reduceai": "reduce",
    "reduceam": "reduce",
    "reduceați": "reduce",
    "reduceau": "reduce",
    "reducem": "reduce",
    "reduceți": "reduce",
    "reduci": "reduce",
    "redus": "reduce",
    "reduse": "reduce",
    "redusei": "reduce",
    "reduseră": "reduce",
    "reduserăm": "reduce",
    "reduserăți": "reduce",
    "redusese": "reduce",
    "redusesem": "reduce",
    "reduseseră": "reduce",
    "reduseserăm": "reduce",
    "reduseserăți": "reduce",
    "reduseseși": "reduce",
    "reduseși": "reduce",
    "reducerea": "reducere",
    "reducereo": "reducere",
    "reduceri": "reducere",
    "reducerii": "reducere",
    "reducerile": "reducere",
    "reducerilor": "reducere",
    "reductibila": "reductibil",
    "reductibilă": "reductibil",
    "reductibile": "reductibil",
    "reductibilei": "reductibil",
    "reductibilele": "reductibil",
    "reductibilelor": "reductibil",
    "reductibili": "reductibil",
    "reductibilii": "reductibil",
    "reductibililor": "reductibil",
    "reductibilul": "reductibil",
    "reductibilului": "reductibil",
    "reductoare": "reductor",
    "reductoarele": "reductor",
    "reductoarelor": "reductor",
    "reductorul": "reductor",
    "reductorului": "reductor",
    "redundanța": "redundanță",
    "redundanțe": "redundanță",
    "redundanței": "redundanță",
    "redundanțele": "redundanță",
    "redundanțelor": "redundanță",
    "reduplic": "reduplica",
    "reduplică": "reduplica",
    "reduplicai": "reduplica",
    "reduplicam": "reduplica",
    "reduplicăm": "reduplica",
    "reduplicând": "reduplica",
    "reduplicându": "reduplica",
    "reduplicară": "reduplica",
    "reduplicarăm": "reduplica",
    "reduplicarăți": "reduplica",
    "reduplicase": "reduplica",
    "reduplicasem": "reduplica",
    "reduplicaseră": "reduplica",
    "reduplicaserăm": "reduplica",
    "reduplicaserăți": "reduplica",
    "reduplicaseși": "reduplica",
    "reduplicași": "reduplica",
    "reduplicat": "reduplica",
    "reduplicați": "reduplica",
    "reduplicatu": "reduplica",
    "reduplicau": "reduplica",
    "reduplice": "reduplica",
    "reduplici": "reduplica",
    "reduplicarea": "reduplicare",
    "reduplicări": "reduplicare",
    "reduplicării": "reduplicare",
    "reduplicările": "reduplicare",
    "reduplicărilor": "reduplicare",
    "reduplicată": "reduplicat",
    "reduplicate": "reduplicat",
    "reduplicați": "reduplicat",
    "redusa": "redus",
    "redusă": "redus",
    "reduse": "redus",
    "redusei": "redus",
    "redusele": "redus",
    "reduselor": "redus",
    "reduși": "redus",
    "redușii": "redus",
    "redușilor": "redus",
    "redusul": "redus",
    "redusului": "redus",
    "reduta": "redută",
    "redute": "redută",
    "redutei": "redută",
    "redutele": "redută",
    "redutelor": "redută",
    "reechilibră": "reechilibra",
    "reechilibrai": "reechilibra",
    "reechilibram": "reechilibra",
    "reechilibrăm": "reechilibra",
    "reechilibrând": "reechilibra",
    "reechilibrându": "reechilibra",
    "reechilibrară": "reechilibra",
    "reechilibrarăm": "reechilibra",
    "reechilibrarăți": "reechilibra",
    "reechilibrase": "reechilibra",
    "reechilibrasem": "reechilibra",
    "reechilibraseră": "reechilibra",
    "reechilibraserăm": "reechilibra",
    "reechilibraserăți": "reechilibra",
    "reechilibraseși": "reechilibra",
    "reechilibrași": "reechilibra",
    "reechilibrat": "reechilibra",
    "reechilibrați": "reechilibra",
    "reechilibratu": "reechilibra",
    "reechilibrau": "reechilibra",
    "reechilibrează": "reechilibra",
    "reechilibrez": "reechilibra",
    "reechilibreze": "reechilibra",
    "reechilibrezi": "reechilibra",
    "reechilibrată": "reechilibrat",
    "reechilibrate": "reechilibrat",
    "reechilibrați": "reechilibrat",
    "nemaireeditând": "reedita",
    "nemaireeditându": "reedita",
    "nereeditând": "reedita",
    "nereeditându": "reedita",
    "reedită": "reedita",
    "reeditai": "reedita",
    "reeditam": "reedita",
    "reedităm": "reedita",
    "reeditând": "reedita",
    "reeditându": "reedita",
    "reeditară": "reedita",
    "reeditarăm": "reedita",
    "reeditarăți": "reedita",
    "reeditase": "reedita",
    "reeditasem": "reedita",
    "reeditaseră": "reedita",
    "reeditaserăm": "reedita",
    "reeditaserăți": "reedita",
    "reeditaseși": "reedita",
    "reeditași": "reedita",
    "reeditat": "reedita",
    "reeditați": "reedita",
    "reeditau": "reedita",
    "reeditează": "reedita",
    "reeditez": "reedita",
    "reediteze": "reedita",
    "reeditezi": "reedita",
    "reeditarea": "reeditare",
    "reeditareo": "reeditare",
    "reeditări": "reeditare",
    "reeditării": "reeditare",
    "reeditările": "reeditare",
    "reeditărilor": "reeditare",
    "reeditata": "reeditat",
    "reeditată": "reeditat",
    "reeditate": "reeditat",
    "reeditatei": "reeditat",
    "reeditatele": "reeditat",
    "reeditatelor": "reeditat",
    "reeditați": "reeditat",
    "reeditații": "reeditat",
    "reeditaților": "reeditat",
    "reeditato": "reeditat",
    "reeditatul": "reeditat",
    "reeditatule": "reeditat",
    "reeditatului": "reeditat",
    "nemaireeducând": "reeduca",
    "nemaireeducându": "reeduca",
    "nereeducând": "reeduca",
    "nereeducându": "reeduca",
    "reeduc": "reeduca",
    "reeducă": "reeduca",
    "reeducai": "reeduca",
    "reeducam": "reeduca",
    "reeducăm": "reeduca",
    "reeducând": "reeduca",
    "reeducându": "reeduca",
    "reeducară": "reeduca",
    "reeducarăm": "reeduca",
    "reeducarăți": "reeduca",
    "reeducase": "reeduca",
    "reeducasem": "reeduca",
    "reeducaseră": "reeduca",
    "reeducaserăm": "reeduca",
    "reeducaserăți": "reeduca",
    "reeducaseși": "reeduca",
    "reeducași": "reeduca",
    "reeducat": "reeduca",
    "reeducați": "reeduca",
    "reeducau": "reeduca",
    "reeduce": "reeduca",
    "reeduci": "reeduca",
    "reeducarea": "reeducare",
    "reeducareo": "reeducare",
    "reeducări": "reeducare",
    "reeducării": "reeducare",
    "reeducările": "reeducare",
    "reeducărilor": "reeducare",
    "reeducată": "reeducat",
    "reeducate": "reeducat",
    "reeducați": "reeducat",
    "reeligibila": "reeligibil",
    "reeligibilă": "reeligibil",
    "reeligibile": "reeligibil",
    "reeligibilei": "reeligibil",
    "reeligibilele": "reeligibil",
    "reeligibilelor": "reeligibil",
    "reeligibili": "reeligibil",
    "reeligibilii": "reeligibil",
    "reeligibililor": "reeligibil",
    "reeligibilul": "reeligibil",
    "reeligibilului": "reeligibil",
    "reescontul": "reescont",
    "reescontului": "reescont",
    "reesconturi": "reescont",
    "reesconturile": "reescont",
    "reesconturilor": "reescont",
    "reevaluarea": "reevaluare",
    "reevaluări": "reevaluare",
    "reevaluării": "reevaluare",
    "reevaluările": "reevaluare",
    "reevaluărilor": "reevaluare",
    "nemaireexaminând": "reexamina",
    "nemaireexaminându": "reexamina",
    "nereexaminând": "reexamina",
    "nereexaminându": "reexamina",
    "reexamină": "reexamina",
    "reexaminai": "reexamina",
    "reexaminam": "reexamina",
    "reexaminăm": "reexamina",
    "reexaminând": "reexamina",
    "reexaminându": "reexamina",
    "reexaminară": "reexamina",
    "reexaminarăm": "reexamina",
    "reexaminarăți": "reexamina",
    "reexaminase": "reexamina",
    "reexaminasem": "reexamina",
    "reexaminaseră": "reexamina",
    "reexaminaserăm": "reexamina",
    "reexaminaserăți": "reexamina",
    "reexaminaseși": "reexamina",
    "reexaminași": "reexamina",
    "reexaminat": "reexamina",
    "reexaminați": "reexamina",
    "reexaminau": "reexamina",
    "reexaminează": "reexamina",
    "reexaminez": "reexamina",
    "reexamineze": "reexamina",
    "reexaminezi": "reexamina",
    "reexaminarea": "reexaminare",
    "reexaminareo": "reexaminare",
    "reexaminări": "reexaminare",
    "reexaminării": "reexaminare",
    "reexaminările": "reexaminare",
    "reexaminărilor": "reexaminare",
    "reexaminată": "reexaminat",
    "reexaminate": "reexaminat",
    "reexaminați": "reexaminat",
    "nemairefăcând": "reface",
    "nemairefăcându": "reface",
    "nerefăcând": "reface",
    "nerefăcându": "reface",
    "refă": "reface",
    "refac": "reface",
    "refacă": "reface",
    "refăcând": "reface",
    "refăcându": "reface",
    "refăcea": "reface",
    "refăceai": "reface",
    "refăceam": "reface",
    "refăceați": "reface",
    "refăceau": "reface",
    "refacem": "reface",
    "refaceți": "reface",
    "refaci": "reface",
    "refăcu": "reface",
    "refăcui": "reface",
    "refăcură": "reface",
    "refăcurăm": "reface",
    "refăcurăți": "reface",
    "refăcuse": "reface",
    "refăcusem": "reface",
    "refăcuseră": "reface",
    "refăcuserăm": "reface",
    "refăcuserăți": "reface",
    "refăcuseși": "reface",
    "refăcuși": "reface",
    "refăcut": "reface",
    "refacerea": "refacere",
    "refacereo": "refacere",
    "refaceri": "refacere",
    "refacerii": "refacere",
    "refacerile": "refacere",
    "refacerilor": "refacere",
    "refăcută": "refăcut",
    "refăcute": "refăcut",
    "refăcuți": "refăcut",
    "refecul": "refec",
    "refecului": "refec",
    "refecuri": "refec",
    "refecurile": "refec",
    "refecurilor": "refec",
    "referate": "referat",
    "referatele": "referat",
    "referatelor": "referat",
    "referatul": "referat",
    "referatului": "referat",
    "referendumul": "referendum",
    "referendumului": "referendum",
    "referendumuri": "referendum",
    "referendumurile": "referendum",
    "referendumurilor": "referendum",
    "referenți": "referent",
    "referenții": "referent",
    "referenților": "referent",
    "referentul": "referent",
    "referentului": "referent",
    "nemaireferind": "referi",
    "nemaireferindu": "referi",
    "nereferind": "referi",
    "nereferindu": "referi",
    "refer": "referi",
    "referă": "referi",
    "refere": "referi",
    "referea": "referi",
    "refereai": "referi",
    "refeream": "referi",
    "refereați": "referi",
    "refereau": "referi",
    "referii": "referi",
    "referim": "referi",
    "referind": "referi",
    "referindu": "referi",
    "referiră": "referi",
    "referirăm": "referi",
    "referirăți": "referi",
    "referise": "referi",
    "referisem": "referi",
    "referiseră": "referi",
    "referiserăm": "referi",
    "referiserăți": "referi",
    "referiseși": "referi",
    "referiși": "referi",
    "referit": "referi",
    "referiți": "referi",
    "referința": "referință",
    "referințe": "referință",
    "referinței": "referință",
    "referințele": "referință",
    "referințelor": "referință",
    "referirea": "referire",
    "referireo": "referire",
    "referiri": "referire",
    "referirii": "referire",
    "referirile": "referire",
    "referirilor": "referire",
    "referită": "referit",
    "referite": "referit",
    "referiți": "referit",
    "referitoare": "referitor",
    "referitoarea": "referitor",
    "referitoarei": "referitor",
    "referitoarele": "referitor",
    "referitoarelor": "referitor",
    "referitoareo": "referitor",
    "referitori": "referitor",
    "referitorii": "referitor",
    "referitorilor": "referitor",
    "referitorul": "referitor",
    "referitorului": "referitor",
    "reflectă": "reflecta",
    "reflectai": "reflecta",
    "reflectam": "reflecta",
    "reflectăm": "reflecta",
    "reflectând": "reflecta",
    "reflectându": "reflecta",
    "reflectară": "reflecta",
    "reflectarăm": "reflecta",
    "reflectarăți": "reflecta",
    "reflectase": "reflecta",
    "reflectasem": "reflecta",
    "reflectaseră": "reflecta",
    "reflectaserăm": "reflecta",
    "reflectaserăți": "reflecta",
    "reflectaseși": "reflecta",
    "reflectași": "reflecta",
    "reflectat": "reflecta",
    "reflectați": "reflecta",
    "reflectatu": "reflecta",
    "reflectau": "reflecta",
    "reflectează": "reflecta",
    "reflectez": "reflecta",
    "reflecteze": "reflecta",
    "reflectezi": "reflecta",
    "reflectarea": "reflectare",
    "reflectări": "reflectare",
    "reflectării": "reflectare",
    "reflectările": "reflectare",
    "reflectărilor": "reflectare",
    "reflectată": "reflectat",
    "reflectate": "reflectat",
    "reflectați": "reflectat",
    "reflecția": "reflecție",
    "reflecției": "reflecție",
    "reflecții": "reflecție",
    "reflecțiile": "reflecție",
    "reflecțiilor": "reflecție",
    "reflectoare": "reflector",
    "reflectoarele": "reflector",
    "reflectoarelor": "reflector",
    "reflectorul": "reflector",
    "reflectorului": "reflector",
    "reflecși": "reflex",
    "reflecșii": "reflex",
    "reflecșilor": "reflex",
    "reflexa": "reflex",
    "reflexă": "reflex",
    "reflexe": "reflex",
    "reflexei": "reflex",
    "reflexele": "reflex",
    "reflexelor": "reflex",
    "reflexul": "reflex",
    "reflexului": "reflex",
    "reflexia": "reflexie",
    "reflexiei": "reflexie",
    "reflexii": "reflexie",
    "reflexiile": "reflexie",
    "reflexiilor": "reflexie",
    "refl.": "reflexiv",
    "reflexiva": "reflexiv",
    "reflexivă": "reflexiv",
    "reflexive": "reflexiv",
    "reflexivei": "reflexiv",
    "reflexivele": "reflexiv",
    "reflexivelor": "reflexiv",
    "reflexivi": "reflexiv",
    "reflexivii": "reflexiv",
    "reflexivilor": "reflexiv",
    "reflexivul": "reflexiv",
    "reflexivului": "reflexiv",
    "reflexivitatea": "reflexivitate",
    "reflexivități": "reflexivitate",
    "reflexivității": "reflexivitate",
    "reflexivitățile": "reflexivitate",
    "reflexivităților": "reflexivitate",
    "refluxul": "reflux",
    "refluxului": "reflux",
    "refluxuri": "reflux",
    "refluxurile": "reflux",
    "refluxurilor": "reflux",
    "nemaireformând": "reforma",
    "nemaireformându": "reforma",
    "nereformând": "reforma",
    "nereformându": "reforma",
    "reformă": "reforma",
    "reformai": "reforma",
    "reformam": "reforma",
    "reformăm": "reforma",
    "reformând": "reforma",
    "reformându": "reforma",
    "reformară": "reforma",
    "reformarăm": "reforma",
    "reformarăți": "reforma",
    "reformase": "reforma",
    "reformasem": "reforma",
    "reformaseră": "reforma",
    "reformaserăm": "reforma",
    "reformaserăți": "reforma",
    "reformaseși": "reforma",
    "reformași": "reforma",
    "reformat": "reforma",
    "reformați": "reforma",
    "reformau": "reforma",
    "reformează": "reforma",
    "reformez": "reforma",
    "reformeze": "reforma",
    "reformezi": "reforma",
    "reforma": "reformă",
    "reforme": "reformă",
    "reformei": "reformă",
    "reformele": "reformă",
    "reformelor": "reformă",
    "reformată": "reformat",
    "reformate": "reformat",
    "reformați": "reformat",
    "reformatoare": "reformator",
    "reformatoarea": "reformator",
    "reformatoarei": "reformator",
    "reformatoarele": "reformator",
    "reformatoarelor": "reformator",
    "reformatori": "reformator",
    "reformatorii": "reformator",
    "reformatorilor": "reformator",
    "reformatorul": "reformator",
    "reformatorului": "reformator",
    "reformista": "reformist",
    "reformistă": "reformist",
    "reformiste": "reformist",
    "reformistei": "reformist",
    "reformistele": "reformist",
    "reformistelor": "reformist",
    "reformiști": "reformist",
    "reformiștii": "reformist",
    "reformiștilor": "reformist",
    "reformistul": "reformist",
    "reformistului": "reformist",
    "reformulă": "reformula",
    "reformulai": "reformula",
    "reformulam": "reformula",
    "reformulăm": "reformula",
    "reformulând": "reformula",
    "reformulându": "reformula",
    "reformulară": "reformula",
    "reformularăm": "reformula",
    "reformularăți": "reformula",
    "reformulase": "reformula",
    "reformulasem": "reformula",
    "reformulaseră": "reformula",
    "reformulaserăm": "reformula",
    "reformulaserăți": "reformula",
    "reformulaseși": "reformula",
    "reformulași": "reformula",
    "reformulat": "reformula",
    "reformulați": "reformula",
    "reformulatu": "reformula",
    "reformulau": "reformula",
    "reformulează": "reformula",
    "reformulez": "reformula",
    "reformuleze": "reformula",
    "reformulezi": "reformula",
    "reformulată": "reformulat",
    "reformulate": "reformulat",
    "reformulați": "reformulat",
    "refractara": "refractar",
    "refractară": "refractar",
    "refractare": "refractar",
    "refractarei": "refractar",
    "refractarele": "refractar",
    "refractarelor": "refractar",
    "refractari": "refractar",
    "refractarii": "refractar",
    "refractarilor": "refractar",
    "refractarul": "refractar",
    "refractarului": "refractar",
    "refracția": "refracție",
    "refracției": "refracție",
    "refracții": "refracție",
    "refracțiile": "refracție",
    "refracțiilor": "refracție",
    "refrangibila": "refrangibil",
    "refrangibilă": "refrangibil",
    "refrangibile": "refrangibil",
    "refrangibilei": "refrangibil",
    "refrangibilele": "refrangibil",
    "refrangibilelor": "refrangibil",
    "refrangibili": "refrangibil",
    "refrangibilii": "refrangibil",
    "refrangibililor": "refrangibil",
    "refrangibilul": "refrangibil",
    "refrangibilului": "refrangibil",
    "refrene": "refren",
    "refrenele": "refren",
    "refrenelor": "refren",
    "refrenul": "refren",
    "refrenului": "refren",
    "nemairefrigerând": "refrigera",
    "nemairefrigerându": "refrigera",
    "nerefrigerând": "refrigera",
    "nerefrigerându": "refrigera",
    "refrigeră": "refrigera",
    "refrigerai": "refrigera",
    "refrigeram": "refrigera",
    "refrigerăm": "refrigera",
    "refrigerând": "refrigera",
    "refrigerându": "refrigera",
    "refrigerară": "refrigera",
    "refrigerarăm": "refrigera",
    "refrigerarăți": "refrigera",
    "refrigerase": "refrigera",
    "refrigerasem": "refrigera",
    "refrigeraseră": "refrigera",
    "refrigeraserăm": "refrigera",
    "refrigeraserăți": "refrigera",
    "refrigeraseși": "refrigera",
    "refrigerași": "refrigera",
    "refrigerat": "refrigera",
    "refrigerați": "refrigera",
    "refrigerau": "refrigera",
    "refrigerează": "refrigera",
    "refrigerez": "refrigera",
    "refrigereze": "refrigera",
    "refrigerezi": "refrigera",
    "refrigerarea": "refrigerare",
    "refrigerareo": "refrigerare",
    "refrigerări": "refrigerare",
    "refrigerării": "refrigerare",
    "refrigerările": "refrigerare",
    "refrigerărilor": "refrigerare",
    "refrigerată": "refrigerat",
    "refrigerate": "refrigerat",
    "refrigerați": "refrigerat",
    "refrigeratoare": "refrigerator",
    "refrigeratoarele": "refrigerator",
    "refrigeratoarelor": "refrigerator",
    "refrigeratorul": "refrigerator",
    "refrigeratorului": "refrigerator",
    "refrigerenta": "refrigerent",
    "refrigerentă": "refrigerent",
    "refrigerente": "refrigerent",
    "refrigerentei": "refrigerent",
    "refrigerentele": "refrigerent",
    "refrigerentelor": "refrigerent",
    "refrigerenți": "refrigerent",
    "refrigerenții": "refrigerent",
    "refrigerenților": "refrigerent",
    "refrigerentul": "refrigerent",
    "refrigerentului": "refrigerent",
    "nemairefugiind": "refugia",
    "nemairefugiindu": "refugia",
    "nerefugiind": "refugia",
    "nerefugiindu": "refugia",
    "refugiai": "refugia",
    "refugiam": "refugia",
    "refugiară": "refugia",
    "refugiarăm": "refugia",
    "refugiarăți": "refugia",
    "refugiase": "refugia",
    "refugiasem": "refugia",
    "refugiaseră": "refugia",
    "refugiaserăm": "refugia",
    "refugiaserăți": "refugia",
    "refugiaseși": "refugia",
    "refugiași": "refugia",
    "refugiat": "refugia",
    "refugiați": "refugia",
    "refugiau": "refugia",
    "refugiază": "refugia",
    "refugie": "refugia",
    "refugiem": "refugia",
    "refugiez": "refugia",
    "refugieze": "refugia",
    "refugiezi": "refugia",
    "refugiind": "refugia",
    "refugiindu": "refugia",
    "refugiată": "refugiat",
    "refugiate": "refugiat",
    "refugiați": "refugiat",
    "refugii": "refugiu",
    "refugiile": "refugiu",
    "refugiilor": "refugiu",
    "refugiul": "refugiu",
    "refugiului": "refugiu",
    "nemairefulând": "refula",
    "nemairefulându": "refula",
    "nerefulând": "refula",
    "nerefulându": "refula",
    "refulă": "refula",
    "refulai": "refula",
    "refulam": "refula",
    "refulăm": "refula",
    "refulând": "refula",
    "refulându": "refula",
    "refulară": "refula",
    "refularăm": "refula",
    "refularăți": "refula",
    "refulase": "refula",
    "refulasem": "refula",
    "refulaseră": "refula",
    "refulaserăm": "refula",
    "refulaserăți": "refula",
    "refulaseși": "refula",
    "refulași": "refula",
    "refulat": "refula",
    "refulați": "refula",
    "refulau": "refula",
    "refulează": "refula",
    "refulez": "refula",
    "refuleze": "refula",
    "refulezi": "refula",
    "refulată": "refulat",
    "refulate": "refulat",
    "refulați": "refulat",
    "refuzul": "refuz",
    "refuzului": "refuz",
    "refuzuri": "refuz",
    "refuzurile": "refuz",
    "refuzurilor": "refuz",
    "nemairefuzând": "refuza",
    "nemairefuzându": "refuza",
    "nerefuzând": "refuza",
    "nerefuzându": "refuza",
    "refuz": "refuza",
    "refuză": "refuza",
    "refuzai": "refuza",
    "refuzam": "refuza",
    "refuzăm": "refuza",
    "refuzând": "refuza",
    "refuzându": "refuza",
    "refuzară": "refuza",
    "refuzarăm": "refuza",
    "refuzarăți": "refuza",
    "refuzase": "refuza",
    "refuzasem": "refuza",
    "refuzaseră": "refuza",
    "refuzaserăm": "refuza",
    "refuzaserăți": "refuza",
    "refuzaseși": "refuza",
    "refuzași": "refuza",
    "refuzat": "refuza",
    "refuzați": "refuza",
    "refuzau": "refuza",
    "refuze": "refuza",
    "refuzi": "refuza",
    "refuzarea": "refuzare",
    "refuzareo": "refuzare",
    "refuzări": "refuzare",
    "refuzării": "refuzare",
    "refuzările": "refuzare",
    "refuzărilor": "refuzare",
    "refuzată": "refuzat",
    "refuzate": "refuzat",
    "refuzați": "refuzat",
    "regala": "regal",
    "regală": "regal",
    "regale": "regal",
    "regalei": "regal",
    "regalele": "regal",
    "regalelor": "regal",
    "regali": "regal",
    "regalii": "regal",
    "regalilor": "regal",
    "regalul": "regal",
    "regalului": "regal",
    "regaluri": "regal",
    "regalurile": "regal",
    "regalurilor": "regal",
    "regalista": "regalist",
    "regalistă": "regalist",
    "regaliste": "regalist",
    "regalistei": "regalist",
    "regalistele": "regalist",
    "regalistelor": "regalist",
    "regaliști": "regalist",
    "regaliștii": "regalist",
    "regaliștilor": "regalist",
    "regalistul": "regalist",
    "regalistului": "regalist",
    "regalista": "regalistă",
    "regaliste": "regalistă",
    "regalistei": "regalistă",
    "regalistele": "regalistă",
    "regalistelor": "regalistă",
    "regalitatea": "regalitate",
    "regalități": "regalitate",
    "regalității": "regalitate",
    "regalitățile": "regalitate",
    "regalităților": "regalitate",
    "regândirea": "regândire",
    "regândiri": "regândire",
    "regândirii": "regândire",
    "regândirile": "regândire",
    "regândirilor": "regândire",
    "nemairegăsind": "regăsi",
    "nemairegăsindu": "regăsi",
    "neregăsind": "regăsi",
    "neregăsindu": "regăsi",
    "regăsea": "regăsi",
    "regăseai": "regăsi",
    "regăseam": "regăsi",
    "regăsească": "regăsi",
    "regăseați": "regăsi",
    "regăseau": "regăsi",
    "regăsesc": "regăsi",
    "regăsește": "regăsi",
    "regăsești": "regăsi",
    "regăsii": "regăsi",
    "regăsim": "regăsi",
    "regăsind": "regăsi",
    "regăsindu": "regăsi",
    "regăsiră": "regăsi",
    "regăsirăm": "regăsi",
    "regăsirăți": "regăsi",
    "regăsise": "regăsi",
    "regăsisem": "regăsi",
    "regăsiseră": "regăsi",
    "regăsiserăm": "regăsi",
    "regăsiserăți": "regăsi",
    "regăsiseși": "regăsi",
    "regăsiși": "regăsi",
    "regăsit": "regăsi",
    "regăsiți": "regăsi",
    "regăsirea": "regăsire",
    "regăsiri": "regăsire",
    "regăsirii": "regăsire",
    "regăsirile": "regăsire",
    "regăsirilor": "regăsire",
    "regăsită": "regăsit",
    "regăsite": "regăsit",
    "regăsiți": "regăsit",
    "regate": "regat",
    "regatele": "regat",
    "regatelor": "regat",
    "regatul": "regat",
    "regatului": "regat",
    "Regatei": "Regata",
    "regata": "regată",
    "regate": "regată",
    "regatei": "regată",
    "regatele": "regată",
    "regatelor": "regată",
    "regățeana": "regățean",
    "regățeană": "regățean",
    "regățeanul": "regățean",
    "regățeanului": "regățean",
    "regățene": "regățean",
    "regățenei": "regățean",
    "regățenele": "regățean",
    "regățenelor": "regățean",
    "regățeni": "regățean",
    "regățenii": "regățean",
    "regățenilor": "regățean",
    "regățeanca": "regățeancă",
    "regățence": "regățeancă",
    "regățencei": "regățeancă",
    "regățencele": "regățeancă",
    "regățencelor": "regățeancă",
    "regele": "rege",
    "regelui": "rege",
    "regi": "rege",
    "regii": "rege",
    "regilor": "rege",
    "nemairegenerând": "regenera",
    "nemairegenerându": "regenera",
    "neregenerând": "regenera",
    "neregenerându": "regenera",
    "regeneră": "regenera",
    "regenerai": "regenera",
    "regeneram": "regenera",
    "regenerăm": "regenera",
    "regenerând": "regenera",
    "regenerându": "regenera",
    "regenerară": "regenera",
    "regenerarăm": "regenera",
    "regenerarăți": "regenera",
    "regenerase": "regenera",
    "regenerasem": "regenera",
    "regeneraseră": "regenera",
    "regeneraserăm": "regenera",
    "regeneraserăți": "regenera",
    "regeneraseși": "regenera",
    "regenerași": "regenera",
    "regenerat": "regenera",
    "regenerați": "regenera",
    "regenerau": "regenera",
    "regenerează": "regenera",
    "regenerez": "regenera",
    "regenereze": "regenera",
    "regenerezi": "regenera",
    "regenerarea": "regenerare",
    "regenerări": "regenerare",
    "regenerării": "regenerare",
    "regenerările": "regenerare",
    "regenerată": "regenerat",
    "regenerate": "regenerat",
    "regenerați": "regenerat",
    "regeneratoare": "regenerator",
    "regeneratoarea": "regenerator",
    "regeneratoarei": "regenerator",
    "regeneratoarele": "regenerator",
    "regeneratoarelor": "regenerator",
    "regeneratori": "regenerator",
    "regeneratorii": "regenerator",
    "regeneratorilor": "regenerator",
    "regeneratorul": "regenerator",
    "regeneratorului": "regenerator",
    "regenta": "regent",
    "regentă": "regent",
    "regente": "regent",
    "regentei": "regent",
    "regentele": "regent",
    "regentelor": "regent",
    "regenți": "regent",
    "regenții": "regent",
    "regenților": "regent",
    "regentul": "regent",
    "regentului": "regent",
    "regeasca": "regesc",
    "regească": "regesc",
    "regescul": "regesc",
    "regescului": "regesc",
    "regești": "regesc",
    "regeștii": "regesc",
    "regeștile": "regesc",
    "regeștilor": "regesc",
    "RATB": "Regia_Autonomă_de_Transport_București",
    "RENEL": "Regia_Națională_de_Electricitate",
    "regia": "regie",
    "regiei": "regie",
    "regii": "regie",
    "regiile": "regie",
    "regiilor": "regie",
    "R.A.": "Regie_Autonomă",
    "RA": "Regie_Autonomă",
    "regimul": "regim",
    "regimului": "regim",
    "regimuri": "regim",
    "regimurile": "regim",
    "regimurilor": "regim",
    "regimente": "regiment",
    "regimentele": "regiment",
    "regimentelor": "regiment",
    "regimentul": "regiment",
    "regimentului": "regiment",
    "Reginei": "Regina",
    "regina": "regină",
    "regine": "regină",
    "reginei": "regină",
    "reginele": "regină",
    "reginelor": "regină",
    "reg.": "regional",
    "regionala": "regional",
    "regională": "regional",
    "regionale": "regional",
    "regionalei": "regional",
    "regionalele": "regional",
    "regionalelor": "regional",
    "regionali": "regional",
    "regionalii": "regional",
    "regionalilor": "regional",
    "regionalul": "regional",
    "regionalului": "regional",
    "regionalisme": "regionalism",
    "regionalismele": "regionalism",
    "regionalismelor": "regionalism",
    "regionalismul": "regionalism",
    "regionalismului": "regionalism",
    "regionalista": "regionalist",
    "regionalistă": "regionalist",
    "regionaliste": "regionalist",
    "regionalistei": "regionalist",
    "regionalistele": "regionalist",
    "regionalistelor": "regionalist",
    "regionaliști": "regionalist",
    "regionaliștii": "regionalist",
    "regionaliștilor": "regionalist",
    "regionalistul": "regionalist",
    "regionalistului": "regionalist",
    "registratoarea": "registratoare",
    "registratoarei": "registratoare",
    "registratoarele": "registratoare",
    "registratoarelor": "registratoare",
    "registratori": "registrator",
    "registratorii": "registrator",
    "registratorilor": "registrator",
    "registratorul": "registrator",
    "registratorului": "registrator",
    "registratura": "registratură",
    "registraturi": "registratură",
    "registraturii": "registratură",
    "registraturile": "registratură",
    "registraturilor": "registratură",
    "registre": "registru",
    "registrele": "registru",
    "registrelor": "registru",
    "registrul": "registru",
    "registrului": "registru",
    "regiunea": "regiune",
    "regiuni": "regiune",
    "regiunii": "regiune",
    "regiunile": "regiune",
    "regiunilor": "regiune",
    "nemairegizând": "regiza",
    "nemairegizându": "regiza",
    "neregizând": "regiza",
    "neregizându": "regiza",
    "regiză": "regiza",
    "regizai": "regiza",
    "regizam": "regiza",
    "regizăm": "regiza",
    "regizând": "regiza",
    "regizându": "regiza",
    "regizară": "regiza",
    "regizarăm": "regiza",
    "regizarăți": "regiza",
    "regizase": "regiza",
    "regizasem": "regiza",
    "regizaseră": "regiza",
    "regizaserăm": "regiza",
    "regizaserăți": "regiza",
    "regizaseși": "regiza",
    "regizași": "regiza",
    "regizat": "regiza",
    "regizați": "regiza",
    "regizau": "regiza",
    "regizează": "regiza",
    "regizez": "regiza",
    "regizeze": "regiza",
    "regizezi": "regiza",
    "regizată": "regizat",
    "regizate": "regizat",
    "regizați": "regizat",
    "regizori": "regizor",
    "regizorii": "regizor",
    "regizorilor": "regizor",
    "regizorul": "regizor",
    "regizorului": "regizor",
    "regizorala": "regizoral",
    "regizorală": "regizoral",
    "regizorale": "regizoral",
    "regizoralei": "regizoral",
    "regizoralele": "regizoral",
    "regizoralelor": "regizoral",
    "regizorali": "regizoral",
    "regizoralii": "regizoral",
    "regizoralilor": "regizoral",
    "regizoralul": "regizoral",
    "regizoralului": "regizoral",
    "nemaireglând": "regla",
    "nemaireglându": "regla",
    "nereglând": "regla",
    "nereglându": "regla",
    "reglă": "regla",
    "reglai": "regla",
    "reglam": "regla",
    "reglăm": "regla",
    "reglând": "regla",
    "reglându": "regla",
    "reglară": "regla",
    "reglarăm": "regla",
    "reglarăți": "regla",
    "reglase": "regla",
    "reglasem": "regla",
    "reglaseră": "regla",
    "reglaserăm": "regla",
    "reglaserăți": "regla",
    "reglaseși": "regla",
    "reglași": "regla",
    "reglat": "regla",
    "reglați": "regla",
    "reglau": "regla",
    "reglează": "regla",
    "reglez": "regla",
    "regleze": "regla",
    "reglezi": "regla",
    "reglaje": "reglaj",
    "reglajele": "reglaj",
    "reglajelor": "reglaj",
    "reglajul": "reglaj",
    "reglajului": "reglaj",
    "reglarea": "reglare",
    "reglareo": "reglare",
    "reglări": "reglare",
    "reglării": "reglare",
    "reglările": "reglare",
    "reglărilor": "reglare",
    "reglată": "reglat",
    "reglate": "reglat",
    "reglați": "reglat",
    "nemaireglementând": "reglementa",
    "nemaireglementându": "reglementa",
    "nereglementând": "reglementa",
    "nereglementându": "reglementa",
    "reglementă": "reglementa",
    "reglementai": "reglementa",
    "reglementam": "reglementa",
    "reglementăm": "reglementa",
    "reglementând": "reglementa",
    "reglementându": "reglementa",
    "reglementară": "reglementa",
    "reglementarăm": "reglementa",
    "reglementarăți": "reglementa",
    "reglementase": "reglementa",
    "reglementasem": "reglementa",
    "reglementaseră": "reglementa",
    "reglementaserăm": "reglementa",
    "reglementaserăți": "reglementa",
    "reglementaseși": "reglementa",
    "reglementași": "reglementa",
    "reglementat": "reglementa",
    "reglementați": "reglementa",
    "reglementau": "reglementa",
    "reglementează": "reglementa",
    "reglementez": "reglementa",
    "reglementeze": "reglementa",
    "reglementezi": "reglementa",
    "reglementara": "reglementar",
    "reglementară": "reglementar",
    "reglementare": "reglementar",
    "reglementarei": "reglementar",
    "reglementarele": "reglementar",
    "reglementarelor": "reglementar",
    "reglementari": "reglementar",
    "reglementarii": "reglementar",
    "reglementarilor": "reglementar",
    "reglementarul": "reglementar",
    "reglementarului": "reglementar",
    "reglementarea": "reglementare",
    "reglementareo": "reglementare",
    "reglementări": "reglementare",
    "reglementării": "reglementare",
    "reglementările": "reglementare",
    "reglementărilor": "reglementare",
    "reglementată": "reglementat",
    "reglementate": "reglementat",
    "reglementați": "reglementat",
    "regnul": "regn",
    "regnului": "regn",
    "regnuri": "regn",
    "regnurile": "regn",
    "regnurilor": "regn",
    "regrese": "regres",
    "regresele": "regres",
    "regreselor": "regres",
    "regresul": "regres",
    "regresului": "regres",
    "nemairegresând": "regresa",
    "nemairegresându": "regresa",
    "neregresând": "regresa",
    "neregresându": "regresa",
    "regresă": "regresa",
    "regresai": "regresa",
    "regresam": "regresa",
    "regresăm": "regresa",
    "regresând": "regresa",
    "regresându": "regresa",
    "regresară": "regresa",
    "regresarăm": "regresa",
    "regresarăți": "regresa",
    "regresase": "regresa",
    "regresasem": "regresa",
    "regresaseră": "regresa",
    "regresaserăm": "regresa",
    "regresaserăți": "regresa",
    "regresaseși": "regresa",
    "regresași": "regresa",
    "regresat": "regresa",
    "regresați": "regresa",
    "regresau": "regresa",
    "regresează": "regresa",
    "regresez": "regresa",
    "regreseze": "regresa",
    "regresezi": "regresa",
    "regresată": "regresat",
    "regresate": "regresat",
    "regresați": "regresat",
    "regresiva": "regresiv",
    "regresivă": "regresiv",
    "regresive": "regresiv",
    "regresivei": "regresiv",
    "regresivele": "regresiv",
    "regresivelor": "regresiv",
    "regresivi": "regresiv",
    "regresivii": "regresiv",
    "regresivilor": "regresiv",
    "regresivul": "regresiv",
    "regresivului": "regresiv",
    "regrete": "regret",
    "regretele": "regret",
    "regretelor": "regret",
    "regretul": "regret",
    "regretului": "regret",
    "nemairegretând": "regreta",
    "nemairegretându": "regreta",
    "neregretând": "regreta",
    "neregretându": "regreta",
    "regret": "regreta",
    "regretă": "regreta",
    "regretai": "regreta",
    "regretam": "regreta",
    "regretăm": "regreta",
    "regretând": "regreta",
    "regretându": "regreta",
    "regretară": "regreta",
    "regretarăm": "regreta",
    "regretarăți": "regreta",
    "regretase": "regreta",
    "regretasem": "regreta",
    "regretaseră": "regreta",
    "regretaserăm": "regreta",
    "regretaserăți": "regreta",
    "regretaseși": "regreta",
    "regretași": "regreta",
    "regretat": "regreta",
    "regretați": "regreta",
    "regretau": "regreta",
    "regrete": "regreta",
    "regreți": "regreta",
    "regretabila": "regretabil",
    "regretabilă": "regretabil",
    "regretabile": "regretabil",
    "regretabilei": "regretabil",
    "regretabilele": "regretabil",
    "regretabilelor": "regretabil",
    "regretabili": "regretabil",
    "regretabilii": "regretabil",
    "regretabililor": "regretabil",
    "regretabilul": "regretabil",
    "regretabilului": "regretabil",
    "regretată": "regretat",
    "regretate": "regretat",
    "regretați": "regretat",
    "nemairegrupând": "regrupa",
    "nemairegrupându": "regrupa",
    "neregrupând": "regrupa",
    "neregrupându": "regrupa",
    "regrupă": "regrupa",
    "regrupai": "regrupa",
    "regrupam": "regrupa",
    "regrupăm": "regrupa",
    "regrupând": "regrupa",
    "regrupându": "regrupa",
    "regrupară": "regrupa",
    "regruparăm": "regrupa",
    "regruparăți": "regrupa",
    "regrupase": "regrupa",
    "regrupasem": "regrupa",
    "regrupaseră": "regrupa",
    "regrupaserăm": "regrupa",
    "regrupaserăți": "regrupa",
    "regrupaseși": "regrupa",
    "regrupași": "regrupa",
    "regrupat": "regrupa",
    "regrupați": "regrupa",
    "regrupau": "regrupa",
    "regrupează": "regrupa",
    "regrupez": "regrupa",
    "regrupeze": "regrupa",
    "regrupezi": "regrupa",
    "regruparea": "regrupare",
    "regrupări": "regrupare",
    "regrupării": "regrupare",
    "regrupările": "regrupare",
    "regrupărilor": "regrupare",
    "regrupată": "regrupat",
    "regrupate": "regrupat",
    "regrupați": "regrupat",
    "nemairegulând": "regula",
    "nemairegulându": "regula",
    "neregulând": "regula",
    "neregulându": "regula",
    "regulă": "regula",
    "regulai": "regula",
    "regulam": "regula",
    "regulăm": "regula",
    "regulând": "regula",
    "regulându": "regula",
    "regulară": "regula",
    "regularăm": "regula",
    "regularăți": "regula",
    "regulase": "regula",
    "regulasem": "regula",
    "regulaseră": "regula",
    "regulaserăm": "regula",
    "regulaserăți": "regula",
    "regulaseși": "regula",
    "regulași": "regula",
    "regulat": "regula",
    "regulați": "regula",
    "regulau": "regula",
    "regulează": "regula",
    "regulez": "regula",
    "reguleze": "regula",
    "regulezi": "regula",
    "regula": "regulă",
    "reguli": "regulă",
    "regulii": "regulă",
    "regulile": "regulă",
    "regulilor": "regulă",
    "regulamente": "regulament",
    "regulamentele": "regulament",
    "regulamentelor": "regulament",
    "regulamentul": "regulament",
    "regulamentului": "regulament",
    "regulamentara": "regulamentar",
    "regulamentară": "regulamentar",
    "regulamentare": "regulamentar",
    "regulamentarei": "regulamentar",
    "regulamentarele": "regulamentar",
    "regulamentarelor": "regulamentar",
    "regulamentari": "regulamentar",
    "regulamentarii": "regulamentar",
    "regulamentarilor": "regulamentar",
    "regulamentarul": "regulamentar",
    "regulamentarului": "regulamentar",
    "regularea": "regulare",
    "regulareo": "regulare",
    "regulări": "regulare",
    "regulării": "regulare",
    "regulările": "regulare",
    "regulărilor": "regulare",
    "regularitatea": "regularitate",
    "regularități": "regularitate",
    "regularității": "regularitate",
    "regularitățile": "regularitate",
    "regularităților": "regularitate",
    "nemairegularizând": "regulariza",
    "nemairegularizându": "regulariza",
    "neregularizând": "regulariza",
    "neregularizându": "regulariza",
    "regulariză": "regulariza",
    "regularizai": "regulariza",
    "regularizam": "regulariza",
    "regularizăm": "regulariza",
    "regularizând": "regulariza",
    "regularizându": "regulariza",
    "regularizară": "regulariza",
    "regularizarăm": "regulariza",
    "regularizarăți": "regulariza",
    "regularizase": "regulariza",
    "regularizasem": "regulariza",
    "regularizaseră": "regulariza",
    "regularizaserăm": "regulariza",
    "regularizaserăți": "regulariza",
    "regularizaseși": "regulariza",
    "regularizași": "regulariza",
    "regularizat": "regulariza",
    "regularizați": "regulariza",
    "regularizau": "regulariza",
    "regularizează": "regulariza",
    "regularizez": "regulariza",
    "regularizeze": "regulariza",
    "regularizezi": "regulariza",
    "regularizată": "regularizat",
    "regularizate": "regularizat",
    "regularizați": "regularizat",
    "regulată": "regulat",
    "regulate": "regulat",
    "regulați": "regulat",
    "regurgitația": "regurgitație",
    "regurgitației": "regurgitație",
    "regurgitații": "regurgitație",
    "regurgitațiile": "regurgitație",
    "regurgitațiilor": "regurgitație",
    "reiata": "reiat",
    "reiată": "reiat",
    "reiate": "reiat",
    "reiatei": "reiat",
    "reiatele": "reiat",
    "reiatelor": "reiat",
    "reiați": "reiat",
    "reiații": "reiat",
    "reiaților": "reiat",
    "reiatul": "reiat",
    "reiatului": "reiat",
    "nemaireieșind": "reieși",
    "nemaireieșindu": "reieși",
    "nereieșind": "reieși",
    "nereieșindu": "reieși",
    "reiasă": "reieși",
    "reiese": "reieși",
    "reieșea": "reieși",
    "reieșeau": "reieși",
    "reieșind": "reieși",
    "reieșindu": "reieși",
    "reieșiră": "reieși",
    "reieșise": "reieși",
    "reieșiseră": "reieși",
    "reieșit": "reieși",
    "reieșită": "reieșit",
    "reieșite": "reieșit",
    "reieșiți": "reieșit",
    "nemaireîmpădurind": "reîmpăduri",
    "nemaireîmpădurindu": "reîmpăduri",
    "nereîmpădurind": "reîmpăduri",
    "nereîmpădurindu": "reîmpăduri",
    "reîmpădurea": "reîmpăduri",
    "reîmpădureai": "reîmpăduri",
    "reîmpăduream": "reîmpăduri",
    "reîmpădurească": "reîmpăduri",
    "reîmpădureați": "reîmpăduri",
    "reîmpădureau": "reîmpăduri",
    "reîmpăduresc": "reîmpăduri",
    "reîmpădurește": "reîmpăduri",
    "reîmpădurești": "reîmpăduri",
    "reîmpădurii": "reîmpăduri",
    "reîmpădurim": "reîmpăduri",
    "reîmpădurind": "reîmpăduri",
    "reîmpădurindu": "reîmpăduri",
    "reîmpăduriră": "reîmpăduri",
    "reîmpădurirăm": "reîmpăduri",
    "reîmpădurirăți": "reîmpăduri",
    "reîmpădurise": "reîmpăduri",
    "reîmpădurisem": "reîmpăduri",
    "reîmpăduriseră": "reîmpăduri",
    "reîmpăduriserăm": "reîmpăduri",
    "reîmpăduriserăți": "reîmpăduri",
    "reîmpăduriseși": "reîmpăduri",
    "reîmpăduriși": "reîmpăduri",
    "reîmpădurit": "reîmpăduri",
    "reîmpăduriți": "reîmpăduri",
    "reîmpădurită": "reîmpădurit",
    "reîmpădurite": "reîmpădurit",
    "reîmpăduriți": "reîmpădurit",
    "nemaireîmpărțind": "reîmpărți",
    "nemaireîmpărțindu": "reîmpărți",
    "nereîmpărțind": "reîmpărți",
    "nereîmpărțindu": "reîmpărți",
    "reîmpart": "reîmpărți",
    "reîmpartă": "reîmpărți",
    "reîmparte": "reîmpărți",
    "reîmpărțea": "reîmpărți",
    "reîmpărțeai": "reîmpărți",
    "reîmpărțeam": "reîmpărți",
    "reîmpărțeați": "reîmpărți",
    "reîmpărțeau": "reîmpărți",
    "reîmparți": "reîmpărți",
    "reîmpărții": "reîmpărți",
    "reîmpărțim": "reîmpărți",
    "reîmpărțind": "reîmpărți",
    "reîmpărțindu": "reîmpărți",
    "reîmpărțiră": "reîmpărți",
    "reîmpărțirăm": "reîmpărți",
    "reîmpărțirăți": "reîmpărți",
    "reîmpărțise": "reîmpărți",
    "reîmpărțisem": "reîmpărți",
    "reîmpărțiseră": "reîmpărți",
    "reîmpărțiserăm": "reîmpărți",
    "reîmpărțiserăți": "reîmpărți",
    "reîmpărțiseși": "reîmpărți",
    "reîmpărțiși": "reîmpărți",
    "reîmpărțit": "reîmpărți",
    "reîmpărțiți": "reîmpărți",
    "reîmpărțirea": "reîmpărțire",
    "reîmpărțiri": "reîmpărțire",
    "reîmpărțirii": "reîmpărțire",
    "reîmpărțirile": "reîmpărțire",
    "reîmpărțirilor": "reîmpărțire",
    "reîmpărțită": "reîmpărțit",
    "reîmpărțite": "reîmpărțit",
    "reîmpărțiți": "reîmpărțit",
    "reîmpletea": "reîmpleti",
    "reîmpleteai": "reîmpleti",
    "reîmpleteam": "reîmpleti",
    "reîmpletească": "reîmpleti",
    "reîmpleteați": "reîmpleti",
    "reîmpleteau": "reîmpleti",
    "reîmpletesc": "reîmpleti",
    "reîmpletește": "reîmpleti",
    "reîmpletești": "reîmpleti",
    "reîmpletii": "reîmpleti",
    "reîmpletim": "reîmpleti",
    "reîmpletind": "reîmpleti",
    "reîmpletindu": "reîmpleti",
    "reîmpletiră": "reîmpleti",
    "reîmpletirăm": "reîmpleti",
    "reîmpletirăți": "reîmpleti",
    "reîmpletise": "reîmpleti",
    "reîmpletisem": "reîmpleti",
    "reîmpletiseră": "reîmpleti",
    "reîmpletiserăm": "reîmpleti",
    "reîmpletiserăți": "reîmpleti",
    "reîmpletiseși": "reîmpleti",
    "reîmpletiși": "reîmpleti",
    "reîmpletit": "reîmpleti",
    "reîmpletiți": "reîmpleti",
    "reîmpletitu": "reîmpleti",
    "reîmpletită": "reîmpletit",
    "reîmpletite": "reîmpletit",
    "reîmpletiți": "reîmpletit",
    "nemaireîmprospătând": "reîmprospăta",
    "nemaireîmprospătându": "reîmprospăta",
    "nereîmprospătând": "reîmprospăta",
    "nereîmprospătându": "reîmprospăta",
    "reîmprospătă": "reîmprospăta",
    "reîmprospătai": "reîmprospăta",
    "reîmprospătam": "reîmprospăta",
    "reîmprospătăm": "reîmprospăta",
    "reîmprospătând": "reîmprospăta",
    "reîmprospătându": "reîmprospăta",
    "reîmprospătară": "reîmprospăta",
    "reîmprospătarăm": "reîmprospăta",
    "reîmprospătarăți": "reîmprospăta",
    "reîmprospătase": "reîmprospăta",
    "reîmprospătasem": "reîmprospăta",
    "reîmprospătaseră": "reîmprospăta",
    "reîmprospătaserăm": "reîmprospăta",
    "reîmprospătaserăți": "reîmprospăta",
    "reîmprospătaseși": "reîmprospăta",
    "reîmprospătași": "reîmprospăta",
    "reîmprospătat": "reîmprospăta",
    "reîmprospătați": "reîmprospăta",
    "reîmprospătau": "reîmprospăta",
    "reîmprospătează": "reîmprospăta",
    "reîmprospătez": "reîmprospăta",
    "reîmprospăteze": "reîmprospăta",
    "reîmprospătezi": "reîmprospăta",
    "reîmprospătată": "reîmprospătat",
    "reîmprospătate": "reîmprospătat",
    "reîmprospătați": "reîmprospătat",
    "nemaireînarmând": "reînarma",
    "nemaireînarmându": "reînarma",
    "nereînarmând": "reînarma",
    "nereînarmându": "reînarma",
    "reînarmă": "reînarma",
    "reînarmai": "reînarma",
    "reînarmam": "reînarma",
    "reînarmăm": "reînarma",
    "reînarmând": "reînarma",
    "reînarmându": "reînarma",
    "reînarmară": "reînarma",
    "reînarmarăm": "reînarma",
    "reînarmarăți": "reînarma",
    "reînarmase": "reînarma",
    "reînarmasem": "reînarma",
    "reînarmaseră": "reînarma",
    "reînarmaserăm": "reînarma",
    "reînarmaserăți": "reînarma",
    "reînarmaseși": "reînarma",
    "reînarmași": "reînarma",
    "reînarmat": "reînarma",
    "reînarmați": "reînarma",
    "reînarmau": "reînarma",
    "reînarmează": "reînarma",
    "reînarmez": "reînarma",
    "reînarmeze": "reînarma",
    "reînarmezi": "reînarma",
    "reînarmată": "reînarmat",
    "reînarmate": "reînarmat",
    "reînarmați": "reînarmat",
    "nemaireîncadrând": "reîncadra",
    "nemaireîncadrându": "reîncadra",
    "nereîncadrând": "reîncadra",
    "nereîncadrându": "reîncadra",
    "reîncadră": "reîncadra",
    "reîncadrai": "reîncadra",
    "reîncadram": "reîncadra",
    "reîncadrăm": "reîncadra",
    "reîncadrând": "reîncadra",
    "reîncadrându": "reîncadra",
    "reîncadrară": "reîncadra",
    "reîncadrarăm": "reîncadra",
    "reîncadrarăți": "reîncadra",
    "reîncadrase": "reîncadra",
    "reîncadrasem": "reîncadra",
    "reîncadraseră": "reîncadra",
    "reîncadraserăm": "reîncadra",
    "reîncadraserăți": "reîncadra",
    "reîncadraseși": "reîncadra",
    "reîncadrași": "reîncadra",
    "reîncadrat": "reîncadra",
    "reîncadrați": "reîncadra",
    "reîncadrau": "reîncadra",
    "reîncadrează": "reîncadra",
    "reîncadrez": "reîncadra",
    "reîncadreze": "reîncadra",
    "reîncadrezi": "reîncadra",
    "reîncadrarea": "reîncadrare",
    "reîncadrări": "reîncadrare",
    "reîncadrării": "reîncadrare",
    "reîncadrările": "reîncadrare",
    "reîncadrărilor": "reîncadrare",
    "reîncadrată": "reîncadrat",
    "reîncadrate": "reîncadrat",
    "reîncadrați": "reîncadrat",
    "nemaireincarnând": "reincarna",
    "nemaireincarnându": "reincarna",
    "nereincarnând": "reincarna",
    "nereincarnându": "reincarna",
    "reincarnă": "reincarna",
    "reincarnai": "reincarna",
    "reincarnam": "reincarna",
    "reincarnăm": "reincarna",
    "reincarnând": "reincarna",
    "reincarnându": "reincarna",
    "reincarnară": "reincarna",
    "reincarnarăm": "reincarna",
    "reincarnarăți": "reincarna",
    "reincarnase": "reincarna",
    "reincarnasem": "reincarna",
    "reincarnaseră": "reincarna",
    "reincarnaserăm": "reincarna",
    "reincarnaserăți": "reincarna",
    "reincarnaseși": "reincarna",
    "reincarnași": "reincarna",
    "reincarnat": "reincarna",
    "reincarnați": "reincarna",
    "reincarnau": "reincarna",
    "reincarnează": "reincarna",
    "reincarnez": "reincarna",
    "reincarneze": "reincarna",
    "reincarnezi": "reincarna",
    "reîncarnarea": "reîncarnare",
    "reîncarnări": "reîncarnare",
    "reîncarnării": "reîncarnare",
    "reîncarnările": "reîncarnare",
    "reîncarnărilor": "reîncarnare",
    "reincarnată": "reincarnat",
    "reincarnate": "reincarnat",
    "reincarnați": "reincarnat",
    "nemaireîncepând": "reîncepe",
    "nemaireîncepându": "reîncepe",
    "nereîncepând": "reîncepe",
    "nereîncepându": "reîncepe",
    "reînceapă": "reîncepe",
    "reîncep": "reîncepe",
    "reîncepând": "reîncepe",
    "reîncepându": "reîncepe",
    "reîncepea": "reîncepe",
    "reîncepeai": "reîncepe",
    "reîncepeam": "reîncepe",
    "reîncepeați": "reîncepe",
    "reîncepeau": "reîncepe",
    "reîncepem": "reîncepe",
    "reîncepeți": "reîncepe",
    "reîncepi": "reîncepe",
    "reîncepu": "reîncepe",
    "reîncepui": "reîncepe",
    "reîncepură": "reîncepe",
    "reîncepurăm": "reîncepe",
    "reîncepurăți": "reîncepe",
    "reîncepuse": "reîncepe",
    "reîncepusem": "reîncepe",
    "reîncepuseră": "reîncepe",
    "reîncepuserăm": "reîncepe",
    "reîncepuserăți": "reîncepe",
    "reîncepuseși": "reîncepe",
    "reîncepuși": "reîncepe",
    "reînceput": "reîncepe",
    "reîncepută": "reînceput",
    "reîncepute": "reînceput",
    "reîncepuți": "reînceput",
    "reincriminarea": "reincriminare",
    "reincriminări": "reincriminare",
    "reincriminării": "reincriminare",
    "reincriminările": "reincriminare",
    "nemaireînființând": "reînființa",
    "nemaireînființându": "reînființa",
    "nereînființând": "reînființa",
    "nereînființându": "reînființa",
    "reînființă": "reînființa",
    "reînființai": "reînființa",
    "reînființam": "reînființa",
    "reînființăm": "reînființa",
    "reînființând": "reînființa",
    "reînființându": "reînființa",
    "reînființară": "reînființa",
    "reînființarăm": "reînființa",
    "reînființarăți": "reînființa",
    "reînființase": "reînființa",
    "reînființasem": "reînființa",
    "reînființaseră": "reînființa",
    "reînființaserăm": "reînființa",
    "reînființaserăți": "reînființa",
    "reînființaseși": "reînființa",
    "reînființași": "reînființa",
    "reînființat": "reînființa",
    "reînființați": "reînființa",
    "reînființau": "reînființa",
    "reînființează": "reînființa",
    "reînființez": "reînființa",
    "reînființeze": "reînființa",
    "reînființezi": "reînființa",
    "reînființată": "reînființat",
    "reînființate": "reînființat",
    "reînființați": "reînființat",
    "reînnoadă": "reînnoda",
    "reînnoade": "reînnoda",
    "reînnod": "reînnoda",
    "reînnodă": "reînnoda",
    "reînnodai": "reînnoda",
    "reînnodam": "reînnoda",
    "reînnodăm": "reînnoda",
    "reînnodând": "reînnoda",
    "reînnodându": "reînnoda",
    "reînnodară": "reînnoda",
    "reînnodarăm": "reînnoda",
    "reînnodarăți": "reînnoda",
    "reînnodase": "reînnoda",
    "reînnodasem": "reînnoda",
    "reînnodaseră": "reînnoda",
    "reînnodaserăm": "reînnoda",
    "reînnodaserăți": "reînnoda",
    "reînnodaseși": "reînnoda",
    "reînnodași": "reînnoda",
    "reînnodat": "reînnoda",
    "reînnodați": "reînnoda",
    "reînnodatu": "reînnoda",
    "reînnodau": "reînnoda",
    "reînnozi": "reînnoda",
    "reînnodată": "reînnodat",
    "reînnodate": "reînnodat",
    "reînnodați": "reînnodat",
    "nemaireînnoind": "reînnoi",
    "nemaireînnoindu": "reînnoi",
    "nereînnoind": "reînnoi",
    "nereînnoindu": "reînnoi",
    "reînnoia": "reînnoi",
    "reînnoiai": "reînnoi",
    "reînnoiam": "reînnoi",
    "reînnoiască": "reînnoi",
    "reînnoiați": "reînnoi",
    "reînnoiau": "reînnoi",
    "reînnoiesc": "reînnoi",
    "reînnoiește": "reînnoi",
    "reînnoiești": "reînnoi",
    "reînnoii": "reînnoi",
    "reînnoim": "reînnoi",
    "reînnoind": "reînnoi",
    "reînnoindu": "reînnoi",
    "reînnoiră": "reînnoi",
    "reînnoirăm": "reînnoi",
    "reînnoirăți": "reînnoi",
    "reînnoise": "reînnoi",
    "reînnoisem": "reînnoi",
    "reînnoiseră": "reînnoi",
    "reînnoiserăm": "reînnoi",
    "reînnoiserăți": "reînnoi",
    "reînnoiseși": "reînnoi",
    "reînnoiși": "reînnoi",
    "reînnoit": "reînnoi",
    "reînnoiți": "reînnoi",
    "reînnoirea": "reînnoire",
    "reînnoireo": "reînnoire",
    "reînnoiri": "reînnoire",
    "reînnoirii": "reînnoire",
    "reînnoirile": "reînnoire",
    "reînnoirilor": "reînnoire",
    "reînnoita": "reînnoit",
    "reînnoită": "reînnoit",
    "reînnoite": "reînnoit",
    "reînnoitei": "reînnoit",
    "reînnoitele": "reînnoit",
    "reînnoitelor": "reînnoit",
    "reînnoiți": "reînnoit",
    "reînnoiții": "reînnoit",
    "reînnoiților": "reînnoit",
    "reînnoito": "reînnoit",
    "reînnoitul": "reînnoit",
    "reînnoitule": "reînnoit",
    "reînnoitului": "reînnoit",
    "reînsămânțarea": "reînsămânțare",
    "reînsămânțări": "reînsămânțare",
    "reînsămânțării": "reînsămânțare",
    "reînsămânțările": "reînsămânțare",
    "reînsămânțărilor": "reînsămânțare",
    "reinstală": "reinstala",
    "reinstalai": "reinstala",
    "reinstalam": "reinstala",
    "reinstalăm": "reinstala",
    "reinstalând": "reinstala",
    "reinstalându": "reinstala",
    "reinstalară": "reinstala",
    "reinstalarăm": "reinstala",
    "reinstalarăți": "reinstala",
    "reinstalase": "reinstala",
    "reinstalasem": "reinstala",
    "reinstalaseră": "reinstala",
    "reinstalaserăm": "reinstala",
    "reinstalaserăți": "reinstala",
    "reinstalaseși": "reinstala",
    "reinstalași": "reinstala",
    "reinstalat": "reinstala",
    "reinstalați": "reinstala",
    "reinstalatu": "reinstala",
    "reinstalau": "reinstala",
    "reinstalează": "reinstala",
    "reinstalez": "reinstala",
    "reinstaleze": "reinstala",
    "reinstalezi": "reinstala",
    "reinstalată": "reinstalat",
    "reinstalate": "reinstalat",
    "reinstalați": "reinstalat",
    "reinstaură": "reinstaura",
    "reinstaurai": "reinstaura",
    "reinstauram": "reinstaura",
    "reinstaurăm": "reinstaura",
    "reinstaurând": "reinstaura",
    "reinstaurându": "reinstaura",
    "reinstaurară": "reinstaura",
    "reinstaurarăm": "reinstaura",
    "reinstaurarăți": "reinstaura",
    "reinstaurase": "reinstaura",
    "reinstaurasem": "reinstaura",
    "reinstauraseră": "reinstaura",
    "reinstauraserăm": "reinstaura",
    "reinstauraserăți": "reinstaura",
    "reinstauraseși": "reinstaura",
    "reinstaurași": "reinstaura",
    "reinstaurat": "reinstaura",
    "reinstaurați": "reinstaura",
    "reinstauratu": "reinstaura",
    "reinstaurau": "reinstaura",
    "reinstaurează": "reinstaura",
    "reinstaurez": "reinstaura",
    "reinstaureze": "reinstaura",
    "reinstaurezi": "reinstaura",
    "reinstaurată": "reinstaurat",
    "reinstaurate": "reinstaurat",
    "reinstaurați": "reinstaurat",
    "nemaireînsuflețind": "reînsufleți",
    "nemaireînsuflețindu": "reînsufleți",
    "nereînsuflețind": "reînsufleți",
    "nereînsuflețindu": "reînsufleți",
    "reînsuflețea": "reînsufleți",
    "reînsuflețeai": "reînsufleți",
    "reînsuflețeam": "reînsufleți",
    "reînsuflețească": "reînsufleți",
    "reînsuflețeați": "reînsufleți",
    "reînsuflețeau": "reînsufleți",
    "reînsuflețesc": "reînsufleți",
    "reînsuflețește": "reînsufleți",
    "reînsuflețești": "reînsufleți",
    "reînsufleții": "reînsufleți",
    "reînsuflețim": "reînsufleți",
    "reînsuflețind": "reînsufleți",
    "reînsuflețindu": "reînsufleți",
    "reînsuflețiră": "reînsufleți",
    "reînsuflețirăm": "reînsufleți",
    "reînsuflețirăți": "reînsufleți",
    "reînsuflețise": "reînsufleți",
    "reînsuflețisem": "reînsufleți",
    "reînsuflețiseră": "reînsufleți",
    "reînsuflețiserăm": "reînsufleți",
    "reînsuflețiserăți": "reînsufleți",
    "reînsuflețiseși": "reînsufleți",
    "reînsuflețiși": "reînsufleți",
    "reînsuflețit": "reînsufleți",
    "reînsuflețiți": "reînsufleți",
    "reînsuflețită": "reînsuflețit",
    "reînsuflețite": "reînsuflețit",
    "reînsuflețiți": "reînsuflețit",
    "nemaireîntâlnind": "reîntâlni",
    "nemaireîntâlnindu": "reîntâlni",
    "nereîntâlnind": "reîntâlni",
    "nereîntâlnindu": "reîntâlni",
    "reîntâlnea": "reîntâlni",
    "reîntâlneai": "reîntâlni",
    "reîntâlneam": "reîntâlni",
    "reîntâlnească": "reîntâlni",
    "reîntâlneați": "reîntâlni",
    "reîntâlneau": "reîntâlni",
    "reîntâlnesc": "reîntâlni",
    "reîntâlnește": "reîntâlni",
    "reîntâlnești": "reîntâlni",
    "reîntâlnii": "reîntâlni",
    "reîntâlnim": "reîntâlni",
    "reîntâlnind": "reîntâlni",
    "reîntâlnindu": "reîntâlni",
    "reîntâlniră": "reîntâlni",
    "reîntâlnirăm": "reîntâlni",
    "reîntâlnirăți": "reîntâlni",
    "reîntâlnise": "reîntâlni",
    "reîntâlnisem": "reîntâlni",
    "reîntâlniseră": "reîntâlni",
    "reîntâlniserăm": "reîntâlni",
    "reîntâlniserăți": "reîntâlni",
    "reîntâlniseși": "reîntâlni",
    "reîntâlniși": "reîntâlni",
    "reîntâlnit": "reîntâlni",
    "reîntâlniți": "reîntâlni",
    "reîntâlnitu": "reîntâlni",
    "reîntâlnirea": "reîntâlnire",
    "reîntâlniri": "reîntâlnire",
    "reîntâlnirii": "reîntâlnire",
    "reîntâlnirile": "reîntâlnire",
    "reîntâlnirilor": "reîntâlnire",
    "reîntâlnită": "reîntâlnit",
    "reîntâlnite": "reîntâlnit",
    "reîntâlniți": "reîntâlnit",
    "nemaireintegrând": "reintegra",
    "nemaireintegrându": "reintegra",
    "nereintegrând": "reintegra",
    "nereintegrându": "reintegra",
    "reintegră": "reintegra",
    "reintegrai": "reintegra",
    "reintegram": "reintegra",
    "reintegrăm": "reintegra",
    "reintegrând": "reintegra",
    "reintegrându": "reintegra",
    "reintegrară": "reintegra",
    "reintegrarăm": "reintegra",
    "reintegrarăți": "reintegra",
    "reintegrase": "reintegra",
    "reintegrasem": "reintegra",
    "reintegraseră": "reintegra",
    "reintegraserăm": "reintegra",
    "reintegraserăți": "reintegra",
    "reintegraseși": "reintegra",
    "reintegrași": "reintegra",
    "reintegrat": "reintegra",
    "reintegrați": "reintegra",
    "reintegrau": "reintegra",
    "reintegrează": "reintegra",
    "reintegrez": "reintegra",
    "reintegreze": "reintegra",
    "reintegrezi": "reintegra",
    "reintegrarea": "reintegrare",
    "reintegrări": "reintegrare",
    "reintegrării": "reintegrare",
    "reintegrările": "reintegrare",
    "reintegrărilor": "reintegrare",
    "reintegrată": "reintegrat",
    "reintegrate": "reintegrat",
    "reintegrați": "reintegrat",
    "reinterpretarea": "reinterpretare",
    "reinterpretări": "reinterpretare",
    "reinterpretării": "reinterpretare",
    "reinterpretările": "reinterpretare",
    "reinterpretărilor": "reinterpretare",
    "nemaireîntinerind": "reîntineri",
    "nemaireîntinerindu": "reîntineri",
    "nereîntinerind": "reîntineri",
    "nereîntinerindu": "reîntineri",
    "reîntinerea": "reîntineri",
    "reîntinereai": "reîntineri",
    "reîntineream": "reîntineri",
    "reîntinerească": "reîntineri",
    "reîntinereați": "reîntineri",
    "reîntinereau": "reîntineri",
    "reîntineresc": "reîntineri",
    "reîntinerește": "reîntineri",
    "reîntinerești": "reîntineri",
    "reîntinerii": "reîntineri",
    "reîntinerim": "reîntineri",
    "reîntinerind": "reîntineri",
    "reîntinerindu": "reîntineri",
    "reîntineriră": "reîntineri",
    "reîntinerirăm": "reîntineri",
    "reîntinerirăți": "reîntineri",
    "reîntinerise": "reîntineri",
    "reîntinerisem": "reîntineri",
    "reîntineriseră": "reîntineri",
    "reîntineriserăm": "reîntineri",
    "reîntineriserăți": "reîntineri",
    "reîntineriseși": "reîntineri",
    "reîntineriși": "reîntineri",
    "reîntinerit": "reîntineri",
    "reîntineriți": "reîntineri",
    "reîntinerita": "reîntinerit",
    "reîntinerită": "reîntinerit",
    "reîntinerite": "reîntinerit",
    "reîntineritei": "reîntinerit",
    "reîntineritele": "reîntinerit",
    "reîntineritelor": "reîntinerit",
    "reîntineriți": "reîntinerit",
    "reîntineriții": "reîntinerit",
    "reîntineriților": "reîntinerit",
    "reîntineritul": "reîntinerit",
    "reîntineritului": "reîntinerit",
    "reîntoarcă": "reîntoarce",
    "reîntoarcem": "reîntoarce",
    "reîntoarceți": "reîntoarce",
    "reîntoarse": "reîntoarce",
    "reîntoarseră": "reîntoarce",
    "reîntoarserăm": "reîntoarce",
    "reîntoarserăți": "reîntoarce",
    "reîntorc": "reîntoarce",
    "reîntorcând": "reîntoarce",
    "reîntorcându": "reîntoarce",
    "reîntorcea": "reîntoarce",
    "reîntorceai": "reîntoarce",
    "reîntorceam": "reîntoarce",
    "reîntorceați": "reîntoarce",
    "reîntorceau": "reîntoarce",
    "reîntorci": "reîntoarce",
    "reîntors": "reîntoarce",
    "reîntorsei": "reîntoarce",
    "reîntorsese": "reîntoarce",
    "reîntorsesem": "reîntoarce",
    "reîntorseseră": "reîntoarce",
    "reîntorseserăm": "reîntoarce",
    "reîntorseserăți": "reîntoarce",
    "reîntorseseși": "reîntoarce",
    "reîntorseși": "reîntoarce",
    "reîntorsu": "reîntoarce",
    "reîntoarsă": "reîntors",
    "reîntoarse": "reîntors",
    "reîntorși": "reîntors",
    "reintră": "reintra",
    "reintrai": "reintra",
    "reintram": "reintra",
    "reintrăm": "reintra",
    "reintrând": "reintra",
    "reintrându": "reintra",
    "reintrară": "reintra",
    "reintrarăm": "reintra",
    "reintrarăți": "reintra",
    "reintrase": "reintra",
    "reintrasem": "reintra",
    "reintraseră": "reintra",
    "reintraserăm": "reintra",
    "reintraserăți": "reintra",
    "reintraseși": "reintra",
    "reintrași": "reintra",
    "reintrat": "reintra",
    "reintrați": "reintra",
    "reintrau": "reintra",
    "reintre": "reintra",
    "reintri": "reintra",
    "reintru": "reintra",
    "reintrarea": "reintrare",
    "reintrări": "reintrare",
    "reintrării": "reintrare",
    "reintrările": "reintrare",
    "reintrărilor": "reintrare",
    "reintrata": "reintrat",
    "reintrată": "reintrat",
    "reintrate": "reintrat",
    "reintratei": "reintrat",
    "reintratele": "reintrat",
    "reintratelor": "reintrat",
    "reintrați": "reintrat",
    "reintrații": "reintrat",
    "reintraților": "reintrat",
    "reintrato": "reintrat",
    "reintratul": "reintrat",
    "reintratule": "reintrat",
    "reintratului": "reintrat",
    "reîntregirea": "reîntregire",
    "reîntregiri": "reîntregire",
    "reîntregirii": "reîntregire",
    "reîntregirile": "reîntregire",
    "reîntregirilor": "reîntregire",
    "nemaireintroducând": "reintroduce",
    "nemaireintroducându": "reintroduce",
    "nereintroducând": "reintroduce",
    "nereintroducându": "reintroduce",
    "reintroduc": "reintroduce",
    "reintroducă": "reintroduce",
    "reintroducând": "reintroduce",
    "reintroducându": "reintroduce",
    "reintroducea": "reintroduce",
    "reintroduceai": "reintroduce",
    "reintroduceam": "reintroduce",
    "reintroduceați": "reintroduce",
    "reintroduceau": "reintroduce",
    "reintroducem": "reintroduce",
    "reintroduceți": "reintroduce",
    "reintroduci": "reintroduce",
    "reintrodus": "reintroduce",
    "reintroduse": "reintroduce",
    "reintrodusei": "reintroduce",
    "reintroduseră": "reintroduce",
    "reintroduserăm": "reintroduce",
    "reintroduserăți": "reintroduce",
    "reintrodusese": "reintroduce",
    "reintrodusesem": "reintroduce",
    "reintroduseseră": "reintroduce",
    "reintroduseserăm": "reintroduce",
    "reintroduseserăți": "reintroduce",
    "reintroduseseși": "reintroduce",
    "reintroduseși": "reintroduce",
    "reintroducerea": "reintroducere",
    "reintroduceri": "reintroducere",
    "reintroducerii": "reintroducere",
    "reintroducerile": "reintroducere",
    "reintroducerilor": "reintroducere",
    "reintrodusă": "reintrodus",
    "reintroduse": "reintrodus",
    "reintroduși": "reintrodus",
    "reinventarierea": "reinventariere",
    "reinventarieri": "reinventariere",
    "reinventarierii": "reinventariere",
    "reinventarierile": "reinventariere",
    "reinventarierilor": "reinventariere",
    "reinvestea": "reinvesti",
    "reinvesteai": "reinvesti",
    "reinvesteam": "reinvesti",
    "reinvestească": "reinvesti",
    "reinvesteați": "reinvesti",
    "reinvesteau": "reinvesti",
    "reinvestesc": "reinvesti",
    "reinvestește": "reinvesti",
    "reinvestești": "reinvesti",
    "reinvestii": "reinvesti",
    "reinvestim": "reinvesti",
    "reinvestind": "reinvesti",
    "reinvestindu": "reinvesti",
    "reinvestiră": "reinvesti",
    "reinvestirăm": "reinvesti",
    "reinvestirăți": "reinvesti",
    "reinvestise": "reinvesti",
    "reinvestisem": "reinvesti",
    "reinvestiseră": "reinvesti",
    "reinvestiserăm": "reinvesti",
    "reinvestiserăți": "reinvesti",
    "reinvestiseși": "reinvesti",
    "reinvestiși": "reinvesti",
    "reinvestit": "reinvesti",
    "reinvestiți": "reinvesti",
    "reinvestitu": "reinvesti",
    "reinvestigă": "reinvestiga",
    "reinvestigai": "reinvestiga",
    "reinvestigam": "reinvestiga",
    "reinvestigăm": "reinvestiga",
    "reinvestigând": "reinvestiga",
    "reinvestigându": "reinvestiga",
    "reinvestigară": "reinvestiga",
    "reinvestigarăm": "reinvestiga",
    "reinvestigarăți": "reinvestiga",
    "reinvestigase": "reinvestiga",
    "reinvestigasem": "reinvestiga",
    "reinvestigaseră": "reinvestiga",
    "reinvestigaserăm": "reinvestiga",
    "reinvestigaserăți": "reinvestiga",
    "reinvestigaseși": "reinvestiga",
    "reinvestigași": "reinvestiga",
    "reinvestigat": "reinvestiga",
    "reinvestigați": "reinvestiga",
    "reinvestigatu": "reinvestiga",
    "reinvestigau": "reinvestiga",
    "reinvestighează": "reinvestiga",
    "reinvestighez": "reinvestiga",
    "reinvestigheze": "reinvestiga",
    "reinvestighezi": "reinvestiga",
    "reinvestigarea": "reinvestigare",
    "reinvestigareo": "reinvestigare",
    "reinvestigări": "reinvestigare",
    "reinvestigării": "reinvestigare",
    "reinvestigările": "reinvestigare",
    "reinvestigărilor": "reinvestigare",
    "reinvestigată": "reinvestigat",
    "reinvestigate": "reinvestigat",
    "reinvestigați": "reinvestigat",
    "reinvestigația": "reinvestigație",
    "reinvestigației": "reinvestigație",
    "reinvestigații": "reinvestigație",
    "reinvestigațiile": "reinvestigație",
    "reinvestigațiilor": "reinvestigație",
    "reinvestirea": "reinvestire",
    "reinvestireo": "reinvestire",
    "reinvestiri": "reinvestire",
    "reinvestirii": "reinvestire",
    "reinvestirile": "reinvestire",
    "reinvestirilor": "reinvestire",
    "reinvestită": "reinvestit",
    "reinvestite": "reinvestit",
    "reinvestiți": "reinvestit",
    "reinvestiția": "reinvestiție",
    "reinvestiției": "reinvestiție",
    "reinvestiții": "reinvestiție",
    "reinvestițiile": "reinvestiție",
    "reinvestițiilor": "reinvestiție",
    "reinvestitori": "reinvestitor",
    "reinvestitorii": "reinvestitor",
    "reinvestitorilor": "reinvestitor",
    "reinvestitorul": "reinvestitor",
    "reinvestitorule": "reinvestitor",
    "reinvestitorului": "reinvestitor",
    "nemaireînviind": "reînvia",
    "nemaireînviindu": "reînvia",
    "nereînviind": "reînvia",
    "nereînviindu": "reînvia",
    "reînviai": "reînvia",
    "reînviam": "reînvia",
    "reînviară": "reînvia",
    "reînviarăm": "reînvia",
    "reînviarăți": "reînvia",
    "reînviase": "reînvia",
    "reînviasem": "reînvia",
    "reînviaseră": "reînvia",
    "reînviaserăm": "reînvia",
    "reînviaserăți": "reînvia",
    "reînviaseși": "reînvia",
    "reînviași": "reînvia",
    "reînviat": "reînvia",
    "reînviați": "reînvia",
    "reînviau": "reînvia",
    "reînvie": "reînvia",
    "reînviem": "reînvia",
    "reînvii": "reînvia",
    "reînviind": "reînvia",
    "reînviindu": "reînvia",
    "reînviata": "reînviat",
    "reînviată": "reînviat",
    "reînviate": "reînviat",
    "reînviatei": "reînviat",
    "reînviatele": "reînviat",
    "reînviatelor": "reînviat",
    "reînviați": "reînviat",
    "reînviații": "reînviat",
    "reînviaților": "reînviat",
    "reînviato": "reînviat",
    "reînviatul": "reînviat",
    "reînviatule": "reînviat",
    "reînviatului": "reînviat",
    "reînvierea": "reînviere",
    "reînviereo": "reînviere",
    "reînvieri": "reînviere",
    "reînvierii": "reînviere",
    "reînvierile": "reînviere",
    "reînvierilor": "reînviere",
    "reînvietoare": "reînvietor",
    "reînvietoarea": "reînvietor",
    "reînvietoarei": "reînvietor",
    "reînvietoarele": "reînvietor",
    "reînvietoarelor": "reînvietor",
    "reînvietori": "reînvietor",
    "reînvietorii": "reînvietor",
    "reînvietorilor": "reînvietor",
    "reînvietorul": "reînvietor",
    "reînvietorului": "reînvietor",
    "reiteră": "reitera",
    "reiterai": "reitera",
    "reiteram": "reitera",
    "reiterăm": "reitera",
    "reiterând": "reitera",
    "reiterându": "reitera",
    "reiterară": "reitera",
    "reiterarăm": "reitera",
    "reiterarăți": "reitera",
    "reiterase": "reitera",
    "reiterasem": "reitera",
    "reiteraseră": "reitera",
    "reiteraserăm": "reitera",
    "reiteraserăți": "reitera",
    "reiteraseși": "reitera",
    "reiterași": "reitera",
    "reiterat": "reitera",
    "reiterați": "reitera",
    "reiteratu": "reitera",
    "reiterau": "reitera",
    "reiterează": "reitera",
    "reiterez": "reitera",
    "reitereze": "reitera",
    "reiterezi": "reitera",
    "reiterată": "reiterat",
    "reiterate": "reiterat",
    "reiterați": "reiterat",
    "reiterativa": "reiterativ",
    "reiterativă": "reiterativ",
    "reiterative": "reiterativ",
    "reiterativei": "reiterativ",
    "reiterativele": "reiterativ",
    "reiterativelor": "reiterativ",
    "reiterativi": "reiterativ",
    "reiterativii": "reiterativ",
    "reiterativilor": "reiterativ",
    "reiterativul": "reiterativ",
    "reiterativului": "reiterativ",
    "rejansa": "rejansă",
    "rejanse": "rejansă",
    "rejansei": "rejansă",
    "rejansele": "rejansă",
    "rejanselor": "rejansă",
    "rejudecata": "rejudecat",
    "rejudecată": "rejudecat",
    "rejudecate": "rejudecat",
    "rejudecatei": "rejudecat",
    "rejudecatele": "rejudecat",
    "rejudecatelor": "rejudecat",
    "rejudecați": "rejudecat",
    "rejudecații": "rejudecat",
    "rejudecaților": "rejudecat",
    "rejudecatul": "rejudecat",
    "rejudecatului": "rejudecat",
    "nemairelansând": "relansa",
    "nemairelansându": "relansa",
    "nerelansând": "relansa",
    "nerelansându": "relansa",
    "relansă": "relansa",
    "relansai": "relansa",
    "relansam": "relansa",
    "relansăm": "relansa",
    "relansând": "relansa",
    "relansându": "relansa",
    "relansară": "relansa",
    "relansarăm": "relansa",
    "relansarăți": "relansa",
    "relansase": "relansa",
    "relansasem": "relansa",
    "relansaseră": "relansa",
    "relansaserăm": "relansa",
    "relansaserăți": "relansa",
    "relansaseși": "relansa",
    "relansași": "relansa",
    "relansat": "relansa",
    "relansați": "relansa",
    "relansau": "relansa",
    "relansează": "relansa",
    "relansez": "relansa",
    "relanseze": "relansa",
    "relansezi": "relansa",
    "relansarea": "relansare",
    "relansări": "relansare",
    "relansării": "relansare",
    "relansările": "relansare",
    "relansărilor": "relansare",
    "relansată": "relansat",
    "relansate": "relansat",
    "relansați": "relansat",
    "nemairelatând": "relata",
    "nemairelatându": "relata",
    "nerelatând": "relata",
    "nerelatându": "relata",
    "relată": "relata",
    "relatai": "relata",
    "relatam": "relata",
    "relatăm": "relata",
    "relatând": "relata",
    "relatându": "relata",
    "relatară": "relata",
    "relatarăm": "relata",
    "relatarăți": "relata",
    "relatase": "relata",
    "relatasem": "relata",
    "relataseră": "relata",
    "relataserăm": "relata",
    "relataserăți": "relata",
    "relataseși": "relata",
    "relatași": "relata",
    "relatat": "relata",
    "relatați": "relata",
    "relatau": "relata",
    "relatează": "relata",
    "relatez": "relata",
    "relateze": "relata",
    "relatezi": "relata",
    "relatarea": "relatare",
    "relatări": "relatare",
    "relatării": "relatare",
    "relatările": "relatare",
    "relatărilor": "relatare",
    "relatata": "relatat",
    "relatată": "relatat",
    "relatate": "relatat",
    "relatatei": "relatat",
    "relatatele": "relatat",
    "relatatelor": "relatat",
    "relatați": "relatat",
    "relatații": "relatat",
    "relataților": "relatat",
    "relatatul": "relatat",
    "relatatului": "relatat",
    "relația": "relație",
    "relației": "relație",
    "relații": "relație",
    "relațiile": "relație",
    "relațiilor": "relație",
    "REI": "Relații_Economice_Internaționale",
    "relaționarea": "relaționare",
    "relaționări": "relaționare",
    "relaționării": "relaționare",
    "relaționările": "relaționare",
    "relaționărilor": "relaționare",
    "relativa": "relativ",
    "relativă": "relativ",
    "relative": "relativ",
    "relativei": "relativ",
    "relativele": "relativ",
    "relativelor": "relativ",
    "relativi": "relativ",
    "relativii": "relativ",
    "relativilor": "relativ",
    "relativul": "relativ",
    "relativului": "relativ",
    "relativismul": "relativism",
    "relativismului": "relativism",
    "relativiști": "relativist",
    "relativiștii": "relativist",
    "relativiștilor": "relativist",
    "relativistul": "relativist",
    "relativistului": "relativist",
    "relativista": "relativistă",
    "relativiste": "relativistă",
    "relativistei": "relativistă",
    "relativistele": "relativistă",
    "relativistelor": "relativistă",
    "relativitatea": "relativitate",
    "relativități": "relativitate",
    "relativității": "relativitate",
    "relativitățile": "relativitate",
    "relativităților": "relativitate",
    "nemairelaxând": "relaxa",
    "nemairelaxându": "relaxa",
    "nerelaxând": "relaxa",
    "nerelaxându": "relaxa",
    "relaxă": "relaxa",
    "relaxai": "relaxa",
    "relaxam": "relaxa",
    "relaxăm": "relaxa",
    "relaxând": "relaxa",
    "relaxându": "relaxa",
    "relaxară": "relaxa",
    "relaxarăm": "relaxa",
    "relaxarăți": "relaxa",
    "relaxase": "relaxa",
    "relaxasem": "relaxa",
    "relaxaseră": "relaxa",
    "relaxaserăm": "relaxa",
    "relaxaserăți": "relaxa",
    "relaxaseși": "relaxa",
    "relaxași": "relaxa",
    "relaxat": "relaxa",
    "relaxați": "relaxa",
    "relaxau": "relaxa",
    "relaxează": "relaxa",
    "relaxez": "relaxa",
    "relaxeze": "relaxa",
    "relaxezi": "relaxa",
    "relaxarea": "relaxare",
    "relaxări": "relaxare",
    "relaxării": "relaxare",
    "relaxările": "relaxare",
    "relaxărilor": "relaxare",
    "relaxată": "relaxat",
    "relaxate": "relaxat",
    "relaxați": "relaxat",
    "relee": "releu",
    "releele": "releu",
    "releelor": "releu",
    "releul": "releu",
    "releului": "releu",
    "nemairelevând": "releva",
    "nemairelevându": "releva",
    "nerelevând": "releva",
    "nerelevându": "releva",
    "relev": "releva",
    "relevă": "releva",
    "relevai": "releva",
    "relevam": "releva",
    "relevăm": "releva",
    "relevând": "releva",
    "relevându": "releva",
    "relevară": "releva",
    "relevarăm": "releva",
    "relevarăți": "releva",
    "relevase": "releva",
    "relevasem": "releva",
    "relevaseră": "releva",
    "relevaserăm": "releva",
    "relevaserăți": "releva",
    "relevaseși": "releva",
    "relevași": "releva",
    "relevat": "releva",
    "relevați": "releva",
    "relevau": "releva",
    "releve": "releva",
    "relevi": "releva",
    "relevanta": "relevant",
    "relevantă": "relevant",
    "relevante": "relevant",
    "relevantei": "relevant",
    "relevantele": "relevant",
    "relevantelor": "relevant",
    "relevanți": "relevant",
    "relevanții": "relevant",
    "relevanților": "relevant",
    "relevantul": "relevant",
    "relevantului": "relevant",
    "relevați": "relevant",
    "relevații": "relevant",
    "relevaților": "relevant",
    "relevarea": "relevare",
    "relevareo": "relevare",
    "relevări": "relevare",
    "relevării": "relevare",
    "relevările": "relevare",
    "relevărilor": "relevare",
    "relevată": "relevat",
    "relevate": "relevat",
    "relevați": "relevat",
    "relicențierea": "relicențiere",
    "relicențieri": "relicențiere",
    "relicențierii": "relicențiere",
    "relicențierile": "relicențiere",
    "relicențierilor": "relicențiere",
    "relicva": "relicvă",
    "relicve": "relicvă",
    "relicvei": "relicvă",
    "relicvele": "relicvă",
    "relicvelor": "relicvă",
    "relieful": "relief",
    "reliefului": "relief",
    "reliefuri": "relief",
    "reliefurile": "relief",
    "reliefurilor": "relief",
    "nemaireliefând": "reliefa",
    "nemaireliefându": "reliefa",
    "nereliefând": "reliefa",
    "nereliefându": "reliefa",
    "reliefă": "reliefa",
    "reliefai": "reliefa",
    "reliefam": "reliefa",
    "reliefăm": "reliefa",
    "reliefând": "reliefa",
    "reliefându": "reliefa",
    "reliefară": "reliefa",
    "reliefarăm": "reliefa",
    "reliefarăți": "reliefa",
    "reliefase": "reliefa",
    "reliefasem": "reliefa",
    "reliefaseră": "reliefa",
    "reliefaserăm": "reliefa",
    "reliefaserăți": "reliefa",
    "reliefaseși": "reliefa",
    "reliefași": "reliefa",
    "reliefat": "reliefa",
    "reliefați": "reliefa",
    "reliefau": "reliefa",
    "reliefează": "reliefa",
    "reliefez": "reliefa",
    "reliefeze": "reliefa",
    "reliefezi": "reliefa",
    "reliefarea": "reliefare",
    "reliefareo": "reliefare",
    "reliefări": "reliefare",
    "reliefării": "reliefare",
    "reliefările": "reliefare",
    "reliefărilor": "reliefare",
    "reliefata": "reliefat",
    "reliefată": "reliefat",
    "reliefate": "reliefat",
    "reliefatei": "reliefat",
    "reliefatele": "reliefat",
    "reliefatelor": "reliefat",
    "reliefați": "reliefat",
    "reliefații": "reliefat",
    "reliefaților": "reliefat",
    "reliefato": "reliefat",
    "reliefatul": "reliefat",
    "reliefatule": "reliefat",
    "reliefatului": "reliefat",
    "relig.": "religie",
    "religia": "religie",
    "religiei": "religie",
    "religii": "religie",
    "religiile": "religie",
    "religiilor": "religie",
    "religioasa": "religios",
    "religioasă": "religios",
    "religioase": "religios",
    "religioasei": "religios",
    "religioasele": "religios",
    "religioaselor": "religios",
    "religioși": "religios",
    "religioșii": "religios",
    "religioșilor": "religios",
    "religiosul": "religios",
    "religiosului": "religios",
    "religiozitatea": "religiozitate",
    "religiozități": "religiozitate",
    "religiozității": "religiozitate",
    "religiozitățile": "religiozitate",
    "religiozităților": "religiozitate",
    "nemaireluând": "relua",
    "nemaireluându": "relua",
    "nereluând": "relua",
    "nereluându": "relua",
    "reia": "relua",
    "reiau": "relua",
    "reiei": "relua",
    "reluă": "relua",
    "reluai": "relua",
    "reluam": "relua",
    "reluăm": "relua",
    "reluând": "relua",
    "reluându": "relua",
    "reluară": "relua",
    "reluarăm": "relua",
    "reluarăți": "relua",
    "reluase": "relua",
    "reluasem": "relua",
    "reluaseră": "relua",
    "reluaserăm": "relua",
    "reluaserăți": "relua",
    "reluaseși": "relua",
    "reluași": "relua",
    "reluat": "relua",
    "reluați": "relua",
    "reluau": "relua",
    "reluarea": "reluare",
    "reluareo": "reluare",
    "reluări": "reluare",
    "reluării": "reluare",
    "reluările": "reluare",
    "reluărilor": "reluare",
    "reluată": "reluat",
    "reluate": "reluat",
    "reluați": "reluat",
    "nemairemaiând": "remaia",
    "nemairemaiându": "remaia",
    "neremaiând": "remaia",
    "neremaiându": "remaia",
    "remaiai": "remaia",
    "remaiam": "remaia",
    "remaiară": "remaia",
    "remaiarăm": "remaia",
    "remaiarăți": "remaia",
    "remaiase": "remaia",
    "remaiasem": "remaia",
    "remaiaseră": "remaia",
    "remaiaserăm": "remaia",
    "remaiaserăți": "remaia",
    "remaiaseși": "remaia",
    "remaiași": "remaia",
    "remaiat": "remaia",
    "remaiați": "remaia",
    "remaiau": "remaia",
    "remaiază": "remaia",
    "remaie": "remaia",
    "remaiem": "remaia",
    "remaiez": "remaia",
    "remaieze": "remaia",
    "remaiezi": "remaia",
    "remaind": "remaia",
    "remaindu": "remaia",
    "remaiată": "remaiat",
    "remaiate": "remaiat",
    "remaiați": "remaiat",
    "remaieza": "remaieză",
    "remaieze": "remaieză",
    "remaiezei": "remaieză",
    "remaiezele": "remaieză",
    "remaiezelor": "remaieză",
    "remanența": "remanență",
    "remanențe": "remanență",
    "remanenței": "remanență",
    "remanențele": "remanență",
    "remanențelor": "remanență",
    "nemairemaniind": "remania",
    "nemairemaniindu": "remania",
    "neremaniind": "remania",
    "neremaniindu": "remania",
    "remaniai": "remania",
    "remaniam": "remania",
    "remaniară": "remania",
    "remaniarăm": "remania",
    "remaniarăți": "remania",
    "remaniase": "remania",
    "remaniasem": "remania",
    "remaniaseră": "remania",
    "remaniaserăm": "remania",
    "remaniaserăți": "remania",
    "remaniaseși": "remania",
    "remaniași": "remania",
    "remaniat": "remania",
    "remaniați": "remania",
    "remaniau": "remania",
    "remaniază": "remania",
    "remanie": "remania",
    "remaniem": "remania",
    "remaniez": "remania",
    "remanieze": "remania",
    "remaniezi": "remania",
    "remaniind": "remania",
    "remaniindu": "remania",
    "remaniată": "remaniat",
    "remaniate": "remaniat",
    "remaniați": "remaniat",
    "remanierea": "remaniere",
    "remanieri": "remaniere",
    "remanierii": "remaniere",
    "remanierile": "remaniere",
    "remanierilor": "remaniere",
    "nemairemarcând": "remarca",
    "nemairemarcându": "remarca",
    "neremarcând": "remarca",
    "neremarcându": "remarca",
    "remarc": "remarca",
    "remarcă": "remarca",
    "remarcai": "remarca",
    "remarcam": "remarca",
    "remarcăm": "remarca",
    "remarcând": "remarca",
    "remarcându": "remarca",
    "remarcară": "remarca",
    "remarcarăm": "remarca",
    "remarcarăți": "remarca",
    "remarcase": "remarca",
    "remarcasem": "remarca",
    "remarcaseră": "remarca",
    "remarcaserăm": "remarca",
    "remarcaserăți": "remarca",
    "remarcaseși": "remarca",
    "remarcași": "remarca",
    "remarcat": "remarca",
    "remarcați": "remarca",
    "remarcau": "remarca",
    "remarci": "remarca",
    "remarca": "remarcă",
    "remarce": "remarcă",
    "remarcei": "remarcă",
    "remarcele": "remarcă",
    "remarcelor": "remarcă",
    "remarci": "remarcă",
    "remarcii": "remarcă",
    "remarcile": "remarcă",
    "remarcilor": "remarcă",
    "remarcabila": "remarcabil",
    "remarcabilă": "remarcabil",
    "remarcabile": "remarcabil",
    "remarcabilei": "remarcabil",
    "remarcabilele": "remarcabil",
    "remarcabilelor": "remarcabil",
    "remarcabili": "remarcabil",
    "remarcabilii": "remarcabil",
    "remarcabililor": "remarcabil",
    "remarcabilul": "remarcabil",
    "remarcabilului": "remarcabil",
    "remarcată": "remarcat",
    "remarcate": "remarcat",
    "remarcați": "remarcat",
    "nemairemediind": "remedia",
    "nemairemediindu": "remedia",
    "neremediind": "remedia",
    "neremediindu": "remedia",
    "remediai": "remedia",
    "remediam": "remedia",
    "remediară": "remedia",
    "remediarăm": "remedia",
    "remediarăți": "remedia",
    "remediase": "remedia",
    "remediasem": "remedia",
    "remediaseră": "remedia",
    "remediaserăm": "remedia",
    "remediaserăți": "remedia",
    "remediaseși": "remedia",
    "remediași": "remedia",
    "remediat": "remedia",
    "remediați": "remedia",
    "remediau": "remedia",
    "remediază": "remedia",
    "remedie": "remedia",
    "remediem": "remedia",
    "remediez": "remedia",
    "remedieze": "remedia",
    "remediezi": "remedia",
    "remediind": "remedia",
    "remediindu": "remedia",
    "remediată": "remediat",
    "remediate": "remediat",
    "remediați": "remediat",
    "remedierea": "remediere",
    "remedieri": "remediere",
    "remedierii": "remediere",
    "remedierile": "remediere",
    "remedierilor": "remediere",
    "remedii": "remediu",
    "remediile": "remediu",
    "remediilor": "remediu",
    "remediul": "remediu",
    "remediului": "remediu",
    "nemairememorând": "rememora",
    "nemairememorându": "rememora",
    "nerememorând": "rememora",
    "nerememorându": "rememora",
    "rememoră": "rememora",
    "rememorai": "rememora",
    "rememoram": "rememora",
    "rememorăm": "rememora",
    "rememorând": "rememora",
    "rememorându": "rememora",
    "rememorară": "rememora",
    "rememorarăm": "rememora",
    "rememorarăți": "rememora",
    "rememorase": "rememora",
    "rememorasem": "rememora",
    "rememoraseră": "rememora",
    "rememoraserăm": "rememora",
    "rememoraserăți": "rememora",
    "rememoraseși": "rememora",
    "rememorași": "rememora",
    "rememorat": "rememora",
    "rememorați": "rememora",
    "rememorau": "rememora",
    "rememorează": "rememora",
    "rememorez": "rememora",
    "rememoreze": "rememora",
    "rememorezi": "rememora",
    "rememorarea": "rememorare",
    "rememorareo": "rememorare",
    "rememorări": "rememorare",
    "rememorării": "rememorare",
    "rememorările": "rememorare",
    "rememorărilor": "rememorare",
    "rememorată": "rememorat",
    "rememorate": "rememorat",
    "rememorați": "rememorat",
    "reminiscența": "reminiscență",
    "reminiscențe": "reminiscență",
    "reminiscenței": "reminiscență",
    "reminiscențele": "reminiscență",
    "reminiscențelor": "reminiscență",
    "remisă": "remis",
    "remise": "remis",
    "remiși": "remis",
    "nemairemițând": "remite",
    "nemairemițându": "remite",
    "neremițând": "remite",
    "neremițându": "remite",
    "remis": "remite",
    "remise": "remite",
    "remisei": "remite",
    "remiseră": "remite",
    "remiserăm": "remite",
    "remiserăți": "remite",
    "remisese": "remite",
    "remisesem": "remite",
    "remiseseră": "remite",
    "remiseserăm": "remite",
    "remiseserăți": "remite",
    "remiseseși": "remite",
    "remiseși": "remite",
    "remit": "remite",
    "remită": "remite",
    "remițând": "remite",
    "remițându": "remite",
    "remitea": "remite",
    "remiteai": "remite",
    "remiteam": "remite",
    "remiteați": "remite",
    "remiteau": "remite",
    "remitem": "remite",
    "remiteți": "remite",
    "remiți": "remite",
    "remiterea": "remitere",
    "remiteri": "remitere",
    "remiterii": "remitere",
    "remiterile": "remitere",
    "remiterilor": "remitere",
    "nemairemizând": "remiza",
    "nemairemizându": "remiza",
    "neremizând": "remiza",
    "neremizându": "remiza",
    "remiză": "remiza",
    "remizai": "remiza",
    "remizam": "remiza",
    "remizăm": "remiza",
    "remizând": "remiza",
    "remizându": "remiza",
    "remizară": "remiza",
    "remizarăm": "remiza",
    "remizarăți": "remiza",
    "remizase": "remiza",
    "remizasem": "remiza",
    "remizaseră": "remiza",
    "remizaserăm": "remiza",
    "remizaserăți": "remiza",
    "remizaseși": "remiza",
    "remizași": "remiza",
    "remizat": "remiza",
    "remizați": "remiza",
    "remizau": "remiza",
    "remizează": "remiza",
    "remizez": "remiza",
    "remizeze": "remiza",
    "remizezi": "remiza",
    "remiza": "remiză",
    "remize": "remiză",
    "remizei": "remiză",
    "remizele": "remiză",
    "remizelor": "remiză",
    "remizată": "remizat",
    "remizate": "remizat",
    "remizați": "remizat",
    "nemairemodelând": "remodela",
    "nemairemodelându": "remodela",
    "neremodelând": "remodela",
    "neremodelându": "remodela",
    "remodelă": "remodela",
    "remodelai": "remodela",
    "remodelam": "remodela",
    "remodelăm": "remodela",
    "remodelând": "remodela",
    "remodelându": "remodela",
    "remodelară": "remodela",
    "remodelarăm": "remodela",
    "remodelarăți": "remodela",
    "remodelase": "remodela",
    "remodelasem": "remodela",
    "remodelaseră": "remodela",
    "remodelaserăm": "remodela",
    "remodelaserăți": "remodela",
    "remodelaseși": "remodela",
    "remodelași": "remodela",
    "remodelat": "remodela",
    "remodelați": "remodela",
    "remodelau": "remodela",
    "remodelează": "remodela",
    "remodelez": "remodela",
    "remodeleze": "remodela",
    "remodelezi": "remodela",
    "remodelată": "remodelat",
    "remodelate": "remodelat",
    "remodelați": "remodelat",
    "nemairemontând": "remonta",
    "nemairemontându": "remonta",
    "neremontând": "remonta",
    "neremontându": "remonta",
    "remontă": "remonta",
    "remontai": "remonta",
    "remontam": "remonta",
    "remontăm": "remonta",
    "remontând": "remonta",
    "remontându": "remonta",
    "remontară": "remonta",
    "remontarăm": "remonta",
    "remontarăți": "remonta",
    "remontase": "remonta",
    "remontasem": "remonta",
    "remontaseră": "remonta",
    "remontaserăm": "remonta",
    "remontaserăți": "remonta",
    "remontaseși": "remonta",
    "remontași": "remonta",
    "remontat": "remonta",
    "remontați": "remonta",
    "remontau": "remonta",
    "remontează": "remonta",
    "remontez": "remonta",
    "remonteze": "remonta",
    "remontezi": "remonta",
    "remonta": "remontă",
    "remonte": "remontă",
    "remontei": "remontă",
    "remontele": "remontă",
    "remontelor": "remontă",
    "remontată": "remontat",
    "remontate": "remontat",
    "remontați": "remontat",
    "nemairemorcând": "remorca",
    "nemairemorcându": "remorca",
    "neremorcând": "remorca",
    "neremorcându": "remorca",
    "remorcă": "remorca",
    "remorcai": "remorca",
    "remorcam": "remorca",
    "remorcăm": "remorca",
    "remorcând": "remorca",
    "remorcându": "remorca",
    "remorcară": "remorca",
    "remorcarăm": "remorca",
    "remorcarăți": "remorca",
    "remorcase": "remorca",
    "remorcasem": "remorca",
    "remorcaseră": "remorca",
    "remorcaserăm": "remorca",
    "remorcaserăți": "remorca",
    "remorcaseși": "remorca",
    "remorcași": "remorca",
    "remorcat": "remorca",
    "remorcați": "remorca",
    "remorcau": "remorca",
    "remorchează": "remorca",
    "remorchez": "remorca",
    "remorcheze": "remorca",
    "remorchezi": "remorca",
    "remorca": "remorcă",
    "remorci": "remorcă",
    "remorcii": "remorcă",
    "remorcile": "remorcă",
    "remorcilor": "remorcă",
    "remorcată": "remorcat",
    "remorcate": "remorcat",
    "remorcați": "remorcat",
    "remorchere": "remorcher",
    "remorcherele": "remorcher",
    "remorcherelor": "remorcher",
    "remorcherul": "remorcher",
    "remorcherului": "remorcher",
    "nemairemunerând": "remunera",
    "nemairemunerându": "remunera",
    "neremunerând": "remunera",
    "neremunerându": "remunera",
    "remuneră": "remunera",
    "remunerai": "remunera",
    "remuneram": "remunera",
    "remunerăm": "remunera",
    "remunerând": "remunera",
    "remunerându": "remunera",
    "remunerară": "remunera",
    "remunerarăm": "remunera",
    "remunerarăți": "remunera",
    "remunerase": "remunera",
    "remunerasem": "remunera",
    "remuneraseră": "remunera",
    "remuneraserăm": "remunera",
    "remuneraserăți": "remunera",
    "remuneraseși": "remunera",
    "remunerași": "remunera",
    "remunerat": "remunera",
    "remunerați": "remunera",
    "remunerau": "remunera",
    "remunerează": "remunera",
    "remunerez": "remunera",
    "remunereze": "remunera",
    "remunerezi": "remunera",
    "remunerată": "remunerat",
    "remunerate": "remunerat",
    "remunerați": "remunerat",
    "remunerația": "remunerație",
    "remunerației": "remunerație",
    "remunerații": "remunerație",
    "remunerațiile": "remunerație",
    "remunerațiilor": "remunerație",
    "remuneratoria": "remuneratoriu",
    "remuneratorie": "remuneratoriu",
    "remuneratoriei": "remuneratoriu",
    "remuneratorii": "remuneratoriu",
    "remuneratoriii": "remuneratoriu",
    "remuneratoriile": "remuneratoriu",
    "remuneratoriilor": "remuneratoriu",
    "remuneratoriul": "remuneratoriu",
    "remuneratoriului": "remuneratoriu",
    "remușcarea": "remușcare",
    "remușcări": "remușcare",
    "remușcării": "remușcare",
    "remușcările": "remușcare",
    "remușcărilor": "remușcare",
    "reni": "ren",
    "renii": "ren",
    "renilor": "ren",
    "renul": "ren",
    "renului": "ren",
    "renala": "renal",
    "renală": "renal",
    "renale": "renal",
    "renalei": "renal",
    "renalele": "renal",
    "renalelor": "renal",
    "renali": "renal",
    "renalii": "renal",
    "renalilor": "renal",
    "renalul": "renal",
    "renalului": "renal",
    "renascentista": "renascentist",
    "renascentistă": "renascentist",
    "renascentiste": "renascentist",
    "renascentistei": "renascentist",
    "renascentistele": "renascentist",
    "renascentistelor": "renascentist",
    "renascentiști": "renascentist",
    "renascentiștii": "renascentist",
    "renascentiștilor": "renascentist",
    "renascentistul": "renascentist",
    "renascentistului": "renascentist",
    "renăscuta": "renăscut",
    "renăscută": "renăscut",
    "renăscute": "renăscut",
    "renăscutei": "renăscut",
    "renăscutele": "renăscut",
    "renăscutelor": "renăscut",
    "renăscuți": "renăscut",
    "renăscuții": "renăscut",
    "renăscuților": "renăscut",
    "renăscutul": "renăscut",
    "renăscutului": "renăscut",
    "nemairenăscând": "renaște",
    "nemairenăscându": "renaște",
    "nerenăscând": "renaște",
    "nerenăscându": "renaște",
    "renasc": "renaște",
    "renască": "renaște",
    "renăscând": "renaște",
    "renăscându": "renaște",
    "renăscu": "renaște",
    "renăscui": "renaște",
    "renăscură": "renaște",
    "renăscurăm": "renaște",
    "renăscurăți": "renaște",
    "renăscuse": "renaște",
    "renăscusem": "renaște",
    "renăscuseră": "renaște",
    "renăscuserăm": "renaște",
    "renăscuserăți": "renaște",
    "renăscuseși": "renaște",
    "renăscuși": "renaște",
    "renăscut": "renaște",
    "renăștea": "renaște",
    "renășteai": "renaște",
    "renășteam": "renaște",
    "renășteați": "renaște",
    "renășteau": "renaște",
    "renaștem": "renaște",
    "renașteți": "renaște",
    "renaști": "renaște",
    "renașterea": "renaștere",
    "renașteri": "renaștere",
    "renașterii": "renaștere",
    "renașterile": "renaștere",
    "renașterilor": "renaștere",
    "nemairenegând": "renega",
    "nemairenegându": "renega",
    "nerenegând": "renega",
    "nerenegându": "renega",
    "reneagă": "renega",
    "reneg": "renega",
    "renegă": "renega",
    "renegai": "renega",
    "renegam": "renega",
    "renegăm": "renega",
    "renegând": "renega",
    "renegându": "renega",
    "renegară": "renega",
    "renegarăm": "renega",
    "renegarăți": "renega",
    "renegase": "renega",
    "renegasem": "renega",
    "renegaseră": "renega",
    "renegaserăm": "renega",
    "renegaserăți": "renega",
    "renegaseși": "renega",
    "renegași": "renega",
    "renegat": "renega",
    "renegați": "renega",
    "renegau": "renega",
    "renege": "renega",
    "renegi": "renega",
    "renegarea": "renegare",
    "renegareo": "renegare",
    "renegări": "renegare",
    "renegării": "renegare",
    "renegările": "renegare",
    "renegărilor": "renegare",
    "renegata": "renegat",
    "renegată": "renegat",
    "renegate": "renegat",
    "renegatei": "renegat",
    "renegatele": "renegat",
    "renegatelor": "renegat",
    "renegați": "renegat",
    "renegații": "renegat",
    "renegaților": "renegat",
    "renegato": "renegat",
    "renegatul": "renegat",
    "renegatule": "renegat",
    "renegatului": "renegat",
    "renghiul": "renghi",
    "renghiului": "renghi",
    "renghiuri": "renghi",
    "renghiurile": "renghi",
    "renghiurilor": "renghi",
    "renglota": "renglotă",
    "renglote": "renglotă",
    "renglotei": "renglotă",
    "renglotele": "renglotă",
    "renglotelor": "renglotă",
    "nemairenovând": "renova",
    "nemairenovându": "renova",
    "nerenovând": "renova",
    "nerenovându": "renova",
    "renovă": "renova",
    "renovai": "renova",
    "renovam": "renova",
    "renovăm": "renova",
    "renovând": "renova",
    "renovându": "renova",
    "renovară": "renova",
    "renovarăm": "renova",
    "renovarăți": "renova",
    "renovase": "renova",
    "renovasem": "renova",
    "renovaseră": "renova",
    "renovaserăm": "renova",
    "renovaserăți": "renova",
    "renovaseși": "renova",
    "renovași": "renova",
    "renovat": "renova",
    "renovați": "renova",
    "renovau": "renova",
    "renovează": "renova",
    "renovez": "renova",
    "renoveze": "renova",
    "renovezi": "renova",
    "renovarea": "renovare",
    "renovări": "renovare",
    "renovării": "renovare",
    "renovările": "renovare",
    "renovărilor": "renovare",
    "renovată": "renovat",
    "renovate": "renovat",
    "renovați": "renovat",
    "nemairentând": "renta",
    "nemairentându": "renta",
    "nerentând": "renta",
    "nerentându": "renta",
    "rentă": "renta",
    "rentai": "renta",
    "rentam": "renta",
    "rentăm": "renta",
    "rentând": "renta",
    "rentându": "renta",
    "rentară": "renta",
    "rentarăm": "renta",
    "rentarăți": "renta",
    "rentase": "renta",
    "rentasem": "renta",
    "rentaseră": "renta",
    "rentaserăm": "renta",
    "rentaserăți": "renta",
    "rentaseși": "renta",
    "rentași": "renta",
    "rentat": "renta",
    "rentați": "renta",
    "rentau": "renta",
    "rentează": "renta",
    "rentez": "renta",
    "renteze": "renta",
    "rentezi": "renta",
    "renta": "rentă",
    "rente": "rentă",
    "rentei": "rentă",
    "rentele": "rentă",
    "rentelor": "rentă",
    "rentabilă": "rentabil",
    "rentabile": "rentabil",
    "rentabili": "rentabil",
    "rentabilitatea": "rentabilitate",
    "rentabilități": "rentabilitate",
    "rentabilității": "rentabilitate",
    "rentabilitățile": "rentabilitate",
    "rentabilităților": "rentabilitate",
    "rentabilizarea": "rentabilizare",
    "rentabilizări": "rentabilizare",
    "rentabilizării": "rentabilizare",
    "rentabilizările": "rentabilizare",
    "rentată": "rentat",
    "rentate": "rentat",
    "rentați": "rentat",
    "rentieri": "rentier",
    "rentierii": "rentier",
    "rentierilor": "rentier",
    "rentierul": "rentier",
    "rentierului": "rentier",
    "renumele": "renume",
    "renumelor": "renume",
    "renumelui": "renume",
    "nemairenumind": "renumi",
    "nemairenumindu": "renumi",
    "nerenumind": "renumi",
    "nerenumindu": "renumi",
    "renumea": "renumi",
    "renumeai": "renumi",
    "renumeam": "renumi",
    "renumească": "renumi",
    "renumeați": "renumi",
    "renumeau": "renumi",
    "renumesc": "renumi",
    "renumește": "renumi",
    "renumești": "renumi",
    "renumii": "renumi",
    "renumim": "renumi",
    "renumind": "renumi",
    "renumindu": "renumi",
    "renumiră": "renumi",
    "renumirăm": "renumi",
    "renumirăți": "renumi",
    "renumise": "renumi",
    "renumisem": "renumi",
    "renumiseră": "renumi",
    "renumiserăm": "renumi",
    "renumiserăți": "renumi",
    "renumiseși": "renumi",
    "renumiși": "renumi",
    "renumit": "renumi",
    "renumiți": "renumi",
    "renumita": "renumit",
    "renumită": "renumit",
    "renumite": "renumit",
    "renumitei": "renumit",
    "renumitele": "renumit",
    "renumitelor": "renumit",
    "renumiți": "renumit",
    "renumiții": "renumit",
    "renumiților": "renumit",
    "renumitul": "renumit",
    "renumitului": "renumit",
    "nemairenunțând": "renunța",
    "nemairenunțându": "renunța",
    "nerenunțând": "renunța",
    "nerenunțându": "renunța",
    "renunț": "renunța",
    "renunță": "renunța",
    "renunțai": "renunța",
    "renunțam": "renunța",
    "renunțăm": "renunța",
    "renunțând": "renunța",
    "renunțându": "renunța",
    "renunțară": "renunța",
    "renunțarăm": "renunța",
    "renunțarăți": "renunța",
    "renunțase": "renunța",
    "renunțasem": "renunța",
    "renunțaseră": "renunța",
    "renunțaserăm": "renunța",
    "renunțaserăți": "renunța",
    "renunțaseși": "renunța",
    "renunțași": "renunța",
    "renunțat": "renunța",
    "renunțați": "renunța",
    "renunțau": "renunța",
    "renunțe": "renunța",
    "renunți": "renunța",
    "renunțarea": "renunțare",
    "renunțareo": "renunțare",
    "renunțări": "renunțare",
    "renunțării": "renunțare",
    "renunțările": "renunțare",
    "renunțărilor": "renunțare",
    "renunțată": "renunțat",
    "renunțate": "renunțat",
    "renunțați": "renunțat",
    "reobișnuirea": "reobișnuire",
    "reobișnuiri": "reobișnuire",
    "reobișnuirii": "reobișnuire",
    "reobișnuirile": "reobișnuire",
    "reobișnuirilor": "reobișnuire",
    "nemaireocupând": "reocupa",
    "nemaireocupându": "reocupa",
    "nereocupând": "reocupa",
    "nereocupându": "reocupa",
    "reocup": "reocupa",
    "reocupă": "reocupa",
    "reocupai": "reocupa",
    "reocupam": "reocupa",
    "reocupăm": "reocupa",
    "reocupând": "reocupa",
    "reocupându": "reocupa",
    "reocupară": "reocupa",
    "reocuparăm": "reocupa",
    "reocuparăți": "reocupa",
    "reocupase": "reocupa",
    "reocupasem": "reocupa",
    "reocupaseră": "reocupa",
    "reocupaserăm": "reocupa",
    "reocupaserăți": "reocupa",
    "reocupaseși": "reocupa",
    "reocupași": "reocupa",
    "reocupat": "reocupa",
    "reocupați": "reocupa",
    "reocupau": "reocupa",
    "reocupe": "reocupa",
    "reocupi": "reocupa",
    "reocupată": "reocupat",
    "reocupate": "reocupat",
    "reocupați": "reocupat",
    "reorânduia": "reorândui",
    "reorânduiai": "reorândui",
    "reorânduiam": "reorândui",
    "reorânduiască": "reorândui",
    "reorânduiați": "reorândui",
    "reorânduiau": "reorândui",
    "reorânduiesc": "reorândui",
    "reorânduiește": "reorândui",
    "reorânduiești": "reorândui",
    "reorânduii": "reorândui",
    "reorânduim": "reorândui",
    "reorânduind": "reorândui",
    "reorânduindu": "reorândui",
    "reorânduiră": "reorândui",
    "reorânduirăm": "reorândui",
    "reorânduirăți": "reorândui",
    "reorânduise": "reorândui",
    "reorânduisem": "reorândui",
    "reorânduiseră": "reorândui",
    "reorânduiserăm": "reorândui",
    "reorânduiserăți": "reorândui",
    "reorânduiseși": "reorândui",
    "reorânduiși": "reorândui",
    "reorânduit": "reorândui",
    "reorânduiți": "reorândui",
    "reorânduitu": "reorândui",
    "reorânduită": "reorânduit",
    "reorânduite": "reorânduit",
    "reorânduiți": "reorânduit",
    "nemaireorganizând": "reorganiza",
    "nemaireorganizându": "reorganiza",
    "nereorganizând": "reorganiza",
    "nereorganizându": "reorganiza",
    "reorganiză": "reorganiza",
    "reorganizai": "reorganiza",
    "reorganizam": "reorganiza",
    "reorganizăm": "reorganiza",
    "reorganizând": "reorganiza",
    "reorganizându": "reorganiza",
    "reorganizară": "reorganiza",
    "reorganizarăm": "reorganiza",
    "reorganizarăți": "reorganiza",
    "reorganizase": "reorganiza",
    "reorganizasem": "reorganiza",
    "reorganizaseră": "reorganiza",
    "reorganizaserăm": "reorganiza",
    "reorganizaserăți": "reorganiza",
    "reorganizaseși": "reorganiza",
    "reorganizași": "reorganiza",
    "reorganizat": "reorganiza",
    "reorganizați": "reorganiza",
    "reorganizatu": "reorganiza",
    "reorganizau": "reorganiza",
    "reorganizează": "reorganiza",
    "reorganizez": "reorganiza",
    "reorganizeze": "reorganiza",
    "reorganizezi": "reorganiza",
    "reorganizarea": "reorganizare",
    "reorganizări": "reorganizare",
    "reorganizării": "reorganizare",
    "reorganizările": "reorganizare",
    "reorganizărilor": "reorganizare",
    "reorganizată": "reorganizat",
    "reorganizate": "reorganizat",
    "reorganizați": "reorganizat",
    "reorganizatoarea": "reorganizatoare",
    "reorganizatoarei": "reorganizatoare",
    "reorganizatoarele": "reorganizatoare",
    "reorganizatoarelor": "reorganizatoare",
    "reorganizatoareo": "reorganizatoare",
    "reorganizatorii": "reorganizator",
    "reorganizatorul": "reorganizator",
    "reorganizatorule": "reorganizator",
    "reorganizatorului": "reorganizator",
    "reostate": "reostat",
    "reostatele": "reostat",
    "reostatelor": "reostat",
    "reostatul": "reostat",
    "reostatului": "reostat",
    "nemaireparând": "repara",
    "nemaireparându": "repara",
    "nereparând": "repara",
    "nereparându": "repara",
    "repar": "repara",
    "repară": "repara",
    "reparai": "repara",
    "reparam": "repara",
    "reparăm": "repara",
    "reparând": "repara",
    "reparându": "repara",
    "reparară": "repara",
    "repararăm": "repara",
    "repararăți": "repara",
    "reparase": "repara",
    "reparasem": "repara",
    "reparaseră": "repara",
    "reparaserăm": "repara",
    "reparaserăți": "repara",
    "reparaseși": "repara",
    "reparași": "repara",
    "reparat": "repara",
    "reparați": "repara",
    "reparau": "repara",
    "repare": "repara",
    "repari": "repara",
    "reparabila": "reparabil",
    "reparabilă": "reparabil",
    "reparabile": "reparabil",
    "reparabilei": "reparabil",
    "reparabilele": "reparabil",
    "reparabilelor": "reparabil",
    "reparabili": "reparabil",
    "reparabilii": "reparabil",
    "reparabililor": "reparabil",
    "reparabilo": "reparabil",
    "reparabilul": "reparabil",
    "reparabilule": "reparabil",
    "reparabilului": "reparabil",
    "repararea": "reparare",
    "reparareo": "reparare",
    "reparări": "reparare",
    "reparării": "reparare",
    "reparările": "reparare",
    "reparărilor": "reparare",
    "reparată": "reparat",
    "reparate": "reparat",
    "reparați": "reparat",
    "reparația": "reparație",
    "reparației": "reparație",
    "reparații": "reparație",
    "reparațiile": "reparație",
    "reparațiilor": "reparație",
    "reparatoare": "reparator",
    "reparatoarea": "reparator",
    "reparatoarei": "reparator",
    "reparatoarele": "reparator",
    "reparatoarelor": "reparator",
    "reparatoareo": "reparator",
    "reparatori": "reparator",
    "reparatorii": "reparator",
    "reparatorilor": "reparator",
    "reparatorul": "reparator",
    "reparatorule": "reparator",
    "reparatorului": "reparator",
    "reparatoria": "reparatoriu",
    "reparatorie": "reparatoriu",
    "reparatoriei": "reparatoriu",
    "reparatorii": "reparatoriu",
    "reparatoriii": "reparatoriu",
    "reparatoriile": "reparatoriu",
    "reparatoriilor": "reparatoriu",
    "reparatoriul": "reparatoriu",
    "reparatoriului": "reparatoriu",
    "repartiția": "repartiție",
    "repartiției": "repartiție",
    "repartiții": "repartiție",
    "repartițiile": "repartiție",
    "repartițiilor": "repartiție",
    "nemairepartizând": "repartiza",
    "nemairepartizându": "repartiza",
    "nerepartizând": "repartiza",
    "nerepartizându": "repartiza",
    "repartiză": "repartiza",
    "repartizai": "repartiza",
    "repartizam": "repartiza",
    "repartizăm": "repartiza",
    "repartizând": "repartiza",
    "repartizându": "repartiza",
    "repartizară": "repartiza",
    "repartizarăm": "repartiza",
    "repartizarăți": "repartiza",
    "repartizase": "repartiza",
    "repartizasem": "repartiza",
    "repartizaseră": "repartiza",
    "repartizaserăm": "repartiza",
    "repartizaserăți": "repartiza",
    "repartizaseși": "repartiza",
    "repartizași": "repartiza",
    "repartizat": "repartiza",
    "repartizați": "repartiza",
    "repartizau": "repartiza",
    "repartizează": "repartiza",
    "repartizez": "repartiza",
    "repartizeze": "repartiza",
    "repartizezi": "repartiza",
    "repartizarea": "repartizare",
    "repartizări": "repartizare",
    "repartizării": "repartizare",
    "repartizările": "repartizare",
    "repartizărilor": "repartizare",
    "repartizată": "repartizat",
    "repartizate": "repartizat",
    "repartizați": "repartizat",
    "nemairepatriind": "repatria",
    "nemairepatriindu": "repatria",
    "nerepatriind": "repatria",
    "nerepatriindu": "repatria",
    "repatriai": "repatria",
    "repatriam": "repatria",
    "repatriară": "repatria",
    "repatriarăm": "repatria",
    "repatriarăți": "repatria",
    "repatriase": "repatria",
    "repatriasem": "repatria",
    "repatriaseră": "repatria",
    "repatriaserăm": "repatria",
    "repatriaserăți": "repatria",
    "repatriaseși": "repatria",
    "repatriași": "repatria",
    "repatriat": "repatria",
    "repatriați": "repatria",
    "repatriau": "repatria",
    "repatriază": "repatria",
    "repatrie": "repatria",
    "repatriem": "repatria",
    "repatriez": "repatria",
    "repatrieze": "repatria",
    "repatriezi": "repatria",
    "repatriind": "repatria",
    "repatriindu": "repatria",
    "repatriată": "repatriat",
    "repatriate": "repatriat",
    "repatriați": "repatriat",
    "repatrierea": "repatriere",
    "repatrieri": "repatriere",
    "repatrierii": "repatriere",
    "repatrierile": "repatriere",
    "repatrierilor": "repatriere",
    "repausul": "repaus",
    "repausului": "repaus",
    "repausuri": "repaus",
    "repausurile": "repaus",
    "repausurilor": "repaus",
    "nemairepauzând": "repauza",
    "nemairepauzându": "repauza",
    "nerepauzând": "repauza",
    "nerepauzându": "repauza",
    "repauză": "repauza",
    "repauzai": "repauza",
    "repauzam": "repauza",
    "repauzăm": "repauza",
    "repauzând": "repauza",
    "repauzându": "repauza",
    "repauzară": "repauza",
    "repauzarăm": "repauza",
    "repauzarăți": "repauza",
    "repauzase": "repauza",
    "repauzasem": "repauza",
    "repauzaseră": "repauza",
    "repauzaserăm": "repauza",
    "repauzaserăți": "repauza",
    "repauzaseși": "repauza",
    "repauzași": "repauza",
    "repauzat": "repauza",
    "repauzați": "repauza",
    "repauzau": "repauza",
    "repauzează": "repauza",
    "repauzez": "repauza",
    "repauzeze": "repauza",
    "repauzezi": "repauza",
    "repauzată": "repauzat",
    "repauzate": "repauzat",
    "repauzați": "repauzat",
    "repedea": "repede",
    "repedele": "repede",
    "repedelui": "repede",
    "repezi": "repede",
    "repezii": "repede",
    "repezile": "repede",
    "repezilor": "repede",
    "repere": "reper",
    "reperele": "reper",
    "reperelor": "reper",
    "reperul": "reper",
    "reperului": "reper",
    "nemaireperând": "repera",
    "nemaireperându": "repera",
    "nereperând": "repera",
    "nereperându": "repera",
    "reperă": "repera",
    "reperai": "repera",
    "reperam": "repera",
    "reperăm": "repera",
    "reperând": "repera",
    "reperându": "repera",
    "reperară": "repera",
    "reperarăm": "repera",
    "reperarăți": "repera",
    "reperase": "repera",
    "reperasem": "repera",
    "reperaseră": "repera",
    "reperaserăm": "repera",
    "reperaserăți": "repera",
    "reperaseși": "repera",
    "reperași": "repera",
    "reperat": "repera",
    "reperați": "repera",
    "reperau": "repera",
    "reperează": "repera",
    "reperez": "repera",
    "repereze": "repera",
    "reperezi": "repera",
    "reperată": "reperat",
    "reperate": "reperat",
    "reperați": "reperat",
    "repercusiunea": "repercusiune",
    "repercusiuni": "repercusiune",
    "repercusiunii": "repercusiune",
    "repercusiunile": "repercusiune",
    "repercusiunilor": "repercusiune",
    "repercută": "repercuta",
    "repercutai": "repercuta",
    "repercutam": "repercuta",
    "repercutăm": "repercuta",
    "repercutând": "repercuta",
    "repercutându": "repercuta",
    "repercutară": "repercuta",
    "repercutarăm": "repercuta",
    "repercutarăți": "repercuta",
    "repercutase": "repercuta",
    "repercutasem": "repercuta",
    "repercutaseră": "repercuta",
    "repercutaserăm": "repercuta",
    "repercutaserăți": "repercuta",
    "repercutaseși": "repercuta",
    "repercutași": "repercuta",
    "repercutat": "repercuta",
    "repercutați": "repercuta",
    "repercutau": "repercuta",
    "repercutează": "repercuta",
    "repercutez": "repercuta",
    "repercuteze": "repercuta",
    "repercutezi": "repercuta",
    "repercutarea": "repercutare",
    "repercutări": "repercutare",
    "repercutării": "repercutare",
    "repercutările": "repercutare",
    "repercutărilor": "repercutare",
    "repercutata": "repercutat",
    "repercutată": "repercutat",
    "repercutate": "repercutat",
    "repercutatei": "repercutat",
    "repercutatele": "repercutat",
    "repercutatelor": "repercutat",
    "repercutați": "repercutat",
    "repercutații": "repercutat",
    "repercutaților": "repercutat",
    "repercutato": "repercutat",
    "repercutatul": "repercutat",
    "repercutatule": "repercutat",
    "repercutatului": "repercutat",
    "repertorii": "repertoriu",
    "repertoriile": "repertoriu",
    "repertoriilor": "repertoriu",
    "repertoriul": "repertoriu",
    "repertoriului": "repertoriu",
    "nemairepetând": "repeta",
    "nemairepetându": "repeta",
    "nerepetând": "repeta",
    "nerepetându": "repeta",
    "repet": "repeta",
    "repetă": "repeta",
    "repetai": "repeta",
    "repetam": "repeta",
    "repetăm": "repeta",
    "repetând": "repeta",
    "repetându": "repeta",
    "repetară": "repeta",
    "repetarăm": "repeta",
    "repetarăți": "repeta",
    "repetase": "repeta",
    "repetasem": "repeta",
    "repetaseră": "repeta",
    "repetaserăm": "repeta",
    "repetaserăți": "repeta",
    "repetaseși": "repeta",
    "repetași": "repeta",
    "repetat": "repeta",
    "repetați": "repeta",
    "repetau": "repeta",
    "repete": "repeta",
    "repeți": "repeta",
    "repetabila": "repetabil",
    "repetabilă": "repetabil",
    "repetabile": "repetabil",
    "repetabilei": "repetabil",
    "repetabilele": "repetabil",
    "repetabilelor": "repetabil",
    "repetabili": "repetabil",
    "repetabilii": "repetabil",
    "repetabililor": "repetabil",
    "repetabilo": "repetabil",
    "repetabilul": "repetabil",
    "repetabilule": "repetabil",
    "repetabilului": "repetabil",
    "repetarea": "repetare",
    "repetareo": "repetare",
    "repetări": "repetare",
    "repetării": "repetare",
    "repetările": "repetare",
    "repetărilor": "repetare",
    "repetata": "repetat",
    "repetată": "repetat",
    "repetate": "repetat",
    "repetatei": "repetat",
    "repetatele": "repetat",
    "repetatelor": "repetat",
    "repetați": "repetat",
    "repetații": "repetat",
    "repetaților": "repetat",
    "repetato": "repetat",
    "repetatul": "repetat",
    "repetatule": "repetat",
    "repetatului": "repetat",
    "repetenta": "repetent",
    "repetentă": "repetent",
    "repetente": "repetent",
    "repetentei": "repetent",
    "repetentele": "repetent",
    "repetentelor": "repetent",
    "repetenți": "repetent",
    "repetenții": "repetent",
    "repetenților": "repetent",
    "repetentul": "repetent",
    "repetentului": "repetent",
    "repetenția": "repetenție",
    "repetenției": "repetenție",
    "repetenții": "repetenție",
    "repetențiile": "repetenție",
    "repetențiilor": "repetenție",
    "repetiția": "repetiție",
    "repetiției": "repetiție",
    "repetiții": "repetiție",
    "repetițiile": "repetiție",
    "repetițiilor": "repetiție",
    "repezeala": "repezeală",
    "repezeli": "repezeală",
    "repezelii": "repezeală",
    "repezelile": "repezeală",
    "repezelilor": "repezeală",
    "nemairepezind": "repezi",
    "nemairepezindu": "repezi",
    "nerepezind": "repezi",
    "nerepezindu": "repezi",
    "repeadă": "repezi",
    "reped": "repezi",
    "repede": "repezi",
    "repezea": "repezi",
    "repezeai": "repezi",
    "repezeam": "repezi",
    "repezeați": "repezi",
    "repezeau": "repezi",
    "repezii": "repezi",
    "repezim": "repezi",
    "repezind": "repezi",
    "repezindu": "repezi",
    "repeziră": "repezi",
    "repezirăm": "repezi",
    "repezirăți": "repezi",
    "repezise": "repezi",
    "repezisem": "repezi",
    "repeziseră": "repezi",
    "repeziserăm": "repezi",
    "repeziserăți": "repezi",
    "repeziseși": "repezi",
    "repeziși": "repezi",
    "repezit": "repezi",
    "repeziți": "repezi",
    "repeziciunea": "repeziciune",
    "repeziciuni": "repeziciune",
    "repeziciunii": "repeziciune",
    "repeziciunile": "repeziciune",
    "repeziciunilor": "repeziciune",
    "repezirea": "repezire",
    "repeziri": "repezire",
    "repezirii": "repezire",
    "repezirile": "repezire",
    "repezirilor": "repezire",
    "repezită": "repezit",
    "repezite": "repezit",
    "repeziți": "repezit",
    "nemaireplantând": "replanta",
    "nemaireplantându": "replanta",
    "nereplantând": "replanta",
    "nereplantându": "replanta",
    "replantă": "replanta",
    "replantai": "replanta",
    "replantam": "replanta",
    "replantăm": "replanta",
    "replantând": "replanta",
    "replantându": "replanta",
    "replantară": "replanta",
    "replantarăm": "replanta",
    "replantarăți": "replanta",
    "replantase": "replanta",
    "replantasem": "replanta",
    "replantaseră": "replanta",
    "replantaserăm": "replanta",
    "replantaserăți": "replanta",
    "replantaseși": "replanta",
    "replantași": "replanta",
    "replantat": "replanta",
    "replantați": "replanta",
    "replantau": "replanta",
    "replantează": "replanta",
    "replantez": "replanta",
    "replanteze": "replanta",
    "replantezi": "replanta",
    "replantarea": "replantare",
    "replantări": "replantare",
    "replantării": "replantare",
    "replantările": "replantare",
    "replantărilor": "replantare",
    "replantată": "replantat",
    "replantate": "replantat",
    "replantați": "replantat",
    "nemairepliind": "replia",
    "nemairepliindu": "replia",
    "nerepliind": "replia",
    "nerepliindu": "replia",
    "repliai": "replia",
    "repliam": "replia",
    "repliară": "replia",
    "repliarăm": "replia",
    "repliarăți": "replia",
    "repliase": "replia",
    "repliasem": "replia",
    "repliaseră": "replia",
    "repliaserăm": "replia",
    "repliaserăți": "replia",
    "repliaseși": "replia",
    "repliași": "replia",
    "repliat": "replia",
    "repliați": "replia",
    "repliau": "replia",
    "repliază": "replia",
    "replie": "replia",
    "repliem": "replia",
    "repliez": "replia",
    "replieze": "replia",
    "repliezi": "replia",
    "repliind": "replia",
    "repliindu": "replia",
    "repliată": "repliat",
    "repliate": "repliat",
    "repliați": "repliat",
    "nemaireplicând": "replica",
    "nemaireplicându": "replica",
    "nereplicând": "replica",
    "nereplicându": "replica",
    "replic": "replica",
    "replică": "replica",
    "replicai": "replica",
    "replicam": "replica",
    "replicăm": "replica",
    "replicând": "replica",
    "replicându": "replica",
    "replicară": "replica",
    "replicarăm": "replica",
    "replicarăți": "replica",
    "replicase": "replica",
    "replicasem": "replica",
    "replicaseră": "replica",
    "replicaserăm": "replica",
    "replicaserăți": "replica",
    "replicaseși": "replica",
    "replicași": "replica",
    "replicat": "replica",
    "replicați": "replica",
    "replicau": "replica",
    "replice": "replica",
    "replici": "replica",
    "replica": "replică",
    "replici": "replică",
    "replicii": "replică",
    "replicile": "replică",
    "replicilor": "replică",
    "replicată": "replicat",
    "replicate": "replicat",
    "replicați": "replicat",
    "nemairepopulând": "repopula",
    "nemairepopulându": "repopula",
    "nerepopulând": "repopula",
    "nerepopulându": "repopula",
    "repopulă": "repopula",
    "repopulai": "repopula",
    "repopulam": "repopula",
    "repopulăm": "repopula",
    "repopulând": "repopula",
    "repopulându": "repopula",
    "repopulară": "repopula",
    "repopularăm": "repopula",
    "repopularăți": "repopula",
    "repopulase": "repopula",
    "repopulasem": "repopula",
    "repopulaseră": "repopula",
    "repopulaserăm": "repopula",
    "repopulaserăți": "repopula",
    "repopulaseși": "repopula",
    "repopulași": "repopula",
    "repopulat": "repopula",
    "repopulați": "repopula",
    "repopulau": "repopula",
    "repopulează": "repopula",
    "repopulez": "repopula",
    "repopuleze": "repopula",
    "repopulezi": "repopula",
    "repopularea": "repopulare",
    "repopulări": "repopulare",
    "repopulării": "repopulare",
    "repopulările": "repopulare",
    "repopulărilor": "repopulare",
    "repopulată": "repopulat",
    "repopulate": "repopulat",
    "repopulați": "repopulat",
    "reportul": "report",
    "reportului": "report",
    "reporturi": "report",
    "reporturile": "report",
    "reporturilor": "report",
    "nemaireportând": "reporta",
    "nemaireportându": "reporta",
    "nereportând": "reporta",
    "nereportându": "reporta",
    "reportă": "reporta",
    "reportai": "reporta",
    "reportam": "reporta",
    "reportăm": "reporta",
    "reportând": "reporta",
    "reportându": "reporta",
    "reportară": "reporta",
    "reportarăm": "reporta",
    "reportarăți": "reporta",
    "reportase": "reporta",
    "reportasem": "reporta",
    "reportaseră": "reporta",
    "reportaserăm": "reporta",
    "reportaserăți": "reporta",
    "reportaseși": "reporta",
    "reportași": "reporta",
    "reportat": "reporta",
    "reportați": "reporta",
    "reportau": "reporta",
    "reportează": "reporta",
    "reportez": "reporta",
    "reporteze": "reporta",
    "reportezi": "reporta",
    "reportaje": "reportaj",
    "reportajele": "reportaj",
    "reportajelor": "reportaj",
    "reportajul": "reportaj",
    "reportajului": "reportaj",
    "reportată": "reportat",
    "reportate": "reportat",
    "reportați": "reportat",
    "reporteri": "reporter",
    "reporterii": "reporter",
    "reporterilor": "reporter",
    "reporterul": "reporter",
    "reporterului": "reporter",
    "reprehensibila": "reprehensibil",
    "reprehensibilă": "reprehensibil",
    "reprehensibile": "reprehensibil",
    "reprehensibilei": "reprehensibil",
    "reprehensibilele": "reprehensibil",
    "reprehensibilelor": "reprehensibil",
    "reprehensibili": "reprehensibil",
    "reprehensibilii": "reprehensibil",
    "reprehensibililor": "reprehensibil",
    "reprehensibilul": "reprehensibil",
    "reprehensibilului": "reprehensibil",
    "represaliile": "represalii",
    "represaliilor": "represalii",
    "represiunea": "represiune",
    "represiuni": "represiune",
    "represiunii": "represiune",
    "represiunile": "represiune",
    "represiunilor": "represiune",
    "represiva": "represiv",
    "represivă": "represiv",
    "represive": "represiv",
    "represivei": "represiv",
    "represivele": "represiv",
    "represivelor": "represiv",
    "represivi": "represiv",
    "represivii": "represiv",
    "represivilor": "represiv",
    "represivul": "represiv",
    "represivului": "represiv",
    "nemaireprezentând": "reprezenta",
    "nemaireprezentându": "reprezenta",
    "nereprezentând": "reprezenta",
    "nereprezentându": "reprezenta",
    "reprezentă": "reprezenta",
    "reprezentai": "reprezenta",
    "reprezentam": "reprezenta",
    "reprezentăm": "reprezenta",
    "reprezentând": "reprezenta",
    "reprezentându": "reprezenta",
    "reprezentară": "reprezenta",
    "reprezentarăm": "reprezenta",
    "reprezentarăți": "reprezenta",
    "reprezentase": "reprezenta",
    "reprezentasem": "reprezenta",
    "reprezentaseră": "reprezenta",
    "reprezentaserăm": "reprezenta",
    "reprezentaserăți": "reprezenta",
    "reprezentaseși": "reprezenta",
    "reprezentași": "reprezenta",
    "reprezentat": "reprezenta",
    "reprezentați": "reprezenta",
    "reprezentau": "reprezenta",
    "reprezint": "reprezenta",
    "reprezintă": "reprezenta",
    "reprezinte": "reprezenta",
    "reprezinți": "reprezenta",
    "reprezentanți": "reprezentant",
    "reprezentanții": "reprezentant",
    "reprezentanților": "reprezentant",
    "reprezentantul": "reprezentant",
    "reprezentantule": "reprezentant",
    "reprezentantului": "reprezentant",
    "reprezentanta": "reprezentantă",
    "reprezentante": "reprezentantă",
    "reprezentantei": "reprezentantă",
    "reprezentantele": "reprezentantă",
    "reprezentantelor": "reprezentantă",
    "reprezentanța": "reprezentanță",
    "reprezentanțe": "reprezentanță",
    "reprezentanței": "reprezentanță",
    "reprezentanțele": "reprezentanță",
    "reprezentanțelor": "reprezentanță",
    "reprezentarea": "reprezentare",
    "reprezentareo": "reprezentare",
    "reprezentări": "reprezentare",
    "reprezentării": "reprezentare",
    "reprezentările": "reprezentare",
    "reprezentărilor": "reprezentare",
    "reprezentată": "reprezentat",
    "reprezentate": "reprezentat",
    "reprezentați": "reprezentat",
    "reprezentația": "reprezentație",
    "reprezentației": "reprezentație",
    "reprezentații": "reprezentație",
    "reprezentațiile": "reprezentație",
    "reprezentațiilor": "reprezentație",
    "reprezentativa": "reprezentativ",
    "reprezentativă": "reprezentativ",
    "reprezentative": "reprezentativ",
    "reprezentativei": "reprezentativ",
    "reprezentativele": "reprezentativ",
    "reprezentativelor": "reprezentativ",
    "reprezentativi": "reprezentativ",
    "reprezentativii": "reprezentativ",
    "reprezentativilor": "reprezentativ",
    "reprezentativul": "reprezentativ",
    "reprezentativului": "reprezentativ",
    "nemaireprimând": "reprima",
    "nemaireprimându": "reprima",
    "nereprimând": "reprima",
    "nereprimându": "reprima",
    "reprim": "reprima",
    "reprimă": "reprima",
    "reprimai": "reprima",
    "reprimam": "reprima",
    "reprimăm": "reprima",
    "reprimând": "reprima",
    "reprimându": "reprima",
    "reprimară": "reprima",
    "reprimarăm": "reprima",
    "reprimarăți": "reprima",
    "reprimase": "reprima",
    "reprimasem": "reprima",
    "reprimaseră": "reprima",
    "reprimaserăm": "reprima",
    "reprimaserăți": "reprima",
    "reprimaseși": "reprima",
    "reprimași": "reprima",
    "reprimat": "reprima",
    "reprimați": "reprima",
    "reprimau": "reprima",
    "reprime": "reprima",
    "reprimi": "reprima",
    "reprimarea": "reprimare",
    "reprimări": "reprimare",
    "reprimării": "reprimare",
    "reprimările": "reprimare",
    "reprimărilor": "reprimare",
    "reprimată": "reprimat",
    "reprimate": "reprimat",
    "reprimați": "reprimat",
    "nemaireprimind": "reprimi",
    "nemaireprimindu": "reprimi",
    "nereprimind": "reprimi",
    "nereprimindu": "reprimi",
    "reprimea": "reprimi",
    "reprimeai": "reprimi",
    "reprimeam": "reprimi",
    "reprimească": "reprimi",
    "reprimeați": "reprimi",
    "reprimeau": "reprimi",
    "reprimesc": "reprimi",
    "reprimește": "reprimi",
    "reprimești": "reprimi",
    "reprimii": "reprimi",
    "reprimim": "reprimi",
    "reprimind": "reprimi",
    "reprimindu": "reprimi",
    "reprimiră": "reprimi",
    "reprimirăm": "reprimi",
    "reprimirăți": "reprimi",
    "reprimise": "reprimi",
    "reprimisem": "reprimi",
    "reprimiseră": "reprimi",
    "reprimiserăm": "reprimi",
    "reprimiserăți": "reprimi",
    "reprimiseși": "reprimi",
    "reprimiși": "reprimi",
    "reprimit": "reprimi",
    "reprimiți": "reprimi",
    "reprimirea": "reprimire",
    "reprimireo": "reprimire",
    "reprimiri": "reprimire",
    "reprimirii": "reprimire",
    "reprimirile": "reprimire",
    "reprimirilor": "reprimire",
    "reprimită": "reprimit",
    "reprimite": "reprimit",
    "reprimiți": "reprimit",
    "repriza": "repriză",
    "reprize": "repriză",
    "reprizei": "repriză",
    "reprizele": "repriză",
    "reprizelor": "repriză",
    "nemaireprobând": "reproba",
    "nemaireprobându": "reproba",
    "nereprobând": "reproba",
    "nereprobându": "reproba",
    "reprob": "reproba",
    "reprobă": "reproba",
    "reprobai": "reproba",
    "reprobam": "reproba",
    "reprobăm": "reproba",
    "reprobând": "reproba",
    "reprobându": "reproba",
    "reprobară": "reproba",
    "reprobarăm": "reproba",
    "reprobarăți": "reproba",
    "reprobase": "reproba",
    "reprobasem": "reproba",
    "reprobaseră": "reproba",
    "reprobaserăm": "reproba",
    "reprobaserăți": "reproba",
    "reprobaseși": "reproba",
    "reprobași": "reproba",
    "reprobat": "reproba",
    "reprobați": "reproba",
    "reprobau": "reproba",
    "reprobe": "reproba",
    "reprobi": "reproba",
    "reprobarea": "reprobare",
    "reprobări": "reprobare",
    "reprobării": "reprobare",
    "reprobările": "reprobare",
    "reprobărilor": "reprobare",
    "reprobată": "reprobat",
    "reprobate": "reprobat",
    "reprobați": "reprobat",
    "reproducătoare": "reproducător",
    "reproducătoarea": "reproducător",
    "reproducătoarei": "reproducător",
    "reproducătoarele": "reproducător",
    "reproducătoarelor": "reproducător",
    "reproducători": "reproducător",
    "reproducătorii": "reproducător",
    "reproducătorilor": "reproducător",
    "reproducătorul": "reproducător",
    "reproducătorului": "reproducător",
    "nemaireproducând": "reproduce",
    "nemaireproducându": "reproduce",
    "nereproducând": "reproduce",
    "nereproducându": "reproduce",
    "reprodu": "reproduce",
    "reproduc": "reproduce",
    "reproducă": "reproduce",
    "reproducând": "reproduce",
    "reproducându": "reproduce",
    "reproducea": "reproduce",
    "reproduceai": "reproduce",
    "reproduceam": "reproduce",
    "reproduceați": "reproduce",
    "reproduceau": "reproduce",
    "reproducem": "reproduce",
    "reproduceți": "reproduce",
    "reproduci": "reproduce",
    "reprodus": "reproduce",
    "reproduse": "reproduce",
    "reprodusei": "reproduce",
    "reproduseră": "reproduce",
    "reproduserăm": "reproduce",
    "reproduserăți": "reproduce",
    "reprodusese": "reproduce",
    "reprodusesem": "reproduce",
    "reproduseseră": "reproduce",
    "reproduseserăm": "reproduce",
    "reproduseserăți": "reproduce",
    "reproduseseși": "reproduce",
    "reproduseși": "reproduce",
    "reproducerea": "reproducere",
    "reproduceri": "reproducere",
    "reproducerii": "reproducere",
    "reproducerile": "reproducere",
    "reproducerilor": "reproducere",
    "reproducția": "reproducție",
    "reproducției": "reproducție",
    "reproducții": "reproducție",
    "reproducțiile": "reproducție",
    "reproducțiilor": "reproducție",
    "reprodusă": "reprodus",
    "reproduse": "reprodus",
    "reproduși": "reprodus",
    "nemaireprofilând": "reprofila",
    "nemaireprofilându": "reprofila",
    "nereprofilând": "reprofila",
    "nereprofilându": "reprofila",
    "reprofilă": "reprofila",
    "reprofilai": "reprofila",
    "reprofilam": "reprofila",
    "reprofilăm": "reprofila",
    "reprofilând": "reprofila",
    "reprofilându": "reprofila",
    "reprofilară": "reprofila",
    "reprofilarăm": "reprofila",
    "reprofilarăți": "reprofila",
    "reprofilase": "reprofila",
    "reprofilasem": "reprofila",
    "reprofilaseră": "reprofila",
    "reprofilaserăm": "reprofila",
    "reprofilaserăți": "reprofila",
    "reprofilaseși": "reprofila",
    "reprofilași": "reprofila",
    "reprofilat": "reprofila",
    "reprofilați": "reprofila",
    "reprofilau": "reprofila",
    "reprofilează": "reprofila",
    "reprofilez": "reprofila",
    "reprofileze": "reprofila",
    "reprofilezi": "reprofila",
    "reprofilată": "reprofilat",
    "reprofilate": "reprofilat",
    "reprofilați": "reprofilat",
    "reproșul": "reproș",
    "reproșului": "reproș",
    "reproșuri": "reproș",
    "reproșurile": "reproș",
    "reproșurilor": "reproș",
    "nemaireproșând": "reproșa",
    "nemaireproșându": "reproșa",
    "nereproșând": "reproșa",
    "nereproșându": "reproșa",
    "reproșă": "reproșa",
    "reproșai": "reproșa",
    "reproșam": "reproșa",
    "reproșăm": "reproșa",
    "reproșând": "reproșa",
    "reproșându": "reproșa",
    "reproșară": "reproșa",
    "reproșarăm": "reproșa",
    "reproșarăți": "reproșa",
    "reproșase": "reproșa",
    "reproșasem": "reproșa",
    "reproșaseră": "reproșa",
    "reproșaserăm": "reproșa",
    "reproșaserăți": "reproșa",
    "reproșaseși": "reproșa",
    "reproșași": "reproșa",
    "reproșat": "reproșa",
    "reproșați": "reproșa",
    "reproșau": "reproșa",
    "reproșează": "reproșa",
    "reproșez": "reproșa",
    "reproșeze": "reproșa",
    "reproșezi": "reproșa",
    "reproșată": "reproșat",
    "reproșate": "reproșat",
    "reproșați": "reproșat",
    "reptila": "reptilă",
    "reptile": "reptilă",
    "reptilei": "reptilă",
    "reptilele": "reptilă",
    "reptilelor": "reptilă",
    "nemairepublicând": "republica",
    "nemairepublicându": "republica",
    "nerepublicând": "republica",
    "nerepublicându": "republica",
    "republic": "republica",
    "republică": "republica",
    "republicai": "republica",
    "republicam": "republica",
    "republicăm": "republica",
    "republicând": "republica",
    "republicându": "republica",
    "republicară": "republica",
    "republicarăm": "republica",
    "republicarăți": "republica",
    "republicase": "republica",
    "republicasem": "republica",
    "republicaseră": "republica",
    "republicaserăm": "republica",
    "republicaserăți": "republica",
    "republicaseși": "republica",
    "republicași": "republica",
    "republicat": "republica",
    "republicați": "republica",
    "republicau": "republica",
    "republice": "republica",
    "republici": "republica",
    "republica": "republică",
    "republici": "republică",
    "republicii": "republică",
    "republicile": "republică",
    "republicilor": "republică",
    "republicana": "republican",
    "republicană": "republican",
    "republicane": "republican",
    "republicanei": "republican",
    "republicanele": "republican",
    "republicanelor": "republican",
    "republicani": "republican",
    "republicanii": "republican",
    "republicanilor": "republican",
    "republicanul": "republican",
    "republicanului": "republican",
    "republicanismul": "republicanism",
    "republicanismului": "republicanism",
    "republicată": "republicat",
    "republicate": "republicat",
    "republicați": "republicat",
    "nemairepudiind": "repudia",
    "nemairepudiindu": "repudia",
    "nerepudiind": "repudia",
    "nerepudiindu": "repudia",
    "repudiai": "repudia",
    "repudiam": "repudia",
    "repudiară": "repudia",
    "repudiarăm": "repudia",
    "repudiarăți": "repudia",
    "repudiase": "repudia",
    "repudiasem": "repudia",
    "repudiaseră": "repudia",
    "repudiaserăm": "repudia",
    "repudiaserăți": "repudia",
    "repudiaseși": "repudia",
    "repudiași": "repudia",
    "repudiat": "repudia",
    "repudiați": "repudia",
    "repudiau": "repudia",
    "repudiază": "repudia",
    "repudie": "repudia",
    "repudiem": "repudia",
    "repudiez": "repudia",
    "repudieze": "repudia",
    "repudiezi": "repudia",
    "repudiind": "repudia",
    "repudiindu": "repudia",
    "repudiată": "repudiat",
    "repudiate": "repudiat",
    "repudiați": "repudiat",
    "repudierea": "repudiere",
    "repudieri": "repudiere",
    "repudierii": "repudiere",
    "repudierile": "repudiere",
    "repudierilor": "repudiere",
    "repulsia": "repulsie",
    "repulsiei": "repulsie",
    "repulsii": "repulsie",
    "repulsiile": "repulsie",
    "repulsiilor": "repulsie",
    "repulsiva": "repulsiv",
    "repulsivă": "repulsiv",
    "repulsive": "repulsiv",
    "repulsivei": "repulsiv",
    "repulsivele": "repulsiv",
    "repulsivelor": "repulsiv",
    "repulsivi": "repulsiv",
    "repulsivii": "repulsiv",
    "repulsivilor": "repulsiv",
    "repulsivul": "repulsiv",
    "repulsivului": "repulsiv",
    "repui": "repune",
    "repun": "repune",
    "repună": "repune",
    "repunând": "repune",
    "repunându": "repune",
    "repunea": "repune",
    "repuneai": "repune",
    "repuneam": "repune",
    "repuneați": "repune",
    "repuneau": "repune",
    "repunem": "repune",
    "repuneți": "repune",
    "repus": "repune",
    "repuse": "repune",
    "repusei": "repune",
    "repuseră": "repune",
    "repuserăm": "repune",
    "repuserăți": "repune",
    "repusese": "repune",
    "repusesem": "repune",
    "repuseseră": "repune",
    "repuseserăm": "repune",
    "repuseserăți": "repune",
    "repuseseși": "repune",
    "repuseși": "repune",
    "repusu": "repune",
    "repunerea": "repunere",
    "repuneri": "repunere",
    "repunerii": "repunere",
    "repunerile": "repunere",
    "repunerilor": "repunere",
    "nemairepurtând": "repurta",
    "nemairepurtându": "repurta",
    "nerepurtând": "repurta",
    "nerepurtându": "repurta",
    "repurtă": "repurta",
    "repurtai": "repurta",
    "repurtam": "repurta",
    "repurtăm": "repurta",
    "repurtând": "repurta",
    "repurtându": "repurta",
    "repurtară": "repurta",
    "repurtarăm": "repurta",
    "repurtarăți": "repurta",
    "repurtase": "repurta",
    "repurtasem": "repurta",
    "repurtaseră": "repurta",
    "repurtaserăm": "repurta",
    "repurtaserăți": "repurta",
    "repurtaseși": "repurta",
    "repurtași": "repurta",
    "repurtat": "repurta",
    "repurtați": "repurta",
    "repurtau": "repurta",
    "repurtează": "repurta",
    "repurtez": "repurta",
    "repurteze": "repurta",
    "repurtezi": "repurta",
    "repurtată": "repurtat",
    "repurtate": "repurtat",
    "repurtați": "repurtat",
    "repusă": "repus",
    "repuse": "repus",
    "repuși": "repus",
    "reputata": "reputat",
    "reputată": "reputat",
    "reputate": "reputat",
    "reputatei": "reputat",
    "reputatele": "reputat",
    "reputatelor": "reputat",
    "reputați": "reputat",
    "reputații": "reputat",
    "reputaților": "reputat",
    "reputato": "reputat",
    "reputatul": "reputat",
    "reputatului": "reputat",
    "reputația": "reputație",
    "reputației": "reputație",
    "reputații": "reputație",
    "reputațiile": "reputație",
    "reputațiilor": "reputație",
    "resacul": "resac",
    "resacului": "resac",
    "resacuri": "resac",
    "resacurile": "resac",
    "resacurilor": "resac",
    "resciziunea": "resciziune",
    "resciziuni": "resciziune",
    "resciziunii": "resciziune",
    "resciziunile": "resciziune",
    "resciziunilor": "resciziune",
    "nemairescriind": "rescrie",
    "nemairescriindu": "rescrie",
    "nerescriind": "rescrie",
    "nerescriindu": "rescrie",
    "rescria": "rescrie",
    "rescriai": "rescrie",
    "rescriam": "rescrie",
    "rescriați": "rescrie",
    "rescriau": "rescrie",
    "rescriem": "rescrie",
    "rescrieți": "rescrie",
    "rescrii": "rescrie",
    "rescriind": "rescrie",
    "rescriindu": "rescrie",
    "rescris": "rescrie",
    "rescrise": "rescrie",
    "rescrisei": "rescrie",
    "rescriseră": "rescrie",
    "rescriserăm": "rescrie",
    "rescriserăți": "rescrie",
    "rescrisese": "rescrie",
    "rescrisesem": "rescrie",
    "rescriseseră": "rescrie",
    "rescriseserăm": "rescrie",
    "rescriseserăți": "rescrie",
    "rescriseseși": "rescrie",
    "rescriseși": "rescrie",
    "rescriu": "rescrie",
    "rescrierea": "rescriere",
    "rescrieri": "rescriere",
    "rescrierii": "rescriere",
    "rescrierile": "rescriere",
    "rescrierilor": "rescriere",
    "rescrisa": "rescris",
    "rescrisă": "rescris",
    "rescrise": "rescris",
    "rescrisei": "rescris",
    "rescrisele": "rescris",
    "rescriselor": "rescris",
    "rescriși": "rescris",
    "rescrișii": "rescris",
    "rescrișilor": "rescris",
    "rescrisul": "rescris",
    "rescrisului": "rescris",
    "reședința": "reședință",
    "reședințe": "reședință",
    "reședinței": "reședință",
    "reședințele": "reședință",
    "reședințelor": "reședință",
    "nemairesemnând": "resemna",
    "nemairesemnându": "resemna",
    "neresemnând": "resemna",
    "neresemnându": "resemna",
    "resemnă": "resemna",
    "resemnai": "resemna",
    "resemnam": "resemna",
    "resemnăm": "resemna",
    "resemnând": "resemna",
    "resemnându": "resemna",
    "resemnară": "resemna",
    "resemnarăm": "resemna",
    "resemnarăți": "resemna",
    "resemnase": "resemna",
    "resemnasem": "resemna",
    "resemnaseră": "resemna",
    "resemnaserăm": "resemna",
    "resemnaserăți": "resemna",
    "resemnaseși": "resemna",
    "resemnași": "resemna",
    "resemnat": "resemna",
    "resemnați": "resemna",
    "resemnau": "resemna",
    "resemnează": "resemna",
    "resemnez": "resemna",
    "resemneze": "resemna",
    "resemnezi": "resemna",
    "resemnarea": "resemnare",
    "resemnareo": "resemnare",
    "resemnări": "resemnare",
    "resemnării": "resemnare",
    "resemnările": "resemnare",
    "resemnărilor": "resemnare",
    "resemnata": "resemnat",
    "resemnată": "resemnat",
    "resemnate": "resemnat",
    "resemnatei": "resemnat",
    "resemnatele": "resemnat",
    "resemnatelor": "resemnat",
    "resemnați": "resemnat",
    "resemnații": "resemnat",
    "resemnaților": "resemnat",
    "resemnato": "resemnat",
    "resemnatul": "resemnat",
    "resemnatule": "resemnat",
    "resemnatului": "resemnat",
    "resentimente": "resentiment",
    "resentimentele": "resentiment",
    "resentimentelor": "resentiment",
    "resentimentul": "resentiment",
    "resentimentului": "resentiment",
    "nemairesimțind": "resimți",
    "nemairesimțindu": "resimți",
    "neresimțind": "resimți",
    "neresimțindu": "resimți",
    "resimt": "resimți",
    "resimtă": "resimți",
    "resimte": "resimți",
    "resimțea": "resimți",
    "resimțeai": "resimți",
    "resimțeam": "resimți",
    "resimțeați": "resimți",
    "resimțeau": "resimți",
    "resimții": "resimți",
    "resimțim": "resimți",
    "resimțind": "resimți",
    "resimțindu": "resimți",
    "resimțiră": "resimți",
    "resimțirăm": "resimți",
    "resimțirăți": "resimți",
    "resimțise": "resimți",
    "resimțisem": "resimți",
    "resimțiseră": "resimți",
    "resimțiserăm": "resimți",
    "resimțiserăți": "resimți",
    "resimțiseși": "resimți",
    "resimțiși": "resimți",
    "resimțit": "resimți",
    "resimțiți": "resimți",
    "resimțirea": "resimțire",
    "resimțiri": "resimțire",
    "resimțirii": "resimțire",
    "resimțirile": "resimțire",
    "resimțirilor": "resimțire",
    "resimțită": "resimțit",
    "resimțite": "resimțit",
    "resimțiți": "resimțit",
    "nemairesorbind": "resorbi",
    "nemairesorbindu": "resorbi",
    "neresorbind": "resorbi",
    "neresorbindu": "resorbi",
    "resoarbă": "resorbi",
    "resoarbe": "resorbi",
    "resorb": "resorbi",
    "resorbea": "resorbi",
    "resorbeai": "resorbi",
    "resorbeam": "resorbi",
    "resorbeați": "resorbi",
    "resorbeau": "resorbi",
    "resorbii": "resorbi",
    "resorbim": "resorbi",
    "resorbind": "resorbi",
    "resorbindu": "resorbi",
    "resorbiră": "resorbi",
    "resorbirăm": "resorbi",
    "resorbirăți": "resorbi",
    "resorbise": "resorbi",
    "resorbisem": "resorbi",
    "resorbiseră": "resorbi",
    "resorbiserăm": "resorbi",
    "resorbiserăți": "resorbi",
    "resorbiseși": "resorbi",
    "resorbiși": "resorbi",
    "resorbit": "resorbi",
    "resorbiți": "resorbi",
    "resorbită": "resorbit",
    "resorbite": "resorbit",
    "resorbiți": "resorbit",
    "resorbția": "resorbție",
    "resorbției": "resorbție",
    "resorbții": "resorbție",
    "resorbțiile": "resorbție",
    "resorbțiilor": "resorbție",
    "resortul": "resort",
    "resortului": "resort",
    "resorturi": "resort",
    "resorturile": "resort",
    "resorturilor": "resort",
    "reșoul": "reșou",
    "reșoului": "reșou",
    "reșouri": "reșou",
    "reșourile": "reșou",
    "reșourilor": "reșou",
    "respecte": "respect",
    "respectele": "respect",
    "respectelor": "respect",
    "respectul": "respect",
    "respectului": "respect",
    "nemairespectând": "respecta",
    "nemairespectându": "respecta",
    "nerespectând": "respecta",
    "nerespectându": "respecta",
    "respect": "respecta",
    "respectă": "respecta",
    "respectai": "respecta",
    "respectam": "respecta",
    "respectăm": "respecta",
    "respectând": "respecta",
    "respectându": "respecta",
    "respectară": "respecta",
    "respectarăm": "respecta",
    "respectarăți": "respecta",
    "respectase": "respecta",
    "respectasem": "respecta",
    "respectaseră": "respecta",
    "respectaserăm": "respecta",
    "respectaserăți": "respecta",
    "respectaseși": "respecta",
    "respectași": "respecta",
    "respectat": "respecta",
    "respectați": "respecta",
    "respectau": "respecta",
    "respecte": "respecta",
    "respecți": "respecta",
    "respectabila": "respectabil",
    "respectabilă": "respectabil",
    "respectabile": "respectabil",
    "respectabilei": "respectabil",
    "respectabilele": "respectabil",
    "respectabilelor": "respectabil",
    "respectabili": "respectabil",
    "respectabilii": "respectabil",
    "respectabililor": "respectabil",
    "respectabilo": "respectabil",
    "respectabilul": "respectabil",
    "respectabilule": "respectabil",
    "respectabilului": "respectabil",
    "respectarea": "respectare",
    "respectareo": "respectare",
    "respectări": "respectare",
    "respectării": "respectare",
    "respectările": "respectare",
    "respectărilor": "respectare",
    "respectata": "respectat",
    "respectată": "respectat",
    "respectate": "respectat",
    "respectatei": "respectat",
    "respectatele": "respectat",
    "respectatelor": "respectat",
    "respectați": "respectat",
    "respectații": "respectat",
    "respectaților": "respectat",
    "respectato": "respectat",
    "respectatul": "respectat",
    "respectatule": "respectat",
    "respectatului": "respectat",
    "respectiva": "respectiv",
    "respectivă": "respectiv",
    "respective": "respectiv",
    "respectivei": "respectiv",
    "respectivele": "respectiv",
    "respectivelor": "respectiv",
    "respectivi": "respectiv",
    "respectivii": "respectiv",
    "respectivilor": "respectiv",
    "respectivul": "respectiv",
    "respectivului": "respectiv",
    "respectivele": "respectiva",
    "respectivelor": "respectiva",
    "respectivii": "respectivul",
    "respectivilor": "respectivul",
    "respectivului": "respectivul",
    "respectuoasa": "respectuos",
    "respectuoasă": "respectuos",
    "respectuoase": "respectuos",
    "respectuoasei": "respectuos",
    "respectuoasele": "respectuos",
    "respectuoaselor": "respectuos",
    "respectuoși": "respectuos",
    "respectuoșii": "respectuos",
    "respectuoșilor": "respectuos",
    "respectuosul": "respectuos",
    "respectuosului": "respectuos",
    "respingătoare": "respingător",
    "respingătoarea": "respingător",
    "respingătoarei": "respingător",
    "respingătoarele": "respingător",
    "respingătoarelor": "respingător",
    "respingători": "respingător",
    "respingătorii": "respingător",
    "respingătorilor": "respingător",
    "respingătorul": "respingător",
    "respingătorului": "respingător",
    "nemairespingând": "respinge",
    "nemairespingându": "respinge",
    "nerespingând": "respinge",
    "nerespingându": "respinge",
    "resping": "respinge",
    "respingă": "respinge",
    "respingând": "respinge",
    "respingându": "respinge",
    "respingea": "respinge",
    "respingeai": "respinge",
    "respingeam": "respinge",
    "respingeați": "respinge",
    "respingeau": "respinge",
    "respingem": "respinge",
    "respingeți": "respinge",
    "respingi": "respinge",
    "respins": "respinge",
    "respinse": "respinge",
    "respinsei": "respinge",
    "respinseră": "respinge",
    "respinserăm": "respinge",
    "respinserăți": "respinge",
    "respinsese": "respinge",
    "respinsesem": "respinge",
    "respinseseră": "respinge",
    "respinseserăm": "respinge",
    "respinseserăți": "respinge",
    "respinseseși": "respinge",
    "respinseși": "respinge",
    "respingerea": "respingere",
    "respingeri": "respingere",
    "respingerii": "respingere",
    "respingerile": "respingere",
    "respingerilor": "respingere",
    "respinsă": "respins",
    "respinse": "respins",
    "respinși": "respins",
    "nemairespirând": "respira",
    "nemairespirându": "respira",
    "nerespirând": "respira",
    "nerespirându": "respira",
    "respir": "respira",
    "respiră": "respira",
    "respirai": "respira",
    "respiram": "respira",
    "respirăm": "respira",
    "respirând": "respira",
    "respirându": "respira",
    "respirară": "respira",
    "respirarăm": "respira",
    "respirarăți": "respira",
    "respirase": "respira",
    "respirasem": "respira",
    "respiraseră": "respira",
    "respiraserăm": "respira",
    "respiraserăți": "respira",
    "respiraseși": "respira",
    "respirași": "respira",
    "respirat": "respira",
    "respirați": "respira",
    "respirau": "respira",
    "respire": "respira",
    "respiri": "respira",
    "respirarea": "respirare",
    "respirareo": "respirare",
    "respirări": "respirare",
    "respirării": "respirare",
    "respirările": "respirare",
    "respirărilor": "respirare",
    "respirată": "respirat",
    "respirate": "respirat",
    "respirați": "respirat",
    "respirația": "respirație",
    "respirației": "respirație",
    "respirații": "respirație",
    "respirațiile": "respirație",
    "respirațiilor": "respirație",
    "respiratoare": "respirator",
    "respiratoarea": "respirator",
    "respiratoarei": "respirator",
    "respiratoarele": "respirator",
    "respiratoarelor": "respirator",
    "respiratoareo": "respirator",
    "respiratori": "respirator",
    "respiratorii": "respirator",
    "respiratorul": "respirator",
    "respiratorule": "respirator",
    "respiratorului": "respirator",
    "respiratoria": "respiratoriu",
    "respiratorie": "respiratoriu",
    "respiratoriei": "respiratoriu",
    "respiratorii": "respiratoriu",
    "responsabila": "responsabil",
    "responsabilă": "responsabil",
    "responsabile": "responsabil",
    "responsabilei": "responsabil",
    "responsabilele": "responsabil",
    "responsabilelor": "responsabil",
    "responsabili": "responsabil",
    "responsabilii": "responsabil",
    "responsabililor": "responsabil",
    "responsabilul": "responsabil",
    "responsabilului": "responsabil",
    "responsabilitatea": "responsabilitate",
    "responsabilități": "responsabilitate",
    "responsabilității": "responsabilitate",
    "responsabilitățile": "responsabilitate",
    "responsabilităților": "responsabilitate",
    "restu'": "rest",
    "restul": "rest",
    "restului": "rest",
    "resturi": "rest",
    "resturile": "rest",
    "resturilor": "rest",
    "nemairestabilind": "restabili",
    "nemairestabilindu": "restabili",
    "nerestabilind": "restabili",
    "nerestabilindu": "restabili",
    "restabilea": "restabili",
    "restabileai": "restabili",
    "restabileam": "restabili",
    "restabilească": "restabili",
    "restabileați": "restabili",
    "restabileau": "restabili",
    "restabilesc": "restabili",
    "restabilește": "restabili",
    "restabilești": "restabili",
    "restabilii": "restabili",
    "restabilim": "restabili",
    "restabilind": "restabili",
    "restabilindu": "restabili",
    "restabiliră": "restabili",
    "restabilirăm": "restabili",
    "restabilirăți": "restabili",
    "restabilise": "restabili",
    "restabilisem": "restabili",
    "restabiliseră": "restabili",
    "restabiliserăm": "restabili",
    "restabiliserăți": "restabili",
    "restabiliseși": "restabili",
    "restabiliși": "restabili",
    "restabilit": "restabili",
    "restabiliți": "restabili",
    "restabilirea": "restabilire",
    "restabilireo": "restabilire",
    "restabiliri": "restabilire",
    "restabilirii": "restabilire",
    "restabilirile": "restabilire",
    "restabilirilor": "restabilire",
    "restabilită": "restabilit",
    "restabilite": "restabilit",
    "restabiliți": "restabilit",
    "restanta": "restant",
    "restantă": "restant",
    "restante": "restant",
    "restantei": "restant",
    "restantele": "restant",
    "restantelor": "restant",
    "restanți": "restant",
    "restanții": "restant",
    "restanților": "restant",
    "restantul": "restant",
    "restantului": "restant",
    "restanța": "restanță",
    "restanțe": "restanță",
    "restanței": "restanță",
    "restanțele": "restanță",
    "restanțelor": "restanță",
    "restanțiera": "restanțier",
    "restanțieră": "restanțier",
    "restanțiere": "restanțier",
    "restanțierei": "restanțier",
    "restanțierele": "restanțier",
    "restanțierelor": "restanțier",
    "restanțieri": "restanțier",
    "restanțierii": "restanțier",
    "restanțierilor": "restanțier",
    "restanțierul": "restanțier",
    "restanțierului": "restanțier",
    "nemairestatornicind": "restatornici",
    "nemairestatornicindu": "restatornici",
    "nerestatornicind": "restatornici",
    "nerestatornicindu": "restatornici",
    "restatornicea": "restatornici",
    "restatorniceai": "restatornici",
    "restatorniceam": "restatornici",
    "restatornicească": "restatornici",
    "restatorniceați": "restatornici",
    "restatorniceau": "restatornici",
    "restatornicesc": "restatornici",
    "restatornicește": "restatornici",
    "restatornicești": "restatornici",
    "restatornicii": "restatornici",
    "restatornicim": "restatornici",
    "restatornicind": "restatornici",
    "restatornicindu": "restatornici",
    "restatorniciră": "restatornici",
    "restatornicirăm": "restatornici",
    "restatornicirăți": "restatornici",
    "restatornicise": "restatornici",
    "restatornicisem": "restatornici",
    "restatorniciseră": "restatornici",
    "restatorniciserăm": "restatornici",
    "restatorniciserăți": "restatornici",
    "restatorniciseși": "restatornici",
    "restatorniciși": "restatornici",
    "restatornicit": "restatornici",
    "restatorniciți": "restatornici",
    "restatornicită": "restatornicit",
    "restatornicite": "restatornicit",
    "restatorniciți": "restatornicit",
    "nemairestaurând": "restaura",
    "nemairestaurându": "restaura",
    "nerestaurând": "restaura",
    "nerestaurându": "restaura",
    "restaură": "restaura",
    "restaurai": "restaura",
    "restauram": "restaura",
    "restaurăm": "restaura",
    "restaurând": "restaura",
    "restaurându": "restaura",
    "restaurară": "restaura",
    "restaurarăm": "restaura",
    "restaurarăți": "restaura",
    "restaurase": "restaura",
    "restaurasem": "restaura",
    "restauraseră": "restaura",
    "restauraserăm": "restaura",
    "restauraserăți": "restaura",
    "restauraseși": "restaura",
    "restaurași": "restaura",
    "restaurat": "restaura",
    "restaurați": "restaura",
    "restaurau": "restaura",
    "restaurează": "restaura",
    "restaurez": "restaura",
    "restaureze": "restaura",
    "restaurezi": "restaura",
    "restaurante": "restaurant",
    "restaurantele": "restaurant",
    "restaurantelor": "restaurant",
    "restaurantul": "restaurant",
    "restaurantului": "restaurant",
    "restaurată": "restaurat",
    "restaurate": "restaurat",
    "restaurați": "restaurat",
    "restaurația": "restaurație",
    "restaurației": "restaurație",
    "restaurații": "restaurație",
    "restaurațiile": "restaurație",
    "restaurațiilor": "restaurație",
    "restauratoarea": "restauratoare",
    "restauratoarei": "restauratoare",
    "restauratoarele": "restauratoare",
    "restauratoarelor": "restauratoare",
    "restauratori": "restaurator",
    "restauratorii": "restaurator",
    "restauratorilor": "restaurator",
    "restauratorul": "restaurator",
    "restauratorului": "restaurator",
    "resteie": "resteu",
    "resteiele": "resteu",
    "resteielor": "resteu",
    "resteul": "resteu",
    "resteului": "resteu",
    "nemairestituind": "restitui",
    "nemairestituindu": "restitui",
    "nerestituind": "restitui",
    "nerestituindu": "restitui",
    "restituia": "restitui",
    "restituiai": "restitui",
    "restituiam": "restitui",
    "restituiați": "restitui",
    "restituiau": "restitui",
    "restituie": "restitui",
    "restituii": "restitui",
    "restituim": "restitui",
    "restituind": "restitui",
    "restituindu": "restitui",
    "restituiră": "restitui",
    "restituirăm": "restitui",
    "restituirăți": "restitui",
    "restituise": "restitui",
    "restituisem": "restitui",
    "restituiseră": "restitui",
    "restituiserăm": "restitui",
    "restituiserăți": "restitui",
    "restituiseși": "restitui",
    "restituiși": "restitui",
    "restituit": "restitui",
    "restituiți": "restitui",
    "restituirea": "restituire",
    "restituiri": "restituire",
    "restituirii": "restituire",
    "restituirile": "restituire",
    "restituirilor": "restituire",
    "restituită": "restituit",
    "restituite": "restituit",
    "restituiți": "restituit",
    "nemairestrângând": "restrânge",
    "nemairestrângându": "restrânge",
    "nerestrângând": "restrânge",
    "nerestrângându": "restrânge",
    "restrâng": "restrânge",
    "restrângă": "restrânge",
    "restrângând": "restrânge",
    "restrângându": "restrânge",
    "restrângea": "restrânge",
    "restrângeai": "restrânge",
    "restrângeam": "restrânge",
    "restrângeați": "restrânge",
    "restrângeau": "restrânge",
    "restrângem": "restrânge",
    "restrângeți": "restrânge",
    "restrângi": "restrânge",
    "restrâns": "restrânge",
    "restrânse": "restrânge",
    "restrânsei": "restrânge",
    "restrânseră": "restrânge",
    "restrânserăm": "restrânge",
    "restrânserăți": "restrânge",
    "restrânsese": "restrânge",
    "restrânsesem": "restrânge",
    "restrânseseră": "restrânge",
    "restrânseserăm": "restrânge",
    "restrânseserăți": "restrânge",
    "restrânseseși": "restrânge",
    "restrânseși": "restrânge",
    "restrângerea": "restrângere",
    "restrângereo": "restrângere",
    "restrângeri": "restrângere",
    "restrângerii": "restrângere",
    "restrângerile": "restrângere",
    "restrângerilor": "restrângere",
    "restrânsa": "restrâns",
    "restrânsă": "restrâns",
    "restrânse": "restrâns",
    "restrânsei": "restrâns",
    "restrânsele": "restrâns",
    "restrânselor": "restrâns",
    "restrânși": "restrâns",
    "restrânșii": "restrâns",
    "restrânșilor": "restrâns",
    "restrânsul": "restrâns",
    "restrânsului": "restrâns",
    "restricția": "restricție",
    "restricției": "restricție",
    "restricții": "restricție",
    "restricțiile": "restricție",
    "restricțiilor": "restricție",
    "restricționarea": "restricționare",
    "restricțiunea": "restricțiune",
    "restricțiuni": "restricțiune",
    "restricțiunii": "restricțiune",
    "restricțiunile": "restricțiune",
    "restricțiunilor": "restricțiune",
    "restrictiva": "restrictiv",
    "restrictivă": "restrictiv",
    "restrictive": "restrictiv",
    "restrictivei": "restrictiv",
    "restrictivele": "restrictiv",
    "restrictivelor": "restrictiv",
    "restrictivi": "restrictiv",
    "restrictivii": "restrictiv",
    "restrictivilor": "restrictiv",
    "restrictivul": "restrictiv",
    "restrictivului": "restrictiv",
    "restriștea": "restriște",
    "restriști": "restriște",
    "restriștii": "restriște",
    "restriștile": "restriște",
    "restriștilor": "restriște",
    "nemairestructurând": "restructura",
    "nemairestructurându": "restructura",
    "nerestructurând": "restructura",
    "nerestructurându": "restructura",
    "restructură": "restructura",
    "restructurai": "restructura",
    "restructuram": "restructura",
    "restructurăm": "restructura",
    "restructurând": "restructura",
    "restructurându": "restructura",
    "restructurară": "restructura",
    "restructurarăm": "restructura",
    "restructurarăți": "restructura",
    "restructurase": "restructura",
    "restructurasem": "restructura",
    "restructuraseră": "restructura",
    "restructuraserăm": "restructura",
    "restructuraserăți": "restructura",
    "restructuraseși": "restructura",
    "restructurași": "restructura",
    "restructurat": "restructura",
    "restructurați": "restructura",
    "restructurau": "restructura",
    "restructurează": "restructura",
    "restructurez": "restructura",
    "restructureze": "restructura",
    "restructurezi": "restructura",
    "restructurarea": "restructurare",
    "restructurareo": "restructurare",
    "restructurări": "restructurare",
    "restructurării": "restructurare",
    "restructurările": "restructurare",
    "restructurărilor": "restructurare",
    "restructurată": "restructurat",
    "restructurate": "restructurat",
    "restructurați": "restructurat",
    "resursa": "resursă",
    "resurse": "resursă",
    "resursei": "resursă",
    "resursele": "resursă",
    "resurselor": "resursă",
    "resuscitarea": "resuscitare",
    "resuscitări": "resuscitare",
    "resuscitării": "resuscitare",
    "resuscitările": "resuscitare",
    "rețeaua": "rețea",
    "rețele": "rețea",
    "rețelei": "rețea",
    "rețelele": "rețea",
    "rețelelor": "rețea",
    "retehnologizarea": "retehnologizare",
    "retehnologizări": "retehnologizare",
    "retehnologizării": "retehnologizare",
    "retehnologizările": "retehnologizare",
    "retehnologizărilor": "retehnologizare",
    "retenția": "retenție",
    "retenției": "retenție",
    "retenții": "retenție",
    "retențiile": "retenție",
    "retențiilor": "retenție",
    "rețeta": "rețetă",
    "rețete": "rețetă",
    "rețetei": "rețetă",
    "rețetele": "rețetă",
    "rețetelor": "rețetă",
    "reteveie": "retevei",
    "reteveiele": "retevei",
    "reteveielor": "retevei",
    "reteveiul": "retevei",
    "reteveiului": "retevei",
    "nemairetezând": "reteza",
    "nemairetezându": "reteza",
    "neretezând": "reteza",
    "neretezându": "reteza",
    "retează": "reteza",
    "retez": "reteza",
    "reteză": "reteza",
    "retezai": "reteza",
    "retezam": "reteza",
    "retezăm": "reteza",
    "retezând": "reteza",
    "retezându": "reteza",
    "retezară": "reteza",
    "retezarăm": "reteza",
    "retezarăți": "reteza",
    "retezase": "reteza",
    "retezasem": "reteza",
    "retezaseră": "reteza",
    "retezaserăm": "reteza",
    "retezaserăți": "reteza",
    "retezaseși": "reteza",
    "retezași": "reteza",
    "retezat": "reteza",
    "retezați": "reteza",
    "retezau": "reteza",
    "reteze": "reteza",
    "retezi": "reteza",
    "retezarea": "retezare",
    "retezareo": "retezare",
    "retezări": "retezare",
    "retezării": "retezare",
    "retezările": "retezare",
    "retezărilor": "retezare",
    "retezata": "retezat",
    "retezată": "retezat",
    "retezate": "retezat",
    "retezatei": "retezat",
    "retezatele": "retezat",
    "retezatelor": "retezat",
    "retezați": "retezat",
    "retezații": "retezat",
    "retezaților": "retezat",
    "retezato": "retezat",
    "retezatul": "retezat",
    "retezatule": "retezat",
    "retezatului": "retezat",
    "retezătura": "retezătură",
    "retezături": "retezătură",
    "retezăturii": "retezătură",
    "retezăturile": "retezătură",
    "retezăturilor": "retezătură",
    "reticenta": "reticent",
    "reticentă": "reticent",
    "reticente": "reticent",
    "reticentei": "reticent",
    "reticentele": "reticent",
    "reticentelor": "reticent",
    "reticenți": "reticent",
    "reticenții": "reticent",
    "reticenților": "reticent",
    "reticentul": "reticent",
    "reticentului": "reticent",
    "reticența": "reticență",
    "reticențe": "reticență",
    "reticenței": "reticență",
    "reticențele": "reticență",
    "reticențelor": "reticență",
    "reticule": "reticul",
    "reticulele": "reticul",
    "reticulelor": "reticul",
    "reticulul": "reticul",
    "reticulului": "reticul",
    "reticulara": "reticular",
    "reticulară": "reticular",
    "reticulare": "reticular",
    "reticularei": "reticular",
    "reticularele": "reticular",
    "reticularelor": "reticular",
    "reticulari": "reticular",
    "reticularii": "reticular",
    "reticularilor": "reticular",
    "reticularul": "reticular",
    "reticularului": "reticular",
    "reticulata": "reticulat",
    "reticulată": "reticulat",
    "reticulate": "reticulat",
    "reticulatei": "reticulat",
    "reticulatele": "reticulat",
    "reticulatelor": "reticulat",
    "reticulați": "reticulat",
    "reticulații": "reticulat",
    "reticulaților": "reticulat",
    "reticulatul": "reticulat",
    "reticulatului": "reticulat",
    "retina": "retină",
    "retine": "retină",
    "retinei": "retină",
    "retinele": "retină",
    "retinelor": "retină",
    "nemaireținând": "reține",
    "nereținând": "reține",
    "nereținându": "reține",
    "reții": "reține",
    "rețin": "reține",
    "rețină": "reține",
    "reținând": "reține",
    "reținea": "reține",
    "rețineai": "reține",
    "rețineam": "reține",
    "rețineați": "reține",
    "rețineau": "reține",
    "reținem": "reține",
    "rețineți": "reține",
    "reținu": "reține",
    "reținui": "reține",
    "reținură": "reține",
    "reținurăm": "reține",
    "reținurăți": "reține",
    "reținuse": "reține",
    "reținusem": "reține",
    "reținuseră": "reține",
    "reținuserăm": "reține",
    "reținuserăți": "reține",
    "reținuseși": "reține",
    "reținuși": "reține",
    "reținut": "reține",
    "reținerea": "reținere",
    "reținereo": "reținere",
    "rețineri": "reținere",
    "reținerii": "reținere",
    "reținerile": "reținere",
    "reținerilor": "reținere",
    "reținută": "reținut",
    "reținute": "reținut",
    "reținuți": "reținut",
    "nemairetipărind": "retipări",
    "nemairetipărindu": "retipări",
    "neretipărind": "retipări",
    "neretipărindu": "retipări",
    "retipărea": "retipări",
    "retipăreai": "retipări",
    "retipăream": "retipări",
    "retipărească": "retipări",
    "retipăreați": "retipări",
    "retipăreau": "retipări",
    "retipăresc": "retipări",
    "retipărește": "retipări",
    "retipărești": "retipări",
    "retipării": "retipări",
    "retipărim": "retipări",
    "retipărind": "retipări",
    "retipărindu": "retipări",
    "retipăriră": "retipări",
    "retipărirăm": "retipări",
    "retipărirăți": "retipări",
    "retipărise": "retipări",
    "retipărisem": "retipări",
    "retipăriseră": "retipări",
    "retipăriserăm": "retipări",
    "retipăriserăți": "retipări",
    "retipăriseși": "retipări",
    "retipăriși": "retipări",
    "retipărit": "retipări",
    "retipăriți": "retipări",
    "retipărirea": "retipărire",
    "retipăriri": "retipărire",
    "retipăririi": "retipărire",
    "retipăririle": "retipărire",
    "retipăririlor": "retipărire",
    "retipărită": "retipărit",
    "retipărite": "retipărit",
    "retipăriți": "retipărit",
    "retori": "retor",
    "retorii": "retor",
    "retorilor": "retor",
    "retorul": "retor",
    "retorului": "retor",
    "retorica": "retoric",
    "retorică": "retoric",
    "retorice": "retoric",
    "retoricei": "retoric",
    "retoricele": "retoric",
    "retoricelor": "retoric",
    "retorici": "retoric",
    "retoricii": "retoric",
    "retoricilor": "retoric",
    "retoricul": "retoric",
    "retoricului": "retoric",
    "retorismul": "retorism",
    "retorismului": "retorism",
    "retorta": "retortă",
    "retorte": "retortă",
    "retortei": "retortă",
    "retortele": "retortă",
    "retortelor": "retortă",
    "nemairetractând": "retracta",
    "nemairetractându": "retracta",
    "neretractând": "retracta",
    "neretractându": "retracta",
    "retractă": "retracta",
    "retractai": "retracta",
    "retractam": "retracta",
    "retractăm": "retracta",
    "retractând": "retracta",
    "retractându": "retracta",
    "retractară": "retracta",
    "retractarăm": "retracta",
    "retractarăți": "retracta",
    "retractase": "retracta",
    "retractasem": "retracta",
    "retractaseră": "retracta",
    "retractaserăm": "retracta",
    "retractaserăți": "retracta",
    "retractaseși": "retracta",
    "retractași": "retracta",
    "retractat": "retracta",
    "retractați": "retracta",
    "retractau": "retracta",
    "retractează": "retracta",
    "retractez": "retracta",
    "retracteze": "retracta",
    "retractezi": "retracta",
    "retractată": "retractat",
    "retractate": "retractat",
    "retractați": "retractat",
    "retracția": "retracție",
    "retracției": "retracție",
    "retracții": "retracție",
    "retracțiile": "retracție",
    "retracțiilor": "retracție",
    "retractila": "retractil",
    "retractilă": "retractil",
    "retractile": "retractil",
    "retractilei": "retractil",
    "retractilele": "retractil",
    "retractilelor": "retractil",
    "retractili": "retractil",
    "retractilii": "retractil",
    "retractililor": "retractil",
    "retractilul": "retractil",
    "retractilului": "retractil",
    "retractilitatea": "retractilitate",
    "retractilitati": "retractilitate",
    "retractilitatii": "retractilitate",
    "retractilitatile": "retractilitate",
    "retractilitatilor": "retractilitate",
    "nemairetrăgând": "retrage",
    "nemairetrăgându": "retrage",
    "neretrăgând": "retrage",
    "neretrăgându": "retrage",
    "retrag": "retrage",
    "retragă": "retrage",
    "retragând": "retrage",
    "retrăgând": "retrage",
    "retragându": "retrage",
    "retrăgându": "retrage",
    "retrăgea": "retrage",
    "retrăgeai": "retrage",
    "retrăgeam": "retrage",
    "retrăgeați": "retrage",
    "retrăgeau": "retrage",
    "retragem": "retrage",
    "retrageți": "retrage",
    "retragi": "retrage",
    "retras": "retrage",
    "retrase": "retrage",
    "retrăsei": "retrage",
    "retraseră": "retrage",
    "retraserăm": "retrage",
    "retraserăți": "retrage",
    "retrăsese": "retrage",
    "retrăsesem": "retrage",
    "retrăseseră": "retrage",
    "retrăseserăm": "retrage",
    "retrăseserăți": "retrage",
    "retrăseseși": "retrage",
    "retraseși": "retrage",
    "retrasu": "retrage",
    "retragerea": "retragere",
    "retrageri": "retragere",
    "retragerii": "retragere",
    "retragerile": "retragere",
    "retragerilor": "retragere",
    "nemairetrăind": "retrăi",
    "nemairetrăindu": "retrăi",
    "neretrăind": "retrăi",
    "neretrăindu": "retrăi",
    "retrăia": "retrăi",
    "retrăiai": "retrăi",
    "retrăiam": "retrăi",
    "retrăiască": "retrăi",
    "retrăiați": "retrăi",
    "retrăiau": "retrăi",
    "retrăiesc": "retrăi",
    "retrăiește": "retrăi",
    "retrăiești": "retrăi",
    "retrăii": "retrăi",
    "retrăim": "retrăi",
    "retrăind": "retrăi",
    "retrăindu": "retrăi",
    "retrăiră": "retrăi",
    "retrăirăm": "retrăi",
    "retrăirăți": "retrăi",
    "retrăise": "retrăi",
    "retrăisem": "retrăi",
    "retrăiseră": "retrăi",
    "retrăiserăm": "retrăi",
    "retrăiserăți": "retrăi",
    "retrăiseși": "retrăi",
    "retrăiși": "retrăi",
    "retrăit": "retrăi",
    "retrăiți": "retrăi",
    "retrăirea": "retrăire",
    "retrăireo": "retrăire",
    "retrăiri": "retrăire",
    "retrăirii": "retrăire",
    "retrăirile": "retrăire",
    "retrăirilor": "retrăire",
    "retrăită": "retrăit",
    "retrăite": "retrăit",
    "retrăiți": "retrăit",
    "retransmisia": "retransmisie",
    "retransmisiei": "retransmisie",
    "retransmisii": "retransmisie",
    "retransmisiile": "retransmisie",
    "retransmisiilor": "retransmisie",
    "retrasă": "retras",
    "retrase": "retras",
    "retrași": "retras",
    "nemairetribuind": "retribui",
    "nemairetribuindu": "retribui",
    "neretribuind": "retribui",
    "neretribuindu": "retribui",
    "retribuia": "retribui",
    "retribuiai": "retribui",
    "retribuiam": "retribui",
    "retribuiați": "retribui",
    "retribuiau": "retribui",
    "retribuie": "retribui",
    "retribuii": "retribui",
    "retribuim": "retribui",
    "retribuind": "retribui",
    "retribuindu": "retribui",
    "retribuiră": "retribui",
    "retribuirăm": "retribui",
    "retribuirăți": "retribui",
    "retribuise": "retribui",
    "retribuisem": "retribui",
    "retribuiseră": "retribui",
    "retribuiserăm": "retribui",
    "retribuiserăți": "retribui",
    "retribuiseși": "retribui",
    "retribuiși": "retribui",
    "retribuit": "retribui",
    "retribuiți": "retribui",
    "retribuită": "retribuit",
    "retribuite": "retribuit",
    "retribuiți": "retribuit",
    "retribuția": "retribuție",
    "retribuției": "retribuție",
    "retribuții": "retribuție",
    "retribuțiile": "retribuție",
    "retribuțiilor": "retribuție",
    "retroactiva": "retroactiv",
    "retroactivă": "retroactiv",
    "retroactive": "retroactiv",
    "retroactivei": "retroactiv",
    "retroactivele": "retroactiv",
    "retroactivelor": "retroactiv",
    "retroactivi": "retroactiv",
    "retroactivii": "retroactiv",
    "retroactivilor": "retroactiv",
    "retroactivul": "retroactiv",
    "retroactivului": "retroactiv",
    "retroactivitatea": "retroactivitate",
    "retroactivități": "retroactivitate",
    "retroactivității": "retroactivitate",
    "retroactivitățile": "retroactivitate",
    "retroactivităților": "retroactivitate",
    "nemairetrocedând": "retroceda",
    "nemairetrocedându": "retroceda",
    "neretrocedând": "retroceda",
    "neretrocedându": "retroceda",
    "retrocedă": "retroceda",
    "retrocedai": "retroceda",
    "retrocedam": "retroceda",
    "retrocedăm": "retroceda",
    "retrocedând": "retroceda",
    "retrocedându": "retroceda",
    "retrocedară": "retroceda",
    "retrocedarăm": "retroceda",
    "retrocedarăți": "retroceda",
    "retrocedase": "retroceda",
    "retrocedasem": "retroceda",
    "retrocedaseră": "retroceda",
    "retrocedaserăm": "retroceda",
    "retrocedaserăți": "retroceda",
    "retrocedaseși": "retroceda",
    "retrocedași": "retroceda",
    "retrocedat": "retroceda",
    "retrocedați": "retroceda",
    "retrocedau": "retroceda",
    "retrocedează": "retroceda",
    "retrocedez": "retroceda",
    "retrocedeze": "retroceda",
    "retrocedezi": "retroceda",
    "retrocedarea": "retrocedare",
    "retrocedări": "retrocedare",
    "retrocedării": "retrocedare",
    "retrocedările": "retrocedare",
    "retrocedărilor": "retrocedare",
    "retrocedată": "retrocedat",
    "retrocedate": "retrocedat",
    "retrocedați": "retrocedat",
    "retrograda": "retrograd",
    "retrogradă": "retrograd",
    "retrograde": "retrograd",
    "retrogradei": "retrograd",
    "retrogradele": "retrograd",
    "retrogradelor": "retrograd",
    "retrogradul": "retrograd",
    "retrogradului": "retrograd",
    "retrograzi": "retrograd",
    "retrograzii": "retrograd",
    "retrograzilor": "retrograd",
    "nemairetrogradând": "retrograda",
    "nemairetrogradându": "retrograda",
    "neretrogradând": "retrograda",
    "neretrogradându": "retrograda",
    "retrogradă": "retrograda",
    "retrogradai": "retrograda",
    "retrogradam": "retrograda",
    "retrogradăm": "retrograda",
    "retrogradând": "retrograda",
    "retrogradându": "retrograda",
    "retrogradară": "retrograda",
    "retrogradarăm": "retrograda",
    "retrogradarăți": "retrograda",
    "retrogradase": "retrograda",
    "retrogradasem": "retrograda",
    "retrogradaseră": "retrograda",
    "retrogradaserăm": "retrograda",
    "retrogradaserăți": "retrograda",
    "retrogradaseși": "retrograda",
    "retrogradași": "retrograda",
    "retrogradat": "retrograda",
    "retrogradați": "retrograda",
    "retrogradau": "retrograda",
    "retrogradează": "retrograda",
    "retrogradez": "retrograda",
    "retrogradeze": "retrograda",
    "retrogradezi": "retrograda",
    "retrogradată": "retrogradat",
    "retrogradate": "retrogradat",
    "retrogradați": "retrogradat",
    "retrospectiva": "retrospectiv",
    "retrospectivă": "retrospectiv",
    "retrospective": "retrospectiv",
    "retrospectivei": "retrospectiv",
    "retrospectivele": "retrospectiv",
    "retrospectivelor": "retrospectiv",
    "retrospectivi": "retrospectiv",
    "retrospectivii": "retrospectiv",
    "retrospectivilor": "retrospectiv",
    "retrospectivul": "retrospectiv",
    "retrospectivului": "retrospectiv",
    "retrospectiva": "retrospectivă",
    "retrospective": "retrospectivă",
    "retrospectivei": "retrospectivă",
    "retrospectivele": "retrospectivă",
    "retrospectivelor": "retrospectivă",
    "retroversiunea": "retroversiune",
    "retroversiuni": "retroversiune",
    "retroversiunii": "retroversiune",
    "retroversiunile": "retroversiune",
    "retroversiunilor": "retroversiune",
    "retrovizoare": "retrovizor",
    "retrovizoarele": "retrovizor",
    "retrovizoarelor": "retrovizor",
    "retrovizorul": "retrovizor",
    "retrovizorului": "retrovizor",
    "returul": "retur",
    "returului": "retur",
    "retururi": "retur",
    "retururile": "retur",
    "retururilor": "retur",
    "returnă": "returna",
    "returnai": "returna",
    "returnam": "returna",
    "returnăm": "returna",
    "returnând": "returna",
    "returnându": "returna",
    "returnară": "returna",
    "returnarăm": "returna",
    "returnarăți": "returna",
    "returnase": "returna",
    "returnasem": "returna",
    "returnaseră": "returna",
    "returnaserăm": "returna",
    "returnaserăți": "returna",
    "returnaseși": "returna",
    "returnași": "returna",
    "returnat": "returna",
    "returnați": "returna",
    "returnatu": "returna",
    "returnau": "returna",
    "returnează": "returna",
    "returnez": "returna",
    "returneze": "returna",
    "returnezi": "returna",
    "returnată": "returnat",
    "returnate": "returnat",
    "returnați": "returnat",
    "retușul": "retuș",
    "retușului": "retuș",
    "retușuri": "retuș",
    "retușurile": "retuș",
    "retușurilor": "retuș",
    "nemairetușând": "retușa",
    "nemairetușându": "retușa",
    "neretușând": "retușa",
    "neretușându": "retușa",
    "retușă": "retușa",
    "retușai": "retușa",
    "retușam": "retușa",
    "retușăm": "retușa",
    "retușând": "retușa",
    "retușându": "retușa",
    "retușară": "retușa",
    "retușarăm": "retușa",
    "retușarăți": "retușa",
    "retușase": "retușa",
    "retușasem": "retușa",
    "retușaseră": "retușa",
    "retușaserăm": "retușa",
    "retușaserăți": "retușa",
    "retușaseși": "retușa",
    "retușași": "retușa",
    "retușat": "retușa",
    "retușați": "retușa",
    "retușau": "retușa",
    "retușează": "retușa",
    "retușez": "retușa",
    "retușeze": "retușa",
    "retușezi": "retușa",
    "retușarea": "retușare",
    "retușări": "retușare",
    "retușării": "retușare",
    "retușările": "retușare",
    "retușărilor": "retușare",
    "retușata": "retușat",
    "retușată": "retușat",
    "retușate": "retușat",
    "retușatei": "retușat",
    "retușatele": "retușat",
    "retușatelor": "retușat",
    "retușați": "retușat",
    "retușații": "retușat",
    "retușaților": "retușat",
    "retușatul": "retușat",
    "retușatului": "retușat",
    "reumatica": "reumatic",
    "reumatică": "reumatic",
    "reumatice": "reumatic",
    "reumaticei": "reumatic",
    "reumaticele": "reumatic",
    "reumaticelor": "reumatic",
    "reumatici": "reumatic",
    "reumaticii": "reumatic",
    "reumaticilor": "reumatic",
    "reumaticul": "reumatic",
    "reumaticului": "reumatic",
    "reumatismul": "reumatism",
    "reumatismului": "reumatism",
    "reumatismala": "reumatismal",
    "reumatismală": "reumatismal",
    "reumatismale": "reumatismal",
    "reumatismalei": "reumatismal",
    "reumatismalele": "reumatismal",
    "reumatismalelor": "reumatismal",
    "reumatismali": "reumatismal",
    "reumatismalii": "reumatismal",
    "reumatismalilor": "reumatismal",
    "reumatismalul": "reumatismal",
    "reumatismalului": "reumatismal",
    "reumatologia": "reumatologie",
    "reumatologiei": "reumatologie",
    "reumatologii": "reumatologie",
    "reumatologiile": "reumatologie",
    "reumatologiilor": "reumatologie",
    "nemaireunind": "reuni",
    "nemaireunindu": "reuni",
    "nereunind": "reuni",
    "nereunindu": "reuni",
    "reunea": "reuni",
    "reuneai": "reuni",
    "reuneam": "reuni",
    "reunească": "reuni",
    "reuneați": "reuni",
    "reuneau": "reuni",
    "reunesc": "reuni",
    "reunește": "reuni",
    "reunești": "reuni",
    "reunii": "reuni",
    "reunim": "reuni",
    "reunind": "reuni",
    "reunindu": "reuni",
    "reuniră": "reuni",
    "reunirăm": "reuni",
    "reunirăți": "reuni",
    "reunise": "reuni",
    "reunisem": "reuni",
    "reuniseră": "reuni",
    "reuniserăm": "reuni",
    "reuniserăți": "reuni",
    "reuniseși": "reuni",
    "reuniși": "reuni",
    "reunit": "reuni",
    "reuniți": "reuni",
    "reunirea": "reunire",
    "reuniri": "reunire",
    "reunirii": "reunire",
    "reunirile": "reunire",
    "reunirilor": "reunire",
    "reunită": "reunit",
    "reunite": "reunit",
    "reuniți": "reunit",
    "reuniunea": "reuniune",
    "reuniuni": "reuniune",
    "reuniunii": "reuniune",
    "reuniunile": "reuniune",
    "reuniunilor": "reuniune",
    "nemaireușind": "reuși",
    "nemaireușindu": "reuși",
    "nereușind": "reuși",
    "nereușindu": "reuși",
    "reușea": "reuși",
    "reușeai": "reuși",
    "reușeam": "reuși",
    "reușească": "reuși",
    "reușeați": "reuși",
    "reușeau": "reuși",
    "reușesc": "reuși",
    "reușește": "reuși",
    "reușești": "reuși",
    "reușii": "reuși",
    "reușim": "reuși",
    "reușind": "reuși",
    "reușindu": "reuși",
    "reușiră": "reuși",
    "reușirăm": "reuși",
    "reușirăți": "reuși",
    "reușise": "reuși",
    "reușisem": "reuși",
    "reușiseră": "reuși",
    "reușiserăm": "reuși",
    "reușiserăți": "reuși",
    "reușiseși": "reuși",
    "reușiși": "reuși",
    "reușit": "reuși",
    "reușiți": "reuși",
    "reușirea": "reușire",
    "reușireo": "reușire",
    "reușiri": "reușire",
    "reușirii": "reușire",
    "reușirile": "reușire",
    "reușirilor": "reușire",
    "reușita": "reușit",
    "reușită": "reușit",
    "reușite": "reușit",
    "reușitei": "reușit",
    "reușitele": "reușit",
    "reușitelor": "reușit",
    "reușiți": "reușit",
    "reușiții": "reușit",
    "reușiților": "reușit",
    "reușito": "reușit",
    "reușitul": "reușit",
    "reușitule": "reușit",
    "reușitului": "reușit",
    "reușita": "reușită",
    "reușite": "reușită",
    "reușitei": "reușită",
    "reușitele": "reușită",
    "reușitelor": "reușită",
    "nemaireutilând": "reutila",
    "nemaireutilându": "reutila",
    "nereutilând": "reutila",
    "nereutilându": "reutila",
    "reutilă": "reutila",
    "reutilai": "reutila",
    "reutilam": "reutila",
    "reutilăm": "reutila",
    "reutilând": "reutila",
    "reutilându": "reutila",
    "reutilară": "reutila",
    "reutilarăm": "reutila",
    "reutilarăți": "reutila",
    "reutilase": "reutila",
    "reutilasem": "reutila",
    "reutilaseră": "reutila",
    "reutilaserăm": "reutila",
    "reutilaserăți": "reutila",
    "reutilaseși": "reutila",
    "reutilași": "reutila",
    "reutilat": "reutila",
    "reutilați": "reutila",
    "reutilau": "reutila",
    "reutilează": "reutila",
    "reutilez": "reutila",
    "reutileze": "reutila",
    "reutilezi": "reutila",
    "reutilată": "reutilat",
    "reutilate": "reutilat",
    "reutilați": "reutilat",
    "nemairevaccinând": "revaccina",
    "nemairevaccinându": "revaccina",
    "nerevaccinând": "revaccina",
    "nerevaccinându": "revaccina",
    "revaccină": "revaccina",
    "revaccinai": "revaccina",
    "revaccinam": "revaccina",
    "revaccinăm": "revaccina",
    "revaccinând": "revaccina",
    "revaccinându": "revaccina",
    "revaccinară": "revaccina",
    "revaccinarăm": "revaccina",
    "revaccinarăți": "revaccina",
    "revaccinase": "revaccina",
    "revaccinasem": "revaccina",
    "revaccinaseră": "revaccina",
    "revaccinaserăm": "revaccina",
    "revaccinaserăți": "revaccina",
    "revaccinaseși": "revaccina",
    "revaccinași": "revaccina",
    "revaccinat": "revaccina",
    "revaccinați": "revaccina",
    "revaccinau": "revaccina",
    "revaccinează": "revaccina",
    "revaccinez": "revaccina",
    "revaccineze": "revaccina",
    "revaccinezi": "revaccina",
    "revaccinată": "revaccinat",
    "revaccinate": "revaccinat",
    "revaccinați": "revaccinat",
    "nemairevalorificând": "revalorifica",
    "nemairevalorificându": "revalorifica",
    "nerevalorificând": "revalorifica",
    "nerevalorificându": "revalorifica",
    "revalorific": "revalorifica",
    "revalorifică": "revalorifica",
    "revalorificai": "revalorifica",
    "revalorificam": "revalorifica",
    "revalorificăm": "revalorifica",
    "revalorificând": "revalorifica",
    "revalorificându": "revalorifica",
    "revalorificară": "revalorifica",
    "revalorificarăm": "revalorifica",
    "revalorificarăți": "revalorifica",
    "revalorificase": "revalorifica",
    "revalorificasem": "revalorifica",
    "revalorificaseră": "revalorifica",
    "revalorificaserăm": "revalorifica",
    "revalorificaserăți": "revalorifica",
    "revalorificaseși": "revalorifica",
    "revalorificași": "revalorifica",
    "revalorificat": "revalorifica",
    "revalorificați": "revalorifica",
    "revalorificau": "revalorifica",
    "revalorifice": "revalorifica",
    "revalorifici": "revalorifica",
    "revalorificată": "revalorificat",
    "revalorificate": "revalorificat",
    "revalorificați": "revalorificat",
    "nemairevalorizând": "revaloriza",
    "nemairevalorizându": "revaloriza",
    "nerevalorizând": "revaloriza",
    "nerevalorizându": "revaloriza",
    "revaloriză": "revaloriza",
    "revalorizai": "revaloriza",
    "revalorizam": "revaloriza",
    "revalorizăm": "revaloriza",
    "revalorizând": "revaloriza",
    "revalorizându": "revaloriza",
    "revalorizară": "revaloriza",
    "revalorizarăm": "revaloriza",
    "revalorizarăți": "revaloriza",
    "revalorizase": "revaloriza",
    "revalorizasem": "revaloriza",
    "revalorizaseră": "revaloriza",
    "revalorizaserăm": "revaloriza",
    "revalorizaserăți": "revaloriza",
    "revalorizaseși": "revaloriza",
    "revalorizași": "revaloriza",
    "revalorizat": "revaloriza",
    "revalorizați": "revaloriza",
    "revalorizau": "revaloriza",
    "revalorizează": "revaloriza",
    "revalorizez": "revaloriza",
    "revalorizeze": "revaloriza",
    "revalorizezi": "revaloriza",
    "revalorizată": "revalorizat",
    "revalorizate": "revalorizat",
    "revalorizați": "revalorizat",
    "nemairevanșând": "revanșa",
    "nemairevanșându": "revanșa",
    "nerevanșând": "revanșa",
    "nerevanșându": "revanșa",
    "revanșă": "revanșa",
    "revanșai": "revanșa",
    "revanșam": "revanșa",
    "revanșăm": "revanșa",
    "revanșând": "revanșa",
    "revanșându": "revanșa",
    "revanșară": "revanșa",
    "revanșarăm": "revanșa",
    "revanșarăți": "revanșa",
    "revanșase": "revanșa",
    "revanșasem": "revanșa",
    "revanșaseră": "revanșa",
    "revanșaserăm": "revanșa",
    "revanșaserăți": "revanșa",
    "revanșaseși": "revanșa",
    "revanșași": "revanșa",
    "revanșat": "revanșa",
    "revanșați": "revanșa",
    "revanșau": "revanșa",
    "revanșează": "revanșa",
    "revanșez": "revanșa",
    "revanșeze": "revanșa",
    "revanșezi": "revanșa",
    "revanșa": "revanșă",
    "revanșe": "revanșă",
    "revanșei": "revanșă",
    "revanșele": "revanșă",
    "revanșelor": "revanșă",
    "revanșarda": "revanșard",
    "revanșardă": "revanșard",
    "revanșarde": "revanșard",
    "revanșardei": "revanșard",
    "revanșardele": "revanșard",
    "revanșardelor": "revanșard",
    "revanșardul": "revanșard",
    "revanșardului": "revanșard",
    "revanșarzi": "revanșard",
    "revanșarzii": "revanșard",
    "revanșarzilor": "revanșard",
    "revanșată": "revanșat",
    "revanșate": "revanșat",
    "revanșați": "revanșat",
    "nemairevărsând": "revărsa",
    "nemairevărsându": "revărsa",
    "nerevărsând": "revărsa",
    "nerevărsându": "revărsa",
    "revărs": "revărsa",
    "revarsă": "revărsa",
    "revărsă": "revărsa",
    "revărsai": "revărsa",
    "revărsam": "revărsa",
    "revărsăm": "revărsa",
    "revărsând": "revărsa",
    "revărsându": "revărsa",
    "revărsară": "revărsa",
    "revărsarăm": "revărsa",
    "revărsarăți": "revărsa",
    "revărsase": "revărsa",
    "revărsasem": "revărsa",
    "revărsaseră": "revărsa",
    "revărsaserăm": "revărsa",
    "revărsaserăți": "revărsa",
    "revărsaseși": "revărsa",
    "revărsași": "revărsa",
    "revărsat": "revărsa",
    "revărsați": "revărsa",
    "revărsau": "revărsa",
    "reverse": "revărsa",
    "reverși": "revărsa",
    "revărsarea": "revărsare",
    "revărsareo": "revărsare",
    "revărsări": "revărsare",
    "revărsării": "revărsare",
    "revărsările": "revărsare",
    "revărsărilor": "revărsare",
    "revărsata": "revărsat",
    "revărsată": "revărsat",
    "revărsate": "revărsat",
    "revărsatei": "revărsat",
    "revărsatele": "revărsat",
    "revărsatelor": "revărsat",
    "revărsați": "revărsat",
    "revărsații": "revărsat",
    "revărsaților": "revărsat",
    "revărsato": "revărsat",
    "revărsatul": "revărsat",
    "revărsatule": "revărsat",
    "revărsatului": "revărsat",
    "revăzută": "revăzut",
    "revăzute": "revăzut",
    "revăzuți": "revăzut",
    "nemairevăzând": "revedea",
    "nemairevăzându": "revedea",
    "nerevăzând": "revedea",
    "nerevăzându": "revedea",
    "revăd": "revedea",
    "revadă": "revedea",
    "revăzând": "revedea",
    "revăzându": "revedea",
    "revăzu": "revedea",
    "revăzui": "revedea",
    "revăzură": "revedea",
    "revăzurăm": "revedea",
    "revăzurăți": "revedea",
    "revăzuse": "revedea",
    "revăzusem": "revedea",
    "revăzuseră": "revedea",
    "revăzuserăm": "revedea",
    "revăzuserăți": "revedea",
    "revăzuseși": "revedea",
    "revăzuși": "revedea",
    "revăzut": "revedea",
    "revede": "revedea",
    "revedeai": "revedea",
    "revedeam": "revedea",
    "revedeați": "revedea",
    "revedeau": "revedea",
    "revedem": "revedea",
    "revedeți": "revedea",
    "revezi": "revedea",
    "revederea": "revedere",
    "revederi": "revedere",
    "revederii": "revedere",
    "revederile": "revedere",
    "revederilor": "revedere",
    "nemairevelând": "revela",
    "nemairevelându": "revela",
    "nerevelând": "revela",
    "nerevelându": "revela",
    "revelă": "revela",
    "revelai": "revela",
    "revelam": "revela",
    "revelăm": "revela",
    "revelând": "revela",
    "revelându": "revela",
    "revelară": "revela",
    "revelarăm": "revela",
    "revelarăți": "revela",
    "revelase": "revela",
    "revelasem": "revela",
    "revelaseră": "revela",
    "revelaserăm": "revela",
    "revelaserăți": "revela",
    "revelaseși": "revela",
    "revelași": "revela",
    "revelat": "revela",
    "revelați": "revela",
    "revelau": "revela",
    "revelează": "revela",
    "revelez": "revela",
    "reveleze": "revela",
    "revelezi": "revela",
    "revelarea": "revelare",
    "revelări": "revelare",
    "revelării": "revelare",
    "revelările": "revelare",
    "revelărilor": "revelare",
    "revelată": "revelat",
    "revelate": "revelat",
    "revelați": "revelat",
    "revelația": "revelație",
    "revelației": "revelație",
    "revelații": "revelație",
    "revelațiile": "revelație",
    "revelațiilor": "revelație",
    "revelatoare": "revelator",
    "revelatoarea": "revelator",
    "revelatoarei": "revelator",
    "revelatoarele": "revelator",
    "revelatoarelor": "revelator",
    "revelatori": "revelator",
    "revelatorii": "revelator",
    "revelatorilor": "revelator",
    "revelatorul": "revelator",
    "revelatorului": "revelator",
    "revelioane": "revelion",
    "revelioanele": "revelion",
    "revelioanelor": "revelion",
    "revelionul": "revelion",
    "revelionului": "revelion",
    "nemairevendicând": "revendica",
    "nemairevendicându": "revendica",
    "nerevendicând": "revendica",
    "nerevendicându": "revendica",
    "revendic": "revendica",
    "revendică": "revendica",
    "revendicai": "revendica",
    "revendicam": "revendica",
    "revendicăm": "revendica",
    "revendicând": "revendica",
    "revendicându": "revendica",
    "revendicară": "revendica",
    "revendicarăm": "revendica",
    "revendicarăți": "revendica",
    "revendicase": "revendica",
    "revendicasem": "revendica",
    "revendicaseră": "revendica",
    "revendicaserăm": "revendica",
    "revendicaserăți": "revendica",
    "revendicaseși": "revendica",
    "revendicași": "revendica",
    "revendicat": "revendica",
    "revendicați": "revendica",
    "revendicau": "revendica",
    "revendice": "revendica",
    "revendici": "revendica",
    "revendicarea": "revendicare",
    "revendicări": "revendicare",
    "revendicării": "revendicare",
    "revendicările": "revendicare",
    "revendicărilor": "revendicare",
    "revendicată": "revendicat",
    "revendicate": "revendicat",
    "revendicați": "revendicat",
    "revendicativa": "revendicativ",
    "revendicativă": "revendicativ",
    "revendicative": "revendicativ",
    "revendicativei": "revendicativ",
    "revendicativele": "revendicativ",
    "revendicativelor": "revendicativ",
    "revendicativi": "revendicativ",
    "revendicativii": "revendicativ",
    "revendicativilor": "revendicativ",
    "revendicativul": "revendicativ",
    "revendicativului": "revendicativ",
    "nemairevenind": "reveni",
    "nemairevenindu": "reveni",
    "nerevenind": "reveni",
    "nerevenindu": "reveni",
    "revenea": "reveni",
    "reveneai": "reveni",
    "reveneam": "reveni",
    "reveneați": "reveni",
    "reveneau": "reveni",
    "revenii": "reveni",
    "revenim": "reveni",
    "revenind": "reveni",
    "revenindu": "reveni",
    "reveniră": "reveni",
    "revenirăm": "reveni",
    "revenirăți": "reveni",
    "revenise": "reveni",
    "revenisem": "reveni",
    "reveniseră": "reveni",
    "reveniserăm": "reveni",
    "reveniserăți": "reveni",
    "reveniseși": "reveni",
    "reveniși": "reveni",
    "revenit": "reveni",
    "reveniți": "reveni",
    "revii": "reveni",
    "revin": "reveni",
    "revină": "reveni",
    "revine": "reveni",
    "revino": "reveni",
    "revenirea": "revenire",
    "revenireo": "revenire",
    "reveniri": "revenire",
    "revenirii": "revenire",
    "revenirile": "revenire",
    "revenirilor": "revenire",
    "revenită": "revenit",
    "revenite": "revenit",
    "reveniți": "revenit",
    "reverberația": "reverberație",
    "reverberației": "reverberație",
    "reverberații": "reverberație",
    "reverberațiile": "reverberație",
    "reverberațiilor": "reverberație",
    "reverende": "reverend",
    "reverendele": "reverend",
    "reverendelor": "reverend",
    "reverendul": "reverend",
    "reverendului": "reverend",
    "reverenda": "reverendă",
    "reverende": "reverendă",
    "reverendei": "reverendă",
    "reverendele": "reverendă",
    "reverendelor": "reverendă",
    "reverența": "reverență",
    "reverențe": "reverență",
    "reverenței": "reverență",
    "reverențele": "reverență",
    "reverențelor": "reverență",
    "reverențioasa": "reverențios",
    "reverențioasă": "reverențios",
    "reverențioase": "reverențios",
    "reverențioasei": "reverențios",
    "reverențioasele": "reverențios",
    "reverențioaselor": "reverențios",
    "reverențioși": "reverențios",
    "reverențioșii": "reverențios",
    "reverențioșilor": "reverențios",
    "reverențiosul": "reverențios",
    "reverențiosului": "reverențios",
    "reveria": "reverie",
    "reveriei": "reverie",
    "reverii": "reverie",
    "reveriile": "reverie",
    "reveriilor": "reverie",
    "reversul": "revers",
    "reversului": "revers",
    "reversuri": "revers",
    "reversurile": "revers",
    "reversurilor": "revers",
    "reversibila": "reversibil",
    "reversibilă": "reversibil",
    "reversibile": "reversibil",
    "reversibilei": "reversibil",
    "reversibilele": "reversibil",
    "reversibilelor": "reversibil",
    "reversibili": "reversibil",
    "reversibilii": "reversibil",
    "reversibililor": "reversibil",
    "reversibilul": "reversibil",
    "reversibilului": "reversibil",
    "revigoră": "revigora",
    "revigorai": "revigora",
    "revigoram": "revigora",
    "revigorăm": "revigora",
    "revigorând": "revigora",
    "revigorându": "revigora",
    "revigorară": "revigora",
    "revigorarăm": "revigora",
    "revigorarăți": "revigora",
    "revigorase": "revigora",
    "revigorasem": "revigora",
    "revigoraseră": "revigora",
    "revigoraserăm": "revigora",
    "revigoraserăți": "revigora",
    "revigoraseși": "revigora",
    "revigorași": "revigora",
    "revigorat": "revigora",
    "revigorați": "revigora",
    "revigorau": "revigora",
    "revigorează": "revigora",
    "revigorez": "revigora",
    "revigoreze": "revigora",
    "revigorezi": "revigora",
    "revigorată": "revigorat",
    "revigorate": "revigorat",
    "revigorați": "revigorat",
    "revista": "revistă",
    "reviste": "revistă",
    "revistei": "revistă",
    "revistele": "revistă",
    "revistelor": "revistă",
    "revizia": "revizie",
    "reviziei": "revizie",
    "revizii": "revizie",
    "reviziile": "revizie",
    "reviziilor": "revizie",
    "revizionismul": "revizionism",
    "revizionismului": "revizionism",
    "revizori": "revizor",
    "revizorii": "revizor",
    "revizorilor": "revizor",
    "revizorul": "revizor",
    "revizorului": "revizor",
    "nemairevizuind": "revizui",
    "nemairevizuindu": "revizui",
    "nerevizuind": "revizui",
    "nerevizuindu": "revizui",
    "revizuia": "revizui",
    "revizuiai": "revizui",
    "revizuiam": "revizui",
    "revizuiască": "revizui",
    "revizuiați": "revizui",
    "revizuiau": "revizui",
    "revizuiesc": "revizui",
    "revizuiește": "revizui",
    "revizuiești": "revizui",
    "revizuii": "revizui",
    "revizuim": "revizui",
    "revizuind": "revizui",
    "revizuindu": "revizui",
    "revizuiră": "revizui",
    "revizuirăm": "revizui",
    "revizuirăți": "revizui",
    "revizuise": "revizui",
    "revizuisem": "revizui",
    "revizuiseră": "revizui",
    "revizuiserăm": "revizui",
    "revizuiserăți": "revizui",
    "revizuiseși": "revizui",
    "revizuiși": "revizui",
    "revizuit": "revizui",
    "revizuiți": "revizui",
    "revizuirea": "revizuire",
    "revizuiri": "revizuire",
    "revizuirii": "revizuire",
    "revizuirile": "revizuire",
    "revizuirilor": "revizuire",
    "revizuită": "revizuit",
    "revizuite": "revizuit",
    "revizuiți": "revizuit",
    "nemairevocând": "revoca",
    "nemairevocându": "revoca",
    "nerevocând": "revoca",
    "nerevocându": "revoca",
    "revoc": "revoca",
    "revocă": "revoca",
    "revocai": "revoca",
    "revocam": "revoca",
    "revocăm": "revoca",
    "revocând": "revoca",
    "revocându": "revoca",
    "revocară": "revoca",
    "revocarăm": "revoca",
    "revocarăți": "revoca",
    "revocase": "revoca",
    "revocasem": "revoca",
    "revocaseră": "revoca",
    "revocaserăm": "revoca",
    "revocaserăți": "revoca",
    "revocaseși": "revoca",
    "revocași": "revoca",
    "revocat": "revoca",
    "revocați": "revoca",
    "revocau": "revoca",
    "revoce": "revoca",
    "revoci": "revoca",
    "revocată": "revocat",
    "revocate": "revocat",
    "revocați": "revocat",
    "nemairevoltând": "revolta",
    "nemairevoltându": "revolta",
    "nerevoltând": "revolta",
    "nerevoltându": "revolta",
    "revolt": "revolta",
    "revoltă": "revolta",
    "revoltai": "revolta",
    "revoltam": "revolta",
    "revoltăm": "revolta",
    "revoltând": "revolta",
    "revoltându": "revolta",
    "revoltară": "revolta",
    "revoltarăm": "revolta",
    "revoltarăți": "revolta",
    "revoltase": "revolta",
    "revoltasem": "revolta",
    "revoltaseră": "revolta",
    "revoltaserăm": "revolta",
    "revoltaserăți": "revolta",
    "revoltaseși": "revolta",
    "revoltași": "revolta",
    "revoltat": "revolta",
    "revoltați": "revolta",
    "revoltau": "revolta",
    "revolte": "revolta",
    "revolți": "revolta",
    "revolta": "revoltă",
    "revolte": "revoltă",
    "revoltei": "revoltă",
    "revoltele": "revoltă",
    "revoltelor": "revoltă",
    "revoltată": "revoltat",
    "revoltate": "revoltat",
    "revoltați": "revoltat",
    "revoltătoare": "revoltător",
    "revoltătoarea": "revoltător",
    "revoltătoarei": "revoltător",
    "revoltătoarele": "revoltător",
    "revoltătoarelor": "revoltător",
    "revoltători": "revoltător",
    "revoluta": "revolut",
    "revolută": "revolut",
    "revolute": "revolut",
    "revolutei": "revolut",
    "revolutele": "revolut",
    "revolutelor": "revolut",
    "revoluți": "revolut",
    "revoluții": "revolut",
    "revoluților": "revolut",
    "revolutul": "revolut",
    "revolutului": "revolut",
    "revoluția": "revoluție",
    "revoluției": "revoluție",
    "revoluții": "revoluție",
    "revoluțiile": "revoluție",
    "revoluțiilor": "revoluție",
    "nemairevoluționând": "revoluționa",
    "nemairevoluționându": "revoluționa",
    "nerevoluționând": "revoluționa",
    "nerevoluționându": "revoluționa",
    "revoluționă": "revoluționa",
    "revoluționai": "revoluționa",
    "revoluționam": "revoluționa",
    "revoluționăm": "revoluționa",
    "revoluționând": "revoluționa",
    "revoluționându": "revoluționa",
    "revoluționară": "revoluționa",
    "revoluționarăm": "revoluționa",
    "revoluționarăți": "revoluționa",
    "revoluționase": "revoluționa",
    "revoluționasem": "revoluționa",
    "revoluționaseră": "revoluționa",
    "revoluționaserăm": "revoluționa",
    "revoluționaserăți": "revoluționa",
    "revoluționaseși": "revoluționa",
    "revoluționași": "revoluționa",
    "revoluționat": "revoluționa",
    "revoluționați": "revoluționa",
    "revoluționau": "revoluționa",
    "revoluționează": "revoluționa",
    "revoluționez": "revoluționa",
    "revoluționeze": "revoluționa",
    "revoluționezi": "revoluționa",
    "revoluționara": "revoluționar",
    "revoluționară": "revoluționar",
    "revoluționare": "revoluționar",
    "revoluționarei": "revoluționar",
    "revoluționarele": "revoluționar",
    "revoluționarelor": "revoluționar",
    "revoluționari": "revoluționar",
    "revoluționarii": "revoluționar",
    "revoluționarilor": "revoluționar",
    "revoluționarul": "revoluționar",
    "revoluționarului": "revoluționar",
    "revoluționată": "revoluționat",
    "revoluționate": "revoluționat",
    "revoluționați": "revoluționat",
    "revolvere": "revolver",
    "revolverele": "revolver",
    "revolverelor": "revolver",
    "revolverul": "revolver",
    "revolverului": "revolver",
    "revuistica": "revuistic",
    "revuistică": "revuistic",
    "revuistice": "revuistic",
    "revuisticei": "revuistic",
    "revuisticele": "revuistic",
    "revuisticelor": "revuistic",
    "revuistici": "revuistic",
    "revuisticii": "revuistic",
    "revuisticilor": "revuistic",
    "revuisticul": "revuistic",
    "revuisticului": "revuistic",
    "revulsia": "revulsie",
    "revulsiei": "revulsie",
    "revulsii": "revulsie",
    "revulsiile": "revulsie",
    "revulsiilor": "revulsie",
    "revulsiva": "revulsiv",
    "revulsivă": "revulsiv",
    "revulsive": "revulsiv",
    "revulsivei": "revulsiv",
    "revulsivele": "revulsiv",
    "revulsivelor": "revulsiv",
    "revulsivi": "revulsiv",
    "revulsivii": "revulsiv",
    "revulsivilor": "revulsiv",
    "revulsivul": "revulsiv",
    "revulsivului": "revulsiv",
    "nemairezemând": "rezema",
    "nemairezemându": "rezema",
    "nerezemând": "rezema",
    "nerezemându": "rezema",
    "reazem": "rezema",
    "reazemă": "rezema",
    "reazeme": "rezema",
    "rezemă": "rezema",
    "rezemai": "rezema",
    "rezemam": "rezema",
    "rezemăm": "rezema",
    "rezemând": "rezema",
    "rezemându": "rezema",
    "rezemară": "rezema",
    "rezemarăm": "rezema",
    "rezemarăți": "rezema",
    "rezemase": "rezema",
    "rezemasem": "rezema",
    "rezemaseră": "rezema",
    "rezemaserăm": "rezema",
    "rezemaserăți": "rezema",
    "rezemaseși": "rezema",
    "rezemași": "rezema",
    "rezemat": "rezema",
    "rezemați": "rezema",
    "rezemau": "rezema",
    "rezemi": "rezema",
    "rezemată": "rezemat",
    "rezemate": "rezemat",
    "rezemați": "rezemat",
    "rezemătoarea": "rezemătoare",
    "rezemătoarele": "rezemătoare",
    "rezemători": "rezemătoare",
    "rezemătorii": "rezemătoare",
    "rezemătorilor": "rezemătoare",
    "nemairezervând": "rezerva",
    "nemairezervându": "rezerva",
    "nerezervând": "rezerva",
    "nerezervându": "rezerva",
    "rezerv": "rezerva",
    "rezervă": "rezerva",
    "rezervai": "rezerva",
    "rezervam": "rezerva",
    "rezervăm": "rezerva",
    "rezervând": "rezerva",
    "rezervându": "rezerva",
    "rezervară": "rezerva",
    "rezervarăm": "rezerva",
    "rezervarăți": "rezerva",
    "rezervase": "rezerva",
    "rezervasem": "rezerva",
    "rezervaseră": "rezerva",
    "rezervaserăm": "rezerva",
    "rezervaserăți": "rezerva",
    "rezervaseși": "rezerva",
    "rezervași": "rezerva",
    "rezervat": "rezerva",
    "rezervați": "rezerva",
    "rezervau": "rezerva",
    "rezerve": "rezerva",
    "rezervi": "rezerva",
    "rezerva": "rezervă",
    "rezerve": "rezervă",
    "rezervei": "rezervă",
    "rezervele": "rezervă",
    "rezervelor": "rezervă",
    "rezervarea": "rezervare",
    "rezervareo": "rezervare",
    "rezervări": "rezervare",
    "rezervării": "rezervare",
    "rezervările": "rezervare",
    "rezervărilor": "rezervare",
    "rezervata": "rezervat",
    "rezervată": "rezervat",
    "rezervate": "rezervat",
    "rezervatei": "rezervat",
    "rezervatele": "rezervat",
    "rezervatelor": "rezervat",
    "rezervați": "rezervat",
    "rezervații": "rezervat",
    "rezervaților": "rezervat",
    "rezervato": "rezervat",
    "rezervatul": "rezervat",
    "rezervatule": "rezervat",
    "rezervatului": "rezervat",
    "rezervația": "rezervație",
    "rezervației": "rezervație",
    "rezervații": "rezervație",
    "rezervațiile": "rezervație",
    "rezervațiilor": "rezervație",
    "rezervoare": "rezervor",
    "rezervoarele": "rezervor",
    "rezervoarelor": "rezervor",
    "rezervorul": "rezervor",
    "rezervorului": "rezervor",
    "rezidă": "rezida",
    "rezidai": "rezida",
    "rezidam": "rezida",
    "rezidăm": "rezida",
    "rezidând": "rezida",
    "rezidându": "rezida",
    "rezidară": "rezida",
    "rezidarăm": "rezida",
    "rezidarăți": "rezida",
    "rezidase": "rezida",
    "rezidasem": "rezida",
    "rezidaseră": "rezida",
    "rezidaserăm": "rezida",
    "rezidaserăți": "rezida",
    "rezidaseși": "rezida",
    "rezidași": "rezida",
    "rezidat": "rezida",
    "rezidați": "rezida",
    "rezidatu": "rezida",
    "rezidau": "rezida",
    "rezidez": "rezida",
    "rezideze": "rezida",
    "rezidezi": "rezida",
    "rezidată": "rezidat",
    "rezidate": "rezidat",
    "rezidați": "rezidat",
    "rezidenți": "rezident",
    "rezidenții": "rezident",
    "rezidenților": "rezident",
    "rezidentul": "rezident",
    "rezidentului": "rezident",
    "rezidenta": "rezidentă",
    "rezidente": "rezidentă",
    "rezidentei": "rezidentă",
    "rezidentele": "rezidentă",
    "rezidentelor": "rezidentă",
    "rezidența": "rezidență",
    "rezidențe": "rezidență",
    "rezidenței": "rezidență",
    "rezidențele": "rezidență",
    "rezidențelor": "rezidență",
    "rezidențială": "rezidențial",
    "rezidențiale": "rezidențial",
    "rezidențiali": "rezidențial",
    "rezidențiate": "rezidențiat",
    "rezidențiatele": "rezidențiat",
    "rezidențiatelor": "rezidențiat",
    "rezidențiatul": "rezidențiat",
    "rezidențiatului": "rezidențiat",
    "reziduala": "rezidual",
    "reziduală": "rezidual",
    "reziduale": "rezidual",
    "rezidualei": "rezidual",
    "rezidualele": "rezidual",
    "rezidualelor": "rezidual",
    "reziduali": "rezidual",
    "rezidualii": "rezidual",
    "rezidualilor": "rezidual",
    "rezidualul": "rezidual",
    "rezidualului": "rezidual",
    "reziduul": "reziduu",
    "reziduului": "reziduu",
    "reziduuri": "reziduu",
    "reziduurile": "reziduu",
    "reziduurilor": "reziduu",
    "nemaireziliind": "rezilia",
    "nemaireziliindu": "rezilia",
    "nereziliind": "rezilia",
    "nereziliindu": "rezilia",
    "reziliai": "rezilia",
    "reziliam": "rezilia",
    "reziliară": "rezilia",
    "reziliarăm": "rezilia",
    "reziliarăți": "rezilia",
    "reziliase": "rezilia",
    "reziliasem": "rezilia",
    "reziliaseră": "rezilia",
    "reziliaserăm": "rezilia",
    "reziliaserăți": "rezilia",
    "reziliaseși": "rezilia",
    "reziliași": "rezilia",
    "reziliat": "rezilia",
    "reziliați": "rezilia",
    "reziliau": "rezilia",
    "reziliază": "rezilia",
    "rezilie": "rezilia",
    "reziliem": "rezilia",
    "reziliez": "rezilia",
    "rezilieze": "rezilia",
    "reziliezi": "rezilia",
    "reziliind": "rezilia",
    "reziliindu": "rezilia",
    "reziliată": "reziliat",
    "reziliate": "reziliat",
    "reziliați": "reziliat",
    "rezilierea": "reziliere",
    "rezilieri": "reziliere",
    "rezilierii": "reziliere",
    "rezilierile": "reziliere",
    "rezilierilor": "reziliere",
    "nemairezistând": "rezista",
    "nemairezistându": "rezista",
    "nerezistând": "rezista",
    "nerezistându": "rezista",
    "rezist": "rezista",
    "rezistă": "rezista",
    "rezistai": "rezista",
    "rezistam": "rezista",
    "rezistăm": "rezista",
    "rezistând": "rezista",
    "rezistându": "rezista",
    "rezistară": "rezista",
    "rezistarăm": "rezista",
    "rezistarăți": "rezista",
    "rezistase": "rezista",
    "rezistasem": "rezista",
    "rezistaseră": "rezista",
    "rezistaserăm": "rezista",
    "rezistaserăți": "rezista",
    "rezistaseși": "rezista",
    "rezistași": "rezista",
    "rezistat": "rezista",
    "rezistați": "rezista",
    "rezistau": "rezista",
    "reziste": "rezista",
    "reziști": "rezista",
    "rezistată": "rezistat",
    "rezistate": "rezistat",
    "rezistați": "rezistat",
    "rezistenta": "rezistent",
    "rezistentă": "rezistent",
    "rezistente": "rezistent",
    "rezistentei": "rezistent",
    "rezistentele": "rezistent",
    "rezistentelor": "rezistent",
    "rezistenți": "rezistent",
    "rezistenții": "rezistent",
    "rezistenților": "rezistent",
    "rezistentul": "rezistent",
    "rezistentului": "rezistent",
    "rezistența": "rezistență",
    "rezistențe": "rezistență",
    "rezistenței": "rezistență",
    "rezistențele": "rezistență",
    "rezistențelor": "rezistență",
    "rezistivitatea": "rezistivitate",
    "rezistivități": "rezistivitate",
    "rezistivității": "rezistivitate",
    "rezistivitățile": "rezistivitate",
    "rezistivităților": "rezistivitate",
    "rezistoare": "rezistor",
    "rezistoarele": "rezistor",
    "rezistoarelor": "rezistor",
    "rezistorul": "rezistor",
    "rezistorului": "rezistor",
    "rezoluția": "rezoluție",
    "rezoluției": "rezoluție",
    "rezoluții": "rezoluție",
    "rezoluțiile": "rezoluție",
    "rezoluțiilor": "rezoluție",
    "nemairezolvând": "rezolva",
    "nemairezolvându": "rezolva",
    "nerezolvând": "rezolva",
    "nerezolvându": "rezolva",
    "rezolv": "rezolva",
    "rezolvă": "rezolva",
    "rezolvai": "rezolva",
    "rezolvam": "rezolva",
    "rezolvăm": "rezolva",
    "rezolvând": "rezolva",
    "rezolvându": "rezolva",
    "rezolvară": "rezolva",
    "rezolvarăm": "rezolva",
    "rezolvarăți": "rezolva",
    "rezolvase": "rezolva",
    "rezolvasem": "rezolva",
    "rezolvaseră": "rezolva",
    "rezolvaserăm": "rezolva",
    "rezolvaserăți": "rezolva",
    "rezolvaseși": "rezolva",
    "rezolvași": "rezolva",
    "rezolvat": "rezolva",
    "rezolvați": "rezolva",
    "rezolvau": "rezolva",
    "rezolve": "rezolva",
    "rezolvi": "rezolva",
    "rezolvarea": "rezolvare",
    "rezolvareo": "rezolvare",
    "rezolvări": "rezolvare",
    "rezolvării": "rezolvare",
    "rezolvările": "rezolvare",
    "rezolvărilor": "rezolvare",
    "rezolvata": "rezolvat",
    "rezolvată": "rezolvat",
    "rezolvate": "rezolvat",
    "rezolvatei": "rezolvat",
    "rezolvatele": "rezolvat",
    "rezolvatelor": "rezolvat",
    "rezolvați": "rezolvat",
    "rezolvații": "rezolvat",
    "rezolvaților": "rezolvat",
    "rezolvato": "rezolvat",
    "rezolvatul": "rezolvat",
    "rezolvatule": "rezolvat",
    "rezolvatului": "rezolvat",
    "rezonabila": "rezonabil",
    "rezonabilă": "rezonabil",
    "rezonabile": "rezonabil",
    "rezonabilei": "rezonabil",
    "rezonabilele": "rezonabil",
    "rezonabilelor": "rezonabil",
    "rezonabili": "rezonabil",
    "rezonabilii": "rezonabil",
    "rezonabililor": "rezonabil",
    "rezonabilul": "rezonabil",
    "rezonabilului": "rezonabil",
    "rezonanța": "rezonanță",
    "rezonanțe": "rezonanță",
    "rezonanței": "rezonanță",
    "rezonanțele": "rezonanță",
    "rezonanțelor": "rezonanță",
    "nemairezultând": "rezulta",
    "nemairezultându": "rezulta",
    "nerezultând": "rezulta",
    "nerezultându": "rezulta",
    "rezultă": "rezulta",
    "rezultând": "rezulta",
    "rezultându": "rezulta",
    "rezultară": "rezulta",
    "rezultase": "rezulta",
    "rezultaseră": "rezulta",
    "rezultat": "rezulta",
    "rezultau": "rezulta",
    "rezulte": "rezulta",
    "rezultanta": "rezultantă",
    "rezultante": "rezultantă",
    "rezultantei": "rezultantă",
    "rezultantele": "rezultantă",
    "rezultantelor": "rezultantă",
    "rezultată": "rezultat",
    "rezultate": "rezultat",
    "rezultatele": "rezultat",
    "rezultatelor": "rezultat",
    "rezultați": "rezultat",
    "rezultatul": "rezultat",
    "rezultatului": "rezultat",
    "nemairezumând": "rezuma",
    "nemairezumându": "rezuma",
    "nerezumând": "rezuma",
    "nerezumându": "rezuma",
    "rezum": "rezuma",
    "rezumă": "rezuma",
    "rezumai": "rezuma",
    "rezumam": "rezuma",
    "rezumăm": "rezuma",
    "rezumând": "rezuma",
    "rezumându": "rezuma",
    "rezumară": "rezuma",
    "rezumarăm": "rezuma",
    "rezumarăți": "rezuma",
    "rezumase": "rezuma",
    "rezumasem": "rezuma",
    "rezumaseră": "rezuma",
    "rezumaserăm": "rezuma",
    "rezumaserăți": "rezuma",
    "rezumaseși": "rezuma",
    "rezumași": "rezuma",
    "rezumat": "rezuma",
    "rezumați": "rezuma",
    "rezumau": "rezuma",
    "rezume": "rezuma",
    "rezumi": "rezuma",
    "rezumată": "rezumat",
    "rezumate": "rezumat",
    "rezumatele": "rezumat",
    "rezumatelor": "rezumat",
    "rezumați": "rezumat",
    "rezumatul": "rezumat",
    "rezumatului": "rezumat",
    "rezumativa": "rezumativ",
    "rezumativă": "rezumativ",
    "rezumative": "rezumativ",
    "rezumativei": "rezumativ",
    "rezumativele": "rezumativ",
    "rezumativelor": "rezumativ",
    "rezumativi": "rezumativ",
    "rezumativii": "rezumativ",
    "rezumativilor": "rezumativ",
    "rezumativul": "rezumativ",
    "rezumativului": "rezumativ",
    "ricini": "ricin",
    "ricinii": "ricin",
    "ricinilor": "ricin",
    "ricinul": "ricin",
    "ricinului": "ricin",
    "nemairicoșând": "ricoșa",
    "nemairicoșându": "ricoșa",
    "nericoșând": "ricoșa",
    "nericoșându": "ricoșa",
    "ricoșă": "ricoșa",
    "ricoșai": "ricoșa",
    "ricoșam": "ricoșa",
    "ricoșăm": "ricoșa",
    "ricoșând": "ricoșa",
    "ricoșându": "ricoșa",
    "ricoșară": "ricoșa",
    "ricoșarăm": "ricoșa",
    "ricoșarăți": "ricoșa",
    "ricoșase": "ricoșa",
    "ricoșasem": "ricoșa",
    "ricoșaseră": "ricoșa",
    "ricoșaserăm": "ricoșa",
    "ricoșaserăți": "ricoșa",
    "ricoșaseși": "ricoșa",
    "ricoșași": "ricoșa",
    "ricoșat": "ricoșa",
    "ricoșați": "ricoșa",
    "ricoșau": "ricoșa",
    "ricoșează": "ricoșa",
    "ricoșez": "ricoșa",
    "ricoșeze": "ricoșa",
    "ricoșezi": "ricoșa",
    "ricoșată": "ricoșat",
    "ricoșate": "ricoșat",
    "ricoșați": "ricoșat",
    "ricoșeul": "ricoșeu",
    "ricoșeului": "ricoșeu",
    "ricoșeuri": "ricoșeu",
    "ricoșeurile": "ricoșeu",
    "ricoșeurilor": "ricoșeu",
    "ricșa": "ricșă",
    "ricșe": "ricșă",
    "ricșei": "ricșă",
    "ricșele": "ricșă",
    "ricșelor": "ricșă",
    "rictusul": "rictus",
    "rictusului": "rictus",
    "rictusuri": "rictus",
    "rictusurile": "rictus",
    "rictusurilor": "rictus",
    "ridul": "rid",
    "ridului": "rid",
    "riduri": "rid",
    "ridurile": "rid",
    "ridurilor": "rid",
    "nemairidicând": "ridica",
    "nemairidicându": "ridica",
    "neridicând": "ridica",
    "neridicându": "ridica",
    "ridic": "ridica",
    "ridică": "ridica",
    "ridicai": "ridica",
    "ridicam": "ridica",
    "ridicăm": "ridica",
    "ridicând": "ridica",
    "ridicându": "ridica",
    "ridicară": "ridica",
    "ridicarăm": "ridica",
    "ridicarăți": "ridica",
    "ridicase": "ridica",
    "ridicasem": "ridica",
    "ridicaseră": "ridica",
    "ridicaserăm": "ridica",
    "ridicaserăți": "ridica",
    "ridicaseși": "ridica",
    "ridicași": "ridica",
    "ridicat": "ridica",
    "ridicați": "ridica",
    "ridicau": "ridica",
    "ridice": "ridica",
    "ridici": "ridica",
    "ridicarea": "ridicare",
    "ridicări": "ridicare",
    "ridicării": "ridicare",
    "ridicările": "ridicare",
    "ridicărilor": "ridicare",
    "ridicată": "ridicat",
    "ridicate": "ridicat",
    "ridicați": "ridicat",
    "ridicătura": "ridicătură",
    "ridicături": "ridicătură",
    "ridicăturii": "ridicătură",
    "ridicăturile": "ridicătură",
    "ridicăturilor": "ridicătură",
    "ridichea": "ridiche",
    "ridichi": "ridiche",
    "ridichii": "ridiche",
    "ridichile": "ridiche",
    "ridichilor": "ridiche",
    "ridicola": "ridicol",
    "ridicolă": "ridicol",
    "ridicole": "ridicol",
    "ridicolei": "ridicol",
    "ridicolele": "ridicol",
    "ridicolelor": "ridicol",
    "ridicoli": "ridicol",
    "ridicolii": "ridicol",
    "ridicolilor": "ridicol",
    "ridicolul": "ridicol",
    "ridicolului": "ridicol",
    "nemairidiculizând": "ridiculiza",
    "nemairidiculizându": "ridiculiza",
    "neridiculizând": "ridiculiza",
    "neridiculizându": "ridiculiza",
    "ridiculiză": "ridiculiza",
    "ridiculizai": "ridiculiza",
    "ridiculizam": "ridiculiza",
    "ridiculizăm": "ridiculiza",
    "ridiculizând": "ridiculiza",
    "ridiculizându": "ridiculiza",
    "ridiculizară": "ridiculiza",
    "ridiculizarăm": "ridiculiza",
    "ridiculizarăți": "ridiculiza",
    "ridiculizase": "ridiculiza",
    "ridiculizasem": "ridiculiza",
    "ridiculizaseră": "ridiculiza",
    "ridiculizaserăm": "ridiculiza",
    "ridiculizaserăți": "ridiculiza",
    "ridiculizaseși": "ridiculiza",
    "ridiculizași": "ridiculiza",
    "ridiculizat": "ridiculiza",
    "ridiculizați": "ridiculiza",
    "ridiculizau": "ridiculiza",
    "ridiculizează": "ridiculiza",
    "ridiculizez": "ridiculiza",
    "ridiculizeze": "ridiculiza",
    "ridiculizezi": "ridiculiza",
    "ridiculizată": "ridiculizat",
    "ridiculizate": "ridiculizat",
    "ridiculizați": "ridiculizat",
    "riflul": "riflu",
    "riflului": "riflu",
    "rifluri": "riflu",
    "riflurile": "riflu",
    "riflurilor": "riflu",
    "rifluiri": "rifluire",
    "riga": "rigă",
    "rigăi": "rigă",
    "rigi": "rigă",
    "rigii": "rigă",
    "rigilor": "rigă",
    "rigida": "rigid",
    "rigidă": "rigid",
    "rigide": "rigid",
    "rigidei": "rigid",
    "rigidele": "rigid",
    "rigidelor": "rigid",
    "rigidul": "rigid",
    "rigidului": "rigid",
    "rigizi": "rigid",
    "rigizii": "rigid",
    "rigizilor": "rigid",
    "rigiditatea": "rigiditate",
    "rigidități": "rigiditate",
    "rigidității": "rigiditate",
    "rigiditățile": "rigiditate",
    "rigidităților": "rigiditate",
    "rigidizata": "rigidizat",
    "rigidizată": "rigidizat",
    "rigidizate": "rigidizat",
    "rigidizatei": "rigidizat",
    "rigidizatele": "rigidizat",
    "rigidizatelor": "rigidizat",
    "rigidizați": "rigidizat",
    "rigidizații": "rigidizat",
    "rigidizaților": "rigidizat",
    "rigidizatul": "rigidizat",
    "rigidizatului": "rigidizat",
    "rigla": "riglă",
    "rigle": "riglă",
    "riglei": "riglă",
    "riglele": "riglă",
    "riglelor": "riglă",
    "rigoarea": "rigoare",
    "rigori": "rigoare",
    "rigorii": "rigoare",
    "rigorile": "rigoare",
    "rigorilor": "rigoare",
    "rigola": "rigolă",
    "rigole": "rigolă",
    "rigolei": "rigolă",
    "rigolele": "rigolă",
    "rigolelor": "rigolă",
    "riguroasa": "riguros",
    "riguroasă": "riguros",
    "riguroase": "riguros",
    "riguroasei": "riguros",
    "riguroasele": "riguros",
    "riguroaselor": "riguros",
    "riguroși": "riguros",
    "riguroșii": "riguros",
    "riguroșilor": "riguros",
    "rigurosul": "riguros",
    "rigurosului": "riguros",
    "rigurozitatea": "rigurozitate",
    "rigurozități": "rigurozitate",
    "rigurozității": "rigurozitate",
    "rigurozitățile": "rigurozitate",
    "rigurozităților": "rigurozitate",
    "nemairihtuind": "rihtui",
    "nemairihtuindu": "rihtui",
    "nerihtuind": "rihtui",
    "nerihtuindu": "rihtui",
    "rihtuia": "rihtui",
    "rihtuiai": "rihtui",
    "rihtuiam": "rihtui",
    "rihtuiască": "rihtui",
    "rihtuiați": "rihtui",
    "rihtuiau": "rihtui",
    "rihtuiesc": "rihtui",
    "rihtuiește": "rihtui",
    "rihtuiești": "rihtui",
    "rihtuii": "rihtui",
    "rihtuim": "rihtui",
    "rihtuind": "rihtui",
    "rihtuindu": "rihtui",
    "rihtuiră": "rihtui",
    "rihtuirăm": "rihtui",
    "rihtuirăți": "rihtui",
    "rihtuise": "rihtui",
    "rihtuisem": "rihtui",
    "rihtuiseră": "rihtui",
    "rihtuiserăm": "rihtui",
    "rihtuiserăți": "rihtui",
    "rihtuiseși": "rihtui",
    "rihtuiși": "rihtui",
    "rihtuit": "rihtui",
    "rihtuiți": "rihtui",
    "rihtuită": "rihtuit",
    "rihtuite": "rihtuit",
    "rihtuiți": "rihtuit",
    "nemairimând": "rima",
    "nemairimându": "rima",
    "nerimând": "rima",
    "nerimându": "rima",
    "rimă": "rima",
    "rimai": "rima",
    "rimam": "rima",
    "rimăm": "rima",
    "rimând": "rima",
    "rimându": "rima",
    "rimară": "rima",
    "rimarăm": "rima",
    "rimarăți": "rima",
    "rimase": "rima",
    "rimasem": "rima",
    "rimaseră": "rima",
    "rimaserăm": "rima",
    "rimaserăți": "rima",
    "rimaseși": "rima",
    "rimași": "rima",
    "rimat": "rima",
    "rimați": "rima",
    "rimau": "rima",
    "rimează": "rima",
    "rimez": "rima",
    "rimeze": "rima",
    "rimezi": "rima",
    "rima": "rimă",
    "rime": "rimă",
    "rimei": "rimă",
    "rimele": "rimă",
    "rimelor": "rimă",
    "rimată": "rimat",
    "rimate": "rimat",
    "rimați": "rimat",
    "rimelul": "rimel",
    "rimelului": "rimel",
    "rimeluri": "rimel",
    "rimelurile": "rimel",
    "rimelurilor": "rimel",
    "rindeaua": "rindea",
    "rindele": "rindea",
    "rindelei": "rindea",
    "rindelele": "rindea",
    "rindelelor": "rindea",
    "nemairindeluind": "rindelui",
    "nemairindeluindu": "rindelui",
    "nerindeluind": "rindelui",
    "nerindeluindu": "rindelui",
    "rindeluia": "rindelui",
    "rindeluiai": "rindelui",
    "rindeluiam": "rindelui",
    "rindeluiască": "rindelui",
    "rindeluiați": "rindelui",
    "rindeluiau": "rindelui",
    "rindeluiesc": "rindelui",
    "rindeluiește": "rindelui",
    "rindeluiești": "rindelui",
    "rindeluii": "rindelui",
    "rindeluim": "rindelui",
    "rindeluind": "rindelui",
    "rindeluindu": "rindelui",
    "rindeluiră": "rindelui",
    "rindeluirăm": "rindelui",
    "rindeluirăți": "rindelui",
    "rindeluise": "rindelui",
    "rindeluisem": "rindelui",
    "rindeluiseră": "rindelui",
    "rindeluiserăm": "rindelui",
    "rindeluiserăți": "rindelui",
    "rindeluiseși": "rindelui",
    "rindeluiși": "rindelui",
    "rindeluit": "rindelui",
    "rindeluiți": "rindelui",
    "rindeluirea": "rindeluire",
    "rindeluiri": "rindeluire",
    "rindeluirii": "rindeluire",
    "rindeluirile": "rindeluire",
    "rindeluirilor": "rindeluire",
    "rindeluită": "rindeluit",
    "rindeluite": "rindeluit",
    "rindeluiți": "rindeluit",
    "ringul": "ring",
    "ringului": "ring",
    "ringuri": "ring",
    "ringurile": "ring",
    "ringurilor": "ring",
    "rinichii": "rinichi",
    "rinichilor": "rinichi",
    "rinichiul": "rinichi",
    "rinichiului": "rinichi",
    "rinoceri": "rinocer",
    "rinocerii": "rinocer",
    "rinocerilor": "rinocer",
    "rinocerul": "rinocer",
    "rinocerului": "rinocer",
    "nemairipostând": "riposta",
    "nemairipostându": "riposta",
    "neripostând": "riposta",
    "neripostându": "riposta",
    "ripostă": "riposta",
    "ripostai": "riposta",
    "ripostam": "riposta",
    "ripostăm": "riposta",
    "ripostând": "riposta",
    "ripostându": "riposta",
    "ripostară": "riposta",
    "ripostarăm": "riposta",
    "ripostarăți": "riposta",
    "ripostase": "riposta",
    "ripostasem": "riposta",
    "ripostaseră": "riposta",
    "ripostaserăm": "riposta",
    "ripostaserăți": "riposta",
    "ripostaseși": "riposta",
    "ripostași": "riposta",
    "ripostat": "riposta",
    "ripostați": "riposta",
    "ripostau": "riposta",
    "ripostează": "riposta",
    "ripostez": "riposta",
    "riposteze": "riposta",
    "ripostezi": "riposta",
    "riposta": "ripostă",
    "riposte": "ripostă",
    "ripostei": "ripostă",
    "ripostele": "ripostă",
    "ripostelor": "ripostă",
    "ripostată": "ripostat",
    "ripostate": "ripostat",
    "ripostați": "ripostat",
    "ripsata": "ripsat",
    "ripsată": "ripsat",
    "ripsate": "ripsat",
    "ripsatei": "ripsat",
    "ripsatele": "ripsat",
    "ripsatelor": "ripsat",
    "ripsați": "ripsat",
    "ripsații": "ripsat",
    "ripsaților": "ripsat",
    "ripsatul": "ripsat",
    "ripsatului": "ripsat",
    "riscul": "risc",
    "riscului": "risc",
    "riscuri": "risc",
    "riscurile": "risc",
    "riscurilor": "risc",
    "nemairiscând": "risca",
    "nemairiscându": "risca",
    "neriscând": "risca",
    "neriscându": "risca",
    "risc": "risca",
    "riscă": "risca",
    "riscai": "risca",
    "riscam": "risca",
    "riscăm": "risca",
    "riscând": "risca",
    "riscându": "risca",
    "riscară": "risca",
    "riscarăm": "risca",
    "riscarăți": "risca",
    "riscase": "risca",
    "riscasem": "risca",
    "riscaseră": "risca",
    "riscaserăm": "risca",
    "riscaserăți": "risca",
    "riscaseși": "risca",
    "riscași": "risca",
    "riscat": "risca",
    "riscați": "risca",
    "riscau": "risca",
    "riște": "risca",
    "riști": "risca",
    "riscanta": "riscant",
    "riscantă": "riscant",
    "riscante": "riscant",
    "riscantei": "riscant",
    "riscantele": "riscant",
    "riscantelor": "riscant",
    "riscanți": "riscant",
    "riscanții": "riscant",
    "riscanților": "riscant",
    "riscantul": "riscant",
    "riscantului": "riscant",
    "riscata": "riscat",
    "riscată": "riscat",
    "riscate": "riscat",
    "riscatei": "riscat",
    "riscatele": "riscat",
    "riscatelor": "riscat",
    "riscați": "riscat",
    "riscații": "riscat",
    "riscaților": "riscat",
    "riscato": "riscat",
    "riscatul": "riscat",
    "riscatule": "riscat",
    "riscatului": "riscat",
    "risipa": "risipă",
    "risipe": "risipă",
    "risipei": "risipă",
    "risipele": "risipă",
    "risipelor": "risipă",
    "nemairisipind": "risipi",
    "nemairisipindu": "risipi",
    "nerisipind": "risipi",
    "nerisipindu": "risipi",
    "risipea": "risipi",
    "risipeai": "risipi",
    "risipeam": "risipi",
    "risipească": "risipi",
    "risipeați": "risipi",
    "risipeau": "risipi",
    "risipesc": "risipi",
    "risipește": "risipi",
    "risipești": "risipi",
    "risipii": "risipi",
    "risipim": "risipi",
    "risipind": "risipi",
    "risipindu": "risipi",
    "risipiră": "risipi",
    "risipirăm": "risipi",
    "risipirăți": "risipi",
    "risipise": "risipi",
    "risipisem": "risipi",
    "risipiseră": "risipi",
    "risipiserăm": "risipi",
    "risipiserăți": "risipi",
    "risipiseși": "risipi",
    "risipiși": "risipi",
    "risipit": "risipi",
    "risipiți": "risipi",
    "risipirea": "risipire",
    "risipireo": "risipire",
    "risipiri": "risipire",
    "risipirii": "risipire",
    "risipirile": "risipire",
    "risipirilor": "risipire",
    "risipita": "risipit",
    "risipită": "risipit",
    "risipite": "risipit",
    "risipitei": "risipit",
    "risipitele": "risipit",
    "risipitelor": "risipit",
    "risipiți": "risipit",
    "risipiții": "risipit",
    "risipiților": "risipit",
    "risipito": "risipit",
    "risipitul": "risipit",
    "risipitule": "risipit",
    "risipitului": "risipit",
    "risipitoare": "risipitor",
    "risipitoarea": "risipitor",
    "risipitoarei": "risipitor",
    "risipitoarele": "risipitor",
    "risipitoarelor": "risipitor",
    "risipitoareo": "risipitor",
    "risipitorii": "risipitor",
    "risipitorilor": "risipitor",
    "risipitorul": "risipitor",
    "risipitorule": "risipitor",
    "risipitorului": "risipitor",
    "ritul": "rit",
    "ritului": "rit",
    "rituri": "rit",
    "riturile": "rit",
    "riturilor": "rit",
    "ritmul": "ritm",
    "ritmului": "ritm",
    "ritmuri": "ritm",
    "ritmurile": "ritm",
    "ritmurilor": "ritm",
    "nemairitmând": "ritma",
    "nemairitmându": "ritma",
    "neritmând": "ritma",
    "neritmându": "ritma",
    "ritmă": "ritma",
    "ritmai": "ritma",
    "ritmam": "ritma",
    "ritmăm": "ritma",
    "ritmând": "ritma",
    "ritmându": "ritma",
    "ritmară": "ritma",
    "ritmarăm": "ritma",
    "ritmarăți": "ritma",
    "ritmase": "ritma",
    "ritmasem": "ritma",
    "ritmaseră": "ritma",
    "ritmaserăm": "ritma",
    "ritmaserăți": "ritma",
    "ritmaseși": "ritma",
    "ritmași": "ritma",
    "ritmat": "ritma",
    "ritmați": "ritma",
    "ritmau": "ritma",
    "ritmează": "ritma",
    "ritmez": "ritma",
    "ritmeze": "ritma",
    "ritmezi": "ritma",
    "ritmată": "ritmat",
    "ritmate": "ritmat",
    "ritmați": "ritmat",
    "ritmica": "ritmic",
    "ritmică": "ritmic",
    "ritmice": "ritmic",
    "ritmicei": "ritmic",
    "ritmicele": "ritmic",
    "ritmicelor": "ritmic",
    "ritmici": "ritmic",
    "ritmicii": "ritmic",
    "ritmicilor": "ritmic",
    "ritmicul": "ritmic",
    "ritmicului": "ritmic",
    "rituala": "ritual",
    "rituală": "ritual",
    "rituale": "ritual",
    "ritualei": "ritual",
    "ritualele": "ritual",
    "ritualelor": "ritual",
    "rituali": "ritual",
    "ritualii": "ritual",
    "ritualilor": "ritual",
    "ritualul": "ritual",
    "ritualului": "ritual",
    "ritualuri": "ritual",
    "ritualurile": "ritual",
    "ritualurilor": "ritual",
    "rivala": "rival",
    "rivală": "rival",
    "rivale": "rival",
    "rivalei": "rival",
    "rivalele": "rival",
    "rivalelor": "rival",
    "rivali": "rival",
    "rivalii": "rival",
    "rivalilor": "rival",
    "rivalul": "rival",
    "rivalului": "rival",
    "rivala": "rivală",
    "rivale": "rivală",
    "rivalei": "rivală",
    "rivalele": "rivală",
    "rivalelor": "rivală",
    "rivalitatea": "rivalitate",
    "rivalități": "rivalitate",
    "rivalității": "rivalitate",
    "rivalitățile": "rivalitate",
    "rivalităților": "rivalitate",
    "nemairivalizând": "rivaliza",
    "nemairivalizându": "rivaliza",
    "nerivalizând": "rivaliza",
    "nerivalizându": "rivaliza",
    "rivaliză": "rivaliza",
    "rivalizai": "rivaliza",
    "rivalizam": "rivaliza",
    "rivalizăm": "rivaliza",
    "rivalizând": "rivaliza",
    "rivalizându": "rivaliza",
    "rivalizară": "rivaliza",
    "rivalizarăm": "rivaliza",
    "rivalizarăți": "rivaliza",
    "rivalizase": "rivaliza",
    "rivalizasem": "rivaliza",
    "rivalizaseră": "rivaliza",
    "rivalizaserăm": "rivaliza",
    "rivalizaserăți": "rivaliza",
    "rivalizaseși": "rivaliza",
    "rivalizași": "rivaliza",
    "rivalizat": "rivaliza",
    "rivalizați": "rivaliza",
    "rivalizau": "rivaliza",
    "rivalizează": "rivaliza",
    "rivalizez": "rivaliza",
    "rivalizeze": "rivaliza",
    "rivalizezi": "rivaliza",
    "rivalizată": "rivalizat",
    "rivalizate": "rivalizat",
    "rivalizați": "rivalizat",
    "riverana": "riveran",
    "riverană": "riveran",
    "riverane": "riveran",
    "riveranei": "riveran",
    "riveranele": "riveran",
    "riveranelor": "riveran",
    "riverani": "riveran",
    "riveranii": "riveran",
    "riveranilor": "riveran",
    "riveranul": "riveran",
    "riveranului": "riveran",
    "riviera": "rivieră",
    "riviere": "rivieră",
    "rivierei": "rivieră",
    "rivierele": "rivieră",
    "rivierelor": "rivieră",
    "rizul": "riz",
    "rizului": "riz",
    "rizuri": "riz",
    "rizurile": "riz",
    "rizurilor": "riz",
    "rizibila": "rizibil",
    "rizibilă": "rizibil",
    "rizibile": "rizibil",
    "rizibilei": "rizibil",
    "rizibilele": "rizibil",
    "rizibilelor": "rizibil",
    "rizibili": "rizibil",
    "rizibilii": "rizibil",
    "rizibililor": "rizibil",
    "rizibilul": "rizibil",
    "rizibilului": "rizibil",
    "rizomi": "rizom",
    "rizomii": "rizom",
    "rizomilor": "rizom",
    "rizomul": "rizom",
    "rizomului": "rizom",
    "rizosfera": "rizosferă",
    "rizosfere": "rizosferă",
    "rizosferei": "rizosferă",
    "rizosferele": "rizosferă",
    "rizosferelor": "rizosferă",
    "roaba": "roabă",
    "roabe": "roabă",
    "roabei": "roabă",
    "roabele": "roabă",
    "roabelor": "roabă",
    "nemairozând": "roade",
    "nemairozându": "roade",
    "nerozând": "roade",
    "nerozându": "roade",
    "roadă": "roade",
    "roadem": "roade",
    "roadeți": "roade",
    "rod": "roade",
    "rodea": "roade",
    "rodeai": "roade",
    "rodeam": "roade",
    "rodeați": "roade",
    "rodeau": "roade",
    "rozând": "roade",
    "rozându": "roade",
    "rozi": "roade",
    "roaderea": "roadere",
    "roaderi": "roadere",
    "roaderii": "roadere",
    "roaderile": "roadere",
    "roaderilor": "roadere",
    "roata": "roată",
    "roate": "roată",
    "roatele": "roată",
    "roatelor": "roată",
    "roți": "roată",
    "roții": "roată",
    "roțile": "roată",
    "roților": "roată",
    "robi": "rob",
    "robii": "rob",
    "robilor": "rob",
    "robul": "rob",
    "robului": "rob",
    "roba": "robă",
    "robe": "robă",
    "robei": "robă",
    "robele": "robă",
    "robelor": "robă",
    "nemairobind": "robi",
    "nemairobindu": "robi",
    "nerobind": "robi",
    "nerobindu": "robi",
    "robea": "robi",
    "robeai": "robi",
    "robeam": "robi",
    "robească": "robi",
    "robeați": "robi",
    "robeau": "robi",
    "robesc": "robi",
    "robește": "robi",
    "robești": "robi",
    "robii": "robi",
    "robim": "robi",
    "robind": "robi",
    "robindu": "robi",
    "robiră": "robi",
    "robirăm": "robi",
    "robirăți": "robi",
    "robise": "robi",
    "robisem": "robi",
    "robiseră": "robi",
    "robiserăm": "robi",
    "robiserăți": "robi",
    "robiseși": "robi",
    "robiși": "robi",
    "robit": "robi",
    "robiți": "robi",
    "robia": "robie",
    "robiei": "robie",
    "robii": "robie",
    "robiile": "robie",
    "robiilor": "robie",
    "robinete": "robinet",
    "robinetele": "robinet",
    "robinetelor": "robinet",
    "robinetul": "robinet",
    "robinetului": "robinet",
    "robirea": "robire",
    "robiri": "robire",
    "robirii": "robire",
    "robirile": "robire",
    "robirilor": "robire",
    "robită": "robit",
    "robite": "robit",
    "robiți": "robit",
    "roboți": "robot",
    "roboții": "robot",
    "roboților": "robot",
    "robotul": "robot",
    "robotului": "robot",
    "roboteala": "roboteală",
    "roboteli": "roboteală",
    "robotelii": "roboteală",
    "robotelile": "roboteală",
    "robotelilor": "roboteală",
    "nemairobotind": "roboti",
    "nemairobotindu": "roboti",
    "nerobotind": "roboti",
    "nerobotindu": "roboti",
    "robotea": "roboti",
    "roboteai": "roboti",
    "roboteam": "roboti",
    "robotească": "roboti",
    "roboteați": "roboti",
    "roboteau": "roboti",
    "robotesc": "roboti",
    "robotește": "roboti",
    "robotești": "roboti",
    "robotii": "roboti",
    "robotim": "roboti",
    "robotind": "roboti",
    "robotindu": "roboti",
    "robotiră": "roboti",
    "robotirăm": "roboti",
    "robotirăți": "roboti",
    "robotise": "roboti",
    "robotisem": "roboti",
    "robotiseră": "roboti",
    "robotiserăm": "roboti",
    "robotiserăți": "roboti",
    "robotiseși": "roboti",
    "robotiși": "roboti",
    "robotit": "roboti",
    "robotiți": "roboti",
    "robotită": "robotit",
    "robotite": "robotit",
    "robotiți": "robotit",
    "robotizarea": "robotizare",
    "robotizări": "robotizare",
    "robotizării": "robotizare",
    "robotizările": "robotizare",
    "robotizărilor": "robotizare",
    "robusta": "robust",
    "robustă": "robust",
    "robuste": "robust",
    "robustei": "robust",
    "robustele": "robust",
    "robustelor": "robust",
    "robuști": "robust",
    "robuștii": "robust",
    "robuștilor": "robust",
    "robustul": "robust",
    "robustului": "robust",
    "robustețea": "robustețe",
    "robusteți": "robustețe",
    "robusteții": "robustețe",
    "robustețile": "robustețe",
    "robusteților": "robustețe",
    "roca": "rocă",
    "roci": "rocă",
    "rocii": "rocă",
    "rocile": "rocă",
    "rocilor": "rocă",
    "rochia": "rochie",
    "rochiei": "rochie",
    "rochii": "rochie",
    "rochiile": "rochie",
    "rochiilor": "rochie",
    "rochioara": "rochioară",
    "rochioare": "rochioară",
    "rochioarei": "rochioară",
    "rochioarele": "rochioară",
    "rochioarelor": "rochioară",
    "rochița": "rochiță",
    "rochițe": "rochiță",
    "rochiței": "rochiță",
    "rochițele": "rochiță",
    "rochițelor": "rochiță",
    "rockul": "rock",
    "rockului": "rock",
    "roade": "rod",
    "roadele": "rod",
    "roadelor": "rod",
    "rodul": "rod",
    "rodului": "rod",
    "nemairodând": "roda",
    "nemairodându": "roda",
    "nerodând": "roda",
    "nerodându": "roda",
    "rodă": "roda",
    "rodai": "roda",
    "rodam": "roda",
    "rodăm": "roda",
    "rodând": "roda",
    "rodându": "roda",
    "rodară": "roda",
    "rodarăm": "roda",
    "rodarăți": "roda",
    "rodase": "roda",
    "rodasem": "roda",
    "rodaseră": "roda",
    "rodaserăm": "roda",
    "rodaserăți": "roda",
    "rodaseși": "roda",
    "rodași": "roda",
    "rodat": "roda",
    "rodați": "roda",
    "rodau": "roda",
    "rodează": "roda",
    "rodez": "roda",
    "rodeze": "roda",
    "rodezi": "roda",
    "rodaje": "rodaj",
    "rodajele": "rodaj",
    "rodajelor": "rodaj",
    "rodajul": "rodaj",
    "rodajului": "rodaj",
    "rodată": "rodat",
    "rodate": "rodat",
    "rodați": "rodat",
    "nemairodind": "rodi",
    "nemairodindu": "rodi",
    "nerodind": "rodi",
    "nerodindu": "rodi",
    "rodea": "rodi",
    "rodeai": "rodi",
    "rodeam": "rodi",
    "rodească": "rodi",
    "rodeați": "rodi",
    "rodeau": "rodi",
    "rodesc": "rodi",
    "rodește": "rodi",
    "rodești": "rodi",
    "rodii": "rodi",
    "rodim": "rodi",
    "rodind": "rodi",
    "rodindu": "rodi",
    "rodiră": "rodi",
    "rodirăm": "rodi",
    "rodirăți": "rodi",
    "rodise": "rodi",
    "rodisem": "rodi",
    "rodiseră": "rodi",
    "rodiserăm": "rodi",
    "rodiserăți": "rodi",
    "rodiseși": "rodi",
    "rodiși": "rodi",
    "rodit": "rodi",
    "rodiți": "rodi",
    "rodia": "rodie",
    "rodiei": "rodie",
    "rodii": "rodie",
    "rodiile": "rodie",
    "rodiilor": "rodie",
    "rodirea": "rodire",
    "rodireo": "rodire",
    "rodiri": "rodire",
    "rodirii": "rodire",
    "rodirile": "rodire",
    "rodirilor": "rodire",
    "rodita": "rodit",
    "rodită": "rodit",
    "rodite": "rodit",
    "roditei": "rodit",
    "roditele": "rodit",
    "roditelor": "rodit",
    "rodiți": "rodit",
    "rodiții": "rodit",
    "rodiților": "rodit",
    "roditul": "rodit",
    "roditule": "rodit",
    "roditului": "rodit",
    "roditori": "roditor",
    "roditorii": "roditor",
    "roditorilor": "roditor",
    "roditorul": "roditor",
    "roditorului": "roditor",
    "rodii": "rodiu",
    "rodiii": "rodiu",
    "rodiilor": "rodiu",
    "rodiul": "rodiu",
    "rodiului": "rodiu",
    "rodnica": "rodnic",
    "rodnică": "rodnic",
    "rodnice": "rodnic",
    "rodnicei": "rodnic",
    "rodnicele": "rodnic",
    "rodnicelor": "rodnic",
    "rodnici": "rodnic",
    "rodnicii": "rodnic",
    "rodnicilor": "rodnic",
    "rodnicul": "rodnic",
    "rodnicului": "rodnic",
    "rododendroni": "rododendron",
    "rododendronii": "rododendron",
    "rododendronilor": "rododendron",
    "rododendronul": "rododendron",
    "rododendronului": "rododendron",
    "rogojina": "rogojină",
    "rogojini": "rogojină",
    "rogojinii": "rogojină",
    "rogojinile": "rogojină",
    "rogojinilor": "rogojină",
    "nemairoind": "roi",
    "nemairoindu": "roi",
    "neroind": "roi",
    "neroindu": "roi",
    "roia": "roi",
    "roiai": "roi",
    "roiam": "roi",
    "roiască": "roi",
    "roiați": "roi",
    "roiau": "roi",
    "roiesc": "roi",
    "roiește": "roi",
    "roiești": "roi",
    "roii": "roi",
    "roim": "roi",
    "roind": "roi",
    "roindu": "roi",
    "roiră": "roi",
    "roirăm": "roi",
    "roirăți": "roi",
    "roise": "roi",
    "roisem": "roi",
    "roiseră": "roi",
    "roiserăm": "roi",
    "roiserăți": "roi",
    "roiseși": "roi",
    "roiși": "roi",
    "roit": "roi",
    "roiți": "roi",
    "roiul": "roi",
    "roiului": "roi",
    "roiuri": "roi",
    "roiurile": "roi",
    "roiurilor": "roi",
    "roiba": "roib",
    "roibă": "roib",
    "roibe": "roib",
    "roibei": "roib",
    "roibele": "roib",
    "roibelor": "roib",
    "roibi": "roib",
    "roibii": "roib",
    "roibilor": "roib",
    "roibul": "roib",
    "roibului": "roib",
    "roinița": "roiniță",
    "roinițe": "roiniță",
    "roiniței": "roiniță",
    "roinițele": "roiniță",
    "roinițelor": "roiniță",
    "roirea": "roire",
    "roiri": "roire",
    "roirii": "roire",
    "roirile": "roire",
    "roirilor": "roire",
    "roită": "roit",
    "roite": "roit",
    "roiți": "roit",
    "roitul": "roit",
    "roitului": "roit",
    "rolul": "rol",
    "rolului": "rol",
    "roluri": "rol",
    "rolurile": "rol",
    "rolurilor": "rol",
    "rola": "rolă",
    "role": "rolă",
    "rolei": "rolă",
    "rolele": "rolă",
    "rolelor": "rolă",
    "romul": "rom",
    "romului": "rom",
    "romuri": "rom",
    "romurile": "rom",
    "romurilor": "rom",
    "Romei": "Roma",
    "romana": "roman",
    "romană": "roman",
    "romane": "roman",
    "romanei": "roman",
    "romanele": "roman",
    "romanelor": "roman",
    "romani": "roman",
    "romanii": "roman",
    "romanilor": "roman",
    "romanul": "roman",
    "romanului": "roman",
    "română": "român",
    "române": "român",
    "românele": "român",
    "românelor": "român",
    "români": "român",
    "românii": "român",
    "românilor": "român",
    "românul": "român",
    "românului": "român",
    "româna": "română",
    "românei": "română",
    "românca": "româncă",
    "românce": "româncă",
    "româncei": "româncă",
    "româncele": "româncă",
    "româncelor": "româncă",
    "romancieri": "romancier",
    "romancierii": "romancier",
    "romancierilor": "romancier",
    "romancierul": "romancier",
    "romancierului": "romancier",
    "romanciera": "romancieră",
    "romanciere": "romancieră",
    "romancierei": "romancieră",
    "romancierele": "romancieră",
    "romancierelor": "romancieră",
    "romanesca": "romanesc",
    "romanescă": "romanesc",
    "romanescul": "romanesc",
    "romanescului": "romanesc",
    "romanești": "romanesc",
    "romaneștii": "romanesc",
    "romaneștile": "romanesc",
    "romaneștilor": "romanesc",
    "româneasca": "românesc",
    "românească": "românesc",
    "românescul": "românesc",
    "românescului": "românesc",
    "românești": "românesc",
    "româneștii": "românesc",
    "româneștile": "românesc",
    "româneștilor": "românesc",
    "Românie": "România",
    "României": "România",
    "Românii": "România",
    "românimea": "românime",
    "românimi": "românime",
    "românimii": "românime",
    "românimile": "românime",
    "românimilor": "românime",
    "românisme": "românism",
    "românismele": "românism",
    "românismelor": "românism",
    "românismul": "românism",
    "românismului": "românism",
    "romanistica": "romanistică",
    "romanitatea": "romanitate",
    "romanități": "romanitate",
    "romanității": "romanitate",
    "nemairomanizând": "romaniza",
    "nemairomanizându": "romaniza",
    "neromanizând": "romaniza",
    "neromanizându": "romaniza",
    "romaniză": "romaniza",
    "romanizai": "romaniza",
    "romanizam": "romaniza",
    "romanizăm": "romaniza",
    "romanizând": "romaniza",
    "romanizându": "romaniza",
    "romanizară": "romaniza",
    "romanizarăm": "romaniza",
    "romanizarăți": "romaniza",
    "romanizase": "romaniza",
    "romanizasem": "romaniza",
    "romanizaseră": "romaniza",
    "romanizaserăm": "romaniza",
    "romanizaserăți": "romaniza",
    "romanizaseși": "romaniza",
    "romanizași": "romaniza",
    "romanizat": "romaniza",
    "romanizați": "romaniza",
    "romanizau": "romaniza",
    "romanizează": "romaniza",
    "romanizez": "romaniza",
    "romanizeze": "romaniza",
    "romanizezi": "romaniza",
    "nemairomânizând": "româniza",
    "nemairomânizându": "româniza",
    "neromânizând": "româniza",
    "neromânizându": "româniza",
    "româniză": "româniza",
    "românizai": "româniza",
    "românizam": "româniza",
    "românizăm": "româniza",
    "românizând": "româniza",
    "românizându": "româniza",
    "românizară": "româniza",
    "românizarăm": "româniza",
    "românizarăți": "româniza",
    "românizase": "româniza",
    "românizasem": "româniza",
    "românizaseră": "româniza",
    "românizaserăm": "româniza",
    "românizaserăți": "româniza",
    "românizaseși": "româniza",
    "românizași": "româniza",
    "românizat": "româniza",
    "românizați": "româniza",
    "românizau": "româniza",
    "românizează": "româniza",
    "românizez": "româniza",
    "românizeze": "româniza",
    "românizezi": "româniza",
    "românizarea": "românizare",
    "românizări": "românizare",
    "românizării": "românizare",
    "românizările": "românizare",
    "românizărilor": "românizare",
    "romanizată": "romanizat",
    "romanizate": "romanizat",
    "romanizați": "romanizat",
    "românizată": "românizat",
    "românizate": "românizat",
    "românizați": "românizat",
    "româno-americană": "româno-american",
    "româno-americane": "româno-american",
    "romano-catolică": "romano-catolic",
    "romano-catolice": "romano-catolic",
    "romano-catolici": "romano-catolic",
    "romano-catolicii": "romano-catolic",
    "romano-catolicilor": "romano-catolic",
    "româno-chineză": "româno-chinez",
    "româno-chineze": "româno-chinez",
    "româno-chinezi": "româno-chinez",
    "româno-franceză": "româno-francez",
    "româno-franceze": "româno-francez",
    "româno-maghiară": "româno-maghiar",
    "româno-maghiare": "româno-maghiar",
    "româno-maghiari": "româno-maghiar",
    "româno-sovietică": "româno-sovietic",
    "româno-sovietice": "româno-sovietic",
    "româno-sovietici": "româno-sovietic",
    "româno-ungară": "româno-ungar",
    "româno-ungare": "româno-ungar",
    "româno-ungari": "româno-ungar",
    "nemairomanțând": "romanța",
    "nemairomanțându": "romanța",
    "neromanțând": "romanța",
    "neromanțându": "romanța",
    "romanță": "romanța",
    "romanțai": "romanța",
    "romanțam": "romanța",
    "romanțăm": "romanța",
    "romanțând": "romanța",
    "romanțându": "romanța",
    "romanțară": "romanța",
    "romanțarăm": "romanța",
    "romanțarăți": "romanța",
    "romanțase": "romanța",
    "romanțasem": "romanța",
    "romanțaseră": "romanța",
    "romanțaserăm": "romanța",
    "romanțaserăți": "romanța",
    "romanțaseși": "romanța",
    "romanțași": "romanța",
    "romanțat": "romanța",
    "romanțați": "romanța",
    "romanțau": "romanța",
    "romanțează": "romanța",
    "romanțez": "romanța",
    "romanțeze": "romanța",
    "romanțezi": "romanța",
    "romanța": "romanță",
    "romanțe": "romanță",
    "romanței": "romanță",
    "romanțele": "romanță",
    "romanțelor": "romanță",
    "romanțată": "romanțat",
    "romanțate": "romanțat",
    "romanțați": "romanțat",
    "romantica": "romantic",
    "romantică": "romantic",
    "romantice": "romantic",
    "romanticei": "romantic",
    "romanticele": "romantic",
    "romanticelor": "romantic",
    "romantici": "romantic",
    "romanticii": "romantic",
    "romanticilor": "romantic",
    "romanticul": "romantic",
    "romanticului": "romantic",
    "romantismul": "romantism",
    "romantismului": "romantism",
    "rombul": "romb",
    "rombului": "romb",
    "romburi": "romb",
    "romburile": "romb",
    "romburilor": "romb",
    "rombica": "rombic",
    "rombică": "rombic",
    "rombice": "rombic",
    "rombicei": "rombic",
    "rombicele": "rombic",
    "rombicelor": "rombic",
    "rombici": "rombic",
    "rombicii": "rombic",
    "rombicilor": "rombic",
    "rombicul": "rombic",
    "rombicului": "rombic",
    "romboedrica": "romboedric",
    "romboedrică": "romboedric",
    "romboedrice": "romboedric",
    "romboedricei": "romboedric",
    "romboedricele": "romboedric",
    "romboedricelor": "romboedric",
    "romboedrici": "romboedric",
    "romboedricii": "romboedric",
    "romboedricilor": "romboedric",
    "romboedricul": "romboedric",
    "romboedricului": "romboedric",
    "romboida": "romboid",
    "romboidă": "romboid",
    "romboide": "romboid",
    "romboidei": "romboid",
    "romboidele": "romboid",
    "romboidelor": "romboid",
    "romboidul": "romboid",
    "romboidului": "romboid",
    "romboizi": "romboid",
    "romboizii": "romboid",
    "romboizilor": "romboid",
    "romboidala": "romboidal",
    "romboidală": "romboidal",
    "romboidale": "romboidal",
    "romboidalei": "romboidal",
    "romboidalele": "romboidal",
    "romboidalelor": "romboidal",
    "romboidali": "romboidal",
    "romboidalii": "romboidal",
    "romboidalilor": "romboidal",
    "romboidalul": "romboidal",
    "romboidalului": "romboidal",
    "rondul": "rond",
    "rondului": "rond",
    "ronduri": "rond",
    "rondurile": "rond",
    "rondurilor": "rond",
    "ronda": "rondă",
    "ronde": "rondă",
    "rondei": "rondă",
    "rondelor": "rondă",
    "rondelul": "rondel",
    "rondelului": "rondel",
    "rondeluri": "rondel",
    "rondelurile": "rondel",
    "rondelurilor": "rondel",
    "rondela": "rondelă",
    "rondele": "rondelă",
    "rondelei": "rondelă",
    "rondelele": "rondelă",
    "rondelelor": "rondelă",
    "rondoul": "rondou",
    "rondoului": "rondou",
    "rondouri": "rondou",
    "rondourile": "rondou",
    "rondourilor": "rondou",
    "nemaironțăind": "ronțăi",
    "nemaironțăindu": "ronțăi",
    "neronțăind": "ronțăi",
    "neronțăindu": "ronțăi",
    "ronțăia": "ronțăi",
    "ronțăiai": "ronțăi",
    "ronțăiam": "ronțăi",
    "ronțăiați": "ronțăi",
    "ronțăiau": "ronțăi",
    "ronțăie": "ronțăi",
    "ronțăii": "ronțăi",
    "ronțăim": "ronțăi",
    "ronțăind": "ronțăi",
    "ronțăindu": "ronțăi",
    "ronțăiră": "ronțăi",
    "ronțăirăm": "ronțăi",
    "ronțăirăți": "ronțăi",
    "ronțăise": "ronțăi",
    "ronțăisem": "ronțăi",
    "ronțăiseră": "ronțăi",
    "ronțăiserăm": "ronțăi",
    "ronțăiserăți": "ronțăi",
    "ronțăiseși": "ronțăi",
    "ronțăiși": "ronțăi",
    "ronțăit": "ronțăi",
    "ronțăiți": "ronțăi",
    "ronțăită": "ronțăit",
    "ronțăite": "ronțăit",
    "ronțăiți": "ronțăit",
    "ropote": "ropot",
    "ropotele": "ropot",
    "ropotelor": "ropot",
    "ropotul": "ropot",
    "ropotului": "ropot",
    "nemairopotind": "ropoti",
    "nemairopotindu": "ropoti",
    "neropotind": "ropoti",
    "neropotindu": "ropoti",
    "ropotea": "ropoti",
    "ropoteai": "ropoti",
    "ropoteam": "ropoti",
    "ropotească": "ropoti",
    "ropoteați": "ropoti",
    "ropoteau": "ropoti",
    "ropotesc": "ropoti",
    "ropotește": "ropoti",
    "ropotești": "ropoti",
    "ropotii": "ropoti",
    "ropotim": "ropoti",
    "ropotind": "ropoti",
    "ropotindu": "ropoti",
    "ropotiră": "ropoti",
    "ropotirăm": "ropoti",
    "ropotirăți": "ropoti",
    "ropotise": "ropoti",
    "ropotisem": "ropoti",
    "ropotiseră": "ropoti",
    "ropotiserăm": "ropoti",
    "ropotiserăți": "ropoti",
    "ropotiseși": "ropoti",
    "ropotiși": "ropoti",
    "ropotit": "ropoti",
    "ropotiți": "ropoti",
    "ropotită": "ropotit",
    "ropotite": "ropotit",
    "ropotiți": "ropotit",
    "roasa": "ros",
    "roasă": "ros",
    "roase": "ros",
    "roasei": "ros",
    "roasele": "ros",
    "roaselor": "ros",
    "rosul": "ros",
    "rosului": "ros",
    "rosătura": "rosătură",
    "rosături": "rosătură",
    "rosăturii": "rosătură",
    "rosăturile": "rosătură",
    "rosăturilor": "rosătură",
    "roșcata": "roșcat",
    "roșcată": "roșcat",
    "roșcate": "roșcat",
    "roșcatei": "roșcat",
    "roșcatele": "roșcat",
    "roșcatelor": "roșcat",
    "roșcați": "roșcat",
    "roșcații": "roșcat",
    "roșcaților": "roșcat",
    "roșcatul": "roșcat",
    "roșcatului": "roșcat",
    "roșcova": "roșcovă",
    "roșcove": "roșcovă",
    "roșcovei": "roșcovă",
    "roșcovele": "roșcovă",
    "roșcovelor": "roșcovă",
    "roșcovana": "roșcovan",
    "roșcovană": "roșcovan",
    "roșcovane": "roșcovan",
    "roșcovanei": "roșcovan",
    "roșcovanele": "roșcovan",
    "roșcovanelor": "roșcovan",
    "roșcovani": "roșcovan",
    "roșcovanii": "roșcovan",
    "roșcovanilor": "roșcovan",
    "roșcovanul": "roșcovan",
    "roșcovanului": "roșcovan",
    "roșeața": "roșeață",
    "roșeței": "roșeață",
    "nemairoșind": "roși",
    "nemairoșindu": "roși",
    "neroșind": "roși",
    "neroșindu": "roși",
    "roșea": "roși",
    "roșeai": "roși",
    "roșeam": "roși",
    "roșească": "roși",
    "roșeați": "roși",
    "roșeau": "roși",
    "roșesc": "roși",
    "roșește": "roși",
    "roșești": "roși",
    "roșii": "roși",
    "roșim": "roși",
    "roșind": "roși",
    "roșindu": "roși",
    "roșiră": "roși",
    "roșirăm": "roși",
    "roșirăți": "roși",
    "roșise": "roși",
    "roșisem": "roși",
    "roșiseră": "roși",
    "roșiserăm": "roși",
    "roșiserăți": "roși",
    "roșiseși": "roși",
    "roșiși": "roși",
    "roșit": "roși",
    "roșiți": "roși",
    "roșiatica": "roșiatic",
    "roșiatică": "roșiatic",
    "roșiatice": "roșiatic",
    "roșiaticei": "roșiatic",
    "roșiatici": "roșiatic",
    "roșiaticii": "roșiatic",
    "roșiaticilor": "roșiatic",
    "roșiaticul": "roșiatic",
    "roșiaticului": "roșiatic",
    "roșietice": "roșiatic",
    "roșieticele": "roșiatic",
    "roșieticelor": "roșiatic",
    "roșită": "roșit",
    "roșite": "roșit",
    "roșiți": "roșit",
    "rostul": "rost",
    "rostului": "rost",
    "rosturi": "rost",
    "rosturile": "rost",
    "rosturilor": "rost",
    "nemairostind": "rosti",
    "nemairostindu": "rosti",
    "nerostind": "rosti",
    "nerostindu": "rosti",
    "rostea": "rosti",
    "rosteai": "rosti",
    "rosteam": "rosti",
    "rostească": "rosti",
    "rosteați": "rosti",
    "rosteau": "rosti",
    "rostesc": "rosti",
    "rostește": "rosti",
    "rostești": "rosti",
    "rostii": "rosti",
    "rostim": "rosti",
    "rostind": "rosti",
    "rostindu": "rosti",
    "rostiră": "rosti",
    "rostirăm": "rosti",
    "rostirăți": "rosti",
    "rostise": "rosti",
    "rostisem": "rosti",
    "rostiseră": "rosti",
    "rostiserăm": "rosti",
    "rostiserăți": "rosti",
    "rostiseși": "rosti",
    "rostiși": "rosti",
    "rostit": "rosti",
    "rostiți": "rosti",
    "rostirea": "rostire",
    "rostireo": "rostire",
    "rostiri": "rostire",
    "rostirii": "rostire",
    "rostirile": "rostire",
    "rostirilor": "rostire",
    "rostită": "rostit",
    "rostite": "rostit",
    "rostiți": "rostit",
    "rostogolul": "rostogol",
    "rostogolului": "rostogol",
    "rostogoluri": "rostogol",
    "rostogolurile": "rostogol",
    "rostogolurilor": "rostogol",
    "nemairostogolind": "rostogoli",
    "nemairostogolindu": "rostogoli",
    "nerostogolind": "rostogoli",
    "nerostogolindu": "rostogoli",
    "rostogolea": "rostogoli",
    "rostogoleai": "rostogoli",
    "rostogoleam": "rostogoli",
    "rostogolească": "rostogoli",
    "rostogoleați": "rostogoli",
    "rostogoleau": "rostogoli",
    "rostogolesc": "rostogoli",
    "rostogolește": "rostogoli",
    "rostogolești": "rostogoli",
    "rostogolii": "rostogoli",
    "rostogolim": "rostogoli",
    "rostogolind": "rostogoli",
    "rostogolindu": "rostogoli",
    "rostogoliră": "rostogoli",
    "rostogolirăm": "rostogoli",
    "rostogolirăți": "rostogoli",
    "rostogolise": "rostogoli",
    "rostogolisem": "rostogoli",
    "rostogoliseră": "rostogoli",
    "rostogoliserăm": "rostogoli",
    "rostogoliserăți": "rostogoli",
    "rostogoliseși": "rostogoli",
    "rostogoliși": "rostogoli",
    "rostogolit": "rostogoli",
    "rostogoliți": "rostogoli",
    "rostogolirea": "rostogolire",
    "rostogoliri": "rostogolire",
    "rostogolirii": "rostogolire",
    "rostogolirile": "rostogolire",
    "rostogolirilor": "rostogolire",
    "rostogolită": "rostogolit",
    "rostogolite": "rostogolit",
    "rostogoliți": "rostogolit",
    "rostopasca": "rostopască",
    "rostrala": "rostral",
    "rostrală": "rostral",
    "rostrale": "rostral",
    "rostralei": "rostral",
    "rostralele": "rostral",
    "rostralelor": "rostral",
    "rostrali": "rostral",
    "rostralii": "rostral",
    "rostralilor": "rostral",
    "rostralul": "rostral",
    "rostralului": "rostral",
    "nemairostuind": "rostui",
    "nemairostuindu": "rostui",
    "nerostuind": "rostui",
    "nerostuindu": "rostui",
    "rostuia": "rostui",
    "rostuiai": "rostui",
    "rostuiam": "rostui",
    "rostuiască": "rostui",
    "rostuiați": "rostui",
    "rostuiau": "rostui",
    "rostuiesc": "rostui",
    "rostuiește": "rostui",
    "rostuiești": "rostui",
    "rostuii": "rostui",
    "rostuim": "rostui",
    "rostuind": "rostui",
    "rostuindu": "rostui",
    "rostuiră": "rostui",
    "rostuirăm": "rostui",
    "rostuirăți": "rostui",
    "rostuise": "rostui",
    "rostuisem": "rostui",
    "rostuiseră": "rostui",
    "rostuiserăm": "rostui",
    "rostuiserăți": "rostui",
    "rostuiseși": "rostui",
    "rostuiși": "rostui",
    "rostuit": "rostui",
    "rostuiți": "rostui",
    "rostuită": "rostuit",
    "rostuite": "rostuit",
    "rostuiți": "rostuit",
    "roșia": "roșu",
    "roșie": "roșu",
    "roșiei": "roșu",
    "roșii": "roșu",
    "roșiii": "roșu",
    "roșiile": "roșu",
    "roșiilor": "roșu",
    "roșul": "roșu",
    "roșului": "roșu",
    "nemairotacizând": "rotaciza",
    "nemairotacizându": "rotaciza",
    "nerotacizând": "rotaciza",
    "nerotacizându": "rotaciza",
    "rotaciză": "rotaciza",
    "rotacizai": "rotaciza",
    "rotacizam": "rotaciza",
    "rotacizăm": "rotaciza",
    "rotacizând": "rotaciza",
    "rotacizându": "rotaciza",
    "rotacizară": "rotaciza",
    "rotacizarăm": "rotaciza",
    "rotacizarăți": "rotaciza",
    "rotacizase": "rotaciza",
    "rotacizasem": "rotaciza",
    "rotacizaseră": "rotaciza",
    "rotacizaserăm": "rotaciza",
    "rotacizaserăți": "rotaciza",
    "rotacizaseși": "rotaciza",
    "rotacizași": "rotaciza",
    "rotacizat": "rotaciza",
    "rotacizați": "rotaciza",
    "rotacizau": "rotaciza",
    "rotacizează": "rotaciza",
    "rotacizez": "rotaciza",
    "rotacizeze": "rotaciza",
    "rotacizezi": "rotaciza",
    "rotacizată": "rotacizat",
    "rotacizate": "rotacizat",
    "rotacizați": "rotacizat",
    "rotari": "rotar",
    "rotarii": "rotar",
    "rotarilor": "rotar",
    "rotarul": "rotar",
    "rotarului": "rotar",
    "rotația": "rotație",
    "rotației": "rotație",
    "rotații": "rotație",
    "rotațiile": "rotație",
    "rotațiilor": "rotație",
    "rot.": "rotații",
    "rotativa": "rotativ",
    "rotativă": "rotativ",
    "rotative": "rotativ",
    "rotativei": "rotativ",
    "rotativele": "rotativ",
    "rotativelor": "rotativ",
    "rotativi": "rotativ",
    "rotativii": "rotativ",
    "rotativilor": "rotativ",
    "rotativul": "rotativ",
    "rotativului": "rotativ",
    "nemairotind": "roti",
    "nemairotindu": "roti",
    "nerotind": "roti",
    "nerotindu": "roti",
    "rotea": "roti",
    "roteai": "roti",
    "roteam": "roti",
    "rotească": "roti",
    "roteați": "roti",
    "roteau": "roti",
    "rotesc": "roti",
    "rotește": "roti",
    "rotești": "roti",
    "rotii": "roti",
    "rotim": "roti",
    "rotind": "roti",
    "rotindu": "roti",
    "rotiră": "roti",
    "rotirăm": "roti",
    "rotirăți": "roti",
    "rotise": "roti",
    "rotisem": "roti",
    "rotiseră": "roti",
    "rotiserăm": "roti",
    "rotiserăți": "roti",
    "rotiseși": "roti",
    "rotiși": "roti",
    "rotit": "roti",
    "rotiți": "roti",
    "rotila": "rotilă",
    "rotile": "rotilă",
    "rotilei": "rotilă",
    "rotilele": "rotilă",
    "rotilelor": "rotilă",
    "rotirea": "rotire",
    "rotiri": "rotire",
    "rotirii": "rotire",
    "rotirile": "rotire",
    "rotirilor": "rotire",
    "rotită": "rotit",
    "rotite": "rotit",
    "rotiți": "rotit",
    "rotița": "rotiță",
    "rotițe": "rotiță",
    "rotiței": "rotiță",
    "rotițele": "rotiță",
    "rotițelor": "rotiță",
    "rotitoare": "rotitor",
    "rotitoarea": "rotitor",
    "rotitoarei": "rotitor",
    "rotitoarele": "rotitor",
    "rotitoarelor": "rotitor",
    "rotitori": "rotitor",
    "rotitorii": "rotitor",
    "rotitorilor": "rotitor",
    "rotitorul": "rotitor",
    "rotitorului": "rotitor",
    "rotocoale": "rotocol",
    "rotocoalele": "rotocol",
    "rotocoalelor": "rotocol",
    "rotocolul": "rotocol",
    "rotocolului": "rotocol",
    "rotofeia": "rotofei",
    "rotofeie": "rotofei",
    "rotofeiei": "rotofei",
    "rotofeiele": "rotofei",
    "rotofeielor": "rotofei",
    "rotofeii": "rotofei",
    "rotofeilor": "rotofei",
    "rotofeiul": "rotofei",
    "rotofeiului": "rotofei",
    "rotonda": "rotondă",
    "rotonde": "rotondă",
    "rotondei": "rotondă",
    "rotondele": "rotondă",
    "rotondelor": "rotondă",
    "rotoare": "rotor",
    "rotoarele": "rotor",
    "rotoarelor": "rotor",
    "rotorul": "rotor",
    "rotorului": "rotor",
    "rotula": "rotulă",
    "rotule": "rotulă",
    "rotulei": "rotulă",
    "rotulele": "rotulă",
    "rotulelor": "rotulă",
    "rotunda": "rotund",
    "rotundă": "rotund",
    "rotunde": "rotund",
    "rotundei": "rotund",
    "rotundele": "rotund",
    "rotundelor": "rotund",
    "rotundul": "rotund",
    "rotundului": "rotund",
    "rotunzi": "rotund",
    "rotunzii": "rotund",
    "rotunzilor": "rotund",
    "nemairotunjind": "rotunji",
    "nemairotunjindu": "rotunji",
    "nerotunjind": "rotunji",
    "nerotunjindu": "rotunji",
    "rotunjea": "rotunji",
    "rotunjeai": "rotunji",
    "rotunjeam": "rotunji",
    "rotunjească": "rotunji",
    "rotunjeați": "rotunji",
    "rotunjeau": "rotunji",
    "rotunjesc": "rotunji",
    "rotunjește": "rotunji",
    "rotunjești": "rotunji",
    "rotunjii": "rotunji",
    "rotunjim": "rotunji",
    "rotunjind": "rotunji",
    "rotunjindu": "rotunji",
    "rotunjiră": "rotunji",
    "rotunjirăm": "rotunji",
    "rotunjirăți": "rotunji",
    "rotunjise": "rotunji",
    "rotunjisem": "rotunji",
    "rotunjiseră": "rotunji",
    "rotunjiserăm": "rotunji",
    "rotunjiserăți": "rotunji",
    "rotunjiseși": "rotunji",
    "rotunjiși": "rotunji",
    "rotunjit": "rotunji",
    "rotunjiți": "rotunji",
    "rotunjimea": "rotunjime",
    "rotunjimi": "rotunjime",
    "rotunjimii": "rotunjime",
    "rotunjimile": "rotunjime",
    "rotunjimilor": "rotunjime",
    "rotunjirea": "rotunjire",
    "rotunjiri": "rotunjire",
    "rotunjirii": "rotunjire",
    "rotunjirile": "rotunjire",
    "rotunjirilor": "rotunjire",
    "rotunjită": "rotunjit",
    "rotunjite": "rotunjit",
    "rotunjiți": "rotunjit",
    "rotunjoara": "rotunjor",
    "rotunjoară": "rotunjor",
    "rotunjoare": "rotunjor",
    "rotunjoarei": "rotunjor",
    "rotunjoarele": "rotunjor",
    "rotunjoarelor": "rotunjor",
    "rotunjori": "rotunjor",
    "rotunjorii": "rotunjor",
    "rotunjorilor": "rotunjor",
    "rotunjorul": "rotunjor",
    "rotunjorului": "rotunjor",
    "roua": "rouă",
    "rouăi": "rouă",
    "Roxanei": "Roxana",
    "roză": "roz",
    "roze": "roz",
    "rozul": "roz",
    "rozului": "roz",
    "roza": "roză",
    "roze": "roză",
    "rozei": "roză",
    "rozele": "roză",
    "rozelor": "roză",
    "rozalia": "rozaliu",
    "rozalie": "rozaliu",
    "rozaliei": "rozaliu",
    "rozalii": "rozaliu",
    "rozaliii": "rozaliu",
    "rozaliile": "rozaliu",
    "rozaliilor": "rozaliu",
    "rozaliul": "rozaliu",
    "rozaliului": "rozaliu",
    "rozarii": "rozariu",
    "rozariile": "rozariu",
    "rozariilor": "rozariu",
    "rozariul": "rozariu",
    "rozariului": "rozariu",
    "rozătoarea": "rozătoare",
    "rozătoarei": "rozătoare",
    "rozătoarele": "rozătoare",
    "rozătoarelor": "rozătoare",
    "rozătoare": "rozător",
    "rozătoarea": "rozător",
    "rozătoarei": "rozător",
    "rozătoarele": "rozător",
    "rozătoarelor": "rozător",
    "rozători": "rozător",
    "rozătorii": "rozător",
    "rozătorilor": "rozător",
    "rozătorul": "rozător",
    "rozătorului": "rozător",
    "rozeta": "rozetă",
    "rozete": "rozetă",
    "rozetei": "rozetă",
    "rozetele": "rozetă",
    "rozetelor": "rozetă",
    "rozia": "roziu",
    "rozie": "roziu",
    "roziei": "roziu",
    "rozii": "roziu",
    "roziii": "roziu",
    "roziile": "roziu",
    "roziilor": "roziu",
    "roziul": "roziu",
    "roziului": "roziu",
    "rubedenia": "rubedenie",
    "rubedeniei": "rubedenie",
    "rubedenii": "rubedenie",
    "rubedeniile": "rubedenie",
    "rubedeniilor": "rubedenie",
    "rubeola": "rubeolă",
    "rubeole": "rubeolă",
    "rubeolei": "rubeolă",
    "rubeolele": "rubeolă",
    "rubeolelor": "rubeolă",
    "rubiconda": "rubicond",
    "rubicondă": "rubicond",
    "rubiconde": "rubicond",
    "rubicondei": "rubicond",
    "rubicondele": "rubicond",
    "rubicondelor": "rubicond",
    "rubicondul": "rubicond",
    "rubicondului": "rubicond",
    "rubiconzi": "rubicond",
    "rubiconzii": "rubicond",
    "rubiconzilor": "rubicond",
    "Rb": "rubidiu",
    "rubidiul": "rubidiu",
    "rubidiului": "rubidiu",
    "rubine": "rubin",
    "rubinele": "rubin",
    "rubinelor": "rubin",
    "rubinul": "rubin",
    "rubinului": "rubin",
    "rubinia": "rubiniu",
    "rubinie": "rubiniu",
    "rubiniei": "rubiniu",
    "rubinii": "rubiniu",
    "rubiniii": "rubiniu",
    "rubiniile": "rubiniu",
    "rubiniilor": "rubiniu",
    "rubiniul": "rubiniu",
    "rubiniului": "rubiniu",
    "rubla": "rublă",
    "ruble": "rublă",
    "rublei": "rublă",
    "rublele": "rublă",
    "rublelor": "rublă",
    "rubrica": "rubrică",
    "rubrici": "rubrică",
    "rubricii": "rubrică",
    "rubricile": "rubrică",
    "rubricilor": "rubrică",
    "rucsacul": "rucsac",
    "rucsacului": "rucsac",
    "rucsacuri": "rucsac",
    "rucsacurile": "rucsac",
    "rucsacurilor": "rucsac",
    "ruda": "rudă",
    "rude": "rudă",
    "rudei": "rudă",
    "rudele": "rudă",
    "rudelor": "rudă",
    "rudăria": "rudărie",
    "rudăriei": "rudărie",
    "rudării": "rudărie",
    "rudăriile": "rudărie",
    "rudăriilor": "rudărie",
    "rudenia": "rudenie",
    "rudeniei": "rudenie",
    "rudenii": "rudenie",
    "rudeniile": "rudenie",
    "rudeniilor": "rudenie",
    "rudimente": "rudiment",
    "rudimentele": "rudiment",
    "rudimentelor": "rudiment",
    "rudimentul": "rudiment",
    "rudimentului": "rudiment",
    "rudimentara": "rudimentar",
    "rudimentară": "rudimentar",
    "rudimentare": "rudimentar",
    "rudimentarei": "rudimentar",
    "rudimentarele": "rudimentar",
    "rudimentarelor": "rudimentar",
    "rudimentari": "rudimentar",
    "rudimentarii": "rudimentar",
    "rudimentarilor": "rudimentar",
    "rudimentarul": "rudimentar",
    "rudimentarului": "rudimentar",
    "rufa": "rufă",
    "rufe": "rufă",
    "rufei": "rufă",
    "rufele": "rufă",
    "rufelor": "rufă",
    "rufăria": "rufărie",
    "rufăriei": "rufărie",
    "rufării": "rufărie",
    "rufăriile": "rufărie",
    "rufăriilor": "rufărie",
    "rugi": "rug",
    "rugii": "rug",
    "rugilor": "rug",
    "rugul": "rug",
    "rugului": "rug",
    "ruguri": "rug",
    "rugurile": "rug",
    "rugurilor": "rug",
    "nemairugând": "ruga",
    "nemairugându": "ruga",
    "nerugând": "ruga",
    "nerugându": "ruga",
    "roagă": "ruga",
    "roage": "ruga",
    "rog": "ruga",
    "rogi": "ruga",
    "rogu": "ruga",
    "rugă": "ruga",
    "rugai": "ruga",
    "rugam": "ruga",
    "rugăm": "ruga",
    "rugând": "ruga",
    "rugându": "ruga",
    "rugară": "ruga",
    "rugarăm": "ruga",
    "rugarăți": "ruga",
    "rugase": "ruga",
    "rugasem": "ruga",
    "rugaseră": "ruga",
    "rugaserăm": "ruga",
    "rugaserăți": "ruga",
    "rugaseși": "ruga",
    "rugași": "ruga",
    "rugat": "ruga",
    "rugați": "ruga",
    "rugatu": "ruga",
    "rugau": "ruga",
    "ruga": "rugă",
    "rugi": "rugă",
    "rugii": "rugă",
    "rugile": "rugă",
    "rugilor": "rugă",
    "rugăciunea": "rugăciune",
    "rugăciuni": "rugăciune",
    "rugăciunii": "rugăciune",
    "rugăciunile": "rugăciune",
    "rugăciunilor": "rugăciune",
    "rugămintea": "rugăminte",
    "rugăminți": "rugăminte",
    "rugăminții": "rugăminte",
    "rugămințile": "rugăminte",
    "rugăminților": "rugăminte",
    "rugarea": "rugare",
    "rugareo": "rugare",
    "rugări": "rugare",
    "rugării": "rugare",
    "rugările": "rugare",
    "rugărilor": "rugare",
    "rugată": "rugat",
    "rugate": "rugat",
    "rugați": "rugat",
    "rugători": "rugător",
    "rugătorii": "rugător",
    "rugătorilor": "rugător",
    "rugătorul": "rugător",
    "rugătorului": "rugător",
    "rugina": "rugină",
    "rugini": "rugină",
    "ruginii": "rugină",
    "ruginile": "rugină",
    "ruginilor": "rugină",
    "nemairuginind": "rugini",
    "nemairuginindu": "rugini",
    "neruginind": "rugini",
    "neruginindu": "rugini",
    "ruginea": "rugini",
    "rugineai": "rugini",
    "rugineam": "rugini",
    "ruginească": "rugini",
    "rugineați": "rugini",
    "rugineau": "rugini",
    "ruginesc": "rugini",
    "ruginește": "rugini",
    "ruginești": "rugini",
    "ruginii": "rugini",
    "ruginim": "rugini",
    "ruginind": "rugini",
    "ruginindu": "rugini",
    "ruginiră": "rugini",
    "ruginirăm": "rugini",
    "ruginirăți": "rugini",
    "ruginise": "rugini",
    "ruginisem": "rugini",
    "ruginiseră": "rugini",
    "ruginiserăm": "rugini",
    "ruginiserăți": "rugini",
    "ruginiseși": "rugini",
    "ruginiși": "rugini",
    "ruginit": "rugini",
    "ruginiți": "rugini",
    "ruginită": "ruginit",
    "ruginite": "ruginit",
    "ruginiți": "ruginit",
    "ruginia": "ruginiu",
    "ruginie": "ruginiu",
    "ruginiei": "ruginiu",
    "ruginii": "ruginiu",
    "ruginiii": "ruginiu",
    "ruginiile": "ruginiu",
    "ruginiilor": "ruginiu",
    "ruginiul": "ruginiu",
    "ruginiului": "ruginiu",
    "nemairuinând": "ruina",
    "nemairuinându": "ruina",
    "neruinând": "ruina",
    "neruinându": "ruina",
    "ruină": "ruina",
    "ruinai": "ruina",
    "ruinam": "ruina",
    "ruinăm": "ruina",
    "ruinând": "ruina",
    "ruinându": "ruina",
    "ruinară": "ruina",
    "ruinarăm": "ruina",
    "ruinarăți": "ruina",
    "ruinase": "ruina",
    "ruinasem": "ruina",
    "ruinaseră": "ruina",
    "ruinaserăm": "ruina",
    "ruinaserăți": "ruina",
    "ruinaseși": "ruina",
    "ruinași": "ruina",
    "ruinat": "ruina",
    "ruinați": "ruina",
    "ruinau": "ruina",
    "ruinează": "ruina",
    "ruinez": "ruina",
    "ruineze": "ruina",
    "ruinezi": "ruina",
    "ruina": "ruină",
    "ruine": "ruină",
    "ruinei": "ruină",
    "ruinele": "ruină",
    "ruinelor": "ruină",
    "ruinarea": "ruinare",
    "ruinări": "ruinare",
    "ruinării": "ruinare",
    "ruinările": "ruinare",
    "ruinărilor": "ruinare",
    "ruinată": "ruinat",
    "ruinate": "ruinat",
    "ruinați": "ruinat",
    "rujul": "ruj",
    "rujului": "ruj",
    "rujuri": "ruj",
    "rujurile": "ruj",
    "rujurilor": "ruj",
    "nemairujând": "ruja",
    "nemairujându": "ruja",
    "nerujând": "ruja",
    "nerujându": "ruja",
    "rujă": "ruja",
    "rujai": "ruja",
    "rujam": "ruja",
    "rujăm": "ruja",
    "rujând": "ruja",
    "rujându": "ruja",
    "rujară": "ruja",
    "rujarăm": "ruja",
    "rujarăți": "ruja",
    "rujase": "ruja",
    "rujasem": "ruja",
    "rujaseră": "ruja",
    "rujaserăm": "ruja",
    "rujaserăți": "ruja",
    "rujaseși": "ruja",
    "rujași": "ruja",
    "rujat": "ruja",
    "rujați": "ruja",
    "rujau": "ruja",
    "rujează": "ruja",
    "rujez": "ruja",
    "rujeze": "ruja",
    "rujezi": "ruja",
    "ruji-galbene": "rujă-galbenă",
    "rujată": "rujat",
    "rujate": "rujat",
    "rujați": "rujat",
    "rujeola": "rujeolă",
    "rujeole": "rujeolă",
    "rujeolei": "rujeolă",
    "rujeolele": "rujeolă",
    "rujeolelor": "rujeolă",
    "nemairulând": "rula",
    "nemairulându": "rula",
    "nerulând": "rula",
    "nerulându": "rula",
    "rulă": "rula",
    "rulai": "rula",
    "rulam": "rula",
    "rulăm": "rula",
    "rulând": "rula",
    "rulându": "rula",
    "rulară": "rula",
    "rularăm": "rula",
    "rularăți": "rula",
    "rulase": "rula",
    "rulasem": "rula",
    "rulaseră": "rula",
    "rulaserăm": "rula",
    "rulaserăți": "rula",
    "rulaseși": "rula",
    "rulași": "rula",
    "rulat": "rula",
    "rulați": "rula",
    "rulau": "rula",
    "rulează": "rula",
    "rulez": "rula",
    "ruleze": "rula",
    "rulezi": "rula",
    "rulada": "ruladă",
    "rulade": "ruladă",
    "ruladei": "ruladă",
    "ruladele": "ruladă",
    "ruladelor": "ruladă",
    "rulaje": "rulaj",
    "rulajele": "rulaj",
    "rulajelor": "rulaj",
    "rulajul": "rulaj",
    "rulajului": "rulaj",
    "rulanta": "rulant",
    "rulantă": "rulant",
    "rulante": "rulant",
    "rulantei": "rulant",
    "rulantele": "rulant",
    "rulantelor": "rulant",
    "rulanți": "rulant",
    "rulanții": "rulant",
    "rulanților": "rulant",
    "rulantul": "rulant",
    "rulantului": "rulant",
    "rulată": "rulat",
    "rulate": "rulat",
    "rulați": "rulat",
    "ruleta": "ruletă",
    "rulete": "ruletă",
    "ruletei": "ruletă",
    "ruletele": "ruletă",
    "ruletelor": "ruletă",
    "ruliul": "ruliu",
    "ruliului": "ruliu",
    "ruliuri": "ruliu",
    "ruliurile": "ruliu",
    "ruliurilor": "ruliu",
    "rulmenți": "rulment",
    "rulmenții": "rulment",
    "rulmenților": "rulment",
    "rulmentul": "rulment",
    "rulmentului": "rulment",
    "ruloul": "rulou",
    "ruloului": "rulou",
    "rulouri": "rulou",
    "rulourile": "rulou",
    "rulourilor": "rulou",
    "nemairumegând": "rumega",
    "nemairumegându": "rumega",
    "nerumegând": "rumega",
    "nerumegându": "rumega",
    "rumeg": "rumega",
    "rumegă": "rumega",
    "rumegai": "rumega",
    "rumegam": "rumega",
    "rumegăm": "rumega",
    "rumegând": "rumega",
    "rumegându": "rumega",
    "rumegară": "rumega",
    "rumegarăm": "rumega",
    "rumegarăți": "rumega",
    "rumegase": "rumega",
    "rumegasem": "rumega",
    "rumegaseră": "rumega",
    "rumegaserăm": "rumega",
    "rumegaserăți": "rumega",
    "rumegaseși": "rumega",
    "rumegași": "rumega",
    "rumegat": "rumega",
    "rumegați": "rumega",
    "rumegau": "rumega",
    "rumege": "rumega",
    "rumegi": "rumega",
    "rumegată": "rumegat",
    "rumegate": "rumegat",
    "rumegați": "rumegat",
    "rumegătoarea": "rumegătoare",
    "rumegătoarei": "rumegătoare",
    "rumegătoarele": "rumegătoare",
    "rumegătoarelor": "rumegătoare",
    "rumegătoare": "rumegător",
    "rumegători": "rumegător",
    "rumegușul": "rumeguș",
    "rumegușului": "rumeguș",
    "rumena": "rumen",
    "rumenă": "rumen",
    "rumene": "rumen",
    "rumenei": "rumen",
    "rumenele": "rumen",
    "rumenelor": "rumen",
    "rumeni": "rumen",
    "rumenii": "rumen",
    "rumenilor": "rumen",
    "rumenul": "rumen",
    "rumenului": "rumen",
    "nemairumenind": "rumeni",
    "nemairumenindu": "rumeni",
    "nerumenind": "rumeni",
    "nerumenindu": "rumeni",
    "rumenea": "rumeni",
    "rumeneai": "rumeni",
    "rumeneam": "rumeni",
    "rumenească": "rumeni",
    "rumeneați": "rumeni",
    "rumeneau": "rumeni",
    "rumenesc": "rumeni",
    "rumenește": "rumeni",
    "rumenești": "rumeni",
    "rumenii": "rumeni",
    "rumenim": "rumeni",
    "rumenind": "rumeni",
    "rumenindu": "rumeni",
    "rumeniră": "rumeni",
    "rumenirăm": "rumeni",
    "rumenirăți": "rumeni",
    "rumenise": "rumeni",
    "rumenisem": "rumeni",
    "rumeniseră": "rumeni",
    "rumeniserăm": "rumeni",
    "rumeniserăți": "rumeni",
    "rumeniseși": "rumeni",
    "rumeniși": "rumeni",
    "rumenit": "rumeni",
    "rumeniți": "rumeni",
    "rumenită": "rumenit",
    "rumenite": "rumenit",
    "rumeniți": "rumenit",
    "rumenia": "rumeniu",
    "rumenie": "rumeniu",
    "rumeniei": "rumeniu",
    "rumenii": "rumeniu",
    "rumeniii": "rumeniu",
    "rumeniile": "rumeniu",
    "rumeniilor": "rumeniu",
    "rumeniul": "rumeniu",
    "rumeniului": "rumeniu",
    "rumoarea": "rumoare",
    "rumori": "rumoare",
    "rumorii": "rumoare",
    "rumorile": "rumoare",
    "rumorilor": "rumoare",
    "runda": "rundă",
    "runde": "rundă",
    "rundei": "rundă",
    "rundele": "rundă",
    "rundelor": "rundă",
    "runica": "runic",
    "runică": "runic",
    "runice": "runic",
    "runicei": "runic",
    "runicele": "runic",
    "runicelor": "runic",
    "runici": "runic",
    "runicii": "runic",
    "runicilor": "runic",
    "runicul": "runic",
    "runicului": "runic",
    "nemairupând": "rupe",
    "nemairupându": "rupe",
    "nerupând": "rupe",
    "nerupându": "rupe",
    "rup": "rupe",
    "rupă": "rupe",
    "rupând": "rupe",
    "rupându": "rupe",
    "rupea": "rupe",
    "rupeai": "rupe",
    "rupeam": "rupe",
    "rupeați": "rupe",
    "rupeau": "rupe",
    "rupem": "rupe",
    "rupeți": "rupe",
    "rupi": "rupe",
    "rupse": "rupe",
    "rupsei": "rupe",
    "rupseră": "rupe",
    "rupserăm": "rupe",
    "rupserăți": "rupe",
    "rupsese": "rupe",
    "rupsesem": "rupe",
    "rupseseră": "rupe",
    "rupseserăm": "rupe",
    "rupseserăți": "rupe",
    "rupseseși": "rupe",
    "rupseși": "rupe",
    "rupt": "rupe",
    "ruperea": "rupere",
    "ruperi": "rupere",
    "ruperii": "rupere",
    "ruperile": "rupere",
    "ruperilor": "rupere",
    "rupestra": "rupestru",
    "rupestră": "rupestru",
    "rupestre": "rupestru",
    "rupestrei": "rupestru",
    "rupestrele": "rupestru",
    "rupestrelor": "rupestru",
    "rupeștri": "rupestru",
    "rupeștrii": "rupestru",
    "rupeștrilor": "rupestru",
    "rupestrul": "rupestru",
    "rupestrului": "rupestru",
    "rupia": "rupie",
    "rupiei": "rupie",
    "rupii": "rupie",
    "rupiile": "rupie",
    "rupiilor": "rupie",
    "rupta": "rupt",
    "ruptă": "rupt",
    "rupte": "rupt",
    "ruptei": "rupt",
    "ruptele": "rupt",
    "ruptelor": "rupt",
    "rupți": "rupt",
    "rupții": "rupt",
    "rupților": "rupt",
    "ruptul": "rupt",
    "ruptului": "rupt",
    "ruptura": "ruptură",
    "rupturi": "ruptură",
    "rupturii": "ruptură",
    "rupturile": "ruptură",
    "rupturilor": "ruptură",
    "rurala": "rural",
    "rurală": "rural",
    "rurale": "rural",
    "ruralei": "rural",
    "ruralele": "rural",
    "ruralelor": "rural",
    "rurali": "rural",
    "ruralii": "rural",
    "ruralilor": "rural",
    "ruralul": "rural",
    "ruralului": "rural",
    "ruși": "rus",
    "rușii": "rus",
    "rușilor": "rus",
    "rusul": "rus",
    "rusului": "rus",
    "rus.": "rusă",
    "rusa": "rusă",
    "ruse": "rusă",
    "rusei": "rusă",
    "rusele": "rusă",
    "ruselor": "rusă",
    "rusalia": "rusalie",
    "rusaliei": "rusalie",
    "rusalii": "rusalie",
    "rusaliile": "rusalie",
    "rusaliilor": "rusalie",
    "ruseasca": "rusesc",
    "rusească": "rusesc",
    "rusescul": "rusesc",
    "rusescului": "rusesc",
    "rusește": "rusesc",
    "rusești": "rusesc",
    "ruseștii": "rusesc",
    "ruseștile": "rusesc",
    "ruseștilor": "rusesc",
    "Rusiei": "Rusia",
    "Rusii": "Rusia",
    "nemairușinând": "rușina",
    "nemairușinându": "rușina",
    "nerușinând": "rușina",
    "nerușinându": "rușina",
    "rușină": "rușina",
    "rușinai": "rușina",
    "rușinam": "rușina",
    "rușinăm": "rușina",
    "rușinând": "rușina",
    "rușinându": "rușina",
    "rușinară": "rușina",
    "rușinarăm": "rușina",
    "rușinarăți": "rușina",
    "rușinase": "rușina",
    "rușinasem": "rușina",
    "rușinaseră": "rușina",
    "rușinaserăm": "rușina",
    "rușinaserăți": "rușina",
    "rușinaseși": "rușina",
    "rușinași": "rușina",
    "rușinat": "rușina",
    "rușinați": "rușina",
    "rușinau": "rușina",
    "rușinează": "rușina",
    "rușinez": "rușina",
    "rușineze": "rușina",
    "rușinezi": "rușina",
    "rușinată": "rușinat",
    "rușinate": "rușinat",
    "rușinați": "rușinat",
    "rușinea": "rușine",
    "rușini": "rușine",
    "rușinii": "rușine",
    "rușinile": "rușine",
    "rușinilor": "rușine",
    "rușinoasa": "rușinos",
    "rușinoasă": "rușinos",
    "rușinoase": "rușinos",
    "rușinoasei": "rușinos",
    "rușinoasele": "rușinos",
    "rușinoaselor": "rușinos",
    "rușinoși": "rușinos",
    "rușinoșii": "rușinos",
    "rușinoșilor": "rușinos",
    "rușinosul": "rușinos",
    "rușinosului": "rușinos",
    "rusoaica": "rusoaică",
    "rusoaice": "rusoaică",
    "rusoaicei": "rusoaică",
    "rusoaicele": "rusoaică",
    "rusoaicelor": "rusoaică",
    "rusofili": "rusofil",
    "rusofilii": "rusofil",
    "rusofililor": "rusofil",
    "rusofilul": "rusofil",
    "rusofilului": "rusofil",
    "rusofoni": "rusofon",
    "rusofonii": "rusofon",
    "rusofonilor": "rusofon",
    "rusofonul": "rusofon",
    "rusofonului": "rusofon",
    "rustica": "rustic",
    "rustică": "rustic",
    "rustice": "rustic",
    "rusticei": "rustic",
    "rusticele": "rustic",
    "rusticelor": "rustic",
    "rustici": "rustic",
    "rusticii": "rustic",
    "rusticilor": "rustic",
    "rusticul": "rustic",
    "rusticului": "rustic",
    "ruta": "rută",
    "rute": "rută",
    "rutei": "rută",
    "rutele": "rută",
    "rutelor": "rută",
    "ruteanul": "rutean",
    "ruteanului": "rutean",
    "ruteni": "rutean",
    "rutenii": "rutean",
    "rutenilor": "rutean",
    "ruteana": "ruteană",
    "rutene": "ruteană",
    "rutenei": "ruteană",
    "rutenele": "ruteană",
    "rutenelor": "ruteană",
    "rutiera": "rutier",
    "rutieră": "rutier",
    "rutiere": "rutier",
    "rutierei": "rutier",
    "rutierele": "rutier",
    "rutierelor": "rutier",
    "rutieri": "rutier",
    "rutierii": "rutier",
    "rutierilor": "rutier",
    "rutierul": "rutier",
    "rutierului": "rutier",
    "rutina": "rutină",
    "rutine": "rutină",
    "rutinei": "rutină",
    "rutinele": "rutină",
    "rutinelor": "rutină",
    "Ruxandrei": "Ruxandra",
    "s-": "să",
    "șaua": "șa",
    "șei": "șa",
    "șeii": "șa",
    "șeile": "șa",
    "șeilor": "șa",
    "sabatul": "sabat",
    "sabatului": "sabat",
    "sabaturi": "sabat",
    "sabaturile": "sabat",
    "sabaturilor": "sabat",
    "sabia": "sabie",
    "săbiei": "sabie",
    "săbii": "sabie",
    "săbiile": "sabie",
    "săbiilor": "sabie",
    "săbieri": "săbier",
    "săbierii": "săbier",
    "săbierilor": "săbier",
    "săbierul": "săbier",
    "săbierului": "săbier",
    "Sabinei": "Sabina",
    "nemaisablând": "sabla",
    "nemaisablându": "sabla",
    "nesablând": "sabla",
    "nesablându": "sabla",
    "sablă": "sabla",
    "sablai": "sabla",
    "sablam": "sabla",
    "sablăm": "sabla",
    "sablând": "sabla",
    "sablându": "sabla",
    "sablară": "sabla",
    "sablarăm": "sabla",
    "sablarăți": "sabla",
    "sablase": "sabla",
    "sablasem": "sabla",
    "sablaseră": "sabla",
    "sablaserăm": "sabla",
    "sablaserăți": "sabla",
    "sablaseși": "sabla",
    "sablași": "sabla",
    "sablat": "sabla",
    "sablați": "sabla",
    "sablau": "sabla",
    "sablează": "sabla",
    "sableze": "sabla",
    "sablezi": "sabla",
    "sablată": "sablat",
    "sablate": "sablat",
    "sablați": "sablat",
    "sableza": "sableză",
    "sableze": "sableză",
    "sablezei": "sableză",
    "sablezele": "sableză",
    "sablezelor": "sableză",
    "șabloane": "șablon",
    "șabloanele": "șablon",
    "șabloanelor": "șablon",
    "șablonul": "șablon",
    "șablonului": "șablon",
    "nemaișablonând": "șablona",
    "nemaișablonându": "șablona",
    "neșablonând": "șablona",
    "neșablonându": "șablona",
    "șablonă": "șablona",
    "șablonai": "șablona",
    "șablonam": "șablona",
    "șablonăm": "șablona",
    "șablonând": "șablona",
    "șablonându": "șablona",
    "șablonară": "șablona",
    "șablonarăm": "șablona",
    "șablonarăți": "șablona",
    "șablonase": "șablona",
    "șablonasem": "șablona",
    "șablonaseră": "șablona",
    "șablonaserăm": "șablona",
    "șablonaserăți": "șablona",
    "șablonaseși": "șablona",
    "șablonași": "șablona",
    "șablonat": "șablona",
    "șablonați": "șablona",
    "șablonau": "șablona",
    "șablonează": "șablona",
    "șablonez": "șablona",
    "șabloneze": "șablona",
    "șablonezi": "șablona",
    "șablonarda": "șablonard",
    "șablonardă": "șablonard",
    "șablonarde": "șablonard",
    "șablonardei": "șablonard",
    "șablonardele": "șablonard",
    "șablonardelor": "șablonard",
    "șablonardul": "șablonard",
    "șablonardului": "șablonard",
    "șablonarzi": "șablonard",
    "șablonarzii": "șablonard",
    "șablonarzilor": "șablonard",
    "șablonarea": "șablonare",
    "șablonareo": "șablonare",
    "șablonări": "șablonare",
    "șablonării": "șablonare",
    "șablonările": "șablonare",
    "șablonărilor": "șablonare",
    "șablonată": "șablonat",
    "șablonate": "șablonat",
    "șablonați": "șablonat",
    "șablonisme": "șablonism",
    "șablonismele": "șablonism",
    "șablonismelor": "șablonism",
    "șablonismul": "șablonism",
    "șablonismului": "șablonism",
    "sabordul": "sabord",
    "sabordului": "sabord",
    "saborduri": "sabord",
    "sabordurile": "sabord",
    "sabordurilor": "sabord",
    "nemaisabordând": "saborda",
    "nemaisabordându": "saborda",
    "nesabordând": "saborda",
    "nesabordându": "saborda",
    "sabordă": "saborda",
    "sabordai": "saborda",
    "sabordam": "saborda",
    "sabordăm": "saborda",
    "sabordând": "saborda",
    "sabordându": "saborda",
    "sabordară": "saborda",
    "sabordarăm": "saborda",
    "sabordarăți": "saborda",
    "sabordase": "saborda",
    "sabordasem": "saborda",
    "sabordaseră": "saborda",
    "sabordaserăm": "saborda",
    "sabordaserăți": "saborda",
    "sabordaseși": "saborda",
    "sabordași": "saborda",
    "sabordat": "saborda",
    "sabordați": "saborda",
    "sabordau": "saborda",
    "sabordează": "saborda",
    "sabordez": "saborda",
    "sabordeze": "saborda",
    "sabordezi": "saborda",
    "sabordaje": "sabordaj",
    "sabordajele": "sabordaj",
    "sabordajelor": "sabordaj",
    "sabordajul": "sabordaj",
    "sabordajului": "sabordaj",
    "sabordată": "sabordat",
    "sabordate": "sabordat",
    "sabordați": "sabordat",
    "saboți": "sabot",
    "saboții": "sabot",
    "saboților": "sabot",
    "sabotul": "sabot",
    "sabotului": "sabot",
    "nemaisabotând": "sabota",
    "nemaisabotându": "sabota",
    "nesabotând": "sabota",
    "nesabotându": "sabota",
    "sabotă": "sabota",
    "sabotai": "sabota",
    "sabotam": "sabota",
    "sabotăm": "sabota",
    "sabotând": "sabota",
    "sabotându": "sabota",
    "sabotară": "sabota",
    "sabotarăm": "sabota",
    "sabotarăți": "sabota",
    "sabotase": "sabota",
    "sabotasem": "sabota",
    "sabotaseră": "sabota",
    "sabotaserăm": "sabota",
    "sabotaserăți": "sabota",
    "sabotaseși": "sabota",
    "sabotași": "sabota",
    "sabotat": "sabota",
    "sabotați": "sabota",
    "sabotau": "sabota",
    "sabotează": "sabota",
    "sabotez": "sabota",
    "saboteze": "sabota",
    "sabotezi": "sabota",
    "șabota": "șabotă",
    "șabote": "șabotă",
    "șabotei": "șabotă",
    "șabotele": "șabotă",
    "șabotelor": "șabotă",
    "sabotaje": "sabotaj",
    "sabotajele": "sabotaj",
    "sabotajelor": "sabotaj",
    "sabotajul": "sabotaj",
    "sabotajului": "sabotaj",
    "sabotată": "sabotat",
    "sabotate": "sabotat",
    "sabotați": "sabotat",
    "sabotoarea": "sabotoare",
    "sabotoarei": "sabotoare",
    "sabotoarele": "sabotoare",
    "sabotoarelor": "sabotoare",
    "sabotori": "sabotor",
    "sabotorii": "sabotor",
    "sabotorilor": "sabotor",
    "sabotorul": "sabotor",
    "sabotorului": "sabotor",
    "sabretașe": "sabretaș",
    "sabretașele": "sabretaș",
    "sabretașelor": "sabretaș",
    "sabretașul": "sabretaș",
    "sabretașului": "sabretaș",
    "saci": "sac",
    "sacii": "sac",
    "sacilor": "sac",
    "sacul": "sac",
    "sacului": "sac",
    "sacale": "saca",
    "sacalei": "saca",
    "sacalele": "saca",
    "sacalelor": "saca",
    "sacaua": "saca",
    "nemaisacadând": "sacada",
    "nemaisacadându": "sacada",
    "nesacadând": "sacada",
    "nesacadându": "sacada",
    "sacadă": "sacada",
    "sacadai": "sacada",
    "sacadam": "sacada",
    "sacadăm": "sacada",
    "sacadând": "sacada",
    "sacadându": "sacada",
    "sacadară": "sacada",
    "sacadarăm": "sacada",
    "sacadarăți": "sacada",
    "sacadase": "sacada",
    "sacadasem": "sacada",
    "sacadaseră": "sacada",
    "sacadaserăm": "sacada",
    "sacadaserăți": "sacada",
    "sacadaseși": "sacada",
    "sacadași": "sacada",
    "sacadat": "sacada",
    "sacadați": "sacada",
    "sacadau": "sacada",
    "sacadează": "sacada",
    "sacadez": "sacada",
    "sacadeze": "sacada",
    "sacadezi": "sacada",
    "sacadarea": "sacadare",
    "sacadareo": "sacadare",
    "sacadări": "sacadare",
    "sacadării": "sacadare",
    "sacadările": "sacadare",
    "sacadărilor": "sacadare",
    "sacadata": "sacadat",
    "sacadată": "sacadat",
    "sacadate": "sacadat",
    "sacadatei": "sacadat",
    "sacadatele": "sacadat",
    "sacadatelor": "sacadat",
    "sacadați": "sacadat",
    "sacadații": "sacadat",
    "sacadaților": "sacadat",
    "sacadato": "sacadat",
    "sacadatul": "sacadat",
    "sacadatule": "sacadat",
    "sacadatului": "sacadat",
    "sacagii": "sacagiu",
    "sacagiii": "sacagiu",
    "sacagiilor": "sacagiu",
    "sacagiul": "sacagiu",
    "sacagiului": "sacagiu",
    "nemaisâcâind": "sâcâi",
    "nemaisâcâindu": "sâcâi",
    "nesâcâind": "sâcâi",
    "nesâcâindu": "sâcâi",
    "sâcâia": "sâcâi",
    "sâcâiai": "sâcâi",
    "sâcâiam": "sâcâi",
    "sâcâiați": "sâcâi",
    "sâcâiau": "sâcâi",
    "sâcâie": "sâcâi",
    "sâcâii": "sâcâi",
    "sâcâim": "sâcâi",
    "sâcâind": "sâcâi",
    "sâcâindu": "sâcâi",
    "sâcâiră": "sâcâi",
    "sâcâirăm": "sâcâi",
    "sâcâirăți": "sâcâi",
    "sâcâise": "sâcâi",
    "sâcâisem": "sâcâi",
    "sâcâiseră": "sâcâi",
    "sâcâiserăm": "sâcâi",
    "sâcâiserăți": "sâcâi",
    "sâcâiseși": "sâcâi",
    "sâcâiși": "sâcâi",
    "sâcâit": "sâcâi",
    "sâcâiți": "sâcâi",
    "sâcâiala": "sâcâială",
    "sâcâieli": "sâcâială",
    "sâcâielii": "sâcâială",
    "sâcâielile": "sâcâială",
    "sâcâielilor": "sâcâială",
    "sâcâită": "sâcâit",
    "sâcâite": "sâcâit",
    "sâcâiți": "sâcâit",
    "sâcâitoare": "sâcâitor",
    "sâcâitori": "sâcâitor",
    "sâcâitorii": "sâcâitor",
    "sâcâitorilor": "sâcâitor",
    "sâcâitorul": "sâcâitor",
    "sâcâitorului": "sâcâitor",
    "șacali": "șacal",
    "șacalii": "șacal",
    "șacalilor": "șacal",
    "șacalul": "șacal",
    "șacalului": "șacal",
    "șagrin": "șacal",
    "șagrinul": "șacal",
    "șagrinului": "șacal",
    "șagrinuri": "șacal",
    "șagrinurile": "șacal",
    "șagrinurilor": "șacal",
    "sacâzul": "sacâz",
    "sacâzului": "sacâz",
    "sacerdoți": "sacerdot",
    "sacerdoții": "sacerdot",
    "sacerdoților": "sacerdot",
    "sacerdotul": "sacerdot",
    "sacerdotului": "sacerdot",
    "sacerdotala": "sacerdotal",
    "sacerdotală": "sacerdotal",
    "sacerdotale": "sacerdotal",
    "sacerdotalei": "sacerdotal",
    "sacerdotalele": "sacerdotal",
    "sacerdotalelor": "sacerdotal",
    "sacerdotali": "sacerdotal",
    "sacerdotalii": "sacerdotal",
    "sacerdotalilor": "sacerdotal",
    "sacerdotalul": "sacerdotal",
    "sacerdotalului": "sacerdotal",
    "sacoșa": "sacoșă",
    "sacoșe": "sacoșă",
    "sacoșei": "sacoșă",
    "sacoșele": "sacoșă",
    "sacoșelor": "sacoșă",
    "sacoul": "sacou",
    "sacoului": "sacou",
    "sacouri": "sacou",
    "sacourile": "sacou",
    "sacourilor": "sacou",
    "sacrala": "sacral",
    "sacrală": "sacral",
    "sacrale": "sacral",
    "sacralei": "sacral",
    "sacralele": "sacral",
    "sacralelor": "sacral",
    "sacrali": "sacral",
    "sacralii": "sacral",
    "sacralilor": "sacral",
    "sacralul": "sacral",
    "sacralului": "sacral",
    "sacramente": "sacrament",
    "sacramentele": "sacrament",
    "sacramentelor": "sacrament",
    "sacramentul": "sacrament",
    "sacramentului": "sacrament",
    "sacramentala": "sacramental",
    "sacramentală": "sacramental",
    "sacramentale": "sacramental",
    "sacramentalei": "sacramental",
    "sacramentalele": "sacramental",
    "sacramentalelor": "sacramental",
    "sacramentali": "sacramental",
    "sacramentalii": "sacramental",
    "sacramentalilor": "sacramental",
    "sacramentalul": "sacramental",
    "sacramentalului": "sacramental",
    "nemaisacrificând": "sacrifica",
    "nemaisacrificându": "sacrifica",
    "nesacrificând": "sacrifica",
    "nesacrificându": "sacrifica",
    "sacrific": "sacrifica",
    "sacrifică": "sacrifica",
    "sacrificai": "sacrifica",
    "sacrificam": "sacrifica",
    "sacrificăm": "sacrifica",
    "sacrificând": "sacrifica",
    "sacrificându": "sacrifica",
    "sacrificară": "sacrifica",
    "sacrificarăm": "sacrifica",
    "sacrificarăți": "sacrifica",
    "sacrificase": "sacrifica",
    "sacrificasem": "sacrifica",
    "sacrificaseră": "sacrifica",
    "sacrificaserăm": "sacrifica",
    "sacrificaserăți": "sacrifica",
    "sacrificaseși": "sacrifica",
    "sacrificași": "sacrifica",
    "sacrificat": "sacrifica",
    "sacrificați": "sacrifica",
    "sacrificau": "sacrifica",
    "sacrifice": "sacrifica",
    "sacrifici": "sacrifica",
    "sacrificarea": "sacrificare",
    "sacrificareo": "sacrificare",
    "sacrificări": "sacrificare",
    "sacrificării": "sacrificare",
    "sacrificările": "sacrificare",
    "sacrificărilor": "sacrificare",
    "sacrificată": "sacrificat",
    "sacrificate": "sacrificat",
    "sacrificați": "sacrificat",
    "sacrificii": "sacrificiu",
    "sacrificiile": "sacrificiu",
    "sacrificiilor": "sacrificiu",
    "sacrificiul": "sacrificiu",
    "sacrificiului": "sacrificiu",
    "sacrilegii": "sacrilegiu",
    "sacrilegiile": "sacrilegiu",
    "sacrilegiilor": "sacrilegiu",
    "sacrilegiul": "sacrilegiu",
    "sacrilegiului": "sacrilegiu",
    "sacristani": "sacristan",
    "sacristanii": "sacristan",
    "sacristanilor": "sacristan",
    "sacristanul": "sacristan",
    "sacristanului": "sacristan",
    "sacristia": "sacristie",
    "sacristiei": "sacristie",
    "sacristii": "sacristie",
    "sacristiile": "sacristie",
    "sacristiilor": "sacristie",
    "sacrosancta": "sacrosanct",
    "sacrosanctă": "sacrosanct",
    "sacrosancte": "sacrosanct",
    "sacrosanctei": "sacrosanct",
    "sacrosanctele": "sacrosanct",
    "sacrosanctelor": "sacrosanct",
    "sacrosancți": "sacrosanct",
    "sacrosancții": "sacrosanct",
    "sacrosancților": "sacrosanct",
    "sacrosanctul": "sacrosanct",
    "sacrosanctului": "sacrosanct",
    "sacra": "sacru",
    "sacră": "sacru",
    "sacre": "sacru",
    "sacrei": "sacru",
    "sacrele": "sacru",
    "sacrelor": "sacru",
    "sacri": "sacru",
    "sacrii": "sacru",
    "sacrilor": "sacru",
    "sacrul": "sacru",
    "sacrului": "sacru",
    "sacrumul": "sacrum",
    "sacrumului": "sacrum",
    "săculețe": "săculeț",
    "săculețele": "săculeț",
    "săculețelor": "săculeț",
    "săculețul": "săculeț",
    "săculețului": "săculeț",
    "nemaisădind": "sădi",
    "nemaisădindu": "sădi",
    "nesădind": "sădi",
    "nesădindu": "sădi",
    "sădea": "sădi",
    "sădeai": "sădi",
    "sădeam": "sădi",
    "sădească": "sădi",
    "sădeați": "sădi",
    "sădeau": "sădi",
    "sădesc": "sădi",
    "sădește": "sădi",
    "sădești": "sădi",
    "sădii": "sădi",
    "sădim": "sădi",
    "sădind": "sădi",
    "sădindu": "sădi",
    "sădiră": "sădi",
    "sădirăm": "sădi",
    "sădirăți": "sădi",
    "sădise": "sădi",
    "sădisem": "sădi",
    "sădiseră": "sădi",
    "sădiserăm": "sădi",
    "sădiserăți": "sădi",
    "sădiseși": "sădi",
    "sădiși": "sădi",
    "sădit": "sădi",
    "sădiți": "sădi",
    "sadica": "sadic",
    "sadică": "sadic",
    "sadice": "sadic",
    "sadicei": "sadic",
    "sadicele": "sadic",
    "sadicelor": "sadic",
    "sadici": "sadic",
    "sadicii": "sadic",
    "sadicilor": "sadic",
    "sadicul": "sadic",
    "sadicului": "sadic",
    "sadismul": "sadism",
    "sadismului": "sadism",
    "sădită": "sădit",
    "sădite": "sădit",
    "sădiți": "sădit",
    "săditoarea": "săditoare",
    "săditoarei": "săditoare",
    "săditoarele": "săditoare",
    "săditoarelor": "săditoare",
    "safica": "safic",
    "safică": "safic",
    "safice": "safic",
    "saficei": "safic",
    "saficele": "safic",
    "saficelor": "safic",
    "saficii": "safic",
    "saficilor": "safic",
    "saficul": "safic",
    "saficului": "safic",
    "safire": "safir",
    "safirele": "safir",
    "safirelor": "safir",
    "safirul": "safir",
    "safirului": "safir",
    "safranul": "safran",
    "safranului": "safran",
    "safranuri": "safran",
    "safranurile": "safran",
    "safranurilor": "safran",
    "safterele": "safterea",
    "safterelei": "safterea",
    "safterelele": "safterea",
    "safterelelor": "safterea",
    "șaga": "șagă",
    "șagi": "șagă",
    "șagii": "șagă",
    "șagile": "șagă",
    "șagilor": "șagă",
    "sagacitatea": "sagacitate",
    "sagacități": "sagacitate",
    "sagacității": "sagacitate",
    "sagacitățile": "sagacitate",
    "sagacităților": "sagacitate",
    "șăgalnica": "șăgalnic",
    "șăgalnică": "șăgalnic",
    "șăgalnice": "șăgalnic",
    "șăgalnicei": "șăgalnic",
    "șăgalnicele": "șăgalnic",
    "șăgalnicelor": "șăgalnic",
    "șăgalnici": "șăgalnic",
    "șăgalnicii": "șăgalnic",
    "șăgalnicilor": "șăgalnic",
    "șăgalnicul": "șăgalnic",
    "șăgalnicului": "șăgalnic",
    "săgeata": "săgeată",
    "săgeți": "săgeată",
    "săgeții": "săgeată",
    "săgețile": "săgeată",
    "săgeților": "săgeată",
    "nemaisăgetând": "săgeta",
    "nemaisăgetându": "săgeta",
    "nesăgetând": "săgeta",
    "nesăgetându": "săgeta",
    "săgetă": "săgeta",
    "săgetai": "săgeta",
    "săgetam": "săgeta",
    "săgetăm": "săgeta",
    "săgetând": "săgeta",
    "săgetându": "săgeta",
    "săgetară": "săgeta",
    "săgetarăm": "săgeta",
    "săgetarăți": "săgeta",
    "săgetase": "săgeta",
    "săgetasem": "săgeta",
    "săgetaseră": "săgeta",
    "săgetaserăm": "săgeta",
    "săgetaserăți": "săgeta",
    "săgetaseși": "săgeta",
    "săgetași": "săgeta",
    "săgetat": "săgeta",
    "săgetați": "săgeta",
    "săgetau": "săgeta",
    "săgetează": "săgeta",
    "săgetez": "săgeta",
    "săgeteze": "săgeta",
    "săgetezi": "săgeta",
    "săgetată": "săgetat",
    "săgetate": "săgetat",
    "săgetați": "săgetat",
    "săgetători": "săgetător",
    "săgetătorii": "săgetător",
    "săgetătorilor": "săgetător",
    "săgetătorul": "săgetător",
    "săgetătorului": "săgetător",
    "săgetătura": "săgetătură",
    "săgetături": "săgetătură",
    "săgetăturii": "săgetătură",
    "săgetăturile": "săgetătură",
    "săgetăturilor": "săgetătură",
    "sagna": "sagnă",
    "sagne": "sagnă",
    "sagnei": "sagnă",
    "sagnele": "sagnă",
    "sagnelor": "sagnă",
    "sagotiere": "sagotier",
    "sagotierele": "sagotier",
    "sagotierelor": "sagotier",
    "sagotierul": "sagotier",
    "sagotierului": "sagotier",
    "nemaișagrinând": "șagrina",
    "nemaișagrinându": "șagrina",
    "neșagrinând": "șagrina",
    "neșagrinându": "șagrina",
    "șagrină": "șagrina",
    "șagrinai": "șagrina",
    "șagrinam": "șagrina",
    "șagrinăm": "șagrina",
    "șagrinând": "șagrina",
    "șagrinându": "șagrina",
    "șagrinară": "șagrina",
    "șagrinarăm": "șagrina",
    "șagrinarăți": "șagrina",
    "șagrinase": "șagrina",
    "șagrinasem": "șagrina",
    "șagrinaseră": "șagrina",
    "șagrinaserăm": "șagrina",
    "șagrinaserăți": "șagrina",
    "șagrinaseși": "șagrina",
    "șagrinași": "șagrina",
    "șagrinat": "șagrina",
    "șagrinați": "șagrina",
    "șagrinau": "șagrina",
    "șagrinează": "șagrina",
    "șagrinez": "șagrina",
    "șagrineze": "șagrina",
    "șagrinezi": "șagrina",
    "șagrinarea": "șagrinare",
    "șagrinareo": "șagrinare",
    "șagrinări": "șagrinare",
    "șagrinării": "șagrinare",
    "șagrinările": "șagrinare",
    "șagrinărilor": "șagrinare",
    "șagrinată": "șagrinat",
    "șagrinate": "șagrinat",
    "șagrinați": "șagrinat",
    "șahi": "șah",
    "șahii": "șah",
    "șahilor": "șah",
    "șahul": "șah",
    "șahului": "șah",
    "șahuri": "șah",
    "șahurile": "șah",
    "șahurilor": "șah",
    "șahista": "șahist",
    "șahistă": "șahist",
    "șahiste": "șahist",
    "șahistei": "șahist",
    "șahistele": "șahist",
    "șahistelor": "șahist",
    "șahiști": "șahist",
    "șahiștii": "șahist",
    "șahiștilor": "șahist",
    "șahistul": "șahist",
    "șahistului": "șahist",
    "șahista": "șahistă",
    "șahiste": "șahistă",
    "șahistei": "șahistă",
    "șahistele": "șahistă",
    "șahistelor": "șahistă",
    "șaiul": "șai",
    "șaiului": "șai",
    "șaiuri": "șai",
    "șaiurile": "șai",
    "șaiurilor": "șai",
    "șaiba": "șaibă",
    "șaibe": "șaibă",
    "șaibei": "șaibă",
    "șaibele": "șaibă",
    "șaibelor": "șaibă",
    "săidăcari": "săidăcar",
    "săidăcarii": "săidăcar",
    "săidăcarilor": "săidăcar",
    "săidăcarul": "săidăcar",
    "săidăcarului": "săidăcar",
    "șaișpe": "șaisprezece",
    "șaișpea": "șaisprezece",
    "șaișpelea": "șaisprezece",
    "șaisprezecea": "șaisprezece",
    "șaisprezecelea": "șaisprezece",
    "XVI": "șaisprezece",
    "șaisprezecimea": "șaisprezecime",
    "șaisprezecimi": "șaisprezecime",
    "șaisprezecimii": "șaisprezecime",
    "șaisprezecimile": "șaisprezecime",
    "șaisprezecimilor": "șaisprezecime",
    "LX": "șaizeci",
    "șaizecea": "șaizeci",
    "șaizecilea": "șaizeci",
    "șalul": "șal",
    "șalului": "șal",
    "șaluri": "șal",
    "șalurile": "șal",
    "șalurilor": "șal",
    "sala": "sală",
    "săli": "sală",
    "sălii": "sală",
    "sălile": "sală",
    "sălilor": "sală",
    "salahori": "salahor",
    "salahorii": "salahor",
    "salahorilor": "salahor",
    "salahorul": "salahor",
    "salahorului": "salahor",
    "nemaisalahorind": "salahori",
    "nemaisalahorindu": "salahori",
    "nesalahorind": "salahori",
    "nesalahorindu": "salahori",
    "salahorea": "salahori",
    "salahoreai": "salahori",
    "salahoream": "salahori",
    "salahorească": "salahori",
    "salahoreați": "salahori",
    "salahoreau": "salahori",
    "salahoresc": "salahori",
    "salahorește": "salahori",
    "salahorești": "salahori",
    "salahorii": "salahori",
    "salahorim": "salahori",
    "salahorind": "salahori",
    "salahorindu": "salahori",
    "salahoriră": "salahori",
    "salahorirăm": "salahori",
    "salahorirăți": "salahori",
    "salahorise": "salahori",
    "salahorisem": "salahori",
    "salahoriseră": "salahori",
    "salahoriserăm": "salahori",
    "salahoriserăți": "salahori",
    "salahoriseși": "salahori",
    "salahoriși": "salahori",
    "salahorit": "salahori",
    "salahoriți": "salahori",
    "salahoria": "salahorie",
    "salahoriei": "salahorie",
    "salahorii": "salahorie",
    "salahoriile": "salahorie",
    "salahoriilor": "salahorie",
    "salahorită": "salahorit",
    "salahorite": "salahorit",
    "salahoriți": "salahorit",
    "salamul": "salam",
    "salamului": "salam",
    "salamuri": "salam",
    "salamurile": "salam",
    "salamurilor": "salam",
    "salamandra": "salamandră",
    "salamandre": "salamandră",
    "salamandrei": "salamandră",
    "salamandrele": "salamandră",
    "salamandrelor": "salamandră",
    "șalandul": "șaland",
    "șalandului": "șaland",
    "șalanduri": "șaland",
    "șalandurile": "șaland",
    "șalandurilor": "șaland",
    "șalangeri": "șalanger",
    "șalangerii": "șalanger",
    "șalangerilor": "șalanger",
    "șalangerul": "șalanger",
    "șalangerului": "șalanger",
    "nemaisalariind": "salaria",
    "nemaisalariindu": "salaria",
    "nesalariind": "salaria",
    "nesalariindu": "salaria",
    "salariai": "salaria",
    "salariam": "salaria",
    "salariară": "salaria",
    "salariarăm": "salaria",
    "salariarăți": "salaria",
    "salariase": "salaria",
    "salariasem": "salaria",
    "salariaseră": "salaria",
    "salariaserăm": "salaria",
    "salariaserăți": "salaria",
    "salariaseși": "salaria",
    "salariași": "salaria",
    "salariat": "salaria",
    "salariați": "salaria",
    "salariau": "salaria",
    "salariază": "salaria",
    "salarie": "salaria",
    "salariem": "salaria",
    "salariez": "salaria",
    "salarieze": "salaria",
    "salariezi": "salaria",
    "salariind": "salaria",
    "salariindu": "salaria",
    "salariala": "salarial",
    "salarială": "salarial",
    "salariale": "salarial",
    "salarialei": "salarial",
    "salarialele": "salarial",
    "salarialelor": "salarial",
    "salariali": "salarial",
    "salarialii": "salarial",
    "salarialilor": "salarial",
    "salarialul": "salarial",
    "salarialului": "salarial",
    "salariata": "salariat",
    "salariată": "salariat",
    "salariate": "salariat",
    "salariatei": "salariat",
    "salariatele": "salariat",
    "salariatelor": "salariat",
    "salariați": "salariat",
    "salariații": "salariat",
    "salariaților": "salariat",
    "salariatul": "salariat",
    "salariatului": "salariat",
    "salarii": "salariu",
    "salariile": "salariu",
    "salariilor": "salariu",
    "salariul": "salariu",
    "salariului": "salariu",
    "nemaisalarizând": "salariza",
    "nemaisalarizându": "salariza",
    "nesalarizând": "salariza",
    "nesalarizându": "salariza",
    "salariză": "salariza",
    "salarizai": "salariza",
    "salarizam": "salariza",
    "salarizăm": "salariza",
    "salarizând": "salariza",
    "salarizându": "salariza",
    "salarizară": "salariza",
    "salarizarăm": "salariza",
    "salarizarăți": "salariza",
    "salarizase": "salariza",
    "salarizasem": "salariza",
    "salarizaseră": "salariza",
    "salarizaserăm": "salariza",
    "salarizaserăți": "salariza",
    "salarizaseși": "salariza",
    "salarizași": "salariza",
    "salarizat": "salariza",
    "salarizați": "salariza",
    "salarizau": "salariza",
    "salarizează": "salariza",
    "salarizez": "salariza",
    "salarizeze": "salariza",
    "salarizezi": "salariza",
    "salarizării": "salarizare",
    "salarizată": "salarizat",
    "salarizate": "salarizat",
    "salarizați": "salarizat",
    "sălașe": "sălaș",
    "sălașele": "sălaș",
    "sălașelor": "sălaș",
    "sălașul": "sălaș",
    "sălașului": "sălaș",
    "nemaisălășluind": "sălășlui",
    "nemaisălășluindu": "sălășlui",
    "nesălășluind": "sălășlui",
    "nesălășluindu": "sălășlui",
    "sălășluia": "sălășlui",
    "sălășluiai": "sălășlui",
    "sălășluiam": "sălășlui",
    "sălășluiască": "sălășlui",
    "sălășluiați": "sălășlui",
    "sălășluiau": "sălășlui",
    "sălășluiesc": "sălășlui",
    "sălășluiește": "sălășlui",
    "sălășluiești": "sălășlui",
    "sălășluii": "sălășlui",
    "sălășluim": "sălășlui",
    "sălășluind": "sălășlui",
    "sălășluindu": "sălășlui",
    "sălășluiră": "sălășlui",
    "sălășluirăm": "sălășlui",
    "sălășluirăți": "sălășlui",
    "sălășluise": "sălășlui",
    "sălășluisem": "sălășlui",
    "sălășluiseră": "sălășlui",
    "sălășluiserăm": "sălășlui",
    "sălășluiserăți": "sălășlui",
    "sălășluiseși": "sălășlui",
    "sălășluiși": "sălășlui",
    "sălășluit": "sălășlui",
    "sălășluiți": "sălășlui",
    "sălășluitu": "sălășlui",
    "sălășluirea": "sălășluire",
    "sălășluiri": "sălășluire",
    "sălășluirii": "sălășluire",
    "sălășluirile": "sălășluire",
    "sălășluirilor": "sălășluire",
    "sălășluită": "sălășluit",
    "sălășluite": "sălășluit",
    "sălășluiți": "sălășluit",
    "salata": "salată",
    "salate": "salată",
    "salatei": "salată",
    "salatele": "salată",
    "salatelor": "salată",
    "salatiera": "salatieră",
    "salatiere": "salatieră",
    "salatierei": "salatieră",
    "salatierele": "salatieră",
    "salatierelor": "salatieră",
    "șalăi": "șalău",
    "șalăii": "șalău",
    "șalăilor": "șalău",
    "șalăul": "șalău",
    "șalăului": "șalău",
    "salba": "salbă",
    "salbe": "salbă",
    "salbei": "salbă",
    "salbele": "salbă",
    "salbelor": "salbă",
    "sălbatica": "sălbatic",
    "sălbatică": "sălbatic",
    "sălbatice": "sălbatic",
    "sălbaticei": "sălbatic",
    "sălbaticele": "sălbatic",
    "sălbaticelor": "sălbatic",
    "sălbatici": "sălbatic",
    "sălbaticii": "sălbatic",
    "sălbaticilor": "sălbatic",
    "sălbaticul": "sălbatic",
    "sălbaticului": "sălbatic",
    "nemaisălbăticind": "sălbătici",
    "nemaisălbăticindu": "sălbătici",
    "nesălbăticind": "sălbătici",
    "nesălbăticindu": "sălbătici",
    "sălbăticea": "sălbătici",
    "sălbăticeai": "sălbătici",
    "sălbăticeam": "sălbătici",
    "sălbăticească": "sălbătici",
    "sălbăticeați": "sălbătici",
    "sălbăticeau": "sălbătici",
    "sălbăticesc": "sălbătici",
    "sălbăticește": "sălbătici",
    "sălbăticești": "sălbătici",
    "sălbăticii": "sălbătici",
    "sălbăticim": "sălbătici",
    "sălbăticind": "sălbătici",
    "sălbăticindu": "sălbătici",
    "sălbăticiră": "sălbătici",
    "sălbăticirăm": "sălbătici",
    "sălbăticirăți": "sălbătici",
    "sălbăticise": "sălbătici",
    "sălbăticisem": "sălbătici",
    "sălbăticiseră": "sălbătici",
    "sălbăticiserăm": "sălbătici",
    "sălbăticiserăți": "sălbătici",
    "sălbăticiseși": "sălbătici",
    "sălbăticiși": "sălbătici",
    "sălbăticit": "sălbătici",
    "sălbăticiți": "sălbătici",
    "sălbăticia": "sălbăticie",
    "sălbăticiei": "sălbăticie",
    "sălbăticii": "sălbăticie",
    "sălbăticiile": "sălbăticie",
    "sălbăticiilor": "sălbăticie",
    "sălbăticită": "sălbăticit",
    "sălbăticite": "sălbăticit",
    "sălbăticiți": "sălbăticit",
    "sălbăticiunea": "sălbăticiune",
    "sălbăticiuni": "sălbăticiune",
    "sălbăticiunii": "sălbăticiune",
    "sălbăticiunile": "sălbăticiune",
    "sălbăticiunilor": "sălbăticiune",
    "salcâmi": "salcâm",
    "salcâmii": "salcâm",
    "salcâmilor": "salcâm",
    "salcâmul": "salcâm",
    "salcâmului": "salcâm",
    "salcia": "salcie",
    "sălciei": "salcie",
    "sălcii": "salcie",
    "sălciile": "salcie",
    "sălciilor": "salcie",
    "sălcia": "sălciu",
    "sălcie": "sălciu",
    "sălciei": "sălciu",
    "sălcii": "sălciu",
    "sălciii": "sălciu",
    "sălciile": "sălciu",
    "sălciilor": "sălciu",
    "sălciul": "sălciu",
    "sălciului": "sălciu",
    "șalele": "șale",
    "șalelor": "șale",
    "salepgii": "salepgiu",
    "salepgiii": "salepgiu",
    "salepgiilor": "salepgiu",
    "salepgiul": "salepgiu",
    "salepgiului": "salepgiu",
    "saleul": "saleu",
    "saleului": "saleu",
    "saleuri": "saleu",
    "saleurile": "saleu",
    "saleurilor": "saleu",
    "salicilați": "salicilat",
    "salicilații": "salicilat",
    "salicilaților": "salicilat",
    "salicilatul": "salicilat",
    "salicilatului": "salicilat",
    "salicilica": "salicilic",
    "salicilică": "salicilic",
    "salicilice": "salicilic",
    "salicilicei": "salicilic",
    "salicilicele": "salicilic",
    "salicilicelor": "salicilic",
    "salicilici": "salicilic",
    "salicilicii": "salicilic",
    "salicilicilor": "salicilic",
    "salicilicul": "salicilic",
    "salicilicului": "salicilic",
    "salicilina": "salicilină",
    "saliciline": "salicilină",
    "salicilinei": "salicilină",
    "salicilinele": "salicilină",
    "salicilinelor": "salicilină",
    "salina": "salin",
    "salină": "salin",
    "saline": "salin",
    "salinei": "salin",
    "salinele": "salin",
    "salinelor": "salin",
    "salini": "salin",
    "salinii": "salin",
    "salinilor": "salin",
    "salinul": "salin",
    "salinului": "salin",
    "salina": "salină",
    "saline": "salină",
    "salinei": "salină",
    "salinele": "salină",
    "salinelor": "salină",
    "salinitatea": "salinitate",
    "salinități": "salinitate",
    "salinității": "salinitate",
    "salinitățile": "salinitate",
    "salinităților": "salinitate",
    "salinizarea": "salinizare",
    "salinizări": "salinizare",
    "salinizării": "salinizare",
    "salinizările": "salinizare",
    "salinizărilor": "salinizare",
    "salinometre": "salinometru",
    "salinometrele": "salinometru",
    "salinometrelor": "salinometru",
    "salinometrul": "salinometru",
    "salinometrului": "salinometru",
    "salipirina": "salipirină",
    "salipirine": "salipirină",
    "salipirinei": "salipirină",
    "salipirinele": "salipirină",
    "salipirinelor": "salipirină",
    "nemaisalivând": "saliva",
    "nemaisalivându": "saliva",
    "nesalivând": "saliva",
    "nesalivându": "saliva",
    "salivă": "saliva",
    "salivai": "saliva",
    "salivam": "saliva",
    "salivăm": "saliva",
    "salivând": "saliva",
    "salivându": "saliva",
    "salivară": "saliva",
    "salivarăm": "saliva",
    "salivarăți": "saliva",
    "salivase": "saliva",
    "salivasem": "saliva",
    "salivaseră": "saliva",
    "salivaserăm": "saliva",
    "salivaserăți": "saliva",
    "salivaseși": "saliva",
    "salivași": "saliva",
    "salivat": "saliva",
    "salivați": "saliva",
    "salivau": "saliva",
    "salivează": "saliva",
    "salivez": "saliva",
    "saliveze": "saliva",
    "salivezi": "saliva",
    "saliva": "salivă",
    "salivată": "salivat",
    "salivate": "salivat",
    "salivați": "salivat",
    "salmonide": "salmonid",
    "salmonidele": "salmonid",
    "salmonidelor": "salmonid",
    "salmonidul": "salmonid",
    "salmonidului": "salmonid",
    "saloane": "salon",
    "saloanele": "salon",
    "saloanelor": "salon",
    "salonul": "salon",
    "salonului": "salon",
    "salonașe": "salonaș",
    "salonașele": "salonaș",
    "salonașelor": "salonaș",
    "salonașul": "salonaș",
    "salonașului": "salonaș",
    "salopeta": "salopetă",
    "salopete": "salopetă",
    "salopetei": "salopetă",
    "salopetele": "salopetă",
    "salopetelor": "salopetă",
    "salpetre": "salpetru",
    "salpetrele": "salpetru",
    "salpetrelor": "salpetru",
    "salpetrul": "salpetru",
    "salpetrului": "salpetru",
    "salpingita": "salpingită",
    "salpingite": "salpingită",
    "salpingitei": "salpingită",
    "salpingitele": "salpingită",
    "salpingitelor": "salpingită",
    "saltul": "salt",
    "saltului": "salt",
    "salturi": "salt",
    "salturile": "salt",
    "salturilor": "salt",
    "nemaisăltând": "sălta",
    "nemaisăltându": "sălta",
    "nesăltând": "sălta",
    "nesăltându": "sălta",
    "salt": "sălta",
    "saltă": "sălta",
    "săltă": "sălta",
    "săltai": "sălta",
    "săltam": "sălta",
    "săltăm": "sălta",
    "săltând": "sălta",
    "săltându": "sălta",
    "săltară": "sălta",
    "săltarăm": "sălta",
    "săltarăți": "sălta",
    "săltase": "sălta",
    "săltasem": "sălta",
    "săltaseră": "sălta",
    "săltaserăm": "sălta",
    "săltaserăți": "sălta",
    "săltaseși": "sălta",
    "săltași": "sălta",
    "săltat": "sălta",
    "săltați": "sălta",
    "săltau": "sălta",
    "salte": "sălta",
    "salți": "sălta",
    "șaltăre": "șaltăr",
    "șaltărele": "șaltăr",
    "șaltărelor": "șaltăr",
    "șaltărul": "șaltăr",
    "șaltărului": "șaltăr",
    "săltarea": "săltare",
    "săltareo": "săltare",
    "săltări": "săltare",
    "săltării": "săltare",
    "săltările": "săltare",
    "săltărilor": "săltare",
    "săltăreața": "săltăreț",
    "săltăreață": "săltăreț",
    "săltărețe": "săltăreț",
    "săltăreței": "săltăreț",
    "săltărețele": "săltăreț",
    "săltărețelor": "săltăreț",
    "săltăreți": "săltăreț",
    "săltăreții": "săltăreț",
    "săltăreților": "săltăreț",
    "săltărețul": "săltăreț",
    "săltărețului": "săltăreț",
    "săltata": "săltat",
    "săltată": "săltat",
    "săltate": "săltat",
    "săltatei": "săltat",
    "săltatele": "săltat",
    "săltatelor": "săltat",
    "săltați": "săltat",
    "săltații": "săltat",
    "săltaților": "săltat",
    "săltato": "săltat",
    "săltatul": "săltat",
    "săltatule": "săltat",
    "săltatului": "săltat",
    "săltătoarea": "săltătoare",
    "săltătoarele": "săltătoare",
    "săltătoarelor": "săltătoare",
    "săltători": "săltătoare",
    "săltătorii": "săltătoare",
    "salteaua": "saltea",
    "saltele": "saltea",
    "saltelei": "saltea",
    "saltelele": "saltea",
    "saltelelor": "saltea",
    "saltimbanci": "saltimbanc",
    "saltimbancii": "saltimbanc",
    "saltimbancilor": "saltimbanc",
    "saltimbancul": "saltimbanc",
    "saltimbancului": "saltimbanc",
    "salubritatea": "salubritate",
    "salubrități": "salubritate",
    "salubrității": "salubritate",
    "salubritățile": "salubritate",
    "salubrităților": "salubritate",
    "salubra": "salubru",
    "salubră": "salubru",
    "salubre": "salubru",
    "salubrei": "salubru",
    "salubrele": "salubru",
    "salubrelor": "salubru",
    "salubri": "salubru",
    "salubrii": "salubru",
    "salubrilor": "salubru",
    "salubrul": "salubru",
    "salubrului": "salubru",
    "șalupa": "șalupă",
    "șalupe": "șalupă",
    "șalupei": "șalupă",
    "șalupele": "șalupă",
    "șalupelor": "șalupă",
    "salutul": "salut",
    "salutului": "salut",
    "saluturi": "salut",
    "saluturile": "salut",
    "saluturilor": "salut",
    "nemaisalutând": "saluta",
    "nemaisalutându": "saluta",
    "nesalutând": "saluta",
    "nesalutându": "saluta",
    "salut": "saluta",
    "salută": "saluta",
    "salutai": "saluta",
    "salutam": "saluta",
    "salutăm": "saluta",
    "salutând": "saluta",
    "salutându": "saluta",
    "salutară": "saluta",
    "salutarăm": "saluta",
    "salutarăți": "saluta",
    "salutase": "saluta",
    "salutasem": "saluta",
    "salutaseră": "saluta",
    "salutaserăm": "saluta",
    "salutaserăți": "saluta",
    "salutaseși": "saluta",
    "salutași": "saluta",
    "salutat": "saluta",
    "salutați": "saluta",
    "salutau": "saluta",
    "salute": "saluta",
    "saluți": "saluta",
    "salutarea": "salutare",
    "salutareo": "salutare",
    "salutări": "salutare",
    "salutării": "salutare",
    "salutările": "salutare",
    "salutărilor": "salutare",
    "salutată": "salutat",
    "salutate": "salutat",
    "salutați": "salutat",
    "nemaisalvând": "salva",
    "nemaisalvându": "salva",
    "nesalvând": "salva",
    "nesalvându": "salva",
    "salvă": "salva",
    "salvai": "salva",
    "salvam": "salva",
    "salvăm": "salva",
    "salvând": "salva",
    "salvându": "salva",
    "salvară": "salva",
    "salvarăm": "salva",
    "salvarăți": "salva",
    "salvase": "salva",
    "salvasem": "salva",
    "salvaseră": "salva",
    "salvaserăm": "salva",
    "salvaserăți": "salva",
    "salvaseși": "salva",
    "salvași": "salva",
    "salvat": "salva",
    "salvați": "salva",
    "salvau": "salva",
    "salvează": "salva",
    "salvez": "salva",
    "salveze": "salva",
    "salvezi": "salva",
    "salva": "salvă",
    "salve": "salvă",
    "salvei": "salvă",
    "salvele": "salvă",
    "salvelor": "salvă",
    "șalvaragii": "șalvaragiu",
    "șalvaragiii": "șalvaragiu",
    "șalvaragiilor": "șalvaragiu",
    "salvarea": "salvare",
    "salvări": "salvare",
    "salvării": "salvare",
    "salvările": "salvare",
    "salvărilor": "salvare",
    "șalvarii": "șalvari",
    "șalvarilor": "șalvari",
    "salvata": "salvat",
    "salvată": "salvat",
    "salvate": "salvat",
    "salvatei": "salvat",
    "salvatele": "salvat",
    "salvatelor": "salvat",
    "salvați": "salvat",
    "salvații": "salvat",
    "salvaților": "salvat",
    "salvato": "salvat",
    "salvatul": "salvat",
    "salvatule": "salvat",
    "salvatului": "salvat",
    "salvatoarea": "salvatoare",
    "salvatoarei": "salvatoare",
    "salvatoarele": "salvatoare",
    "salvatoarelor": "salvatoare",
    "salvatoare": "salvator",
    "salvatoarea": "salvator",
    "salvatoarei": "salvator",
    "salvatoarele": "salvator",
    "salvatoarelor": "salvator",
    "salvatori": "salvator",
    "salvatorii": "salvator",
    "salvatorilor": "salvator",
    "salvatorul": "salvator",
    "salvatorului": "salvator",
    "salvgardă": "salvgarda",
    "salvgardai": "salvgarda",
    "salvgardam": "salvgarda",
    "salvgardăm": "salvgarda",
    "salvgardând": "salvgarda",
    "salvgardându": "salvgarda",
    "salvgardară": "salvgarda",
    "salvgardarăm": "salvgarda",
    "salvgardarăți": "salvgarda",
    "salvgardase": "salvgarda",
    "salvgardasem": "salvgarda",
    "salvgardaseră": "salvgarda",
    "salvgardaserăm": "salvgarda",
    "salvgardaserăți": "salvgarda",
    "salvgardaseși": "salvgarda",
    "salvgardași": "salvgarda",
    "salvgardat": "salvgarda",
    "salvgardați": "salvgarda",
    "salvgardatu": "salvgarda",
    "salvgardau": "salvgarda",
    "salvgardează": "salvgarda",
    "salvgardez": "salvgarda",
    "salvgardeze": "salvgarda",
    "salvgardezi": "salvgarda",
    "salvgardată": "salvgardat",
    "salvgardate": "salvgardat",
    "salvgardați": "salvgardat",
    "salvia": "salvie",
    "salviei": "salvie",
    "salvii": "salvie",
    "salviile": "salvie",
    "salviilor": "salvie",
    "șamani": "șaman",
    "șamanii": "șaman",
    "șamanilor": "șaman",
    "șamanul": "șaman",
    "șamanului": "șaman",
    "șamanismul": "șamanism",
    "șamanismului": "șamanism",
    "sămânța": "sămânță",
    "semințe": "sămânță",
    "seminței": "sămânță",
    "semințele": "sămânță",
    "semințelor": "sămânță",
    "sămânțoasa": "sămânțos",
    "sămânțoasă": "sămânțos",
    "sămânțoase": "sămânțos",
    "sămânțoasei": "sămânțos",
    "sămânțoasele": "sămânțos",
    "sămânțoaselor": "sămânțos",
    "sămânțoși": "sămânțos",
    "sămânțoșii": "sămânțos",
    "sămânțoșilor": "sămânțos",
    "sămânțosul": "sămânțos",
    "sămânțosului": "sămânțos",
    "samare": "samar",
    "samarele": "samar",
    "samarelor": "samar",
    "samarul": "samar",
    "samarului": "samar",
    "samara": "samară",
    "samare": "samară",
    "samarei": "samară",
    "samarele": "samară",
    "samarelor": "samară",
    "samariteanul": "samaritean",
    "samariteanului": "samaritean",
    "samariteni": "samaritean",
    "samaritenii": "samaritean",
    "samaritenilor": "samaritean",
    "samavolnica": "samavolnic",
    "samavolnică": "samavolnic",
    "samavolnice": "samavolnic",
    "samavolnicei": "samavolnic",
    "samavolnicele": "samavolnic",
    "samavolnicelor": "samavolnic",
    "samavolnici": "samavolnic",
    "samavolnicii": "samavolnic",
    "samavolnicilor": "samavolnic",
    "samavolnicul": "samavolnic",
    "samavolnicului": "samavolnic",
    "samavolnicia": "samavolnicie",
    "samavolniciei": "samavolnicie",
    "samavolnicii": "samavolnicie",
    "samavolniciile": "samavolnicie",
    "samavolniciilor": "samavolnicie",
    "S.": "sâmbătă",
    "sâmbăta": "sâmbătă",
    "sâmbete": "sâmbătă",
    "sâmbetei": "sâmbătă",
    "sâmbetele": "sâmbătă",
    "sâmbetelor": "sâmbătă",
    "șambelani": "șambelan",
    "șambelanii": "șambelan",
    "șambelanilor": "șambelan",
    "șambelanul": "șambelan",
    "șambelanului": "șambelan",
    "sâmbovina": "sâmbovină",
    "sâmbovine": "sâmbovină",
    "sâmbovinei": "sâmbovină",
    "sâmbovinele": "sâmbovină",
    "sâmbovinelor": "sâmbovină",
    "sâmburele": "sâmbure",
    "sâmburelui": "sâmbure",
    "sâmburi": "sâmbure",
    "sâmburii": "sâmbure",
    "sâmburilor": "sâmbure",
    "șamota": "șamotă",
    "șamote": "șamotă",
    "șamotei": "șamotă",
    "șamotele": "șamotă",
    "șamotelor": "șamotă",
    "samovare": "samovar",
    "samovarele": "samovar",
    "samovarelor": "samovar",
    "samovarul": "samovar",
    "samovarului": "samovar",
    "șampania": "șampanie",
    "șampaniei": "șampanie",
    "șampanii": "șampanie",
    "șampaniile": "șampanie",
    "șampaniilor": "șampanie",
    "nemaișampanizând": "șampaniza",
    "nemaișampanizându": "șampaniza",
    "neșampanizând": "șampaniza",
    "neșampanizându": "șampaniza",
    "șampaniză": "șampaniza",
    "șampanizai": "șampaniza",
    "șampanizam": "șampaniza",
    "șampanizăm": "șampaniza",
    "șampanizând": "șampaniza",
    "șampanizându": "șampaniza",
    "șampanizară": "șampaniza",
    "șampanizarăm": "șampaniza",
    "șampanizarăți": "șampaniza",
    "șampanizase": "șampaniza",
    "șampanizasem": "șampaniza",
    "șampanizaseră": "șampaniza",
    "șampanizaserăm": "șampaniza",
    "șampanizaserăți": "șampaniza",
    "șampanizaseși": "șampaniza",
    "șampanizași": "șampaniza",
    "șampanizat": "șampaniza",
    "șampanizați": "șampaniza",
    "șampanizau": "șampaniza",
    "șampanizează": "șampaniza",
    "șampanizez": "șampaniza",
    "șampanizeze": "șampaniza",
    "șampanizezi": "șampaniza",
    "șampanizarea": "șampanizare",
    "șampanizareo": "șampanizare",
    "șampanizări": "șampanizare",
    "șampanizării": "șampanizare",
    "șampanizările": "șampanizare",
    "șampanizărilor": "șampanizare",
    "șampanizată": "șampanizat",
    "șampanizate": "șampanizat",
    "șampanizați": "șampanizat",
    "șampoane": "șampon",
    "șampoanele": "șampon",
    "șampoanelor": "șampon",
    "șamponul": "șampon",
    "șamponului": "șampon",
    "samsari": "samsar",
    "samsarii": "samsar",
    "samsarilor": "samsar",
    "samsarul": "samsar",
    "samsarului": "samsar",
    "samuri": "samur",
    "samurii": "samur",
    "samurilor": "samur",
    "samurul": "samur",
    "samurului": "samur",
    "samuraii": "samurai",
    "samurailor": "samurai",
    "samuraiul": "samurai",
    "samuraiului": "samurai",
    "sâni": "sân",
    "sânii": "sân",
    "sânilor": "sân",
    "sânul": "sân",
    "sânului": "sân",
    "sânuri": "sân",
    "sânurile": "sân",
    "sânurilor": "sân",
    "șanul": "șan",
    "șanului": "șan",
    "șanuri": "șan",
    "șanurile": "șan",
    "șanurilor": "șan",
    "sănătatea": "sănătate",
    "sănătăți": "sănătate",
    "sănătății": "sănătate",
    "sănătățile": "sănătate",
    "sănătăților": "sănătate",
    "sanatorii": "sanatoriu",
    "sanatoriile": "sanatoriu",
    "sanatoriilor": "sanatoriu",
    "sanatoriul": "sanatoriu",
    "sanatoriului": "sanatoriu",
    "sănătoasa": "sănătos",
    "sănătoasă": "sănătos",
    "sănătoase": "sănătos",
    "sănătoasei": "sănătos",
    "sănătoasele": "sănătos",
    "sănătoaselor": "sănătos",
    "sănătoși": "sănătos",
    "sănătoșii": "sănătos",
    "sănătoșilor": "sănătos",
    "sănătosul": "sănătos",
    "sănătosului": "sănătos",
    "șancre": "șancru",
    "șancrele": "șancru",
    "șancrelor": "șancru",
    "șancrul": "șancru",
    "șancrului": "șancru",
    "nemaisanctificând": "sanctifica",
    "nemaisanctificându": "sanctifica",
    "nesanctificând": "sanctifica",
    "nesanctificându": "sanctifica",
    "sanctific": "sanctifica",
    "sanctifică": "sanctifica",
    "sanctificai": "sanctifica",
    "sanctificam": "sanctifica",
    "sanctificăm": "sanctifica",
    "sanctificând": "sanctifica",
    "sanctificându": "sanctifica",
    "sanctificară": "sanctifica",
    "sanctificarăm": "sanctifica",
    "sanctificarăți": "sanctifica",
    "sanctificase": "sanctifica",
    "sanctificasem": "sanctifica",
    "sanctificaseră": "sanctifica",
    "sanctificaserăm": "sanctifica",
    "sanctificaserăți": "sanctifica",
    "sanctificaseși": "sanctifica",
    "sanctificași": "sanctifica",
    "sanctificat": "sanctifica",
    "sanctificați": "sanctifica",
    "sanctificau": "sanctifica",
    "sanctifice": "sanctifica",
    "sanctifici": "sanctifica",
    "sanctificată": "sanctificat",
    "sanctificate": "sanctificat",
    "sanctificați": "sanctificat",
    "nemaisancționând": "sancționa",
    "nemaisancționându": "sancționa",
    "nesancționând": "sancționa",
    "nesancționându": "sancționa",
    "sancționă": "sancționa",
    "sancționai": "sancționa",
    "sancționam": "sancționa",
    "sancționăm": "sancționa",
    "sancționând": "sancționa",
    "sancționându": "sancționa",
    "sancționară": "sancționa",
    "sancționarăm": "sancționa",
    "sancționarăți": "sancționa",
    "sancționase": "sancționa",
    "sancționasem": "sancționa",
    "sancționaseră": "sancționa",
    "sancționaserăm": "sancționa",
    "sancționaserăți": "sancționa",
    "sancționaseși": "sancționa",
    "sancționași": "sancționa",
    "sancționat": "sancționa",
    "sancționați": "sancționa",
    "sancționau": "sancționa",
    "sancționează": "sancționa",
    "sancționez": "sancționa",
    "sancționeze": "sancționa",
    "sancționezi": "sancționa",
    "sancționarea": "sancționare",
    "sancționări": "sancționare",
    "sancționării": "sancționare",
    "sancționările": "sancționare",
    "sancționărilor": "sancționare",
    "sancționată": "sancționat",
    "sancționate": "sancționat",
    "sancționați": "sancționat",
    "sanctitatea": "sanctitate",
    "sanctități": "sanctitate",
    "sanctității": "sanctitate",
    "sanctitățile": "sanctitate",
    "sanctităților": "sanctitate",
    "sancțiunea": "sancțiune",
    "sancțiuni": "sancțiune",
    "sancțiunii": "sancțiune",
    "sancțiunile": "sancțiune",
    "sancțiunilor": "sancțiune",
    "sanctuare": "sanctuar",
    "sanctuarele": "sanctuar",
    "sanctuarelor": "sanctuar",
    "sanctuarul": "sanctuar",
    "sanctuarului": "sanctuar",
    "Sandei": "Sanda",
    "sandala": "sandală",
    "sandale": "sandală",
    "sandalei": "sandală",
    "sandalele": "sandală",
    "sandalelor": "sandală",
    "șandramale": "șandrama",
    "șandramalei": "șandrama",
    "șandramalele": "șandrama",
    "șandramalelor": "șandrama",
    "șandramaua": "șandrama",
    "Sandule": "Sandu",
    "sandvișul": "sandviș",
    "sandvișului": "sandviș",
    "sandvișuri": "sandviș",
    "sandvișurile": "sandviș",
    "sandvișurilor": "sandviș",
    "sângele": "sânge",
    "sângelui": "sânge",
    "sangeacul": "sangeac",
    "sangeacului": "sangeac",
    "sangeacuri": "sangeac",
    "sangeacurile": "sangeac",
    "sangeacurilor": "sangeac",
    "sângeri": "sânger",
    "sângerii": "sânger",
    "sângerilor": "sânger",
    "sângerul": "sânger",
    "sângerului": "sânger",
    "nemaisângerând": "sângera",
    "nemaisângerându": "sângera",
    "nesângerând": "sângera",
    "nesângerându": "sângera",
    "sângeră": "sângera",
    "sângerai": "sângera",
    "sângeram": "sângera",
    "sângerăm": "sângera",
    "sângerând": "sângera",
    "sângerându": "sângera",
    "sângerară": "sângera",
    "sângerarăm": "sângera",
    "sângerarăți": "sângera",
    "sângerase": "sângera",
    "sângerasem": "sângera",
    "sângeraseră": "sângera",
    "sângeraserăm": "sângera",
    "sângeraserăți": "sângera",
    "sângeraseși": "sângera",
    "sângerași": "sângera",
    "sângerat": "sângera",
    "sângerați": "sângera",
    "sângerau": "sângera",
    "sângerează": "sângera",
    "sângerez": "sângera",
    "sângereze": "sângera",
    "sângerezi": "sângera",
    "sângerânda": "sângerând",
    "sângerândă": "sângerând",
    "sângerânde": "sângerând",
    "sângerândei": "sângerând",
    "sângerândele": "sângerând",
    "sângerândelor": "sângerând",
    "sângerândul": "sângerând",
    "sângerândului": "sângerând",
    "sângerânzi": "sângerând",
    "sângerânzii": "sângerând",
    "sângerânzilor": "sângerând",
    "sângerată": "sângerat",
    "sângerate": "sângerat",
    "sângerați": "sângerat",
    "sângeria": "sângeriu",
    "sângerie": "sângeriu",
    "sângeriei": "sângeriu",
    "sângerii": "sângeriu",
    "sângeriii": "sângeriu",
    "sângeriile": "sângeriu",
    "sângeriilor": "sângeriu",
    "sângeriul": "sângeriu",
    "sângeriului": "sângeriu",
    "sângeroasa": "sângeros",
    "sângeroasă": "sângeros",
    "sângeroase": "sângeros",
    "sângeroasei": "sângeros",
    "sângeroasele": "sângeros",
    "sângeroaselor": "sângeros",
    "sângeroși": "sângeros",
    "sângeroșii": "sângeros",
    "sângeroșilor": "sângeros",
    "sângerosul": "sângeros",
    "sângerosului": "sângeros",
    "sanguina": "sanguin",
    "sanguină": "sanguin",
    "sanguine": "sanguin",
    "sanguinei": "sanguin",
    "sanguinele": "sanguin",
    "sanguinelor": "sanguin",
    "sanguini": "sanguin",
    "sanguinii": "sanguin",
    "sanguinilor": "sanguin",
    "sanguinul": "sanguin",
    "sanguinului": "sanguin",
    "sangvina": "sangvin",
    "sangvină": "sangvin",
    "sangvine": "sangvin",
    "sangvinei": "sangvin",
    "sangvinele": "sangvin",
    "sangvinelor": "sangvin",
    "sangvini": "sangvin",
    "sangvinii": "sangvin",
    "sangvinilor": "sangvin",
    "sangvinul": "sangvin",
    "sangvinului": "sangvin",
    "sania": "sanie",
    "săniei": "sanie",
    "sănii": "sanie",
    "săniile": "sanie",
    "săniilor": "sanie",
    "sanitara": "sanitar",
    "sanitară": "sanitar",
    "sanitare": "sanitar",
    "sanitarei": "sanitar",
    "sanitarele": "sanitar",
    "sanitarelor": "sanitar",
    "sanitari": "sanitar",
    "sanitarii": "sanitar",
    "sanitarilor": "sanitar",
    "sanitarul": "sanitar",
    "sanitarului": "sanitar",
    "săniușul": "săniuș",
    "săniușului": "săniuș",
    "săniușuri": "săniuș",
    "săniușurile": "săniuș",
    "săniușurilor": "săniuș",
    "săniuța": "săniuță",
    "săniuțe": "săniuță",
    "săniuței": "săniuță",
    "săniuțele": "săniuță",
    "săniuțelor": "săniuță",
    "șansa": "șansă",
    "șanse": "șansă",
    "șansei": "șansă",
    "șansele": "șansă",
    "șanselor": "șansă",
    "sanscrita": "sanscrit",
    "sanscrită": "sanscrit",
    "sanscrite": "sanscrit",
    "sanscritei": "sanscrit",
    "sanscritele": "sanscrit",
    "sanscritelor": "sanscrit",
    "sanscriți": "sanscrit",
    "sanscriții": "sanscrit",
    "sanscriților": "sanscrit",
    "sanscritul": "sanscrit",
    "sanscritului": "sanscrit",
    "șansoneta": "șansonetă",
    "șansonete": "șansonetă",
    "șansonetei": "șansonetă",
    "șansonetele": "șansonetă",
    "șansonetelor": "șansonetă",
    "șansonetiști": "șansonetist",
    "șansonetiștii": "șansonetist",
    "șansonetiștilor": "șansonetist",
    "șansonetistul": "șansonetist",
    "șansonetistului": "șansonetist",
    "șansonetista": "șansonetistă",
    "șansonetiste": "șansonetistă",
    "șansonetistei": "șansonetistă",
    "șansonetistele": "șansonetistă",
    "șansonetistelor": "șansonetistă",
    "șanțul": "șanț",
    "șanțului": "șanț",
    "șanțuri": "șanț",
    "șanțurile": "șanț",
    "șanțurilor": "șanț",
    "Santei": "Santa",
    "șantagista": "șantagistă",
    "șantagiste": "șantagistă",
    "șantagistei": "șantagistă",
    "șantagistele": "șantagistă",
    "șantagistelor": "șantagistă",
    "șantaje": "șantaj",
    "șantajele": "șantaj",
    "șantajelor": "șantaj",
    "șantajul": "șantaj",
    "șantajului": "șantaj",
    "nemaișantajând": "șantaja",
    "nemaișantajându": "șantaja",
    "neșantajând": "șantaja",
    "neșantajându": "șantaja",
    "șantajă": "șantaja",
    "șantajai": "șantaja",
    "șantajam": "șantaja",
    "șantajăm": "șantaja",
    "șantajând": "șantaja",
    "șantajându": "șantaja",
    "șantajară": "șantaja",
    "șantajarăm": "șantaja",
    "șantajarăți": "șantaja",
    "șantajase": "șantaja",
    "șantajasem": "șantaja",
    "șantajaseră": "șantaja",
    "șantajaserăm": "șantaja",
    "șantajaserăți": "șantaja",
    "șantajaseși": "șantaja",
    "șantajași": "șantaja",
    "șantajat": "șantaja",
    "șantajați": "șantaja",
    "șantajau": "șantaja",
    "șantajează": "șantaja",
    "șantajez": "șantaja",
    "șantajeze": "șantaja",
    "șantajezi": "șantaja",
    "șantajată": "șantajat",
    "șantajate": "șantajat",
    "șantajați": "șantajat",
    "șantajiști": "șantajist",
    "șantajiștii": "șantajist",
    "șantajiștilor": "șantajist",
    "șantajistul": "șantajist",
    "șantajistului": "șantajist",
    "șantajista": "șantajistă",
    "șantajiste": "șantajistă",
    "șantajistei": "șantajistă",
    "șantajistele": "șantajistă",
    "șantajistelor": "șantajistă",
    "santali": "santal",
    "santalii": "santal",
    "santalilor": "santal",
    "santalul": "santal",
    "santalului": "santal",
    "șantiere": "șantier",
    "șantierele": "șantier",
    "șantierelor": "șantier",
    "șantierul": "șantier",
    "șantierului": "șantier",
    "santinela": "santinelă",
    "santinele": "santinelă",
    "santinelei": "santinelă",
    "santinelele": "santinelă",
    "santinelelor": "santinelă",
    "sânziana": "sânziană",
    "sânziene": "sânziană",
    "sânzienei": "sânziană",
    "sânzienele": "sânziană",
    "sânzienelor": "sânziană",
    "sapa": "sapă",
    "sape": "sapă",
    "sapei": "sapă",
    "sapele": "sapă",
    "sapelor": "sapă",
    "nemaisăpând": "săpa",
    "nemaisăpându": "săpa",
    "nesăpând": "săpa",
    "nesăpându": "săpa",
    "sap": "săpa",
    "sapă": "săpa",
    "săpă": "săpa",
    "săpai": "săpa",
    "săpam": "săpa",
    "săpăm": "săpa",
    "săpând": "săpa",
    "săpându": "săpa",
    "săpară": "săpa",
    "săparăm": "săpa",
    "săparăți": "săpa",
    "săpase": "săpa",
    "săpasem": "săpa",
    "săpaseră": "săpa",
    "săpaserăm": "săpa",
    "săpaserăți": "săpa",
    "săpaseși": "săpa",
    "săpași": "săpa",
    "săpat": "săpa",
    "săpați": "săpa",
    "săpau": "săpa",
    "sape": "săpa",
    "sapi": "săpa",
    "săpăliga": "săpăligă",
    "săpăligi": "săpăligă",
    "săpăligii": "săpăligă",
    "săpăligile": "săpăligă",
    "săpăligilor": "săpăligă",
    "săpată": "săpat",
    "săpate": "săpat",
    "săpați": "săpat",
    "săpătura": "săpătură",
    "săpături": "săpătură",
    "săpăturii": "săpătură",
    "săpăturile": "săpătură",
    "săpăturilor": "săpătură",
    "șapca": "șapcă",
    "șepci": "șapcă",
    "șepcii": "șapcă",
    "șepcile": "șapcă",
    "șepcilor": "șapcă",
    "sapiența": "sapiență",
    "sapiențe": "sapiență",
    "sapienței": "sapiență",
    "sapiențele": "sapiență",
    "sapiențelor": "sapiență",
    "șapirografe": "șapirograf",
    "șapirografele": "șapirograf",
    "șapirografelor": "șapirograf",
    "șapirograful": "șapirograf",
    "șapirografului": "șapirograf",
    "saponificarea": "saponificare",
    "saponificări": "saponificare",
    "saponificării": "saponificare",
    "saponificările": "saponificare",
    "saponificărilor": "saponificare",
    "saprofiți": "saprofit",
    "saprofiții": "saprofit",
    "saprofiților": "saprofit",
    "saprofitul": "saprofit",
    "saprofitului": "saprofit",
    "săptămâna": "săptămână",
    "săptămâni": "săptămână",
    "săptămânii": "săptămână",
    "săptămânile": "săptămână",
    "săptămânilor": "săptămână",
    "săptămânala": "săptămânal",
    "săptămânală": "săptămânal",
    "săptămânale": "săptămânal",
    "săptămânalei": "săptămânal",
    "săptămânalele": "săptămânal",
    "săptămânalelor": "săptămânal",
    "săptămânali": "săptămânal",
    "săptămânalii": "săptămânal",
    "săptămânalilor": "săptămânal",
    "săptămânalul": "săptămânal",
    "săptămânalului": "săptămânal",
    "șaptea": "șapte",
    "șaptelea": "șapte",
    "VII": "șapte",
    "șapteșpe": "șaptesprezece",
    "șapteșpea": "șaptesprezece",
    "șapteșpelea": "șaptesprezece",
    "șaptesprezecea": "șaptesprezece",
    "șaptesprezecelea": "șaptesprezece",
    "XVII": "șaptesprezece",
    "șaptesprezecimea": "șaptesprezecime",
    "șaptesprezecimi": "șaptesprezecime",
    "șaptesprezecimii": "șaptesprezecime",
    "șaptesprezecimile": "șaptesprezecime",
    "șaptesprezecimilor": "șaptesprezecime",
    "LXX": "șaptezeci",
    "șaptezecea": "șaptezeci",
    "șaptezecilea": "șaptezeci",
    "săpunul": "săpun",
    "săpunului": "săpun",
    "săpunuri": "săpun",
    "săpunurile": "săpun",
    "săpunurilor": "săpun",
    "săpunari": "săpunar",
    "săpunarii": "săpunar",
    "săpunarilor": "săpunar",
    "săpunarul": "săpunar",
    "săpunarului": "săpunar",
    "săpuneala": "săpuneală",
    "săpuneli": "săpuneală",
    "săpunelii": "săpuneală",
    "săpunelile": "săpuneală",
    "săpunelilor": "săpuneală",
    "nemaisăpunind": "săpuni",
    "nemaisăpunindu": "săpuni",
    "nesăpunind": "săpuni",
    "nesăpunindu": "săpuni",
    "săpunea": "săpuni",
    "săpuneai": "săpuni",
    "săpuneam": "săpuni",
    "săpunească": "săpuni",
    "săpuneați": "săpuni",
    "săpuneau": "săpuni",
    "săpunesc": "săpuni",
    "săpunește": "săpuni",
    "săpunești": "săpuni",
    "săpunii": "săpuni",
    "săpunim": "săpuni",
    "săpunind": "săpuni",
    "săpunindu": "săpuni",
    "săpuniră": "săpuni",
    "săpunirăm": "săpuni",
    "săpunirăți": "săpuni",
    "săpunise": "săpuni",
    "săpunisem": "săpuni",
    "săpuniseră": "săpuni",
    "săpuniserăm": "săpuni",
    "săpuniserăți": "săpuni",
    "săpuniseși": "săpuni",
    "săpuniși": "săpuni",
    "săpunit": "săpuni",
    "săpuniți": "săpuni",
    "săpuniera": "săpunieră",
    "săpuniere": "săpunieră",
    "săpunierei": "săpunieră",
    "săpunierele": "săpunieră",
    "săpunierelor": "săpunieră",
    "săpunită": "săpunit",
    "săpunite": "săpunit",
    "săpuniți": "săpunit",
    "nemaisărând": "săra",
    "nemaisărându": "săra",
    "nesărând": "săra",
    "nesărându": "săra",
    "sără": "săra",
    "sărai": "săra",
    "săram": "săra",
    "sărăm": "săra",
    "sărând": "săra",
    "sărându": "săra",
    "sărară": "săra",
    "sărarăm": "săra",
    "sărarăți": "săra",
    "sărase": "săra",
    "sărasem": "săra",
    "săraseră": "săra",
    "săraserăm": "săra",
    "săraserăți": "săra",
    "săraseși": "săra",
    "sărași": "săra",
    "sărat": "săra",
    "sărați": "săra",
    "sărau": "săra",
    "sărează": "săra",
    "sărez": "săra",
    "săreze": "săra",
    "sărezi": "săra",
    "săraca": "sărac",
    "săracă": "sărac",
    "sărace": "sărac",
    "săracei": "sărac",
    "săracele": "sărac",
    "săracelor": "sărac",
    "săraci": "sărac",
    "săracii": "sărac",
    "săracilor": "sărac",
    "săracul": "sărac",
    "săracului": "sărac",
    "sărăcăcioasa": "sărăcăcios",
    "sărăcăcioasă": "sărăcăcios",
    "sărăcăcioase": "sărăcăcios",
    "sărăcăcioasei": "sărăcăcios",
    "sărăcăcioasele": "sărăcăcios",
    "sărăcăcioaselor": "sărăcăcios",
    "sărăcăcioși": "sărăcăcios",
    "sărăcana": "sărăcan",
    "sărăcană": "sărăcan",
    "sărăcane": "sărăcan",
    "sărăcanei": "sărăcan",
    "sărăcanele": "sărăcan",
    "sărăcanelor": "sărăcan",
    "sărăcani": "sărăcan",
    "sărăcanii": "sărăcan",
    "sărăcanilor": "sărăcan",
    "sărăcanul": "sărăcan",
    "sărăcanului": "sărăcan",
    "nemaisărăcind": "sărăci",
    "nemaisărăcindu": "sărăci",
    "nesărăcind": "sărăci",
    "nesărăcindu": "sărăci",
    "sărăcea": "sărăci",
    "sărăceai": "sărăci",
    "sărăceam": "sărăci",
    "sărăcească": "sărăci",
    "sărăceați": "sărăci",
    "sărăceau": "sărăci",
    "sărăcesc": "sărăci",
    "sărăcește": "sărăci",
    "sărăcești": "sărăci",
    "sărăcii": "sărăci",
    "sărăcim": "sărăci",
    "sărăcind": "sărăci",
    "sărăcindu": "sărăci",
    "sărăciră": "sărăci",
    "sărăcirăm": "sărăci",
    "sărăcirăți": "sărăci",
    "sărăcise": "sărăci",
    "sărăcisem": "sărăci",
    "sărăciseră": "sărăci",
    "sărăciserăm": "sărăci",
    "sărăciserăți": "sărăci",
    "sărăciseși": "sărăci",
    "sărăciși": "sărăci",
    "sărăcit": "sărăci",
    "sărăciți": "sărăci",
    "sărăcia": "sărăcie",
    "sărăciei": "sărăcie",
    "sărăcii": "sărăcie",
    "sărăciile": "sărăcie",
    "sărăciilor": "sărăcie",
    "sărăcimea": "sărăcime",
    "sărăcimi": "sărăcime",
    "sărăcimii": "sărăcime",
    "sărăcimile": "sărăcime",
    "sărăcimilor": "sărăcime",
    "sărăcirea": "sărăcire",
    "sărăciri": "sărăcire",
    "sărăcirii": "sărăcire",
    "sărăcirile": "sărăcire",
    "sărăcirilor": "sărăcire",
    "sărăcită": "sărăcit",
    "sărăcite": "sărăcit",
    "sărăciți": "sărăcit",
    "șarada": "șaradă",
    "șarade": "șaradă",
    "șaradei": "șaradă",
    "șaradele": "șaradă",
    "șaradelor": "șaradă",
    "sarafane": "sarafan",
    "sarafanele": "sarafan",
    "sarafanelor": "sarafan",
    "sarafanul": "sarafan",
    "sarafanului": "sarafan",
    "sarailia": "sarailie",
    "sarailiei": "sarailie",
    "sarailii": "sarailie",
    "sarailiile": "sarailie",
    "sarailiilor": "sarailie",
    "nemaisaramurând": "saramura",
    "nemaisaramurându": "saramura",
    "nesaramurând": "saramura",
    "nesaramurându": "saramura",
    "saramură": "saramura",
    "saramurai": "saramura",
    "saramuram": "saramura",
    "saramurăm": "saramura",
    "saramurând": "saramura",
    "saramurându": "saramura",
    "saramurară": "saramura",
    "saramurarăm": "saramura",
    "saramurarăți": "saramura",
    "saramurase": "saramura",
    "saramurasem": "saramura",
    "saramuraseră": "saramura",
    "saramuraserăm": "saramura",
    "saramuraserăți": "saramura",
    "saramuraseși": "saramura",
    "saramurași": "saramura",
    "saramurat": "saramura",
    "saramurați": "saramura",
    "saramurau": "saramura",
    "saramurează": "saramura",
    "saramurez": "saramura",
    "saramureze": "saramura",
    "saramurezi": "saramura",
    "saramura": "saramură",
    "saramuri": "saramură",
    "saramurii": "saramură",
    "saramurile": "saramură",
    "saramurilor": "saramură",
    "saramurată": "saramurat",
    "saramurate": "saramurat",
    "saramurați": "saramurat",
    "sărăntoci": "sărăntoc",
    "sărăntocii": "sărăntoc",
    "sărăntocilor": "sărăntoc",
    "sărăntocul": "sărăntoc",
    "sărăntocului": "sărăntoc",
    "sărari": "sărar",
    "sărarii": "sărar",
    "sărarilor": "sărar",
    "sărarul": "sărar",
    "sărarului": "sărar",
    "sărarea": "sărare",
    "sărăria": "sărărie",
    "sărăriei": "sărărie",
    "sărării": "sărărie",
    "sărăriile": "sărărie",
    "sărăriilor": "sărărie",
    "sărata": "sărat",
    "sărată": "sărat",
    "sărate": "sărat",
    "săratei": "sărat",
    "săratele": "sărat",
    "săratelor": "sărat",
    "sărați": "sărat",
    "sărații": "sărat",
    "săraților": "sărat",
    "săratul": "sărat",
    "săratului": "sărat",
    "sărători": "sărător",
    "sărătorii": "sărător",
    "sărătorilor": "sărător",
    "sărătorul": "sărător",
    "sărătorului": "sărător",
    "sarazini": "sarazin",
    "sarazinii": "sarazin",
    "sarazinilor": "sarazin",
    "sarazinul": "sarazin",
    "sarazinului": "sarazin",
    "sarazina": "sarazină",
    "sarazine": "sarazină",
    "sarazinei": "sarazină",
    "sarazinele": "sarazină",
    "sarazinelor": "sarazină",
    "sârbi": "sârb",
    "sârbii": "sârb",
    "sârbilor": "sârb",
    "sârbul": "sârb",
    "sârbului": "sârb",
    "sârba": "sârbă",
    "sârbe": "sârbă",
    "sârbei": "sârbă",
    "sârbele": "sârbă",
    "sârbelor": "sârbă",
    "sărbătoarea": "sărbătoare",
    "sărbători": "sărbătoare",
    "sărbătorii": "sărbătoare",
    "sărbătorile": "sărbătoare",
    "sărbătorilor": "sărbătoare",
    "sărbătoreasca": "sărbătoresc",
    "sărbătorească": "sărbătoresc",
    "sărbătorescul": "sărbătoresc",
    "sărbătorescului": "sărbătoresc",
    "sărbătorești": "sărbătoresc",
    "sărbătoreștii": "sărbătoresc",
    "sărbătoreștile": "sărbătoresc",
    "sărbătoreștilor": "sărbătoresc",
    "nemaisărbătorind": "sărbători",
    "nemaisărbătorindu": "sărbători",
    "nesărbătorind": "sărbători",
    "nesărbătorindu": "sărbători",
    "sărbătorea": "sărbători",
    "sărbătoreai": "sărbători",
    "sărbătoream": "sărbători",
    "sărbătorească": "sărbători",
    "sărbătoreați": "sărbători",
    "sărbătoreau": "sărbători",
    "sărbătoresc": "sărbători",
    "sărbătorește": "sărbători",
    "sărbătorești": "sărbători",
    "sărbătorii": "sărbători",
    "sărbătorim": "sărbători",
    "sărbătorind": "sărbători",
    "sărbătorindu": "sărbători",
    "sărbătoriră": "sărbători",
    "sărbătorirăm": "sărbători",
    "sărbătorirăți": "sărbători",
    "sărbătorise": "sărbători",
    "sărbătorisem": "sărbători",
    "sărbătoriseră": "sărbători",
    "sărbătoriserăm": "sărbători",
    "sărbătoriserăți": "sărbători",
    "sărbătoriseși": "sărbători",
    "sărbătoriși": "sărbători",
    "sărbătorit": "sărbători",
    "sărbătoriți": "sărbători",
    "sărbătorirea": "sărbătorire",
    "sărbătoriri": "sărbătorire",
    "sărbătoririi": "sărbătorire",
    "sărbătoririle": "sărbătorire",
    "sărbătoririlor": "sărbătorire",
    "sărbătorită": "sărbătorit",
    "sărbătorite": "sărbătorit",
    "sărbătoriți": "sărbătorit",
    "sărbătoriții": "sărbătorit",
    "sărbătoriților": "sărbătorit",
    "sărbătoritul": "sărbătorit",
    "sărbătoritului": "sărbătorit",
    "sârbisme": "sârbism",
    "sârbismele": "sârbism",
    "sârbismelor": "sârbism",
    "sârbismul": "sârbism",
    "sârbismului": "sârbism",
    "sârboaica": "sârboaică",
    "sârboaice": "sârboaică",
    "sârboaicei": "sârboaică",
    "sârboaicele": "sârboaică",
    "sârboaicelor": "sârboaică",
    "sarcasme": "sarcasm",
    "sarcasmele": "sarcasm",
    "sarcasmelor": "sarcasm",
    "sarcasmul": "sarcasm",
    "sarcasmului": "sarcasm",
    "sarcastica": "sarcastic",
    "sarcastică": "sarcastic",
    "sarcastice": "sarcastic",
    "sarcasticei": "sarcastic",
    "sarcasticele": "sarcastic",
    "sarcasticelor": "sarcastic",
    "sarcastici": "sarcastic",
    "sarcasticii": "sarcastic",
    "sarcasticilor": "sarcastic",
    "sarcasticul": "sarcastic",
    "sarcasticului": "sarcastic",
    "sarcina": "sarcină",
    "sarcini": "sarcină",
    "sarcinii": "sarcină",
    "sarcinile": "sarcină",
    "sarcinilor": "sarcină",
    "sarcofage": "sarcofag",
    "sarcofagele": "sarcofag",
    "sarcofagelor": "sarcofag",
    "sarcofagul": "sarcofag",
    "sarcofagului": "sarcofag",
    "sarcoame": "sarcom",
    "sarcoamele": "sarcom",
    "sarcoamelor": "sarcom",
    "sarcomul": "sarcom",
    "sarcomului": "sarcom",
    "sarcoplasma": "sarcoplasmă",
    "sarcoplasme": "sarcoplasmă",
    "sarcoplasmei": "sarcoplasmă",
    "sarcoplasmele": "sarcoplasmă",
    "sarcoplasmelor": "sarcoplasmă",
    "sarcopți": "sarcopt",
    "sarcopții": "sarcopt",
    "sarcopților": "sarcopt",
    "sarcoptul": "sarcopt",
    "sarcoptului": "sarcopt",
    "sardeaua": "sardea",
    "sardele": "sardea",
    "sardelei": "sardea",
    "sardelele": "sardea",
    "sardelelor": "sardea",
    "sardeluța": "sardeluță",
    "sardeluțe": "sardeluță",
    "sardeluței": "sardeluță",
    "sardeluțele": "sardeluță",
    "sardeluțelor": "sardeluță",
    "sardonica": "sardonic",
    "sardonică": "sardonic",
    "sardonice": "sardonic",
    "sardonicei": "sardonic",
    "sardonicele": "sardonic",
    "sardonicelor": "sardonic",
    "sardonici": "sardonic",
    "sardonicii": "sardonic",
    "sardonicilor": "sardonic",
    "sardonicul": "sardonic",
    "sardonicului": "sardonic",
    "sarea": "sare",
    "sări": "sare",
    "sării": "sare",
    "săruri": "sare",
    "sărurile": "sare",
    "sărurilor": "sare",
    "șareta": "șaretă",
    "șarete": "șaretă",
    "șaretei": "șaretă",
    "șaretele": "șaretă",
    "șaretelor": "șaretă",
    "sârgul": "sârg",
    "sârgului": "sârg",
    "sârguri": "sârg",
    "sârgurile": "sârg",
    "sârgurilor": "sârg",
    "nemaisârguind": "sârgui",
    "nemaisârguindu": "sârgui",
    "nesârguind": "sârgui",
    "nesârguindu": "sârgui",
    "sârguia": "sârgui",
    "sârguiai": "sârgui",
    "sârguiam": "sârgui",
    "sârguiască": "sârgui",
    "sârguiați": "sârgui",
    "sârguiau": "sârgui",
    "sârguiesc": "sârgui",
    "sârguiește": "sârgui",
    "sârguiești": "sârgui",
    "sârguii": "sârgui",
    "sârguim": "sârgui",
    "sârguind": "sârgui",
    "sârguindu": "sârgui",
    "sârguiră": "sârgui",
    "sârguirăm": "sârgui",
    "sârguirăți": "sârgui",
    "sârguise": "sârgui",
    "sârguisem": "sârgui",
    "sârguiseră": "sârgui",
    "sârguiserăm": "sârgui",
    "sârguiserăți": "sârgui",
    "sârguiseși": "sârgui",
    "sârguiși": "sârgui",
    "sârguit": "sârgui",
    "sârguiți": "sârgui",
    "sârguincioasa": "sârguincios",
    "sârguincioasă": "sârguincios",
    "sârguincioase": "sârguincios",
    "sârguincioasei": "sârguincios",
    "sârguincioasele": "sârguincios",
    "sârguincioaselor": "sârguincios",
    "sârguincioși": "sârguincios",
    "sârguincioșii": "sârguincios",
    "sârguincioșilor": "sârguincios",
    "sârguinciosul": "sârguincios",
    "sârguinciosului": "sârguincios",
    "sârguința": "sârguință",
    "sârguințe": "sârguință",
    "sârguinței": "sârguință",
    "sârguințele": "sârguință",
    "sârguințelor": "sârguință",
    "sârguită": "sârguit",
    "sârguite": "sârguit",
    "sârguiți": "sârguit",
    "nemaisărind": "sări",
    "nemaisărindu": "sări",
    "nesărind": "sări",
    "nesărindu": "sări",
    "sar": "sări",
    "sară": "sări",
    "sare": "sări",
    "sărea": "sări",
    "săreai": "sări",
    "săream": "sări",
    "săreați": "sări",
    "săreau": "sări",
    "sari": "sări",
    "sării": "sări",
    "sărim": "sări",
    "sărind": "sări",
    "sărindu": "sări",
    "săriră": "sări",
    "sărirăm": "sări",
    "sărirăți": "sări",
    "sărise": "sări",
    "sărisem": "sări",
    "săriseră": "sări",
    "săriserăm": "sări",
    "săriserăți": "sări",
    "săriseși": "sări",
    "săriși": "sări",
    "sărit": "sări",
    "săriți": "sări",
    "sarica": "sarică",
    "sarici": "sarică",
    "saricii": "sarică",
    "saricile": "sarică",
    "saricilor": "sarică",
    "sărindare": "sărindar",
    "sărindarele": "sărindar",
    "sărindarelor": "sărindar",
    "sărindarul": "sărindar",
    "sărindarului": "sărindar",
    "sărită": "sărit",
    "sărite": "sărit",
    "săriți": "sărit",
    "săritori": "săritor",
    "săritorii": "săritor",
    "săritorilor": "săritor",
    "săritorul": "săritor",
    "săritorului": "săritor",
    "săritura": "săritură",
    "sărituri": "săritură",
    "săriturii": "săritură",
    "săriturile": "săritură",
    "săriturilor": "săritură",
    "nemaișarjând": "șarja",
    "nemaișarjându": "șarja",
    "neșarjând": "șarja",
    "neșarjându": "șarja",
    "șarjă": "șarja",
    "șarjai": "șarja",
    "șarjam": "șarja",
    "șarjăm": "șarja",
    "șarjând": "șarja",
    "șarjându": "șarja",
    "șarjară": "șarja",
    "șarjarăm": "șarja",
    "șarjarăți": "șarja",
    "șarjase": "șarja",
    "șarjasem": "șarja",
    "șarjaseră": "șarja",
    "șarjaserăm": "șarja",
    "șarjaserăți": "șarja",
    "șarjaseși": "șarja",
    "șarjași": "șarja",
    "șarjat": "șarja",
    "șarjați": "șarja",
    "șarjau": "șarja",
    "șarjează": "șarja",
    "șarjez": "șarja",
    "șarjeze": "șarja",
    "șarjezi": "șarja",
    "șarja": "șarjă",
    "șarje": "șarjă",
    "șarjei": "șarjă",
    "șarjele": "șarjă",
    "șarjelor": "șarjă",
    "șarjarea": "șarjare",
    "șarjareo": "șarjare",
    "șarjări": "șarjare",
    "șarjării": "șarjare",
    "șarjările": "șarjare",
    "șarjărilor": "șarjare",
    "șarjată": "șarjat",
    "șarjate": "șarjat",
    "șarjați": "șarjat",
    "șarlatani": "șarlatan",
    "șarlatanii": "șarlatan",
    "șarlatanilor": "șarlatan",
    "șarlatanul": "șarlatan",
    "șarlatanului": "șarlatan",
    "șarlatania": "șarlatanie",
    "șarlataniei": "șarlatanie",
    "șarlatanii": "șarlatanie",
    "șarlataniile": "șarlatanie",
    "șarlataniilor": "șarlatanie",
    "șarlota": "șarlotă",
    "șarlote": "șarlotă",
    "șarlotei": "șarlotă",
    "șarlotele": "șarlotă",
    "șarlotelor": "șarlotă",
    "șarmul": "șarm",
    "șarmului": "șarm",
    "șarmuri": "șarm",
    "șarmurile": "șarm",
    "șarmurilor": "șarm",
    "sarmale": "sarma",
    "sarmalei": "sarma",
    "sarmalele": "sarma",
    "sarmalelor": "sarma",
    "sarmaua": "sarma",
    "sârma": "sârmă",
    "sârme": "sârmă",
    "sârmei": "sârmă",
    "sârmele": "sârmă",
    "sârmelor": "sârmă",
    "sărmana": "sărman",
    "sărmană": "sărman",
    "sărmane": "sărman",
    "sărmanei": "sărman",
    "sărmanele": "sărman",
    "sărmanelor": "sărman",
    "sărmani": "sărman",
    "sărmanii": "sărman",
    "sărmanilor": "sărman",
    "sărmanul": "sărman",
    "sărmanului": "sărman",
    "sarmațianul": "sarmațian",
    "sarmațianului": "sarmațian",
    "sarmațieni": "sarmațian",
    "sarmațienii": "sarmațian",
    "sarmațienilor": "sarmațian",
    "sârmulița": "sârmuliță",
    "sârmulițe": "sârmuliță",
    "sârmuliței": "sârmuliță",
    "sârmulițele": "sârmuliță",
    "sârmulițelor": "sârmuliță",
    "șarniera": "șarnieră",
    "șarniere": "șarnieră",
    "șarnierei": "șarnieră",
    "șarnierele": "șarnieră",
    "șarnierelor": "șarnieră",
    "sarongul": "sarong",
    "sarongului": "sarong",
    "saronguri": "sarong",
    "sarongurile": "sarong",
    "sarongurilor": "sarong",
    "șarpanta": "șarpantă",
    "șarpante": "șarpantă",
    "șarpantei": "șarpantă",
    "șarpantele": "șarpantă",
    "șarpantelor": "șarpantă",
    "șarpele": "șarpe",
    "șarpelui": "șarpe",
    "șerpi": "șarpe",
    "șerpii": "șarpe",
    "șerpilor": "șarpe",
    "sartul": "sart",
    "sartului": "sart",
    "sarturi": "sart",
    "sarturile": "sart",
    "sarturilor": "sart",
    "sărutul": "sărut",
    "sărutului": "sărut",
    "săruturi": "sărut",
    "săruturile": "sărut",
    "săruturilor": "sărut",
    "nemaisărutând": "săruta",
    "nemaisărutându": "săruta",
    "nesărutând": "săruta",
    "nesărutându": "săruta",
    "sărut": "săruta",
    "sărută": "săruta",
    "sărutai": "săruta",
    "sărutam": "săruta",
    "sărutăm": "săruta",
    "sărutând": "săruta",
    "sărutându": "săruta",
    "sărutară": "săruta",
    "sărutarăm": "săruta",
    "sărutarăți": "săruta",
    "sărutase": "săruta",
    "sărutasem": "săruta",
    "sărutaseră": "săruta",
    "sărutaserăm": "săruta",
    "sărutaserăți": "săruta",
    "sărutaseși": "săruta",
    "sărutași": "săruta",
    "sărutat": "săruta",
    "sărutați": "săruta",
    "sărutau": "săruta",
    "sărute": "săruta",
    "săruți": "săruta",
    "sărutarea": "sărutare",
    "sărutareo": "sărutare",
    "sărutări": "sărutare",
    "sărutării": "sărutare",
    "sărutările": "sărutare",
    "sărutărilor": "sărutare",
    "săruta": "sărutat",
    "sărutată": "sărutat",
    "sărutate": "sărutat",
    "sărutatei": "sărutat",
    "sărutatele": "sărutat",
    "sărutatelor": "sărutat",
    "sărutați": "sărutat",
    "sărutații": "sărutat",
    "sărutaților": "sărutat",
    "sărutato": "sărutat",
    "sărutatul": "sărutat",
    "sărutatule": "sărutat",
    "sărutatului": "sărutat",
    "sărute": "sărutat",
    "sași": "sas",
    "sașii": "sas",
    "sașilor": "sas",
    "sasul": "sas",
    "sasului": "sas",
    "nemaisâsâind": "sâsâi",
    "nemaisâsâindu": "sâsâi",
    "nesâsâind": "sâsâi",
    "nesâsâindu": "sâsâi",
    "sâsâia": "sâsâi",
    "sâsâiai": "sâsâi",
    "sâsâiam": "sâsâi",
    "sâsâiați": "sâsâi",
    "sâsâiau": "sâsâi",
    "sâsâie": "sâsâi",
    "sâsâii": "sâsâi",
    "sâsâim": "sâsâi",
    "sâsâind": "sâsâi",
    "sâsâindu": "sâsâi",
    "sâsâiră": "sâsâi",
    "sâsâirăm": "sâsâi",
    "sâsâirăți": "sâsâi",
    "sâsâise": "sâsâi",
    "sâsâisem": "sâsâi",
    "sâsâiseră": "sâsâi",
    "sâsâiserăm": "sâsâi",
    "sâsâiserăți": "sâsâi",
    "sâsâiseși": "sâsâi",
    "sâsâiși": "sâsâi",
    "sâsâit": "sâsâi",
    "sâsâiți": "sâsâi",
    "sâsâită": "sâsâit",
    "sâsâite": "sâsâit",
    "sâsâiți": "sâsâit",
    "șasea": "șase",
    "șaselea": "șase",
    "VI": "șase",
    "săseasca": "săsesc",
    "săsească": "săsesc",
    "săsescul": "săsesc",
    "săsescului": "săsesc",
    "săsești": "săsesc",
    "săseștii": "săsesc",
    "săseștile": "săsesc",
    "săseștilor": "săsesc",
    "sașia": "sașiu",
    "sașie": "sașiu",
    "sașiei": "sașiu",
    "sașii": "sașiu",
    "sașiii": "sașiu",
    "sașiile": "sașiu",
    "sașiilor": "sașiu",
    "sașiul": "sașiu",
    "sașiului": "sașiu",
    "șasiul": "șasiu",
    "șasiului": "șasiu",
    "șasiuri": "șasiu",
    "șasiurile": "șasiu",
    "șasiurilor": "șasiu",
    "sate": "sat",
    "satele": "sat",
    "satelor": "sat",
    "satul": "sat",
    "satului": "sat",
    "satana": "satană",
    "satane": "satană",
    "satanei": "satană",
    "satanele": "satană",
    "satanelor": "satană",
    "satanizarea": "satanizare",
    "satanizări": "satanizare",
    "satanizării": "satanizare",
    "satanizările": "satanizare",
    "satanizărilor": "satanizare",
    "satâre": "satâr",
    "satârele": "satâr",
    "satârelor": "satâr",
    "satârul": "satâr",
    "satârului": "satâr",
    "săteanul": "sătean",
    "săteanului": "sătean",
    "săteni": "sătean",
    "sătenii": "sătean",
    "sătenilor": "sătean",
    "săteanca": "săteancă",
    "sătence": "săteancă",
    "sătencei": "săteancă",
    "sătencele": "săteancă",
    "sătencelor": "săteancă",
    "sateliți": "satelit",
    "sateliții": "satelit",
    "sateliților": "satelit",
    "satelitul": "satelit",
    "satelitului": "satelit",
    "șatena": "șaten",
    "șatenă": "șaten",
    "șatene": "șaten",
    "șatenei": "șaten",
    "șatenele": "șaten",
    "șatenelor": "șaten",
    "șateni": "șaten",
    "șatenii": "șaten",
    "șatenilor": "șaten",
    "șatenul": "șaten",
    "șatenului": "șaten",
    "săteasca": "sătesc",
    "sătească": "sătesc",
    "sătescul": "sătesc",
    "sătescului": "sătesc",
    "sătești": "sătesc",
    "săteștii": "sătesc",
    "săteștile": "sătesc",
    "săteștilor": "sătesc",
    "sațietatea": "sațietate",
    "sațietăți": "sațietate",
    "sațietății": "sațietate",
    "sațietățile": "sațietate",
    "sațietăților": "sațietate",
    "satinul": "satin",
    "satinului": "satin",
    "nemaisatinând": "satina",
    "nemaisatinându": "satina",
    "nesatinând": "satina",
    "nesatinându": "satina",
    "satină": "satina",
    "satinai": "satina",
    "satinam": "satina",
    "satinăm": "satina",
    "satinând": "satina",
    "satinându": "satina",
    "satinară": "satina",
    "satinarăm": "satina",
    "satinarăți": "satina",
    "satinase": "satina",
    "satinasem": "satina",
    "satinaseră": "satina",
    "satinaserăm": "satina",
    "satinaserăți": "satina",
    "satinaseși": "satina",
    "satinași": "satina",
    "satinat": "satina",
    "satinați": "satina",
    "satinau": "satina",
    "satinează": "satina",
    "satinez": "satina",
    "satineze": "satina",
    "satinezi": "satina",
    "satinată": "satinat",
    "satinate": "satinat",
    "satinați": "satinat",
    "sățioasa": "sățios",
    "sățioasă": "sățios",
    "sățioase": "sățios",
    "sățioasei": "sățios",
    "sățioasele": "sățios",
    "sățioaselor": "sățios",
    "sățioși": "sățios",
    "sățioșii": "sățios",
    "sățioșilor": "sățios",
    "sățiosul": "sățios",
    "sățiosului": "sățios",
    "satiri": "satir",
    "satirii": "satir",
    "satirilor": "satir",
    "satirul": "satir",
    "satirului": "satir",
    "satira": "satiră",
    "satire": "satiră",
    "satirei": "satiră",
    "satirele": "satiră",
    "satirelor": "satiră",
    "nemaisatirizând": "satiriza",
    "nemaisatirizându": "satiriza",
    "nesatirizând": "satiriza",
    "nesatirizându": "satiriza",
    "satiriză": "satiriza",
    "satirizai": "satiriza",
    "satirizam": "satiriza",
    "satirizăm": "satiriza",
    "satirizând": "satiriza",
    "satirizându": "satiriza",
    "satirizară": "satiriza",
    "satirizarăm": "satiriza",
    "satirizarăți": "satiriza",
    "satirizase": "satiriza",
    "satirizasem": "satiriza",
    "satirizaseră": "satiriza",
    "satirizaserăm": "satiriza",
    "satirizaserăți": "satiriza",
    "satirizaseși": "satiriza",
    "satirizași": "satiriza",
    "satirizat": "satiriza",
    "satirizați": "satiriza",
    "satirizau": "satiriza",
    "satirizează": "satiriza",
    "satirizez": "satiriza",
    "satirizeze": "satiriza",
    "satirizezi": "satiriza",
    "satirizată": "satirizat",
    "satirizate": "satirizat",
    "satirizați": "satirizat",
    "satisfăcătoare": "satisfăcător",
    "satisfăcătoarea": "satisfăcător",
    "satisfăcătoarei": "satisfăcător",
    "satisfăcătoarele": "satisfăcător",
    "satisfăcătoarelor": "satisfăcător",
    "satisfăcători": "satisfăcător",
    "satisfăcătorii": "satisfăcător",
    "satisfăcătorilor": "satisfăcător",
    "satisfăcătorul": "satisfăcător",
    "satisfăcătorului": "satisfăcător",
    "nemaisatisfăcând": "satisface",
    "nemaisatisfăcându": "satisface",
    "nesatisfăcând": "satisface",
    "nesatisfăcându": "satisface",
    "satisfă": "satisface",
    "satisfac": "satisface",
    "satisfacă": "satisface",
    "satisfăcând": "satisface",
    "satisfăcându": "satisface",
    "satisfăcea": "satisface",
    "satisfăceai": "satisface",
    "satisfăceam": "satisface",
    "satisfăceați": "satisface",
    "satisfăceau": "satisface",
    "satisfacem": "satisface",
    "satisfaceți": "satisface",
    "satisfaci": "satisface",
    "satisfăcu": "satisface",
    "satisfăcui": "satisface",
    "satisfăcură": "satisface",
    "satisfăcurăm": "satisface",
    "satisfăcurăți": "satisface",
    "satisfăcuse": "satisface",
    "satisfăcusem": "satisface",
    "satisfăcuseră": "satisface",
    "satisfăcuserăm": "satisface",
    "satisfăcuserăți": "satisface",
    "satisfăcuseși": "satisface",
    "satisfăcuși": "satisface",
    "satisfăcut": "satisface",
    "satisfacerea": "satisfacere",
    "satisfacereo": "satisfacere",
    "satisfaceri": "satisfacere",
    "satisfacerii": "satisfacere",
    "satisfacerile": "satisfacere",
    "satisfacerilor": "satisfacere",
    "satisfacția": "satisfacție",
    "satisfacției": "satisfacție",
    "satisfacții": "satisfacție",
    "satisfacțiile": "satisfacție",
    "satisfacțiilor": "satisfacție",
    "satisfăcută": "satisfăcut",
    "satisfăcute": "satisfăcut",
    "satisfăcuți": "satisfăcut",
    "sătmăreana": "sătmărean",
    "sătmăreană": "sătmărean",
    "sătmăreanul": "sătmărean",
    "sătmăreanului": "sătmărean",
    "sătmărene": "sătmărean",
    "sătmărenei": "sătmărean",
    "sătmărenele": "sătmărean",
    "sătmărenelor": "sătmărean",
    "sătmăreni": "sătmărean",
    "sătmărenii": "sătmărean",
    "sătmărenilor": "sătmărean",
    "sătmăreanca": "sătmăreancă",
    "sătmărence": "sătmăreancă",
    "sătmărencei": "sătmăreancă",
    "sătmărencele": "sătmăreancă",
    "sătmărencelor": "sătmăreancă",
    "șatra": "șatră",
    "șatre": "șatră",
    "șatrei": "șatră",
    "șatrele": "șatră",
    "șatrelor": "șatră",
    "satrapi": "satrap",
    "satrapii": "satrap",
    "satrapilor": "satrap",
    "satrapul": "satrap",
    "satrapului": "satrap",
    "satrapia": "satrapie",
    "satrapiei": "satrapie",
    "satrapii": "satrapie",
    "satrapiile": "satrapie",
    "satrapiilor": "satrapie",
    "șătrari": "șătrar",
    "șătrarii": "șătrar",
    "șătrarilor": "șătrar",
    "șătrarul": "șătrar",
    "șătrarului": "șătrar",
    "sătui": "sătul",
    "sătuii": "sătul",
    "sătuilor": "sătul",
    "sătula": "sătul",
    "sătulă": "sătul",
    "sătule": "sătul",
    "sătulei": "sătul",
    "sătulele": "sătul",
    "sătulelor": "sătul",
    "sătulul": "sătul",
    "sătulului": "sătul",
    "nemaisaturând": "satura",
    "nemaisaturându": "satura",
    "nesaturând": "satura",
    "nesaturându": "satura",
    "satură": "satura",
    "saturai": "satura",
    "saturam": "satura",
    "saturăm": "satura",
    "saturând": "satura",
    "saturându": "satura",
    "saturară": "satura",
    "saturarăm": "satura",
    "saturarăți": "satura",
    "saturase": "satura",
    "saturasem": "satura",
    "saturaseră": "satura",
    "saturaserăm": "satura",
    "saturaserăți": "satura",
    "saturaseși": "satura",
    "saturași": "satura",
    "saturat": "satura",
    "saturați": "satura",
    "saturau": "satura",
    "saturează": "satura",
    "saturez": "satura",
    "satureze": "satura",
    "saturezi": "satura",
    "nemaisăturând": "sătura",
    "nemaisăturându": "sătura",
    "nesăturând": "sătura",
    "nesăturându": "sătura",
    "satur": "sătura",
    "satură": "sătura",
    "sătură": "sătura",
    "săturai": "sătura",
    "săturam": "sătura",
    "săturăm": "sătura",
    "săturând": "sătura",
    "săturându": "sătura",
    "săturară": "sătura",
    "săturarăm": "sătura",
    "săturarăți": "sătura",
    "săturase": "sătura",
    "săturasem": "sătura",
    "săturaseră": "sătura",
    "săturaserăm": "sătura",
    "săturaserăți": "sătura",
    "săturaseși": "sătura",
    "săturași": "sătura",
    "săturat": "sătura",
    "săturați": "sătura",
    "săturau": "sătura",
    "sature": "sătura",
    "saturi": "sătura",
    "săturarea": "săturare",
    "săturări": "săturare",
    "săturării": "săturare",
    "săturările": "săturare",
    "săturărilor": "săturare",
    "saturată": "saturat",
    "saturate": "saturat",
    "saturați": "saturat",
    "săturată": "săturat",
    "săturate": "săturat",
    "săturați": "săturat",
    "saturația": "saturație",
    "saturației": "saturație",
    "saturații": "saturație",
    "saturațiile": "saturație",
    "saturațiilor": "saturație",
    "saturatori": "saturator",
    "saturatorii": "saturator",
    "saturatorilor": "saturator",
    "saturatorul": "saturator",
    "saturatorului": "saturator",
    "saturnismul": "saturnism",
    "saturnismului": "saturnism",
    "au": "sau",
    "sa": "său",
    "săi": "său",
    "sale": "său",
    "șăuași": "șăuaș",
    "șăuașii": "șăuaș",
    "șăuașilor": "șăuaș",
    "șăuașul": "șăuaș",
    "șăuașului": "șăuaș",
    "savana": "savană",
    "savane": "savană",
    "savanei": "savană",
    "savanele": "savană",
    "savanelor": "savană",
    "savanta": "savant",
    "savantă": "savant",
    "savante": "savant",
    "savantei": "savant",
    "savantele": "savant",
    "savantelor": "savant",
    "savanți": "savant",
    "savanții": "savant",
    "savanților": "savant",
    "savantul": "savant",
    "savantului": "savant",
    "savarina": "savarină",
    "savarine": "savarină",
    "savarinei": "savarină",
    "savarinele": "savarină",
    "savarinelor": "savarină",
    "nemaisăvârșind": "săvârși",
    "nemaisăvârșindu": "săvârși",
    "nesăvârșind": "săvârși",
    "nesăvârșindu": "săvârși",
    "săvârșea": "săvârși",
    "săvârșeai": "săvârși",
    "săvârșeam": "săvârși",
    "săvârșească": "săvârși",
    "săvârșeați": "săvârși",
    "săvârșeau": "săvârși",
    "săvârșesc": "săvârși",
    "săvârșește": "săvârși",
    "săvârșești": "săvârși",
    "săvârșii": "săvârși",
    "săvârșim": "săvârși",
    "săvârșind": "săvârși",
    "săvârșindu": "săvârși",
    "săvârșiră": "săvârși",
    "săvârșirăm": "săvârși",
    "săvârșirăți": "săvârși",
    "săvârșise": "săvârși",
    "săvârșisem": "săvârși",
    "săvârșiseră": "săvârși",
    "săvârșiserăm": "săvârși",
    "săvârșiserăți": "săvârși",
    "săvârșiseși": "săvârși",
    "săvârșiși": "săvârși",
    "săvârșit": "săvârși",
    "săvârșiți": "săvârși",
    "săvârșirea": "săvârșire",
    "săvârșiri": "săvârșire",
    "săvârșirii": "săvârșire",
    "săvârșirile": "săvârșire",
    "săvârșirilor": "săvârșire",
    "săvârșită": "săvârșit",
    "săvârșite": "săvârșit",
    "săvârșiți": "săvârșit",
    "savoarea": "savoare",
    "nemaisavurând": "savura",
    "nemaisavurându": "savura",
    "nesavurând": "savura",
    "nesavurându": "savura",
    "savură": "savura",
    "savurai": "savura",
    "savuram": "savura",
    "savurăm": "savura",
    "savurând": "savura",
    "savurându": "savura",
    "savurară": "savura",
    "savurarăm": "savura",
    "savurarăți": "savura",
    "savurase": "savura",
    "savurasem": "savura",
    "savuraseră": "savura",
    "savuraserăm": "savura",
    "savuraserăți": "savura",
    "savuraseși": "savura",
    "savurași": "savura",
    "savurat": "savura",
    "savurați": "savura",
    "savurau": "savura",
    "savurează": "savura",
    "savurez": "savura",
    "savureze": "savura",
    "savurezi": "savura",
    "savurată": "savurat",
    "savurate": "savurat",
    "savurați": "savurat",
    "saxofoane": "saxofon",
    "saxofoanele": "saxofon",
    "saxofoanelor": "saxofon",
    "saxofonul": "saxofon",
    "saxofonului": "saxofon",
    "saxofoniști": "saxofonist",
    "saxofoniștii": "saxofonist",
    "saxofoniștilor": "saxofonist",
    "saxofonistul": "saxofonist",
    "saxofonistului": "saxofonist",
    "saxoni": "saxon",
    "saxonii": "saxon",
    "saxonilor": "saxon",
    "saxonul": "saxon",
    "saxonului": "saxon",
    "Saxoniei": "Saxonia",
    "scabia": "scabie",
    "scabiei": "scabie",
    "scabii": "scabie",
    "scabiile": "scabie",
    "scabiilor": "scabie",
    "scabroasa": "scabros",
    "scabroasă": "scabros",
    "scabroase": "scabros",
    "scabroasei": "scabros",
    "scabroasele": "scabros",
    "scabroaselor": "scabros",
    "scabroși": "scabros",
    "scabroșii": "scabros",
    "scabroșilor": "scabros",
    "scabrosul": "scabros",
    "scabrosului": "scabros",
    "nemaiscăzând": "scădea",
    "nemaiscăzându": "scădea",
    "nescăzând": "scădea",
    "nescăzându": "scădea",
    "scad": "scădea",
    "scadă": "scădea",
    "scade": "scădea",
    "scădeai": "scădea",
    "scădeam": "scădea",
    "scădeați": "scădea",
    "scădeau": "scădea",
    "scădem": "scădea",
    "scădeți": "scădea",
    "scăzând": "scădea",
    "scăzându": "scădea",
    "scazi": "scădea",
    "scăzu": "scădea",
    "scăzui": "scădea",
    "scăzură": "scădea",
    "scăzurăm": "scădea",
    "scăzurăți": "scădea",
    "scăzuse": "scădea",
    "scăzusem": "scădea",
    "scăzuseră": "scădea",
    "scăzuserăm": "scădea",
    "scăzuserăți": "scădea",
    "scăzuseși": "scădea",
    "scăzuși": "scădea",
    "scăzut": "scădea",
    "scadenta": "scadent",
    "scadentă": "scadent",
    "scadente": "scadent",
    "scadentei": "scadent",
    "scadentele": "scadent",
    "scadentelor": "scadent",
    "scadenți": "scadent",
    "scadenții": "scadent",
    "scadenților": "scadent",
    "scadentul": "scadent",
    "scadentului": "scadent",
    "scadența": "scadență",
    "scadențe": "scadență",
    "scadenței": "scadență",
    "scadențele": "scadență",
    "scadențelor": "scadență",
    "scăderea": "scădere",
    "scăderi": "scădere",
    "scăderii": "scădere",
    "scăderile": "scădere",
    "scăderilor": "scădere",
    "scafandri": "scafandru",
    "scafandrii": "scafandru",
    "scafandrilor": "scafandru",
    "scafandrul": "scafandru",
    "scafandrului": "scafandru",
    "scăfârlia": "scăfârlie",
    "scăfârliei": "scăfârlie",
    "scăfârlii": "scăfârlie",
    "scăfârliile": "scăfârlie",
    "scăfârliilor": "scăfârlie",
    "scaii": "scai",
    "scailor": "scai",
    "scaiul": "scai",
    "scaiului": "scai",
    "scaietele": "scaiete",
    "scaietelui": "scaiete",
    "scaieți": "scaiete",
    "scaieții": "scaiete",
    "scaieților": "scaiete",
    "scala": "scală",
    "scale": "scală",
    "scalei": "scală",
    "scalele": "scală",
    "scalelor": "scală",
    "scălâmba": "scălâmb",
    "scălâmbă": "scălâmb",
    "scălâmbe": "scălâmb",
    "scălâmbei": "scălâmb",
    "scălâmbele": "scălâmb",
    "scălâmbelor": "scălâmb",
    "scălâmbi": "scălâmb",
    "scălâmbii": "scălâmb",
    "scălâmbilor": "scălâmb",
    "scălâmbul": "scălâmb",
    "scălâmbului": "scălâmb",
    "nemaiscălâmbăiind": "scălâmbăia",
    "nemaiscălâmbăiindu": "scălâmbăia",
    "nescălâmbăiind": "scălâmbăia",
    "nescălâmbăiindu": "scălâmbăia",
    "scălâmbăiai": "scălâmbăia",
    "scălâmbăiam": "scălâmbăia",
    "scălâmbăiară": "scălâmbăia",
    "scălâmbăiarăm": "scălâmbăia",
    "scălâmbăiarăți": "scălâmbăia",
    "scălâmbăiase": "scălâmbăia",
    "scălâmbăiasem": "scălâmbăia",
    "scălâmbăiaseră": "scălâmbăia",
    "scălâmbăiaserăm": "scălâmbăia",
    "scălâmbăiaserăți": "scălâmbăia",
    "scălâmbăiaseși": "scălâmbăia",
    "scălâmbăiași": "scălâmbăia",
    "scălâmbăiat": "scălâmbăia",
    "scălâmbăiați": "scălâmbăia",
    "scălâmbăiau": "scălâmbăia",
    "scălâmbăiază": "scălâmbăia",
    "scălâmbăie": "scălâmbăia",
    "scălâmbăiem": "scălâmbăia",
    "scălâmbăiez": "scălâmbăia",
    "scălâmbăieze": "scălâmbăia",
    "scălâmbăiezi": "scălâmbăia",
    "scălâmbăind": "scălâmbăia",
    "scălâmbăindu": "scălâmbăia",
    "scălâmbăiala": "scălâmbăială",
    "scălâmbăieli": "scălâmbăială",
    "scălâmbăielii": "scălâmbăială",
    "scălâmbăielile": "scălâmbăială",
    "scălâmbăielilor": "scălâmbăială",
    "scălâmbăiată": "scălâmbăiat",
    "scălâmbăiate": "scălâmbăiat",
    "scălâmbăiați": "scălâmbăiat",
    "scâlciata": "scâlciat",
    "scâlciată": "scâlciat",
    "scâlciate": "scâlciat",
    "scâlciatei": "scâlciat",
    "scâlciatele": "scâlciat",
    "scâlciatelor": "scâlciat",
    "scâlciați": "scâlciat",
    "scâlciații": "scâlciat",
    "scâlciaților": "scâlciat",
    "scâlciatul": "scâlciat",
    "scâlciatului": "scâlciat",
    "scâlcietura": "scâlcietură",
    "scâlcieturi": "scâlcietură",
    "scâlcieturii": "scâlcietură",
    "scâlcieturile": "scâlcietură",
    "scâlcieturilor": "scâlcietură",
    "nemaiscăldând": "scălda",
    "nemaiscăldându": "scălda",
    "nescăldând": "scălda",
    "nescăldându": "scălda",
    "scald": "scălda",
    "scaldă": "scălda",
    "scăldă": "scălda",
    "scăldai": "scălda",
    "scăldam": "scălda",
    "scăldăm": "scălda",
    "scăldând": "scălda",
    "scăldându": "scălda",
    "scăldară": "scălda",
    "scăldarăm": "scălda",
    "scăldarăți": "scălda",
    "scăldase": "scălda",
    "scăldasem": "scălda",
    "scăldaseră": "scălda",
    "scăldaserăm": "scălda",
    "scăldaserăți": "scălda",
    "scăldaseși": "scălda",
    "scăldași": "scălda",
    "scăldat": "scălda",
    "scăldați": "scălda",
    "scăldau": "scălda",
    "scalde": "scălda",
    "scalzi": "scălda",
    "scăldată": "scăldat",
    "scăldate": "scăldat",
    "scăldați": "scăldat",
    "scăldatul": "scăldat",
    "scăldatului": "scăldat",
    "scăldaturi": "scăldat",
    "scăldaturile": "scăldat",
    "scăldaturilor": "scăldat",
    "scăldătoarea": "scăldătoare",
    "scăldători": "scăldătoare",
    "scăldătorii": "scăldătoare",
    "scăldătorile": "scăldătoare",
    "scăldătorilor": "scăldătoare",
    "scalpul": "scalp",
    "scalpului": "scalp",
    "scalpuri": "scalp",
    "scalpurile": "scalp",
    "scalpurilor": "scalp",
    "nemaiscalpând": "scalpa",
    "nemaiscalpându": "scalpa",
    "nescalpând": "scalpa",
    "nescalpându": "scalpa",
    "scalpă": "scalpa",
    "scalpai": "scalpa",
    "scalpam": "scalpa",
    "scalpăm": "scalpa",
    "scalpând": "scalpa",
    "scalpându": "scalpa",
    "scalpară": "scalpa",
    "scalparăm": "scalpa",
    "scalparăți": "scalpa",
    "scalpase": "scalpa",
    "scalpasem": "scalpa",
    "scalpaseră": "scalpa",
    "scalpaserăm": "scalpa",
    "scalpaserăți": "scalpa",
    "scalpaseși": "scalpa",
    "scalpași": "scalpa",
    "scalpat": "scalpa",
    "scalpați": "scalpa",
    "scalpau": "scalpa",
    "scalpează": "scalpa",
    "scalpez": "scalpa",
    "scalpeze": "scalpa",
    "scalpezi": "scalpa",
    "scalpată": "scalpat",
    "scalpate": "scalpat",
    "scalpați": "scalpat",
    "scalpele": "scalpel",
    "scalpelele": "scalpel",
    "scalpelelor": "scalpel",
    "scalpelul": "scalpel",
    "scalpelului": "scalpel",
    "scama": "scamă",
    "scame": "scamă",
    "scamei": "scamă",
    "scamele": "scamă",
    "scamelor": "scamă",
    "scamatori": "scamator",
    "scamatorii": "scamator",
    "scamatorilor": "scamator",
    "scamatorul": "scamator",
    "scamatorului": "scamator",
    "scamatoria": "scamatorie",
    "scamatoriei": "scamatorie",
    "scamatorii": "scamatorie",
    "scamatoriile": "scamatorie",
    "scamatoriilor": "scamatorie",
    "nemaiscămoșând": "scămoșa",
    "nemaiscămoșându": "scămoșa",
    "nescămoșând": "scămoșa",
    "nescămoșându": "scămoșa",
    "scămoșă": "scămoșa",
    "scămoșai": "scămoșa",
    "scămoșam": "scămoșa",
    "scămoșăm": "scămoșa",
    "scămoșând": "scămoșa",
    "scămoșându": "scămoșa",
    "scămoșară": "scămoșa",
    "scămoșarăm": "scămoșa",
    "scămoșarăți": "scămoșa",
    "scămoșase": "scămoșa",
    "scămoșasem": "scămoșa",
    "scămoșaseră": "scămoșa",
    "scămoșaserăm": "scămoșa",
    "scămoșaserăți": "scămoșa",
    "scămoșaseși": "scămoșa",
    "scămoșași": "scămoșa",
    "scămoșat": "scămoșa",
    "scămoșați": "scămoșa",
    "scămoșau": "scămoșa",
    "scămoșează": "scămoșa",
    "scămoșez": "scămoșa",
    "scămoșeze": "scămoșa",
    "scămoșezi": "scămoșa",
    "scămoșată": "scămoșat",
    "scămoșate": "scămoșat",
    "scămoșați": "scămoșat",
    "scâncete": "scâncet",
    "scâncetele": "scâncet",
    "scâncetelor": "scâncet",
    "scâncetul": "scâncet",
    "scâncetului": "scâncet",
    "nemaiscâncind": "scânci",
    "nemaiscâncindu": "scânci",
    "nescâncind": "scânci",
    "nescâncindu": "scânci",
    "scâncea": "scânci",
    "scânceai": "scânci",
    "scânceam": "scânci",
    "scâncească": "scânci",
    "scânceați": "scânci",
    "scânceau": "scânci",
    "scâncesc": "scânci",
    "scâncește": "scânci",
    "scâncești": "scânci",
    "scâncii": "scânci",
    "scâncim": "scânci",
    "scâncind": "scânci",
    "scâncindu": "scânci",
    "scânciră": "scânci",
    "scâncirăm": "scânci",
    "scâncirăți": "scânci",
    "scâncise": "scânci",
    "scâncisem": "scânci",
    "scânciseră": "scânci",
    "scânciserăm": "scânci",
    "scânciserăți": "scânci",
    "scânciseși": "scânci",
    "scânciși": "scânci",
    "scâncit": "scânci",
    "scânciți": "scânci",
    "scâncită": "scâncit",
    "scâncite": "scâncit",
    "scânciți": "scâncit",
    "scâncitura": "scâncitură",
    "scâncituri": "scâncitură",
    "scânciturii": "scâncitură",
    "scânciturile": "scâncitură",
    "scânciturilor": "scâncitură",
    "nemaiscandând": "scanda",
    "nemaiscandându": "scanda",
    "nescandând": "scanda",
    "nescandându": "scanda",
    "scandă": "scanda",
    "scandai": "scanda",
    "scandam": "scanda",
    "scandăm": "scanda",
    "scandând": "scanda",
    "scandându": "scanda",
    "scandară": "scanda",
    "scandarăm": "scanda",
    "scandarăți": "scanda",
    "scandase": "scanda",
    "scandasem": "scanda",
    "scandaseră": "scanda",
    "scandaserăm": "scanda",
    "scandaserăți": "scanda",
    "scandaseși": "scanda",
    "scandași": "scanda",
    "scandat": "scanda",
    "scandați": "scanda",
    "scandau": "scanda",
    "scandează": "scanda",
    "scandez": "scanda",
    "scandeze": "scanda",
    "scandezi": "scanda",
    "scandalul": "scandal",
    "scandalului": "scandal",
    "scandaluri": "scandal",
    "scandalurile": "scandal",
    "scandalurilor": "scandal",
    "scandalagii": "scandalagiu",
    "scandalagiii": "scandalagiu",
    "scandalagiilor": "scandalagiu",
    "scandalagiul": "scandalagiu",
    "scandalagiului": "scandalagiu",
    "nemaiscandalizând": "scandaliza",
    "nemaiscandalizându": "scandaliza",
    "nescandalizând": "scandaliza",
    "nescandalizându": "scandaliza",
    "scandaliză": "scandaliza",
    "scandalizai": "scandaliza",
    "scandalizam": "scandaliza",
    "scandalizăm": "scandaliza",
    "scandalizând": "scandaliza",
    "scandalizându": "scandaliza",
    "scandalizară": "scandaliza",
    "scandalizarăm": "scandaliza",
    "scandalizarăți": "scandaliza",
    "scandalizase": "scandaliza",
    "scandalizasem": "scandaliza",
    "scandalizaseră": "scandaliza",
    "scandalizaserăm": "scandaliza",
    "scandalizaserăți": "scandaliza",
    "scandalizaseși": "scandaliza",
    "scandalizași": "scandaliza",
    "scandalizat": "scandaliza",
    "scandalizați": "scandaliza",
    "scandalizau": "scandaliza",
    "scandalizează": "scandaliza",
    "scandalizez": "scandaliza",
    "scandalizeze": "scandaliza",
    "scandalizezi": "scandaliza",
    "scandalizarea": "scandalizare",
    "scandalizareo": "scandalizare",
    "scandalizări": "scandalizare",
    "scandalizării": "scandalizare",
    "scandalizările": "scandalizare",
    "scandalizărilor": "scandalizare",
    "scandalizata": "scandalizat",
    "scandalizată": "scandalizat",
    "scandalizate": "scandalizat",
    "scandalizatei": "scandalizat",
    "scandalizatele": "scandalizat",
    "scandalizatelor": "scandalizat",
    "scandalizați": "scandalizat",
    "scandalizații": "scandalizat",
    "scandalizaților": "scandalizat",
    "scandalizato": "scandalizat",
    "scandalizatul": "scandalizat",
    "scandalizatule": "scandalizat",
    "scandalizatului": "scandalizat",
    "scandaloasa": "scandalos",
    "scandaloasă": "scandalos",
    "scandaloase": "scandalos",
    "scandaloasei": "scandalos",
    "scandaloasele": "scandalos",
    "scandaloaselor": "scandalos",
    "scandaloși": "scandalos",
    "scandaloșii": "scandalos",
    "scandaloșilor": "scandalos",
    "scandalosul": "scandalos",
    "scandalosului": "scandalos",
    "scandarea": "scandare",
    "scandări": "scandare",
    "scandării": "scandare",
    "scandările": "scandare",
    "scandărilor": "scandare",
    "scandată": "scandat",
    "scandate": "scandat",
    "scandați": "scandat",
    "scandinava": "scandinav",
    "scandinavă": "scandinav",
    "scandinave": "scandinav",
    "scandinavei": "scandinav",
    "scandinavele": "scandinav",
    "scandinavelor": "scandinav",
    "scandinavi": "scandinav",
    "scandinavii": "scandinav",
    "scandinavilor": "scandinav",
    "scandinavul": "scandinav",
    "scandinavului": "scandinav",
    "scândura": "scândură",
    "scânduri": "scândură",
    "scândurii": "scândură",
    "scândurile": "scândură",
    "scândurilor": "scândură",
    "nemaiscânteiind": "scânteia",
    "nemaiscânteiindu": "scânteia",
    "nescânteiind": "scânteia",
    "nescânteiindu": "scânteia",
    "scânteiai": "scânteia",
    "scânteiam": "scânteia",
    "scânteiară": "scânteia",
    "scânteiarăm": "scânteia",
    "scânteiarăți": "scânteia",
    "scânteiase": "scânteia",
    "scânteiasem": "scânteia",
    "scânteiaseră": "scânteia",
    "scânteiaserăm": "scânteia",
    "scânteiaserăți": "scânteia",
    "scânteiaseși": "scânteia",
    "scânteiași": "scânteia",
    "scânteiat": "scânteia",
    "scânteiați": "scânteia",
    "scânteiau": "scânteia",
    "scânteiază": "scânteia",
    "scânteie": "scânteia",
    "scânteiem": "scânteia",
    "scânteiez": "scânteia",
    "scânteieze": "scânteia",
    "scânteiezi": "scânteia",
    "scânteind": "scânteia",
    "scânteindu": "scânteia",
    "scânteiată": "scânteiat",
    "scânteiate": "scânteiat",
    "scânteiați": "scânteiat",
    "scântei": "scânteie",
    "scânteia": "scânteie",
    "scânteii": "scânteie",
    "scânteile": "scânteie",
    "scânteilor": "scânteie",
    "scânteietoare": "scânteietor",
    "scânteietoarea": "scânteietor",
    "scânteietoarei": "scânteietor",
    "scânteietoarele": "scânteietor",
    "scânteietoarelor": "scânteietor",
    "scânteietori": "scânteietor",
    "scânteietorii": "scânteietor",
    "scânteietorilor": "scânteietor",
    "scânteietorul": "scânteietor",
    "scânteietorului": "scânteietor",
    "nemaiscăpând": "scăpa",
    "nemaiscăpându": "scăpa",
    "nescăpând": "scăpa",
    "nescăpându": "scăpa",
    "scap": "scăpa",
    "scapă": "scăpa",
    "scăpă": "scăpa",
    "scăpai": "scăpa",
    "scăpam": "scăpa",
    "scăpăm": "scăpa",
    "scăpând": "scăpa",
    "scăpându": "scăpa",
    "scăpară": "scăpa",
    "scăparăm": "scăpa",
    "scăparăți": "scăpa",
    "scăpase": "scăpa",
    "scăpasem": "scăpa",
    "scăpaseră": "scăpa",
    "scăpaserăm": "scăpa",
    "scăpaserăți": "scăpa",
    "scăpaseși": "scăpa",
    "scăpași": "scăpa",
    "scăpat": "scăpa",
    "scăpați": "scăpa",
    "scăpau": "scăpa",
    "scape": "scăpa",
    "scapi": "scăpa",
    "nemaiscăpărând": "scăpăra",
    "nemaiscăpărându": "scăpăra",
    "nescăpărând": "scăpăra",
    "nescăpărându": "scăpăra",
    "scapăr": "scăpăra",
    "scapără": "scăpăra",
    "scăpără": "scăpăra",
    "scăpărai": "scăpăra",
    "scăpăram": "scăpăra",
    "scăpărăm": "scăpăra",
    "scăpărând": "scăpăra",
    "scăpărându": "scăpăra",
    "scăpărară": "scăpăra",
    "scăpărarăm": "scăpăra",
    "scăpărarăți": "scăpăra",
    "scăpărase": "scăpăra",
    "scăpărasem": "scăpăra",
    "scăpăraseră": "scăpăra",
    "scăpăraserăm": "scăpăra",
    "scăpăraserăți": "scăpăra",
    "scăpăraseși": "scăpăra",
    "scăpărași": "scăpăra",
    "scăpărat": "scăpăra",
    "scăpărați": "scăpăra",
    "scăpărau": "scăpăra",
    "scapere": "scăpăra",
    "scaperi": "scăpăra",
    "scăpărarea": "scăpărare",
    "scăpărări": "scăpărare",
    "scăpărării": "scăpărare",
    "scăpărările": "scăpărare",
    "scăpărărilor": "scăpărare",
    "scăpărată": "scăpărat",
    "scăpărate": "scăpărat",
    "scăpărați": "scăpărat",
    "scăpărătoarea": "scăpărătoare",
    "scăpărătoarei": "scăpărătoare",
    "scăpărătoarele": "scăpărătoare",
    "scăpărătoarelor": "scăpărătoare",
    "scăpărători": "scăpărător",
    "scăpărătorii": "scăpărător",
    "scăpărătorilor": "scăpărător",
    "scăpărătorul": "scăpărător",
    "scăpărătorului": "scăpărător",
    "scăparea": "scăpare",
    "scăpareo": "scăpare",
    "scăpări": "scăpare",
    "scăpării": "scăpare",
    "scăpările": "scăpare",
    "scăpărilor": "scăpare",
    "scăpată": "scăpat",
    "scăpate": "scăpat",
    "scăpați": "scăpat",
    "nemaiscăpătând": "scăpăta",
    "nemaiscăpătându": "scăpăta",
    "nescăpătând": "scăpăta",
    "nescăpătându": "scăpăta",
    "scapăt": "scăpăta",
    "scapătă": "scăpăta",
    "scăpătă": "scăpăta",
    "scăpătai": "scăpăta",
    "scăpătam": "scăpăta",
    "scăpătăm": "scăpăta",
    "scăpătând": "scăpăta",
    "scăpătându": "scăpăta",
    "scăpătară": "scăpăta",
    "scăpătarăm": "scăpăta",
    "scăpătarăți": "scăpăta",
    "scăpătase": "scăpăta",
    "scăpătasem": "scăpăta",
    "scăpătaseră": "scăpăta",
    "scăpătaserăm": "scăpăta",
    "scăpătaserăți": "scăpăta",
    "scăpătaseși": "scăpăta",
    "scăpătași": "scăpăta",
    "scăpătat": "scăpăta",
    "scăpătați": "scăpăta",
    "scăpătau": "scăpăta",
    "scapete": "scăpăta",
    "scapeți": "scăpăta",
    "scăpătată": "scăpătat",
    "scăpătate": "scăpătat",
    "scăpătați": "scăpătat",
    "scara": "scară",
    "scări": "scară",
    "scării": "scară",
    "scările": "scară",
    "scărilor": "scară",
    "scarabei": "scarabeu",
    "scarabeii": "scarabeu",
    "scarabeilor": "scarabeu",
    "scarabeul": "scarabeu",
    "scarabeului": "scarabeu",
    "scârba": "scârbă",
    "scârbe": "scârbă",
    "scârbei": "scârbă",
    "scârbele": "scârbă",
    "scârbelor": "scârbă",
    "nemaiscârbind": "scârbi",
    "nemaiscârbindu": "scârbi",
    "nescârbind": "scârbi",
    "nescârbindu": "scârbi",
    "scârbea": "scârbi",
    "scârbeai": "scârbi",
    "scârbeam": "scârbi",
    "scârbească": "scârbi",
    "scârbeați": "scârbi",
    "scârbeau": "scârbi",
    "scârbesc": "scârbi",
    "scârbește": "scârbi",
    "scârbești": "scârbi",
    "scârbii": "scârbi",
    "scârbim": "scârbi",
    "scârbind": "scârbi",
    "scârbindu": "scârbi",
    "scârbiră": "scârbi",
    "scârbirăm": "scârbi",
    "scârbirăți": "scârbi",
    "scârbise": "scârbi",
    "scârbisem": "scârbi",
    "scârbiseră": "scârbi",
    "scârbiserăm": "scârbi",
    "scârbiserăți": "scârbi",
    "scârbiseși": "scârbi",
    "scârbiși": "scârbi",
    "scârbit": "scârbi",
    "scârbiți": "scârbi",
    "scârbită": "scârbit",
    "scârbite": "scârbit",
    "scârbiți": "scârbit",
    "scârboasa": "scârbos",
    "scârboasă": "scârbos",
    "scârboase": "scârbos",
    "scârboasei": "scârbos",
    "scârboasele": "scârbos",
    "scârboaselor": "scârbos",
    "scârboși": "scârbos",
    "scârboșii": "scârbos",
    "scârboșilor": "scârbos",
    "scârbosul": "scârbos",
    "scârbosului": "scârbos",
    "scârboșenia": "scârboșenie",
    "scârboșeniei": "scârboșenie",
    "scârboșenii": "scârboșenie",
    "scârboșeniile": "scârboșenie",
    "scârboșeniilor": "scârboșenie",
    "scărița": "scăriță",
    "scărițe": "scăriță",
    "scăriței": "scăriță",
    "scărițele": "scăriță",
    "scărițelor": "scăriță",
    "scarlatina": "scarlatină",
    "scarlatine": "scarlatină",
    "scarlatinei": "scarlatină",
    "scarlatinele": "scarlatină",
    "scarlatinelor": "scarlatină",
    "nemaiscărmănând": "scărmăna",
    "nemaiscărmănându": "scărmăna",
    "nescărmănând": "scărmăna",
    "nescărmănându": "scărmăna",
    "scarmăn": "scărmăna",
    "scarmănă": "scărmăna",
    "scărmănă": "scărmăna",
    "scărmănai": "scărmăna",
    "scărmănam": "scărmăna",
    "scărmănăm": "scărmăna",
    "scărmănând": "scărmăna",
    "scărmănându": "scărmăna",
    "scărmănară": "scărmăna",
    "scărmănarăm": "scărmăna",
    "scărmănarăți": "scărmăna",
    "scărmănase": "scărmăna",
    "scărmănasem": "scărmăna",
    "scărmănaseră": "scărmăna",
    "scărmănaserăm": "scărmăna",
    "scărmănaserăți": "scărmăna",
    "scărmănaseși": "scărmăna",
    "scărmănași": "scărmăna",
    "scărmănat": "scărmăna",
    "scărmănați": "scărmăna",
    "scărmănau": "scărmăna",
    "scarmene": "scărmăna",
    "scarmeni": "scărmăna",
    "scărmănată": "scărmănat",
    "scărmănate": "scărmănat",
    "scărmănați": "scărmănat",
    "scărmănătoarea": "scărmănătoare",
    "scărmănătoarele": "scărmănătoare",
    "scărmănătoarelor": "scărmănătoare",
    "scărmănători": "scărmănătoare",
    "scărmănătorii": "scărmănătoare",
    "scârna": "scârnă",
    "scârne": "scârnă",
    "scârnei": "scârnă",
    "scârnele": "scârnă",
    "scârnelor": "scârnă",
    "scârnava": "scârnav",
    "scârnavă": "scârnav",
    "scârnave": "scârnav",
    "scârnavei": "scârnav",
    "scârnavele": "scârnav",
    "scârnavelor": "scârnav",
    "scârnavi": "scârnav",
    "scârnavii": "scârnav",
    "scârnavilor": "scârnav",
    "scârnavul": "scârnav",
    "scârnavului": "scârnav",
    "nemaiscârnăvind": "scârnăvi",
    "nemaiscârnăvindu": "scârnăvi",
    "nescârnăvind": "scârnăvi",
    "nescârnăvindu": "scârnăvi",
    "scârnăvea": "scârnăvi",
    "scârnăveai": "scârnăvi",
    "scârnăveam": "scârnăvi",
    "scârnăvească": "scârnăvi",
    "scârnăveați": "scârnăvi",
    "scârnăveau": "scârnăvi",
    "scârnăvesc": "scârnăvi",
    "scârnăvește": "scârnăvi",
    "scârnăvești": "scârnăvi",
    "scârnăvii": "scârnăvi",
    "scârnăvim": "scârnăvi",
    "scârnăvind": "scârnăvi",
    "scârnăvindu": "scârnăvi",
    "scârnăviră": "scârnăvi",
    "scârnăvirăm": "scârnăvi",
    "scârnăvirăți": "scârnăvi",
    "scârnăvise": "scârnăvi",
    "scârnăvisem": "scârnăvi",
    "scârnăviseră": "scârnăvi",
    "scârnăviserăm": "scârnăvi",
    "scârnăviserăți": "scârnăvi",
    "scârnăviseși": "scârnăvi",
    "scârnăviși": "scârnăvi",
    "scârnăvit": "scârnăvi",
    "scârnăviți": "scârnăvi",
    "scârnăvia": "scârnăvie",
    "scârnăviei": "scârnăvie",
    "scârnăvii": "scârnăvie",
    "scârnăviile": "scârnăvie",
    "scârnăviilor": "scârnăvie",
    "scârnăvită": "scârnăvit",
    "scârnăvite": "scârnăvit",
    "scârnăviți": "scârnăvit",
    "nemaiscărpinând": "scărpina",
    "nemaiscărpinându": "scărpina",
    "nescărpinând": "scărpina",
    "nescărpinându": "scărpina",
    "scarpin": "scărpina",
    "scarpină": "scărpina",
    "scărpină": "scărpina",
    "scărpinai": "scărpina",
    "scărpinam": "scărpina",
    "scărpinăm": "scărpina",
    "scărpinând": "scărpina",
    "scărpinându": "scărpina",
    "scărpinară": "scărpina",
    "scărpinarăm": "scărpina",
    "scărpinarăți": "scărpina",
    "scărpinase": "scărpina",
    "scărpinasem": "scărpina",
    "scărpinaseră": "scărpina",
    "scărpinaserăm": "scărpina",
    "scărpinaserăți": "scărpina",
    "scărpinaseși": "scărpina",
    "scărpinași": "scărpina",
    "scărpinat": "scărpina",
    "scărpinați": "scărpina",
    "scărpinau": "scărpina",
    "scarpine": "scărpina",
    "scarpini": "scărpina",
    "scărpinarea": "scărpinare",
    "scărpinareo": "scărpinare",
    "scărpinări": "scărpinare",
    "scărpinării": "scărpinare",
    "scărpinările": "scărpinare",
    "scărpinărilor": "scărpinare",
    "scărpinata": "scărpinat",
    "scărpinată": "scărpinat",
    "scărpinate": "scărpinat",
    "scărpinatei": "scărpinat",
    "scărpinatele": "scărpinat",
    "scărpinatelor": "scărpinat",
    "scărpinați": "scărpinat",
    "scărpinații": "scărpinat",
    "scărpinaților": "scărpinat",
    "scărpinato": "scărpinat",
    "scărpinatul": "scărpinat",
    "scărpinatule": "scărpinat",
    "scărpinatului": "scărpinat",
    "scărpinătoarea": "scărpinătoare",
    "scărpinătoarele": "scărpinătoare",
    "scărpinătoarelor": "scărpinătoare",
    "scărpinători": "scărpinătoare",
    "scărpinătorii": "scărpinătoare",
    "nemaiscârțâind": "scârțâi",
    "nemaiscârțâindu": "scârțâi",
    "nescârțâind": "scârțâi",
    "nescârțâindu": "scârțâi",
    "scârțâia": "scârțâi",
    "scârțâiai": "scârțâi",
    "scârțâiam": "scârțâi",
    "scârțâiați": "scârțâi",
    "scârțâiau": "scârțâi",
    "scârțâie": "scârțâi",
    "scârțâii": "scârțâi",
    "scârțâim": "scârțâi",
    "scârțâind": "scârțâi",
    "scârțâindu": "scârțâi",
    "scârțâiră": "scârțâi",
    "scârțâirăm": "scârțâi",
    "scârțâirăți": "scârțâi",
    "scârțâise": "scârțâi",
    "scârțâisem": "scârțâi",
    "scârțâiseră": "scârțâi",
    "scârțâiserăm": "scârțâi",
    "scârțâiserăți": "scârțâi",
    "scârțâiseși": "scârțâi",
    "scârțâiși": "scârțâi",
    "scârțâit": "scârțâi",
    "scârțâiți": "scârțâi",
    "scârțâiala": "scârțâială",
    "scârțâieli": "scârțâială",
    "scârțâielii": "scârțâială",
    "scârțâielile": "scârțâială",
    "scârțâielilor": "scârțâială",
    "scârțâită": "scârțâit",
    "scârțâite": "scârțâit",
    "scârțâiți": "scârțâit",
    "scârțâitul": "scârțâit",
    "scârțâitului": "scârțâit",
    "scârțâituri": "scârțâit",
    "scârțâiturile": "scârțâit",
    "scârțâiturilor": "scârțâit",
    "scatii": "scatiu",
    "scatiii": "scatiu",
    "scatiilor": "scatiu",
    "scatiul": "scatiu",
    "scatiului": "scatiu",
    "scatoalca": "scatoalcă",
    "scatoalce": "scatoalcă",
    "scatoalcei": "scatoalcă",
    "scatoalcele": "scatoalcă",
    "scatoalcelor": "scatoalcă",
    "scaune": "scaun",
    "scaunele": "scaun",
    "scaunelor": "scaun",
    "scaunul": "scaun",
    "scaunului": "scaun",
    "scăunele": "scăunel",
    "scăunelele": "scăunel",
    "scăunelelor": "scăunel",
    "scăunelul": "scăunel",
    "scăunelului": "scăunel",
    "scăzământul": "scăzământ",
    "scăzământului": "scăzământ",
    "scăzăminte": "scăzământ",
    "scăzămintele": "scăzământ",
    "scăzămintelor": "scăzământ",
    "scăzători": "scăzător",
    "scăzătorii": "scăzător",
    "scăzătorilor": "scăzător",
    "scăzătorul": "scăzător",
    "scăzătorului": "scăzător",
    "scăzută": "scăzut",
    "scăzute": "scăzut",
    "scăzuți": "scăzut",
    "scelerați": "scelerat",
    "scelerații": "scelerat",
    "sceleraților": "scelerat",
    "sceleratul": "scelerat",
    "sceleratului": "scelerat",
    "scena": "scenă",
    "scene": "scenă",
    "scenei": "scenă",
    "scenele": "scenă",
    "scenelor": "scenă",
    "scenariști": "scenarist",
    "scenariștii": "scenarist",
    "scenariștilor": "scenarist",
    "scenaristul": "scenarist",
    "scenaristului": "scenarist",
    "scenarii": "scenariu",
    "scenariile": "scenariu",
    "scenariilor": "scenariu",
    "scenariul": "scenariu",
    "scenariului": "scenariu",
    "sceneta": "scenetă",
    "scenete": "scenetă",
    "scenetei": "scenetă",
    "scenetele": "scenetă",
    "scenetelor": "scenetă",
    "scenica": "scenic",
    "scenică": "scenic",
    "scenice": "scenic",
    "scenicei": "scenic",
    "scenicele": "scenic",
    "scenicelor": "scenic",
    "scenici": "scenic",
    "scenicii": "scenic",
    "scenicilor": "scenic",
    "scenicul": "scenic",
    "scenicului": "scenic",
    "scenografi": "scenograf",
    "scenografii": "scenograf",
    "scenografilor": "scenograf",
    "scenograful": "scenograf",
    "scenografului": "scenograf",
    "scenografica": "scenografic",
    "scenografică": "scenografic",
    "scenografice": "scenografic",
    "scenograficei": "scenografic",
    "scenograficele": "scenografic",
    "scenograficelor": "scenografic",
    "scenografici": "scenografic",
    "scenograficii": "scenografic",
    "scenograficilor": "scenografic",
    "scenograficul": "scenografic",
    "scenograficului": "scenografic",
    "scenografia": "scenografie",
    "scenografiei": "scenografie",
    "scenografii": "scenografie",
    "scenografiile": "scenografie",
    "scenografiilor": "scenografie",
    "sceptica": "sceptic",
    "sceptică": "sceptic",
    "sceptice": "sceptic",
    "scepticei": "sceptic",
    "scepticele": "sceptic",
    "scepticelor": "sceptic",
    "sceptici": "sceptic",
    "scepticii": "sceptic",
    "scepticilor": "sceptic",
    "scepticul": "sceptic",
    "scepticului": "sceptic",
    "scepticismul": "scepticism",
    "scepticismului": "scepticism",
    "sceptre": "sceptru",
    "sceptrele": "sceptru",
    "sceptrelor": "sceptru",
    "sceptrul": "sceptru",
    "sceptrului": "sceptru",
    "schela": "schelă",
    "schele": "schelă",
    "schelei": "schelă",
    "schelele": "schelă",
    "schelelor": "schelă",
    "schelăria": "schelărie",
    "schelăriei": "schelărie",
    "schelării": "schelărie",
    "schelăriile": "schelărie",
    "schelăriilor": "schelărie",
    "schelete": "schelet",
    "scheletele": "schelet",
    "scheletelor": "schelet",
    "scheletul": "schelet",
    "scheletului": "schelet",
    "schema": "schemă",
    "scheme": "schemă",
    "schemei": "schemă",
    "schemele": "schemă",
    "schemelor": "schemă",
    "schematica": "schematic",
    "schematică": "schematic",
    "schematice": "schematic",
    "schematicei": "schematic",
    "schematicele": "schematic",
    "schematicelor": "schematic",
    "schematici": "schematic",
    "schematicii": "schematic",
    "schematicilor": "schematic",
    "schematicul": "schematic",
    "schematicului": "schematic",
    "schematismul": "schematism",
    "schematismului": "schematism",
    "schepsisul": "schepsis",
    "schepsisului": "schepsis",
    "nemaischeunând": "scheuna",
    "nemaischeunându": "scheuna",
    "nescheunând": "scheuna",
    "nescheunându": "scheuna",
    "scheaun": "scheuna",
    "scheaună": "scheuna",
    "scheaune": "scheuna",
    "scheauni": "scheuna",
    "scheună": "scheuna",
    "scheunai": "scheuna",
    "scheunam": "scheuna",
    "scheunăm": "scheuna",
    "scheunând": "scheuna",
    "scheunându": "scheuna",
    "scheunară": "scheuna",
    "scheunarăm": "scheuna",
    "scheunarăți": "scheuna",
    "scheunase": "scheuna",
    "scheunasem": "scheuna",
    "scheunaseră": "scheuna",
    "scheunaserăm": "scheuna",
    "scheunaserăți": "scheuna",
    "scheunaseși": "scheuna",
    "scheunași": "scheuna",
    "scheunat": "scheuna",
    "scheunați": "scheuna",
    "scheunau": "scheuna",
    "scheunarea": "scheunare",
    "scheunareo": "scheunare",
    "scheunări": "scheunare",
    "scheunării": "scheunare",
    "scheunările": "scheunare",
    "scheunărilor": "scheunare",
    "scheunată": "scheunat",
    "scheunate": "scheunat",
    "scheunați": "scheunat",
    "scheunatul": "scheunat",
    "scheunatului": "scheunat",
    "scheunătura": "scheunătură",
    "scheunături": "scheunătură",
    "scheunăturii": "scheunătură",
    "scheunăturile": "scheunătură",
    "scheunăturilor": "scheunătură",
    "scheunăturo": "scheunătură",
    "schiul": "schi",
    "schiului": "schi",
    "schiuri": "schi",
    "schiurile": "schi",
    "schiurilor": "schi",
    "nemaischiind": "schia",
    "nemaischiindu": "schia",
    "neschiind": "schia",
    "neschiindu": "schia",
    "schiai": "schia",
    "schiam": "schia",
    "schiară": "schia",
    "schiarăm": "schia",
    "schiarăți": "schia",
    "schiase": "schia",
    "schiasem": "schia",
    "schiaseră": "schia",
    "schiaserăm": "schia",
    "schiaserăți": "schia",
    "schiaseși": "schia",
    "schiași": "schia",
    "schiat": "schia",
    "schiați": "schia",
    "schiau": "schia",
    "schiază": "schia",
    "schie": "schia",
    "schiem": "schia",
    "schiez": "schia",
    "schieze": "schia",
    "schiezi": "schia",
    "schiind": "schia",
    "schiindu": "schia",
    "schiată": "schiat",
    "schiate": "schiat",
    "schiați": "schiat",
    "schija": "schijă",
    "schije": "schijă",
    "schijei": "schijă",
    "schijele": "schijă",
    "schijelor": "schijă",
    "schiloada": "schilod",
    "schiloadă": "schilod",
    "schiloade": "schilod",
    "schiloadei": "schilod",
    "schiloadele": "schilod",
    "schiloadelor": "schilod",
    "schilodul": "schilod",
    "schilodului": "schilod",
    "schilozi": "schilod",
    "schilozii": "schilod",
    "schilozilor": "schilod",
    "schilodeala": "schilodeală",
    "schilodeli": "schilodeală",
    "schilodelii": "schilodeală",
    "schilodelile": "schilodeală",
    "schilodelilor": "schilodeală",
    "nemaischilodind": "schilodi",
    "nemaischilodindu": "schilodi",
    "neschilodind": "schilodi",
    "neschilodindu": "schilodi",
    "schilodea": "schilodi",
    "schilodeai": "schilodi",
    "schilodeam": "schilodi",
    "schilodească": "schilodi",
    "schilodeați": "schilodi",
    "schilodeau": "schilodi",
    "schilodesc": "schilodi",
    "schilodește": "schilodi",
    "schilodești": "schilodi",
    "schilodii": "schilodi",
    "schilodim": "schilodi",
    "schilodind": "schilodi",
    "schilodindu": "schilodi",
    "schilodiră": "schilodi",
    "schilodirăm": "schilodi",
    "schilodirăți": "schilodi",
    "schilodise": "schilodi",
    "schilodisem": "schilodi",
    "schilodiseră": "schilodi",
    "schilodiserăm": "schilodi",
    "schilodiserăți": "schilodi",
    "schilodiseși": "schilodi",
    "schilodiși": "schilodi",
    "schilodit": "schilodi",
    "schilodiți": "schilodi",
    "schilodită": "schilodit",
    "schilodite": "schilodit",
    "schilodiți": "schilodit",
    "schima": "schimă",
    "schime": "schimă",
    "schimei": "schimă",
    "schimele": "schimă",
    "schimelor": "schimă",
    "schimbul": "schimb",
    "schimbului": "schimb",
    "schimburi": "schimb",
    "schimburile": "schimb",
    "schimburilor": "schimb",
    "nemaischimbând": "schimba",
    "nemaischimbându": "schimba",
    "neschimbând": "schimba",
    "neschimbându": "schimba",
    "schimb": "schimba",
    "schimbă": "schimba",
    "schimbai": "schimba",
    "schimbam": "schimba",
    "schimbăm": "schimba",
    "schimbând": "schimba",
    "schimbându": "schimba",
    "schimbară": "schimba",
    "schimbarăm": "schimba",
    "schimbarăți": "schimba",
    "schimbase": "schimba",
    "schimbasem": "schimba",
    "schimbaseră": "schimba",
    "schimbaserăm": "schimba",
    "schimbaserăți": "schimba",
    "schimbaseși": "schimba",
    "schimbași": "schimba",
    "schimbat": "schimba",
    "schimbați": "schimba",
    "schimbau": "schimba",
    "schimbe": "schimba",
    "schimbi": "schimba",
    "schimbabilitatea": "schimbabilitate",
    "schimbarea": "schimbare",
    "schimbări": "schimbare",
    "schimbării": "schimbare",
    "schimbările": "schimbare",
    "schimbărilor": "schimbare",
    "schimbată": "schimbat",
    "schimbate": "schimbat",
    "schimbați": "schimbat",
    "schimbătoare": "schimbător",
    "schimbătoarea": "schimbător",
    "schimbătoarei": "schimbător",
    "schimbătoarele": "schimbător",
    "schimbătoarelor": "schimbător",
    "schimbători": "schimbător",
    "schimbătorii": "schimbător",
    "schimbătorilor": "schimbător",
    "schimbătorul": "schimbător",
    "schimbătorului": "schimbător",
    "schimnici": "schimnic",
    "schimnicii": "schimnic",
    "schimnicilor": "schimnic",
    "schimnicul": "schimnic",
    "schimnicului": "schimnic",
    "schimnica": "schimnică",
    "schimnice": "schimnică",
    "schimnicei": "schimnică",
    "schimnicele": "schimnică",
    "schimnicelor": "schimnică",
    "schimnicescul": "schimnicesc",
    "schimnicescului": "schimnicesc",
    "schimnicești": "schimnicesc",
    "schimniceștii": "schimnicesc",
    "schimniceștilor": "schimnicesc",
    "schimnicia": "schimnicie",
    "schimniciei": "schimnicie",
    "schimnicii": "schimnicie",
    "schimniciile": "schimnicie",
    "schimniciilor": "schimnicie",
    "nemaischimonosind": "schimonosi",
    "nemaischimonosindu": "schimonosi",
    "neschimonosind": "schimonosi",
    "neschimonosindu": "schimonosi",
    "schimonosea": "schimonosi",
    "schimonoseai": "schimonosi",
    "schimonoseam": "schimonosi",
    "schimonosească": "schimonosi",
    "schimonoseați": "schimonosi",
    "schimonoseau": "schimonosi",
    "schimonosesc": "schimonosi",
    "schimonosește": "schimonosi",
    "schimonosești": "schimonosi",
    "schimonosii": "schimonosi",
    "schimonosim": "schimonosi",
    "schimonosind": "schimonosi",
    "schimonosindu": "schimonosi",
    "schimonosiră": "schimonosi",
    "schimonosirăm": "schimonosi",
    "schimonosirăți": "schimonosi",
    "schimonosise": "schimonosi",
    "schimonosisem": "schimonosi",
    "schimonosiseră": "schimonosi",
    "schimonosiserăm": "schimonosi",
    "schimonosiserăți": "schimonosi",
    "schimonosiseși": "schimonosi",
    "schimonosiși": "schimonosi",
    "schimonosit": "schimonosi",
    "schimonosiți": "schimonosi",
    "schimonosirea": "schimonosire",
    "schimonosireo": "schimonosire",
    "schimonosiri": "schimonosire",
    "schimonosirii": "schimonosire",
    "schimonosirile": "schimonosire",
    "schimonosirilor": "schimonosire",
    "schimonosita": "schimonosit",
    "schimonosită": "schimonosit",
    "schimonosite": "schimonosit",
    "schimonositei": "schimonosit",
    "schimonositele": "schimonosit",
    "schimonositelor": "schimonosit",
    "schimonosiți": "schimonosit",
    "schimonosiții": "schimonosit",
    "schimonosiților": "schimonosit",
    "schimonosito": "schimonosit",
    "schimonositul": "schimonosit",
    "schimonositule": "schimonosit",
    "schimonositului": "schimonosit",
    "schimonositura": "schimonositură",
    "schimonosituri": "schimonositură",
    "schimonositurii": "schimonositură",
    "schimonositurile": "schimonositură",
    "schimonositurilor": "schimonositură",
    "schimonosituro": "schimonositură",
    "nemaischingiuind": "schingiui",
    "nemaischingiuindu": "schingiui",
    "neschingiuind": "schingiui",
    "neschingiuindu": "schingiui",
    "schingiuia": "schingiui",
    "schingiuiai": "schingiui",
    "schingiuiam": "schingiui",
    "schingiuiască": "schingiui",
    "schingiuiați": "schingiui",
    "schingiuiau": "schingiui",
    "schingiuiesc": "schingiui",
    "schingiuiește": "schingiui",
    "schingiuiești": "schingiui",
    "schingiuii": "schingiui",
    "schingiuim": "schingiui",
    "schingiuind": "schingiui",
    "schingiuindu": "schingiui",
    "schingiuiră": "schingiui",
    "schingiuirăm": "schingiui",
    "schingiuirăți": "schingiui",
    "schingiuise": "schingiui",
    "schingiuisem": "schingiui",
    "schingiuiseră": "schingiui",
    "schingiuiserăm": "schingiui",
    "schingiuiserăți": "schingiui",
    "schingiuiseși": "schingiui",
    "schingiuiși": "schingiui",
    "schingiuit": "schingiui",
    "schingiuiți": "schingiui",
    "schingiuirea": "schingiuire",
    "schingiuiri": "schingiuire",
    "schingiuirii": "schingiuire",
    "schingiuirile": "schingiuire",
    "schingiuirilor": "schingiuire",
    "schingiuită": "schingiuit",
    "schingiuite": "schingiuit",
    "schingiuiți": "schingiuit",
    "schingiuitori": "schingiuitor",
    "schingiuitorii": "schingiuitor",
    "schingiuitorilor": "schingiuitor",
    "schingiuitorul": "schingiuitor",
    "schingiuitorului": "schingiuitor",
    "schioarea": "schioare",
    "schioarei": "schioare",
    "schioarele": "schioare",
    "schioarelor": "schioare",
    "șchioapa": "șchiop",
    "șchioapă": "șchiop",
    "șchioape": "șchiop",
    "șchioapei": "șchiop",
    "șchioapele": "șchiop",
    "șchioapelor": "șchiop",
    "șchiopi": "șchiop",
    "șchiopii": "șchiop",
    "șchiopilor": "șchiop",
    "șchiopul": "șchiop",
    "șchiopului": "șchiop",
    "nemaișchiopând": "șchiopa",
    "nemaișchiopându": "șchiopa",
    "neșchiopând": "șchiopa",
    "neșchiopându": "șchiopa",
    "șchiopă": "șchiopa",
    "șchiopai": "șchiopa",
    "șchiopam": "șchiopa",
    "șchiopăm": "șchiopa",
    "șchiopând": "șchiopa",
    "șchiopându": "șchiopa",
    "șchiopară": "șchiopa",
    "șchioparăm": "șchiopa",
    "șchioparăți": "șchiopa",
    "șchiopase": "șchiopa",
    "șchiopasem": "șchiopa",
    "șchiopaseră": "șchiopa",
    "șchiopaserăm": "șchiopa",
    "șchiopaserăți": "șchiopa",
    "șchiopaseși": "șchiopa",
    "șchiopași": "șchiopa",
    "șchiopat": "șchiopa",
    "șchiopați": "șchiopa",
    "șchiopau": "șchiopa",
    "șchiopează": "șchiopa",
    "șchiopez": "șchiopa",
    "șchiopeze": "șchiopa",
    "șchiopezi": "șchiopa",
    "șchiopată": "șchiopat",
    "șchiopate": "șchiopat",
    "șchiopați": "șchiopat",
    "nemaișchiopătând": "șchiopăta",
    "nemaișchiopătându": "șchiopăta",
    "neșchiopătând": "șchiopăta",
    "neșchiopătându": "șchiopăta",
    "șchiopătă": "șchiopăta",
    "șchiopătai": "șchiopăta",
    "șchiopătam": "șchiopăta",
    "șchiopătăm": "șchiopăta",
    "șchiopătând": "șchiopăta",
    "șchiopătându": "șchiopăta",
    "șchiopătară": "șchiopăta",
    "șchiopătarăm": "șchiopăta",
    "șchiopătarăți": "șchiopăta",
    "șchiopătase": "șchiopăta",
    "șchiopătasem": "șchiopăta",
    "șchiopătaseră": "șchiopăta",
    "șchiopătaserăm": "șchiopăta",
    "șchiopătaserăți": "șchiopăta",
    "șchiopătaseși": "șchiopăta",
    "șchiopătași": "șchiopăta",
    "șchiopătat": "șchiopăta",
    "șchiopătați": "șchiopăta",
    "șchiopătau": "șchiopăta",
    "șchiopătează": "șchiopăta",
    "șchiopătez": "șchiopăta",
    "șchiopăteze": "șchiopăta",
    "șchiopătezi": "șchiopăta",
    "șchiopătată": "șchiopătat",
    "șchiopătate": "șchiopătat",
    "șchiopătați": "șchiopătat",
    "șchiopătura": "șchiopătură",
    "șchiopături": "șchiopătură",
    "șchiopăturii": "șchiopătură",
    "șchiopăturile": "șchiopătură",
    "șchiopăturilor": "șchiopătură",
    "șchiopăturo": "șchiopătură",
    "schiori": "schior",
    "schiorii": "schior",
    "schiorilor": "schior",
    "schiorul": "schior",
    "schiorului": "schior",
    "schitul": "schit",
    "Schitului": "Schit",
    "schituri": "schit",
    "schiturile": "schit",
    "schiturilor": "schit",
    "nemaischițând": "schița",
    "nemaischițându": "schița",
    "neschițând": "schița",
    "neschițându": "schița",
    "schiță": "schița",
    "schițai": "schița",
    "schițam": "schița",
    "schițăm": "schița",
    "schițând": "schița",
    "schițându": "schița",
    "schițară": "schița",
    "schițarăm": "schița",
    "schițarăți": "schița",
    "schițase": "schița",
    "schițasem": "schița",
    "schițaseră": "schița",
    "schițaserăm": "schița",
    "schițaserăți": "schița",
    "schițaseși": "schița",
    "schițași": "schița",
    "schițat": "schița",
    "schițați": "schița",
    "schițau": "schița",
    "schițează": "schița",
    "schițez": "schița",
    "schițeze": "schița",
    "schițezi": "schița",
    "schița": "schiță",
    "schițe": "schiță",
    "schiței": "schiță",
    "schițele": "schiță",
    "schițelor": "schiță",
    "schițarea": "schițare",
    "schițări": "schițare",
    "schițării": "schițare",
    "schițările": "schițare",
    "schițărilor": "schițare",
    "schițată": "schițat",
    "schițate": "schițat",
    "schițați": "schițat",
    "schizofrenici": "schizofrenic",
    "schizofrenicii": "schizofrenic",
    "schizofrenicilor": "schizofrenic",
    "schizofrenicul": "schizofrenic",
    "schizofrenicului": "schizofrenic",
    "schizofrenica": "schizofrenică",
    "schizofrenice": "schizofrenică",
    "schizofrenicei": "schizofrenică",
    "schizofrenicele": "schizofrenică",
    "schizofrenicelor": "schizofrenică",
    "schizofrenia": "schizofrenie",
    "schizofreniei": "schizofrenie",
    "schizofrenii": "schizofrenie",
    "schizofreniile": "schizofrenie",
    "schizofreniilor": "schizofrenie",
    "sciatica": "sciatic",
    "sciatică": "sciatic",
    "sciatice": "sciatic",
    "sciaticei": "sciatic",
    "sciaticele": "sciatic",
    "sciaticelor": "sciatic",
    "sciatici": "sciatic",
    "sciaticii": "sciatic",
    "sciaticilor": "sciatic",
    "sciaticul": "sciatic",
    "sciaticului": "sciatic",
    "sciatica": "sciatică",
    "sciaticele": "sciatică",
    "sciaticelor": "sciatică",
    "sciatici": "sciatică",
    "sciaticii": "sciatică",
    "scientiști": "scientist",
    "scientiștii": "scientist",
    "scientiștilor": "scientist",
    "scientistul": "scientist",
    "scientistului": "scientist",
    "scientista": "scientistă",
    "scientiste": "scientistă",
    "scientistei": "scientistă",
    "scientistele": "scientistă",
    "scientistelor": "scientistă",
    "sc.": "scilicet",
    "scil.": "scilicet",
    "nemaiscindând": "scinda",
    "nemaiscindându": "scinda",
    "nescindând": "scinda",
    "nescindându": "scinda",
    "scindă": "scinda",
    "scindai": "scinda",
    "scindam": "scinda",
    "scindăm": "scinda",
    "scindând": "scinda",
    "scindându": "scinda",
    "scindară": "scinda",
    "scindarăm": "scinda",
    "scindarăți": "scinda",
    "scindase": "scinda",
    "scindasem": "scinda",
    "scindaseră": "scinda",
    "scindaserăm": "scinda",
    "scindaserăți": "scinda",
    "scindaseși": "scinda",
    "scindași": "scinda",
    "scindat": "scinda",
    "scindați": "scinda",
    "scindau": "scinda",
    "scindează": "scinda",
    "scindez": "scinda",
    "scindeze": "scinda",
    "scindezi": "scinda",
    "scindată": "scindat",
    "scindate": "scindat",
    "scindați": "scindat",
    "scintilația": "scintilație",
    "scintilației": "scintilație",
    "scintilații": "scintilație",
    "scintilațiile": "scintilație",
    "scintilațiilor": "scintilație",
    "sciți": "scit",
    "sciții": "scit",
    "sciților": "scit",
    "scitul": "scit",
    "scitului": "scit",
    "nemaiscizionând": "sciziona",
    "nemaiscizionându": "sciziona",
    "nescizionând": "sciziona",
    "nescizionându": "sciziona",
    "scizionă": "sciziona",
    "scizionai": "sciziona",
    "scizionam": "sciziona",
    "scizionăm": "sciziona",
    "scizionând": "sciziona",
    "scizionându": "sciziona",
    "scizionară": "sciziona",
    "scizionarăm": "sciziona",
    "scizionarăți": "sciziona",
    "scizionase": "sciziona",
    "scizionasem": "sciziona",
    "scizionaseră": "sciziona",
    "scizionaserăm": "sciziona",
    "scizionaserăți": "sciziona",
    "scizionaseși": "sciziona",
    "scizionași": "sciziona",
    "scizionat": "sciziona",
    "scizionați": "sciziona",
    "scizionau": "sciziona",
    "scizionează": "sciziona",
    "scizionez": "sciziona",
    "scizioneze": "sciziona",
    "scizionezi": "sciziona",
    "scizionată": "scizionat",
    "scizionate": "scizionat",
    "scizionați": "scizionat",
    "sciziunea": "sciziune",
    "sciziuni": "sciziune",
    "sciziunii": "sciziune",
    "sciziunile": "sciziune",
    "sciziunilor": "sciziune",
    "sclava": "sclav",
    "sclavă": "sclav",
    "sclave": "sclav",
    "sclavei": "sclav",
    "sclavele": "sclav",
    "sclavelor": "sclav",
    "sclavi": "sclav",
    "sclavii": "sclav",
    "sclavilor": "sclav",
    "sclavul": "sclav",
    "sclavului": "sclav",
    "sclava": "sclavă",
    "sclave": "sclavă",
    "sclavei": "sclavă",
    "sclavele": "sclavă",
    "sclavelor": "sclavă",
    "sclavagismul": "sclavagism",
    "sclavagismului": "sclavagism",
    "sclavagista": "sclavagist",
    "sclavagistă": "sclavagist",
    "sclavagiste": "sclavagist",
    "sclavagistei": "sclavagist",
    "sclavagistele": "sclavagist",
    "sclavagistelor": "sclavagist",
    "sclavagiști": "sclavagist",
    "sclavagiștii": "sclavagist",
    "sclavagiștilor": "sclavagist",
    "sclavagistul": "sclavagist",
    "sclavagistului": "sclavagist",
    "sclavia": "sclavie",
    "sclaviei": "sclavie",
    "sclavii": "sclavie",
    "sclaviile": "sclavie",
    "sclaviilor": "sclavie",
    "nemaisclerozând": "scleroza",
    "nemaisclerozându": "scleroza",
    "nesclerozând": "scleroza",
    "nesclerozându": "scleroza",
    "scleroză": "scleroza",
    "sclerozai": "scleroza",
    "sclerozam": "scleroza",
    "sclerozăm": "scleroza",
    "sclerozând": "scleroza",
    "sclerozându": "scleroza",
    "sclerozară": "scleroza",
    "sclerozarăm": "scleroza",
    "sclerozarăți": "scleroza",
    "sclerozase": "scleroza",
    "sclerozasem": "scleroza",
    "sclerozaseră": "scleroza",
    "sclerozaserăm": "scleroza",
    "sclerozaserăți": "scleroza",
    "sclerozaseși": "scleroza",
    "sclerozași": "scleroza",
    "sclerozat": "scleroza",
    "sclerozați": "scleroza",
    "sclerozau": "scleroza",
    "sclerozează": "scleroza",
    "sclerozez": "scleroza",
    "sclerozeze": "scleroza",
    "sclerozezi": "scleroza",
    "scleroza": "scleroză",
    "scleroze": "scleroză",
    "sclerozei": "scleroză",
    "sclerozele": "scleroză",
    "sclerozelor": "scleroză",
    "sclerozată": "sclerozat",
    "sclerozate": "sclerozat",
    "sclerozați": "sclerozat",
    "nemaisclifosind": "sclifosi",
    "nemaisclifosindu": "sclifosi",
    "nesclifosind": "sclifosi",
    "nesclifosindu": "sclifosi",
    "sclifosea": "sclifosi",
    "sclifoseai": "sclifosi",
    "sclifoseam": "sclifosi",
    "sclifosească": "sclifosi",
    "sclifoseați": "sclifosi",
    "sclifoseau": "sclifosi",
    "sclifosesc": "sclifosi",
    "sclifosește": "sclifosi",
    "sclifosești": "sclifosi",
    "sclifosii": "sclifosi",
    "sclifosim": "sclifosi",
    "sclifosind": "sclifosi",
    "sclifosindu": "sclifosi",
    "sclifosiră": "sclifosi",
    "sclifosirăm": "sclifosi",
    "sclifosirăți": "sclifosi",
    "sclifosise": "sclifosi",
    "sclifosisem": "sclifosi",
    "sclifosiseră": "sclifosi",
    "sclifosiserăm": "sclifosi",
    "sclifosiserăți": "sclifosi",
    "sclifosiseși": "sclifosi",
    "sclifosiși": "sclifosi",
    "sclifosit": "sclifosi",
    "sclifosiți": "sclifosi",
    "sclifosită": "sclifosit",
    "sclifosite": "sclifosit",
    "sclifosiți": "sclifosit",
    "nemaisclipind": "sclipi",
    "nemaisclipindu": "sclipi",
    "nesclipind": "sclipi",
    "nesclipindu": "sclipi",
    "sclipea": "sclipi",
    "sclipeai": "sclipi",
    "sclipeam": "sclipi",
    "sclipească": "sclipi",
    "sclipeați": "sclipi",
    "sclipeau": "sclipi",
    "sclipesc": "sclipi",
    "sclipește": "sclipi",
    "sclipești": "sclipi",
    "sclipii": "sclipi",
    "sclipim": "sclipi",
    "sclipind": "sclipi",
    "sclipindu": "sclipi",
    "sclipiră": "sclipi",
    "sclipirăm": "sclipi",
    "sclipirăți": "sclipi",
    "sclipise": "sclipi",
    "sclipisem": "sclipi",
    "sclipiseră": "sclipi",
    "sclipiserăm": "sclipi",
    "sclipiserăți": "sclipi",
    "sclipiseși": "sclipi",
    "sclipiși": "sclipi",
    "sclipit": "sclipi",
    "sclipiți": "sclipi",
    "sclipirea": "sclipire",
    "sclipiri": "sclipire",
    "sclipirii": "sclipire",
    "sclipirile": "sclipire",
    "sclipirilor": "sclipire",
    "sclipită": "sclipit",
    "sclipite": "sclipit",
    "sclipiți": "sclipit",
    "sclipitoare": "sclipitor",
    "sclipitoarea": "sclipitor",
    "sclipitoarei": "sclipitor",
    "sclipitoarele": "sclipitor",
    "sclipitoarelor": "sclipitor",
    "sclipitori": "sclipitor",
    "sclipitorii": "sclipitor",
    "sclipitorilor": "sclipitor",
    "sclipitorul": "sclipitor",
    "sclipitorului": "sclipitor",
    "scoaba": "scoabă",
    "scoabe": "scoabă",
    "scoabei": "scoabă",
    "scoabele": "scoabă",
    "scoabelor": "scoabă",
    "șc.": "școală",
    "școala": "școală",
    "școli": "școală",
    "școlii": "școală",
    "școlile": "școală",
    "școlilor": "școală",
    "scoarța": "scoarță",
    "scoarțe": "scoarță",
    "scoarței": "scoarță",
    "scoarțele": "scoarță",
    "scoarțelor": "scoarță",
    "nemaiscoțând": "scoate",
    "nemaiscoțându": "scoate",
    "nescoțând": "scoate",
    "nescoțându": "scoate",
    "scoase": "scoate",
    "scoaseră": "scoate",
    "scoaserăm": "scoate",
    "scoaserăți": "scoate",
    "scoată": "scoate",
    "scoatem": "scoate",
    "scoateți": "scoate",
    "scos": "scoate",
    "scosei": "scoate",
    "scosese": "scoate",
    "scosesem": "scoate",
    "scoseseră": "scoate",
    "scoseserăm": "scoate",
    "scoseserăți": "scoate",
    "scoseseși": "scoate",
    "scoseși": "scoate",
    "scot": "scoate",
    "scoțând": "scoate",
    "scoțându": "scoate",
    "scotea": "scoate",
    "scoteai": "scoate",
    "scoteam": "scoate",
    "scoteați": "scoate",
    "scoteau": "scoate",
    "scoți": "scoate",
    "scoaterea": "scoatere",
    "scoatereo": "scoatere",
    "scoateri": "scoatere",
    "scoaterii": "scoatere",
    "scoaterile": "scoatere",
    "scoaterilor": "scoatere",
    "nemaiscobind": "scobi",
    "nemaiscobindu": "scobi",
    "nescobind": "scobi",
    "nescobindu": "scobi",
    "scobea": "scobi",
    "scobeai": "scobi",
    "scobeam": "scobi",
    "scobească": "scobi",
    "scobeați": "scobi",
    "scobeau": "scobi",
    "scobesc": "scobi",
    "scobește": "scobi",
    "scobești": "scobi",
    "scobii": "scobi",
    "scobim": "scobi",
    "scobind": "scobi",
    "scobindu": "scobi",
    "scobiră": "scobi",
    "scobirăm": "scobi",
    "scobirăți": "scobi",
    "scobise": "scobi",
    "scobisem": "scobi",
    "scobiseră": "scobi",
    "scobiserăm": "scobi",
    "scobiserăți": "scobi",
    "scobiseși": "scobi",
    "scobiși": "scobi",
    "scobit": "scobi",
    "scobiți": "scobi",
    "scobită": "scobit",
    "scobite": "scobit",
    "scobiți": "scobit",
    "scobitoarea": "scobitoare",
    "scobitori": "scobitoare",
    "scobitorii": "scobitoare",
    "scobitorile": "scobitoare",
    "scobitorilor": "scobitoare",
    "scobitura": "scobitură",
    "scobituri": "scobitură",
    "scobiturii": "scobitură",
    "scobiturile": "scobitură",
    "scobiturilor": "scobitură",
    "scocul": "scoc",
    "scocului": "scoc",
    "scocuri": "scoc",
    "scocurile": "scoc",
    "scocurilor": "scoc",
    "scofala": "scofală",
    "scofale": "scofală",
    "scofalei": "scofală",
    "nemaiscofâlcind": "scofâlci",
    "nemaiscofâlcindu": "scofâlci",
    "nescofâlcind": "scofâlci",
    "nescofâlcindu": "scofâlci",
    "scofâlcea": "scofâlci",
    "scofâlceai": "scofâlci",
    "scofâlceam": "scofâlci",
    "scofâlcească": "scofâlci",
    "scofâlceați": "scofâlci",
    "scofâlceau": "scofâlci",
    "scofâlcesc": "scofâlci",
    "scofâlcește": "scofâlci",
    "scofâlcești": "scofâlci",
    "scofâlcii": "scofâlci",
    "scofâlcim": "scofâlci",
    "scofâlcind": "scofâlci",
    "scofâlcindu": "scofâlci",
    "scofâlciră": "scofâlci",
    "scofâlcirăm": "scofâlci",
    "scofâlcirăți": "scofâlci",
    "scofâlcise": "scofâlci",
    "scofâlcisem": "scofâlci",
    "scofâlciseră": "scofâlci",
    "scofâlciserăm": "scofâlci",
    "scofâlciserăți": "scofâlci",
    "scofâlciseși": "scofâlci",
    "scofâlciși": "scofâlci",
    "scofâlcit": "scofâlci",
    "scofâlciți": "scofâlci",
    "scofâlcirea": "scofâlcire",
    "scofâlciri": "scofâlcire",
    "scofâlcirii": "scofâlcire",
    "scofâlcirile": "scofâlcire",
    "scofâlcirilor": "scofâlcire",
    "scofâlcită": "scofâlcit",
    "scofâlcite": "scofâlcit",
    "scofâlciți": "scofâlcit",
    "scoica": "scoică",
    "scoici": "scoică",
    "scoicii": "scoică",
    "scoicile": "scoică",
    "scoicilor": "scoică",
    "școlară": "școlar",
    "școlare": "școlar",
    "școlari": "școlar",
    "școlarii": "școlar",
    "școlarilor": "școlar",
    "școlarul": "școlar",
    "școlarului": "școlar",
    "nemaișcolărind": "școlări",
    "nemaișcolărindu": "școlări",
    "neșcolărind": "școlări",
    "neșcolărindu": "școlări",
    "școlărea": "școlări",
    "școlăreai": "școlări",
    "școlăream": "școlări",
    "școlărească": "școlări",
    "școlăreați": "școlări",
    "școlăreau": "școlări",
    "școlăresc": "școlări",
    "școlărește": "școlări",
    "școlărești": "școlări",
    "școlării": "școlări",
    "școlărim": "școlări",
    "școlărind": "școlări",
    "școlărindu": "școlări",
    "școlăriră": "școlări",
    "școlărirăm": "școlări",
    "școlărirăți": "școlări",
    "școlărise": "școlări",
    "școlărisem": "școlări",
    "școlăriseră": "școlări",
    "școlăriserăm": "școlări",
    "școlăriserăți": "școlări",
    "școlăriseși": "școlări",
    "școlăriși": "școlări",
    "școlărit": "școlări",
    "școlăriți": "școlări",
    "școlărisme": "școlărism",
    "școlărismele": "școlărism",
    "școlărismelor": "școlărism",
    "școlărismul": "școlărism",
    "școlărismului": "școlărism",
    "școlărită": "școlărit",
    "școlărite": "școlărit",
    "școlăriți": "școlărit",
    "școlărița": "școlăriță",
    "școlărițe": "școlăriță",
    "școlăriței": "școlăriță",
    "școlărițele": "școlăriță",
    "școlărițelor": "școlăriță",
    "nemaișcolarizând": "școlariza",
    "nemaișcolarizându": "școlariza",
    "neșcolarizând": "școlariza",
    "neșcolarizându": "școlariza",
    "școlariză": "școlariza",
    "școlarizai": "școlariza",
    "școlarizam": "școlariza",
    "școlarizăm": "școlariza",
    "școlarizând": "școlariza",
    "școlarizându": "școlariza",
    "școlarizară": "școlariza",
    "școlarizarăm": "școlariza",
    "școlarizarăți": "școlariza",
    "școlarizase": "școlariza",
    "școlarizasem": "școlariza",
    "școlarizaseră": "școlariza",
    "școlarizaserăm": "școlariza",
    "școlarizaserăți": "școlariza",
    "școlarizaseși": "școlariza",
    "școlarizași": "școlariza",
    "școlarizat": "școlariza",
    "școlarizați": "școlariza",
    "școlarizau": "școlariza",
    "școlarizează": "școlariza",
    "școlarizez": "școlariza",
    "școlarizeze": "școlariza",
    "școlarizezi": "școlariza",
    "școlarizarea": "școlarizare",
    "școlarizareo": "școlarizare",
    "școlarizări": "școlarizare",
    "școlarizării": "școlarizare",
    "școlarizările": "școlarizare",
    "școlarizărilor": "școlarizare",
    "școlarizată": "școlarizat",
    "școlarizate": "școlarizat",
    "școlarizați": "școlarizat",
    "scolia": "scolie",
    "scoliei": "scolie",
    "scolii": "scolie",
    "scoliile": "scolie",
    "scoliilor": "scolie",
    "scolioza": "scolioză",
    "scolioze": "scolioză",
    "scoliozei": "scolioză",
    "scoliozele": "scolioză",
    "scoliozelor": "scolioză",
    "sconcși": "sconcs",
    "sconcșii": "sconcs",
    "sconcșilor": "sconcs",
    "sconcsul": "sconcs",
    "sconcsului": "sconcs",
    "scontul": "scont",
    "scontului": "scont",
    "sconturi": "scont",
    "sconturile": "scont",
    "sconturilor": "scont",
    "nemaiscontând": "sconta",
    "nemaiscontându": "sconta",
    "nescontând": "sconta",
    "nescontându": "sconta",
    "scontă": "sconta",
    "scontai": "sconta",
    "scontam": "sconta",
    "scontăm": "sconta",
    "scontând": "sconta",
    "scontându": "sconta",
    "scontară": "sconta",
    "scontarăm": "sconta",
    "scontarăți": "sconta",
    "scontase": "sconta",
    "scontasem": "sconta",
    "scontaseră": "sconta",
    "scontaserăm": "sconta",
    "scontaserăți": "sconta",
    "scontaseși": "sconta",
    "scontași": "sconta",
    "scontat": "sconta",
    "scontați": "sconta",
    "scontau": "sconta",
    "scontează": "sconta",
    "scontez": "sconta",
    "sconteze": "sconta",
    "scontezi": "sconta",
    "scontată": "scontat",
    "scontate": "scontat",
    "scontați": "scontat",
    "scopul": "scop",
    "scopului": "scop",
    "scopuri": "scop",
    "scopurile": "scop",
    "scopurilor": "scop",
    "scorul": "scor",
    "scorului": "scor",
    "scoruri": "scor",
    "scorurile": "scor",
    "scorurilor": "scor",
    "scorbura": "scorbură",
    "scorburi": "scorbură",
    "scorburii": "scorbură",
    "scorburile": "scorbură",
    "scorburilor": "scorbură",
    "scorbutul": "scorbut",
    "scorbutului": "scorbut",
    "scorbuturi": "scorbut",
    "scorbuturile": "scorbut",
    "scorbuturilor": "scorbut",
    "scoreri": "scorer",
    "scorerii": "scorer",
    "scorerilor": "scorer",
    "scorerul": "scorer",
    "scorerului": "scorer",
    "nemaiscormonind": "scormoni",
    "nemaiscormonindu": "scormoni",
    "nescormonind": "scormoni",
    "nescormonindu": "scormoni",
    "scormonea": "scormoni",
    "scormoneai": "scormoni",
    "scormoneam": "scormoni",
    "scormonească": "scormoni",
    "scormoneați": "scormoni",
    "scormoneau": "scormoni",
    "scormonesc": "scormoni",
    "scormonește": "scormoni",
    "scormonești": "scormoni",
    "scormonii": "scormoni",
    "scormonim": "scormoni",
    "scormonind": "scormoni",
    "scormonindu": "scormoni",
    "scormoniră": "scormoni",
    "scormonirăm": "scormoni",
    "scormonirăți": "scormoni",
    "scormonise": "scormoni",
    "scormonisem": "scormoni",
    "scormoniseră": "scormoni",
    "scormoniserăm": "scormoni",
    "scormoniserăți": "scormoni",
    "scormoniseși": "scormoni",
    "scormoniși": "scormoni",
    "scormonit": "scormoni",
    "scormoniți": "scormoni",
    "scormonită": "scormonit",
    "scormonite": "scormonit",
    "scormoniți": "scormonit",
    "scornelei": "scorneală",
    "scorneli": "scorneală",
    "scornelii": "scorneală",
    "scornelile": "scorneală",
    "scornelilor": "scorneală",
    "nemaiscornind": "scorni",
    "nemaiscornindu": "scorni",
    "nescornind": "scorni",
    "nescornindu": "scorni",
    "scornea": "scorni",
    "scorneai": "scorni",
    "scorneam": "scorni",
    "scornească": "scorni",
    "scorneați": "scorni",
    "scorneau": "scorni",
    "scornesc": "scorni",
    "scornește": "scorni",
    "scornești": "scorni",
    "scornii": "scorni",
    "scornim": "scorni",
    "scornind": "scorni",
    "scornindu": "scorni",
    "scorniră": "scorni",
    "scornirăm": "scorni",
    "scornirăți": "scorni",
    "scornise": "scorni",
    "scornisem": "scorni",
    "scorniseră": "scorni",
    "scorniserăm": "scorni",
    "scorniserăți": "scorni",
    "scorniseși": "scorni",
    "scorniși": "scorni",
    "scornit": "scorni",
    "scorniți": "scorni",
    "scorniceșteana": "scorniceștean",
    "scorniceșteană": "scorniceștean",
    "scorniceșteanul": "scorniceștean",
    "scorniceșteanului": "scorniceștean",
    "scorniceștene": "scorniceștean",
    "scorniceștenei": "scorniceștean",
    "scorniceștenele": "scorniceștean",
    "scorniceștenelor": "scorniceștean",
    "scorniceșteni": "scorniceștean",
    "scorniceștenii": "scorniceștean",
    "scorniceștenilor": "scorniceștean",
    "scorniceșteanca": "scorniceșteancă",
    "scorniceștence": "scorniceșteancă",
    "scorniceștencei": "scorniceșteancă",
    "scorniceștencele": "scorniceșteancă",
    "scorniceștencelor": "scorniceșteancă",
    "scornirea": "scornire",
    "scorniri": "scornire",
    "scornirii": "scornire",
    "scornirile": "scornire",
    "scornirilor": "scornire",
    "scornită": "scornit",
    "scornite": "scornit",
    "scorniți": "scornit",
    "nemaiscorojind": "scoroji",
    "nemaiscorojindu": "scoroji",
    "nescorojind": "scoroji",
    "nescorojindu": "scoroji",
    "scorojea": "scoroji",
    "scorojeai": "scoroji",
    "scorojeam": "scoroji",
    "scorojească": "scoroji",
    "scorojeați": "scoroji",
    "scorojeau": "scoroji",
    "scorojesc": "scoroji",
    "scorojește": "scoroji",
    "scorojești": "scoroji",
    "scorojii": "scoroji",
    "scorojim": "scoroji",
    "scorojind": "scoroji",
    "scorojindu": "scoroji",
    "scorojiră": "scoroji",
    "scorojirăm": "scoroji",
    "scorojirăți": "scoroji",
    "scorojise": "scoroji",
    "scorojisem": "scoroji",
    "scorojiseră": "scoroji",
    "scorojiserăm": "scoroji",
    "scorojiserăți": "scoroji",
    "scorojiseși": "scoroji",
    "scorojiși": "scoroji",
    "scorojit": "scoroji",
    "scorojiți": "scoroji",
    "scorojită": "scorojit",
    "scorojite": "scorojit",
    "scorojiți": "scorojit",
    "scorpia": "scorpie",
    "scorpiei": "scorpie",
    "scorpii": "scorpie",
    "scorpiile": "scorpie",
    "scorpiilor": "scorpie",
    "scorpioni": "scorpion",
    "scorpionii": "scorpion",
    "scorpionilor": "scorpion",
    "scorpionul": "scorpion",
    "scorpionului": "scorpion",
    "scorțari": "scorțar",
    "scorțarii": "scorțar",
    "scorțarilor": "scorțar",
    "scorțarul": "scorțar",
    "scorțarului": "scorțar",
    "scorțișoara": "scorțișoară",
    "scorțișoarei": "scorțișoară",
    "scorțișoarele": "scorțișoară",
    "scorțișoarelor": "scorțișoară",
    "scorțoasa": "scorțos",
    "scorțoasă": "scorțos",
    "scorțoase": "scorțos",
    "scorțoasei": "scorțos",
    "scorțoasele": "scorțos",
    "scorțoaselor": "scorțos",
    "scorțoși": "scorțos",
    "scorțoșii": "scorțos",
    "scorțoșilor": "scorțos",
    "scorțosul": "scorțos",
    "scorțosului": "scorțos",
    "scoasă": "scos",
    "scoase": "scos",
    "scoși": "scos",
    "scosul": "scos",
    "scosului": "scos",
    "scoțiana": "scoțian",
    "scoțiană": "scoțian",
    "scoțianul": "scoțian",
    "scoțianului": "scoțian",
    "scoțiene": "scoțian",
    "scoțienei": "scoțian",
    "scoțienele": "scoțian",
    "scoțienelor": "scoțian",
    "scoțieni": "scoțian",
    "scoțienii": "scoțian",
    "scoțienilor": "scoțian",
    "scoțiana": "scoțiană",
    "scoțiene": "scoțiană",
    "scoțienei": "scoțiană",
    "scoțienele": "scoțiană",
    "scoțienelor": "scoțiană",
    "nemaiscotocind": "scotoci",
    "nemaiscotocindu": "scotoci",
    "nescotocind": "scotoci",
    "nescotocindu": "scotoci",
    "scotocea": "scotoci",
    "scotoceai": "scotoci",
    "scotoceam": "scotoci",
    "scotocească": "scotoci",
    "scotoceați": "scotoci",
    "scotoceau": "scotoci",
    "scotocesc": "scotoci",
    "scotocește": "scotoci",
    "scotocești": "scotoci",
    "scotocii": "scotoci",
    "scotocim": "scotoci",
    "scotocind": "scotoci",
    "scotocindu": "scotoci",
    "scotociră": "scotoci",
    "scotocirăm": "scotoci",
    "scotocirăți": "scotoci",
    "scotocise": "scotoci",
    "scotocisem": "scotoci",
    "scotociseră": "scotoci",
    "scotociserăm": "scotoci",
    "scotociserăți": "scotoci",
    "scotociseși": "scotoci",
    "scotociși": "scotoci",
    "scotocit": "scotoci",
    "scotociți": "scotoci",
    "scotocită": "scotocit",
    "scotocite": "scotocit",
    "scotociți": "scotocit",
    "scrânciobul": "scrânciob",
    "scrânciobului": "scrânciob",
    "scrâncioburi": "scrânciob",
    "scrâncioburile": "scrânciob",
    "scrâncioburilor": "scrânciob",
    "nemaiscrântind": "scrânti",
    "nemaiscrântindu": "scrânti",
    "nescrântind": "scrânti",
    "nescrântindu": "scrânti",
    "scrântea": "scrânti",
    "scrânteai": "scrânti",
    "scrânteam": "scrânti",
    "scrântească": "scrânti",
    "scrânteați": "scrânti",
    "scrânteau": "scrânti",
    "scrântesc": "scrânti",
    "scrântește": "scrânti",
    "scrântești": "scrânti",
    "scrântii": "scrânti",
    "scrântim": "scrânti",
    "scrântind": "scrânti",
    "scrântindu": "scrânti",
    "scrântiră": "scrânti",
    "scrântirăm": "scrânti",
    "scrântirăți": "scrânti",
    "scrântise": "scrânti",
    "scrântisem": "scrânti",
    "scrântiseră": "scrânti",
    "scrântiserăm": "scrânti",
    "scrântiserăți": "scrânti",
    "scrântiseși": "scrânti",
    "scrântiși": "scrânti",
    "scrântit": "scrânti",
    "scrântiți": "scrânti",
    "scrântită": "scrântit",
    "scrântite": "scrântit",
    "scrântiți": "scrântit",
    "scrântitura": "scrântitură",
    "scrântituri": "scrântitură",
    "scrântiturii": "scrântitură",
    "scrântiturile": "scrântitură",
    "scrântiturilor": "scrântitură",
    "scrâșnete": "scrâșnet",
    "scrâșnetele": "scrâșnet",
    "scrâșnetelor": "scrâșnet",
    "scrâșnetul": "scrâșnet",
    "scrâșnetului": "scrâșnet",
    "nemaiscrâșnind": "scrâșni",
    "nemaiscrâșnindu": "scrâșni",
    "nescrâșnind": "scrâșni",
    "nescrâșnindu": "scrâșni",
    "scrâșnea": "scrâșni",
    "scrâșneai": "scrâșni",
    "scrâșneam": "scrâșni",
    "scrâșnească": "scrâșni",
    "scrâșneați": "scrâșni",
    "scrâșneau": "scrâșni",
    "scrâșnesc": "scrâșni",
    "scrâșnește": "scrâșni",
    "scrâșnești": "scrâșni",
    "scrâșnii": "scrâșni",
    "scrâșnim": "scrâșni",
    "scrâșnind": "scrâșni",
    "scrâșnindu": "scrâșni",
    "scrâșniră": "scrâșni",
    "scrâșnirăm": "scrâșni",
    "scrâșnirăți": "scrâșni",
    "scrâșnise": "scrâșni",
    "scrâșnisem": "scrâșni",
    "scrâșniseră": "scrâșni",
    "scrâșniserăm": "scrâșni",
    "scrâșniserăți": "scrâșni",
    "scrâșniseși": "scrâșni",
    "scrâșniși": "scrâșni",
    "scrâșnit": "scrâșni",
    "scrâșniți": "scrâșni",
    "scrâșnirea": "scrâșnire",
    "scrâșnireo": "scrâșnire",
    "scrâșniri": "scrâșnire",
    "scrâșnirii": "scrâșnire",
    "scrâșnirile": "scrâșnire",
    "scrâșnirilor": "scrâșnire",
    "scrâșnita": "scrâșnit",
    "scrâșnită": "scrâșnit",
    "scrâșnite": "scrâșnit",
    "scrâșnitei": "scrâșnit",
    "scrâșnitele": "scrâșnit",
    "scrâșnitelor": "scrâșnit",
    "scrâșniți": "scrâșnit",
    "scrâșniții": "scrâșnit",
    "scrâșniților": "scrâșnit",
    "scrâșnito": "scrâșnit",
    "scrâșnitul": "scrâșnit",
    "scrâșnitule": "scrâșnit",
    "scrâșnitului": "scrâșnit",
    "scrâșnitura": "scrâșnitură",
    "scrâșnituri": "scrâșnitură",
    "scrâșniturii": "scrâșnitură",
    "scrâșniturile": "scrâșnitură",
    "scrâșniturilor": "scrâșnitură",
    "scrâșnituro": "scrâșnitură",
    "scremete": "scremet",
    "scremetele": "scremet",
    "scremetelor": "scremet",
    "scremetul": "scremet",
    "scremetului": "scremet",
    "scremută": "scremut",
    "scremute": "scremut",
    "scremuți": "scremut",
    "scribi": "scrib",
    "scribii": "scrib",
    "scribilor": "scrib",
    "scribul": "scrib",
    "scribului": "scrib",
    "nemaiscriind": "scrie",
    "nemaiscriindu": "scrie",
    "nescriind": "scrie",
    "nescriindu": "scrie",
    "scria": "scrie",
    "scriai": "scrie",
    "scriam": "scrie",
    "scriați": "scrie",
    "scriau": "scrie",
    "scriem": "scrie",
    "scrieți": "scrie",
    "scrii": "scrie",
    "scriind": "scrie",
    "scriindu": "scrie",
    "scris": "scrie",
    "scrise": "scrie",
    "scrisei": "scrie",
    "scriseră": "scrie",
    "scriserăm": "scrie",
    "scriserăți": "scrie",
    "scrisese": "scrie",
    "scrisesem": "scrie",
    "scriseseră": "scrie",
    "scriseserăm": "scrie",
    "scriseserăți": "scrie",
    "scriseseși": "scrie",
    "scriseși": "scrie",
    "scriu": "scrie",
    "scrierea": "scriere",
    "scriereo": "scriere",
    "scrieri": "scriere",
    "scrierii": "scriere",
    "scrierile": "scriere",
    "scrierilor": "scriere",
    "scrievorbitorul": "scrievorbitor",
    "scrievorbitorului": "scrievorbitor",
    "scriitoarea": "scriitoare",
    "scriitoarei": "scriitoare",
    "scriitoarele": "scriitoare",
    "scriitoarelor": "scriitoare",
    "scriitori": "scriitor",
    "scriitorii": "scriitor",
    "scriitorilor": "scriitor",
    "scriitorul": "scriitor",
    "scriitorului": "scriitor",
    "scriitoriceasca": "scriitoricesc",
    "scriitoricească": "scriitoricesc",
    "scriitoricescul": "scriitoricesc",
    "scriitoricescului": "scriitoricesc",
    "scriitoricești": "scriitoricesc",
    "scriitoriceștii": "scriitoricesc",
    "scriitoriceștile": "scriitoricesc",
    "scriitoriceștilor": "scriitoricesc",
    "scriitorimea": "scriitorime",
    "scriitorimi": "scriitorime",
    "scriitorimii": "scriitorime",
    "scriitorimile": "scriitorime",
    "scriitorimilor": "scriitorime",
    "scriitura": "scriitură",
    "scriituri": "scriitură",
    "scriiturii": "scriitură",
    "scriiturile": "scriitură",
    "scriiturilor": "scriitură",
    "scrijelarea": "scrijelare",
    "scrijelări": "scrijelare",
    "scrijelării": "scrijelare",
    "scrijelările": "scrijelare",
    "scrijelărilor": "scrijelare",
    "nemaiscrijelind": "scrijeli",
    "nemaiscrijelindu": "scrijeli",
    "nescrijelind": "scrijeli",
    "nescrijelindu": "scrijeli",
    "scrijelea": "scrijeli",
    "scrijeleai": "scrijeli",
    "scrijeleam": "scrijeli",
    "scrijelească": "scrijeli",
    "scrijeleați": "scrijeli",
    "scrijeleau": "scrijeli",
    "scrijelesc": "scrijeli",
    "scrijelește": "scrijeli",
    "scrijelești": "scrijeli",
    "scrijelii": "scrijeli",
    "scrijelim": "scrijeli",
    "scrijelind": "scrijeli",
    "scrijelindu": "scrijeli",
    "scrijeliră": "scrijeli",
    "scrijelirăm": "scrijeli",
    "scrijelirăți": "scrijeli",
    "scrijelise": "scrijeli",
    "scrijelisem": "scrijeli",
    "scrijeliseră": "scrijeli",
    "scrijeliserăm": "scrijeli",
    "scrijeliserăți": "scrijeli",
    "scrijeliseși": "scrijeli",
    "scrijeliși": "scrijeli",
    "scrijelit": "scrijeli",
    "scrijeliți": "scrijeli",
    "scrijelirea": "scrijelire",
    "scrijelireo": "scrijelire",
    "scrijeliri": "scrijelire",
    "scrijelirii": "scrijelire",
    "scrijelirile": "scrijelire",
    "scrijelirilor": "scrijelire",
    "scrijelita": "scrijelit",
    "scrijelită": "scrijelit",
    "scrijelite": "scrijelit",
    "scrijelitei": "scrijelit",
    "scrijelitele": "scrijelit",
    "scrijelitelor": "scrijelit",
    "scrijeliți": "scrijelit",
    "scrijeliții": "scrijelit",
    "scrijeliților": "scrijelit",
    "scrijelito": "scrijelit",
    "scrijelitul": "scrijelit",
    "scrijelitule": "scrijelit",
    "scrijelitului": "scrijelit",
    "scrijelitura": "scrijelitură",
    "scrijelituri": "scrijelitură",
    "scrijeliturii": "scrijelitură",
    "scrijeliturile": "scrijelitură",
    "scrijeliturilor": "scrijelitură",
    "scrijelituro": "scrijelitură",
    "scrima": "scrimă",
    "scrime": "scrimă",
    "scrimei": "scrimă",
    "scrimeri": "scrimer",
    "scrimerii": "scrimer",
    "scrimerilor": "scrimer",
    "scrimerul": "scrimer",
    "scrimerului": "scrimer",
    "scrimera": "scrimeră",
    "scrimere": "scrimeră",
    "scrimerei": "scrimeră",
    "scrimerele": "scrimeră",
    "scrimerelor": "scrimeră",
    "scrinul": "scrin",
    "scrinului": "scrin",
    "scrinuri": "scrin",
    "scrinurile": "scrin",
    "scrinurilor": "scrin",
    "scripca": "scripcă",
    "scripci": "scripcă",
    "scripcii": "scripcă",
    "scripcile": "scripcă",
    "scripcilor": "scripcă",
    "scripcari": "scripcar",
    "scripcarii": "scripcar",
    "scripcarilor": "scripcar",
    "scripcarul": "scripcar",
    "scripcarului": "scripcar",
    "scripetele": "scripete",
    "scripetelui": "scripete",
    "scripeți": "scripete",
    "scripeții": "scripete",
    "scripeților": "scripete",
    "scripta": "scriptă",
    "scripte": "scriptă",
    "scriptei": "scriptă",
    "scriptele": "scriptă",
    "scriptelor": "scriptă",
    "scriptica": "scriptic",
    "scriptică": "scriptic",
    "scriptice": "scriptic",
    "scripticei": "scriptic",
    "scripticele": "scriptic",
    "scripticelor": "scriptic",
    "scriptici": "scriptic",
    "scripticii": "scriptic",
    "scripticilor": "scriptic",
    "scripticul": "scriptic",
    "scripticului": "scriptic",
    "scriptologi": "scriptolog",
    "scriptologii": "scriptolog",
    "scriptologilor": "scriptolog",
    "scriptologul": "scriptolog",
    "scriptologului": "scriptolog",
    "scriptologia": "scriptologie",
    "scriptologiei": "scriptologie",
    "scriptologii": "scriptologie",
    "scriptologiile": "scriptologie",
    "scriptologiilor": "scriptologie",
    "scriptomani": "scriptoman",
    "scriptomanii": "scriptoman",
    "scriptomanilor": "scriptoman",
    "scriptomanul": "scriptoman",
    "scriptomanului": "scriptoman",
    "scriptomana": "scriptomană",
    "scriptomane": "scriptomană",
    "scriptomanei": "scriptomană",
    "scriptomanele": "scriptomană",
    "scriptomanelor": "scriptomană",
    "scriptomania": "scriptomanie",
    "scriptomaniei": "scriptomanie",
    "scriptomanii": "scriptomanie",
    "scriptomaniile": "scriptomanie",
    "scriptomaniilor": "scriptomanie",
    "scriptura": "scriptură",
    "scripturi": "scriptură",
    "scripturii": "scriptură",
    "scripturile": "scriptură",
    "scripturilor": "scriptură",
    "scrisă": "scris",
    "scrise": "scris",
    "scriși": "scris",
    "scrisul": "scris",
    "scrisului": "scris",
    "scris-cititul": "scris-citit",
    "scrisoarea": "scrisoare",
    "scrisori": "scrisoare",
    "scrisorii": "scrisoare",
    "scrisorile": "scrisoare",
    "scrisorilor": "scrisoare",
    "scroafa": "scroafă",
    "scroafe": "scroafă",
    "scroafei": "scroafă",
    "scroafele": "scroafă",
    "scroafelor": "scroafă",
    "scrobul": "scrob",
    "scrobului": "scrob",
    "scroburi": "scrob",
    "scroburile": "scrob",
    "scroburilor": "scrob",
    "nemaiscrobind": "scrobi",
    "nemaiscrobindu": "scrobi",
    "nescrobind": "scrobi",
    "nescrobindu": "scrobi",
    "scrobea": "scrobi",
    "scrobeai": "scrobi",
    "scrobeam": "scrobi",
    "scrobească": "scrobi",
    "scrobeați": "scrobi",
    "scrobeau": "scrobi",
    "scrobesc": "scrobi",
    "scrobește": "scrobi",
    "scrobești": "scrobi",
    "scrobii": "scrobi",
    "scrobim": "scrobi",
    "scrobind": "scrobi",
    "scrobindu": "scrobi",
    "scrobiră": "scrobi",
    "scrobirăm": "scrobi",
    "scrobirăți": "scrobi",
    "scrobise": "scrobi",
    "scrobisem": "scrobi",
    "scrobiseră": "scrobi",
    "scrobiserăm": "scrobi",
    "scrobiserăți": "scrobi",
    "scrobiseși": "scrobi",
    "scrobiși": "scrobi",
    "scrobit": "scrobi",
    "scrobiți": "scrobi",
    "scrobită": "scrobit",
    "scrobite": "scrobit",
    "scrobiți": "scrobit",
    "scrofula": "scrofulă",
    "scrofule": "scrofulă",
    "scrofulei": "scrofulă",
    "scrofulele": "scrofulă",
    "scrofulelor": "scrofulă",
    "scrofuloasa": "scrofulos",
    "scrofuloasă": "scrofulos",
    "scrofuloase": "scrofulos",
    "scrofuloasei": "scrofulos",
    "scrofuloasele": "scrofulos",
    "scrofuloaselor": "scrofulos",
    "scrofuloși": "scrofulos",
    "scrofuloșii": "scrofulos",
    "scrofuloșilor": "scrofulos",
    "scrofulosul": "scrofulos",
    "scrofulosului": "scrofulos",
    "scrotul": "scrot",
    "scrotului": "scrot",
    "scroturi": "scrot",
    "scroturile": "scrot",
    "scroturilor": "scrot",
    "scrubere": "scruber",
    "scruberele": "scruber",
    "scruberelor": "scruber",
    "scruberul": "scruber",
    "scruberului": "scruber",
    "scrumul": "scrum",
    "scrumului": "scrum",
    "scrumbia": "scrumbie",
    "scrumbiei": "scrumbie",
    "scrumbii": "scrumbie",
    "scrumbiile": "scrumbie",
    "scrumbiilor": "scrumbie",
    "scrumelnița": "scrumelniță",
    "scrumelnițe": "scrumelniță",
    "scrumelniței": "scrumelniță",
    "scrumelnițele": "scrumelniță",
    "scrumelnițelor": "scrumelniță",
    "scrumiera": "scrumieră",
    "scrumiere": "scrumieră",
    "scrumierei": "scrumieră",
    "scrumierele": "scrumieră",
    "scrumierelor": "scrumieră",
    "scrupule": "scrupul",
    "scrupulele": "scrupul",
    "scrupulelor": "scrupul",
    "scrupulul": "scrupul",
    "scrupulului": "scrupul",
    "scrupuloasa": "scrupulos",
    "scrupuloasă": "scrupulos",
    "scrupuloase": "scrupulos",
    "scrupuloasei": "scrupulos",
    "scrupuloasele": "scrupulos",
    "scrupuloaselor": "scrupulos",
    "scrupuloși": "scrupulos",
    "scrupuloșii": "scrupulos",
    "scrupuloșilor": "scrupulos",
    "scrupulosul": "scrupulos",
    "scrupulosului": "scrupulos",
    "scrupulozitatea": "scrupulozitate",
    "scrupulozități": "scrupulozitate",
    "scrupulozității": "scrupulozitate",
    "scrupulozitățile": "scrupulozitate",
    "scrupulozităților": "scrupulozitate",
    "nemaiscrutând": "scruta",
    "nemaiscrutându": "scruta",
    "nescrutând": "scruta",
    "nescrutându": "scruta",
    "scrută": "scruta",
    "scrutai": "scruta",
    "scrutam": "scruta",
    "scrutăm": "scruta",
    "scrutând": "scruta",
    "scrutându": "scruta",
    "scrutară": "scruta",
    "scrutarăm": "scruta",
    "scrutarăți": "scruta",
    "scrutase": "scruta",
    "scrutasem": "scruta",
    "scrutaseră": "scruta",
    "scrutaserăm": "scruta",
    "scrutaserăți": "scruta",
    "scrutaseși": "scruta",
    "scrutași": "scruta",
    "scrutat": "scruta",
    "scrutați": "scruta",
    "scrutau": "scruta",
    "scrutează": "scruta",
    "scrutez": "scruta",
    "scruteze": "scruta",
    "scrutezi": "scruta",
    "scrutarea": "scrutare",
    "scrutări": "scrutare",
    "scrutării": "scrutare",
    "scrutările": "scrutare",
    "scrutărilor": "scrutare",
    "scrutată": "scrutat",
    "scrutate": "scrutat",
    "scrutați": "scrutat",
    "scrutine": "scrutin",
    "scrutinele": "scrutin",
    "scrutinelor": "scrutin",
    "scrutinul": "scrutin",
    "scrutinului": "scrutin",
    "scuarul": "scuar",
    "scuarului": "scuar",
    "scuaruri": "scuar",
    "scuarurile": "scuar",
    "scuarurilor": "scuar",
    "scudul": "scud",
    "scudului": "scud",
    "scuzi": "scud",
    "scuzii": "scud",
    "scuzilor": "scud",
    "scufa": "scufă",
    "scufe": "scufă",
    "scufei": "scufă",
    "scufele": "scufă",
    "scufelor": "scufă",
    "scufia": "scufie",
    "scufiei": "scufie",
    "scufii": "scufie",
    "scufiile": "scufie",
    "scufiilor": "scufie",
    "nemaiscufundând": "scufunda",
    "nemaiscufundându": "scufunda",
    "nescufundând": "scufunda",
    "nescufundându": "scufunda",
    "scufund": "scufunda",
    "scufundă": "scufunda",
    "scufundai": "scufunda",
    "scufundam": "scufunda",
    "scufundăm": "scufunda",
    "scufundând": "scufunda",
    "scufundându": "scufunda",
    "scufundară": "scufunda",
    "scufundarăm": "scufunda",
    "scufundarăți": "scufunda",
    "scufundase": "scufunda",
    "scufundasem": "scufunda",
    "scufundaseră": "scufunda",
    "scufundaserăm": "scufunda",
    "scufundaserăți": "scufunda",
    "scufundaseși": "scufunda",
    "scufundași": "scufunda",
    "scufundat": "scufunda",
    "scufundați": "scufunda",
    "scufundau": "scufunda",
    "scufunde": "scufunda",
    "scufunzi": "scufunda",
    "scufundarea": "scufundare",
    "scufundareo": "scufundare",
    "scufundări": "scufundare",
    "scufundării": "scufundare",
    "scufundările": "scufundare",
    "scufundărilor": "scufundare",
    "scufundata": "scufundat",
    "scufundată": "scufundat",
    "scufundate": "scufundat",
    "scufundatei": "scufundat",
    "scufundatele": "scufundat",
    "scufundatelor": "scufundat",
    "scufundați": "scufundat",
    "scufundații": "scufundat",
    "scufundaților": "scufundat",
    "scufundato": "scufundat",
    "scufundatul": "scufundat",
    "scufundatule": "scufundat",
    "scufundatului": "scufundat",
    "scufundători": "scufundător",
    "scufundătorii": "scufundător",
    "scufundătorilor": "scufundător",
    "scufundătorul": "scufundător",
    "scufundătorului": "scufundător",
    "scufundătura": "scufundătură",
    "scufundături": "scufundătură",
    "scufundăturii": "scufundătură",
    "scufundăturile": "scufundătură",
    "scufundăturilor": "scufundătură",
    "nemaiscuipând": "scuipa",
    "nemaiscuipându": "scuipa",
    "nescuipând": "scuipa",
    "nescuipându": "scuipa",
    "scuip": "scuipa",
    "scuipă": "scuipa",
    "scuipai": "scuipa",
    "scuipam": "scuipa",
    "scuipăm": "scuipa",
    "scuipând": "scuipa",
    "scuipându": "scuipa",
    "scuipară": "scuipa",
    "scuiparăm": "scuipa",
    "scuiparăți": "scuipa",
    "scuipase": "scuipa",
    "scuipasem": "scuipa",
    "scuipaseră": "scuipa",
    "scuipaserăm": "scuipa",
    "scuipaserăți": "scuipa",
    "scuipaseși": "scuipa",
    "scuipași": "scuipa",
    "scuipat": "scuipa",
    "scuipați": "scuipa",
    "scuipau": "scuipa",
    "scuipe": "scuipa",
    "scuipi": "scuipa",
    "scuiparea": "scuipare",
    "scuipareo": "scuipare",
    "scuipări": "scuipare",
    "scuipării": "scuipare",
    "scuipările": "scuipare",
    "scuipărilor": "scuipare",
    "scuipata": "scuipat",
    "scuipată": "scuipat",
    "scuipate": "scuipat",
    "scuipatei": "scuipat",
    "scuipatele": "scuipat",
    "scuipatelor": "scuipat",
    "scuipați": "scuipat",
    "scuipații": "scuipat",
    "scuipaților": "scuipat",
    "scuipato": "scuipat",
    "scuipatul": "scuipat",
    "scuipatule": "scuipat",
    "scuipatului": "scuipat",
    "scuipătoarea": "scuipătoare",
    "scuipătoarele": "scuipătoare",
    "scuipătoarelor": "scuipătoare",
    "scuipători": "scuipătoare",
    "scuipătorii": "scuipătoare",
    "sculul": "scul",
    "sculului": "scul",
    "sculuri": "scul",
    "sculurile": "scul",
    "sculurilor": "scul",
    "nemaisculând": "scula",
    "nemaisculându": "scula",
    "nesculând": "scula",
    "nesculându": "scula",
    "scoal'": "scula",
    "scoală": "scula",
    "scoale": "scula",
    "scol": "scula",
    "scoli": "scula",
    "sculă": "scula",
    "sculai": "scula",
    "sculam": "scula",
    "sculăm": "scula",
    "sculând": "scula",
    "sculându": "scula",
    "sculară": "scula",
    "scularăm": "scula",
    "scularăți": "scula",
    "sculase": "scula",
    "sculasem": "scula",
    "sculaseră": "scula",
    "sculaserăm": "scula",
    "sculaserăți": "scula",
    "sculaseși": "scula",
    "sculași": "scula",
    "sculat": "scula",
    "sculați": "scula",
    "sculau": "scula",
    "scula": "sculă",
    "scule": "sculă",
    "sculei": "sculă",
    "sculele": "sculă",
    "sculelor": "sculă",
    "sculamente": "sculament",
    "sculamentele": "sculament",
    "sculamentelor": "sculament",
    "sculamentul": "sculament",
    "sculamentului": "sculament",
    "scularea": "sculare",
    "sculareo": "sculare",
    "sculări": "sculare",
    "sculării": "sculare",
    "sculările": "sculare",
    "sculărilor": "sculare",
    "sculăria": "sculărie",
    "sculăriei": "sculărie",
    "sculării": "sculărie",
    "sculăriile": "sculărie",
    "sculăriilor": "sculărie",
    "sculata": "sculat",
    "sculată": "sculat",
    "sculate": "sculat",
    "sculatei": "sculat",
    "sculatele": "sculat",
    "sculatelor": "sculat",
    "sculați": "sculat",
    "sculații": "sculat",
    "sculaților": "sculat",
    "sculato": "sculat",
    "sculatul": "sculat",
    "sculatule": "sculat",
    "sculatului": "sculat",
    "sculeri": "sculer",
    "sculerii": "sculer",
    "sculerilor": "sculer",
    "sculerul": "sculer",
    "sculerului": "sculer",
    "nemaisculptând": "sculpta",
    "nemaisculptându": "sculpta",
    "nesculptând": "sculpta",
    "nesculptându": "sculpta",
    "sculptă": "sculpta",
    "sculptai": "sculpta",
    "sculptam": "sculpta",
    "sculptăm": "sculpta",
    "sculptând": "sculpta",
    "sculptându": "sculpta",
    "sculptară": "sculpta",
    "sculptarăm": "sculpta",
    "sculptarăți": "sculpta",
    "sculptase": "sculpta",
    "sculptasem": "sculpta",
    "sculptaseră": "sculpta",
    "sculptaserăm": "sculpta",
    "sculptaserăți": "sculpta",
    "sculptaseși": "sculpta",
    "sculptași": "sculpta",
    "sculptat": "sculpta",
    "sculptați": "sculpta",
    "sculptau": "sculpta",
    "sculptează": "sculpta",
    "sculptez": "sculpta",
    "sculpteze": "sculpta",
    "sculptezi": "sculpta",
    "sculptată": "sculptat",
    "sculptate": "sculptat",
    "sculptați": "sculptat",
    "sculptori": "sculptor",
    "sculptorii": "sculptor",
    "sculptorilor": "sculptor",
    "sculptorul": "sculptor",
    "sculptorului": "sculptor",
    "sculptorița": "sculptoriță",
    "sculptorițe": "sculptoriță",
    "sculptoriței": "sculptoriță",
    "sculptorițele": "sculptoriță",
    "sculptorițelor": "sculptoriță",
    "sculptura": "sculptură",
    "sculpturi": "sculptură",
    "sculpturii": "sculptură",
    "sculpturile": "sculptură",
    "sculpturilor": "sculptură",
    "sculpturalitatea": "sculpturalitate",
    "sculpturalități": "sculpturalitate",
    "sculpturalității": "sculpturalitate",
    "sculpturalitățile": "sculpturalitate",
    "sculpturalităților": "sculpturalitate",
    "scumpa": "scump",
    "scumpă": "scump",
    "scumpe": "scump",
    "scumpei": "scump",
    "scumpele": "scump",
    "scumpelor": "scump",
    "scumpi": "scump",
    "scumpii": "scump",
    "scumpilor": "scump",
    "scumpul": "scump",
    "scumpule": "scump",
    "scumpului": "scump",
    "scumpetea": "scumpete",
    "scumpetei": "scumpete",
    "scumpetele": "scumpete",
    "scumpetelor": "scumpete",
    "scumpeturi": "scumpete",
    "scumpeturile": "scumpete",
    "scumpeturilor": "scumpete",
    "nemaiscumpind": "scumpi",
    "nemaiscumpindu": "scumpi",
    "nescumpind": "scumpi",
    "nescumpindu": "scumpi",
    "scumpea": "scumpi",
    "scumpeai": "scumpi",
    "scumpeam": "scumpi",
    "scumpească": "scumpi",
    "scumpeați": "scumpi",
    "scumpeau": "scumpi",
    "scumpesc": "scumpi",
    "scumpește": "scumpi",
    "scumpești": "scumpi",
    "scumpii": "scumpi",
    "scumpim": "scumpi",
    "scumpind": "scumpi",
    "scumpindu": "scumpi",
    "scumpiră": "scumpi",
    "scumpirăm": "scumpi",
    "scumpirăți": "scumpi",
    "scumpise": "scumpi",
    "scumpisem": "scumpi",
    "scumpiseră": "scumpi",
    "scumpiserăm": "scumpi",
    "scumpiserăți": "scumpi",
    "scumpiseși": "scumpi",
    "scumpiși": "scumpi",
    "scumpit": "scumpi",
    "scumpiți": "scumpi",
    "scumpirea": "scumpire",
    "scumpiri": "scumpire",
    "scumpirii": "scumpire",
    "scumpirile": "scumpire",
    "scumpirilor": "scumpire",
    "scumpită": "scumpit",
    "scumpite": "scumpit",
    "scumpiți": "scumpit",
    "scunda": "scund",
    "scundă": "scund",
    "scunde": "scund",
    "scundei": "scund",
    "scundele": "scund",
    "scundelor": "scund",
    "scundul": "scund",
    "scundului": "scund",
    "scunzi": "scund",
    "scunzii": "scund",
    "scunzilor": "scund",
    "nemaiscurgând": "scurge",
    "nemaiscurgându": "scurge",
    "nescurgând": "scurge",
    "nescurgându": "scurge",
    "scurg": "scurge",
    "scurgă": "scurge",
    "scurgând": "scurge",
    "scurgându": "scurge",
    "scurgea": "scurge",
    "scurgeai": "scurge",
    "scurgeam": "scurge",
    "scurgeați": "scurge",
    "scurgeau": "scurge",
    "scurgem": "scurge",
    "scurgeți": "scurge",
    "scurgi": "scurge",
    "scurs": "scurge",
    "scurse": "scurge",
    "scursei": "scurge",
    "scurseră": "scurge",
    "scurserăm": "scurge",
    "scurserăți": "scurge",
    "scursese": "scurge",
    "scursesem": "scurge",
    "scurseseră": "scurge",
    "scurseserăm": "scurge",
    "scurseserăți": "scurge",
    "scurseseși": "scurge",
    "scurseși": "scurge",
    "scurgerea": "scurgere",
    "scurgeri": "scurgere",
    "scurgerii": "scurgere",
    "scurgerile": "scurgere",
    "scurgerilor": "scurgere",
    "nemaiscurmând": "scurma",
    "nemaiscurmându": "scurma",
    "nescurmând": "scurma",
    "nescurmându": "scurma",
    "scurm": "scurma",
    "scurmă": "scurma",
    "scurmai": "scurma",
    "scurmam": "scurma",
    "scurmăm": "scurma",
    "scurmând": "scurma",
    "scurmându": "scurma",
    "scurmară": "scurma",
    "scurmarăm": "scurma",
    "scurmarăți": "scurma",
    "scurmase": "scurma",
    "scurmasem": "scurma",
    "scurmaseră": "scurma",
    "scurmaserăm": "scurma",
    "scurmaserăți": "scurma",
    "scurmaseși": "scurma",
    "scurmași": "scurma",
    "scurmat": "scurma",
    "scurmați": "scurma",
    "scurmau": "scurma",
    "scurme": "scurma",
    "scurmi": "scurma",
    "scurmată": "scurmat",
    "scurmate": "scurmat",
    "scurmați": "scurmat",
    "scursă": "scurs",
    "scurse": "scurs",
    "scurși": "scurs",
    "scursoarea": "scursoare",
    "scursori": "scursoare",
    "scursorii": "scursoare",
    "scursorile": "scursoare",
    "scursorilor": "scursoare",
    "scursura": "scursură",
    "scursuri": "scursură",
    "scursurii": "scursură",
    "scursurile": "scursură",
    "scursurilor": "scursură",
    "scurta": "scurt",
    "scurtă": "scurt",
    "scurte": "scurt",
    "scurtei": "scurt",
    "scurtele": "scurt",
    "scurtelor": "scurt",
    "scurți": "scurt",
    "scurții": "scurt",
    "scurților": "scurt",
    "scurtul": "scurt",
    "scurtului": "scurt",
    "nemaiscurtând": "scurta",
    "nemaiscurtându": "scurta",
    "nescurtând": "scurta",
    "nescurtându": "scurta",
    "scurtă": "scurta",
    "scurtai": "scurta",
    "scurtam": "scurta",
    "scurtăm": "scurta",
    "scurtând": "scurta",
    "scurtându": "scurta",
    "scurtară": "scurta",
    "scurtarăm": "scurta",
    "scurtarăți": "scurta",
    "scurtase": "scurta",
    "scurtasem": "scurta",
    "scurtaseră": "scurta",
    "scurtaserăm": "scurta",
    "scurtaserăți": "scurta",
    "scurtaseși": "scurta",
    "scurtași": "scurta",
    "scurtat": "scurta",
    "scurtați": "scurta",
    "scurtau": "scurta",
    "scurtează": "scurta",
    "scurtez": "scurta",
    "scurteze": "scurta",
    "scurtezi": "scurta",
    "scurtarea": "scurtare",
    "scurtareo": "scurtare",
    "scurtări": "scurtare",
    "scurtării": "scurtare",
    "scurtările": "scurtare",
    "scurtărilor": "scurtare",
    "scurtată": "scurtat",
    "scurtate": "scurtat",
    "scurtați": "scurtat",
    "scurtătura": "scurtătură",
    "scurtături": "scurtătură",
    "scurtăturii": "scurtătură",
    "scurtăturile": "scurtătură",
    "scurtăturilor": "scurtătură",
    "scurtcircuite": "scurtcircuit",
    "scurtcircuitele": "scurtcircuit",
    "scurtcircuitelor": "scurtcircuit",
    "scurtcircuitul": "scurtcircuit",
    "scurtcircuitului": "scurtcircuit",
    "scurtcircuitarea": "scurtcircuitare",
    "scurtcircuitări": "scurtcircuitare",
    "scurtcircuitării": "scurtcircuitare",
    "scurtcircuitările": "scurtcircuitare",
    "scurtcircuitărilor": "scurtcircuitare",
    "scurteica": "scurteică",
    "scurteici": "scurteică",
    "scurteicii": "scurteică",
    "scurteicile": "scurteică",
    "scurteicilor": "scurteică",
    "scurtimea": "scurtime",
    "scurtimi": "scurtime",
    "scurtimii": "scurtime",
    "scurtimile": "scurtime",
    "scurtimilor": "scurtime",
    "scurtmetraje": "scurtmetraj",
    "scurtmetrajele": "scurtmetraj",
    "scurtmetrajelor": "scurtmetraj",
    "scurtmetrajul": "scurtmetraj",
    "scurtmetrajului": "scurtmetraj",
    "scutul": "scut",
    "scutului": "scut",
    "scuturi": "scut",
    "scuturile": "scut",
    "scuturilor": "scut",
    "scutece": "scutec",
    "scutecele": "scutec",
    "scutecelor": "scutec",
    "scutecul": "scutec",
    "scutecului": "scutec",
    "scutere": "scuter",
    "scuterele": "scuter",
    "scuterelor": "scuter",
    "scuterul": "scuter",
    "scuterului": "scuter",
    "nemaiscutind": "scuti",
    "nemaiscutindu": "scuti",
    "nescutind": "scuti",
    "nescutindu": "scuti",
    "scutea": "scuti",
    "scuteai": "scuti",
    "scuteam": "scuti",
    "scutească": "scuti",
    "scuteați": "scuti",
    "scuteau": "scuti",
    "scutesc": "scuti",
    "scutește": "scuti",
    "scutești": "scuti",
    "scutii": "scuti",
    "scutim": "scuti",
    "scutind": "scuti",
    "scutindu": "scuti",
    "scutiră": "scuti",
    "scutirăm": "scuti",
    "scutirăți": "scuti",
    "scutise": "scuti",
    "scutisem": "scuti",
    "scutiseră": "scuti",
    "scutiserăm": "scuti",
    "scutiserăți": "scuti",
    "scutiseși": "scuti",
    "scutiși": "scuti",
    "scutit": "scuti",
    "scutiți": "scuti",
    "scutieri": "scutier",
    "scutierii": "scutier",
    "scutierilor": "scutier",
    "scutierul": "scutier",
    "scutierului": "scutier",
    "scutirea": "scutire",
    "scutireo": "scutire",
    "scutiri": "scutire",
    "scutirii": "scutire",
    "scutirile": "scutire",
    "scutirilor": "scutire",
    "scutită": "scutit",
    "scutite": "scutit",
    "scutiți": "scutit",
    "nemaiscuturând": "scutura",
    "nemaiscuturându": "scutura",
    "nescuturând": "scutura",
    "nescuturându": "scutura",
    "scutur": "scutura",
    "scutură": "scutura",
    "scuturai": "scutura",
    "scuturam": "scutura",
    "scuturăm": "scutura",
    "scuturând": "scutura",
    "scuturându": "scutura",
    "scuturară": "scutura",
    "scuturarăm": "scutura",
    "scuturarăți": "scutura",
    "scuturase": "scutura",
    "scuturasem": "scutura",
    "scuturaseră": "scutura",
    "scuturaserăm": "scutura",
    "scuturaserăți": "scutura",
    "scuturaseși": "scutura",
    "scuturași": "scutura",
    "scuturat": "scutura",
    "scuturați": "scutura",
    "scuturau": "scutura",
    "scuture": "scutura",
    "scuturi": "scutura",
    "scuturarea": "scuturare",
    "scuturareo": "scuturare",
    "scuturări": "scuturare",
    "scuturării": "scuturare",
    "scuturările": "scuturare",
    "scuturărilor": "scuturare",
    "scuturata": "scuturat",
    "scuturată": "scuturat",
    "scuturate": "scuturat",
    "scuturatei": "scuturat",
    "scuturatele": "scuturat",
    "scuturatelor": "scuturat",
    "scuturați": "scuturat",
    "scuturații": "scuturat",
    "scuturaților": "scuturat",
    "scuturato": "scuturat",
    "scuturatul": "scuturat",
    "scuturatule": "scuturat",
    "scuturatului": "scuturat",
    "scuturătoarea": "scuturătoare",
    "scuturători": "scuturătoare",
    "scuturătorii": "scuturătoare",
    "scuturătorile": "scuturătoare",
    "scuturătorilor": "scuturătoare",
    "scuturătura": "scuturătură",
    "scuturături": "scuturătură",
    "scuturăturii": "scuturătură",
    "scuturăturile": "scuturătură",
    "scuturăturilor": "scuturătură",
    "nemaiscuzând": "scuza",
    "nemaiscuzându": "scuza",
    "nescuzând": "scuza",
    "nescuzându": "scuza",
    "scuz": "scuza",
    "scuză": "scuza",
    "scuzai": "scuza",
    "scuzam": "scuza",
    "scuzăm": "scuza",
    "scuzând": "scuza",
    "scuzându": "scuza",
    "scuzară": "scuza",
    "scuzarăm": "scuza",
    "scuzarăți": "scuza",
    "scuzase": "scuza",
    "scuzasem": "scuza",
    "scuzaseră": "scuza",
    "scuzaserăm": "scuza",
    "scuzaserăți": "scuza",
    "scuzaseși": "scuza",
    "scuzași": "scuza",
    "scuzat": "scuza",
    "scuzați": "scuza",
    "scuzau": "scuza",
    "scuze": "scuza",
    "scuzi": "scuza",
    "scuza": "scuză",
    "scuze": "scuză",
    "scuzei": "scuză",
    "scuzele": "scuză",
    "scuzelor": "scuză",
    "scuzabila": "scuzabil",
    "scuzabilă": "scuzabil",
    "scuzabile": "scuzabil",
    "scuzabilei": "scuzabil",
    "scuzabilele": "scuzabil",
    "scuzabilelor": "scuzabil",
    "scuzabili": "scuzabil",
    "scuzabilii": "scuzabil",
    "scuzabililor": "scuzabil",
    "scuzabilul": "scuzabil",
    "scuzabilului": "scuzabil",
    "scuzată": "scuzat",
    "scuzate": "scuzat",
    "scuzați": "scuzat",
    "să": "se",
    "seama": "seamă",
    "seame": "seamă",
    "seamei": "seamă",
    "semeni": "seamăn",
    "seara": "seară",
    "seri": "seară",
    "serii": "seară",
    "serile": "seară",
    "serilor": "seară",
    "searbăda": "searbăd",
    "searbădă": "searbăd",
    "searbădul": "searbăd",
    "searbădului": "searbăd",
    "serbede": "searbăd",
    "serbedei": "searbăd",
    "serbedele": "searbăd",
    "serbedelor": "searbăd",
    "serbezi": "searbăd",
    "serbezii": "searbăd",
    "serbezilor": "searbăd",
    "sebacee": "sebaceu",
    "sebaceea": "sebaceu",
    "sebaceei": "sebaceu",
    "sebaceele": "sebaceu",
    "sebaceelor": "sebaceu",
    "sebacei": "sebaceu",
    "sebaceii": "sebaceu",
    "sebaceilor": "sebaceu",
    "sebaceul": "sebaceu",
    "sebaceului": "sebaceu",
    "sebumul": "sebum",
    "sebumului": "sebum",
    "seca": "sec",
    "secă": "sec",
    "sece": "sec",
    "secei": "sec",
    "secele": "sec",
    "secelor": "sec",
    "seci": "sec",
    "secii": "sec",
    "secilor": "sec",
    "secul": "sec",
    "secului": "sec",
    "nemaisecând": "seca",
    "nemaisecându": "seca",
    "nesecând": "seca",
    "nesecându": "seca",
    "seacă": "seca",
    "sec": "seca",
    "secă": "seca",
    "secai": "seca",
    "secam": "seca",
    "secăm": "seca",
    "secând": "seca",
    "secându": "seca",
    "secară": "seca",
    "secarăm": "seca",
    "secarăți": "seca",
    "secase": "seca",
    "secasem": "seca",
    "secaseră": "seca",
    "secaserăm": "seca",
    "secaserăți": "seca",
    "secaseși": "seca",
    "secași": "seca",
    "secat": "seca",
    "secați": "seca",
    "secau": "seca",
    "sece": "seca",
    "seci": "seca",
    "secara": "secară",
    "secare": "secară",
    "secarei": "secară",
    "secara-cornută": "secară-cornută",
    "secată": "secat",
    "secate": "secat",
    "secați": "secat",
    "nemaisecătuind": "secătui",
    "nemaisecătuindu": "secătui",
    "nesecătuind": "secătui",
    "nesecătuindu": "secătui",
    "secătuia": "secătui",
    "secătuiai": "secătui",
    "secătuiam": "secătui",
    "secătuiască": "secătui",
    "secătuiați": "secătui",
    "secătuiau": "secătui",
    "secătuiesc": "secătui",
    "secătuiește": "secătui",
    "secătuiești": "secătui",
    "secătuii": "secătui",
    "secătuim": "secătui",
    "secătuind": "secătui",
    "secătuindu": "secătui",
    "secătuiră": "secătui",
    "secătuirăm": "secătui",
    "secătuirăți": "secătui",
    "secătuise": "secătui",
    "secătuisem": "secătui",
    "secătuiseră": "secătui",
    "secătuiserăm": "secătui",
    "secătuiserăți": "secătui",
    "secătuiseși": "secătui",
    "secătuiși": "secătui",
    "secătuit": "secătui",
    "secătuiți": "secătui",
    "secătuită": "secătuit",
    "secătuite": "secătuit",
    "secătuiți": "secătuit",
    "secătura": "secătură",
    "secături": "secătură",
    "secăturii": "secătură",
    "secăturile": "secătură",
    "secăturilor": "secătură",
    "nemaisecerând": "secera",
    "nemaisecerându": "secera",
    "nesecerând": "secera",
    "nesecerându": "secera",
    "secer": "secera",
    "seceră": "secera",
    "secerai": "secera",
    "seceram": "secera",
    "secerăm": "secera",
    "secerând": "secera",
    "secerându": "secera",
    "secerară": "secera",
    "secerarăm": "secera",
    "secerarăți": "secera",
    "secerase": "secera",
    "secerasem": "secera",
    "seceraseră": "secera",
    "seceraserăm": "secera",
    "seceraserăți": "secera",
    "seceraseși": "secera",
    "secerași": "secera",
    "secerat": "secera",
    "secerați": "secera",
    "secerau": "secera",
    "secere": "secera",
    "seceri": "secera",
    "secera": "seceră",
    "secerei": "seceră",
    "secerele": "seceră",
    "secerelor": "seceră",
    "seceri": "seceră",
    "secerată": "secerat",
    "secerate": "secerat",
    "secerați": "secerat",
    "secerătoarea": "secerătoare",
    "secerătoarele": "secerătoare",
    "secerătoarelor": "secerătoare",
    "secerătoare": "secerător",
    "secerătoarea": "secerător",
    "secerătoarei": "secerător",
    "secerătoarele": "secerător",
    "secerătoarelor": "secerător",
    "secerători": "secerător",
    "secerătorii": "secerător",
    "secerătorilor": "secerător",
    "secerătorul": "secerător",
    "secerătorului": "secerător",
    "secerătura": "secerătură",
    "secerături": "secerătură",
    "secerăturii": "secerătură",
    "secerăturile": "secerătură",
    "secerăturilor": "secerătură",
    "secerișul": "seceriș",
    "secerișului": "seceriș",
    "secerișuri": "seceriș",
    "secerișurile": "seceriș",
    "secerișurilor": "seceriș",
    "secesioniști": "secesionist",
    "secesioniștii": "secesionist",
    "secesioniștilor": "secesionist",
    "secesionistul": "secesionist",
    "secesionistului": "secesionist",
    "secesiunea": "secesiune",
    "secesiuni": "secesiune",
    "secesiunii": "secesiune",
    "secesiunile": "secesiune",
    "secesiunilor": "secesiune",
    "seceta": "secetă",
    "secete": "secetă",
    "secetei": "secetă",
    "secetele": "secetă",
    "secetelor": "secetă",
    "sechela": "sechelă",
    "sechele": "sechelă",
    "sechelei": "sechelă",
    "sechelele": "sechelă",
    "sechelelor": "sechelă",
    "nemaisechestrând": "sechestra",
    "nemaisechestrându": "sechestra",
    "nesechestrând": "sechestra",
    "nesechestrându": "sechestra",
    "sechestră": "sechestra",
    "sechestrai": "sechestra",
    "sechestram": "sechestra",
    "sechestrăm": "sechestra",
    "sechestrând": "sechestra",
    "sechestrându": "sechestra",
    "sechestrară": "sechestra",
    "sechestrarăm": "sechestra",
    "sechestrarăți": "sechestra",
    "sechestrase": "sechestra",
    "sechestrasem": "sechestra",
    "sechestraseră": "sechestra",
    "sechestraserăm": "sechestra",
    "sechestraserăți": "sechestra",
    "sechestraseși": "sechestra",
    "sechestrași": "sechestra",
    "sechestrat": "sechestra",
    "sechestrați": "sechestra",
    "sechestrau": "sechestra",
    "sechestrează": "sechestra",
    "sechestrez": "sechestra",
    "sechestreze": "sechestra",
    "sechestrezi": "sechestra",
    "sechestrată": "sechestrat",
    "sechestrate": "sechestrat",
    "sechestrați": "sechestrat",
    "sechestre": "sechestru",
    "sechestrele": "sechestru",
    "sechestrelor": "sechestru",
    "sechestrul": "sechestru",
    "sechestrului": "sechestru",
    "sec.": "secol",
    "secole": "secol",
    "secolele": "secol",
    "secolelor": "secol",
    "secolul": "secol",
    "secolului": "secol",
    "secreta": "secret",
    "secretă": "secret",
    "secrete": "secret",
    "secretei": "secret",
    "secretele": "secret",
    "secretelor": "secret",
    "secreți": "secret",
    "secreții": "secret",
    "secreților": "secret",
    "secretul": "secret",
    "secretului": "secret",
    "nemaisecretând": "secreta",
    "nemaisecretându": "secreta",
    "nesecretând": "secreta",
    "nesecretându": "secreta",
    "secret": "secreta",
    "secretă": "secreta",
    "secretai": "secreta",
    "secretam": "secreta",
    "secretăm": "secreta",
    "secretând": "secreta",
    "secretându": "secreta",
    "secretară": "secreta",
    "secretarăm": "secreta",
    "secretarăți": "secreta",
    "secretase": "secreta",
    "secretasem": "secreta",
    "secretaseră": "secreta",
    "secretaserăm": "secreta",
    "secretaserăți": "secreta",
    "secretaseși": "secreta",
    "secretași": "secreta",
    "secretat": "secreta",
    "secretați": "secreta",
    "secretau": "secreta",
    "secrete": "secreta",
    "secreți": "secreta",
    "secretari": "secretar",
    "secretarii": "secretar",
    "secretarilor": "secretar",
    "secretarul": "secretar",
    "secretarului": "secretar",
    "secretara": "secretară",
    "secretare": "secretară",
    "secretarei": "secretară",
    "secretarele": "secretară",
    "secretarelor": "secretară",
    "secretare-dactilografe": "secretară-dactilografă",
    "secretarei-dactilografe": "secretară-dactilografă",
    "secretarele-dactilografe": "secretară-dactilografă",
    "secretarelor-dactilografe": "secretară-dactilografă",
    "secretariate": "secretariat",
    "secretariatele": "secretariat",
    "secretariatelor": "secretariat",
    "secretariatul": "secretariat",
    "secretariatului": "secretariat",
    "secretată": "secretat",
    "secretate": "secretat",
    "secretați": "secretat",
    "secreția": "secreție",
    "secreției": "secreție",
    "secreții": "secreție",
    "secrețiile": "secreție",
    "secrețiilor": "secreție",
    "secretomania": "secretomanie",
    "secretomaniei": "secretomanie",
    "secretomanii": "secretomanie",
    "secretoare": "secretor",
    "secretoarea": "secretor",
    "secretoarei": "secretor",
    "secretoarele": "secretor",
    "secretoarelor": "secretor",
    "secretori": "secretor",
    "secretorii": "secretor",
    "secretorilor": "secretor",
    "secretorul": "secretor",
    "secretorului": "secretor",
    "secretoasa": "secretos",
    "secretoasă": "secretos",
    "secretoase": "secretos",
    "secretoasei": "secretos",
    "secretoasele": "secretos",
    "secretoaselor": "secretos",
    "secretoși": "secretos",
    "secretoșii": "secretos",
    "secretoșilor": "secretos",
    "secretosul": "secretos",
    "secretosului": "secretos",
    "secta": "sectă",
    "secte": "sectă",
    "sectei": "sectă",
    "sectele": "sectă",
    "sectelor": "sectă",
    "sectanți": "sectant",
    "sectanții": "sectant",
    "sectanților": "sectant",
    "sectantul": "sectant",
    "sectantului": "sectant",
    "sectanta": "sectantă",
    "sectante": "sectantă",
    "sectantei": "sectantă",
    "sectantele": "sectantă",
    "sectantelor": "sectantă",
    "sectara": "sectar",
    "sectară": "sectar",
    "sectare": "sectar",
    "sectarei": "sectar",
    "sectarele": "sectar",
    "sectarelor": "sectar",
    "sectari": "sectar",
    "sectarii": "sectar",
    "sectarilor": "sectar",
    "sectarul": "sectar",
    "sectarului": "sectar",
    "sectarismul": "sectarism",
    "sectarismului": "sectarism",
    "secția": "secție",
    "secției": "secție",
    "secții": "secție",
    "secțiile": "secție",
    "secțiilor": "secție",
    "nemaisecționând": "secționa",
    "nemaisecționându": "secționa",
    "nesecționând": "secționa",
    "nesecționându": "secționa",
    "secționă": "secționa",
    "secționai": "secționa",
    "secționam": "secționa",
    "secționăm": "secționa",
    "secționând": "secționa",
    "secționându": "secționa",
    "secționară": "secționa",
    "secționarăm": "secționa",
    "secționarăți": "secționa",
    "secționase": "secționa",
    "secționasem": "secționa",
    "secționaseră": "secționa",
    "secționaserăm": "secționa",
    "secționaserăți": "secționa",
    "secționaseși": "secționa",
    "secționași": "secționa",
    "secționat": "secționa",
    "secționați": "secționa",
    "secționau": "secționa",
    "secționează": "secționa",
    "secționez": "secționa",
    "secționeze": "secționa",
    "secționezi": "secționa",
    "secționată": "secționat",
    "secționate": "secționat",
    "secționați": "secționat",
    "secțiunea": "secțiune",
    "secțiuni": "secțiune",
    "secțiunii": "secțiune",
    "secțiunile": "secțiune",
    "secțiunilor": "secțiune",
    "sect.": "sector",
    "sectoare": "sector",
    "sectoarele": "sector",
    "sectoarelor": "sector",
    "sectorul": "sector",
    "sectorului": "sector",
    "sectorială": "sectorial",
    "sectoriale": "sectorial",
    "sectoriali": "sectorial",
    "sectoriști": "sectorist",
    "sectoriștii": "sectorist",
    "sectoriștilor": "sectorist",
    "sectoristul": "sectorist",
    "sectoristului": "sectorist",
    "SAI": "Sectorul_Agricol_Ilfov",
    "secuii": "secui",
    "secuilor": "secui",
    "secuiul": "secui",
    "secuiului": "secui",
    "secuimea": "secuime",
    "secuimi": "secuime",
    "secuimii": "secuime",
    "secuimile": "secuime",
    "secuimilor": "secuime",
    "seculara": "secular",
    "seculară": "secular",
    "seculare": "secular",
    "secularei": "secular",
    "secularele": "secular",
    "secularelor": "secular",
    "seculari": "secular",
    "secularii": "secular",
    "secularilor": "secular",
    "secularul": "secular",
    "secularului": "secular",
    "nemaisecularizând": "seculariza",
    "nemaisecularizându": "seculariza",
    "nesecularizând": "seculariza",
    "nesecularizându": "seculariza",
    "seculariză": "seculariza",
    "secularizai": "seculariza",
    "secularizam": "seculariza",
    "secularizăm": "seculariza",
    "secularizând": "seculariza",
    "secularizându": "seculariza",
    "secularizară": "seculariza",
    "secularizarăm": "seculariza",
    "secularizarăți": "seculariza",
    "secularizase": "seculariza",
    "secularizasem": "seculariza",
    "secularizaseră": "seculariza",
    "secularizaserăm": "seculariza",
    "secularizaserăți": "seculariza",
    "secularizaseși": "seculariza",
    "secularizași": "seculariza",
    "secularizat": "seculariza",
    "secularizați": "seculariza",
    "secularizau": "seculariza",
    "secularizează": "seculariza",
    "secularizez": "seculariza",
    "secularizeze": "seculariza",
    "secularizezi": "seculariza",
    "secularizarea": "secularizare",
    "secularizări": "secularizare",
    "secularizării": "secularizare",
    "secularizările": "secularizare",
    "secularizărilor": "secularizare",
    "secularizată": "secularizat",
    "secularizate": "secularizat",
    "secularizați": "secularizat",
    "secundul": "secund",
    "secundului": "secund",
    "secunzi": "secund",
    "secunzii": "secund",
    "secunzilor": "secund",
    "nemaisecundând": "secunda",
    "nemaisecundându": "secunda",
    "nesecundând": "secunda",
    "nesecundându": "secunda",
    "secundă": "secunda",
    "secundai": "secunda",
    "secundam": "secunda",
    "secundăm": "secunda",
    "secundând": "secunda",
    "secundându": "secunda",
    "secundară": "secunda",
    "secundarăm": "secunda",
    "secundarăți": "secunda",
    "secundase": "secunda",
    "secundasem": "secunda",
    "secundaseră": "secunda",
    "secundaserăm": "secunda",
    "secundaserăți": "secunda",
    "secundaseși": "secunda",
    "secundași": "secunda",
    "secundat": "secunda",
    "secundați": "secunda",
    "secundau": "secunda",
    "secundează": "secunda",
    "secundez": "secunda",
    "secundeze": "secunda",
    "secundezi": "secunda",
    "s.": "secundă",
    "sec.": "secundă",
    "secunda": "secundă",
    "secunde": "secundă",
    "secundei": "secundă",
    "secundele": "secundă",
    "secundelor": "secundă",
    "secundanți": "secundant",
    "secundanții": "secundant",
    "secundanților": "secundant",
    "secundantul": "secundant",
    "secundantului": "secundant",
    "secundanta": "secundantă",
    "secundante": "secundantă",
    "secundantei": "secundantă",
    "secundantele": "secundantă",
    "secundantelor": "secundantă",
    "secundara": "secundar",
    "secundară": "secundar",
    "secundare": "secundar",
    "secundarei": "secundar",
    "secundarele": "secundar",
    "secundarelor": "secundar",
    "secundari": "secundar",
    "secundarii": "secundar",
    "secundarilor": "secundar",
    "secundarul": "secundar",
    "secundarului": "secundar",
    "secundată": "secundat",
    "secundate": "secundat",
    "secundați": "secundat",
    "securea": "secure",
    "securi": "secure",
    "securii": "secure",
    "securile": "secure",
    "securilor": "secure",
    "securiști": "securist",
    "securiștii": "securist",
    "securiștilor": "securist",
    "securistul": "securist",
    "securistului": "securist",
    "securitul": "securit",
    "securitului": "securit",
    "securitatea": "securitate",
    "securități": "securitate",
    "securității": "securitate",
    "securitățile": "securitate",
    "securităților": "securitate",
    "securizarea": "securizare",
    "securizări": "securizare",
    "securizării": "securizare",
    "securizările": "securizare",
    "securizărilor": "securizare",
    "secvența": "secvență",
    "secvențe": "secvență",
    "secvenței": "secvență",
    "secvențele": "secvență",
    "secvențelor": "secvență",
    "sedativa": "sedativ",
    "sedativă": "sedativ",
    "sedative": "sedativ",
    "sedativei": "sedativ",
    "sedativele": "sedativ",
    "sedativelor": "sedativ",
    "sedativi": "sedativ",
    "sedativii": "sedativ",
    "sedativilor": "sedativ",
    "sedativul": "sedativ",
    "sedativului": "sedativ",
    "nemaișezând": "ședea",
    "nemaișezându": "ședea",
    "neșezând": "ședea",
    "neșezându": "ședea",
    "șadă": "ședea",
    "șade": "ședea",
    "șed": "ședea",
    "ședeai": "ședea",
    "ședeam": "ședea",
    "ședeați": "ședea",
    "ședeau": "ședea",
    "ședem": "ședea",
    "ședeți": "ședea",
    "șezând": "ședea",
    "șezându": "ședea",
    "șezi": "ședea",
    "șezu": "ședea",
    "șezui": "ședea",
    "șezură": "ședea",
    "șezurăm": "ședea",
    "șezurăți": "ședea",
    "șezuse": "ședea",
    "șezusem": "ședea",
    "șezuseră": "ședea",
    "șezuserăm": "ședea",
    "șezuserăți": "ședea",
    "șezuseși": "ședea",
    "șezuși": "ședea",
    "șezut": "ședea",
    "sedentara": "sedentar",
    "sedentară": "sedentar",
    "sedentare": "sedentar",
    "sedentarei": "sedentar",
    "sedentarele": "sedentar",
    "sedentarelor": "sedentar",
    "sedentari": "sedentar",
    "sedentarii": "sedentar",
    "sedentarilor": "sedentar",
    "sedentarul": "sedentar",
    "sedentarului": "sedentar",
    "sedentarismul": "sedentarism",
    "sedentarismului": "sedentarism",
    "șederea": "ședere",
    "șederi": "ședere",
    "șederii": "ședere",
    "șederile": "ședere",
    "șederilor": "ședere",
    "sedila": "sedilă",
    "sedile": "sedilă",
    "sedilei": "sedilă",
    "sedilele": "sedilă",
    "sedilelor": "sedilă",
    "sedimente": "sediment",
    "sedimentele": "sediment",
    "sedimentelor": "sediment",
    "sedimentul": "sediment",
    "sedimentului": "sediment",
    "nemaisedimentând": "sedimenta",
    "nemaisedimentându": "sedimenta",
    "nesedimentând": "sedimenta",
    "nesedimentându": "sedimenta",
    "sedimentă": "sedimenta",
    "sedimentai": "sedimenta",
    "sedimentam": "sedimenta",
    "sedimentăm": "sedimenta",
    "sedimentând": "sedimenta",
    "sedimentându": "sedimenta",
    "sedimentară": "sedimenta",
    "sedimentarăm": "sedimenta",
    "sedimentarăți": "sedimenta",
    "sedimentase": "sedimenta",
    "sedimentasem": "sedimenta",
    "sedimentaseră": "sedimenta",
    "sedimentaserăm": "sedimenta",
    "sedimentaserăți": "sedimenta",
    "sedimentaseși": "sedimenta",
    "sedimentași": "sedimenta",
    "sedimentat": "sedimenta",
    "sedimentați": "sedimenta",
    "sedimentau": "sedimenta",
    "sedimentează": "sedimenta",
    "sedimentez": "sedimenta",
    "sedimenteze": "sedimenta",
    "sedimentezi": "sedimenta",
    "sedimentată": "sedimentat",
    "sedimentate": "sedimentat",
    "sedimentați": "sedimentat",
    "sedimentația": "sedimentație",
    "sedimentației": "sedimentație",
    "sedimentații": "sedimentație",
    "sedimentațiile": "sedimentație",
    "sedimentațiilor": "sedimentație",
    "ședința": "ședință",
    "ședințe": "ședință",
    "ședinței": "ședință",
    "ședințele": "ședință",
    "ședințelor": "ședință",
    "sedii": "sediu",
    "sediile": "sediu",
    "sediilor": "sediu",
    "sediul": "sediu",
    "sediului": "sediu",
    "seducătoare": "seducător",
    "seducătoarea": "seducător",
    "seducătoarei": "seducător",
    "seducătoarele": "seducător",
    "seducătoarelor": "seducător",
    "seducători": "seducător",
    "seducătorii": "seducător",
    "seducătorilor": "seducător",
    "seducătorul": "seducător",
    "seducătorului": "seducător",
    "nemaiseducând": "seduce",
    "nemaiseducându": "seduce",
    "neseducând": "seduce",
    "neseducându": "seduce",
    "sedu": "seduce",
    "seduc": "seduce",
    "seducă": "seduce",
    "seducând": "seduce",
    "seducându": "seduce",
    "seducea": "seduce",
    "seduceai": "seduce",
    "seduceam": "seduce",
    "seduceați": "seduce",
    "seduceau": "seduce",
    "seducem": "seduce",
    "seduceți": "seduce",
    "seduci": "seduce",
    "sedus": "seduce",
    "seduse": "seduce",
    "sedusei": "seduce",
    "seduseră": "seduce",
    "seduserăm": "seduce",
    "seduserăți": "seduce",
    "sedusese": "seduce",
    "sedusesem": "seduce",
    "seduseseră": "seduce",
    "seduseserăm": "seduce",
    "seduseserăți": "seduce",
    "seduseseși": "seduce",
    "seduseși": "seduce",
    "seducerea": "seducere",
    "seducereo": "seducere",
    "seduceri": "seducere",
    "seducerii": "seducere",
    "seducerile": "seducere",
    "seducerilor": "seducere",
    "seducția": "seducție",
    "seducției": "seducție",
    "seducții": "seducție",
    "seducțiile": "seducție",
    "seducțiilor": "seducție",
    "sedusă": "sedus",
    "seduse": "sedus",
    "seduși": "sedus",
    "șefi": "șef",
    "șefii": "șef",
    "șefilor": "șef",
    "șeful": "șef",
    "șefului": "șef",
    "șefa": "șefă",
    "șefe": "șefă",
    "șefei": "șefă",
    "șefele": "șefă",
    "șefelor": "șefă",
    "șefia": "șefie",
    "șefiei": "șefie",
    "șefii": "șefie",
    "șefiile": "șefie",
    "șefiilor": "șefie",
    "segmente": "segment",
    "segmentele": "segment",
    "segmentelor": "segment",
    "segmentul": "segment",
    "segmentului": "segment",
    "nemaisegmentând": "segmenta",
    "nemaisegmentându": "segmenta",
    "nesegmentând": "segmenta",
    "nesegmentându": "segmenta",
    "segmentă": "segmenta",
    "segmentai": "segmenta",
    "segmentam": "segmenta",
    "segmentăm": "segmenta",
    "segmentând": "segmenta",
    "segmentându": "segmenta",
    "segmentară": "segmenta",
    "segmentarăm": "segmenta",
    "segmentarăți": "segmenta",
    "segmentase": "segmenta",
    "segmentasem": "segmenta",
    "segmentaseră": "segmenta",
    "segmentaserăm": "segmenta",
    "segmentaserăți": "segmenta",
    "segmentaseși": "segmenta",
    "segmentași": "segmenta",
    "segmentat": "segmenta",
    "segmentați": "segmenta",
    "segmentau": "segmenta",
    "segmentează": "segmenta",
    "segmentez": "segmenta",
    "segmenteze": "segmenta",
    "segmentezi": "segmenta",
    "segmentată": "segmentat",
    "segmentate": "segmentat",
    "segmentați": "segmentat",
    "segmentația": "segmentație",
    "segmentației": "segmentație",
    "segmentații": "segmentație",
    "segmentațiile": "segmentație",
    "segmentațiilor": "segmentație",
    "segmentară": "segmentator",
    "segmentatoare": "segmentator",
    "segmentatoarea": "segmentator",
    "segmentatoarei": "segmentator",
    "segmentatoarele": "segmentator",
    "segmentatoarelor": "segmentator",
    "segmentatori": "segmentator",
    "segmentatorii": "segmentator",
    "segmentatorilor": "segmentator",
    "segmentatorul": "segmentator",
    "segmentatorului": "segmentator",
    "segregația": "segregație",
    "segregației": "segregație",
    "segregații": "segregație",
    "segregațiile": "segregație",
    "segregațiilor": "segregație",
    "segregaționista": "segregaționist",
    "segregaționistă": "segregaționist",
    "segregaționiste": "segregaționist",
    "segregaționistei": "segregaționist",
    "segregaționistele": "segregaționist",
    "segregaționistelor": "segregaționist",
    "segregaționiști": "segregaționist",
    "segregaționiștii": "segregaționist",
    "segregaționiștilor": "segregaționist",
    "segregaționistul": "segregaționist",
    "segregaționistului": "segregaționist",
    "Şeherazadei": "Şeherazada",
    "șeici": "șeic",
    "șeicii": "șeic",
    "șeicilor": "șeic",
    "șeicul": "șeic",
    "șeicului": "șeic",
    "seiful": "seif",
    "seifului": "seif",
    "seifuri": "seif",
    "seifurile": "seif",
    "seifurilor": "seif",
    "seisme": "seism",
    "seismele": "seism",
    "seismelor": "seism",
    "seismul": "seism",
    "seismului": "seism",
    "seismicitatea": "seismicitate",
    "seismicități": "seismicitate",
    "seismicității": "seismicitate",
    "seismicitățile": "seismicitate",
    "seismicităților": "seismicitate",
    "seismografe": "seismograf",
    "seismografele": "seismograf",
    "seismografelor": "seismograf",
    "seismograful": "seismograf",
    "seismografului": "seismograf",
    "seismografia": "seismografie",
    "seismografiei": "seismografie",
    "seismografii": "seismografie",
    "seismografiile": "seismografie",
    "seismografiilor": "seismografie",
    "seismograma": "seismogramă",
    "seismograme": "seismogramă",
    "seismogramei": "seismogramă",
    "seismogramele": "seismogramă",
    "seismogramelor": "seismogramă",
    "seismologi": "seismolog",
    "seismologii": "seismolog",
    "seismologilor": "seismolog",
    "seismologul": "seismolog",
    "seismologului": "seismolog",
    "seismologia": "seismologie",
    "seismologiei": "seismologie",
    "seismologii": "seismologie",
    "seismologiile": "seismologie",
    "seismologiilor": "seismologie",
    "seismometria": "seismometrie",
    "seismometriei": "seismometrie",
    "seismometrii": "seismometrie",
    "seismometriile": "seismometrie",
    "seismometriilor": "seismometrie",
    "seismometre": "seismometru",
    "seismometrele": "seismometru",
    "seismometrelor": "seismometru",
    "seismometrul": "seismometru",
    "seismometrului": "seismometru",
    "seismoscoape": "seismoscop",
    "seismoscoapele": "seismoscop",
    "seismoscoapelor": "seismoscop",
    "seismoscopul": "seismoscop",
    "seismoscopului": "seismoscop",
    "sejurul": "sejur",
    "sejurului": "sejur",
    "sejururi": "sejur",
    "sejururile": "sejur",
    "sejururilor": "sejur",
    "șelari": "șelar",
    "șelarii": "șelar",
    "șelarilor": "șelar",
    "șelarul": "șelar",
    "șelarului": "șelar",
    "șelăria": "șelărie",
    "șelăriei": "șelărie",
    "șelării": "șelărie",
    "șelăriile": "șelărie",
    "șelăriilor": "șelărie",
    "selecta": "select",
    "selectă": "select",
    "selecte": "select",
    "selectei": "select",
    "selectele": "select",
    "selectelor": "select",
    "selecți": "select",
    "selecții": "select",
    "selecților": "select",
    "selectul": "select",
    "selectului": "select",
    "nemaiselectând": "selecta",
    "nemaiselectându": "selecta",
    "neselectând": "selecta",
    "neselectându": "selecta",
    "selectă": "selecta",
    "selectai": "selecta",
    "selectam": "selecta",
    "selectăm": "selecta",
    "selectând": "selecta",
    "selectându": "selecta",
    "selectară": "selecta",
    "selectarăm": "selecta",
    "selectarăți": "selecta",
    "selectase": "selecta",
    "selectasem": "selecta",
    "selectaseră": "selecta",
    "selectaserăm": "selecta",
    "selectaserăți": "selecta",
    "selectaseși": "selecta",
    "selectași": "selecta",
    "selectat": "selecta",
    "selectați": "selecta",
    "selectau": "selecta",
    "selectează": "selecta",
    "selectez": "selecta",
    "selecteze": "selecta",
    "selectezi": "selecta",
    "selectată": "selectat",
    "selectate": "selectat",
    "selectați": "selectat",
    "selecția": "selecție",
    "selecției": "selecție",
    "selecții": "selecție",
    "selecțiile": "selecție",
    "selecțiilor": "selecție",
    "nemaiselecționând": "selecționa",
    "nemaiselecționându": "selecționa",
    "neselecționând": "selecționa",
    "neselecționându": "selecționa",
    "selecționă": "selecționa",
    "selecționai": "selecționa",
    "selecționam": "selecționa",
    "selecționăm": "selecționa",
    "selecționând": "selecționa",
    "selecționându": "selecționa",
    "selecționară": "selecționa",
    "selecționarăm": "selecționa",
    "selecționarăți": "selecționa",
    "selecționase": "selecționa",
    "selecționasem": "selecționa",
    "selecționaseră": "selecționa",
    "selecționaserăm": "selecționa",
    "selecționaserăți": "selecționa",
    "selecționaseși": "selecționa",
    "selecționași": "selecționa",
    "selecționat": "selecționa",
    "selecționați": "selecționa",
    "selecționau": "selecționa",
    "selecționează": "selecționa",
    "selecționez": "selecționa",
    "selecționeze": "selecționa",
    "selecționezi": "selecționa",
    "selecționabila": "selecționabil",
    "selecționabilă": "selecționabil",
    "selecționabile": "selecționabil",
    "selecționabilei": "selecționabil",
    "selecționabilele": "selecționabil",
    "selecționabilelor": "selecționabil",
    "selecționabili": "selecționabil",
    "selecționabilii": "selecționabil",
    "selecționabililor": "selecționabil",
    "selecționabilo": "selecționabil",
    "selecționabilul": "selecționabil",
    "selecționabilule": "selecționabil",
    "selecționabilului": "selecționabil",
    "selecționarea": "selecționare",
    "selecționareo": "selecționare",
    "selecționări": "selecționare",
    "selecționării": "selecționare",
    "selecționările": "selecționare",
    "selecționărilor": "selecționare",
    "selecționata": "selecționat",
    "selecționată": "selecționat",
    "selecționate": "selecționat",
    "selecționatei": "selecționat",
    "selecționatele": "selecționat",
    "selecționatelor": "selecționat",
    "selecționați": "selecționat",
    "selecționații": "selecționat",
    "selecționaților": "selecționat",
    "selecționato": "selecționat",
    "selecționatul": "selecționat",
    "selecționatule": "selecționat",
    "selecționatului": "selecționat",
    "selecționeri": "selecționer",
    "selecționerii": "selecționer",
    "selecționerilor": "selecționer",
    "selecționerul": "selecționer",
    "selecționerului": "selecționer",
    "selecționera": "selecționeră",
    "selecționere": "selecționeră",
    "selecționerei": "selecționeră",
    "selecționerele": "selecționeră",
    "selecționerelor": "selecționeră",
    "selecționismul": "selecționism",
    "selecționismului": "selecționism",
    "selecționiști": "selecționist",
    "selecționiștii": "selecționist",
    "selecționiștilor": "selecționist",
    "selecționistul": "selecționist",
    "selecționistului": "selecționist",
    "selecționista": "selecționistă",
    "selecționiste": "selecționistă",
    "selecționistei": "selecționistă",
    "selecționistele": "selecționistă",
    "selecționistelor": "selecționistă",
    "selecțiunea": "selecțiune",
    "selecțiuni": "selecțiune",
    "selecțiunii": "selecțiune",
    "selecțiunile": "selecțiune",
    "selecțiunilor": "selecțiune",
    "selectiva": "selectiv",
    "selectivă": "selectiv",
    "selective": "selectiv",
    "selectivei": "selectiv",
    "selectivele": "selectiv",
    "selectivelor": "selectiv",
    "selectivi": "selectiv",
    "selectivii": "selectiv",
    "selectivilor": "selectiv",
    "selectivul": "selectiv",
    "selectivului": "selectiv",
    "selectivitatea": "selectivitate",
    "selectivități": "selectivitate",
    "selectivității": "selectivitate",
    "selectivitățile": "selectivitate",
    "selectivităților": "selectivitate",
    "selectoare": "selector",
    "selectoarele": "selector",
    "selectoarelor": "selector",
    "selectorul": "selector",
    "selectorului": "selector",
    "Se": "seleniu",
    "seleniul": "seleniu",
    "seleniului": "seleniu",
    "selenodezia": "selenodezie",
    "selenodeziei": "selenodezie",
    "selenodezii": "selenodezie",
    "selenodeziile": "selenodezie",
    "selenodeziilor": "selenodezie",
    "selenografia": "selenografie",
    "selenografiei": "selenografie",
    "selenografii": "selenografie",
    "selenografiile": "selenografie",
    "selenografiilor": "selenografie",
    "selenostate": "selenostat",
    "selenostatele": "selenostat",
    "selenostatelor": "selenostat",
    "selenostatul": "selenostat",
    "selenostatului": "selenostat",
    "selva": "selvă",
    "selve": "selvă",
    "selvei": "selvă",
    "selvele": "selvă",
    "selvelor": "selvă",
    "semafoare": "semafor",
    "semafoarele": "semafor",
    "semafoarelor": "semafor",
    "semaforul": "semafor",
    "semaforului": "semafor",
    "nemaisemănând": "semăna",
    "nemaisemănându": "semăna",
    "nesemănând": "semăna",
    "nesemănându": "semăna",
    "seamănă": "semăna",
    "semăn": "semăna",
    "semănă": "semăna",
    "semănai": "semăna",
    "semănam": "semăna",
    "semănăm": "semăna",
    "semănând": "semăna",
    "semănându": "semăna",
    "semănară": "semăna",
    "semănarăm": "semăna",
    "semănarăți": "semăna",
    "semănase": "semăna",
    "semănasem": "semăna",
    "semănaseră": "semăna",
    "semănaserăm": "semăna",
    "semănaserăți": "semăna",
    "semănaseși": "semăna",
    "semănași": "semăna",
    "semănat": "semăna",
    "semănați": "semăna",
    "semănau": "semăna",
    "semene": "semăna",
    "semeni": "semăna",
    "semănarea": "semănare",
    "semănări": "semănare",
    "semănării": "semănare",
    "semănările": "semănare",
    "semănărilor": "semănare",
    "semănată": "semănat",
    "semănate": "semănat",
    "semănați": "semănat",
    "semănătoarea": "semănătoare",
    "semănătoarele": "semănătoare",
    "semănătoarelor": "semănătoare",
    "semănătoare": "semănător",
    "semănătoarea": "semănător",
    "semănătoarei": "semănător",
    "semănătoarele": "semănător",
    "semănătoarelor": "semănător",
    "semănători": "semănător",
    "semănătorii": "semănător",
    "semănătorilor": "semănător",
    "semănătorul": "semănător",
    "semănătorului": "semănător",
    "semănătura": "semănătură",
    "semănături": "semănătură",
    "semănăturii": "semănătură",
    "semănăturile": "semănătură",
    "semănăturilor": "semănătură",
    "semantica": "semantic",
    "semantică": "semantic",
    "semantice": "semantic",
    "semanticei": "semantic",
    "semanticele": "semantic",
    "semanticelor": "semantic",
    "semantici": "semantic",
    "semanticii": "semantic",
    "semanticilor": "semantic",
    "semanticul": "semantic",
    "semanticului": "semantic",
    "semantica": "semantică",
    "semantici": "semantică",
    "semanticii": "semantică",
    "semanticianul": "semantician",
    "semanticianului": "semantician",
    "semanticieni": "semantician",
    "semanticienii": "semantician",
    "semanticienilor": "semantician",
    "semantismul": "semantism",
    "semantismului": "semantism",
    "semeni": "semen",
    "semenii": "semen",
    "semenilor": "semen",
    "semenul": "semen",
    "semenului": "semen",
    "semestriala": "semestrial",
    "semestrială": "semestrial",
    "semestriale": "semestrial",
    "semestrialei": "semestrial",
    "semestrialele": "semestrial",
    "semestrialelor": "semestrial",
    "semestriali": "semestrial",
    "semestrialii": "semestrial",
    "semestrialilor": "semestrial",
    "semestrialul": "semestrial",
    "semestrialului": "semestrial",
    "sem.": "semestru",
    "semestre": "semestru",
    "semestrele": "semestru",
    "semestrelor": "semestru",
    "semestrul": "semestru",
    "semestrului": "semestru",
    "semețe": "semeț",
    "semeței": "semeț",
    "semețele": "semeț",
    "semețelor": "semeț",
    "semeți": "semeț",
    "semeții": "semeț",
    "semeților": "semeț",
    "semețul": "semeț",
    "semețului": "semeț",
    "nemaisemețind": "semeți",
    "nemaisemețindu": "semeți",
    "nesemețind": "semeți",
    "nesemețindu": "semeți",
    "semețea": "semeți",
    "semețeai": "semeți",
    "semețeam": "semeți",
    "semețească": "semeți",
    "semețeați": "semeți",
    "semețeau": "semeți",
    "semețesc": "semeți",
    "semețește": "semeți",
    "semețești": "semeți",
    "semeții": "semeți",
    "semețim": "semeți",
    "semețind": "semeți",
    "semețindu": "semeți",
    "semețiră": "semeți",
    "semețirăm": "semeți",
    "semețirăți": "semeți",
    "semețise": "semeți",
    "semețisem": "semeți",
    "semețiseră": "semeți",
    "semețiserăm": "semeți",
    "semețiserăți": "semeți",
    "semețiseși": "semeți",
    "semețiși": "semeți",
    "semețit": "semeți",
    "semețiți": "semeți",
    "semeția": "semeție",
    "semeției": "semeție",
    "semeții": "semeție",
    "semețiile": "semeție",
    "semețiilor": "semeție",
    "semețită": "semețit",
    "semețite": "semețit",
    "semețiți": "semețit",
    "semiaderenți": "semiaderent",
    "semiaderenții": "semiaderent",
    "semiaderenților": "semiaderent",
    "semiaderentul": "semiaderent",
    "semiaderentului": "semiaderent",
    "semiagnostici": "semiagnostic",
    "semiagnosticii": "semiagnostic",
    "semiagnosticilor": "semiagnostic",
    "semiagnosticul": "semiagnostic",
    "semiagnosticului": "semiagnostic",
    "semianarhiști": "semianarhist",
    "semianarhiștii": "semianarhist",
    "semianarhiștilor": "semianarhist",
    "semianarhistul": "semianarhist",
    "semianarhistului": "semianarhist",
    "semiarbuști": "semiarbust",
    "semiarbuștii": "semiarbust",
    "semiarbuștilor": "semiarbust",
    "semiarbustul": "semiarbust",
    "semiarbustului": "semiarbust",
    "semiarticulația": "semiarticulație",
    "semiarticulației": "semiarticulație",
    "semiarticulații": "semiarticulație",
    "semiarticulațiile": "semiarticulație",
    "semiarticulațiilor": "semiarticulație",
    "semiartizanate": "semiartizanat",
    "semiartizanatele": "semiartizanat",
    "semiartizanatelor": "semiartizanat",
    "semiartizanatul": "semiartizanat",
    "semiartizanatului": "semiartizanat",
    "semiaxa": "semiaxă",
    "semiaxe": "semiaxă",
    "semiaxei": "semiaxă",
    "semiaxele": "semiaxă",
    "semiaxelor": "semiaxă",
    "semicarbonizarea": "semicarbonizare",
    "semicarbonizări": "semicarbonizare",
    "semicarbonizării": "semicarbonizare",
    "semicarbonizările": "semicarbonizare",
    "semicarbonizărilor": "semicarbonizare",
    "semicentenare": "semicentenar",
    "semicentenarele": "semicentenar",
    "semicentenarelor": "semicentenar",
    "semicentenarul": "semicentenar",
    "semicentenarului": "semicentenar",
    "semicercul": "semicerc",
    "semicercului": "semicerc",
    "semicercuri": "semicerc",
    "semicercurile": "semicerc",
    "semicercurilor": "semicerc",
    "semicirculara": "semicircular",
    "semicirculară": "semicircular",
    "semicirculare": "semicircular",
    "semicircularei": "semicircular",
    "semicircularele": "semicircular",
    "semicircularelor": "semicircular",
    "semicirculari": "semicircular",
    "semicircularii": "semicircular",
    "semicircularilor": "semicircular",
    "semicircularul": "semicircular",
    "semicircularului": "semicircular",
    "semicocsul": "semicocs",
    "semicocsului": "semicocs",
    "semicocsuri": "semicocs",
    "semicocsurile": "semicocs",
    "semicocsurilor": "semicocs",
    "semicoloniala": "semicolonial",
    "semicolonială": "semicolonial",
    "semicoloniale": "semicolonial",
    "semicolonialei": "semicolonial",
    "semicolonialele": "semicolonial",
    "semicolonialelor": "semicolonial",
    "semicoloniali": "semicolonial",
    "semicolonialii": "semicolonial",
    "semicolonialilor": "semicolonial",
    "semicolonialul": "semicolonial",
    "semicolonialului": "semicolonial",
    "semicolonia": "semicolonie",
    "semicoloniei": "semicolonie",
    "semicolonii": "semicolonie",
    "semicoloniile": "semicolonie",
    "semicoloniilor": "semicolonie",
    "semiconductoare": "semiconductor",
    "semiconductoarea": "semiconductor",
    "semiconductoarei": "semiconductor",
    "semiconductoarele": "semiconductor",
    "semiconductoarelor": "semiconductor",
    "semiconductori": "semiconductor",
    "semiconductorii": "semiconductor",
    "semiconductorilor": "semiconductor",
    "semiconductorul": "semiconductor",
    "semiconductorului": "semiconductor",
    "semiconsoana": "semiconsoană",
    "semiconsoane": "semiconsoană",
    "semiconsoanei": "semiconsoană",
    "semiconsoanele": "semiconsoană",
    "semiconsoanelor": "semiconsoană",
    "semiconsonanta": "semiconsonantă",
    "semiconsonante": "semiconsonantă",
    "semiconsonantei": "semiconsonantă",
    "semiconsonantele": "semiconsonantă",
    "semiconsonantelor": "semiconsonantă",
    "semideșertul": "semideșert",
    "semideșertului": "semideșert",
    "semideșerturi": "semideșert",
    "semideșerturile": "semideșert",
    "semideșerturilor": "semideșert",
    "semidreapta": "semidreaptă",
    "semidrepte": "semidreaptă",
    "semidreptei": "semidreaptă",
    "semidreptele": "semidreaptă",
    "semidreptelor": "semidreaptă",
    "semifinala": "semifinală",
    "semifinale": "semifinală",
    "semifinalei": "semifinală",
    "semifinalele": "semifinală",
    "semifinalelor": "semifinală",
    "semifinaliști": "semifinalist",
    "semifinaliștii": "semifinalist",
    "semifinaliștilor": "semifinalist",
    "semifinalistul": "semifinalist",
    "semifinalistului": "semifinalist",
    "semifinalista": "semifinalistă",
    "semifinaliste": "semifinalistă",
    "semifinalistei": "semifinalistă",
    "semifinalistele": "semifinalistă",
    "semifinalistelor": "semifinalistă",
    "semifluida": "semifluid",
    "semifluidă": "semifluid",
    "semifluide": "semifluid",
    "semifluidei": "semifluid",
    "semifluidele": "semifluid",
    "semifluidelor": "semifluid",
    "semifluidul": "semifluid",
    "semifluidului": "semifluid",
    "semifluizi": "semifluid",
    "semifluizii": "semifluid",
    "semifluizilor": "semifluid",
    "semifondiști": "semifondist",
    "semifondiștii": "semifondist",
    "semifondiștilor": "semifondist",
    "semifondistul": "semifondist",
    "semifondistului": "semifondist",
    "semifondista": "semifondistă",
    "semifondiste": "semifondistă",
    "semifondistei": "semifondistă",
    "semifondistele": "semifondistă",
    "semifondistelor": "semifondistă",
    "semiîntunericul": "semiîntuneric",
    "semiîntunericului": "semiîntuneric",
    "semiluna": "semilună",
    "semiluni": "semilună",
    "semilunii": "semilună",
    "semilunile": "semilună",
    "semilunilor": "semilună",
    "semimetale": "semimetal",
    "semimetalele": "semimetal",
    "semimetalelor": "semimetal",
    "semimetalul": "semimetal",
    "semimetalului": "semimetal",
    "seminala": "seminal",
    "seminală": "seminal",
    "seminale": "seminal",
    "seminalei": "seminal",
    "seminalele": "seminal",
    "seminalelor": "seminal",
    "seminali": "seminal",
    "seminalii": "seminal",
    "seminalilor": "seminal",
    "seminalul": "seminal",
    "seminalului": "seminal",
    "seminarii": "seminar",
    "seminariile": "seminar",
    "seminariilor": "seminar",
    "seminarul": "seminar",
    "seminarului": "seminar",
    "seminariști": "seminarist",
    "seminariștii": "seminarist",
    "seminariștilor": "seminarist",
    "seminaristul": "seminarist",
    "seminaristului": "seminarist",
    "seminceri": "semincer",
    "semincerii": "semincer",
    "semincerilor": "semincer",
    "semincerul": "semincer",
    "semincerului": "semincer",
    "șemineul": "șemineu",
    "șemineului": "șemineu",
    "șemineuri": "șemineu",
    "șemineurile": "șemineu",
    "șemineurilor": "șemineu",
    "seminomadul": "seminomad",
    "seminomadului": "seminomad",
    "seminomazi": "seminomad",
    "seminomazii": "seminomad",
    "seminomazilor": "seminomad",
    "seminomada": "seminomadă",
    "seminomade": "seminomadă",
    "seminomadei": "seminomadă",
    "seminomadele": "seminomadă",
    "seminomadelor": "seminomadă",
    "seminomadismul": "seminomadism",
    "seminomadismului": "seminomadism",
    "semințenia": "semințenie",
    "semințeniei": "semințenie",
    "semințenii": "semințenie",
    "semințeniile": "semințenie",
    "semințeniilor": "semințenie",
    "seminția": "seminție",
    "seminției": "seminție",
    "seminții": "seminție",
    "semințiile": "seminție",
    "semințiilor": "seminție",
    "semiobscura": "semiobscur",
    "semiobscură": "semiobscur",
    "semiobscure": "semiobscur",
    "semiobscurei": "semiobscur",
    "semiobscurele": "semiobscur",
    "semiobscurelor": "semiobscur",
    "semiobscuri": "semiobscur",
    "semiobscurii": "semiobscur",
    "semiobscurilor": "semiobscur",
    "semiobscurul": "semiobscur",
    "semiobscurului": "semiobscur",
    "semiobscuritatea": "semiobscuritate",
    "semiobscurități": "semiobscuritate",
    "semiobscurității": "semiobscuritate",
    "semiobscuritățile": "semiobscuritate",
    "semiobscurităților": "semiobscuritate",
    "semiologi": "semiolog",
    "semiologii": "semiolog",
    "semiologilor": "semiolog",
    "semiologul": "semiolog",
    "semiologului": "semiolog",
    "semiologa": "semiologă",
    "semiologe": "semiologă",
    "semiologei": "semiologă",
    "semiologele": "semiologă",
    "semiologelor": "semiologă",
    "semiologia": "semiologie",
    "semiologiei": "semiologie",
    "semiologii": "semiologie",
    "semiologiile": "semiologie",
    "semiologiilor": "semiologie",
    "semioptimistă": "semioptimist",
    "semioptimiste": "semioptimist",
    "semioptimiști": "semioptimist",
    "semiotica": "semiotică",
    "semiotice": "semiotică",
    "semioticei": "semiotică",
    "semioticele": "semiotică",
    "semioticelor": "semiotică",
    "semiparaziți": "semiparazit",
    "semiparaziții": "semiparazit",
    "semiparaziților": "semiparazit",
    "semiparazitul": "semiparazit",
    "semiparazitului": "semiparazit",
    "semiparazitismul": "semiparazitism",
    "semiparazitismului": "semiparazitism",
    "semiperioada": "semiperioadă",
    "semiperioade": "semiperioadă",
    "semiperioadei": "semiperioadă",
    "semiperioadele": "semiperioadă",
    "semiperioadelor": "semiperioadă",
    "semiplanul": "semiplan",
    "semiplanului": "semiplan",
    "semiplanuri": "semiplan",
    "semiplanurile": "semiplan",
    "semiplanurilor": "semiplan",
    "semiproletari": "semiproletar",
    "semiproletarii": "semiproletar",
    "semiproletarilor": "semiproletar",
    "semiproletarul": "semiproletar",
    "semiproletarului": "semiproletar",
    "semiproletara": "semiproletară",
    "semiproletare": "semiproletară",
    "semiproletarei": "semiproletară",
    "semiproletarele": "semiproletară",
    "semiproletarelor": "semiproletară",
    "semirelieful": "semirelief",
    "semireliefului": "semirelief",
    "semireliefuri": "semirelief",
    "semireliefurile": "semirelief",
    "semireliefurilor": "semirelief",
    "semispații": "semispațiu",
    "semispațiile": "semispațiu",
    "semispațiilor": "semispațiu",
    "semispațiul": "semispațiu",
    "semispațiului": "semispațiu",
    "semisuma": "semisumă",
    "semisume": "semisumă",
    "semisumei": "semisumă",
    "semisumele": "semisumă",
    "semisumelor": "semisumă",
    "semita": "semit",
    "semită": "semit",
    "semite": "semit",
    "semitei": "semit",
    "semitele": "semit",
    "semitelor": "semit",
    "semiți": "semit",
    "semiții": "semit",
    "semiților": "semit",
    "semitul": "semit",
    "semitului": "semit",
    "semitisme": "semitism",
    "semitismele": "semitism",
    "semitismelor": "semitism",
    "semitismul": "semitism",
    "semitismului": "semitism",
    "semitologi": "semitolog",
    "semitologii": "semitolog",
    "semitologilor": "semitolog",
    "semitologul": "semitolog",
    "semitologului": "semitolog",
    "semitologa": "semitologă",
    "semitologe": "semitologă",
    "semitologei": "semitologă",
    "semitologele": "semitologă",
    "semitologelor": "semitologă",
    "semitologia": "semitologie",
    "semitologiei": "semitologie",
    "semitologii": "semitologie",
    "semitologiile": "semitologie",
    "semitologiilor": "semitologie",
    "semitonul": "semiton",
    "semitonului": "semiton",
    "semitonuri": "semiton",
    "semitonurile": "semiton",
    "semitonurilor": "semiton",
    "semivocala": "semivocală",
    "semivocale": "semivocală",
    "semivocalei": "semivocală",
    "semivocalele": "semivocală",
    "semivocalelor": "semivocală",
    "semivolta": "semivoltă",
    "semivolte": "semivoltă",
    "semivoltei": "semivoltă",
    "semivoltele": "semivoltă",
    "semivoltelor": "semivoltă",
    "semizei": "semizeu",
    "semizeii": "semizeu",
    "semizeilor": "semizeu",
    "semizeul": "semizeu",
    "semizeului": "semizeu",
    "sem'": "semn",
    "semne": "semn",
    "semnele": "semn",
    "semnelor": "semn",
    "semnul": "semn",
    "semnului": "semn",
    "nemaisemnând": "semna",
    "nemaisemnându": "semna",
    "nesemnând": "semna",
    "nesemnându": "semna",
    "semnă": "semna",
    "semnai": "semna",
    "semnam": "semna",
    "semnăm": "semna",
    "semnând": "semna",
    "semnându": "semna",
    "semnară": "semna",
    "semnarăm": "semna",
    "semnarăți": "semna",
    "semnase": "semna",
    "semnasem": "semna",
    "semnaseră": "semna",
    "semnaserăm": "semna",
    "semnaserăți": "semna",
    "semnaseși": "semna",
    "semnași": "semna",
    "semnat": "semna",
    "semnați": "semna",
    "semnau": "semna",
    "semnează": "semna",
    "semnez": "semna",
    "semneze": "semna",
    "semnezi": "semna",
    "semnale": "semnal",
    "semnalele": "semnal",
    "semnalelor": "semnal",
    "semnalul": "semnal",
    "semnalului": "semnal",
    "nemaisemnalând": "semnala",
    "nemaisemnalându": "semnala",
    "nesemnalând": "semnala",
    "nesemnalându": "semnala",
    "semnală": "semnala",
    "semnalai": "semnala",
    "semnalam": "semnala",
    "semnalăm": "semnala",
    "semnalând": "semnala",
    "semnalându": "semnala",
    "semnalară": "semnala",
    "semnalarăm": "semnala",
    "semnalarăți": "semnala",
    "semnalase": "semnala",
    "semnalasem": "semnala",
    "semnalaseră": "semnala",
    "semnalaserăm": "semnala",
    "semnalaserăți": "semnala",
    "semnalaseși": "semnala",
    "semnalași": "semnala",
    "semnalat": "semnala",
    "semnalați": "semnala",
    "semnalau": "semnala",
    "semnalează": "semnala",
    "semnalez": "semnala",
    "semnaleze": "semnala",
    "semnalezi": "semnala",
    "semnalată": "semnalat",
    "semnalate": "semnalat",
    "semnalați": "semnalat",
    "nemaisemnalizând": "semnaliza",
    "nemaisemnalizându": "semnaliza",
    "nesemnalizând": "semnaliza",
    "nesemnalizându": "semnaliza",
    "semnaliză": "semnaliza",
    "semnalizai": "semnaliza",
    "semnalizam": "semnaliza",
    "semnalizăm": "semnaliza",
    "semnalizând": "semnaliza",
    "semnalizându": "semnaliza",
    "semnalizară": "semnaliza",
    "semnalizarăm": "semnaliza",
    "semnalizarăți": "semnaliza",
    "semnalizase": "semnaliza",
    "semnalizasem": "semnaliza",
    "semnalizaseră": "semnaliza",
    "semnalizaserăm": "semnaliza",
    "semnalizaserăți": "semnaliza",
    "semnalizaseși": "semnaliza",
    "semnalizași": "semnaliza",
    "semnalizat": "semnaliza",
    "semnalizați": "semnaliza",
    "semnalizau": "semnaliza",
    "semnalizează": "semnaliza",
    "semnalizez": "semnaliza",
    "semnalizeze": "semnaliza",
    "semnalizezi": "semnaliza",
    "semnalizată": "semnalizat",
    "semnalizate": "semnalizat",
    "semnalizați": "semnalizat",
    "semnalmente": "semnalment",
    "semnalmentele": "semnalment",
    "semnalmentelor": "semnalment",
    "semnalmentul": "semnalment",
    "semnalmentului": "semnalment",
    "semnarea": "semnare",
    "semnări": "semnare",
    "semnării": "semnare",
    "semnările": "semnare",
    "semnărilor": "semnare",
    "semnată": "semnat",
    "semnate": "semnat",
    "semnați": "semnat",
    "semnatari": "semnatar",
    "semnatarii": "semnatar",
    "semnatarilor": "semnatar",
    "semnatarul": "semnatar",
    "semnatarului": "semnatar",
    "semnatara": "semnatară",
    "semnatare": "semnatară",
    "semnatarei": "semnatară",
    "semnatarele": "semnatară",
    "semnatarelor": "semnatară",
    "semnătura": "semnătură",
    "semnături": "semnătură",
    "semnăturii": "semnătură",
    "semnăturile": "semnătură",
    "semnăturilor": "semnătură",
    "ss.": "semnături",
    "semnific": "semnifica",
    "semnifică": "semnifica",
    "semnificai": "semnifica",
    "semnificam": "semnifica",
    "semnificăm": "semnifica",
    "semnificând": "semnifica",
    "semnificându": "semnifica",
    "semnificară": "semnifica",
    "semnificarăm": "semnifica",
    "semnificarăți": "semnifica",
    "semnificase": "semnifica",
    "semnificasem": "semnifica",
    "semnificaseră": "semnifica",
    "semnificaserăm": "semnifica",
    "semnificaserăți": "semnifica",
    "semnificaseși": "semnifica",
    "semnificași": "semnifica",
    "semnificat": "semnifica",
    "semnificați": "semnifica",
    "semnificatu": "semnifica",
    "semnificau": "semnifica",
    "semnifice": "semnifica",
    "semnifici": "semnifica",
    "semnificată": "semnificat",
    "semnificate": "semnificat",
    "semnificați": "semnificat",
    "semnificația": "semnificație",
    "semnificației": "semnificație",
    "semnificații": "semnificație",
    "semnificațiile": "semnificație",
    "semnificațiilor": "semnificație",
    "semnificativa": "semnificativ",
    "semnificativă": "semnificativ",
    "semnificative": "semnificativ",
    "semnificativei": "semnificativ",
    "semnificativele": "semnificativ",
    "semnificativelor": "semnificativ",
    "semnificativi": "semnificativ",
    "semnificativii": "semnificativ",
    "semnificativilor": "semnificativ",
    "semnificativul": "semnificativ",
    "semnificativului": "semnificativ",
    "șenale": "șenal",
    "șenalele": "șenal",
    "șenalelor": "șenal",
    "șenalul": "șenal",
    "șenalului": "șenal",
    "senate": "senat",
    "senatele": "senat",
    "senatelor": "senat",
    "senatul": "senat",
    "senatului": "senat",
    "senatori": "senator",
    "senatorii": "senator",
    "senatorilor": "senator",
    "senatorul": "senator",
    "senatorului": "senator",
    "senatoriala": "senatorial",
    "senatorială": "senatorial",
    "senatoriale": "senatorial",
    "senatorialei": "senatorial",
    "senatorialele": "senatorial",
    "senatorialelor": "senatorial",
    "senatoriali": "senatorial",
    "senatorialii": "senatorial",
    "senatorialilor": "senatorial",
    "senatorialul": "senatorial",
    "senatorialului": "senatorial",
    "senectutea": "senectute",
    "senectuți": "senectute",
    "senectuții": "senectute",
    "senectuțile": "senectute",
    "senectuților": "senectute",
    "senegalezi": "senegalez",
    "senegalezii": "senegalez",
    "senegalezilor": "senegalez",
    "senegalezul": "senegalez",
    "senegalezului": "senegalez",
    "senegaleza": "senegaleză",
    "senegaleze": "senegaleză",
    "senegalezei": "senegaleză",
    "senegalezele": "senegaleză",
    "senegalezelor": "senegaleză",
    "senila": "senil",
    "senilă": "senil",
    "senile": "senil",
    "senilei": "senil",
    "senilele": "senil",
    "senilelor": "senil",
    "senili": "senil",
    "senilii": "senil",
    "senililor": "senil",
    "senilul": "senil",
    "senilului": "senil",
    "șenila": "șenilă",
    "șenile": "șenilă",
    "șenilei": "șenilă",
    "șenilele": "șenilă",
    "șenilelor": "șenilă",
    "senilitatea": "senilitate",
    "senilități": "senilitate",
    "senilității": "senilitate",
    "senilitățile": "senilitate",
    "senilităților": "senilitate",
    "senina": "senin",
    "senină": "senin",
    "senine": "senin",
    "seninei": "senin",
    "seninele": "senin",
    "seninelor": "senin",
    "senini": "senin",
    "seninii": "senin",
    "seninilor": "senin",
    "seninul": "senin",
    "seninului": "senin",
    "seninătatea": "seninătate",
    "seninătăți": "seninătate",
    "seninătății": "seninătate",
    "seninătățile": "seninătate",
    "seninătăților": "seninătate",
    "senioara": "senioare",
    "senioarei": "senioare",
    "senioarele": "senioare",
    "senioarelor": "senioare",
    "seniori": "senior",
    "seniorii": "senior",
    "seniorilor": "senior",
    "seniorul": "senior",
    "seniorului": "senior",
    "senioriala": "seniorial",
    "seniorială": "seniorial",
    "senioriale": "seniorial",
    "seniorialei": "seniorial",
    "seniorialele": "seniorial",
    "seniorialelor": "seniorial",
    "senioriali": "seniorial",
    "seniorialii": "seniorial",
    "seniorialilor": "seniorial",
    "seniorialul": "seniorial",
    "seniorialului": "seniorial",
    "senioria": "seniorie",
    "senioriei": "seniorie",
    "seniorii": "seniorie",
    "senioriile": "seniorie",
    "senioriilor": "seniorie",
    "sensul": "sens",
    "sensului": "sens",
    "sensuri": "sens",
    "sensurile": "sens",
    "sensurilor": "sens",
    "sensibila": "sensibil",
    "sensibilă": "sensibil",
    "sensibile": "sensibil",
    "sensibilei": "sensibil",
    "sensibilele": "sensibil",
    "sensibilelor": "sensibil",
    "sensibili": "sensibil",
    "sensibilii": "sensibil",
    "sensibililor": "sensibil",
    "sensibilul": "sensibil",
    "sensibilului": "sensibil",
    "sensibilitatea": "sensibilitate",
    "sensibilități": "sensibilitate",
    "sensibilității": "sensibilitate",
    "sensibilitățile": "sensibilitate",
    "sensibilităților": "sensibilitate",
    "nemaisensibilizând": "sensibiliza",
    "nemaisensibilizându": "sensibiliza",
    "nesensibilizând": "sensibiliza",
    "nesensibilizându": "sensibiliza",
    "sensibiliză": "sensibiliza",
    "sensibilizai": "sensibiliza",
    "sensibilizam": "sensibiliza",
    "sensibilizăm": "sensibiliza",
    "sensibilizând": "sensibiliza",
    "sensibilizându": "sensibiliza",
    "sensibilizară": "sensibiliza",
    "sensibilizarăm": "sensibiliza",
    "sensibilizarăți": "sensibiliza",
    "sensibilizase": "sensibiliza",
    "sensibilizasem": "sensibiliza",
    "sensibilizaseră": "sensibiliza",
    "sensibilizaserăm": "sensibiliza",
    "sensibilizaserăți": "sensibiliza",
    "sensibilizaseși": "sensibiliza",
    "sensibilizași": "sensibiliza",
    "sensibilizat": "sensibiliza",
    "sensibilizați": "sensibiliza",
    "sensibilizau": "sensibiliza",
    "sensibilizează": "sensibiliza",
    "sensibilizez": "sensibiliza",
    "sensibilizeze": "sensibiliza",
    "sensibilizezi": "sensibiliza",
    "sensibilizată": "sensibilizat",
    "sensibilizate": "sensibilizat",
    "sensibilizați": "sensibilizat",
    "sensibilizatori": "sensibilizator",
    "sensibilizatorii": "sensibilizator",
    "sensibilizatorilor": "sensibilizator",
    "sensibilizatorul": "sensibilizator",
    "sensibilizatorului": "sensibilizator",
    "sensualitatea": "sensualitate",
    "sensualități": "sensualitate",
    "sensualității": "sensualitate",
    "sensualitățile": "sensualitate",
    "sensualităților": "sensualitate",
    "sentențioasa": "sentențios",
    "sentențioasă": "sentențios",
    "sentențioase": "sentențios",
    "sentențioasei": "sentențios",
    "sentențioasele": "sentențios",
    "sentențioaselor": "sentențios",
    "sentențioși": "sentențios",
    "sentențioșii": "sentențios",
    "sentențioșilor": "sentențios",
    "sentențiosul": "sentențios",
    "sentențiosului": "sentențios",
    "sentimente": "sentiment",
    "sentimentele": "sentiment",
    "sentimentelor": "sentiment",
    "sentimentul": "sentiment",
    "sentimentului": "sentiment",
    "sentimentala": "sentimental",
    "sentimentală": "sentimental",
    "sentimentale": "sentimental",
    "sentimentalei": "sentimental",
    "sentimentalele": "sentimental",
    "sentimentalelor": "sentimental",
    "sentimentali": "sentimental",
    "sentimentalii": "sentimental",
    "sentimentalilor": "sentimental",
    "sentimentalul": "sentimental",
    "sentimentalului": "sentimental",
    "sentimentalisme": "sentimentalism",
    "sentimentalismele": "sentimentalism",
    "sentimentalismelor": "sentimentalism",
    "sentimentalismul": "sentimentalism",
    "sentimentalismului": "sentimentalism",
    "sentimentalitatea": "sentimentalitate",
    "sentimentalități": "sentimentalitate",
    "sentimentalității": "sentimentalitate",
    "sentimentalitățile": "sentimentalitate",
    "sentimentalităților": "sentimentalitate",
    "sentimentalizarea": "sentimentalizare",
    "sentimentalizări": "sentimentalizare",
    "sentimentalizării": "sentimentalizare",
    "sentimentalizările": "sentimentalizare",
    "sentimentalizărilor": "sentimentalizare",
    "sentința": "sentință",
    "sentințe": "sentință",
    "sentinței": "sentință",
    "sentințele": "sentință",
    "sentințelor": "sentință",
    "senzația": "senzație",
    "senzației": "senzație",
    "senzații": "senzație",
    "senzațiile": "senzație",
    "senzațiilor": "senzație",
    "senzaționala": "senzațional",
    "senzațională": "senzațional",
    "senzaționale": "senzațional",
    "senzaționalei": "senzațional",
    "senzaționalele": "senzațional",
    "senzaționalelor": "senzațional",
    "senzaționali": "senzațional",
    "senzaționalii": "senzațional",
    "senzaționalilor": "senzațional",
    "senzaționalul": "senzațional",
    "senzaționalului": "senzațional",
    "senzitiva": "senzitiv",
    "senzitivă": "senzitiv",
    "senzitive": "senzitiv",
    "senzitivei": "senzitiv",
    "senzitivele": "senzitiv",
    "senzitivelor": "senzitiv",
    "senzitivi": "senzitiv",
    "senzitivii": "senzitiv",
    "senzitivilor": "senzitiv",
    "senzitivul": "senzitiv",
    "senzitivului": "senzitiv",
    "senzoriala": "senzorial",
    "senzorială": "senzorial",
    "senzoriale": "senzorial",
    "senzorialei": "senzorial",
    "senzorialele": "senzorial",
    "senzorialelor": "senzorial",
    "senzoriali": "senzorial",
    "senzorialii": "senzorial",
    "senzorialilor": "senzorial",
    "senzorialul": "senzorial",
    "senzorialului": "senzorial",
    "senzuala": "senzual",
    "senzuală": "senzual",
    "senzuale": "senzual",
    "senzualei": "senzual",
    "senzualele": "senzual",
    "senzualelor": "senzual",
    "senzuali": "senzual",
    "senzualii": "senzual",
    "senzualilor": "senzual",
    "senzualul": "senzual",
    "senzualului": "senzual",
    "senzualismul": "senzualism",
    "senzualismului": "senzualism",
    "senzualista": "senzualist",
    "senzualistă": "senzualist",
    "senzualiste": "senzualist",
    "senzualistei": "senzualist",
    "senzualistele": "senzualist",
    "senzualistelor": "senzualist",
    "senzualiști": "senzualist",
    "senzualiștii": "senzualist",
    "senzualiștilor": "senzualist",
    "senzualistul": "senzualist",
    "senzualistului": "senzualist",
    "senzualista": "senzualistă",
    "senzualiste": "senzualistă",
    "senzualistei": "senzualistă",
    "senzualistele": "senzualistă",
    "senzualistelor": "senzualistă",
    "senzualitatea": "senzualitate",
    "senzualități": "senzualitate",
    "senzualității": "senzualitate",
    "senzualitățile": "senzualitate",
    "senzualităților": "senzualitate",
    "sepala": "sepală",
    "sepale": "sepală",
    "sepalei": "sepală",
    "sepalele": "sepală",
    "sepalelor": "sepală",
    "nemaiseparând": "separa",
    "nemaiseparându": "separa",
    "neseparând": "separa",
    "neseparându": "separa",
    "separ": "separa",
    "separă": "separa",
    "separai": "separa",
    "separam": "separa",
    "separăm": "separa",
    "separând": "separa",
    "separându": "separa",
    "separară": "separa",
    "separarăm": "separa",
    "separarăți": "separa",
    "separase": "separa",
    "separasem": "separa",
    "separaseră": "separa",
    "separaserăm": "separa",
    "separaserăți": "separa",
    "separaseși": "separa",
    "separași": "separa",
    "separat": "separa",
    "separați": "separa",
    "separau": "separa",
    "separe": "separa",
    "separi": "separa",
    "separabila": "separabil",
    "separabilă": "separabil",
    "separabile": "separabil",
    "separabilei": "separabil",
    "separabilele": "separabil",
    "separabilelor": "separabil",
    "separabili": "separabil",
    "separabilii": "separabil",
    "separabililor": "separabil",
    "separabilo": "separabil",
    "separabilul": "separabil",
    "separabilule": "separabil",
    "separabilului": "separabil",
    "separarea": "separare",
    "separareo": "separare",
    "separări": "separare",
    "separării": "separare",
    "separările": "separare",
    "separărilor": "separare",
    "separata": "separat",
    "separată": "separat",
    "separate": "separat",
    "separatei": "separat",
    "separatele": "separat",
    "separatelor": "separat",
    "separați": "separat",
    "separații": "separat",
    "separaților": "separat",
    "separato": "separat",
    "separatul": "separat",
    "separatule": "separat",
    "separatului": "separat",
    "separația": "separație",
    "separației": "separație",
    "separații": "separație",
    "separațiile": "separație",
    "separațiilor": "separație",
    "separatismul": "separatism",
    "separatismului": "separatism",
    "separatiști": "separatist",
    "separatiștii": "separatist",
    "separatiștilor": "separatist",
    "separatistul": "separatist",
    "separatistului": "separatist",
    "separatista": "separatistă",
    "separatiste": "separatistă",
    "separatistei": "separatistă",
    "separatistele": "separatistă",
    "separatistelor": "separatistă",
    "separeul": "separeu",
    "separeului": "separeu",
    "separeuri": "separeu",
    "separeurile": "separeu",
    "separeurilor": "separeu",
    "șepcari": "șepcar",
    "șepcarii": "șepcar",
    "șepcarilor": "șepcar",
    "șepcarul": "șepcar",
    "șepcarului": "șepcar",
    "sepia": "sepie",
    "sepiei": "sepie",
    "sepii": "sepie",
    "sepiile": "sepie",
    "sepiilor": "sepie",
    "sepioni": "sepion",
    "sepionii": "sepion",
    "sepionilor": "sepion",
    "sepionul": "sepion",
    "sepionului": "sepion",
    "septul": "sept",
    "septului": "sept",
    "septuri": "sept",
    "septurile": "sept",
    "septurilor": "sept",
    "șeptelul": "șeptel",
    "șeptelului": "șeptel",
    "șepteluri": "șeptel",
    "șeptelurile": "șeptel",
    "șeptelurilor": "șeptel",
    "septembriele": "septembrie",
    "septembrielui": "septembrie",
    "septenari": "septenar",
    "septenarii": "septenar",
    "septenarilor": "septenar",
    "septenarul": "septenar",
    "septenarului": "septenar",
    "septentrionala": "septentrional",
    "septentrională": "septentrional",
    "septentrionale": "septentrional",
    "septentrionalei": "septentrional",
    "septentrionalele": "septentrional",
    "septentrionalelor": "septentrional",
    "septentrionali": "septentrional",
    "septentrionalii": "septentrional",
    "septentrionalilor": "septentrional",
    "septentrionalul": "septentrional",
    "septentrionalului": "septentrional",
    "septete": "septet",
    "septetele": "septet",
    "septetelor": "septet",
    "septetul": "septet",
    "septetului": "septet",
    "septica": "septic",
    "septică": "septic",
    "septice": "septic",
    "septicei": "septic",
    "septicele": "septic",
    "septicelor": "septic",
    "septici": "septic",
    "septicii": "septic",
    "septicilor": "septic",
    "septicul": "septic",
    "septicului": "septic",
    "septicemia": "septicemie",
    "septicemiei": "septicemie",
    "septicemii": "septicemie",
    "septicemiile": "septicemie",
    "septicemiilor": "septicemie",
    "septicitatea": "septicitate",
    "septicități": "septicitate",
    "septicității": "septicitate",
    "septicitățile": "septicitate",
    "septicităților": "septicitate",
    "septima": "septimă",
    "septime": "septimă",
    "septimei": "septimă",
    "septimele": "septimă",
    "septimelor": "septimă",
    "șeptimea": "șeptime",
    "șeptimi": "șeptime",
    "șeptimii": "șeptime",
    "șeptimile": "șeptime",
    "șeptimilor": "șeptime",
    "septolete": "septolet",
    "septoletele": "septolet",
    "septoletelor": "septolet",
    "septoletul": "septolet",
    "septoletului": "septolet",
    "septuagenari": "septuagenar",
    "septuagenarii": "septuagenar",
    "septuagenarilor": "septuagenar",
    "septuagenarul": "septuagenar",
    "septuagenarului": "septuagenar",
    "septuagenara": "septuagenară",
    "septuagenare": "septuagenară",
    "septuagenarei": "septuagenară",
    "septuagenarele": "septuagenară",
    "septuagenarelor": "septuagenară",
    "sepulcrala": "sepulcral",
    "sepulcrală": "sepulcral",
    "sepulcrale": "sepulcral",
    "sepulcralei": "sepulcral",
    "sepulcralele": "sepulcral",
    "sepulcralelor": "sepulcral",
    "sepulcrali": "sepulcral",
    "sepulcralii": "sepulcral",
    "sepulcralilor": "sepulcral",
    "sepulcralul": "sepulcral",
    "sepulcralului": "sepulcral",
    "sepulcre": "sepulcru",
    "sepulcrele": "sepulcru",
    "sepulcrelor": "sepulcru",
    "sepulcrul": "sepulcru",
    "sepulcrului": "sepulcru",
    "sepultura": "sepultură",
    "sepulturi": "sepultură",
    "sepulturii": "sepultură",
    "sepulturile": "sepultură",
    "sepulturilor": "sepultură",
    "serul": "ser",
    "serului": "ser",
    "seruri": "ser",
    "serurile": "ser",
    "serurilor": "ser",
    "sera": "seră",
    "sere": "seră",
    "serei": "seră",
    "serele": "seră",
    "serelor": "seră",
    "serafica": "serafic",
    "serafică": "serafic",
    "serafice": "serafic",
    "seraficei": "serafic",
    "seraficele": "serafic",
    "seraficelor": "serafic",
    "serafici": "serafic",
    "seraficii": "serafic",
    "seraficilor": "serafic",
    "seraficul": "serafic",
    "seraficului": "serafic",
    "serafimi": "serafim",
    "serafimii": "serafim",
    "serafimilor": "serafim",
    "serafimul": "serafim",
    "serafimului": "serafim",
    "seraiul": "serai",
    "seraiului": "serai",
    "seraiuri": "serai",
    "seraiurile": "serai",
    "seraiurilor": "serai",
    "serală": "seral",
    "serale": "seral",
    "serali": "seral",
    "serata": "serată",
    "serate": "serată",
    "seratei": "serată",
    "seratele": "serată",
    "seratelor": "serată",
    "șerbi": "șerb",
    "șerbii": "șerb",
    "șerbilor": "șerb",
    "șerbul": "șerb",
    "șerbului": "șerb",
    "nemaiserbând": "serba",
    "nemaiserbându": "serba",
    "neserbând": "serba",
    "neserbându": "serba",
    "serbă": "serba",
    "serbai": "serba",
    "serbam": "serba",
    "serbăm": "serba",
    "serbând": "serba",
    "serbându": "serba",
    "serbară": "serba",
    "serbarăm": "serba",
    "serbarăți": "serba",
    "serbase": "serba",
    "serbasem": "serba",
    "serbaseră": "serba",
    "serbaserăm": "serba",
    "serbaserăți": "serba",
    "serbaseși": "serba",
    "serbași": "serba",
    "serbat": "serba",
    "serbați": "serba",
    "serbau": "serba",
    "serbează": "serba",
    "serbez": "serba",
    "serbeze": "serba",
    "serbezi": "serba",
    "serbarea": "serbare",
    "serbări": "serbare",
    "serbării": "serbare",
    "serbările": "serbare",
    "serbărilor": "serbare",
    "serbată": "serbat",
    "serbate": "serbat",
    "serbați": "serbat",
    "șerbetul": "șerbet",
    "șerbetului": "șerbet",
    "șerbeturi": "șerbet",
    "șerbeturile": "șerbet",
    "șerbeturilor": "șerbet",
    "șerbia": "șerbie",
    "șerbiei": "șerbie",
    "șerbii": "șerbie",
    "serdari": "serdar",
    "serdarii": "serdar",
    "serdarilor": "serdar",
    "serdarul": "serdar",
    "serdarului": "serdar",
    "sereleul": "sereleu",
    "sereleului": "sereleu",
    "sereleuri": "sereleu",
    "sereleurile": "sereleu",
    "sereleurilor": "sereleu",
    "serenada": "serenadă",
    "serenade": "serenadă",
    "serenadei": "serenadă",
    "serenadele": "serenadă",
    "serenadelor": "serenadă",
    "serenisima": "serenisim",
    "serenisimă": "serenisim",
    "serenisime": "serenisim",
    "serenisimei": "serenisim",
    "serenisimele": "serenisim",
    "serenisimelor": "serenisim",
    "serenisimi": "serenisim",
    "serenisimii": "serenisim",
    "serenisimilor": "serenisim",
    "serenisimul": "serenisim",
    "serenisimului": "serenisim",
    "serg.": "sergent",
    "sergenți": "sergent",
    "sergenții": "sergent",
    "sergenților": "sergent",
    "sergentul": "sergent",
    "sergentului": "sergent",
    "serg.maj.": "sergent_major",
    "sergenții-majori": "sergent-major",
    "sergenților-majori": "sergent-major",
    "sergenți-majori": "sergent-major",
    "sergentul-major": "sergent-major",
    "sergentului-major": "sergent-major",
    "nemaiseriind": "seria",
    "nemaiseriindu": "seria",
    "neseriind": "seria",
    "neseriindu": "seria",
    "seriai": "seria",
    "seriam": "seria",
    "seriară": "seria",
    "seriarăm": "seria",
    "seriarăți": "seria",
    "seriase": "seria",
    "seriasem": "seria",
    "seriaseră": "seria",
    "seriaserăm": "seria",
    "seriaserăți": "seria",
    "seriaseși": "seria",
    "seriași": "seria",
    "seriat": "seria",
    "seriați": "seria",
    "seriau": "seria",
    "seriază": "seria",
    "serie": "seria",
    "seriem": "seria",
    "seriez": "seria",
    "serieze": "seria",
    "seriezi": "seria",
    "seriind": "seria",
    "seriindu": "seria",
    "seriale": "serial",
    "serialele": "serial",
    "serialelor": "serial",
    "serialul": "serial",
    "serialului": "serial",
    "seriată": "seriat",
    "seriate": "seriat",
    "seriați": "seriat",
    "sericicola": "sericicol",
    "sericicolă": "sericicol",
    "sericicole": "sericicol",
    "sericicolei": "sericicol",
    "sericicolele": "sericicol",
    "sericicolelor": "sericicol",
    "sericicoli": "sericicol",
    "sericicolii": "sericicol",
    "sericicolilor": "sericicol",
    "sericicolul": "sericicol",
    "sericicolului": "sericicol",
    "sericicultoarea": "sericicultoare",
    "sericicultoarei": "sericicultoare",
    "sericicultoarele": "sericicultoare",
    "sericicultoarelor": "sericicultoare",
    "sericicultori": "sericicultor",
    "sericicultorii": "sericicultor",
    "sericicultorilor": "sericicultor",
    "sericicultorul": "sericicultor",
    "sericicultorului": "sericicultor",
    "sericicultura": "sericicultură",
    "sericiculturi": "sericicultură",
    "sericiculturii": "sericicultură",
    "sericiculturile": "sericicultură",
    "sericiculturilor": "sericicultură",
    "seria": "serie",
    "seriei": "serie",
    "serii": "serie",
    "seriile": "serie",
    "seriilor": "serie",
    "s.n.": "serie_nouă",
    "serierea": "seriere",
    "serieri": "seriere",
    "serierii": "seriere",
    "serierile": "seriere",
    "serierilor": "seriere",
    "șerifi": "șerif",
    "șerifii": "șerif",
    "șerifilor": "șerif",
    "șeriful": "șerif",
    "șerifului": "șerif",
    "seringa": "seringă",
    "seringi": "seringă",
    "seringii": "seringă",
    "seringile": "seringă",
    "seringilor": "seringă",
    "serioasa": "serios",
    "serioasă": "serios",
    "serioase": "serios",
    "serioasei": "serios",
    "serioasele": "serios",
    "serioaselor": "serios",
    "serioși": "serios",
    "serioșii": "serios",
    "serioșilor": "serios",
    "seriosul": "serios",
    "seriosului": "serios",
    "seriozitatea": "seriozitate",
    "seriozități": "seriozitate",
    "seriozității": "seriozitate",
    "seriozitățile": "seriozitate",
    "seriozităților": "seriozitate",
    "serjul": "serj",
    "serjului": "serj",
    "serjuri": "serj",
    "serjurile": "serj",
    "serjurilor": "serj",
    "serodiagnostice": "serodiagnostic",
    "serodiagnosticele": "serodiagnostic",
    "serodiagnosticelor": "serodiagnostic",
    "serodiagnosticul": "serodiagnostic",
    "serodiagnosticului": "serodiagnostic",
    "serologica": "serologic",
    "serologică": "serologic",
    "serologice": "serologic",
    "serologicei": "serologic",
    "serologicele": "serologic",
    "serologicelor": "serologic",
    "serologici": "serologic",
    "serologicii": "serologic",
    "serologicilor": "serologic",
    "serologicul": "serologic",
    "serologicului": "serologic",
    "serologia": "serologie",
    "serologiei": "serologie",
    "serologii": "serologie",
    "serologiile": "serologie",
    "serologiilor": "serologie",
    "seroprofilaxia": "seroprofilaxie",
    "seroprofilaxiei": "seroprofilaxie",
    "seroprofilaxii": "seroprofilaxie",
    "seroprofilaxiile": "seroprofilaxie",
    "seroprofilaxiilor": "seroprofilaxie",
    "seroasa": "seros",
    "seroasă": "seros",
    "seroase": "seros",
    "seroasei": "seros",
    "seroasele": "seros",
    "seroaselor": "seros",
    "seroși": "seros",
    "seroșii": "seros",
    "seroșilor": "seros",
    "serosul": "seros",
    "serosului": "seros",
    "seroterapia": "seroterapie",
    "seroterapiei": "seroterapie",
    "seroterapii": "seroterapie",
    "seroterapiile": "seroterapie",
    "seroterapiilor": "seroterapie",
    "serozitatea": "serozitate",
    "serozități": "serozitate",
    "serozității": "serozitate",
    "serozitățile": "serozitate",
    "serozităților": "serozitate",
    "șerpare": "șerpar",
    "șerparele": "șerpar",
    "șerparelor": "șerpar",
    "șerpari": "șerpar",
    "șerparii": "șerpar",
    "șerparilor": "șerpar",
    "șerparul": "șerpar",
    "șerparului": "șerpar",
    "șerpăria": "șerpărie",
    "șerpăriei": "șerpărie",
    "șerpării": "șerpărie",
    "șerpăriile": "șerpărie",
    "șerpăriilor": "șerpărie",
    "șerpași": "șerpaș",
    "șerpașii": "șerpaș",
    "șerpașul": "șerpaș",
    "șerpașului": "șerpaș",
    "serpentina": "serpentină",
    "serpentine": "serpentină",
    "serpentinei": "serpentină",
    "serpentinele": "serpentină",
    "serpentinelor": "serpentină",
    "șerpeasca": "șerpesc",
    "șerpească": "șerpesc",
    "șerpescul": "șerpesc",
    "șerpescului": "șerpesc",
    "șerpești": "șerpesc",
    "șerpeștii": "șerpesc",
    "șerpeștile": "șerpesc",
    "șerpeștilor": "șerpesc",
    "șerpișori": "șerpișor",
    "șerpișorii": "șerpișor",
    "șerpișorilor": "șerpișor",
    "șerpișorul": "șerpișor",
    "șerpișorului": "șerpișor",
    "șerpoaica": "șerpoaică",
    "șerpoaice": "șerpoaică",
    "șerpoaicei": "șerpoaică",
    "șerpoaicele": "șerpoaică",
    "șerpoaicelor": "șerpoaică",
    "șerpoii": "șerpoi",
    "șerpoilor": "șerpoi",
    "șerpoiul": "șerpoi",
    "șerpoiului": "șerpoi",
    "nemaișerpuind": "șerpui",
    "nemaișerpuindu": "șerpui",
    "neșerpuind": "șerpui",
    "neșerpuindu": "șerpui",
    "șerpuia": "șerpui",
    "șerpuiai": "șerpui",
    "șerpuiam": "șerpui",
    "șerpuiască": "șerpui",
    "șerpuiați": "șerpui",
    "șerpuiau": "șerpui",
    "șerpuiesc": "șerpui",
    "șerpuiește": "șerpui",
    "șerpuiești": "șerpui",
    "șerpuii": "șerpui",
    "șerpuim": "șerpui",
    "șerpuind": "șerpui",
    "șerpuindu": "șerpui",
    "șerpuiră": "șerpui",
    "șerpuirăm": "șerpui",
    "șerpuirăți": "șerpui",
    "șerpuise": "șerpui",
    "șerpuisem": "șerpui",
    "șerpuiseră": "șerpui",
    "șerpuiserăm": "șerpui",
    "șerpuiserăți": "șerpui",
    "șerpuiseși": "șerpui",
    "șerpuiși": "șerpui",
    "șerpuit": "șerpui",
    "șerpuiți": "șerpui",
    "șerpuirea": "șerpuire",
    "șerpuireo": "șerpuire",
    "șerpuiri": "șerpuire",
    "șerpuirii": "șerpuire",
    "șerpuirile": "șerpuire",
    "șerpuirilor": "șerpuire",
    "șerpuită": "șerpuit",
    "șerpuite": "șerpuit",
    "șerpuiți": "șerpuit",
    "sertare": "sertar",
    "sertarele": "sertar",
    "sertarelor": "sertar",
    "sertarul": "sertar",
    "sertarului": "sertar",
    "servi": "serv",
    "servii": "serv",
    "servilor": "serv",
    "servul": "serv",
    "servului": "serv",
    "serva": "servă",
    "serve": "servă",
    "servei": "servă",
    "servele": "servă",
    "servelor": "servă",
    "servanți": "servant",
    "servanții": "servant",
    "servanților": "servant",
    "servantul": "servant",
    "servantului": "servant",
    "servanta": "servantă",
    "servante": "servantă",
    "servantei": "servantă",
    "servantele": "servantă",
    "servantelor": "servantă",
    "șervete": "șervet",
    "șervetele": "șervet",
    "șervetelor": "șervet",
    "șervetul": "șervet",
    "șervetului": "șervet",
    "șervețele": "șervețel",
    "șervețelele": "șervețel",
    "șervețelelor": "șervețel",
    "șervețelul": "șervețel",
    "șervețelului": "șervețel",
    "nemaiservind": "servi",
    "nemaiservindu": "servi",
    "neservind": "servi",
    "neservindu": "servi",
    "servea": "servi",
    "serveai": "servi",
    "serveam": "servi",
    "servească": "servi",
    "serveați": "servi",
    "serveau": "servi",
    "servesc": "servi",
    "servește": "servi",
    "servești": "servi",
    "servii": "servi",
    "servim": "servi",
    "servind": "servi",
    "servindu": "servi",
    "serviră": "servi",
    "servirăm": "servi",
    "servirăți": "servi",
    "servise": "servi",
    "servisem": "servi",
    "serviseră": "servi",
    "serviserăm": "servi",
    "serviserăți": "servi",
    "serviseși": "servi",
    "serviși": "servi",
    "servit": "servi",
    "serviți": "servi",
    "serviabila": "serviabil",
    "serviabilă": "serviabil",
    "serviabile": "serviabil",
    "serviabilei": "serviabil",
    "serviabilele": "serviabil",
    "serviabilelor": "serviabil",
    "serviabili": "serviabil",
    "serviabilii": "serviabil",
    "serviabililor": "serviabil",
    "serviabilul": "serviabil",
    "serviabilului": "serviabil",
    "serviabilitatea": "serviabilitate",
    "serviabilități": "serviabilitate",
    "serviabilității": "serviabilitate",
    "serviabilitățile": "serviabilitate",
    "serviabilităților": "serviabilitate",
    "servicii": "serviciu",
    "serviciile": "serviciu",
    "serviciilor": "serviciu",
    "serviciul": "serviciu",
    "serviciului": "serviciu",
    "serv.": "serviciul",
    "SPP": "Serviciul_de_Pază_și_Protecție",
    "SRI": "Serviciul_Român_de_Informații",
    "servieta": "servietă",
    "serviete": "servietă",
    "servietei": "servietă",
    "servietele": "servietă",
    "servietelor": "servietă",
    "servila": "servil",
    "servilă": "servil",
    "servile": "servil",
    "servilei": "servil",
    "servilele": "servil",
    "servilelor": "servil",
    "servili": "servil",
    "servilii": "servil",
    "servililor": "servil",
    "servilul": "servil",
    "servilului": "servil",
    "servilismul": "servilism",
    "servilismului": "servilism",
    "servilitatea": "servilitate",
    "servilități": "servilitate",
    "servilității": "servilitate",
    "servilitățile": "servilitate",
    "servilităților": "servilitate",
    "servită": "servit",
    "servite": "servit",
    "serviți": "servit",
    "servitoarea": "servitoare",
    "servitoarei": "servitoare",
    "servitoarele": "servitoare",
    "servitoarelor": "servitoare",
    "servitori": "servitor",
    "servitorii": "servitor",
    "servitorilor": "servitor",
    "servitorul": "servitor",
    "servitorului": "servitor",
    "servitudinea": "servitudine",
    "servitudini": "servitudine",
    "servitudinii": "servitudine",
    "servitudinile": "servitudine",
    "servitudinilor": "servitudine",
    "servitutea": "servitute",
    "servituți": "servitute",
    "servituții": "servitute",
    "servituțile": "servitute",
    "servituților": "servitute",
    "servocomanda": "servocomandă",
    "servocomenzi": "servocomandă",
    "servocomenzii": "servocomandă",
    "servocomenzile": "servocomandă",
    "servocomenzilor": "servocomandă",
    "servoelemente": "servoelement",
    "servoelementele": "servoelement",
    "servoelementelor": "servoelement",
    "servoelementul": "servoelement",
    "servoelementului": "servoelement",
    "servofrâna": "servofrână",
    "servofrâne": "servofrână",
    "servofrânei": "servofrână",
    "servofrânele": "servofrână",
    "servofrânelor": "servofrână",
    "servomecanisme": "servomecanism",
    "servomecanismele": "servomecanism",
    "servomecanismelor": "servomecanism",
    "servomecanismul": "servomecanism",
    "servomecanismului": "servomecanism",
    "servomotoare": "servomotor",
    "servomotoarele": "servomotor",
    "servomotoarelor": "servomotor",
    "servomotorul": "servomotor",
    "servomotorului": "servomotor",
    "servoreglarea": "servoreglare",
    "servoreglări": "servoreglare",
    "servoreglării": "servoreglare",
    "servoreglările": "servoreglare",
    "servoreglărilor": "servoreglare",
    "șesul": "șes",
    "șesului": "șes",
    "șesuri": "șes",
    "șesurile": "șes",
    "șesurilor": "șes",
    "șesimea": "șesime",
    "șesimi": "șesime",
    "șesimii": "șesime",
    "șesimile": "șesime",
    "șesimilor": "șesime",
    "sesiunea": "sesiune",
    "sesiuni": "sesiune",
    "sesiunii": "sesiune",
    "sesiunile": "sesiune",
    "sesiunilor": "sesiune",
    "nemaisesizând": "sesiza",
    "nemaisesizându": "sesiza",
    "nesesizând": "sesiza",
    "nesesizându": "sesiza",
    "sesiză": "sesiza",
    "sesizai": "sesiza",
    "sesizam": "sesiza",
    "sesizăm": "sesiza",
    "sesizând": "sesiza",
    "sesizându": "sesiza",
    "sesizară": "sesiza",
    "sesizarăm": "sesiza",
    "sesizarăți": "sesiza",
    "sesizase": "sesiza",
    "sesizasem": "sesiza",
    "sesizaseră": "sesiza",
    "sesizaserăm": "sesiza",
    "sesizaserăți": "sesiza",
    "sesizaseși": "sesiza",
    "sesizași": "sesiza",
    "sesizat": "sesiza",
    "sesizați": "sesiza",
    "sesizau": "sesiza",
    "sesizează": "sesiza",
    "sesizez": "sesiza",
    "sesizeze": "sesiza",
    "sesizezi": "sesiza",
    "sesizarea": "sesizare",
    "sesizări": "sesizare",
    "sesizării": "sesizare",
    "sesizările": "sesizare",
    "sesizărilor": "sesizare",
    "sesizată": "sesizat",
    "sesizate": "sesizat",
    "sesizați": "sesizat",
    "setul": "set",
    "setului": "set",
    "seturi": "set",
    "seturile": "set",
    "seturilor": "set",
    "setaveraje": "setaveraj",
    "setaverajele": "setaveraj",
    "setaverajelor": "setaveraj",
    "setaverajul": "setaveraj",
    "setaverajului": "setaveraj",
    "setca": "setcă",
    "setci": "setcă",
    "setcii": "setcă",
    "setcile": "setcă",
    "setcilor": "setcă",
    "setcari": "setcar",
    "setcarii": "setcar",
    "setcarilor": "setcar",
    "setcarul": "setcar",
    "setcarului": "setcar",
    "setea": "sete",
    "setei": "sete",
    "setoasa": "setos",
    "setoasă": "setos",
    "setoase": "setos",
    "setoasei": "setos",
    "setoasele": "setos",
    "setoaselor": "setos",
    "setoși": "setos",
    "setoșii": "setos",
    "setoșilor": "setos",
    "setosul": "setos",
    "setosului": "setos",
    "seul": "seu",
    "seului": "seu",
    "seva": "sevă",
    "seve": "sevă",
    "sevei": "sevă",
    "sevele": "sevă",
    "sevelor": "sevă",
    "șevalete": "șevalet",
    "șevaletele": "șevalet",
    "șevaletelor": "șevalet",
    "șevaletul": "șevalet",
    "șevaletului": "șevalet",
    "severa": "sever",
    "severă": "sever",
    "severe": "sever",
    "severei": "sever",
    "severele": "sever",
    "severelor": "sever",
    "severi": "sever",
    "severii": "sever",
    "severilor": "sever",
    "severul": "sever",
    "severului": "sever",
    "severineana": "severinean",
    "severineană": "severinean",
    "severineanul": "severinean",
    "severineanului": "severinean",
    "severinene": "severinean",
    "severinenei": "severinean",
    "severinenele": "severinean",
    "severinenelor": "severinean",
    "severineni": "severinean",
    "severinenii": "severinean",
    "severinenilor": "severinean",
    "severitatea": "severitate",
    "severități": "severitate",
    "severității": "severitate",
    "severitățile": "severitate",
    "severităților": "severitate",
    "șevroul": "șevro",
    "șevroului": "șevro",
    "șevrouri": "șevro",
    "șevrourile": "șevro",
    "șevrourilor": "șevro",
    "sexe": "sex",
    "sexele": "sex",
    "sexelor": "sex",
    "sexul": "sex",
    "sexului": "sex",
    "sexagenara": "sexagenar",
    "sexagenară": "sexagenar",
    "sexagenare": "sexagenar",
    "sexagenarei": "sexagenar",
    "sexagenarele": "sexagenar",
    "sexagenarelor": "sexagenar",
    "sexagenari": "sexagenar",
    "sexagenarii": "sexagenar",
    "sexagenarilor": "sexagenar",
    "sexagenarul": "sexagenar",
    "sexagenarului": "sexagenar",
    "sexagenara": "sexagenară",
    "sexagenare": "sexagenară",
    "sexagenarei": "sexagenară",
    "sexagenarele": "sexagenară",
    "sexagenarelor": "sexagenară",
    "sexagesimala": "sexagesimal",
    "sexagesimală": "sexagesimal",
    "sexagesimale": "sexagesimal",
    "sexagesimalei": "sexagesimal",
    "sexagesimalele": "sexagesimal",
    "sexagesimalelor": "sexagesimal",
    "sexagesimali": "sexagesimal",
    "sexagesimalii": "sexagesimal",
    "sexagesimalilor": "sexagesimal",
    "sexagesimalul": "sexagesimal",
    "sexagesimalului": "sexagesimal",
    "sexcrima": "sexcrimă",
    "sexologia": "sexologie",
    "sexologiei": "sexologie",
    "sexologii": "sexologie",
    "sexologiile": "sexologie",
    "sexologiilor": "sexologie",
    "sexta": "sextă",
    "sexte": "sextă",
    "sextei": "sextă",
    "sextele": "sextă",
    "sextelor": "sextă",
    "sextante": "sextant",
    "sextanții": "sextant",
    "sextanților": "sextant",
    "sextantul": "sextant",
    "sextantului": "sextant",
    "sextete": "sextet",
    "sextetele": "sextet",
    "sextetelor": "sextet",
    "sextetul": "sextet",
    "sextetului": "sextet",
    "sextina": "sextină",
    "sextine": "sextină",
    "sextinei": "sextină",
    "sextinele": "sextină",
    "sextinelor": "sextină",
    "sexuala": "sexual",
    "sexuală": "sexual",
    "sexuale": "sexual",
    "sexualei": "sexual",
    "sexualele": "sexual",
    "sexualelor": "sexual",
    "sexuali": "sexual",
    "sexualii": "sexual",
    "sexualilor": "sexual",
    "sexualul": "sexual",
    "sexualului": "sexual",
    "sexualismul": "sexualism",
    "sexualismului": "sexualism",
    "sexualitatea": "sexualitate",
    "sexualități": "sexualitate",
    "sexualității": "sexualitate",
    "sexualitățile": "sexualitate",
    "sexualităților": "sexualitate",
    "sexuata": "sexuat",
    "sexuată": "sexuat",
    "sexuate": "sexuat",
    "sexuatei": "sexuat",
    "sexuatele": "sexuat",
    "sexuatelor": "sexuat",
    "sexuați": "sexuat",
    "sexuații": "sexuat",
    "sexuaților": "sexuat",
    "sexuatul": "sexuat",
    "sexuatului": "sexuat",
    "șezătoarea": "șezătoare",
    "șezători": "șezătoare",
    "șezătorii": "șezătoare",
    "șezătorile": "șezătoare",
    "șezătorilor": "șezătoare",
    "șezlongul": "șezlong",
    "șezlongului": "șezlong",
    "șezlonguri": "șezlong",
    "șezlongurile": "șezlong",
    "șezlongurilor": "șezlong",
    "sezoane": "sezon",
    "sezoanele": "sezon",
    "sezoanelor": "sezon",
    "sezonul": "sezon",
    "sezonului": "sezon",
    "sezoniera": "sezonier",
    "sezonieră": "sezonier",
    "sezoniere": "sezonier",
    "sezonierei": "sezonier",
    "sezonierele": "sezonier",
    "sezonierelor": "sezonier",
    "sezonieri": "sezonier",
    "sezonierii": "sezonier",
    "sezonierilor": "sezonier",
    "sezonierul": "sezonier",
    "sezonierului": "sezonier",
    "sezoniști": "sezonist",
    "sezoniștii": "sezonist",
    "sezoniștilor": "sezonist",
    "sezonistul": "sezonist",
    "sezonistului": "sezonist",
    "sezonista": "sezonistă",
    "sezoniste": "sezonistă",
    "sezonistei": "sezonistă",
    "sezonistele": "sezonistă",
    "sezonistelor": "sezonistă",
    "șezută": "șezut",
    "șezute": "șezut",
    "șezuți": "șezut",
    "șezutul": "șezut",
    "șezutului": "șezut",
    "șezuturi": "șezut",
    "șezuturile": "șezut",
    "șezuturilor": "șezut",
    "sfada": "sfadă",
    "sfezi": "sfadă",
    "sfezii": "sfadă",
    "sfezile": "sfadă",
    "sfezilor": "sfadă",
    "nemaisfădind": "sfădi",
    "nemaisfădindu": "sfădi",
    "nesfădind": "sfădi",
    "nesfădindu": "sfădi",
    "sfădea": "sfădi",
    "sfădeai": "sfădi",
    "sfădeam": "sfădi",
    "sfădească": "sfădi",
    "sfădeați": "sfădi",
    "sfădeau": "sfădi",
    "sfădesc": "sfădi",
    "sfădește": "sfădi",
    "sfădești": "sfădi",
    "sfădii": "sfădi",
    "sfădim": "sfădi",
    "sfădind": "sfădi",
    "sfădindu": "sfădi",
    "sfădiră": "sfădi",
    "sfădirăm": "sfădi",
    "sfădirăți": "sfădi",
    "sfădise": "sfădi",
    "sfădisem": "sfădi",
    "sfădiseră": "sfădi",
    "sfădiserăm": "sfădi",
    "sfădiserăți": "sfădi",
    "sfădiseși": "sfădi",
    "sfădiși": "sfădi",
    "sfădit": "sfădi",
    "sfădiți": "sfădi",
    "sfădită": "sfădit",
    "sfădite": "sfădit",
    "sfădiți": "sfădit",
    "sfanți": "sfanț",
    "sfanții": "sfanț",
    "sfanților": "sfanț",
    "sfanțul": "sfanț",
    "sfanțului": "sfanț",
    "sfânta": "sfânt",
    "sfântă": "sfânt",
    "sfântul": "sfânt",
    "sfântului": "sfânt",
    "sfinte": "sfânt",
    "sfintei": "sfânt",
    "sfintele": "sfânt",
    "sfintelor": "sfânt",
    "sfinți": "sfânt",
    "sfinții": "sfânt",
    "sfinților": "sfânt",
    "sfânta": "sfântă",
    "sfinte": "sfântă",
    "sfintei": "sfântă",
    "sfintele": "sfântă",
    "sfintelor": "sfântă",
    "sf.": "sfântul",
    "nemaisfârâind": "sfârâi",
    "nemaisfârâindu": "sfârâi",
    "nesfârâind": "sfârâi",
    "nesfârâindu": "sfârâi",
    "sfârâia": "sfârâi",
    "sfârâiai": "sfârâi",
    "sfârâiam": "sfârâi",
    "sfârâiați": "sfârâi",
    "sfârâiau": "sfârâi",
    "sfârâie": "sfârâi",
    "sfârâii": "sfârâi",
    "sfârâim": "sfârâi",
    "sfârâind": "sfârâi",
    "sfârâindu": "sfârâi",
    "sfârâiră": "sfârâi",
    "sfârâirăm": "sfârâi",
    "sfârâirăți": "sfârâi",
    "sfârâise": "sfârâi",
    "sfârâisem": "sfârâi",
    "sfârâiseră": "sfârâi",
    "sfârâiserăm": "sfârâi",
    "sfârâiserăți": "sfârâi",
    "sfârâiseși": "sfârâi",
    "sfârâiși": "sfârâi",
    "sfârâit": "sfârâi",
    "sfârâiți": "sfârâi",
    "sfârâiala": "sfârâială",
    "sfârâieli": "sfârâială",
    "sfârâielii": "sfârâială",
    "sfârâielile": "sfârâială",
    "sfârâielilor": "sfârâială",
    "sfârâită": "sfârâit",
    "sfârâite": "sfârâit",
    "sfârâiți": "sfârâit",
    "sfârâitul": "sfârâit",
    "sfârâitului": "sfârâit",
    "nemaisfărâmând": "sfărâma",
    "nemaisfărâmându": "sfărâma",
    "nesfărâmând": "sfărâma",
    "nesfărâmându": "sfărâma",
    "sfărâm": "sfărâma",
    "sfărâmă": "sfărâma",
    "sfărâmai": "sfărâma",
    "sfărâmam": "sfărâma",
    "sfărâmăm": "sfărâma",
    "sfărâmând": "sfărâma",
    "sfărâmându": "sfărâma",
    "sfărâmară": "sfărâma",
    "sfărâmarăm": "sfărâma",
    "sfărâmarăți": "sfărâma",
    "sfărâmase": "sfărâma",
    "sfărâmasem": "sfărâma",
    "sfărâmaseră": "sfărâma",
    "sfărâmaserăm": "sfărâma",
    "sfărâmaserăți": "sfărâma",
    "sfărâmaseși": "sfărâma",
    "sfărâmași": "sfărâma",
    "sfărâmat": "sfărâma",
    "sfărâmați": "sfărâma",
    "sfărâmau": "sfărâma",
    "sfărâme": "sfărâma",
    "sfărâmi": "sfărâma",
    "sfărâma": "sfărâmă",
    "sfărâme": "sfărâmă",
    "sfărâmei": "sfărâmă",
    "sfărâmele": "sfărâmă",
    "sfărâmelor": "sfărâmă",
    "sfărâmarea": "sfărâmare",
    "sfărâmată": "sfărâmat",
    "sfărâmate": "sfărâmat",
    "sfărâmați": "sfărâmat",
    "sfărâmătura": "sfărâmătură",
    "sfărâmături": "sfărâmătură",
    "sfărâmăturii": "sfărâmătură",
    "sfărâmăturile": "sfărâmătură",
    "sfărâmăturilor": "sfărâmătură",
    "sfărâmicioasa": "sfărâmicios",
    "sfărâmicioasă": "sfărâmicios",
    "sfărâmicioase": "sfărâmicios",
    "sfărâmicioasei": "sfărâmicios",
    "sfărâmicioasele": "sfărâmicios",
    "sfărâmicioaselor": "sfărâmicios",
    "sfărâmicioși": "sfărâmicios",
    "sfărâmicioșii": "sfărâmicios",
    "sfărâmicioșilor": "sfărâmicios",
    "sfărâmiciosul": "sfărâmicios",
    "sfărâmiciosului": "sfărâmicios",
    "sfârcul": "sfârc",
    "sfârcului": "sfârc",
    "sfârcuri": "sfârc",
    "sfârcurile": "sfârc",
    "sfârcurilor": "sfârc",
    "sfârleaza": "sfârlează",
    "sfârleze": "sfârlează",
    "sfârlezei": "sfârlează",
    "sfârlezele": "sfârlează",
    "sfârlezelor": "sfârlează",
    "nemaisfărmând": "sfărma",
    "nemaisfărmându": "sfărma",
    "nesfărmând": "sfărma",
    "nesfărmându": "sfărma",
    "sfarm": "sfărma",
    "sfarmă": "sfărma",
    "sfărmă": "sfărma",
    "sfărmai": "sfărma",
    "sfărmam": "sfărma",
    "sfărmăm": "sfărma",
    "sfărmând": "sfărma",
    "sfărmându": "sfărma",
    "sfărmară": "sfărma",
    "sfărmarăm": "sfărma",
    "sfărmarăți": "sfărma",
    "sfărmase": "sfărma",
    "sfărmasem": "sfărma",
    "sfărmaseră": "sfărma",
    "sfărmaserăm": "sfărma",
    "sfărmaserăți": "sfărma",
    "sfărmaseși": "sfărma",
    "sfărmași": "sfărma",
    "sfărmat": "sfărma",
    "sfărmați": "sfărma",
    "sfărmau": "sfărma",
    "sfarme": "sfărma",
    "sfarmi": "sfărma",
    "sfărmată": "sfărmat",
    "sfărmate": "sfărmat",
    "sfărmați": "sfărmat",
    "sfârșeala": "sfârșeală",
    "sfârșeli": "sfârșeală",
    "sfârșelii": "sfârșeală",
    "sfârșelile": "sfârșeală",
    "sfârșelilor": "sfârșeală",
    "nemaisfârșind": "sfârși",
    "nemaisfârșindu": "sfârși",
    "nesfârșind": "sfârși",
    "nesfârșindu": "sfârși",
    "sfârșea": "sfârși",
    "sfârșeai": "sfârși",
    "sfârșeam": "sfârși",
    "sfârșească": "sfârși",
    "sfârșeați": "sfârși",
    "sfârșeau": "sfârși",
    "sfârșesc": "sfârși",
    "sfârșește": "sfârși",
    "sfârșești": "sfârși",
    "sfârșii": "sfârși",
    "sfârșim": "sfârși",
    "sfârșind": "sfârși",
    "sfârșindu": "sfârși",
    "sfârșiră": "sfârși",
    "sfârșirăm": "sfârși",
    "sfârșirăți": "sfârși",
    "sfârșise": "sfârși",
    "sfârșisem": "sfârși",
    "sfârșiseră": "sfârși",
    "sfârșiserăm": "sfârși",
    "sfârșiserăți": "sfârși",
    "sfârșiseși": "sfârși",
    "sfârșiși": "sfârși",
    "sfârșit": "sfârși",
    "sfârșiți": "sfârși",
    "sfârșita": "sfârșit",
    "sfârșită": "sfârșit",
    "sfârșite": "sfârșit",
    "sfârșitei": "sfârșit",
    "sfârșitele": "sfârșit",
    "sfârșitelor": "sfârșit",
    "sfârșiți": "sfârșit",
    "sfârșiții": "sfârșit",
    "sfârșiților": "sfârșit",
    "sfârșitul": "sfârșit",
    "sfârșitului": "sfârșit",
    "nemaisfârtecând": "sfârteca",
    "nemaisfârtecându": "sfârteca",
    "nesfârtecând": "sfârteca",
    "nesfârtecându": "sfârteca",
    "sfârtec": "sfârteca",
    "sfârtecă": "sfârteca",
    "sfârtecai": "sfârteca",
    "sfârtecam": "sfârteca",
    "sfârtecăm": "sfârteca",
    "sfârtecând": "sfârteca",
    "sfârtecându": "sfârteca",
    "sfârtecară": "sfârteca",
    "sfârtecarăm": "sfârteca",
    "sfârtecarăți": "sfârteca",
    "sfârtecase": "sfârteca",
    "sfârtecasem": "sfârteca",
    "sfârtecaseră": "sfârteca",
    "sfârtecaserăm": "sfârteca",
    "sfârtecaserăți": "sfârteca",
    "sfârtecaseși": "sfârteca",
    "sfârtecași": "sfârteca",
    "sfârtecat": "sfârteca",
    "sfârtecați": "sfârteca",
    "sfârtecau": "sfârteca",
    "sfârtece": "sfârteca",
    "sfârteci": "sfârteca",
    "sfârtecată": "sfârtecat",
    "sfârtecate": "sfârtecat",
    "sfârtecați": "sfârtecat",
    "nemaisfârticând": "sfârtica",
    "nemaisfârticându": "sfârtica",
    "nesfârticând": "sfârtica",
    "nesfârticându": "sfârtica",
    "sfârtic": "sfârtica",
    "sfârtică": "sfârtica",
    "sfârticai": "sfârtica",
    "sfârticam": "sfârtica",
    "sfârticăm": "sfârtica",
    "sfârticând": "sfârtica",
    "sfârticându": "sfârtica",
    "sfârticară": "sfârtica",
    "sfârticarăm": "sfârtica",
    "sfârticarăți": "sfârtica",
    "sfârticase": "sfârtica",
    "sfârticasem": "sfârtica",
    "sfârticaseră": "sfârtica",
    "sfârticaserăm": "sfârtica",
    "sfârticaserăți": "sfârtica",
    "sfârticaseși": "sfârtica",
    "sfârticași": "sfârtica",
    "sfârticat": "sfârtica",
    "sfârticați": "sfârtica",
    "sfârticau": "sfârtica",
    "sfârtice": "sfârtica",
    "sfârtici": "sfârtica",
    "sfârticată": "sfârticat",
    "sfârticate": "sfârticat",
    "sfârticați": "sfârticat",
    "nemaisfâșiind": "sfâșia",
    "nemaisfâșiindu": "sfâșia",
    "nesfâșiind": "sfâșia",
    "nesfâșiindu": "sfâșia",
    "sfâși-": "sfâșia",
    "sfâșiai": "sfâșia",
    "sfâșiam": "sfâșia",
    "sfâșiară": "sfâșia",
    "sfâșiarăm": "sfâșia",
    "sfâșiarăți": "sfâșia",
    "sfâșiase": "sfâșia",
    "sfâșiasem": "sfâșia",
    "sfâșiaseră": "sfâșia",
    "sfâșiaserăm": "sfâșia",
    "sfâșiaserăți": "sfâșia",
    "sfâșiaseși": "sfâșia",
    "sfâșiași": "sfâșia",
    "sfâșiat": "sfâșia",
    "sfâșiați": "sfâșia",
    "sfâșiau": "sfâșia",
    "sfâșie": "sfâșia",
    "sfâșiem": "sfâșia",
    "sfâșii": "sfâșia",
    "sfâșiind": "sfâșia",
    "sfâșiindu": "sfâșia",
    "sfâșiata": "sfâșiat",
    "sfâșiată": "sfâșiat",
    "sfâșiate": "sfâșiat",
    "sfâșiatei": "sfâșiat",
    "sfâșiatele": "sfâșiat",
    "sfâșiatelor": "sfâșiat",
    "sfâșiați": "sfâșiat",
    "sfâșiații": "sfâșiat",
    "sfâșiaților": "sfâșiat",
    "sfâșiato": "sfâșiat",
    "sfâșiatul": "sfâșiat",
    "sfâșiatule": "sfâșiat",
    "sfâșiatului": "sfâșiat",
    "sfâșierea": "sfâșiere",
    "sfâșiereo": "sfâșiere",
    "sfâșieri": "sfâșiere",
    "sfâșierii": "sfâșiere",
    "sfâșierile": "sfâșiere",
    "sfâșierilor": "sfâșiere",
    "sfâșietoare": "sfâșietor",
    "sfâșietoarea": "sfâșietor",
    "sfâșietoarei": "sfâșietor",
    "sfâșietoarele": "sfâșietor",
    "sfâșietoarelor": "sfâșietor",
    "sfâșietori": "sfâșietor",
    "sfâșietorii": "sfâșietor",
    "sfâșietorilor": "sfâșietor",
    "sfâșietorul": "sfâșietor",
    "sfâșietorului": "sfâșietor",
    "sfâșietura": "sfâșietură",
    "sfâșieturi": "sfâșietură",
    "sfâșieturii": "sfâșietură",
    "sfâșieturile": "sfâșietură",
    "sfâșieturilor": "sfâșietură",
    "sfâșieturo": "sfâșietură",
    "sfatul": "sfat",
    "sfatului": "sfat",
    "sfaturi": "sfat",
    "sfaturile": "sfat",
    "sfaturilor": "sfat",
    "sfătoasa": "sfătos",
    "sfătoasă": "sfătos",
    "sfătoase": "sfătos",
    "sfătoasei": "sfătos",
    "sfătoasele": "sfătos",
    "sfătoaselor": "sfătos",
    "sfătoși": "sfătos",
    "sfătoșii": "sfătos",
    "sfătoșilor": "sfătos",
    "sfătosul": "sfătos",
    "sfătosului": "sfătos",
    "sfătoșenia": "sfătoșenie",
    "sfătoșeniei": "sfătoșenie",
    "sfătoșenii": "sfătoșenie",
    "sfătoșeniile": "sfătoșenie",
    "sfătoșeniilor": "sfătoșenie",
    "nemaisfătuind": "sfătui",
    "nemaisfătuindu": "sfătui",
    "nesfătuind": "sfătui",
    "nesfătuindu": "sfătui",
    "sfătuia": "sfătui",
    "sfătuiai": "sfătui",
    "sfătuiam": "sfătui",
    "sfătuiască": "sfătui",
    "sfătuiați": "sfătui",
    "sfătuiau": "sfătui",
    "sfătuiesc": "sfătui",
    "sfătuiește": "sfătui",
    "sfătuiești": "sfătui",
    "sfătuii": "sfătui",
    "sfătuim": "sfătui",
    "sfătuind": "sfătui",
    "sfătuindu": "sfătui",
    "sfătuiră": "sfătui",
    "sfătuirăm": "sfătui",
    "sfătuirăți": "sfătui",
    "sfătuise": "sfătui",
    "sfătuisem": "sfătui",
    "sfătuiseră": "sfătui",
    "sfătuiserăm": "sfătui",
    "sfătuiserăți": "sfătui",
    "sfătuiseși": "sfătui",
    "sfătuiși": "sfătui",
    "sfătuit": "sfătui",
    "sfătuiți": "sfătui",
    "sfătuiala": "sfătuială",
    "sfătuieli": "sfătuială",
    "sfătuielii": "sfătuială",
    "sfătuielile": "sfătuială",
    "sfătuielilor": "sfătuială",
    "sfătuirea": "sfătuire",
    "sfătuiri": "sfătuire",
    "sfătuirii": "sfătuire",
    "sfătuirile": "sfătuire",
    "sfătuirilor": "sfătuire",
    "sfătuită": "sfătuit",
    "sfătuite": "sfătuit",
    "sfătuiți": "sfătuit",
    "sfătuitoarea": "sfătuitoare",
    "sfătuitoarei": "sfătuitoare",
    "sfătuitoarele": "sfătuitoare",
    "sfătuitoarelor": "sfătuitoare",
    "sfătuitori": "sfătuitor",
    "sfătuitorii": "sfătuitor",
    "sfătuitorilor": "sfătuitor",
    "sfătuitorul": "sfătuitor",
    "sfătuitorului": "sfătuitor",
    "sfecla": "sfeclă",
    "sfecle": "sfeclă",
    "sfeclei": "sfeclă",
    "sfeclele": "sfeclă",
    "sfeclelor": "sfeclă",
    "nemaisfeclind": "sfecli",
    "nemaisfeclindu": "sfecli",
    "nesfeclind": "sfecli",
    "nesfeclindu": "sfecli",
    "sfeclea": "sfecli",
    "sfecleai": "sfecli",
    "sfecleam": "sfecli",
    "sfeclească": "sfecli",
    "sfecleați": "sfecli",
    "sfecleau": "sfecli",
    "sfeclesc": "sfecli",
    "sfeclește": "sfecli",
    "sfeclești": "sfecli",
    "sfeclii": "sfecli",
    "sfeclim": "sfecli",
    "sfeclind": "sfecli",
    "sfeclindu": "sfecli",
    "sfecliră": "sfecli",
    "sfeclirăm": "sfecli",
    "sfeclirăți": "sfecli",
    "sfeclise": "sfecli",
    "sfeclisem": "sfecli",
    "sfecliseră": "sfecli",
    "sfecliserăm": "sfecli",
    "sfecliserăți": "sfecli",
    "sfecliseși": "sfecli",
    "sfecliși": "sfecli",
    "sfeclit": "sfecli",
    "sfecliți": "sfecli",
    "sfeclită": "sfeclit",
    "sfeclite": "sfeclit",
    "sfecliți": "sfeclit",
    "sfenoide": "sfenoid",
    "sfenoidele": "sfenoid",
    "sfenoidelor": "sfenoid",
    "sfenoidul": "sfenoid",
    "sfenoidului": "sfenoid",
    "sfera": "sferă",
    "sfere": "sferă",
    "sferei": "sferă",
    "sferele": "sferă",
    "sferelor": "sferă",
    "sferica": "sferic",
    "sferică": "sferic",
    "sferice": "sferic",
    "sfericei": "sferic",
    "sfericele": "sferic",
    "sfericelor": "sferic",
    "sferici": "sferic",
    "sfericii": "sferic",
    "sfericilor": "sferic",
    "sfericul": "sferic",
    "sfericului": "sferic",
    "sfericitatea": "sfericitate",
    "sfericități": "sfericitate",
    "sfericității": "sfericitate",
    "sfericitățile": "sfericitate",
    "sfericităților": "sfericitate",
    "sferoide": "sferoid",
    "sferoidele": "sferoid",
    "sferoidelor": "sferoid",
    "sferoidul": "sferoid",
    "sferoidului": "sferoid",
    "sferoidala": "sferoidal",
    "sferoidală": "sferoidal",
    "sferoidale": "sferoidal",
    "sferoidalei": "sferoidal",
    "sferoidalele": "sferoidal",
    "sferoidalelor": "sferoidal",
    "sferoidali": "sferoidal",
    "sferoidalii": "sferoidal",
    "sferoidalilor": "sferoidal",
    "sferoidalul": "sferoidal",
    "sferoidalului": "sferoidal",
    "sferometre": "sferometru",
    "sferometrele": "sferometru",
    "sferometrelor": "sferometru",
    "sferometrul": "sferometru",
    "sferometrului": "sferometru",
    "sfertul": "sfert",
    "sfertului": "sfert",
    "sferturi": "sfert",
    "sferturile": "sfert",
    "sferturilor": "sfert",
    "sfeșnice": "sfeșnic",
    "sfeșnicele": "sfeșnic",
    "sfeșnicelor": "sfeșnic",
    "sfeșnicul": "sfeșnic",
    "sfeșnicului": "sfeșnic",
    "sfeștania": "sfeștanie",
    "sfeștaniei": "sfeștanie",
    "sfeștanii": "sfeștanie",
    "sfeștaniile": "sfeștanie",
    "sfeștaniilor": "sfeștanie",
    "sfeștoace": "sfeștoc",
    "sfeștoacele": "sfeștoc",
    "sfeștoacelor": "sfeștoc",
    "sfeștocul": "sfeștoc",
    "sfeștocului": "sfeștoc",
    "nemaisfetind": "sfeti",
    "nemaisfetindu": "sfeti",
    "nesfetind": "sfeti",
    "nesfetindu": "sfeti",
    "sfetea": "sfeti",
    "sfeteai": "sfeti",
    "sfeteam": "sfeti",
    "sfetească": "sfeti",
    "sfeteați": "sfeti",
    "sfeteau": "sfeti",
    "sfetesc": "sfeti",
    "sfetește": "sfeti",
    "sfetești": "sfeti",
    "sfetii": "sfeti",
    "sfetim": "sfeti",
    "sfetind": "sfeti",
    "sfetindu": "sfeti",
    "sfetiră": "sfeti",
    "sfetirăm": "sfeti",
    "sfetirăți": "sfeti",
    "sfetise": "sfeti",
    "sfetisem": "sfeti",
    "sfetiseră": "sfeti",
    "sfetiserăm": "sfeti",
    "sfetiserăți": "sfeti",
    "sfetiseși": "sfeti",
    "sfetiși": "sfeti",
    "sfetit": "sfeti",
    "sfetiți": "sfeti",
    "sfetită": "sfetit",
    "sfetite": "sfetit",
    "sfetiți": "sfetit",
    "sfetnici": "sfetnic",
    "sfetnicii": "sfetnic",
    "sfetnicilor": "sfetnic",
    "sfetnicul": "sfetnic",
    "sfetnicului": "sfetnic",
    "sfiala": "sfială",
    "sfieli": "sfială",
    "sfielii": "sfială",
    "sfielile": "sfială",
    "sfielilor": "sfială",
    "șfichiul": "șfichi",
    "șfichiului": "șfichi",
    "șfichiuri": "șfichi",
    "șfichiurile": "șfichi",
    "șfichiurilor": "șfichi",
    "nemaișfichiuind": "șfichiui",
    "nemaișfichiuindu": "șfichiui",
    "neșfichiuind": "șfichiui",
    "neșfichiuindu": "șfichiui",
    "șfichiuia": "șfichiui",
    "șfichiuiai": "șfichiui",
    "șfichiuiam": "șfichiui",
    "șfichiuiască": "șfichiui",
    "șfichiuiați": "șfichiui",
    "șfichiuiau": "șfichiui",
    "șfichiuiesc": "șfichiui",
    "șfichiuiește": "șfichiui",
    "șfichiuiești": "șfichiui",
    "șfichiuii": "șfichiui",
    "șfichiuim": "șfichiui",
    "șfichiuind": "șfichiui",
    "șfichiuindu": "șfichiui",
    "șfichiuiră": "șfichiui",
    "șfichiuirăm": "șfichiui",
    "șfichiuirăți": "șfichiui",
    "șfichiuise": "șfichiui",
    "șfichiuisem": "șfichiui",
    "șfichiuiseră": "șfichiui",
    "șfichiuiserăm": "șfichiui",
    "șfichiuiserăți": "șfichiui",
    "șfichiuiseși": "șfichiui",
    "șfichiuiși": "șfichiui",
    "șfichiuit": "șfichiui",
    "șfichiuiți": "șfichiui",
    "șfichiuirea": "șfichiuire",
    "șfichiuireo": "șfichiuire",
    "șfichiuiri": "șfichiuire",
    "șfichiuirii": "șfichiuire",
    "șfichiuirile": "șfichiuire",
    "șfichiuirilor": "șfichiuire",
    "șfichiuită": "șfichiuit",
    "șfichiuite": "șfichiuit",
    "șfichiuiți": "șfichiuit",
    "nemaisfidând": "sfida",
    "nemaisfidându": "sfida",
    "nesfidând": "sfida",
    "nesfidându": "sfida",
    "sfidă": "sfida",
    "sfidai": "sfida",
    "sfidam": "sfida",
    "sfidăm": "sfida",
    "sfidând": "sfida",
    "sfidându": "sfida",
    "sfidară": "sfida",
    "sfidarăm": "sfida",
    "sfidarăți": "sfida",
    "sfidase": "sfida",
    "sfidasem": "sfida",
    "sfidaseră": "sfida",
    "sfidaserăm": "sfida",
    "sfidaserăți": "sfida",
    "sfidaseși": "sfida",
    "sfidași": "sfida",
    "sfidat": "sfida",
    "sfidați": "sfida",
    "sfidau": "sfida",
    "sfidează": "sfida",
    "sfidez": "sfida",
    "sfideze": "sfida",
    "sfidezi": "sfida",
    "sfidarea": "sfidare",
    "sfidări": "sfidare",
    "sfidării": "sfidare",
    "sfidările": "sfidare",
    "sfidărilor": "sfidare",
    "sfidată": "sfidat",
    "sfidate": "sfidat",
    "sfidați": "sfidat",
    "sfidătoare": "sfidător",
    "sfidătoarea": "sfidător",
    "sfidătoarei": "sfidător",
    "sfidătoarele": "sfidător",
    "sfidătoarelor": "sfidător",
    "sfidători": "sfidător",
    "sfidătorii": "sfidător",
    "sfidătorilor": "sfidător",
    "sfidătorul": "sfidător",
    "sfidătorului": "sfidător",
    "sfielnica": "sfielnic",
    "sfielnică": "sfielnic",
    "sfielnice": "sfielnic",
    "sfielnicei": "sfielnic",
    "sfielnicele": "sfielnic",
    "sfielnicelor": "sfielnic",
    "sfielnici": "sfielnic",
    "sfielnicii": "sfielnic",
    "sfielnicilor": "sfielnic",
    "sfielnicul": "sfielnic",
    "sfielnicului": "sfielnic",
    "sfigmografe": "sfigmograf",
    "sfigmografele": "sfigmograf",
    "sfigmografelor": "sfigmograf",
    "sfigmograful": "sfigmograf",
    "sfigmografului": "sfigmograf",
    "nemaisfiind": "sfii",
    "nemaisfiindu": "sfii",
    "nesfiind": "sfii",
    "nesfiindu": "sfii",
    "sfia": "sfii",
    "sfiai": "sfii",
    "sfiam": "sfii",
    "sfiați": "sfii",
    "sfiau": "sfii",
    "sfiesc": "sfii",
    "sfiește": "sfii",
    "sfiești": "sfii",
    "sfiim": "sfii",
    "sfiind": "sfii",
    "sfiindu": "sfii",
    "sfiiră": "sfii",
    "sfiirăm": "sfii",
    "sfiirăți": "sfii",
    "sfiise": "sfii",
    "sfiisem": "sfii",
    "sfiiseră": "sfii",
    "sfiiserăm": "sfii",
    "sfiiserăți": "sfii",
    "sfiiseși": "sfii",
    "sfiiși": "sfii",
    "sfiit": "sfii",
    "sfiiți": "sfii",
    "sfiicioasa": "sfiicios",
    "sfiicioasă": "sfiicios",
    "sfiicioase": "sfiicios",
    "sfiicioasei": "sfiicios",
    "sfiicioasele": "sfiicios",
    "sfiicioaselor": "sfiicios",
    "sfiicioși": "sfiicios",
    "sfiicioșii": "sfiicios",
    "sfiicioșilor": "sfiicios",
    "sfiiciosul": "sfiicios",
    "sfiiciosului": "sfiicios",
    "sfiiciunea": "sfiiciune",
    "sfiiciuni": "sfiiciune",
    "sfiiciunii": "sfiiciune",
    "sfiiciunile": "sfiiciune",
    "sfiiciunilor": "sfiiciune",
    "sfiită": "sfiit",
    "sfiite": "sfiit",
    "sfiiți": "sfiit",
    "sfinctere": "sfincter",
    "sfincterele": "sfincter",
    "sfincterelor": "sfincter",
    "sfincterul": "sfincter",
    "sfincterului": "sfincter",
    "sfințenia": "sfințenie",
    "sfințeniei": "sfințenie",
    "sfințenii": "sfințenie",
    "nemaisfințind": "sfinți",
    "nemaisfințindu": "sfinți",
    "nesfințind": "sfinți",
    "nesfințindu": "sfinți",
    "sfințea": "sfinți",
    "sfințeai": "sfinți",
    "sfințeam": "sfinți",
    "sfințească": "sfinți",
    "sfințeați": "sfinți",
    "sfințeau": "sfinți",
    "sfințesc": "sfinți",
    "sfințește": "sfinți",
    "sfințești": "sfinți",
    "sfinții": "sfinți",
    "sfințim": "sfinți",
    "sfințind": "sfinți",
    "sfințindu": "sfinți",
    "sfințiră": "sfinți",
    "sfințirăm": "sfinți",
    "sfințirăți": "sfinți",
    "sfințise": "sfinți",
    "sfințisem": "sfinți",
    "sfințiseră": "sfinți",
    "sfințiserăm": "sfinți",
    "sfințiserăți": "sfinți",
    "sfințiseși": "sfinți",
    "sfințiși": "sfinți",
    "sfințit": "sfinți",
    "sfințiți": "sfinți",
    "sfinția": "sfinție",
    "sfinției": "sfinție",
    "sfinții": "sfinție",
    "sfințirea": "sfințire",
    "sfințiri": "sfințire",
    "sfințirii": "sfințire",
    "sfințirile": "sfințire",
    "sfințirilor": "sfințire",
    "sfințită": "sfințit",
    "sfințite": "sfințit",
    "sfințiți": "sfințit",
    "sfințitul": "sfințit",
    "sfințitului": "sfințit",
    "sfincși": "sfinx",
    "sfincșii": "sfinx",
    "sfincșilor": "sfinx",
    "sfinxul": "sfinx",
    "sfinxului": "sfinx",
    "sfioasa": "sfios",
    "sfioasă": "sfios",
    "sfioase": "sfios",
    "sfioasei": "sfios",
    "sfioasele": "sfios",
    "sfioaselor": "sfios",
    "sfioși": "sfios",
    "sfioșii": "sfios",
    "sfioșilor": "sfios",
    "sfiosul": "sfios",
    "sfiosului": "sfios",
    "sfoara": "sfoară",
    "sfori": "sfoară",
    "sforii": "sfoară",
    "sforile": "sfoară",
    "sforilor": "sfoară",
    "sfoiagul": "sfoiag",
    "sfoiagului": "sfoiag",
    "sfoiegi": "sfoiag",
    "sfoiegii": "sfoiag",
    "sfoiegilor": "sfoiag",
    "nemaisfoiegind": "sfoiegi",
    "nemaisfoiegindu": "sfoiegi",
    "nesfoiegind": "sfoiegi",
    "nesfoiegindu": "sfoiegi",
    "sfoiegea": "sfoiegi",
    "sfoiegeai": "sfoiegi",
    "sfoiegeam": "sfoiegi",
    "sfoiegească": "sfoiegi",
    "sfoiegeați": "sfoiegi",
    "sfoiegeau": "sfoiegi",
    "sfoiegesc": "sfoiegi",
    "sfoiegește": "sfoiegi",
    "sfoiegești": "sfoiegi",
    "sfoiegii": "sfoiegi",
    "sfoiegim": "sfoiegi",
    "sfoiegind": "sfoiegi",
    "sfoiegindu": "sfoiegi",
    "sfoiegiră": "sfoiegi",
    "sfoiegirăm": "sfoiegi",
    "sfoiegirăți": "sfoiegi",
    "sfoiegise": "sfoiegi",
    "sfoiegisem": "sfoiegi",
    "sfoiegiseră": "sfoiegi",
    "sfoiegiserăm": "sfoiegi",
    "sfoiegiserăți": "sfoiegi",
    "sfoiegiseși": "sfoiegi",
    "sfoiegiși": "sfoiegi",
    "sfoiegit": "sfoiegi",
    "sfoiegiți": "sfoiegi",
    "sfoiegita": "sfoiegit",
    "sfoiegită": "sfoiegit",
    "sfoiegite": "sfoiegit",
    "sfoiegitei": "sfoiegit",
    "sfoiegitele": "sfoiegit",
    "sfoiegitelor": "sfoiegit",
    "sfoiegiți": "sfoiegit",
    "sfoiegiții": "sfoiegit",
    "sfoiegiților": "sfoiegit",
    "sfoiegitul": "sfoiegit",
    "sfoiegitului": "sfoiegit",
    "nemaisforăind": "sforăi",
    "nemaisforăindu": "sforăi",
    "nesforăind": "sforăi",
    "nesforăindu": "sforăi",
    "sforăia": "sforăi",
    "sforăiai": "sforăi",
    "sforăiam": "sforăi",
    "sforăiați": "sforăi",
    "sforăiau": "sforăi",
    "sforăie": "sforăi",
    "sforăii": "sforăi",
    "sforăim": "sforăi",
    "sforăind": "sforăi",
    "sforăindu": "sforăi",
    "sforăiră": "sforăi",
    "sforăirăm": "sforăi",
    "sforăirăți": "sforăi",
    "sforăise": "sforăi",
    "sforăisem": "sforăi",
    "sforăiseră": "sforăi",
    "sforăiserăm": "sforăi",
    "sforăiserăți": "sforăi",
    "sforăiseși": "sforăi",
    "sforăiși": "sforăi",
    "sforăit": "sforăi",
    "sforăiți": "sforăi",
    "sforăiala": "sforăială",
    "sforăieli": "sforăială",
    "sforăielii": "sforăială",
    "sforăielile": "sforăială",
    "sforăielilor": "sforăială",
    "sforăită": "sforăit",
    "sforăite": "sforăit",
    "sforăiți": "sforăit",
    "sforăitul": "sforăit",
    "sforăitului": "sforăit",
    "sforăituri": "sforăit",
    "sforăiturile": "sforăit",
    "sforăiturilor": "sforăit",
    "sforari": "sforar",
    "sforarii": "sforar",
    "sforarilor": "sforar",
    "sforarul": "sforar",
    "sforarului": "sforar",
    "nemaisforțând": "sforța",
    "nemaisforțându": "sforța",
    "nesforțând": "sforța",
    "nesforțându": "sforța",
    "sforță": "sforța",
    "sforțai": "sforța",
    "sforțam": "sforța",
    "sforțăm": "sforța",
    "sforțând": "sforța",
    "sforțându": "sforța",
    "sforțară": "sforța",
    "sforțarăm": "sforța",
    "sforțarăți": "sforța",
    "sforțase": "sforța",
    "sforțasem": "sforța",
    "sforțaseră": "sforța",
    "sforțaserăm": "sforța",
    "sforțaserăți": "sforța",
    "sforțaseși": "sforța",
    "sforțași": "sforța",
    "sforțat": "sforța",
    "sforțați": "sforța",
    "sforțau": "sforța",
    "sforțează": "sforța",
    "sforțez": "sforța",
    "sforțeze": "sforța",
    "sforțezi": "sforța",
    "sforțată": "sforțat",
    "sforțate": "sforțat",
    "sforțați": "sforțat",
    "sfrâncioci": "sfrâncioc",
    "sfrânciocii": "sfrâncioc",
    "sfrânciocilor": "sfrâncioc",
    "sfrânciocul": "sfrâncioc",
    "sfrânciocului": "sfrâncioc",
    "sfredele": "sfredel",
    "sfredelele": "sfredel",
    "sfredelelor": "sfredel",
    "sfredelul": "sfredel",
    "sfredelului": "sfredel",
    "nemaisfredelind": "sfredeli",
    "nemaisfredelindu": "sfredeli",
    "nesfredelind": "sfredeli",
    "nesfredelindu": "sfredeli",
    "sfredelea": "sfredeli",
    "sfredeleai": "sfredeli",
    "sfredeleam": "sfredeli",
    "sfredelească": "sfredeli",
    "sfredeleați": "sfredeli",
    "sfredeleau": "sfredeli",
    "sfredelesc": "sfredeli",
    "sfredelește": "sfredeli",
    "sfredelești": "sfredeli",
    "sfredelii": "sfredeli",
    "sfredelim": "sfredeli",
    "sfredelind": "sfredeli",
    "sfredelindu": "sfredeli",
    "sfredeliră": "sfredeli",
    "sfredelirăm": "sfredeli",
    "sfredelirăți": "sfredeli",
    "sfredelise": "sfredeli",
    "sfredelisem": "sfredeli",
    "sfredeliseră": "sfredeli",
    "sfredeliserăm": "sfredeli",
    "sfredeliserăți": "sfredeli",
    "sfredeliseși": "sfredeli",
    "sfredeliși": "sfredeli",
    "sfredelit": "sfredeli",
    "sfredeliți": "sfredeli",
    "sfredelirea": "sfredelire",
    "sfredeliri": "sfredelire",
    "sfredelirii": "sfredelire",
    "sfredelirile": "sfredelire",
    "sfredelirilor": "sfredelire",
    "sfredelită": "sfredelit",
    "sfredelite": "sfredelit",
    "sfredeliți": "sfredelit",
    "nemaisfrijind": "sfriji",
    "nemaisfrijindu": "sfriji",
    "nesfrijind": "sfriji",
    "nesfrijindu": "sfriji",
    "sfrijea": "sfriji",
    "sfrijeai": "sfriji",
    "sfrijeam": "sfriji",
    "sfrijească": "sfriji",
    "sfrijeați": "sfriji",
    "sfrijeau": "sfriji",
    "sfrijesc": "sfriji",
    "sfrijește": "sfriji",
    "sfrijești": "sfriji",
    "sfrijii": "sfriji",
    "sfrijim": "sfriji",
    "sfrijind": "sfriji",
    "sfrijindu": "sfriji",
    "sfrijiră": "sfriji",
    "sfrijirăm": "sfriji",
    "sfrijirăți": "sfriji",
    "sfrijise": "sfriji",
    "sfrijisem": "sfriji",
    "sfrijiseră": "sfriji",
    "sfrijiserăm": "sfriji",
    "sfrijiserăți": "sfriji",
    "sfrijiseși": "sfriji",
    "sfrijiși": "sfriji",
    "sfrijit": "sfriji",
    "sfrijiți": "sfriji",
    "sfrijită": "sfrijit",
    "sfrijite": "sfrijit",
    "sfrijiți": "sfrijit",
    "sfrijitura": "sfrijitură",
    "sfrijituri": "sfrijitură",
    "sfrijiturii": "sfrijitură",
    "sfrijiturile": "sfrijitură",
    "sfrijiturilor": "sfrijitură",
    "nemaisfruntând": "sfrunta",
    "nemaisfruntându": "sfrunta",
    "nesfruntând": "sfrunta",
    "nesfruntându": "sfrunta",
    "sfruntă": "sfrunta",
    "sfruntai": "sfrunta",
    "sfruntam": "sfrunta",
    "sfruntăm": "sfrunta",
    "sfruntând": "sfrunta",
    "sfruntându": "sfrunta",
    "sfruntară": "sfrunta",
    "sfruntarăm": "sfrunta",
    "sfruntarăți": "sfrunta",
    "sfruntase": "sfrunta",
    "sfruntasem": "sfrunta",
    "sfruntaseră": "sfrunta",
    "sfruntaserăm": "sfrunta",
    "sfruntaserăți": "sfrunta",
    "sfruntaseși": "sfrunta",
    "sfruntași": "sfrunta",
    "sfruntat": "sfrunta",
    "sfruntați": "sfrunta",
    "sfruntau": "sfrunta",
    "sfruntează": "sfrunta",
    "sfruntez": "sfrunta",
    "sfrunteze": "sfrunta",
    "sfruntezi": "sfrunta",
    "sfruntarea": "sfruntare",
    "sfruntări": "sfruntare",
    "sfruntării": "sfruntare",
    "sfruntările": "sfruntare",
    "sfruntărilor": "sfruntare",
    "sfruntată": "sfruntat",
    "sfruntate": "sfruntat",
    "sfruntați": "sfruntat",
    "showul": "show",
    "showului": "show",
    "showuri": "show",
    "showurile": "show",
    "showurilor": "show",
    "ș'": "și",
    "ș-": "și",
    "și-": "și",
    "șî": "și",
    "ș.a.": "și_altele",
    "ș.a.m.d.": "și_așa_mai_departe",
    "ș.cl.": "și_celelalte",
    "ș.m.a.": "și_multe_altele",
    "șiace": "șiac",
    "șiacele": "șiac",
    "șiacelor": "șiac",
    "șiacul": "șiac",
    "șiacului": "șiac",
    "siameza": "siamez",
    "siameză": "siamez",
    "siameze": "siamez",
    "siamezei": "siamez",
    "siamezele": "siamez",
    "siamezelor": "siamez",
    "siamezi": "siamez",
    "siamezii": "siamez",
    "siamezilor": "siamez",
    "siamezul": "siamez",
    "siamezului": "siamez",
    "siameza": "siameză",
    "siameze": "siameză",
    "siamezei": "siameză",
    "siamezele": "siameză",
    "siamezelor": "siameză",
    "sibariți": "sibarit",
    "sibariții": "sibarit",
    "sibariților": "sibarit",
    "sibaritul": "sibarit",
    "sibaritului": "sibarit",
    "sibarita": "sibarită",
    "sibarite": "sibarită",
    "sibaritei": "sibarită",
    "sibaritele": "sibarită",
    "sibaritelor": "sibarită",
    "siberiana": "siberian",
    "siberiană": "siberian",
    "siberianul": "siberian",
    "siberianului": "siberian",
    "siberiene": "siberian",
    "siberienei": "siberian",
    "siberienele": "siberian",
    "siberienelor": "siberian",
    "siberieni": "siberian",
    "siberienii": "siberian",
    "siberienilor": "siberian",
    "sibila": "sibilă",
    "sibile": "sibilă",
    "sibilei": "sibilă",
    "sibilele": "sibilă",
    "sibilelor": "sibilă",
    "sibilanta": "sibilant",
    "sibilantă": "sibilant",
    "sibilante": "sibilant",
    "sibilantei": "sibilant",
    "sibilantele": "sibilant",
    "sibilantelor": "sibilant",
    "sibilanți": "sibilant",
    "sibilanții": "sibilant",
    "sibilanților": "sibilant",
    "sibilantul": "sibilant",
    "sibilantului": "sibilant",
    "sibilinici": "sibilinic",
    "sibilinicii": "sibilinic",
    "sibilinicilor": "sibilinic",
    "sibilinicul": "sibilinic",
    "sibilinicului": "sibilinic",
    "sibirul": "sibir",
    "sibirului": "sibir",
    "sibiruri": "sibir",
    "sibirurile": "sibir",
    "sibirurilor": "sibir",
    "Sibiului": "Sibiu",
    "șicul": "șic",
    "șicului": "șic",
    "nemaișicanând": "șicana",
    "nemaișicanându": "șicana",
    "neșicanând": "șicana",
    "neșicanându": "șicana",
    "șicană": "șicana",
    "șicanai": "șicana",
    "șicanam": "șicana",
    "șicanăm": "șicana",
    "șicanând": "șicana",
    "șicanându": "șicana",
    "șicanară": "șicana",
    "șicanarăm": "șicana",
    "șicanarăți": "șicana",
    "șicanase": "șicana",
    "șicanasem": "șicana",
    "șicanaseră": "șicana",
    "șicanaserăm": "șicana",
    "șicanaserăți": "șicana",
    "șicanaseși": "șicana",
    "șicanași": "șicana",
    "șicanat": "șicana",
    "șicanați": "șicana",
    "șicanau": "șicana",
    "șicanează": "șicana",
    "șicanez": "șicana",
    "șicaneze": "șicana",
    "șicanezi": "șicana",
    "șicana": "șicană",
    "șicane": "șicană",
    "șicanei": "șicană",
    "șicanele": "șicană",
    "șicanelor": "șicană",
    "șicanarea": "șicanare",
    "șicanareo": "șicanare",
    "șicanări": "șicanare",
    "șicanării": "șicanare",
    "șicanările": "șicanare",
    "șicanărilor": "șicanare",
    "șicanata": "șicanat",
    "șicanată": "șicanat",
    "șicanate": "șicanat",
    "șicanatei": "șicanat",
    "șicanatele": "șicanat",
    "șicanatelor": "șicanat",
    "șicanați": "șicanat",
    "șicanații": "șicanat",
    "șicanaților": "șicanat",
    "șicanato": "șicanat",
    "șicanatul": "șicanat",
    "șicanatule": "șicanat",
    "șicanatului": "șicanat",
    "sicativa": "sicativ",
    "sicativă": "sicativ",
    "sicative": "sicativ",
    "sicativei": "sicativ",
    "sicativele": "sicativ",
    "sicativelor": "sicativ",
    "sicativi": "sicativ",
    "sicativii": "sicativ",
    "sicativilor": "sicativ",
    "sicativul": "sicativ",
    "sicativului": "sicativ",
    "siciliana": "sicilian",
    "siciliană": "sicilian",
    "sicilianul": "sicilian",
    "sicilianului": "sicilian",
    "siciliene": "sicilian",
    "sicilienei": "sicilian",
    "sicilienele": "sicilian",
    "sicilienelor": "sicilian",
    "sicilieni": "sicilian",
    "sicilienii": "sicilian",
    "sicilienilor": "sicilian",
    "siciliana": "siciliană",
    "siciliene": "siciliană",
    "sicilienei": "siciliană",
    "sicilienele": "siciliană",
    "sicilienelor": "siciliană",
    "sicofanți": "sicofant",
    "sicofanții": "sicofant",
    "sicofanților": "sicofant",
    "sicofantul": "sicofant",
    "sicofantului": "sicofant",
    "sicomori": "sicomor",
    "sicomorii": "sicomor",
    "sicomorilor": "sicomor",
    "sicomorul": "sicomor",
    "sicomorului": "sicomor",
    "sicrie": "sicriu",
    "sicriele": "sicriu",
    "sicrielor": "sicriu",
    "sicriul": "sicriu",
    "sicriului": "sicriu",
    "nemaisictirind": "sictiri",
    "nemaisictirindu": "sictiri",
    "nesictirind": "sictiri",
    "nesictirindu": "sictiri",
    "sictirea": "sictiri",
    "sictireai": "sictiri",
    "sictiream": "sictiri",
    "sictirească": "sictiri",
    "sictireați": "sictiri",
    "sictireau": "sictiri",
    "sictiresc": "sictiri",
    "sictirește": "sictiri",
    "sictirești": "sictiri",
    "sictirii": "sictiri",
    "sictirim": "sictiri",
    "sictirind": "sictiri",
    "sictirindu": "sictiri",
    "sictiriră": "sictiri",
    "sictirirăm": "sictiri",
    "sictirirăți": "sictiri",
    "sictirise": "sictiri",
    "sictirisem": "sictiri",
    "sictiriseră": "sictiri",
    "sictiriserăm": "sictiri",
    "sictiriserăți": "sictiri",
    "sictiriseși": "sictiri",
    "sictiriși": "sictiri",
    "sictirit": "sictiri",
    "sictiriți": "sictiri",
    "sictirită": "sictirit",
    "sictirite": "sictirit",
    "sictiriți": "sictirit",
    "sideful": "sidef",
    "sidefului": "sidef",
    "sidefuri": "sidef",
    "sidefurile": "sidef",
    "sidefurilor": "sidef",
    "sidefia": "sidefiu",
    "sidefie": "sidefiu",
    "sidefiei": "sidefiu",
    "sidefii": "sidefiu",
    "sidefiii": "sidefiu",
    "sidefiile": "sidefiu",
    "sidefiilor": "sidefiu",
    "sidefiul": "sidefiu",
    "sidefiului": "sidefiu",
    "sidelca": "sidelcă",
    "sidelci": "sidelcă",
    "sidelcii": "sidelcă",
    "sidelcile": "sidelcă",
    "sidelcilor": "sidelcă",
    "siderala": "sideral",
    "siderală": "sideral",
    "siderale": "sideral",
    "sideralei": "sideral",
    "sideralele": "sideral",
    "sideralelor": "sideral",
    "siderali": "sideral",
    "sideralii": "sideral",
    "sideralilor": "sideral",
    "sideralul": "sideral",
    "sideralului": "sideral",
    "sideritul": "siderit",
    "sideritului": "siderit",
    "sideroliți": "siderolit",
    "sideroliții": "siderolit",
    "sideroliților": "siderolit",
    "siderolitul": "siderolit",
    "siderolitului": "siderolit",
    "sideroza": "sideroză",
    "sideroze": "sideroză",
    "siderozei": "sideroză",
    "siderozele": "sideroză",
    "siderozelor": "sideroză",
    "siderurgica": "siderurgic",
    "siderurgică": "siderurgic",
    "siderurgice": "siderurgic",
    "siderurgicei": "siderurgic",
    "siderurgicele": "siderurgic",
    "siderurgicelor": "siderurgic",
    "siderurgici": "siderurgic",
    "siderurgicii": "siderurgic",
    "siderurgicilor": "siderurgic",
    "siderurgicul": "siderurgic",
    "siderurgicului": "siderurgic",
    "siderurgia": "siderurgie",
    "siderurgiei": "siderurgie",
    "siderurgii": "siderurgie",
    "își": "sieși",
    "și-": "sieși",
    "sie": "sieși",
    "siesta": "siestă",
    "sieste": "siestă",
    "siestei": "siestă",
    "siestele": "siestă",
    "siestelor": "siestă",
    "sifilida": "sifilidă",
    "sifilide": "sifilidă",
    "sifilidei": "sifilidă",
    "sifilidele": "sifilidă",
    "sifilidelor": "sifilidă",
    "sifilisul": "sifilis",
    "sifilisului": "sifilis",
    "sifilitica": "sifilitic",
    "sifilitică": "sifilitic",
    "sifilitice": "sifilitic",
    "sifiliticei": "sifilitic",
    "sifiliticele": "sifilitic",
    "sifiliticelor": "sifilitic",
    "sifilitici": "sifilitic",
    "sifiliticii": "sifilitic",
    "sifiliticilor": "sifilitic",
    "sifiliticul": "sifilitic",
    "sifiliticului": "sifilitic",
    "siflanta": "siflant",
    "siflantă": "siflant",
    "siflante": "siflant",
    "siflantei": "siflant",
    "siflantele": "siflant",
    "siflantelor": "siflant",
    "siflanți": "siflant",
    "siflanții": "siflant",
    "siflanților": "siflant",
    "siflantul": "siflant",
    "siflantului": "siflant",
    "sifoane": "sifon",
    "sifoanele": "sifon",
    "sifoanelor": "sifon",
    "sifonul": "sifon",
    "sifonului": "sifon",
    "șifoane": "șifon",
    "șifoanele": "șifon",
    "șifoanelor": "șifon",
    "șifonul": "șifon",
    "șifonului": "șifon",
    "nemaișifonând": "șifona",
    "nemaișifonându": "șifona",
    "neșifonând": "șifona",
    "neșifonându": "șifona",
    "șifonă": "șifona",
    "șifonai": "șifona",
    "șifonam": "șifona",
    "șifonăm": "șifona",
    "șifonând": "șifona",
    "șifonându": "șifona",
    "șifonară": "șifona",
    "șifonarăm": "șifona",
    "șifonarăți": "șifona",
    "șifonase": "șifona",
    "șifonasem": "șifona",
    "șifonaseră": "șifona",
    "șifonaserăm": "șifona",
    "șifonaserăți": "șifona",
    "șifonaseși": "șifona",
    "șifonași": "șifona",
    "șifonat": "șifona",
    "șifonați": "șifona",
    "șifonau": "șifona",
    "șifonează": "șifona",
    "șifonez": "șifona",
    "șifoneze": "șifona",
    "șifonezi": "șifona",
    "șifonabila": "șifonabil",
    "șifonabilă": "șifonabil",
    "șifonabile": "șifonabil",
    "șifonabilei": "șifonabil",
    "șifonabilele": "șifonabil",
    "șifonabilelor": "șifonabil",
    "șifonabili": "șifonabil",
    "șifonabilii": "șifonabil",
    "șifonabililor": "șifonabil",
    "șifonabilo": "șifonabil",
    "șifonabilul": "șifonabil",
    "șifonabilule": "șifonabil",
    "șifonabilului": "șifonabil",
    "șifonată": "șifonabil",
    "șifonata": "șifonat",
    "șifonată": "șifonat",
    "șifonate": "șifonat",
    "șifonatei": "șifonat",
    "șifonatele": "șifonat",
    "șifonatelor": "șifonat",
    "șifonați": "șifonat",
    "șifonații": "șifonat",
    "șifonaților": "șifonat",
    "șifonato": "șifonat",
    "șifonatul": "șifonat",
    "șifonatule": "șifonat",
    "șifonatului": "șifonat",
    "șifoniere": "șifonier",
    "șifonierele": "șifonier",
    "șifonierelor": "șifonier",
    "șifonierul": "șifonier",
    "șifonierului": "șifonier",
    "nemaisigilând": "sigila",
    "nemaisigilându": "sigila",
    "nesigilând": "sigila",
    "nesigilându": "sigila",
    "sigilă": "sigila",
    "sigilai": "sigila",
    "sigilam": "sigila",
    "sigilăm": "sigila",
    "sigilând": "sigila",
    "sigilându": "sigila",
    "sigilară": "sigila",
    "sigilarăm": "sigila",
    "sigilarăți": "sigila",
    "sigilase": "sigila",
    "sigilasem": "sigila",
    "sigilaseră": "sigila",
    "sigilaserăm": "sigila",
    "sigilaserăți": "sigila",
    "sigilaseși": "sigila",
    "sigilași": "sigila",
    "sigilat": "sigila",
    "sigilați": "sigila",
    "sigilau": "sigila",
    "sigilează": "sigila",
    "sigilez": "sigila",
    "sigileze": "sigila",
    "sigilezi": "sigila",
    "sigilarea": "sigilare",
    "sigilareo": "sigilare",
    "sigilări": "sigilare",
    "sigilării": "sigilare",
    "sigilările": "sigilare",
    "sigilărilor": "sigilare",
    "sigilata": "sigilat",
    "sigilată": "sigilat",
    "sigilate": "sigilat",
    "sigilatei": "sigilat",
    "sigilatele": "sigilat",
    "sigilatelor": "sigilat",
    "sigilați": "sigilat",
    "sigilații": "sigilat",
    "sigilaților": "sigilat",
    "sigilato": "sigilat",
    "sigilatul": "sigilat",
    "sigilatule": "sigilat",
    "sigilatului": "sigilat",
    "sigilii": "sigiliu",
    "sigiliile": "sigiliu",
    "sigiliilor": "sigiliu",
    "sigiliul": "sigiliu",
    "sigiliului": "sigiliu",
    "sigla": "siglă",
    "sigle": "siglă",
    "siglei": "siglă",
    "siglele": "siglă",
    "siglelor": "siglă",
    "sigmoida": "sigmoid",
    "sigmoidă": "sigmoid",
    "sigmoide": "sigmoid",
    "sigmoidei": "sigmoid",
    "sigmoidele": "sigmoid",
    "sigmoidelor": "sigmoid",
    "sigmoizi": "sigmoid",
    "signale": "signal",
    "signalele": "signal",
    "signalelor": "signal",
    "signalul": "signal",
    "signalului": "signal",
    "sigura": "sigur",
    "sigură": "sigur",
    "sigure": "sigur",
    "sigurei": "sigur",
    "sigurele": "sigur",
    "sigurelor": "sigur",
    "siguri": "sigur",
    "sigurii": "sigur",
    "sigurilor": "sigur",
    "sigurul": "sigur",
    "sigurului": "sigur",
    "siguranța": "siguranță",
    "siguranțe": "siguranță",
    "siguranței": "siguranță",
    "siguranțele": "siguranță",
    "siguranțelor": "siguranță",
    "nemaisihăstrind": "sihăstri",
    "nemaisihăstrindu": "sihăstri",
    "nesihăstrind": "sihăstri",
    "nesihăstrindu": "sihăstri",
    "sihăstrea": "sihăstri",
    "sihăstreai": "sihăstri",
    "sihăstream": "sihăstri",
    "sihăstrească": "sihăstri",
    "sihăstreați": "sihăstri",
    "sihăstreau": "sihăstri",
    "sihăstresc": "sihăstri",
    "sihăstrește": "sihăstri",
    "sihăstrești": "sihăstri",
    "sihăstrii": "sihăstri",
    "sihăstrim": "sihăstri",
    "sihăstrind": "sihăstri",
    "sihăstrindu": "sihăstri",
    "sihăstriră": "sihăstri",
    "sihăstrirăm": "sihăstri",
    "sihăstrirăți": "sihăstri",
    "sihăstrise": "sihăstri",
    "sihăstrisem": "sihăstri",
    "sihăstriseră": "sihăstri",
    "sihăstriserăm": "sihăstri",
    "sihăstriserăți": "sihăstri",
    "sihăstriseși": "sihăstri",
    "sihăstriși": "sihăstri",
    "sihăstrit": "sihăstri",
    "sihăstriți": "sihăstri",
    "sihăstria": "sihăstrie",
    "sihăstriei": "sihăstrie",
    "sihăstrii": "sihăstrie",
    "sihăstriile": "sihăstrie",
    "sihăstriilor": "sihăstrie",
    "sihăstrită": "sihăstrit",
    "sihăstrite": "sihăstrit",
    "sihăstriți": "sihăstrit",
    "sihaștri": "sihastru",
    "sihaștrii": "sihastru",
    "sihaștrilor": "sihastru",
    "sihastrul": "sihastru",
    "sihastrului": "sihastru",
    "sihla": "sihlă",
    "sihle": "sihlă",
    "sihlei": "sihlă",
    "sihlele": "sihlă",
    "sihlelor": "sihlă",
    "sila": "silă",
    "sile": "silă",
    "silei": "silă",
    "silele": "silă",
    "silelor": "silă",
    "silaba": "silabă",
    "silabe": "silabă",
    "silabei": "silabă",
    "silabele": "silabă",
    "silabelor": "silabă",
    "silabica": "silabic",
    "silabică": "silabic",
    "silabice": "silabic",
    "silabicei": "silabic",
    "silabicele": "silabic",
    "silabicelor": "silabic",
    "silabici": "silabic",
    "silabicii": "silabic",
    "silabicilor": "silabic",
    "silabicul": "silabic",
    "silabicului": "silabic",
    "nemaisilabisind": "silabisi",
    "nemaisilabisindu": "silabisi",
    "nesilabisind": "silabisi",
    "nesilabisindu": "silabisi",
    "silabisea": "silabisi",
    "silabiseai": "silabisi",
    "silabiseam": "silabisi",
    "silabisească": "silabisi",
    "silabiseați": "silabisi",
    "silabiseau": "silabisi",
    "silabisesc": "silabisi",
    "silabisește": "silabisi",
    "silabisești": "silabisi",
    "silabisii": "silabisi",
    "silabisim": "silabisi",
    "silabisind": "silabisi",
    "silabisindu": "silabisi",
    "silabisiră": "silabisi",
    "silabisirăm": "silabisi",
    "silabisirăți": "silabisi",
    "silabisise": "silabisi",
    "silabisisem": "silabisi",
    "silabisiseră": "silabisi",
    "silabisiserăm": "silabisi",
    "silabisiserăți": "silabisi",
    "silabisiseși": "silabisi",
    "silabisiși": "silabisi",
    "silabisit": "silabisi",
    "silabisiți": "silabisi",
    "silabisită": "silabisit",
    "silabisite": "silabisit",
    "silabisiți": "silabisit",
    "șildul": "șild",
    "șildului": "șild",
    "șilduri": "șild",
    "șildurile": "șild",
    "șildurilor": "șild",
    "silențioasa": "silențios",
    "silențioasă": "silențios",
    "silențioase": "silențios",
    "silențioasei": "silențios",
    "silențioasele": "silențios",
    "silențioaselor": "silențios",
    "silențioși": "silențios",
    "silențioșii": "silențios",
    "silențioșilor": "silențios",
    "silențiosul": "silențios",
    "silențiosului": "silențios",
    "silepsa": "silepsă",
    "silepse": "silepsă",
    "silepsei": "silepsă",
    "silepsele": "silepsă",
    "silepselor": "silepsă",
    "silexul": "silex",
    "silexului": "silex",
    "silexuri": "silex",
    "silexurile": "silex",
    "silexurilor": "silex",
    "silfi": "silf",
    "silfii": "silf",
    "silfilor": "silf",
    "silful": "silf",
    "silfului": "silf",
    "silfida": "silfidă",
    "silfide": "silfidă",
    "silfidei": "silfidă",
    "silfidele": "silfidă",
    "silfidelor": "silfidă",
    "nemaisilind": "sili",
    "nemaisilindu": "sili",
    "nesilind": "sili",
    "nesilindu": "sili",
    "silea": "sili",
    "sileai": "sili",
    "sileam": "sili",
    "silească": "sili",
    "sileați": "sili",
    "sileau": "sili",
    "silesc": "sili",
    "silește": "sili",
    "silești": "sili",
    "silii": "sili",
    "silim": "sili",
    "silind": "sili",
    "silindu": "sili",
    "siliră": "sili",
    "silirăm": "sili",
    "silirăți": "sili",
    "silise": "sili",
    "silisem": "sili",
    "siliseră": "sili",
    "siliserăm": "sili",
    "siliserăți": "sili",
    "siliseși": "sili",
    "siliși": "sili",
    "silit": "sili",
    "siliți": "sili",
    "silica": "silică",
    "silice": "silică",
    "silicei": "silică",
    "silicele": "silică",
    "silicelor": "silică",
    "silicați": "silicat",
    "silicații": "silicat",
    "silicaților": "silicat",
    "silicatul": "silicat",
    "silicatului": "silicat",
    "silicilica": "silicilic",
    "silicilică": "silicilic",
    "silicilice": "silicilic",
    "silicilicei": "silicilic",
    "silicilicele": "silicilic",
    "silicilicelor": "silicilic",
    "silicilici": "silicilic",
    "silicilicii": "silicilic",
    "silicilicilor": "silicilic",
    "silicilicul": "silicilic",
    "silicilicului": "silicilic",
    "silicioasa": "silicios",
    "silicioasă": "silicios",
    "silicioase": "silicios",
    "silicioasei": "silicios",
    "silicioasele": "silicios",
    "silicioaselor": "silicios",
    "silicioși": "silicios",
    "silicioșii": "silicios",
    "silicioșilor": "silicios",
    "siliciosul": "silicios",
    "siliciosului": "silicios",
    "Si": "siliciu",
    "siliciul": "siliciu",
    "siliciului": "siliciu",
    "silicoasa": "silicos",
    "silicoasă": "silicos",
    "silicoase": "silicos",
    "silicoasei": "silicos",
    "silicoasele": "silicos",
    "silicoaselor": "silicos",
    "silicoși": "silicos",
    "silicoșii": "silicos",
    "silicoșilor": "silicos",
    "silicosul": "silicos",
    "silicosului": "silicos",
    "silicoza": "silicoză",
    "silicoze": "silicoză",
    "silicozei": "silicoză",
    "silicozele": "silicoză",
    "silicozelor": "silicoză",
    "silicula": "siliculă",
    "silicule": "siliculă",
    "siliculei": "siliculă",
    "siliculele": "siliculă",
    "siliculelor": "siliculă",
    "silicva": "silicvă",
    "silicve": "silicvă",
    "silicvei": "silicvă",
    "silicvele": "silicvă",
    "silicvelor": "silicvă",
    "Sh.": "șiling",
    "silința": "silință",
    "silințe": "silință",
    "silinței": "silință",
    "silințele": "silință",
    "silințelor": "silință",
    "silirea": "silire",
    "siliri": "silire",
    "silirii": "silire",
    "silirile": "silire",
    "silirilor": "silire",
    "siliștea": "siliște",
    "siliști": "siliște",
    "siliștii": "siliște",
    "siliștile": "siliște",
    "siliștilor": "siliște",
    "silită": "silit",
    "silite": "silit",
    "siliți": "silit",
    "silitoare": "silitor",
    "silitoarea": "silitor",
    "silitoarei": "silitor",
    "silitoarele": "silitor",
    "silitoarelor": "silitor",
    "silitori": "silitor",
    "silitorii": "silitor",
    "silitorilor": "silitor",
    "silitorul": "silitor",
    "silitorului": "silitor",
    "silnica": "silnic",
    "silnică": "silnic",
    "silnice": "silnic",
    "silnicei": "silnic",
    "silnicele": "silnic",
    "silnicelor": "silnic",
    "silnici": "silnic",
    "silnicii": "silnic",
    "silnicilor": "silnic",
    "silnicul": "silnic",
    "silnicului": "silnic",
    "nemaisilnicind": "silnici",
    "nemaisilnicindu": "silnici",
    "nesilnicind": "silnici",
    "nesilnicindu": "silnici",
    "silnicea": "silnici",
    "silniceai": "silnici",
    "silniceam": "silnici",
    "silnicească": "silnici",
    "silniceați": "silnici",
    "silniceau": "silnici",
    "silnicesc": "silnici",
    "silnicește": "silnici",
    "silnicești": "silnici",
    "silnicii": "silnici",
    "silnicim": "silnici",
    "silnicind": "silnici",
    "silnicindu": "silnici",
    "silniciră": "silnici",
    "silnicirăm": "silnici",
    "silnicirăți": "silnici",
    "silnicise": "silnici",
    "silnicisem": "silnici",
    "silniciseră": "silnici",
    "silniciserăm": "silnici",
    "silniciserăți": "silnici",
    "silniciseși": "silnici",
    "silniciși": "silnici",
    "silnicit": "silnici",
    "silniciți": "silnici",
    "silnicia": "silnicie",
    "silniciei": "silnicie",
    "silnicii": "silnicie",
    "silnicită": "silnicit",
    "silnicite": "silnicit",
    "silniciți": "silnicit",
    "silogisme": "silogism",
    "silogismele": "silogism",
    "silogismelor": "silogism",
    "silogismul": "silogism",
    "silogismului": "silogism",
    "silogistica": "silogistic",
    "silogistică": "silogistic",
    "silogistice": "silogistic",
    "silogisticei": "silogistic",
    "silogisticele": "silogistic",
    "silogisticelor": "silogistic",
    "silogistici": "silogistic",
    "silogisticii": "silogistic",
    "silogisticilor": "silogistic",
    "silogisticul": "silogistic",
    "silogisticului": "silogistic",
    "silozul": "siloz",
    "silozului": "siloz",
    "silozuri": "siloz",
    "silozurile": "siloz",
    "silozurilor": "siloz",
    "silueta": "siluetă",
    "siluete": "siluetă",
    "siluetei": "siluetă",
    "siluetele": "siluetă",
    "siluetelor": "siluetă",
    "nemaisiluind": "silui",
    "nemaisiluindu": "silui",
    "nesiluind": "silui",
    "nesiluindu": "silui",
    "siluia": "silui",
    "siluiai": "silui",
    "siluiam": "silui",
    "siluiască": "silui",
    "siluiați": "silui",
    "siluiau": "silui",
    "siluiesc": "silui",
    "siluiește": "silui",
    "siluiești": "silui",
    "siluii": "silui",
    "siluim": "silui",
    "siluind": "silui",
    "siluindu": "silui",
    "siluiră": "silui",
    "siluirăm": "silui",
    "siluirăți": "silui",
    "siluise": "silui",
    "siluisem": "silui",
    "siluiseră": "silui",
    "siluiserăm": "silui",
    "siluiserăți": "silui",
    "siluiseși": "silui",
    "siluiși": "silui",
    "siluit": "silui",
    "siluiți": "silui",
    "siluită": "siluit",
    "siluite": "siluit",
    "siluiți": "siluit",
    "siluitori": "siluitor",
    "siluitorii": "siluitor",
    "siluitorilor": "siluitor",
    "siluitorul": "siluitor",
    "siluitorului": "siluitor",
    "siluriana": "silurian",
    "siluriană": "silurian",
    "silurianul": "silurian",
    "silurianului": "silurian",
    "siluriene": "silurian",
    "silurienei": "silurian",
    "silurienele": "silurian",
    "silurienelor": "silurian",
    "silurieni": "silurian",
    "silurienii": "silurian",
    "silurienilor": "silurian",
    "silurica": "siluric",
    "silurică": "siluric",
    "silurice": "siluric",
    "siluricei": "siluric",
    "siluricele": "siluric",
    "siluricelor": "siluric",
    "silurici": "siluric",
    "siluricii": "siluric",
    "siluricilor": "siluric",
    "siluricul": "siluric",
    "siluricului": "siluric",
    "silvani": "silvan",
    "silvanii": "silvan",
    "silvanilor": "silvan",
    "silvanul": "silvan",
    "silvanului": "silvan",
    "silvanitul": "silvanit",
    "silvanitului": "silvanit",
    "Silviei": "Silvia",
    "silvica": "silvic",
    "silvică": "silvic",
    "silvice": "silvic",
    "silvicei": "silvic",
    "silvicele": "silvic",
    "silvicelor": "silvic",
    "silvici": "silvic",
    "silvicii": "silvic",
    "silvicilor": "silvic",
    "silvicul": "silvic",
    "silvicului": "silvic",
    "silvicultura": "silvicultură",
    "silviculturi": "silvicultură",
    "silviculturii": "silvicultură",
    "silvostepa": "silvostepă",
    "silvostepe": "silvostepă",
    "silvostepei": "silvostepă",
    "silvostepele": "silvostepă",
    "silvostepelor": "silvostepă",
    "simandicoasa": "simandicos",
    "simandicoasă": "simandicos",
    "simandicoase": "simandicos",
    "simandicoasei": "simandicos",
    "simandicoasele": "simandicos",
    "simandicoaselor": "simandicos",
    "simandicoși": "simandicos",
    "simandicoșii": "simandicos",
    "simandicoșilor": "simandicos",
    "simandicosul": "simandicos",
    "simandicosului": "simandicos",
    "simbioza": "simbioză",
    "simbioze": "simbioză",
    "simbiozei": "simbioză",
    "simbiozele": "simbioză",
    "simbiozelor": "simbioză",
    "simbolul": "simbol",
    "simbolului": "simbol",
    "simboluri": "simbol",
    "simbolurile": "simbol",
    "simbolurilor": "simbol",
    "simbolica": "simbolic",
    "simbolică": "simbolic",
    "simbolice": "simbolic",
    "simbolicei": "simbolic",
    "simbolicele": "simbolic",
    "simbolicelor": "simbolic",
    "simbolici": "simbolic",
    "simbolicii": "simbolic",
    "simbolicilor": "simbolic",
    "simbolicul": "simbolic",
    "simbolicului": "simbolic",
    "simbolisme": "simbolism",
    "simbolismele": "simbolism",
    "simbolismelor": "simbolism",
    "simbolismul": "simbolism",
    "simbolismului": "simbolism",
    "simbolista": "simbolist",
    "simbolistă": "simbolist",
    "simboliste": "simbolist",
    "simbolistei": "simbolist",
    "simbolistele": "simbolist",
    "simbolistelor": "simbolist",
    "simboliști": "simbolist",
    "simboliștii": "simbolist",
    "simboliștilor": "simbolist",
    "simbolistul": "simbolist",
    "simbolistului": "simbolist",
    "simbolista": "simbolistă",
    "simboliste": "simbolistă",
    "simbolistei": "simbolistă",
    "simbolistele": "simbolistă",
    "simbolistelor": "simbolistă",
    "nemaisimbolizând": "simboliza",
    "nemaisimbolizându": "simboliza",
    "nesimbolizând": "simboliza",
    "nesimbolizându": "simboliza",
    "simboliză": "simboliza",
    "simbolizai": "simboliza",
    "simbolizam": "simboliza",
    "simbolizăm": "simboliza",
    "simbolizând": "simboliza",
    "simbolizându": "simboliza",
    "simbolizară": "simboliza",
    "simbolizarăm": "simboliza",
    "simbolizarăți": "simboliza",
    "simbolizase": "simboliza",
    "simbolizasem": "simboliza",
    "simbolizaseră": "simboliza",
    "simbolizaserăm": "simboliza",
    "simbolizaserăți": "simboliza",
    "simbolizaseși": "simboliza",
    "simbolizași": "simboliza",
    "simbolizat": "simboliza",
    "simbolizați": "simboliza",
    "simbolizau": "simboliza",
    "simbolizează": "simboliza",
    "simbolizez": "simboliza",
    "simbolizeze": "simboliza",
    "simbolizezi": "simboliza",
    "simbolizarea": "simbolizare",
    "simbolizareo": "simbolizare",
    "simbolizări": "simbolizare",
    "simbolizării": "simbolizare",
    "simbolizările": "simbolizare",
    "simbolizărilor": "simbolizare",
    "simbolizată": "simbolizat",
    "simbolizate": "simbolizat",
    "simbolizați": "simbolizat",
    "simbriași": "simbriaș",
    "simbriașii": "simbriaș",
    "simbriașilor": "simbriaș",
    "simbriașul": "simbriaș",
    "simbriașului": "simbriaș",
    "simbriașa": "simbriașă",
    "simbriașe": "simbriașă",
    "simbriașei": "simbriașă",
    "simbriașele": "simbriașă",
    "simbriașelor": "simbriașă",
    "simbria": "simbrie",
    "simbriei": "simbrie",
    "simbrii": "simbrie",
    "simbriile": "simbrie",
    "simbriilor": "simbrie",
    "simetrica": "simetric",
    "simetrică": "simetric",
    "simetrice": "simetric",
    "simetricei": "simetric",
    "simetricele": "simetric",
    "simetricelor": "simetric",
    "simetrici": "simetric",
    "simetricii": "simetric",
    "simetricilor": "simetric",
    "simetricul": "simetric",
    "simetricului": "simetric",
    "simetria": "simetrie",
    "simetriei": "simetrie",
    "simetrii": "simetrie",
    "simetriile": "simetrie",
    "simetriilor": "simetrie",
    "simfonica": "simfonic",
    "simfonică": "simfonic",
    "simfonice": "simfonic",
    "simfonicei": "simfonic",
    "simfonicele": "simfonic",
    "simfonicelor": "simfonic",
    "simfonici": "simfonic",
    "simfonicii": "simfonic",
    "simfonicilor": "simfonic",
    "simfonicul": "simfonic",
    "simfonicului": "simfonic",
    "simfonia": "simfonie",
    "simfoniei": "simfonie",
    "simfonii": "simfonie",
    "simfoniile": "simfonie",
    "simfoniilor": "simfonie",
    "simigeria": "simigerie",
    "simigeriei": "simigerie",
    "simigerii": "simigerie",
    "simigeriile": "simigerie",
    "simigeriilor": "simigerie",
    "simigii": "simigiu",
    "simigiii": "simigiu",
    "simigiilor": "simigiu",
    "simigiul": "simigiu",
    "simigiului": "simigiu",
    "similara": "similar",
    "similară": "similar",
    "similare": "similar",
    "similarei": "similar",
    "similarele": "similar",
    "similarelor": "similar",
    "similari": "similar",
    "similarii": "similar",
    "similarilor": "similar",
    "similarul": "similar",
    "similarului": "similar",
    "similitudinea": "similitudine",
    "similitudini": "similitudine",
    "similitudinii": "similitudine",
    "similitudinile": "similitudine",
    "similitudinilor": "similitudine",
    "siminoci": "siminoc",
    "siminocii": "siminoc",
    "siminocilor": "siminoc",
    "siminocul": "siminoc",
    "siminocului": "siminoc",
    "simpatica": "simpatic",
    "simpatică": "simpatic",
    "simpatice": "simpatic",
    "simpaticei": "simpatic",
    "simpaticele": "simpatic",
    "simpaticelor": "simpatic",
    "simpatici": "simpatic",
    "simpaticii": "simpatic",
    "simpaticilor": "simpatic",
    "simpaticul": "simpatic",
    "simpaticului": "simpatic",
    "simpatia": "simpatie",
    "simpatiei": "simpatie",
    "simpatii": "simpatie",
    "simpatiile": "simpatie",
    "simpatiilor": "simpatie",
    "nemaisimpatizând": "simpatiza",
    "nemaisimpatizându": "simpatiza",
    "nesimpatizând": "simpatiza",
    "nesimpatizându": "simpatiza",
    "simpatiză": "simpatiza",
    "simpatizai": "simpatiza",
    "simpatizam": "simpatiza",
    "simpatizăm": "simpatiza",
    "simpatizând": "simpatiza",
    "simpatizându": "simpatiza",
    "simpatizară": "simpatiza",
    "simpatizarăm": "simpatiza",
    "simpatizarăți": "simpatiza",
    "simpatizase": "simpatiza",
    "simpatizasem": "simpatiza",
    "simpatizaseră": "simpatiza",
    "simpatizaserăm": "simpatiza",
    "simpatizaserăți": "simpatiza",
    "simpatizaseși": "simpatiza",
    "simpatizași": "simpatiza",
    "simpatizat": "simpatiza",
    "simpatizați": "simpatiza",
    "simpatizau": "simpatiza",
    "simpatizează": "simpatiza",
    "simpatizez": "simpatiza",
    "simpatizeze": "simpatiza",
    "simpatizezi": "simpatiza",
    "simpatizanți": "simpatizant",
    "simpatizanții": "simpatizant",
    "simpatizanților": "simpatizant",
    "simpatizantul": "simpatizant",
    "simpatizantului": "simpatizant",
    "simpatizanta": "simpatizantă",
    "simpatizante": "simpatizantă",
    "simpatizantei": "simpatizantă",
    "simpatizantele": "simpatizantă",
    "simpatizantelor": "simpatizantă",
    "simpatizată": "simpatizat",
    "simpatizate": "simpatizat",
    "simpatizați": "simpatizat",
    "simplicitatea": "simplicitate",
    "simplicități": "simplicitate",
    "simplicității": "simplicitate",
    "nemaisimplificând": "simplifica",
    "nemaisimplificându": "simplifica",
    "nesimplificând": "simplifica",
    "nesimplificându": "simplifica",
    "simplific": "simplifica",
    "simplifică": "simplifica",
    "simplificai": "simplifica",
    "simplificam": "simplifica",
    "simplificăm": "simplifica",
    "simplificând": "simplifica",
    "simplificându": "simplifica",
    "simplificară": "simplifica",
    "simplificarăm": "simplifica",
    "simplificarăți": "simplifica",
    "simplificase": "simplifica",
    "simplificasem": "simplifica",
    "simplificaseră": "simplifica",
    "simplificaserăm": "simplifica",
    "simplificaserăți": "simplifica",
    "simplificaseși": "simplifica",
    "simplificași": "simplifica",
    "simplificat": "simplifica",
    "simplificați": "simplifica",
    "simplificau": "simplifica",
    "simplifice": "simplifica",
    "simplifici": "simplifica",
    "simplificarea": "simplificare",
    "simplificări": "simplificare",
    "simplificării": "simplificare",
    "simplificările": "simplificare",
    "simplificărilor": "simplificare",
    "simplificată": "simplificat",
    "simplificate": "simplificat",
    "simplificați": "simplificat",
    "simplista": "simplist",
    "simplistă": "simplist",
    "simpliste": "simplist",
    "simplistei": "simplist",
    "simplistele": "simplist",
    "simplistelor": "simplist",
    "simpliști": "simplist",
    "simpliștii": "simplist",
    "simpliștilor": "simplist",
    "simplistul": "simplist",
    "simplistului": "simplist",
    "simplitatea": "simplitate",
    "simplități": "simplitate",
    "simplității": "simplitate",
    "simpla": "simplu",
    "simplă": "simplu",
    "simple": "simplu",
    "simplei": "simplu",
    "simplele": "simplu",
    "simplelor": "simplu",
    "simpli": "simplu",
    "simplii": "simplu",
    "simplilor": "simplu",
    "simplul": "simplu",
    "simplului": "simplu",
    "simpozioane": "simpozion",
    "simpozioanele": "simpozion",
    "simpozioanelor": "simpozion",
    "simpozionul": "simpozion",
    "simpozionului": "simpozion",
    "simptome": "simptom",
    "simptomele": "simptom",
    "simptomelor": "simptom",
    "simptomul": "simptom",
    "simptomului": "simptom",
    "simptomatica": "simptomatic",
    "simptomatică": "simptomatic",
    "simptomatice": "simptomatic",
    "simptomaticei": "simptomatic",
    "simptomaticele": "simptomatic",
    "simptomaticelor": "simptomatic",
    "simptomatici": "simptomatic",
    "simptomaticii": "simptomatic",
    "simptomaticilor": "simptomatic",
    "simptomaticul": "simptomatic",
    "simptomaticului": "simptomatic",
    "simțul": "simț",
    "simțului": "simț",
    "simțuri": "simț",
    "simțurile": "simț",
    "simțurilor": "simț",
    "simțământul": "simțământ",
    "simțământului": "simțământ",
    "simțăminte": "simțământ",
    "simțămintele": "simțământ",
    "simțămintelor": "simțământ",
    "nemaisimțind": "simți",
    "nemaisimțindu": "simți",
    "nesimțind": "simți",
    "nesimțindu": "simți",
    "sim'": "simți",
    "simt": "simți",
    "simtă": "simți",
    "simte": "simți",
    "simțea": "simți",
    "simțeai": "simți",
    "simțeam": "simți",
    "simțeați": "simți",
    "simțeau": "simți",
    "simții": "simți",
    "simțim": "simți",
    "simțind": "simți",
    "simțindu": "simți",
    "simțiră": "simți",
    "simțirăm": "simți",
    "simțirăți": "simți",
    "simțise": "simți",
    "simțisem": "simți",
    "simțiseră": "simți",
    "simțiserăm": "simți",
    "simțiserăți": "simți",
    "simțiseși": "simți",
    "simțiși": "simți",
    "simțit": "simți",
    "simțiți": "simți",
    "simțirea": "simțire",
    "simțiri": "simțire",
    "simțirii": "simțire",
    "simțirile": "simțire",
    "simțirilor": "simțire",
    "simțită": "simțit",
    "simțite": "simțit",
    "simțiți": "simțit",
    "simțitori": "simțitor",
    "simțitorii": "simțitor",
    "simțitorilor": "simțitor",
    "simțitorul": "simțitor",
    "simțitorului": "simțitor",
    "nemaisimulând": "simula",
    "nemaisimulându": "simula",
    "nesimulând": "simula",
    "nesimulându": "simula",
    "simulă": "simula",
    "simulai": "simula",
    "simulam": "simula",
    "simulăm": "simula",
    "simulând": "simula",
    "simulându": "simula",
    "simulară": "simula",
    "simularăm": "simula",
    "simularăți": "simula",
    "simulase": "simula",
    "simulasem": "simula",
    "simulaseră": "simula",
    "simulaserăm": "simula",
    "simulaserăți": "simula",
    "simulaseși": "simula",
    "simulași": "simula",
    "simulat": "simula",
    "simulați": "simula",
    "simulau": "simula",
    "simulează": "simula",
    "simulez": "simula",
    "simuleze": "simula",
    "simulezi": "simula",
    "simulacre": "simulacru",
    "simulacrele": "simulacru",
    "simulacrelor": "simulacru",
    "simulacrul": "simulacru",
    "simulacrului": "simulacru",
    "simulată": "simulat",
    "simulate": "simulat",
    "simulați": "simulat",
    "simulatoare": "simulator",
    "simulatoarele": "simulator",
    "simulatoarelor": "simulator",
    "simulatorul": "simulator",
    "simulatorului": "simulator",
    "simultana": "simultan",
    "simultană": "simultan",
    "simultane": "simultan",
    "simultanei": "simultan",
    "simultanele": "simultan",
    "simultanelor": "simultan",
    "simultani": "simultan",
    "simultanii": "simultan",
    "simultanilor": "simultan",
    "simultanul": "simultan",
    "simultanului": "simultan",
    "simultaneitatea": "simultaneitate",
    "simultaneități": "simultaneitate",
    "simultaneității": "simultaneitate",
    "simultaneitățile": "simultaneitate",
    "simultaneităților": "simultaneitate",
    "șina": "șină",
    "șine": "șină",
    "șinei": "șină",
    "șinele": "șină",
    "șinelor": "șină",
    "sinagoga": "sinagogă",
    "sinagogi": "sinagogă",
    "sinagogii": "sinagogă",
    "sinagogile": "sinagogă",
    "sinagogilor": "sinagogă",
    "sinantropi": "sinantrop",
    "sinantropii": "sinantrop",
    "sinantropilor": "sinantrop",
    "sinantropul": "sinantrop",
    "sinantropului": "sinantrop",
    "sinapisme": "sinapism",
    "sinapismele": "sinapism",
    "sinapismelor": "sinapism",
    "sinapismul": "sinapism",
    "sinapismului": "sinapism",
    "sinaxare": "sinaxar",
    "sinaxarele": "sinaxar",
    "sinaxarelor": "sinaxar",
    "sinaxarul": "sinaxar",
    "sinaxarului": "sinaxar",
    "sincera": "sincer",
    "sinceră": "sincer",
    "sincere": "sincer",
    "sincerei": "sincer",
    "sincerele": "sincer",
    "sincerelor": "sincer",
    "sinceri": "sincer",
    "sincerii": "sincer",
    "sincerilor": "sincer",
    "sincerul": "sincer",
    "sincerului": "sincer",
    "sinceritatea": "sinceritate",
    "sincerități": "sinceritate",
    "sincerității": "sinceritate",
    "sinceritățile": "sinceritate",
    "sincerităților": "sinceritate",
    "nemaisinchisind": "sinchisi",
    "nemaisinchisindu": "sinchisi",
    "nesinchisind": "sinchisi",
    "nesinchisindu": "sinchisi",
    "sinchisea": "sinchisi",
    "sinchiseai": "sinchisi",
    "sinchiseam": "sinchisi",
    "sinchisească": "sinchisi",
    "sinchiseați": "sinchisi",
    "sinchiseau": "sinchisi",
    "sinchisesc": "sinchisi",
    "sinchisește": "sinchisi",
    "sinchisești": "sinchisi",
    "sinchisii": "sinchisi",
    "sinchisim": "sinchisi",
    "sinchisind": "sinchisi",
    "sinchisindu": "sinchisi",
    "sinchisiră": "sinchisi",
    "sinchisirăm": "sinchisi",
    "sinchisirăți": "sinchisi",
    "sinchisise": "sinchisi",
    "sinchisisem": "sinchisi",
    "sinchisiseră": "sinchisi",
    "sinchisiserăm": "sinchisi",
    "sinchisiserăți": "sinchisi",
    "sinchisiseși": "sinchisi",
    "sinchisiși": "sinchisi",
    "sinchisit": "sinchisi",
    "sinchisiți": "sinchisi",
    "sinchisită": "sinchisit",
    "sinchisite": "sinchisit",
    "sinchisiți": "sinchisit",
    "sinclinale": "sinclinal",
    "sinclinalele": "sinclinal",
    "sinclinalelor": "sinclinal",
    "sinclinalul": "sinclinal",
    "sinclinalului": "sinclinal",
    "sincopa": "sincopă",
    "sincope": "sincopă",
    "sincopei": "sincopă",
    "sincopele": "sincopă",
    "sincopelor": "sincopă",
    "sincopata": "sincopat",
    "sincopată": "sincopat",
    "sincopate": "sincopat",
    "sincopatei": "sincopat",
    "sincopatele": "sincopat",
    "sincopatelor": "sincopat",
    "sincopați": "sincopat",
    "sincopații": "sincopat",
    "sincopaților": "sincopat",
    "sincopatul": "sincopat",
    "sincopatului": "sincopat",
    "sincretisme": "sincretism",
    "sincretismele": "sincretism",
    "sincretismelor": "sincretism",
    "sincretismul": "sincretism",
    "sincretismului": "sincretism",
    "sincrociclotroane": "sincrociclotron",
    "sincrociclotroanele": "sincrociclotron",
    "sincrociclotroanelor": "sincrociclotron",
    "sincrociclotronul": "sincrociclotron",
    "sincrociclotronului": "sincrociclotron",
    "sincrofazotroane": "sincrofazotron",
    "sincrofazotroanele": "sincrofazotron",
    "sincrofazotroanelor": "sincrofazotron",
    "sincrofazotronul": "sincrofazotron",
    "sincrofazotronului": "sincrofazotron",
    "sincrona": "sincron",
    "sincronă": "sincron",
    "sincrone": "sincron",
    "sincronei": "sincron",
    "sincronele": "sincron",
    "sincronelor": "sincron",
    "sincroni": "sincron",
    "sincronii": "sincron",
    "sincronilor": "sincron",
    "sincronul": "sincron",
    "sincronului": "sincron",
    "sincronica": "sincronic",
    "sincronică": "sincronic",
    "sincronice": "sincronic",
    "sincronicei": "sincronic",
    "sincronicele": "sincronic",
    "sincronicelor": "sincronic",
    "sincronici": "sincronic",
    "sincronicii": "sincronic",
    "sincronicilor": "sincronic",
    "sincronicul": "sincronic",
    "sincronicului": "sincronic",
    "sincronia": "sincronie",
    "sincroniei": "sincronie",
    "sincronii": "sincronie",
    "sincroniile": "sincronie",
    "sincroniilor": "sincronie",
    "sincronisme": "sincronism",
    "sincronismele": "sincronism",
    "sincronismelor": "sincronism",
    "sincronismul": "sincronism",
    "sincronismului": "sincronism",
    "nemaisincronizând": "sincroniza",
    "nemaisincronizându": "sincroniza",
    "nesincronizând": "sincroniza",
    "nesincronizându": "sincroniza",
    "sincroniză": "sincroniza",
    "sincronizai": "sincroniza",
    "sincronizam": "sincroniza",
    "sincronizăm": "sincroniza",
    "sincronizând": "sincroniza",
    "sincronizându": "sincroniza",
    "sincronizară": "sincroniza",
    "sincronizarăm": "sincroniza",
    "sincronizarăți": "sincroniza",
    "sincronizase": "sincroniza",
    "sincronizasem": "sincroniza",
    "sincronizaseră": "sincroniza",
    "sincronizaserăm": "sincroniza",
    "sincronizaserăți": "sincroniza",
    "sincronizaseși": "sincroniza",
    "sincronizași": "sincroniza",
    "sincronizat": "sincroniza",
    "sincronizați": "sincroniza",
    "sincronizau": "sincroniza",
    "sincronizează": "sincroniza",
    "sincronizez": "sincroniza",
    "sincronizeze": "sincroniza",
    "sincronizezi": "sincroniza",
    "sincronizată": "sincronizat",
    "sincronizate": "sincronizat",
    "sincronizați": "sincronizat",
    "sincronizatoare": "sincronizator",
    "sincronizatoarele": "sincronizator",
    "sincronizatoarelor": "sincronizator",
    "sincronizatorul": "sincronizator",
    "sincronizatorului": "sincronizator",
    "sincrotroane": "sincrotron",
    "sincrotroanele": "sincrotron",
    "sincrotroanelor": "sincrotron",
    "sincrotronul": "sincrotron",
    "sincrotronului": "sincrotron",
    "sindicala": "sindical",
    "sindicală": "sindical",
    "sindicale": "sindical",
    "sindicalei": "sindical",
    "sindicalele": "sindical",
    "sindicalelor": "sindical",
    "sindicali": "sindical",
    "sindicalii": "sindical",
    "sindicalilor": "sindical",
    "sindicalul": "sindical",
    "sindicalului": "sindical",
    "sindicalismul": "sindicalism",
    "sindicalismului": "sindicalism",
    "sindicaliști": "sindicalist",
    "sindicaliștii": "sindicalist",
    "sindicaliștilor": "sindicalist",
    "sindicalistul": "sindicalist",
    "sindicalistului": "sindicalist",
    "nemaisindicalizând": "sindicaliza",
    "nemaisindicalizându": "sindicaliza",
    "nesindicalizând": "sindicaliza",
    "nesindicalizându": "sindicaliza",
    "sindicaliză": "sindicaliza",
    "sindicalizai": "sindicaliza",
    "sindicalizam": "sindicaliza",
    "sindicalizăm": "sindicaliza",
    "sindicalizând": "sindicaliza",
    "sindicalizându": "sindicaliza",
    "sindicalizară": "sindicaliza",
    "sindicalizarăm": "sindicaliza",
    "sindicalizarăți": "sindicaliza",
    "sindicalizase": "sindicaliza",
    "sindicalizasem": "sindicaliza",
    "sindicalizaseră": "sindicaliza",
    "sindicalizaserăm": "sindicaliza",
    "sindicalizaserăți": "sindicaliza",
    "sindicalizaseși": "sindicaliza",
    "sindicalizași": "sindicaliza",
    "sindicalizat": "sindicaliza",
    "sindicalizați": "sindicaliza",
    "sindicalizau": "sindicaliza",
    "sindicalizează": "sindicaliza",
    "sindicalizez": "sindicaliza",
    "sindicalizeze": "sindicaliza",
    "sindicalizezi": "sindicaliza",
    "sindicalizată": "sindicalizat",
    "sindicalizate": "sindicalizat",
    "sindicalizați": "sindicalizat",
    "sindicate": "sindicat",
    "sindicatele": "sindicat",
    "sindicatelor": "sindicat",
    "sindicatul": "sindicat",
    "sindicatului": "sindicat",
    "șindrila": "șindrilă",
    "șindrile": "șindrilă",
    "șindrilei": "șindrilă",
    "șindrilele": "șindrilă",
    "șindrilelor": "șindrilă",
    "nemaișindrilind": "șindrili",
    "nemaișindrilindu": "șindrili",
    "neșindrilind": "șindrili",
    "neșindrilindu": "șindrili",
    "șindrilea": "șindrili",
    "șindrileai": "șindrili",
    "șindrileam": "șindrili",
    "șindrilească": "șindrili",
    "șindrileați": "șindrili",
    "șindrileau": "șindrili",
    "șindrilesc": "șindrili",
    "șindrilește": "șindrili",
    "șindrilești": "șindrili",
    "șindrilii": "șindrili",
    "șindrilim": "șindrili",
    "șindrilind": "șindrili",
    "șindrilindu": "șindrili",
    "șindriliră": "șindrili",
    "șindrilirăm": "șindrili",
    "șindrilirăți": "șindrili",
    "șindrilise": "șindrili",
    "șindrilisem": "șindrili",
    "șindriliseră": "șindrili",
    "șindriliserăm": "șindrili",
    "șindriliserăți": "șindrili",
    "șindriliseși": "șindrili",
    "șindriliși": "șindrili",
    "șindrilit": "șindrili",
    "șindriliți": "șindrili",
    "șindrilită": "șindrilit",
    "șindrilite": "șindrilit",
    "șindriliți": "șindrilit",
    "sindrofia": "sindrofie",
    "sindrofiei": "sindrofie",
    "sindrofii": "sindrofie",
    "sindrofiile": "sindrofie",
    "sindrofiilor": "sindrofie",
    "sindroame": "sindrom",
    "sindroamele": "sindrom",
    "sindroamelor": "sindrom",
    "sindromul": "sindrom",
    "sindromului": "sindrom",
    "nemaișindruind": "șindrui",
    "nemaișindruindu": "șindrui",
    "neșindruind": "șindrui",
    "neșindruindu": "șindrui",
    "șindruia": "șindrui",
    "șindruiai": "șindrui",
    "șindruiam": "șindrui",
    "șindruiască": "șindrui",
    "șindruiați": "șindrui",
    "șindruiau": "șindrui",
    "șindruiesc": "șindrui",
    "șindruiește": "șindrui",
    "șindruiești": "șindrui",
    "șindruii": "șindrui",
    "șindruim": "șindrui",
    "șindruind": "șindrui",
    "șindruindu": "șindrui",
    "șindruiră": "șindrui",
    "șindruirăm": "șindrui",
    "șindruirăți": "șindrui",
    "șindruise": "șindrui",
    "șindruisem": "șindrui",
    "șindruiseră": "șindrui",
    "șindruiserăm": "șindrui",
    "șindruiserăți": "șindrui",
    "șindruiseși": "șindrui",
    "șindruiși": "șindrui",
    "șindruit": "șindrui",
    "șindruiți": "șindrui",
    "șindruirea": "șindruire",
    "șindruireo": "șindruire",
    "șindruiri": "șindruire",
    "șindruirii": "șindruire",
    "șindruirile": "șindruire",
    "șindruirilor": "șindruire",
    "șindruita": "șindruit",
    "șindruită": "șindruit",
    "șindruite": "șindruit",
    "șindruitei": "șindruit",
    "șindruitele": "șindruit",
    "șindruitelor": "șindruit",
    "șindruiți": "șindruit",
    "șindruiții": "șindruit",
    "șindruiților": "șindruit",
    "șindruito": "șindruit",
    "șindruitul": "șindruit",
    "șindruitule": "șindruit",
    "șindruitului": "șindruit",
    "s-": "sine",
    "se": "sine",
    "se-": "sine",
    "sineși": "sine",
    "s.a.": "sine_anno",
    "s.d.": "sine_die",
    "s.l.": "sine_loco",
    "s.n.": "sine_nomine",
    "sineala": "sineală",
    "sineli": "sineală",
    "sinelii": "sineală",
    "sinelile": "sineală",
    "sinelilor": "sineală",
    "sinecdoca": "sinecdocă",
    "sinecdoce": "sinecdocă",
    "sinecdocei": "sinecdocă",
    "sinecdocele": "sinecdocă",
    "sinecdocelor": "sinecdocă",
    "sinecura": "sinecură",
    "sinecuri": "sinecură",
    "sinecurii": "sinecură",
    "sinecurile": "sinecură",
    "sinecurilor": "sinecură",
    "sinecuriști": "sinecurist",
    "sinecuriștii": "sinecurist",
    "sinecuriștilor": "sinecurist",
    "sinecuristul": "sinecurist",
    "sinecuristului": "sinecurist",
    "sinecurista": "sinecuristă",
    "sinecuriste": "sinecuristă",
    "sinecuristei": "sinecuristă",
    "sinecuristele": "sinecuristă",
    "sinecuristelor": "sinecuristă",
    "sinelui": "sinele",
    "sinergia": "sinergie",
    "sinergiei": "sinergie",
    "sinergii": "sinergie",
    "sinergiile": "sinergie",
    "sinergiilor": "sinergie",
    "sinestezia": "sinestezie",
    "sinesteziei": "sinestezie",
    "sinestezii": "sinestezie",
    "sinesteziile": "sinestezie",
    "sinesteziilor": "sinestezie",
    "sinetul": "sinet",
    "sinetului": "sinet",
    "sineturi": "sinet",
    "sineturile": "sinet",
    "sineturilor": "sinet",
    "sg.": "singular",
    "singulara": "singular",
    "singulară": "singular",
    "singulare": "singular",
    "singularei": "singular",
    "singularele": "singular",
    "singularelor": "singular",
    "singulari": "singular",
    "singularii": "singular",
    "singularilor": "singular",
    "singularul": "singular",
    "singularului": "singular",
    "nemaisingularizând": "singulariza",
    "nemaisingularizându": "singulariza",
    "nesingularizând": "singulariza",
    "nesingularizându": "singulariza",
    "singulariză": "singulariza",
    "singularizai": "singulariza",
    "singularizam": "singulariza",
    "singularizăm": "singulariza",
    "singularizând": "singulariza",
    "singularizându": "singulariza",
    "singularizară": "singulariza",
    "singularizarăm": "singulariza",
    "singularizarăți": "singulariza",
    "singularizase": "singulariza",
    "singularizasem": "singulariza",
    "singularizaseră": "singulariza",
    "singularizaserăm": "singulariza",
    "singularizaserăți": "singulariza",
    "singularizaseși": "singulariza",
    "singularizași": "singulariza",
    "singularizat": "singulariza",
    "singularizați": "singulariza",
    "singularizau": "singulariza",
    "singularizează": "singulariza",
    "singularizez": "singulariza",
    "singularizeze": "singulariza",
    "singularizezi": "singulariza",
    "singularizată": "singularizat",
    "singularizate": "singularizat",
    "singularizați": "singularizat",
    "singura": "singur",
    "singură": "singur",
    "singure": "singur",
    "singurei": "singur",
    "singurele": "singur",
    "singurelor": "singur",
    "singuri": "singur",
    "singurii": "singur",
    "singurilor": "singur",
    "singurul": "singur",
    "singurului": "singur",
    "singurătatea": "singurătate",
    "singurătăți": "singurătate",
    "singurătății": "singurătate",
    "singurătățile": "singurătate",
    "singurătăților": "singurătate",
    "singuratica": "singuratic",
    "singuratică": "singuratic",
    "singuratice": "singuratic",
    "singuraticei": "singuratic",
    "singuraticele": "singuratic",
    "singuraticelor": "singuratic",
    "singuratici": "singuratic",
    "singuraticii": "singuratic",
    "singuraticilor": "singuratic",
    "singuraticul": "singuratic",
    "singuraticului": "singuratic",
    "singură-singurică": "singur-singurel",
    "singure-singurele": "singur-singurel",
    "singuri-singurei": "singur-singurel",
    "sinia": "sinie",
    "siniei": "sinie",
    "sinii": "sinie",
    "siniile": "sinie",
    "siniilor": "sinie",
    "sinistra": "sinistru",
    "sinistră": "sinistru",
    "sinistre": "sinistru",
    "sinistrei": "sinistru",
    "sinistrele": "sinistru",
    "sinistrelor": "sinistru",
    "siniștri": "sinistru",
    "siniștrii": "sinistru",
    "siniștrilor": "sinistru",
    "sinistrul": "sinistru",
    "sinistrului": "sinistru",
    "sinoade": "sinod",
    "sinoadele": "sinod",
    "sinoadelor": "sinod",
    "sinodul": "sinod",
    "sinodului": "sinod",
    "sinodala": "sinodal",
    "sinodală": "sinodal",
    "sinodale": "sinodal",
    "sinodalei": "sinodal",
    "sinodalele": "sinodal",
    "sinodalelor": "sinodal",
    "sinodali": "sinodal",
    "sinodalii": "sinodal",
    "sinodalilor": "sinodal",
    "sinodalul": "sinodal",
    "sinodalului": "sinodal",
    "sinodica": "sinodic",
    "sinodică": "sinodic",
    "sinodice": "sinodic",
    "sinodicei": "sinodic",
    "sinodicele": "sinodic",
    "sinodicelor": "sinodic",
    "sinodici": "sinodic",
    "sinodicii": "sinodic",
    "sinodicilor": "sinodic",
    "sinodicul": "sinodic",
    "sinodicului": "sinodic",
    "sinologi": "sinolog",
    "sinologii": "sinolog",
    "sinologilor": "sinolog",
    "sinologul": "sinolog",
    "sinologului": "sinolog",
    "sinologica": "sinologic",
    "sinologică": "sinologic",
    "sinologice": "sinologic",
    "sinologicei": "sinologic",
    "sinologicele": "sinologic",
    "sinologicelor": "sinologic",
    "sinologici": "sinologic",
    "sinologicii": "sinologic",
    "sinologicilor": "sinologic",
    "sinologicul": "sinologic",
    "sinologicului": "sinologic",
    "sinologia": "sinologie",
    "sinologiei": "sinologie",
    "sinologii": "sinologie",
    "sinonimă": "sinonim",
    "sinonime": "sinonim",
    "sinonimele": "sinonim",
    "sinonimelor": "sinonim",
    "sinonimi": "sinonim",
    "sinonimul": "sinonim",
    "sinonimului": "sinonim",
    "sinonimia": "sinonimie",
    "sinonimiei": "sinonimie",
    "sinonimii": "sinonimie",
    "sinonimiile": "sinonimie",
    "sinonimiilor": "sinonimie",
    "sinoptica": "sinoptic",
    "sinoptică": "sinoptic",
    "sinoptice": "sinoptic",
    "sinopticei": "sinoptic",
    "sinopticele": "sinoptic",
    "sinopticelor": "sinoptic",
    "sinoptici": "sinoptic",
    "sinopticii": "sinoptic",
    "sinopticilor": "sinoptic",
    "sinopticul": "sinoptic",
    "sinopticului": "sinoptic",
    "sinoviala": "sinovial",
    "sinovială": "sinovial",
    "sinoviale": "sinovial",
    "sinovialei": "sinovial",
    "sinovialele": "sinovial",
    "sinovialelor": "sinovial",
    "sinoviali": "sinovial",
    "sinovialii": "sinovial",
    "sinovialilor": "sinovial",
    "sinovialul": "sinovial",
    "sinovialului": "sinovial",
    "sinovia": "sinovie",
    "sinoviei": "sinovie",
    "sinovii": "sinovie",
    "sinoviile": "sinovie",
    "sinoviilor": "sinovie",
    "sinovita": "sinovită",
    "sinovite": "sinovită",
    "sinovitei": "sinovită",
    "sinovitele": "sinovită",
    "sinovitelor": "sinovită",
    "sintactica": "sintactic",
    "sintactică": "sintactic",
    "sintactice": "sintactic",
    "sintacticei": "sintactic",
    "sintacticele": "sintactic",
    "sintacticelor": "sintactic",
    "sintactici": "sintactic",
    "sintacticii": "sintactic",
    "sintacticilor": "sintactic",
    "sintacticul": "sintactic",
    "sintacticului": "sintactic",
    "sintagma": "sintagmă",
    "sintagme": "sintagmă",
    "sintagmei": "sintagmă",
    "sintagmele": "sintagmă",
    "sintagmelor": "sintagmă",
    "sintaxa": "sintaxă",
    "sintaxe": "sintaxă",
    "sintaxei": "sintaxă",
    "sintaxele": "sintaxă",
    "sintaxelor": "sintaxă",
    "sintetica": "sintetic",
    "sintetică": "sintetic",
    "sintetice": "sintetic",
    "sinteticei": "sintetic",
    "sinteticele": "sintetic",
    "sinteticelor": "sintetic",
    "sintetici": "sintetic",
    "sinteticii": "sintetic",
    "sinteticilor": "sintetic",
    "sinteticul": "sintetic",
    "sinteticului": "sintetic",
    "nemaisintetizând": "sintetiza",
    "nemaisintetizându": "sintetiza",
    "nesintetizând": "sintetiza",
    "nesintetizându": "sintetiza",
    "sintetiză": "sintetiza",
    "sintetizai": "sintetiza",
    "sintetizam": "sintetiza",
    "sintetizăm": "sintetiza",
    "sintetizând": "sintetiza",
    "sintetizându": "sintetiza",
    "sintetizară": "sintetiza",
    "sintetizarăm": "sintetiza",
    "sintetizarăți": "sintetiza",
    "sintetizase": "sintetiza",
    "sintetizasem": "sintetiza",
    "sintetizaseră": "sintetiza",
    "sintetizaserăm": "sintetiza",
    "sintetizaserăți": "sintetiza",
    "sintetizaseși": "sintetiza",
    "sintetizași": "sintetiza",
    "sintetizat": "sintetiza",
    "sintetizați": "sintetiza",
    "sintetizau": "sintetiza",
    "sintetizează": "sintetiza",
    "sintetizez": "sintetiza",
    "sintetizeze": "sintetiza",
    "sintetizezi": "sintetiza",
    "sintetizată": "sintetizat",
    "sintetizate": "sintetizat",
    "sintetizați": "sintetizat",
    "sinteza": "sinteză",
    "sinteze": "sinteză",
    "sintezei": "sinteză",
    "sintezele": "sinteză",
    "sintezelor": "sinteză",
    "sintonia": "sintonie",
    "sintoniei": "sintonie",
    "sintonii": "sintonie",
    "nemaisinucizând": "sinucide",
    "nemaisinucizându": "sinucide",
    "nesinucizând": "sinucide",
    "nesinucizându": "sinucide",
    "sinucid": "sinucide",
    "sinucidă": "sinucide",
    "sinucidea": "sinucide",
    "sinucideai": "sinucide",
    "sinucideam": "sinucide",
    "sinucideați": "sinucide",
    "sinucideau": "sinucide",
    "sinucidem": "sinucide",
    "sinucideți": "sinucide",
    "sinucigând": "sinucide",
    "sinucigându": "sinucide",
    "sinucis": "sinucide",
    "sinucise": "sinucide",
    "sinucisei": "sinucide",
    "sinuciseră": "sinucide",
    "sinuciserăm": "sinucide",
    "sinuciserăți": "sinucide",
    "sinucisese": "sinucide",
    "sinucisesem": "sinucide",
    "sinuciseseră": "sinucide",
    "sinuciseserăm": "sinucide",
    "sinuciseserăți": "sinucide",
    "sinuciseseși": "sinucide",
    "sinuciseși": "sinucide",
    "sinucizi": "sinucide",
    "sinuciderea": "sinucidere",
    "sinucideri": "sinucidere",
    "sinuciderii": "sinucidere",
    "sinuciderile": "sinucidere",
    "sinuciderilor": "sinucidere",
    "sinucigașa": "sinucigaș",
    "sinucigașă": "sinucigaș",
    "sinucigașe": "sinucigaș",
    "sinucigașei": "sinucigaș",
    "sinucigașele": "sinucigaș",
    "sinucigașelor": "sinucigaș",
    "sinucigași": "sinucigaș",
    "sinucigașii": "sinucigaș",
    "sinucigașilor": "sinucigaș",
    "sinucigașul": "sinucigaș",
    "sinucigașului": "sinucigaș",
    "sinucigașa": "sinucigașă",
    "sinucigașe": "sinucigașă",
    "sinucigașei": "sinucigașă",
    "sinucigașele": "sinucigașă",
    "sinucigașelor": "sinucigașă",
    "sinucisă": "sinucis",
    "sinucise": "sinucis",
    "sinuciși": "sinucis",
    "sinuoasa": "sinuos",
    "sinuoasă": "sinuos",
    "sinuoase": "sinuos",
    "sinuoasei": "sinuos",
    "sinuoasele": "sinuos",
    "sinuoaselor": "sinuos",
    "sinuoși": "sinuos",
    "sinuoșii": "sinuos",
    "sinuoșilor": "sinuos",
    "sinuosul": "sinuos",
    "sinuosului": "sinuos",
    "sinuozitatea": "sinuozitate",
    "sinuozități": "sinuozitate",
    "sinuozității": "sinuozitate",
    "sinuozitățile": "sinuozitate",
    "sinuozităților": "sinuozitate",
    "sin": "sinus",
    "sinusul": "sinus",
    "sinusului": "sinus",
    "sinusuri": "sinus",
    "sinusurile": "sinus",
    "sinusurilor": "sinus",
    "sinusoida": "sinusoidă",
    "sinusoide": "sinusoidă",
    "sinusoidei": "sinusoidă",
    "sinusoidele": "sinusoidă",
    "sinusoidelor": "sinusoidă",
    "sinusoidala": "sinusoidal",
    "sinusoidală": "sinusoidal",
    "sinusoidale": "sinusoidal",
    "sinusoidalei": "sinusoidal",
    "sinusoidalele": "sinusoidal",
    "sinusoidalelor": "sinusoidal",
    "sinusoidali": "sinusoidal",
    "sinusoidalii": "sinusoidal",
    "sinusoidalilor": "sinusoidal",
    "sinusoidalul": "sinusoidal",
    "sinusoidalului": "sinusoidal",
    "sinuzita": "sinuzită",
    "sinuzite": "sinuzită",
    "sinuzitei": "sinuzită",
    "sinuzitele": "sinuzită",
    "sinuzitelor": "sinuzită",
    "sionismul": "sionism",
    "sionismului": "sionism",
    "sionista": "sionist",
    "sionistă": "sionist",
    "sioniste": "sionist",
    "sionistei": "sionist",
    "sionistele": "sionist",
    "sionistelor": "sionist",
    "sioniști": "sionist",
    "sioniștii": "sionist",
    "sioniștilor": "sionist",
    "sionistul": "sionist",
    "sionistului": "sionist",
    "sionista": "sionistă",
    "sioniste": "sionistă",
    "sionistei": "sionistă",
    "sionistele": "sionistă",
    "sionistelor": "sionistă",
    "șipca": "șipcă",
    "șipci": "șipcă",
    "șipcii": "șipcă",
    "șipcile": "șipcă",
    "șipcilor": "șipcă",
    "sipete": "sipet",
    "sipetele": "sipet",
    "sipetelor": "sipet",
    "sipetul": "sipet",
    "sipetului": "sipet",
    "sipica": "sipică",
    "sipici": "sipică",
    "sipicii": "sipică",
    "sipicile": "sipică",
    "sipicilor": "sipică",
    "șipote": "șipot",
    "șipotele": "șipot",
    "șipotelor": "șipot",
    "șipotul": "șipot",
    "șipotului": "șipot",
    "Sr.": "Sir",
    "șirul": "șir",
    "șirului": "șir",
    "șiruri": "șir",
    "șirurile": "șir",
    "șirurilor": "șir",
    "șira": "șiră",
    "șire": "șiră",
    "șirei": "șiră",
    "șirele": "șiră",
    "șirelor": "șiră",
    "șiragul": "șirag",
    "șiragului": "șirag",
    "șiraguri": "șirag",
    "șiragurile": "șirag",
    "șiragurilor": "șirag",
    "sirena": "sirenă",
    "sirene": "sirenă",
    "sirenei": "sirenă",
    "sirenele": "sirenă",
    "sirenelor": "sirenă",
    "șireata": "șiret",
    "șireată": "șiret",
    "șirete": "șiret",
    "șiretei": "șiret",
    "șiretele": "șiret",
    "șiretelor": "șiret",
    "șireți": "șiret",
    "șireții": "șiret",
    "șireților": "șiret",
    "șiretul": "șiret",
    "șiretului": "șiret",
    "șireturi": "șiret",
    "șireturile": "șiret",
    "șireturilor": "șiret",
    "șiretenia": "șiretenie",
    "șireteniei": "șiretenie",
    "șiretenii": "șiretenie",
    "șireteniile": "șiretenie",
    "șireteniilor": "șiretenie",
    "șiretlicul": "șiretlic",
    "șiretlicului": "șiretlic",
    "șiretlicuri": "șiretlic",
    "șiretlicurile": "șiretlic",
    "șiretlicurilor": "șiretlic",
    "sirianul": "sirian",
    "sirianului": "sirian",
    "sirieni": "sirian",
    "sirienii": "sirian",
    "sirienilor": "sirian",
    "nemaișiroind": "șiroi",
    "nemaișiroindu": "șiroi",
    "neșiroind": "șiroi",
    "neșiroindu": "șiroi",
    "șiroaie": "șiroi",
    "șiroaiele": "șiroi",
    "șiroaielor": "șiroi",
    "șiroia": "șiroi",
    "șiroiască": "șiroi",
    "șiroiau": "șiroi",
    "șiroiesc": "șiroi",
    "șiroiește": "șiroi",
    "șiroind": "șiroi",
    "șiroindu": "șiroi",
    "șiroiră": "șiroi",
    "șiroise": "șiroi",
    "șiroiseră": "șiroi",
    "șiroit": "șiroi",
    "șiroiul": "șiroi",
    "șiroiului": "șiroi",
    "șiroirea": "șiroire",
    "șiroireo": "șiroire",
    "șiroiri": "șiroire",
    "șiroirii": "șiroire",
    "șiroirile": "șiroire",
    "șiroirilor": "șiroire",
    "șiroită": "șiroit",
    "șiroite": "șiroit",
    "șiroiți": "șiroit",
    "siropul": "sirop",
    "siropului": "sirop",
    "siropuri": "sirop",
    "siropurile": "sirop",
    "siropurilor": "sirop",
    "șișul": "șiș",
    "șișului": "șiș",
    "șișuri": "șiș",
    "șișurile": "șiș",
    "șișurilor": "șiș",
    "sisali": "sisal",
    "sisalii": "sisal",
    "sisalilor": "sisal",
    "sisalul": "sisal",
    "sisalului": "sisal",
    "șistul": "șist",
    "șistului": "șist",
    "șisturi": "șist",
    "șisturile": "șist",
    "șisturilor": "șist",
    "nemaisistând": "sista",
    "nemaisistându": "sista",
    "nesistând": "sista",
    "nesistându": "sista",
    "sistă": "sista",
    "sistai": "sista",
    "sistam": "sista",
    "sistăm": "sista",
    "sistând": "sista",
    "sistându": "sista",
    "sistară": "sista",
    "sistarăm": "sista",
    "sistarăți": "sista",
    "sistase": "sista",
    "sistasem": "sista",
    "sistaseră": "sista",
    "sistaserăm": "sista",
    "sistaserăți": "sista",
    "sistaseși": "sista",
    "sistași": "sista",
    "sistat": "sista",
    "sistați": "sista",
    "sistau": "sista",
    "sistează": "sista",
    "sistez": "sista",
    "sisteze": "sista",
    "sistezi": "sista",
    "șiștare": "șiștar",
    "șiștarele": "șiștar",
    "șiștarelor": "șiștar",
    "șiștarul": "șiștar",
    "șiștarului": "șiștar",
    "sistarea": "sistare",
    "sistări": "sistare",
    "sistării": "sistare",
    "sistările": "sistare",
    "sistată": "sistat",
    "sistate": "sistat",
    "sistați": "sistat",
    "sisteme": "sistem",
    "sistemele": "sistem",
    "sistemelor": "sistem",
    "sistemul": "sistem",
    "sistemului": "sistem",
    "sistematica": "sistematic",
    "sistematică": "sistematic",
    "sistematice": "sistematic",
    "sistematicei": "sistematic",
    "sistematicele": "sistematic",
    "sistematicelor": "sistematic",
    "sistematici": "sistematic",
    "sistematicii": "sistematic",
    "sistematicilor": "sistematic",
    "sistematicul": "sistematic",
    "sistematicului": "sistematic",
    "nemaisistematizând": "sistematiza",
    "nemaisistematizându": "sistematiza",
    "nesistematizând": "sistematiza",
    "nesistematizându": "sistematiza",
    "sistematiză": "sistematiza",
    "sistematizai": "sistematiza",
    "sistematizam": "sistematiza",
    "sistematizăm": "sistematiza",
    "sistematizând": "sistematiza",
    "sistematizându": "sistematiza",
    "sistematizară": "sistematiza",
    "sistematizarăm": "sistematiza",
    "sistematizarăți": "sistematiza",
    "sistematizase": "sistematiza",
    "sistematizasem": "sistematiza",
    "sistematizaseră": "sistematiza",
    "sistematizaserăm": "sistematiza",
    "sistematizaserăți": "sistematiza",
    "sistematizaseși": "sistematiza",
    "sistematizași": "sistematiza",
    "sistematizat": "sistematiza",
    "sistematizați": "sistematiza",
    "sistematizau": "sistematiza",
    "sistematizează": "sistematiza",
    "sistematizez": "sistematiza",
    "sistematizeze": "sistematiza",
    "sistematizezi": "sistematiza",
    "sistematizarea": "sistematizare",
    "sistematizareo": "sistematizare",
    "sistematizări": "sistematizare",
    "sistematizării": "sistematizare",
    "sistematizările": "sistematizare",
    "sistematizărilor": "sistematizare",
    "sistematizată": "sistematizat",
    "sistematizate": "sistematizat",
    "sistematizați": "sistematizat",
    "sistola": "sistolă",
    "sistole": "sistolă",
    "sistolei": "sistolă",
    "sistolele": "sistolă",
    "sistolelor": "sistolă",
    "sistolica": "sistolic",
    "sistolică": "sistolic",
    "sistolice": "sistolic",
    "sistolicei": "sistolic",
    "sistolicele": "sistolic",
    "sistolicelor": "sistolic",
    "sistolici": "sistolic",
    "sistolicii": "sistolic",
    "sistolicilor": "sistolic",
    "sistolicul": "sistolic",
    "sistolicului": "sistolic",
    "șistoasa": "șistos",
    "șistoasă": "șistos",
    "șistoase": "șistos",
    "șistoasei": "șistos",
    "șistoasele": "șistos",
    "șistoaselor": "șistos",
    "șistoși": "șistos",
    "șistoșii": "șistos",
    "șistoșilor": "șistos",
    "șistosul": "șistos",
    "șistosului": "șistos",
    "sita": "sită",
    "site": "sită",
    "sitei": "sită",
    "sitele": "sită",
    "sitelor": "sită",
    "șița": "șiță",
    "șițe": "șiță",
    "șiței": "șiță",
    "șițele": "șiță",
    "șițelor": "șiță",
    "sitari": "sitar",
    "sitarii": "sitar",
    "sitarilor": "sitar",
    "sitarul": "sitar",
    "sitarului": "sitar",
    "sitronada": "sitronadă",
    "sitronade": "sitronadă",
    "sitronadei": "sitronadă",
    "sitronadele": "sitronadă",
    "sitronadelor": "sitronadă",
    "nemaisituând": "situa",
    "nemaisituându": "situa",
    "nesituând": "situa",
    "nesituându": "situa",
    "situă": "situa",
    "situai": "situa",
    "situam": "situa",
    "situăm": "situa",
    "situând": "situa",
    "situându": "situa",
    "situară": "situa",
    "situarăm": "situa",
    "situarăți": "situa",
    "situase": "situa",
    "situasem": "situa",
    "situaseră": "situa",
    "situaserăm": "situa",
    "situaserăți": "situa",
    "situaseși": "situa",
    "situași": "situa",
    "situat": "situa",
    "situați": "situa",
    "situau": "situa",
    "situează": "situa",
    "situez": "situa",
    "situeze": "situa",
    "situezi": "situa",
    "situarea": "situare",
    "situareo": "situare",
    "situări": "situare",
    "situării": "situare",
    "situările": "situare",
    "situărilor": "situare",
    "situata": "situat",
    "situată": "situat",
    "situate": "situat",
    "situatei": "situat",
    "situatele": "situat",
    "situatelor": "situat",
    "situați": "situat",
    "situații": "situat",
    "situaților": "situat",
    "situato": "situat",
    "situatul": "situat",
    "situatule": "situat",
    "situatului": "situat",
    "situația": "situație",
    "situației": "situație",
    "situații": "situație",
    "situațiile": "situație",
    "situațiilor": "situație",
    "situația-limită": "situație-limită",
    "situației-limită": "situație-limită",
    "situațiile-limită": "situație-limită",
    "situații-limită": "situație-limită",
    "situațiilor-limită": "situație-limită",
    "Siutghiolul": "Siutghiol",
    "Siutghiolului": "Siutghiol",
    "slaba": "slab",
    "slabă": "slab",
    "slăbănoaga": "slab",
    "slăbănoagă": "slab",
    "slăbănoage": "slab",
    "slăbănoagei": "slab",
    "slăbănoagele": "slab",
    "slăbănoagelor": "slab",
    "slăbănog": "slab",
    "slăbănogi": "slab",
    "slăbănogii": "slab",
    "slăbănogilor": "slab",
    "slăbănogul": "slab",
    "slăbănogului": "slab",
    "slabe": "slab",
    "slabei": "slab",
    "slabele": "slab",
    "slabelor": "slab",
    "slabi": "slab",
    "slabii": "slab",
    "slabilor": "slab",
    "slabul": "slab",
    "slabului": "slab",
    "slăbănogi": "slăbănog",
    "slăbănogii": "slăbănog",
    "slăbănogilor": "slăbănog",
    "slăbănogul": "slăbănog",
    "slăbănogului": "slăbănog",
    "nemaislăbănogind": "slăbănogi",
    "nemaislăbănogindu": "slăbănogi",
    "neslăbănogind": "slăbănogi",
    "neslăbănogindu": "slăbănogi",
    "slăbănogea": "slăbănogi",
    "slăbănogeai": "slăbănogi",
    "slăbănogeam": "slăbănogi",
    "slăbănogească": "slăbănogi",
    "slăbănogeați": "slăbănogi",
    "slăbănogeau": "slăbănogi",
    "slăbănogesc": "slăbănogi",
    "slăbănogește": "slăbănogi",
    "slăbănogești": "slăbănogi",
    "slăbănogii": "slăbănogi",
    "slăbănogim": "slăbănogi",
    "slăbănogind": "slăbănogi",
    "slăbănogindu": "slăbănogi",
    "slăbănogiră": "slăbănogi",
    "slăbănogirăm": "slăbănogi",
    "slăbănogirăți": "slăbănogi",
    "slăbănogise": "slăbănogi",
    "slăbănogisem": "slăbănogi",
    "slăbănogiseră": "slăbănogi",
    "slăbănogiserăm": "slăbănogi",
    "slăbănogiserăți": "slăbănogi",
    "slăbănogiseși": "slăbănogi",
    "slăbănogiși": "slăbănogi",
    "slăbănogit": "slăbănogi",
    "slăbănogiți": "slăbănogi",
    "slăbănogită": "slăbănogit",
    "slăbănogite": "slăbănogit",
    "slăbănogiți": "slăbănogit",
    "nemaislăbind": "slăbi",
    "nemaislăbindu": "slăbi",
    "neslăbind": "slăbi",
    "neslăbindu": "slăbi",
    "slăbea": "slăbi",
    "slăbeai": "slăbi",
    "slăbeam": "slăbi",
    "slăbească": "slăbi",
    "slăbeați": "slăbi",
    "slăbeau": "slăbi",
    "slăbesc": "slăbi",
    "slăbește": "slăbi",
    "slăbești": "slăbi",
    "slăbii": "slăbi",
    "slăbim": "slăbi",
    "slăbind": "slăbi",
    "slăbindu": "slăbi",
    "slăbiră": "slăbi",
    "slăbirăm": "slăbi",
    "slăbirăți": "slăbi",
    "slăbise": "slăbi",
    "slăbisem": "slăbi",
    "slăbiseră": "slăbi",
    "slăbiserăm": "slăbi",
    "slăbiserăți": "slăbi",
    "slăbiseși": "slăbi",
    "slăbiși": "slăbi",
    "slăbit": "slăbi",
    "slăbiți": "slăbi",
    "slăbiciunea": "slăbiciune",
    "slăbiciuni": "slăbiciune",
    "slăbiciunii": "slăbiciune",
    "slăbiciunile": "slăbiciune",
    "slăbiciunilor": "slăbiciune",
    "slăbirea": "slăbire",
    "slăbireo": "slăbire",
    "slăbiri": "slăbire",
    "slăbirii": "slăbire",
    "slăbirile": "slăbire",
    "slăbirilor": "slăbire",
    "slăbita": "slăbit",
    "slăbită": "slăbit",
    "slăbite": "slăbit",
    "slăbitei": "slăbit",
    "slăbitele": "slăbit",
    "slăbitelor": "slăbit",
    "slăbiți": "slăbit",
    "slăbiții": "slăbit",
    "slăbiților": "slăbit",
    "slăbito": "slăbit",
    "slăbitul": "slăbit",
    "slăbitule": "slăbit",
    "slăbitului": "slăbit",
    "șlagăre": "șlagăr",
    "șlagărele": "șlagăr",
    "șlagărelor": "șlagăr",
    "șlagărul": "șlagăr",
    "șlagărului": "șlagăr",
    "slaiul": "slai",
    "slaiului": "slai",
    "slaiuri": "slai",
    "slaiurile": "slai",
    "slaiurilor": "slai",
    "slalomul": "slalom",
    "slalomului": "slalom",
    "slalomuri": "slalom",
    "slalomurile": "slalom",
    "slalomurilor": "slalom",
    "șlampăta": "șlampăt",
    "șlampătă": "șlampăt",
    "șlampătul": "șlampăt",
    "șlampătului": "șlampăt",
    "șlampete": "șlampăt",
    "șlampetei": "șlampăt",
    "șlampetele": "șlampăt",
    "șlampetelor": "șlampăt",
    "șlampeți": "șlampăt",
    "șlampeții": "șlampăt",
    "șlampeților": "șlampăt",
    "slănina": "slănină",
    "slănini": "slănină",
    "slăninii": "slănină",
    "slăninile": "slănină",
    "slăninilor": "slănină",
    "slatina": "slatină",
    "slatine": "slatină",
    "slatinei": "slatină",
    "slatinele": "slatină",
    "slatinelor": "slatină",
    "slavi": "slav",
    "slavii": "slav",
    "slavilor": "slav",
    "slavul": "slav",
    "slavului": "slav",
    "slava": "slavă",
    "slave": "slavă",
    "slavei": "slavă",
    "slavele": "slavă",
    "slavelor": "slavă",
    "slăvi": "slavă",
    "slăvii": "slavă",
    "slăvile": "slavă",
    "slăvilor": "slavă",
    "sl.": "slavă_veche",
    "nemaislăvind": "slăvi",
    "nemaislăvindu": "slăvi",
    "neslăvind": "slăvi",
    "neslăvindu": "slăvi",
    "slăvea": "slăvi",
    "slăveai": "slăvi",
    "slăveam": "slăvi",
    "slăvească": "slăvi",
    "slăveați": "slăvi",
    "slăveau": "slăvi",
    "slăvesc": "slăvi",
    "slăvește": "slăvi",
    "slăvești": "slăvi",
    "slăvii": "slăvi",
    "slăvim": "slăvi",
    "slăvind": "slăvi",
    "slăvindu": "slăvi",
    "slăviră": "slăvi",
    "slăvirăm": "slăvi",
    "slăvirăți": "slăvi",
    "slăvise": "slăvi",
    "slăvisem": "slăvi",
    "slăviseră": "slăvi",
    "slăviserăm": "slăvi",
    "slăviserăți": "slăvi",
    "slăviseși": "slăvi",
    "slăviși": "slăvi",
    "slăvit": "slăvi",
    "slăviți": "slăvi",
    "slăvirea": "slăvire",
    "slăvireo": "slăvire",
    "slăviri": "slăvire",
    "slăvirii": "slăvire",
    "slăvirile": "slăvire",
    "slăvirilor": "slăvire",
    "slaviști": "slavist",
    "slaviștii": "slavist",
    "slaviștilor": "slavist",
    "slavistul": "slavist",
    "slavistului": "slavist",
    "slavista": "slavistă",
    "slaviste": "slavistă",
    "slavistei": "slavistă",
    "slavistele": "slavistă",
    "slavistelor": "slavistă",
    "slavistica": "slavistică",
    "slavistice": "slavistică",
    "slavisticei": "slavistică",
    "slavisticele": "slavistică",
    "slavisticelor": "slavistică",
    "slăvita": "slăvit",
    "slăvită": "slăvit",
    "slăvite": "slăvit",
    "slăvitei": "slăvit",
    "slăvitele": "slăvit",
    "slăvitelor": "slăvit",
    "slăviți": "slăvit",
    "slăviții": "slăvit",
    "slăviților": "slăvit",
    "slăvito": "slăvit",
    "slăvitul": "slăvit",
    "slăvitule": "slăvit",
    "slăvitului": "slăvit",
    "nemaislavizând": "slaviza",
    "nemaislavizându": "slaviza",
    "neslavizând": "slaviza",
    "neslavizându": "slaviza",
    "slaviză": "slaviza",
    "slavizai": "slaviza",
    "slavizam": "slaviza",
    "slavizăm": "slaviza",
    "slavizând": "slaviza",
    "slavizându": "slaviza",
    "slavizară": "slaviza",
    "slavizarăm": "slaviza",
    "slavizarăți": "slaviza",
    "slavizase": "slaviza",
    "slavizasem": "slaviza",
    "slavizaseră": "slaviza",
    "slavizaserăm": "slaviza",
    "slavizaserăți": "slaviza",
    "slavizaseși": "slaviza",
    "slavizași": "slaviza",
    "slavizat": "slaviza",
    "slavizați": "slaviza",
    "slavizau": "slaviza",
    "slavizează": "slaviza",
    "slavizez": "slaviza",
    "slavizeze": "slaviza",
    "slavizezi": "slaviza",
    "slavizată": "slavizat",
    "slavizate": "slavizat",
    "slavizați": "slavizat",
    "Slavoniei": "Slavonia",
    "șleahta": "șleahtă",
    "șlehte": "șleahtă",
    "șlehtei": "șleahtă",
    "șlehtele": "șleahtă",
    "șlehtelor": "șleahtă",
    "șleampăta": "șleampăt",
    "șleampătă": "șleampăt",
    "șleampătul": "șleampăt",
    "șleampătului": "șleampăt",
    "șleampete": "șleampăt",
    "șleampetei": "șleampăt",
    "șleampetele": "șleampăt",
    "șleampetelor": "șleampăt",
    "șleampeți": "șleampăt",
    "șleampeții": "șleampăt",
    "șleampeților": "șleampăt",
    "șleaul": "șleau",
    "șleaului": "șleau",
    "șleauri": "șleau",
    "șleaurile": "șleau",
    "șleaurilor": "șleau",
    "nemaișlefuind": "șlefui",
    "nemaișlefuindu": "șlefui",
    "neșlefuind": "șlefui",
    "neșlefuindu": "șlefui",
    "șlefuia": "șlefui",
    "șlefuiai": "șlefui",
    "șlefuiam": "șlefui",
    "șlefuiască": "șlefui",
    "șlefuiați": "șlefui",
    "șlefuiau": "șlefui",
    "șlefuiesc": "șlefui",
    "șlefuiește": "șlefui",
    "șlefuiești": "șlefui",
    "șlefuii": "șlefui",
    "șlefuim": "șlefui",
    "șlefuind": "șlefui",
    "șlefuindu": "șlefui",
    "șlefuiră": "șlefui",
    "șlefuirăm": "șlefui",
    "șlefuirăți": "șlefui",
    "șlefuise": "șlefui",
    "șlefuisem": "șlefui",
    "șlefuiseră": "șlefui",
    "șlefuiserăm": "șlefui",
    "șlefuiserăți": "șlefui",
    "șlefuiseși": "șlefui",
    "șlefuiși": "șlefui",
    "șlefuit": "șlefui",
    "șlefuiți": "șlefui",
    "șlefuită": "șlefuit",
    "șlefuite": "șlefuit",
    "șlefuiți": "șlefuit",
    "nemaisleind": "slei",
    "nemaisleindu": "slei",
    "nesleind": "slei",
    "nesleindu": "slei",
    "sleia": "slei",
    "sleiai": "slei",
    "sleiam": "slei",
    "sleiască": "slei",
    "sleiați": "slei",
    "sleiau": "slei",
    "sleiesc": "slei",
    "sleiește": "slei",
    "sleiești": "slei",
    "sleii": "slei",
    "sleim": "slei",
    "sleind": "slei",
    "sleindu": "slei",
    "sleiră": "slei",
    "sleirăm": "slei",
    "sleirăți": "slei",
    "sleise": "slei",
    "sleisem": "slei",
    "sleiseră": "slei",
    "sleiserăm": "slei",
    "sleiserăți": "slei",
    "sleiseși": "slei",
    "sleiși": "slei",
    "sleit": "slei",
    "sleiți": "slei",
    "sleirea": "sleire",
    "sleiri": "sleire",
    "sleirii": "sleire",
    "sleirile": "sleire",
    "sleirilor": "sleire",
    "sleită": "sleit",
    "sleite": "sleit",
    "sleiți": "sleit",
    "șlepul": "șlep",
    "șlepului": "șlep",
    "șlepuri": "șlep",
    "șlepurile": "șlep",
    "șlepurilor": "șlep",
    "șlibovița": "șliboviță",
    "șlibovițe": "șliboviță",
    "șliboviței": "șliboviță",
    "șlibovițele": "șliboviță",
    "șlibovițelor": "șliboviță",
    "slinoasa": "slinos",
    "slinoasă": "slinos",
    "slinoase": "slinos",
    "slinoasei": "slinos",
    "slinoasele": "slinos",
    "slinoaselor": "slinos",
    "slinoși": "slinos",
    "slinoșii": "slinos",
    "slinoșilor": "slinos",
    "slinosul": "slinos",
    "slinosului": "slinos",
    "slipul": "slip",
    "slipului": "slip",
    "slipuri": "slip",
    "slipurile": "slip",
    "slipurilor": "slip",
    "șlițul": "șliț",
    "șlițului": "șliț",
    "șlițuri": "șliț",
    "șlițurile": "șliț",
    "șlițurilor": "șliț",
    "sloboda": "slobod",
    "slobodă": "slobod",
    "slobode": "slobod",
    "slobodei": "slobod",
    "slobodele": "slobod",
    "slobodelor": "slobod",
    "slobodul": "slobod",
    "slobodului": "slobod",
    "slobozi": "slobod",
    "slobozii": "slobod",
    "slobozilor": "slobod",
    "slobozenia": "slobozenie",
    "slobozeniei": "slobozenie",
    "slobozenii": "slobozenie",
    "slobozeniile": "slobozenie",
    "slobozeniilor": "slobozenie",
    "nemaislobozind": "slobozi",
    "nemaislobozindu": "slobozi",
    "neslobozind": "slobozi",
    "neslobozindu": "slobozi",
    "slobod": "slobozi",
    "slobode": "slobozi",
    "slobozea": "slobozi",
    "slobozeai": "slobozi",
    "slobozeam": "slobozi",
    "slobozească": "slobozi",
    "slobozeați": "slobozi",
    "slobozeau": "slobozi",
    "slobozesc": "slobozi",
    "slobozește": "slobozi",
    "slobozești": "slobozi",
    "slobozii": "slobozi",
    "slobozim": "slobozi",
    "slobozind": "slobozi",
    "slobozindu": "slobozi",
    "sloboziră": "slobozi",
    "slobozirăm": "slobozi",
    "slobozirăți": "slobozi",
    "slobozise": "slobozi",
    "slobozisem": "slobozi",
    "sloboziseră": "slobozi",
    "sloboziserăm": "slobozi",
    "sloboziserăți": "slobozi",
    "sloboziseși": "slobozi",
    "sloboziși": "slobozi",
    "slobozit": "slobozi",
    "sloboziți": "slobozi",
    "slobozia": "slobozie",
    "sloboziei": "slobozie",
    "slobozii": "slobozie",
    "sloboziile": "slobozie",
    "sloboziilor": "slobozie",
    "slobozirea": "slobozire",
    "sloboziri": "slobozire",
    "slobozirii": "slobozire",
    "slobozirile": "slobozire",
    "slobozirilor": "slobozire",
    "slobozită": "slobozit",
    "slobozite": "slobozit",
    "sloboziți": "slobozit",
    "slogane": "slogan",
    "sloganele": "slogan",
    "sloganelor": "slogan",
    "sloganul": "slogan",
    "sloganului": "slogan",
    "sloganuri": "slogan",
    "sloganurile": "slogan",
    "sloganurilor": "slogan",
    "sloiul": "sloi",
    "sloiului": "sloi",
    "sloiuri": "sloi",
    "sloiurile": "sloi",
    "sloiurilor": "sloi",
    "slova": "slovă",
    "slove": "slovă",
    "slovei": "slovă",
    "slovele": "slovă",
    "slovelor": "slovă",
    "slovaci": "slovac",
    "slovacii": "slovac",
    "slovacilor": "slovac",
    "slovacul": "slovac",
    "slovacului": "slovac",
    "slovaca": "slovacă",
    "slovace": "slovacă",
    "slovacei": "slovacă",
    "slovacele": "slovacă",
    "slovacelor": "slovacă",
    "Slovaciei": "Slovacia",
    "sloveni": "sloven",
    "slovenii": "sloven",
    "slovenilor": "sloven",
    "slovenul": "sloven",
    "slovenului": "sloven",
    "slov.": "slovenă",
    "slovena": "slovenă",
    "slovene": "slovenă",
    "slovenei": "slovenă",
    "slovenele": "slovenă",
    "slovenelor": "slovenă",
    "slovenirea": "slovenire",
    "sloveniri": "slovenire",
    "slovenirii": "slovenire",
    "slovenirile": "slovenire",
    "slovenirilor": "slovenire",
    "sluga": "slugă",
    "slugi": "slugă",
    "slugii": "slugă",
    "slugile": "slugă",
    "slugilor": "slugă",
    "nemaislugărind": "slugări",
    "nemaislugărindu": "slugări",
    "neslugărind": "slugări",
    "neslugărindu": "slugări",
    "slugărea": "slugări",
    "slugăreai": "slugări",
    "slugăream": "slugări",
    "slugărească": "slugări",
    "slugăreați": "slugări",
    "slugăreau": "slugări",
    "slugăresc": "slugări",
    "slugărește": "slugări",
    "slugărești": "slugări",
    "slugării": "slugări",
    "slugărim": "slugări",
    "slugărind": "slugări",
    "slugărindu": "slugări",
    "slugăriră": "slugări",
    "slugărirăm": "slugări",
    "slugărirăți": "slugări",
    "slugărise": "slugări",
    "slugărisem": "slugări",
    "slugăriseră": "slugări",
    "slugăriserăm": "slugări",
    "slugăriserăți": "slugări",
    "slugăriseși": "slugări",
    "slugăriși": "slugări",
    "slugărit": "slugări",
    "slugăriți": "slugări",
    "slugărită": "slugărit",
    "slugărite": "slugărit",
    "slugăriți": "slugărit",
    "slugarnica": "slugarnic",
    "slugarnică": "slugarnic",
    "slugarnice": "slugarnic",
    "slugarnicei": "slugarnic",
    "slugarnicele": "slugarnic",
    "slugarnicelor": "slugarnic",
    "slugarnici": "slugarnic",
    "slugarnicii": "slugarnic",
    "slugarnicilor": "slugarnic",
    "slugarnicul": "slugarnic",
    "slugarnicului": "slugarnic",
    "nemaislugărnicind": "slugărnici",
    "nemaislugărnicindu": "slugărnici",
    "neslugărnicind": "slugărnici",
    "neslugărnicindu": "slugărnici",
    "slugărnicea": "slugărnici",
    "slugărniceai": "slugărnici",
    "slugărniceam": "slugărnici",
    "slugărnicească": "slugărnici",
    "slugărniceați": "slugărnici",
    "slugărniceau": "slugărnici",
    "slugărnicesc": "slugărnici",
    "slugărnicește": "slugărnici",
    "slugărnicești": "slugărnici",
    "slugărnicii": "slugărnici",
    "slugărnicim": "slugărnici",
    "slugărnicind": "slugărnici",
    "slugărnicindu": "slugărnici",
    "slugărniciră": "slugărnici",
    "slugărnicirăm": "slugărnici",
    "slugărnicirăți": "slugărnici",
    "slugărnicise": "slugărnici",
    "slugărnicisem": "slugărnici",
    "slugărniciseră": "slugărnici",
    "slugărniciserăm": "slugărnici",
    "slugărniciserăți": "slugărnici",
    "slugărniciseși": "slugărnici",
    "slugărniciși": "slugărnici",
    "slugărnicit": "slugărnici",
    "slugărniciți": "slugărnici",
    "slugărnicia": "slugărnicie",
    "slugărniciei": "slugărnicie",
    "slugărnicii": "slugărnicie",
    "slugărniciile": "slugărnicie",
    "slugărniciilor": "slugărnicie",
    "slugărnicită": "slugărnicit",
    "slugărnicite": "slugărnicit",
    "slugărniciți": "slugărnicit",
    "slugeri": "sluger",
    "slugerii": "sluger",
    "slugerilor": "sluger",
    "slugerul": "sluger",
    "slugerului": "sluger",
    "slujba": "slujbă",
    "slujbe": "slujbă",
    "slujbei": "slujbă",
    "slujbele": "slujbă",
    "slujbelor": "slujbă",
    "slujbași": "slujbaș",
    "slujbașii": "slujbaș",
    "slujbașilor": "slujbaș",
    "slujbașul": "slujbaș",
    "slujbașului": "slujbaș",
    "slujbașa": "slujbașă",
    "slujbașe": "slujbașă",
    "slujbașei": "slujbașă",
    "slujbașele": "slujbașă",
    "slujbașelor": "slujbașă",
    "nemaislujind": "sluji",
    "nemaislujindu": "sluji",
    "neslujind": "sluji",
    "neslujindu": "sluji",
    "slujea": "sluji",
    "slujeai": "sluji",
    "slujeam": "sluji",
    "slujească": "sluji",
    "slujeați": "sluji",
    "slujeau": "sluji",
    "slujesc": "sluji",
    "slujește": "sluji",
    "slujești": "sluji",
    "slujii": "sluji",
    "slujim": "sluji",
    "slujind": "sluji",
    "slujindu": "sluji",
    "slujiră": "sluji",
    "slujirăm": "sluji",
    "slujirăți": "sluji",
    "slujise": "sluji",
    "slujisem": "sluji",
    "slujiseră": "sluji",
    "slujiserăm": "sluji",
    "slujiserăți": "sluji",
    "slujiseși": "sluji",
    "slujiși": "sluji",
    "slujit": "sluji",
    "slujiți": "sluji",
    "slujirea": "slujire",
    "slujireo": "slujire",
    "slujiri": "slujire",
    "slujirii": "slujire",
    "slujirile": "slujire",
    "slujirilor": "slujire",
    "slujită": "slujit",
    "slujite": "slujit",
    "slujiți": "slujit",
    "slujitoarea": "slujitoare",
    "slujitoarei": "slujitoare",
    "slujitoarele": "slujitoare",
    "slujitoarelor": "slujitoare",
    "slujitoare": "slujitor",
    "slujitoarea": "slujitor",
    "slujitoarei": "slujitor",
    "slujitoarele": "slujitor",
    "slujitoarelor": "slujitor",
    "slujitoareo": "slujitor",
    "slujitori": "slujitor",
    "slujitorii": "slujitor",
    "slujitorilor": "slujitor",
    "slujitorul": "slujitor",
    "slujitorule": "slujitor",
    "slujitorului": "slujitor",
    "slujnica": "slujnică",
    "slujnice": "slujnică",
    "slujnicei": "slujnică",
    "slujnicele": "slujnică",
    "slujnicelor": "slujnică",
    "sluta": "slut",
    "slută": "slut",
    "slute": "slut",
    "slutei": "slut",
    "slutele": "slut",
    "slutelor": "slut",
    "sluți": "slut",
    "sluții": "slut",
    "sluților": "slut",
    "slutul": "slut",
    "slutului": "slut",
    "sluțenia": "sluțenie",
    "sluțeniei": "sluțenie",
    "sluțenii": "sluțenie",
    "sluțeniile": "sluțenie",
    "sluțeniilor": "sluțenie",
    "nemaisluțind": "sluți",
    "nemaisluțindu": "sluți",
    "nesluțind": "sluți",
    "nesluțindu": "sluți",
    "sluțea": "sluți",
    "sluțeai": "sluți",
    "sluțeam": "sluți",
    "sluțească": "sluți",
    "sluțeați": "sluți",
    "sluțeau": "sluți",
    "sluțesc": "sluți",
    "sluțește": "sluți",
    "sluțești": "sluți",
    "sluții": "sluți",
    "sluțim": "sluți",
    "sluțind": "sluți",
    "sluțindu": "sluți",
    "sluțiră": "sluți",
    "sluțirăm": "sluți",
    "sluțirăți": "sluți",
    "sluțise": "sluți",
    "sluțisem": "sluți",
    "sluțiseră": "sluți",
    "sluțiserăm": "sluți",
    "sluțiserăți": "sluți",
    "sluțiseși": "sluți",
    "sluțiși": "sluți",
    "sluțit": "sluți",
    "sluțiți": "sluți",
    "sluțită": "sluțit",
    "sluțite": "sluțit",
    "sluțiți": "sluțit",
    "smalțul": "smalț",
    "smalțului": "smalț",
    "smalțuri": "smalț",
    "smalțurile": "smalț",
    "smalțurilor": "smalț",
    "nemaismălțuind": "smălțui",
    "nemaismălțuindu": "smălțui",
    "nesmălțuind": "smălțui",
    "nesmălțuindu": "smălțui",
    "smălțuia": "smălțui",
    "smălțuiai": "smălțui",
    "smălțuiam": "smălțui",
    "smălțuiască": "smălțui",
    "smălțuiați": "smălțui",
    "smălțuiau": "smălțui",
    "smălțuiesc": "smălțui",
    "smălțuiește": "smălțui",
    "smălțuiești": "smălțui",
    "smălțuii": "smălțui",
    "smălțuim": "smălțui",
    "smălțuind": "smălțui",
    "smălțuindu": "smălțui",
    "smălțuiră": "smălțui",
    "smălțuirăm": "smălțui",
    "smălțuirăți": "smălțui",
    "smălțuise": "smălțui",
    "smălțuisem": "smălțui",
    "smălțuiseră": "smălțui",
    "smălțuiserăm": "smălțui",
    "smălțuiserăți": "smălțui",
    "smălțuiseși": "smălțui",
    "smălțuiși": "smălțui",
    "smălțuit": "smălțui",
    "smălțuiți": "smălțui",
    "smălțuită": "smălțuit",
    "smălțuite": "smălțuit",
    "smălțuiți": "smălțuit",
    "smântâna": "smântână",
    "smântânea": "smântână",
    "smântânii": "smântână",
    "nemaismântânind": "smântâni",
    "nemaismântânindu": "smântâni",
    "nesmântânind": "smântâni",
    "nesmântânindu": "smântâni",
    "smântânea": "smântâni",
    "smântâneai": "smântâni",
    "smântâneam": "smântâni",
    "smântânească": "smântâni",
    "smântâneați": "smântâni",
    "smântâneau": "smântâni",
    "smântânesc": "smântâni",
    "smântânește": "smântâni",
    "smântânești": "smântâni",
    "smântânii": "smântâni",
    "smântânim": "smântâni",
    "smântânind": "smântâni",
    "smântânindu": "smântâni",
    "smântâniră": "smântâni",
    "smântânirăm": "smântâni",
    "smântânirăți": "smântâni",
    "smântânise": "smântâni",
    "smântânisem": "smântâni",
    "smântâniseră": "smântâni",
    "smântâniserăm": "smântâni",
    "smântâniserăți": "smântâni",
    "smântâniseși": "smântâni",
    "smântâniși": "smântâni",
    "smântânit": "smântâni",
    "smântâniți": "smântâni",
    "smântânită": "smântânit",
    "smântânite": "smântânit",
    "smântâniți": "smântânit",
    "smaragde": "smaragd",
    "smaragdele": "smaragd",
    "smaragdelor": "smaragd",
    "smaragdul": "smaragd",
    "smaragdului": "smaragd",
    "smaralde": "smarald",
    "smaraldele": "smarald",
    "smaraldelor": "smarald",
    "smaraldul": "smarald",
    "smaraldului": "smarald",
    "Smarandei": "Smaranda",
    "smârcul": "smârc",
    "smârcului": "smârc",
    "smârcuri": "smârc",
    "smârcurile": "smârc",
    "smârcurilor": "smârc",
    "nemaismârcâind": "smârcâi",
    "nemaismârcâindu": "smârcâi",
    "nesmârcâind": "smârcâi",
    "nesmârcâindu": "smârcâi",
    "smârcâia": "smârcâi",
    "smârcâiai": "smârcâi",
    "smârcâiam": "smârcâi",
    "smârcâiați": "smârcâi",
    "smârcâiau": "smârcâi",
    "smârcâie": "smârcâi",
    "smârcâii": "smârcâi",
    "smârcâim": "smârcâi",
    "smârcâind": "smârcâi",
    "smârcâindu": "smârcâi",
    "smârcâiră": "smârcâi",
    "smârcâirăm": "smârcâi",
    "smârcâirăți": "smârcâi",
    "smârcâise": "smârcâi",
    "smârcâisem": "smârcâi",
    "smârcâiseră": "smârcâi",
    "smârcâiserăm": "smârcâi",
    "smârcâiserăți": "smârcâi",
    "smârcâiseși": "smârcâi",
    "smârcâiși": "smârcâi",
    "smârcâit": "smârcâi",
    "smârcâiți": "smârcâi",
    "smârcâită": "smârcâit",
    "smârcâite": "smârcâit",
    "smârcâiți": "smârcâit",
    "smeada": "smead",
    "smeadă": "smead",
    "smeadul": "smead",
    "smeadului": "smead",
    "smede": "smead",
    "smedei": "smead",
    "smedele": "smead",
    "smedelor": "smead",
    "smezi": "smead",
    "smezii": "smead",
    "smezilor": "smead",
    "șmechera": "șmecher",
    "șmecheră": "șmecher",
    "șmechere": "șmecher",
    "șmecherei": "șmecher",
    "șmecherele": "șmecher",
    "șmecherelor": "șmecher",
    "șmecheri": "șmecher",
    "șmecherii": "șmecher",
    "șmecherilor": "șmecher",
    "șmecherul": "șmecher",
    "șmecherului": "șmecher",
    "șmechera": "șmecheră",
    "șmechere": "șmecheră",
    "șmecherei": "șmecheră",
    "șmecherele": "șmecheră",
    "șmecherelor": "șmecheră",
    "șmechereasca": "șmecheresc",
    "șmecherească": "șmecheresc",
    "șmecherescul": "șmecheresc",
    "șmecherescului": "șmecheresc",
    "șmecherești": "șmecheresc",
    "șmechereștii": "șmecheresc",
    "șmechereștile": "șmecheresc",
    "șmechereștilor": "șmecheresc",
    "nemaișmecherind": "șmecheri",
    "nemaișmecherindu": "șmecheri",
    "neșmecherind": "șmecheri",
    "neșmecherindu": "șmecheri",
    "șmecherea": "șmecheri",
    "șmechereai": "șmecheri",
    "șmecheream": "șmecheri",
    "șmecherească": "șmecheri",
    "șmechereați": "șmecheri",
    "șmechereau": "șmecheri",
    "șmecheresc": "șmecheri",
    "șmecherește": "șmecheri",
    "șmecherești": "șmecheri",
    "șmecherii": "șmecheri",
    "șmecherim": "șmecheri",
    "șmecherind": "șmecheri",
    "șmecherindu": "șmecheri",
    "șmecheriră": "șmecheri",
    "șmecherirăm": "șmecheri",
    "șmecherirăți": "șmecheri",
    "șmecherise": "șmecheri",
    "șmecherisem": "șmecheri",
    "șmecheriseră": "șmecheri",
    "șmecheriserăm": "șmecheri",
    "șmecheriserăți": "șmecheri",
    "șmecheriseși": "șmecheri",
    "șmecheriși": "șmecheri",
    "șmecherit": "șmecheri",
    "șmecheriți": "șmecheri",
    "șmecheria": "șmecherie",
    "șmecheriei": "șmecherie",
    "șmecherii": "șmecherie",
    "șmecheriile": "șmecherie",
    "șmecheriilor": "șmecherie",
    "șmecherirea": "șmecherire",
    "șmecherireo": "șmecherire",
    "șmecheriri": "șmecherire",
    "șmecheririi": "șmecherire",
    "șmecheririle": "șmecherire",
    "șmecheririlor": "șmecherire",
    "șmecherită": "șmecherit",
    "șmecherite": "șmecherit",
    "șmecheriți": "șmecherit",
    "smerenia": "smerenie",
    "smereniei": "smerenie",
    "smerenii": "smerenie",
    "smereniile": "smerenie",
    "smereniilor": "smerenie",
    "nemaismerind": "smeri",
    "nemaismerindu": "smeri",
    "nesmerind": "smeri",
    "nesmerindu": "smeri",
    "smerea": "smeri",
    "smereai": "smeri",
    "smeream": "smeri",
    "smerească": "smeri",
    "smereați": "smeri",
    "smereau": "smeri",
    "smeresc": "smeri",
    "smerește": "smeri",
    "smerești": "smeri",
    "smerii": "smeri",
    "smerim": "smeri",
    "smerind": "smeri",
    "smerindu": "smeri",
    "smeriră": "smeri",
    "smerirăm": "smeri",
    "smerirăți": "smeri",
    "smerise": "smeri",
    "smerisem": "smeri",
    "smeriseră": "smeri",
    "smeriserăm": "smeri",
    "smeriserăți": "smeri",
    "smeriseși": "smeri",
    "smeriși": "smeri",
    "smerit": "smeri",
    "smeriți": "smeri",
    "smerirea": "smerire",
    "smeriri": "smerire",
    "smeririi": "smerire",
    "smeririle": "smerire",
    "smeririlor": "smerire",
    "smerită": "smerit",
    "smerite": "smerit",
    "smeriți": "smerit",
    "smeritul": "smerit",
    "smeritului": "smerit",
    "smiceaua": "smicea",
    "smicele": "smicea",
    "smicelei": "smicea",
    "smicelele": "smicea",
    "smicelelor": "smicea",
    "sminteala": "sminteală",
    "sminteli": "sminteală",
    "smintelii": "sminteală",
    "smintelile": "sminteală",
    "smintelilor": "sminteală",
    "nemaismintind": "sminti",
    "nemaismintindu": "sminti",
    "nesmintind": "sminti",
    "nesmintindu": "sminti",
    "smintea": "sminti",
    "sminteai": "sminti",
    "sminteam": "sminti",
    "smintească": "sminti",
    "sminteați": "sminti",
    "sminteau": "sminti",
    "smintesc": "sminti",
    "smintește": "sminti",
    "smintești": "sminti",
    "smintii": "sminti",
    "smintim": "sminti",
    "smintind": "sminti",
    "smintindu": "sminti",
    "smintiră": "sminti",
    "smintirăm": "sminti",
    "smintirăți": "sminti",
    "smintise": "sminti",
    "smintisem": "sminti",
    "smintiseră": "sminti",
    "smintiserăm": "sminti",
    "smintiserăți": "sminti",
    "smintiseși": "sminti",
    "smintiși": "sminti",
    "smintit": "sminti",
    "smintiți": "sminti",
    "smintirea": "smintire",
    "smintireo": "smintire",
    "smintiri": "smintire",
    "smintirii": "smintire",
    "smintirile": "smintire",
    "smintirilor": "smintire",
    "smintita": "smintit",
    "smintită": "smintit",
    "smintite": "smintit",
    "smintitei": "smintit",
    "smintitele": "smintit",
    "smintitelor": "smintit",
    "smintiți": "smintit",
    "smintiții": "smintit",
    "smintiților": "smintit",
    "smintito": "smintit",
    "smintitul": "smintit",
    "smintitule": "smintit",
    "smintitului": "smintit",
    "smintita": "smintită",
    "smintite": "smintită",
    "smintitei": "smintită",
    "smintitele": "smintită",
    "smintitelor": "smintită",
    "smintito": "smintită",
    "nemaismiorcăind": "smiorcăi",
    "nemaismiorcăindu": "smiorcăi",
    "nesmiorcăind": "smiorcăi",
    "nesmiorcăindu": "smiorcăi",
    "smiorcăia": "smiorcăi",
    "smiorcăiai": "smiorcăi",
    "smiorcăiam": "smiorcăi",
    "smiorcăiați": "smiorcăi",
    "smiorcăiau": "smiorcăi",
    "smiorcăie": "smiorcăi",
    "smiorcăii": "smiorcăi",
    "smiorcăim": "smiorcăi",
    "smiorcăind": "smiorcăi",
    "smiorcăindu": "smiorcăi",
    "smiorcăiră": "smiorcăi",
    "smiorcăirăm": "smiorcăi",
    "smiorcăirăți": "smiorcăi",
    "smiorcăise": "smiorcăi",
    "smiorcăisem": "smiorcăi",
    "smiorcăiseră": "smiorcăi",
    "smiorcăiserăm": "smiorcăi",
    "smiorcăiserăți": "smiorcăi",
    "smiorcăiseși": "smiorcăi",
    "smiorcăiși": "smiorcăi",
    "smiorcăit": "smiorcăi",
    "smiorcăiți": "smiorcăi",
    "smiorcăiala": "smiorcăială",
    "smiorcăialo": "smiorcăială",
    "smiorcăieli": "smiorcăială",
    "smiorcăielii": "smiorcăială",
    "smiorcăielile": "smiorcăială",
    "smiorcăielilor": "smiorcăială",
    "smiorcăirea": "smiorcăire",
    "smiorcăireo": "smiorcăire",
    "smiorcăiri": "smiorcăire",
    "smiorcăirii": "smiorcăire",
    "smiorcăirile": "smiorcăire",
    "smiorcăirilor": "smiorcăire",
    "smiorcăita": "smiorcăit",
    "smiorcăită": "smiorcăit",
    "smiorcăite": "smiorcăit",
    "smiorcăitei": "smiorcăit",
    "smiorcăitele": "smiorcăit",
    "smiorcăitelor": "smiorcăit",
    "smiorcăiți": "smiorcăit",
    "smiorcăiții": "smiorcăit",
    "smiorcăiților": "smiorcăit",
    "smiorcăito": "smiorcăit",
    "smiorcăitul": "smiorcăit",
    "smiorcăitule": "smiorcăit",
    "smiorcăitului": "smiorcăit",
    "smirdari": "smirdar",
    "smirdarii": "smirdar",
    "smirdarilor": "smirdar",
    "smirdarul": "smirdar",
    "smirdarului": "smirdar",
    "șmirghelul": "șmirghel",
    "șmirghelului": "șmirghel",
    "smirna": "smirnă",
    "smirne": "smirnă",
    "smirnei": "smirnă",
    "smirnele": "smirnă",
    "smirnelor": "smirnă",
    "smoala": "smoală",
    "smoale": "smoală",
    "smoalei": "smoală",
    "smocul": "smoc",
    "smocului": "smoc",
    "smocuri": "smoc",
    "smocurile": "smoc",
    "smocurilor": "smoc",
    "smochinul": "smochin",
    "smochinului": "smochin",
    "smochina": "smochină",
    "smochine": "smochină",
    "smochinei": "smochină",
    "smochinele": "smochină",
    "smochinelor": "smochină",
    "smochingul": "smoching",
    "smochingului": "smoching",
    "smochinguri": "smoching",
    "smochingurile": "smoching",
    "smochingurilor": "smoching",
    "nemaismochinind": "smochini",
    "nemaismochinindu": "smochini",
    "nesmochinind": "smochini",
    "nesmochinindu": "smochini",
    "smochinea": "smochini",
    "smochineai": "smochini",
    "smochineam": "smochini",
    "smochinească": "smochini",
    "smochineați": "smochini",
    "smochineau": "smochini",
    "smochinesc": "smochini",
    "smochinește": "smochini",
    "smochinești": "smochini",
    "smochinii": "smochini",
    "smochinim": "smochini",
    "smochinind": "smochini",
    "smochinindu": "smochini",
    "smochiniră": "smochini",
    "smochinirăm": "smochini",
    "smochinirăți": "smochini",
    "smochinise": "smochini",
    "smochinisem": "smochini",
    "smochiniseră": "smochini",
    "smochiniserăm": "smochini",
    "smochiniserăți": "smochini",
    "smochiniseși": "smochini",
    "smochiniși": "smochini",
    "smochinit": "smochini",
    "smochiniți": "smochini",
    "smochinită": "smochinit",
    "smochinite": "smochinit",
    "smochiniți": "smochinit",
    "smochinuța": "smochinuță",
    "smochinuțe": "smochinuță",
    "smochinuței": "smochinuță",
    "smochinuțele": "smochinuță",
    "smochinuțelor": "smochinuță",
    "smogul": "smog",
    "smogului": "smog",
    "nemaismolind": "smoli",
    "nemaismolindu": "smoli",
    "nesmolind": "smoli",
    "nesmolindu": "smoli",
    "smolea": "smoli",
    "smoleai": "smoli",
    "smoleam": "smoli",
    "smolească": "smoli",
    "smoleați": "smoli",
    "smoleau": "smoli",
    "smolesc": "smoli",
    "smolește": "smoli",
    "smolești": "smoli",
    "smolii": "smoli",
    "smolim": "smoli",
    "smolind": "smoli",
    "smolindu": "smoli",
    "smoliră": "smoli",
    "smolirăm": "smoli",
    "smolirăți": "smoli",
    "smolise": "smoli",
    "smolisem": "smoli",
    "smoliseră": "smoli",
    "smoliserăm": "smoli",
    "smoliserăți": "smoli",
    "smoliseși": "smoli",
    "smoliși": "smoli",
    "smolit": "smoli",
    "smoliți": "smoli",
    "smolită": "smolit",
    "smolite": "smolit",
    "smoliți": "smolit",
    "nemaișmotrind": "șmotri",
    "nemaișmotrindu": "șmotri",
    "neșmotrind": "șmotri",
    "neșmotrindu": "șmotri",
    "șmotrea": "șmotri",
    "șmotreai": "șmotri",
    "șmotream": "șmotri",
    "șmotrească": "șmotri",
    "șmotreați": "șmotri",
    "șmotreau": "șmotri",
    "șmotresc": "șmotri",
    "șmotrește": "șmotri",
    "șmotrești": "șmotri",
    "șmotrii": "șmotri",
    "șmotrim": "șmotri",
    "șmotrind": "șmotri",
    "șmotrindu": "șmotri",
    "șmotriră": "șmotri",
    "șmotrirăm": "șmotri",
    "șmotrirăți": "șmotri",
    "șmotrise": "șmotri",
    "șmotrisem": "șmotri",
    "șmotriseră": "șmotri",
    "șmotriserăm": "șmotri",
    "șmotriserăți": "șmotri",
    "șmotriseși": "șmotri",
    "șmotriși": "șmotri",
    "șmotrit": "șmotri",
    "șmotriți": "șmotri",
    "șmotrită": "șmotrit",
    "șmotrite": "șmotrit",
    "șmotriți": "șmotrit",
    "nemaismucind": "smuci",
    "nemaismucindu": "smuci",
    "nesmucind": "smuci",
    "nesmucindu": "smuci",
    "smucea": "smuci",
    "smuceai": "smuci",
    "smuceam": "smuci",
    "smucească": "smuci",
    "smuceați": "smuci",
    "smuceau": "smuci",
    "smucesc": "smuci",
    "smucește": "smuci",
    "smucești": "smuci",
    "smucii": "smuci",
    "smucim": "smuci",
    "smucind": "smuci",
    "smucindu": "smuci",
    "smuciră": "smuci",
    "smucirăm": "smuci",
    "smucirăți": "smuci",
    "smucise": "smuci",
    "smucisem": "smuci",
    "smuciseră": "smuci",
    "smuciserăm": "smuci",
    "smuciserăți": "smuci",
    "smuciseși": "smuci",
    "smuciși": "smuci",
    "smucit": "smuci",
    "smuciți": "smuci",
    "smucita": "smucit",
    "smucită": "smucit",
    "smucite": "smucit",
    "smucitei": "smucit",
    "smucitele": "smucit",
    "smucitelor": "smucit",
    "smuciți": "smucit",
    "smuciții": "smucit",
    "smuciților": "smucit",
    "smucito": "smucit",
    "smucitul": "smucit",
    "smucitule": "smucit",
    "smucitului": "smucit",
    "smucitura": "smucitură",
    "smucituri": "smucitură",
    "smuciturii": "smucitură",
    "smuciturile": "smucitură",
    "smuciturilor": "smucitură",
    "smucituro": "smucitură",
    "nemaismulgând": "smulge",
    "nemaismulgându": "smulge",
    "nesmulgând": "smulge",
    "nesmulgându": "smulge",
    "smulg": "smulge",
    "smulgă": "smulge",
    "smulgând": "smulge",
    "smulgându": "smulge",
    "smulgea": "smulge",
    "smulgeai": "smulge",
    "smulgeam": "smulge",
    "smulgeați": "smulge",
    "smulgeau": "smulge",
    "smulgem": "smulge",
    "smulgeți": "smulge",
    "smulgi": "smulge",
    "smuls": "smulge",
    "smulse": "smulge",
    "smulsei": "smulge",
    "smulseră": "smulge",
    "smulserăm": "smulge",
    "smulserăți": "smulge",
    "smulsese": "smulge",
    "smulsesem": "smulge",
    "smulseseră": "smulge",
    "smulseserăm": "smulge",
    "smulseserăți": "smulge",
    "smulseseși": "smulge",
    "smulseși": "smulge",
    "smulgerea": "smulgere",
    "smulgereo": "smulgere",
    "smulgeri": "smulgere",
    "smulgerii": "smulgere",
    "smulgerile": "smulgere",
    "smulgerilor": "smulgere",
    "smulsă": "smuls",
    "smulse": "smuls",
    "smulși": "smuls",
    "șnapani": "șnapan",
    "șnapanii": "șnapan",
    "șnapanilor": "șnapan",
    "șnapanul": "șnapan",
    "șnapanului": "șnapan",
    "șnițele": "șnițel",
    "șnițelele": "șnițel",
    "șnițelelor": "șnițel",
    "șnițelul": "șnițel",
    "șnițelului": "șnițel",
    "snoaba": "snoabă",
    "snoabe": "snoabă",
    "snoabei": "snoabă",
    "snoabele": "snoabă",
    "snoabelor": "snoabă",
    "snoava": "snoavă",
    "snoave": "snoavă",
    "snoavei": "snoavă",
    "snoavele": "snoavă",
    "snoavelor": "snoavă",
    "snobi": "snob",
    "snobii": "snob",
    "snobilor": "snob",
    "snobul": "snob",
    "snobului": "snob",
    "snobismul": "snobism",
    "snobismului": "snobism",
    "snopi": "snop",
    "snopii": "snop",
    "snopilor": "snop",
    "snopul": "snop",
    "snopului": "snop",
    "nemaisnopind": "snopi",
    "nemaisnopindu": "snopi",
    "nesnopind": "snopi",
    "nesnopindu": "snopi",
    "snopea": "snopi",
    "snopeai": "snopi",
    "snopeam": "snopi",
    "snopească": "snopi",
    "snopeați": "snopi",
    "snopeau": "snopi",
    "snopesc": "snopi",
    "snopește": "snopi",
    "snopești": "snopi",
    "snopii": "snopi",
    "snopim": "snopi",
    "snopind": "snopi",
    "snopindu": "snopi",
    "snopiră": "snopi",
    "snopirăm": "snopi",
    "snopirăți": "snopi",
    "snopise": "snopi",
    "snopisem": "snopi",
    "snopiseră": "snopi",
    "snopiserăm": "snopi",
    "snopiserăți": "snopi",
    "snopiseși": "snopi",
    "snopiși": "snopi",
    "snopit": "snopi",
    "snopiți": "snopi",
    "snopită": "snopit",
    "snopite": "snopit",
    "snopiți": "snopit",
    "șnurul": "șnur",
    "șnurului": "șnur",
    "șnururi": "șnur",
    "șnururile": "șnur",
    "șnururilor": "șnur",
    "nemaișnuruind": "șnurui",
    "nemaișnuruindu": "șnurui",
    "neșnuruind": "șnurui",
    "neșnuruindu": "șnurui",
    "șnuruia": "șnurui",
    "șnuruiai": "șnurui",
    "șnuruiam": "șnurui",
    "șnuruiască": "șnurui",
    "șnuruiați": "șnurui",
    "șnuruiau": "șnurui",
    "șnuruiesc": "șnurui",
    "șnuruiește": "șnurui",
    "șnuruiești": "șnurui",
    "șnuruii": "șnurui",
    "șnuruim": "șnurui",
    "șnuruind": "șnurui",
    "șnuruindu": "șnurui",
    "șnuruiră": "șnurui",
    "șnuruirăm": "șnurui",
    "șnuruirăți": "șnurui",
    "șnuruise": "șnurui",
    "șnuruisem": "șnurui",
    "șnuruiseră": "șnurui",
    "șnuruiserăm": "șnurui",
    "șnuruiserăți": "șnurui",
    "șnuruiseși": "șnurui",
    "șnuruiși": "șnurui",
    "șnuruit": "șnurui",
    "șnuruiți": "șnurui",
    "șnuruirea": "șnuruire",
    "șnuruireo": "șnuruire",
    "șnuruiri": "șnuruire",
    "șnuruirii": "șnuruire",
    "șnuruirile": "șnuruire",
    "șnuruirilor": "șnuruire",
    "șnuruita": "șnuruit",
    "șnuruită": "șnuruit",
    "șnuruite": "șnuruit",
    "șnuruitei": "șnuruit",
    "șnuruitele": "șnuruit",
    "șnuruitelor": "șnuruit",
    "șnuruiți": "șnuruit",
    "șnuruiții": "șnuruit",
    "șnuruiților": "șnuruit",
    "șnuruito": "șnuruit",
    "șnuruitul": "șnuruit",
    "șnuruitule": "șnuruit",
    "șnuruitului": "șnuruit",
    "soacra": "soacră",
    "soacre": "soacră",
    "soacrei": "soacră",
    "soacrele": "soacră",
    "soacrelor": "soacră",
    "soacra-mare": "soacră-mare",
    "soacrei-mari": "soacră-mare",
    "soacrele-mari": "soacră-mare",
    "soacrelor-mari": "soacră-mare",
    "soacre-mari": "soacră-mare",
    "șoalda": "șoaldă",
    "șoalde": "șoaldă",
    "șoaldei": "șoaldă",
    "șoaldele": "șoaldă",
    "șoaldelor": "șoaldă",
    "șoapta": "șoaptă",
    "șoapte": "șoaptă",
    "șoaptei": "șoaptă",
    "șoaptele": "șoaptă",
    "șoaptelor": "șoaptă",
    "soarele": "soare",
    "soarelui": "soare",
    "sori": "soare",
    "sorii": "soare",
    "sorilor": "soare",
    "șoarecele": "șoarece",
    "șoarecelui": "șoarece",
    "șoareci": "șoarece",
    "șoarecii": "șoarece",
    "șoarecilor": "șoarece",
    "soarta": "soartă",
    "soartei": "soartă",
    "sorți": "soartă",
    "sorții": "soartă",
    "sorțile": "soartă",
    "sorților": "soartă",
    "soața": "soață",
    "soațe": "soață",
    "soaței": "soață",
    "soațele": "soață",
    "soațelor": "soață",
    "soba": "sobă",
    "sobe": "sobă",
    "sobei": "sobă",
    "sobele": "sobă",
    "sobelor": "sobă",
    "sobari": "sobar",
    "sobarii": "sobar",
    "sobarilor": "sobar",
    "sobarul": "sobar",
    "sobarului": "sobar",
    "soboli": "sobol",
    "sobolii": "sobol",
    "sobolilor": "sobol",
    "sobolul": "sobol",
    "sobolului": "sobol",
    "șobolani": "șobolan",
    "șobolanii": "șobolan",
    "șobolanilor": "șobolan",
    "șobolanul": "șobolan",
    "șobolanului": "șobolan",
    "soboare": "sobor",
    "soboarele": "sobor",
    "soboarelor": "sobor",
    "soborul": "sobor",
    "soborului": "sobor",
    "soborniceasca": "sobornicesc",
    "sobornicească": "sobornicesc",
    "sobornicescul": "sobornicesc",
    "sobornicescului": "sobornicesc",
    "sobornicești": "sobornicesc",
    "soborniceștii": "sobornicesc",
    "soborniceștile": "sobornicesc",
    "soborniceștilor": "sobornicesc",
    "sobrietatea": "sobrietate",
    "sobrietăți": "sobrietate",
    "sobrietății": "sobrietate",
    "sobrietățile": "sobrietate",
    "sobrietăților": "sobrietate",
    "sobra": "sobru",
    "sobră": "sobru",
    "sobre": "sobru",
    "sobrei": "sobru",
    "sobrele": "sobru",
    "sobrelor": "sobru",
    "sobri": "sobru",
    "sobrii": "sobru",
    "sobrilor": "sobru",
    "sobrul": "sobru",
    "sobrului": "sobru",
    "soci": "soc",
    "socii": "soc",
    "socilor": "soc",
    "socul": "soc",
    "socului": "soc",
    "șocul": "șoc",
    "șocului": "șoc",
    "șocuri": "șoc",
    "șocurile": "șoc",
    "șocurilor": "șoc",
    "nemaișocând": "șoca",
    "nemaișocându": "șoca",
    "neșocând": "șoca",
    "neșocându": "șoca",
    "șocă": "șoca",
    "șocai": "șoca",
    "șocam": "șoca",
    "șocăm": "șoca",
    "șocând": "șoca",
    "șocându": "șoca",
    "șocară": "șoca",
    "șocarăm": "șoca",
    "șocarăți": "șoca",
    "șocase": "șoca",
    "șocasem": "șoca",
    "șocaseră": "șoca",
    "șocaserăm": "șoca",
    "șocaserăți": "șoca",
    "șocaseși": "șoca",
    "șocași": "șoca",
    "șocat": "șoca",
    "șocați": "șoca",
    "șocau": "șoca",
    "șochează": "șoca",
    "șochez": "șoca",
    "șocheze": "șoca",
    "șochezi": "șoca",
    "șocantă": "șocant",
    "șocată": "șocat",
    "șocate": "șocat",
    "șocați": "șocat",
    "sociabila": "sociabil",
    "sociabilă": "sociabil",
    "sociabile": "sociabil",
    "sociabilei": "sociabil",
    "sociabilele": "sociabil",
    "sociabilelor": "sociabil",
    "sociabili": "sociabil",
    "sociabilii": "sociabil",
    "sociabililor": "sociabil",
    "sociabilul": "sociabil",
    "sociabilului": "sociabil",
    "sociabilitatea": "sociabilitate",
    "sociabilități": "sociabilitate",
    "sociabilității": "sociabilitate",
    "sociabilitățile": "sociabilitate",
    "sociabilităților": "sociabilitate",
    "sociala": "social",
    "socială": "social",
    "sociale": "social",
    "socialei": "social",
    "socialele": "social",
    "socialelor": "social",
    "sociali": "social",
    "socialii": "social",
    "socialilor": "social",
    "socialul": "social",
    "socialului": "social",
    "social-democrați": "social-democrat",
    "social-democrații": "social-democrat",
    "social-democraților": "social-democrat",
    "social-democratul": "social-democrat",
    "social-democratului": "social-democrat",
    "social-democrata": "social-democrată",
    "social-democrate": "social-democrată",
    "social-democratei": "social-democrată",
    "social-democratele": "social-democrată",
    "social-democratelor": "social-democrată",
    "social-democrația": "social-democrație",
    "social-democrației": "social-democrație",
    "social-democrații": "social-democrație",
    "social-democrațiile": "social-democrație",
    "social-democrațiilor": "social-democrație",
    "social-democratismul": "social-democratism",
    "social-democratismului": "social-democratism",
    "socialismul": "socialism",
    "socialismului": "socialism",
    "socialista": "socialist",
    "socialistă": "socialist",
    "socialiste": "socialist",
    "socialistei": "socialist",
    "socialistele": "socialist",
    "socialistelor": "socialist",
    "socialiști": "socialist",
    "socialiștii": "socialist",
    "socialiștilor": "socialist",
    "socialistul": "socialist",
    "socialistului": "socialist",
    "socialista": "socialistă",
    "socialiste": "socialistă",
    "socialistei": "socialistă",
    "socialistele": "socialistă",
    "socialistelor": "socialistă",
    "nemaisocializând": "socializa",
    "nemaisocializându": "socializa",
    "nesocializând": "socializa",
    "nesocializându": "socializa",
    "socializă": "socializa",
    "socializai": "socializa",
    "socializam": "socializa",
    "socializăm": "socializa",
    "socializând": "socializa",
    "socializându": "socializa",
    "socializară": "socializa",
    "socializarăm": "socializa",
    "socializarăți": "socializa",
    "socializase": "socializa",
    "socializasem": "socializa",
    "socializaseră": "socializa",
    "socializaserăm": "socializa",
    "socializaserăți": "socializa",
    "socializaseși": "socializa",
    "socializași": "socializa",
    "socializat": "socializa",
    "socializați": "socializa",
    "socializau": "socializa",
    "socializează": "socializa",
    "socializez": "socializa",
    "socializeze": "socializa",
    "socializezi": "socializa",
    "socializată": "socializat",
    "socializate": "socializat",
    "socializați": "socializat",
    "sociativa": "sociativ",
    "sociativă": "sociativ",
    "sociative": "sociativ",
    "sociativei": "sociativ",
    "sociativele": "sociativ",
    "sociativelor": "sociativ",
    "sociativi": "sociativ",
    "sociativii": "sociativ",
    "sociativilor": "sociativ",
    "sociativul": "sociativ",
    "sociativului": "sociativ",
    "societatea": "societate",
    "societăți": "societate",
    "societății": "societate",
    "societățile": "societate",
    "societăților": "societate",
    "S.C.": "Societate_Comercială",
    "SC": "Societate_Comercială",
    "S.R.L.": "Societate_cu_Răspundere_Limitată",
    "SRL": "Societate_cu_Răspundere_Limitată",
    "SVM": "Societate_de_Valori_Mobiliare",
    "S.M.": "Societate_Mixtă",
    "S.A.": "Societate_pe_Acțiuni",
    "SA": "Societate_pe_Acțiuni",
    "sociologi": "sociolog",
    "sociologii": "sociolog",
    "sociologilor": "sociolog",
    "sociologul": "sociolog",
    "sociologului": "sociolog",
    "sociologica": "sociologic",
    "sociologică": "sociologic",
    "sociologice": "sociologic",
    "sociologicei": "sociologic",
    "sociologicele": "sociologic",
    "sociologicelor": "sociologic",
    "sociologici": "sociologic",
    "sociologicii": "sociologic",
    "sociologicilor": "sociologic",
    "sociologicul": "sociologic",
    "sociologicului": "sociologic",
    "sociologia": "sociologie",
    "sociologiei": "sociologie",
    "sociologii": "sociologie",
    "sociologiile": "sociologie",
    "sociologiilor": "sociologie",
    "soclul": "soclu",
    "soclului": "soclu",
    "socluri": "soclu",
    "soclurile": "soclu",
    "soclurilor": "soclu",
    "socoteala": "socoteală",
    "socoteli": "socoteală",
    "socotelii": "socoteală",
    "socotelile": "socoteală",
    "socotelilor": "socoteală",
    "nemaisocotind": "socoti",
    "nemaisocotindu": "socoti",
    "nesocotind": "socoti",
    "nesocotindu": "socoti",
    "socoate": "socoti",
    "socot": "socoti",
    "socotea": "socoti",
    "socoteai": "socoti",
    "socoteam": "socoti",
    "socotească": "socoti",
    "socoteați": "socoti",
    "socoteau": "socoti",
    "socotesc": "socoti",
    "socotește": "socoti",
    "socotești": "socoti",
    "socoți": "socoti",
    "socotii": "socoti",
    "socotim": "socoti",
    "socotind": "socoti",
    "socotindu": "socoti",
    "socotiră": "socoti",
    "socotirăm": "socoti",
    "socotirăți": "socoti",
    "socotise": "socoti",
    "socotisem": "socoti",
    "socotiseră": "socoti",
    "socotiserăm": "socoti",
    "socotiserăți": "socoti",
    "socotiseși": "socoti",
    "socotiși": "socoti",
    "socotit": "socoti",
    "socotiți": "socoti",
    "socotința": "socotință",
    "socotințe": "socotință",
    "socotinței": "socotință",
    "socotințele": "socotință",
    "socotințelor": "socotință",
    "socotirea": "socotire",
    "socotireo": "socotire",
    "socotiri": "socotire",
    "socotirii": "socotire",
    "socotirile": "socotire",
    "socotirilor": "socotire",
    "socotita": "socotit",
    "socotită": "socotit",
    "socotite": "socotit",
    "socotitei": "socotit",
    "socotitele": "socotit",
    "socotitelor": "socotit",
    "socotiți": "socotit",
    "socotiții": "socotit",
    "socotiților": "socotit",
    "socotito": "socotit",
    "socotitul": "socotit",
    "socotitule": "socotit",
    "socotitului": "socotit",
    "socotitoarea": "socotitoare",
    "socotitoarei": "socotitoare",
    "socotitoarele": "socotitoare",
    "socotitoarelor": "socotitoare",
    "socotitorul": "socotitor",
    "socotitorule": "socotitor",
    "socotitorului": "socotitor",
    "socri": "socru",
    "socrii": "socru",
    "socrilor": "socru",
    "socrul": "socru",
    "socrului": "socru",
    "socrii-mari": "socru-mare",
    "socrilor-mari": "socru-mare",
    "socri-mari": "socru-mare",
    "socrul-mare": "socru-mare",
    "socrului-mare": "socru-mare",
    "șoada": "șod",
    "șoadă": "șod",
    "șoade": "șod",
    "șoadei": "șod",
    "șoadele": "șod",
    "șoadelor": "șod",
    "șodul": "șod",
    "șodului": "șod",
    "șozi": "șod",
    "șozii": "șod",
    "șozilor": "șod",
    "soda": "sodă",
    "sode": "sodă",
    "sodei": "sodă",
    "Na": "sodiu",
    "sodiul": "sodiu",
    "sodiului": "sodiu",
    "nemaisodomind": "sodomi",
    "nemaisodomindu": "sodomi",
    "nesodomind": "sodomi",
    "nesodomindu": "sodomi",
    "sodomea": "sodomi",
    "sodomeai": "sodomi",
    "sodomeam": "sodomi",
    "sodomească": "sodomi",
    "sodomeați": "sodomi",
    "sodomeau": "sodomi",
    "sodomesc": "sodomi",
    "sodomește": "sodomi",
    "sodomești": "sodomi",
    "sodomii": "sodomi",
    "sodomim": "sodomi",
    "sodomind": "sodomi",
    "sodomindu": "sodomi",
    "sodomiră": "sodomi",
    "sodomirăm": "sodomi",
    "sodomirăți": "sodomi",
    "sodomise": "sodomi",
    "sodomisem": "sodomi",
    "sodomiseră": "sodomi",
    "sodomiserăm": "sodomi",
    "sodomiserăți": "sodomi",
    "sodomiseși": "sodomi",
    "sodomiși": "sodomi",
    "sodomit": "sodomi",
    "sodomiți": "sodomi",
    "sodomea": "sodomie",
    "sodomia": "sodomie",
    "sodomiei": "sodomie",
    "sodomii": "sodomie",
    "sodomiile": "sodomie",
    "sodomiilor": "sodomie",
    "sodomită": "sodomit",
    "sodomite": "sodomit",
    "sodomiți": "sodomit",
    "sofale": "sofa",
    "sofalei": "sofa",
    "sofalele": "sofa",
    "sofalelor": "sofa",
    "sofaua": "sofa",
    "nemaișofând": "șofa",
    "nemaișofându": "șofa",
    "neșofând": "șofa",
    "neșofându": "șofa",
    "șofă": "șofa",
    "șofai": "șofa",
    "șofam": "șofa",
    "șofăm": "șofa",
    "șofând": "șofa",
    "șofându": "șofa",
    "șofară": "șofa",
    "șofarăm": "șofa",
    "șofarăți": "șofa",
    "șofase": "șofa",
    "șofasem": "șofa",
    "șofaseră": "șofa",
    "șofaserăm": "șofa",
    "șofaserăți": "șofa",
    "șofaseși": "șofa",
    "șofași": "șofa",
    "șofat": "șofa",
    "șofați": "șofa",
    "șofau": "șofa",
    "șofează": "șofa",
    "șofez": "șofa",
    "șofeze": "șofa",
    "șofezi": "șofa",
    "șofată": "șofat",
    "șofate": "șofat",
    "șofați": "șofat",
    "șoferi": "șofer",
    "șoferii": "șofer",
    "șoferilor": "șofer",
    "șoferul": "șofer",
    "șoferului": "șofer",
    "Sofiei": "Sofia",
    "sofisme": "sofism",
    "sofismele": "sofism",
    "sofismelor": "sofism",
    "sofismul": "sofism",
    "sofismului": "sofism",
    "sofiști": "sofist",
    "sofiștii": "sofist",
    "sofiștilor": "sofist",
    "sofistul": "sofist",
    "sofistului": "sofist",
    "sofistica": "sofistic",
    "sofistică": "sofistic",
    "sofistice": "sofistic",
    "sofisticei": "sofistic",
    "sofisticele": "sofistic",
    "sofisticelor": "sofistic",
    "sofistici": "sofistic",
    "sofisticii": "sofistic",
    "sofisticilor": "sofistic",
    "sofisticul": "sofistic",
    "sofisticului": "sofistic",
    "sofita": "sofită",
    "sofite": "sofită",
    "sofitei": "sofită",
    "sofitele": "sofită",
    "sofitelor": "sofită",
    "șofranelor": "șofran",
    "șofrani": "șofran",
    "șofranii": "șofran",
    "șofranilor": "șofran",
    "șofranul": "șofran",
    "șofranului": "șofran",
    "soiul": "soi",
    "soiului": "soi",
    "soiuri": "soi",
    "soiurile": "soi",
    "soiurilor": "soi",
    "soiei": "soia",
    "șoimi": "șoim",
    "șoimii": "șoim",
    "șoimilor": "șoim",
    "șoimul": "șoim",
    "șoimului": "șoim",
    "șoimani": "șoiman",
    "șoimanii": "șoiman",
    "șoimanilor": "șoiman",
    "șoimanul": "șoiman",
    "șoimanului": "șoiman",
    "soioasa": "soios",
    "soioasă": "soios",
    "soioase": "soios",
    "soioasei": "soios",
    "soioasele": "soios",
    "soioaselor": "soios",
    "soioși": "soios",
    "soioșii": "soios",
    "soioșilor": "soios",
    "soiosul": "soios",
    "soiosului": "soios",
    "soli": "sol",
    "solii": "sol",
    "solilor": "sol",
    "solul": "sol",
    "solului": "sol",
    "soluri": "sol",
    "solurile": "sol",
    "solurilor": "sol",
    "solara": "solar",
    "solară": "solar",
    "solare": "solar",
    "solarei": "solar",
    "solarele": "solar",
    "solarelor": "solar",
    "solari": "solar",
    "solarii": "solar",
    "solarilor": "solar",
    "solarul": "solar",
    "solarului": "solar",
    "solarii": "solariu",
    "solariile": "solariu",
    "solariilor": "solariu",
    "solariul": "solariu",
    "solariului": "solariu",
    "solbancul": "solbanc",
    "solbancului": "solbanc",
    "solbancuri": "solbanc",
    "solbancurile": "solbanc",
    "solbancurilor": "solbanc",
    "soldul": "sold",
    "soldului": "sold",
    "solduri": "sold",
    "soldurile": "sold",
    "soldurilor": "sold",
    "șoldul": "șold",
    "șoldului": "șold",
    "șolduri": "șold",
    "șoldurile": "șold",
    "șoldurilor": "șold",
    "nemaisoldând": "solda",
    "nemaisoldându": "solda",
    "nesoldând": "solda",
    "nesoldându": "solda",
    "soldă": "solda",
    "soldai": "solda",
    "soldam": "solda",
    "soldăm": "solda",
    "soldând": "solda",
    "soldându": "solda",
    "soldară": "solda",
    "soldarăm": "solda",
    "soldarăți": "solda",
    "soldase": "solda",
    "soldasem": "solda",
    "soldaseră": "solda",
    "soldaserăm": "solda",
    "soldaserăți": "solda",
    "soldaseși": "solda",
    "soldași": "solda",
    "soldat": "solda",
    "soldați": "solda",
    "soldau": "solda",
    "soldează": "solda",
    "soldez": "solda",
    "soldeze": "solda",
    "soldezi": "solda",
    "solda": "soldă",
    "solde": "soldă",
    "soldei": "soldă",
    "soldele": "soldă",
    "soldelor": "soldă",
    "șoldani": "șoldan",
    "șoldanii": "șoldan",
    "șoldanilor": "șoldan",
    "șoldanul": "șoldan",
    "șoldanului": "șoldan",
    "sold.": "soldat",
    "soldată": "soldat",
    "soldate": "soldat",
    "soldați": "soldat",
    "soldații": "soldat",
    "soldaților": "soldat",
    "soldatul": "soldat",
    "soldatului": "soldat",
    "soldățimea": "soldățime",
    "soldățimi": "soldățime",
    "soldățimii": "soldățime",
    "soldățimile": "soldățime",
    "soldățimilor": "soldățime",
    "solecisme": "solecism",
    "solecismele": "solecism",
    "solecismelor": "solecism",
    "solecismul": "solecism",
    "solecismului": "solecism",
    "solemna": "solemn",
    "solemnă": "solemn",
    "solemne": "solemn",
    "solemnei": "solemn",
    "solemnele": "solemn",
    "solemnelor": "solemn",
    "solemni": "solemn",
    "solemnii": "solemn",
    "solemnilor": "solemn",
    "solemnul": "solemn",
    "solemnului": "solemn",
    "solemnitatea": "solemnitate",
    "solemnități": "solemnitate",
    "solemnității": "solemnitate",
    "solemnitățile": "solemnitate",
    "solemnităților": "solemnitate",
    "solenoidul": "solenoid",
    "solenoidului": "solenoid",
    "solenoizi": "solenoid",
    "solenoizii": "solenoid",
    "solenoizilor": "solenoid",
    "nemaisolfegiind": "solfegia",
    "nemaisolfegiindu": "solfegia",
    "nesolfegiind": "solfegia",
    "nesolfegiindu": "solfegia",
    "solfegiai": "solfegia",
    "solfegiam": "solfegia",
    "solfegiară": "solfegia",
    "solfegiarăm": "solfegia",
    "solfegiarăți": "solfegia",
    "solfegiase": "solfegia",
    "solfegiasem": "solfegia",
    "solfegiaseră": "solfegia",
    "solfegiaserăm": "solfegia",
    "solfegiaserăți": "solfegia",
    "solfegiaseși": "solfegia",
    "solfegiași": "solfegia",
    "solfegiat": "solfegia",
    "solfegiați": "solfegia",
    "solfegiau": "solfegia",
    "solfegiază": "solfegia",
    "solfegie": "solfegia",
    "solfegiem": "solfegia",
    "solfegiez": "solfegia",
    "solfegieze": "solfegia",
    "solfegiezi": "solfegia",
    "solfegiind": "solfegia",
    "solfegiindu": "solfegia",
    "solfegiată": "solfegiat",
    "solfegiate": "solfegiat",
    "solfegiați": "solfegiat",
    "solfegii": "solfegiu",
    "solfegiile": "solfegiu",
    "solfegiilor": "solfegiu",
    "solfegiul": "solfegiu",
    "solfegiului": "solfegiu",
    "nemaisolicitând": "solicita",
    "nemaisolicitându": "solicita",
    "nesolicitând": "solicita",
    "nesolicitându": "solicita",
    "solicit": "solicita",
    "solicită": "solicita",
    "solicitai": "solicita",
    "solicitam": "solicita",
    "solicităm": "solicita",
    "solicitând": "solicita",
    "solicitându": "solicita",
    "solicitară": "solicita",
    "solicitarăm": "solicita",
    "solicitarăți": "solicita",
    "solicitase": "solicita",
    "solicitasem": "solicita",
    "solicitaseră": "solicita",
    "solicitaserăm": "solicita",
    "solicitaserăți": "solicita",
    "solicitaseși": "solicita",
    "solicitași": "solicita",
    "solicitat": "solicita",
    "solicitați": "solicita",
    "solicitau": "solicita",
    "solicite": "solicita",
    "soliciți": "solicita",
    "solicitanți": "solicitant",
    "solicitanții": "solicitant",
    "solicitanților": "solicitant",
    "solicitantul": "solicitant",
    "solicitantule": "solicitant",
    "solicitantului": "solicitant",
    "solicitanta": "solicitantă",
    "solicitante": "solicitantă",
    "solicitantei": "solicitantă",
    "solicitantele": "solicitantă",
    "solicitantelor": "solicitantă",
    "solicitanto": "solicitantă",
    "solicitarea": "solicitare",
    "solicitareo": "solicitare",
    "solicitări": "solicitare",
    "solicitării": "solicitare",
    "solicitările": "solicitare",
    "solicitărilor": "solicitare",
    "solicitată": "solicitat",
    "solicitate": "solicitat",
    "solicitați": "solicitat",
    "solicitudinea": "solicitudine",
    "solicitudini": "solicitudine",
    "solicitudinii": "solicitudine",
    "solicitudinile": "solicitudine",
    "solicitudinilor": "solicitudine",
    "solida": "solid",
    "solidă": "solid",
    "solide": "solid",
    "solidei": "solid",
    "solidele": "solid",
    "solidelor": "solid",
    "solidul": "solid",
    "solidului": "solid",
    "solizi": "solid",
    "solizii": "solid",
    "solizilor": "solid",
    "solidara": "solidar",
    "solidară": "solidar",
    "solidare": "solidar",
    "solidarei": "solidar",
    "solidarele": "solidar",
    "solidarelor": "solidar",
    "solidari": "solidar",
    "solidarii": "solidar",
    "solidarilor": "solidar",
    "solidarul": "solidar",
    "solidarului": "solidar",
    "solidaritatea": "solidaritate",
    "solidarități": "solidaritate",
    "solidarității": "solidaritate",
    "solidaritățile": "solidaritate",
    "solidarităților": "solidaritate",
    "nemaisolidarizând": "solidariza",
    "nemaisolidarizându": "solidariza",
    "nesolidarizând": "solidariza",
    "nesolidarizându": "solidariza",
    "solidariză": "solidariza",
    "solidarizai": "solidariza",
    "solidarizam": "solidariza",
    "solidarizăm": "solidariza",
    "solidarizând": "solidariza",
    "solidarizându": "solidariza",
    "solidarizară": "solidariza",
    "solidarizarăm": "solidariza",
    "solidarizarăți": "solidariza",
    "solidarizase": "solidariza",
    "solidarizasem": "solidariza",
    "solidarizaseră": "solidariza",
    "solidarizaserăm": "solidariza",
    "solidarizaserăți": "solidariza",
    "solidarizaseși": "solidariza",
    "solidarizași": "solidariza",
    "solidarizat": "solidariza",
    "solidarizați": "solidariza",
    "solidarizau": "solidariza",
    "solidarizează": "solidariza",
    "solidarizez": "solidariza",
    "solidarizeze": "solidariza",
    "solidarizezi": "solidariza",
    "solidarizată": "solidarizat",
    "solidarizate": "solidarizat",
    "solidarizați": "solidarizat",
    "nemaisolidificând": "solidifica",
    "nemaisolidificându": "solidifica",
    "nesolidificând": "solidifica",
    "nesolidificându": "solidifica",
    "solidific": "solidifica",
    "solidifică": "solidifica",
    "solidificai": "solidifica",
    "solidificam": "solidifica",
    "solidificăm": "solidifica",
    "solidificând": "solidifica",
    "solidificându": "solidifica",
    "solidificară": "solidifica",
    "solidificarăm": "solidifica",
    "solidificarăți": "solidifica",
    "solidificase": "solidifica",
    "solidificasem": "solidifica",
    "solidificaseră": "solidifica",
    "solidificaserăm": "solidifica",
    "solidificaserăți": "solidifica",
    "solidificaseși": "solidifica",
    "solidificași": "solidifica",
    "solidificat": "solidifica",
    "solidificați": "solidifica",
    "solidificau": "solidifica",
    "solidifice": "solidifica",
    "solidifici": "solidifica",
    "solidificată": "solidificat",
    "solidificate": "solidificat",
    "solidificați": "solidificat",
    "soliditatea": "soliditate",
    "solidități": "soliditate",
    "solidității": "soliditate",
    "soliditățile": "soliditate",
    "solidităților": "soliditate",
    "solia": "solie",
    "soliei": "solie",
    "solii": "solie",
    "soliile": "solie",
    "soliilor": "solie",
    "solipedul": "soliped",
    "solipedului": "soliped",
    "solipezi": "soliped",
    "solipezii": "soliped",
    "solipezilor": "soliped",
    "solipsismul": "solipsism",
    "solipsismului": "solipsism",
    "solista": "solist",
    "solistă": "solist",
    "soliste": "solist",
    "solistei": "solist",
    "solistele": "solist",
    "solistelor": "solist",
    "soliști": "solist",
    "soliștii": "solist",
    "soliștilor": "solist",
    "solistul": "solist",
    "solistului": "solist",
    "solista": "solistă",
    "soliste": "solistă",
    "solistei": "solistă",
    "solistele": "solistă",
    "solistelor": "solistă",
    "solitara": "solitar",
    "solitară": "solitar",
    "solitare": "solitar",
    "solitarei": "solitar",
    "solitarele": "solitar",
    "solitarelor": "solitar",
    "solitari": "solitar",
    "solitarii": "solitar",
    "solitarilor": "solitar",
    "solitarul": "solitar",
    "solitarului": "solitar",
    "solitudinea": "solitudine",
    "solitudini": "solitudine",
    "solitudinii": "solitudine",
    "solitudinile": "solitudine",
    "solitudinilor": "solitudine",
    "solnița": "solniță",
    "solnițe": "solniță",
    "solniței": "solniță",
    "solnițele": "solniță",
    "solnițelor": "solniță",
    "solomonari": "solomonar",
    "solomonarii": "solomonar",
    "solomonarilor": "solomonar",
    "solomonarul": "solomonar",
    "solomonarului": "solomonar",
    "solstiții": "solstițiu",
    "solstițiile": "solstițiu",
    "solstițiilor": "solstițiu",
    "solstițiul": "solstițiu",
    "solstițiului": "solstițiu",
    "șolticăria": "șolticărie",
    "șolticăriei": "șolticărie",
    "șolticării": "șolticărie",
    "șolticăriile": "șolticărie",
    "șolticăriilor": "șolticărie",
    "șoltuzi": "șoltuz",
    "șoltuzii": "șoltuz",
    "șoltuzilor": "șoltuz",
    "șoltuzul": "șoltuz",
    "șoltuzului": "șoltuz",
    "solubila": "solubil",
    "solubilă": "solubil",
    "solubile": "solubil",
    "solubilei": "solubil",
    "solubilele": "solubil",
    "solubilelor": "solubil",
    "solubili": "solubil",
    "solubilii": "solubil",
    "solubililor": "solubil",
    "solubilul": "solubil",
    "solubilului": "solubil",
    "solubilitatea": "solubilitate",
    "solubilități": "solubilitate",
    "solubilității": "solubilitate",
    "solubilitățile": "solubilitate",
    "solubilităților": "solubilitate",
    "nemaisolubilizând": "solubiliza",
    "nemaisolubilizându": "solubiliza",
    "nesolubilizând": "solubiliza",
    "nesolubilizându": "solubiliza",
    "solubiliză": "solubiliza",
    "solubilizai": "solubiliza",
    "solubilizam": "solubiliza",
    "solubilizăm": "solubiliza",
    "solubilizând": "solubiliza",
    "solubilizându": "solubiliza",
    "solubilizară": "solubiliza",
    "solubilizarăm": "solubiliza",
    "solubilizarăți": "solubiliza",
    "solubilizase": "solubiliza",
    "solubilizasem": "solubiliza",
    "solubilizaseră": "solubiliza",
    "solubilizaserăm": "solubiliza",
    "solubilizaserăți": "solubiliza",
    "solubilizaseși": "solubiliza",
    "solubilizași": "solubiliza",
    "solubilizat": "solubiliza",
    "solubilizați": "solubiliza",
    "solubilizau": "solubiliza",
    "solubilizează": "solubiliza",
    "solubilizez": "solubiliza",
    "solubilizeze": "solubiliza",
    "solubilizezi": "solubiliza",
    "solubilizată": "solubilizat",
    "solubilizate": "solubilizat",
    "solubilizați": "solubilizat",
    "soluția": "soluție",
    "soluției": "soluție",
    "soluții": "soluție",
    "soluțiile": "soluție",
    "soluțiilor": "soluție",
    "nemaisoluționând": "soluționa",
    "nemaisoluționându": "soluționa",
    "nesoluționând": "soluționa",
    "nesoluționându": "soluționa",
    "soluționă": "soluționa",
    "soluționai": "soluționa",
    "soluționam": "soluționa",
    "soluționăm": "soluționa",
    "soluționând": "soluționa",
    "soluționându": "soluționa",
    "soluționară": "soluționa",
    "soluționarăm": "soluționa",
    "soluționarăți": "soluționa",
    "soluționase": "soluționa",
    "soluționasem": "soluționa",
    "soluționaseră": "soluționa",
    "soluționaserăm": "soluționa",
    "soluționaserăți": "soluționa",
    "soluționaseși": "soluționa",
    "soluționași": "soluționa",
    "soluționat": "soluționa",
    "soluționați": "soluționa",
    "soluționau": "soluționa",
    "soluționează": "soluționa",
    "soluționez": "soluționa",
    "soluționeze": "soluționa",
    "soluționezi": "soluționa",
    "soluționarea": "soluționare",
    "soluționareo": "soluționare",
    "soluționări": "soluționare",
    "soluționării": "soluționare",
    "soluționările": "soluționare",
    "soluționărilor": "soluționare",
    "soluționată": "soluționat",
    "soluționate": "soluționat",
    "soluționați": "soluționat",
    "solvabila": "solvabil",
    "solvabilă": "solvabil",
    "solvabile": "solvabil",
    "solvabilei": "solvabil",
    "solvabilele": "solvabil",
    "solvabilelor": "solvabil",
    "solvabili": "solvabil",
    "solvabilii": "solvabil",
    "solvabililor": "solvabil",
    "solvabilul": "solvabil",
    "solvabilului": "solvabil",
    "solvabilitatea": "solvabilitate",
    "solvabilități": "solvabilitate",
    "solvabilității": "solvabilitate",
    "solvabilitățile": "solvabilitate",
    "solvabilităților": "solvabilitate",
    "solvenți": "solvent",
    "solvenții": "solvent",
    "solvenților": "solvent",
    "solventul": "solvent",
    "solventului": "solvent",
    "nemaisolvind": "solvi",
    "nemaisolvindu": "solvi",
    "nesolvind": "solvi",
    "nesolvindu": "solvi",
    "solv": "solvi",
    "solvă": "solvi",
    "solve": "solvi",
    "solvea": "solvi",
    "solveai": "solvi",
    "solveam": "solvi",
    "solveați": "solvi",
    "solveau": "solvi",
    "solvii": "solvi",
    "solvim": "solvi",
    "solvind": "solvi",
    "solvindu": "solvi",
    "solviră": "solvi",
    "solvirăm": "solvi",
    "solvirăți": "solvi",
    "solvise": "solvi",
    "solvisem": "solvi",
    "solviseră": "solvi",
    "solviserăm": "solvi",
    "solviserăți": "solvi",
    "solviseși": "solvi",
    "solviși": "solvi",
    "solvit": "solvi",
    "solviți": "solvi",
    "solvită": "solvit",
    "solvite": "solvit",
    "solviți": "solvit",
    "solzi": "solz",
    "solzii": "solz",
    "solzilor": "solz",
    "solzul": "solz",
    "solzului": "solz",
    "solzoasa": "solzos",
    "solzoasă": "solzos",
    "solzoase": "solzos",
    "solzoasei": "solzos",
    "solzoasele": "solzos",
    "solzoaselor": "solzos",
    "solzoși": "solzos",
    "solzoșii": "solzos",
    "solzoșilor": "solzos",
    "solzosul": "solzos",
    "solzosului": "solzos",
    "nemaisomând": "soma",
    "nemaisomându": "soma",
    "nesomând": "soma",
    "nesomându": "soma",
    "somă": "soma",
    "somai": "soma",
    "somam": "soma",
    "somăm": "soma",
    "somând": "soma",
    "somându": "soma",
    "somară": "soma",
    "somarăm": "soma",
    "somarăți": "soma",
    "somase": "soma",
    "somasem": "soma",
    "somaseră": "soma",
    "somaserăm": "soma",
    "somaserăți": "soma",
    "somaseși": "soma",
    "somași": "soma",
    "somat": "soma",
    "somați": "soma",
    "somau": "soma",
    "somează": "soma",
    "somez": "soma",
    "someze": "soma",
    "somezi": "soma",
    "nemaișomând": "șoma",
    "nemaișomându": "șoma",
    "neșomând": "șoma",
    "neșomându": "șoma",
    "șomă": "șoma",
    "șomai": "șoma",
    "șomam": "șoma",
    "șomăm": "șoma",
    "șomând": "șoma",
    "șomându": "șoma",
    "șomară": "șoma",
    "șomarăm": "șoma",
    "șomarăți": "șoma",
    "șomase": "șoma",
    "șomasem": "șoma",
    "șomaseră": "șoma",
    "șomaserăm": "șoma",
    "șomaserăți": "șoma",
    "șomaseși": "șoma",
    "șomași": "șoma",
    "șomat": "șoma",
    "șomați": "șoma",
    "șomau": "șoma",
    "șomează": "șoma",
    "șomez": "șoma",
    "șomeze": "șoma",
    "șomezi": "șoma",
    "șomajul": "șomaj",
    "șomajului": "șomaj",
    "somată": "somat",
    "somate": "somat",
    "somați": "somat",
    "șomată": "șomat",
    "șomate": "șomat",
    "șomați": "șomat",
    "somatica": "somatic",
    "somatică": "somatic",
    "somatice": "somatic",
    "somaticei": "somatic",
    "somaticele": "somatic",
    "somaticelor": "somatic",
    "somatici": "somatic",
    "somaticii": "somatic",
    "somaticilor": "somatic",
    "somaticul": "somatic",
    "somaticului": "somatic",
    "somația": "somație",
    "somației": "somație",
    "somații": "somație",
    "somațiile": "somație",
    "somațiilor": "somație",
    "somatologia": "somatologie",
    "somatologiei": "somatologie",
    "somatologii": "somatologie",
    "somatologiile": "somatologie",
    "somatologiilor": "somatologie",
    "șomeri": "șomer",
    "șomerii": "șomer",
    "șomerilor": "șomer",
    "șomerul": "șomer",
    "șomerului": "șomer",
    "șomera": "șomeră",
    "șomere": "șomeră",
    "șomerei": "șomeră",
    "șomerele": "șomeră",
    "șomerelor": "șomeră",
    "somiera": "somieră",
    "somiere": "somieră",
    "somierei": "somieră",
    "somierele": "somieră",
    "somierelor": "somieră",
    "somitatea": "somitate",
    "somități": "somitate",
    "somității": "somitate",
    "somitățile": "somitate",
    "somităților": "somitate",
    "somni": "somn",
    "somnii": "somn",
    "somnul": "somn",
    "somnului": "somn",
    "somnambuli": "somnambul",
    "somnambulii": "somnambul",
    "somnambulilor": "somnambul",
    "somnambulul": "somnambul",
    "somnambulului": "somnambul",
    "somnambula": "somnambulă",
    "somnambule": "somnambulă",
    "somnambulei": "somnambulă",
    "somnambulele": "somnambulă",
    "somnambulelor": "somnambulă",
    "somnambulica": "somnambulic",
    "somnambulică": "somnambulic",
    "somnambulice": "somnambulic",
    "somnambulicei": "somnambulic",
    "somnambulicele": "somnambulic",
    "somnambulicelor": "somnambulic",
    "somnambulici": "somnambulic",
    "somnambulicii": "somnambulic",
    "somnambulicilor": "somnambulic",
    "somnambulicul": "somnambulic",
    "somnambulicului": "somnambulic",
    "somnambulismul": "somnambulism",
    "somnambulismului": "somnambulism",
    "somnifera": "somnifer",
    "somniferă": "somnifer",
    "somnifere": "somnifer",
    "somniferei": "somnifer",
    "somniferele": "somnifer",
    "somniferelor": "somnifer",
    "somniferi": "somnifer",
    "somniferii": "somnifer",
    "somniferilor": "somnifer",
    "somniferul": "somnifer",
    "somniferului": "somnifer",
    "somnolenta": "somnolent",
    "somnolentă": "somnolent",
    "somnolente": "somnolent",
    "somnolentei": "somnolent",
    "somnolentele": "somnolent",
    "somnolentelor": "somnolent",
    "somnolenți": "somnolent",
    "somnolenții": "somnolent",
    "somnolenților": "somnolent",
    "somnolentul": "somnolent",
    "somnolentului": "somnolent",
    "somnolența": "somnolență",
    "somnolențe": "somnolență",
    "somnolenței": "somnolență",
    "somnolențele": "somnolență",
    "somnolențelor": "somnolență",
    "somnoroasa": "somnoros",
    "somnoroasă": "somnoros",
    "somnoroase": "somnoros",
    "somnoroasei": "somnoros",
    "somnoroasele": "somnoros",
    "somnoroaselor": "somnoros",
    "somnoroși": "somnoros",
    "somnoroșii": "somnoros",
    "somnoroșilor": "somnoros",
    "somnorosul": "somnoros",
    "somnorosului": "somnoros",
    "somnoterapia": "somnoterapie",
    "somnoterapiei": "somnoterapie",
    "somnoterapii": "somnoterapie",
    "somnoterapiile": "somnoterapie",
    "somnoterapiilor": "somnoterapie",
    "șomoioage": "șomoiog",
    "șomoioagele": "șomoiog",
    "șomoioagelor": "șomoiog",
    "șomoiogul": "șomoiog",
    "șomoiogului": "șomoiog",
    "șomoltoace": "șomoltoc",
    "șomoltoacele": "șomoltoc",
    "șomoltoacelor": "șomoltoc",
    "șomoltocul": "șomoltoc",
    "șomoltocului": "șomoltoc",
    "somoni": "somon",
    "somonii": "somon",
    "somonilor": "somon",
    "somonul": "somon",
    "somonului": "somon",
    "somptuoasa": "somptuos",
    "somptuoasă": "somptuos",
    "somptuoase": "somptuos",
    "somptuoasei": "somptuos",
    "somptuoasele": "somptuos",
    "somptuoaselor": "somptuos",
    "somptuoși": "somptuos",
    "somptuoșii": "somptuos",
    "somptuoșilor": "somptuos",
    "somptuosul": "somptuos",
    "somptuosului": "somptuos",
    "somptuozitatea": "somptuozitate",
    "somptuozități": "somptuozitate",
    "somptuozității": "somptuozitate",
    "somptuozitățile": "somptuozitate",
    "somptuozităților": "somptuozitate",
    "sonata": "sonată",
    "sonate": "sonată",
    "sonatei": "sonată",
    "sonatele": "sonată",
    "sonatelor": "sonată",
    "sonatina": "sonatină",
    "sonatine": "sonatină",
    "sonatinei": "sonatină",
    "sonatinele": "sonatină",
    "sonatinelor": "sonatină",
    "nemaisondând": "sonda",
    "nemaisondându": "sonda",
    "nesondând": "sonda",
    "nesondându": "sonda",
    "sondă": "sonda",
    "sondai": "sonda",
    "sondam": "sonda",
    "sondăm": "sonda",
    "sondând": "sonda",
    "sondându": "sonda",
    "sondară": "sonda",
    "sondarăm": "sonda",
    "sondarăți": "sonda",
    "sondase": "sonda",
    "sondasem": "sonda",
    "sondaseră": "sonda",
    "sondaserăm": "sonda",
    "sondaserăți": "sonda",
    "sondaseși": "sonda",
    "sondași": "sonda",
    "sondat": "sonda",
    "sondați": "sonda",
    "sondau": "sonda",
    "sondează": "sonda",
    "sondez": "sonda",
    "sondeze": "sonda",
    "sondezi": "sonda",
    "sonda": "sondă",
    "sonde": "sondă",
    "sondei": "sondă",
    "sondele": "sondă",
    "sondelor": "sondă",
    "sondaje": "sondaj",
    "sondajele": "sondaj",
    "sondajelor": "sondaj",
    "sondajul": "sondaj",
    "sondajului": "sondaj",
    "sondarea": "sondare",
    "sondări": "sondare",
    "sondării": "sondare",
    "sondările": "sondare",
    "sondărilor": "sondare",
    "sondată": "sondat",
    "sondate": "sondat",
    "sondați": "sondat",
    "sondori": "sondor",
    "sondorii": "sondor",
    "sondorilor": "sondor",
    "sondorul": "sondor",
    "sondorului": "sondor",
    "soneria": "sonerie",
    "soneriei": "sonerie",
    "sonerii": "sonerie",
    "soneriile": "sonerie",
    "soneriilor": "sonerie",
    "sonete": "sonet",
    "sonetele": "sonet",
    "sonetelor": "sonet",
    "sonetul": "sonet",
    "sonetului": "sonet",
    "soneta": "sonetă",
    "sonete": "sonetă",
    "sonetei": "sonetă",
    "sonetele": "sonetă",
    "sonetelor": "sonetă",
    "sonica": "sonic",
    "sonică": "sonic",
    "sonice": "sonic",
    "sonicei": "sonic",
    "sonicele": "sonic",
    "sonicelor": "sonic",
    "sonici": "sonic",
    "sonicii": "sonic",
    "sonicilor": "sonic",
    "sonicul": "sonic",
    "sonicului": "sonic",
    "sonicitatea": "sonicitate",
    "sonicități": "sonicitate",
    "sonicității": "sonicitate",
    "sonicitățile": "sonicitate",
    "sonicităților": "sonicitate",
    "sonometre": "sonometru",
    "sonometrele": "sonometru",
    "sonometrelor": "sonometru",
    "sonometrul": "sonometru",
    "sonometrului": "sonometru",
    "sonora": "sonor",
    "sonoră": "sonor",
    "sonore": "sonor",
    "sonorei": "sonor",
    "sonorele": "sonor",
    "sonorelor": "sonor",
    "sonori": "sonor",
    "sonorii": "sonor",
    "sonorilor": "sonor",
    "sonorul": "sonor",
    "sonorului": "sonor",
    "sonoritatea": "sonoritate",
    "sonorități": "sonoritate",
    "sonorității": "sonoritate",
    "sonoritățile": "sonoritate",
    "sonorităților": "sonoritate",
    "nemaisonorizând": "sonoriza",
    "nemaisonorizându": "sonoriza",
    "nesonorizând": "sonoriza",
    "nesonorizându": "sonoriza",
    "sonoriză": "sonoriza",
    "sonorizai": "sonoriza",
    "sonorizam": "sonoriza",
    "sonorizăm": "sonoriza",
    "sonorizând": "sonoriza",
    "sonorizându": "sonoriza",
    "sonorizară": "sonoriza",
    "sonorizarăm": "sonoriza",
    "sonorizarăți": "sonoriza",
    "sonorizase": "sonoriza",
    "sonorizasem": "sonoriza",
    "sonorizaseră": "sonoriza",
    "sonorizaserăm": "sonoriza",
    "sonorizaserăți": "sonoriza",
    "sonorizaseși": "sonoriza",
    "sonorizași": "sonoriza",
    "sonorizat": "sonoriza",
    "sonorizați": "sonoriza",
    "sonorizau": "sonoriza",
    "sonorizează": "sonoriza",
    "sonorizez": "sonoriza",
    "sonorizeze": "sonoriza",
    "sonorizezi": "sonoriza",
    "sonorizată": "sonorizat",
    "sonorizate": "sonorizat",
    "sonorizați": "sonorizat",
    "șontoroaga": "șontorog",
    "șontoroagă": "șontorog",
    "șontoroage": "șontorog",
    "șontoroagei": "șontorog",
    "șontoroagele": "șontorog",
    "șontoroagelor": "șontorog",
    "șontorogi": "șontorog",
    "șontorogii": "șontorog",
    "șontorogilor": "șontorog",
    "șontorogul": "șontorog",
    "șontorogului": "șontorog",
    "nemaișopăind": "șopăi",
    "nemaișopăindu": "șopăi",
    "neșopăind": "șopăi",
    "neșopăindu": "șopăi",
    "șopăia": "șopăi",
    "șopăiai": "șopăi",
    "șopăiam": "șopăi",
    "șopăiască": "șopăi",
    "șopăiați": "șopăi",
    "șopăiau": "șopăi",
    "șopăiesc": "șopăi",
    "șopăiește": "șopăi",
    "șopăiești": "șopăi",
    "șopăii": "șopăi",
    "șopăim": "șopăi",
    "șopăind": "șopăi",
    "șopăindu": "șopăi",
    "șopăiră": "șopăi",
    "șopăirăm": "șopăi",
    "șopăirăți": "șopăi",
    "șopăise": "șopăi",
    "șopăisem": "șopăi",
    "șopăiseră": "șopăi",
    "șopăiserăm": "șopăi",
    "șopăiserăți": "șopăi",
    "șopăiseși": "șopăi",
    "șopăiși": "șopăi",
    "șopăit": "șopăi",
    "șopăiți": "șopăi",
    "șopăiala": "șopăială",
    "șopăialo": "șopăială",
    "șopăieli": "șopăială",
    "șopăielii": "șopăială",
    "șopăielile": "șopăială",
    "șopăielilor": "șopăială",
    "șopăirea": "șopăire",
    "șopăireo": "șopăire",
    "șopăiri": "șopăire",
    "șopăirii": "șopăire",
    "șopăirile": "șopăire",
    "șopăirilor": "șopăire",
    "șopăită": "șopăit",
    "șopăite": "șopăit",
    "șopăiți": "șopăit",
    "șopârla": "șopârlă",
    "șopârle": "șopârlă",
    "șopârlei": "șopârlă",
    "șopârlele": "șopârlă",
    "șopârlelor": "șopârlă",
    "soporifice": "soporific",
    "soporificele": "soporific",
    "soporificelor": "soporific",
    "soporificul": "soporific",
    "soporificului": "soporific",
    "șopote": "șopot",
    "șopotele": "șopot",
    "șopotelor": "șopot",
    "șopotul": "șopot",
    "șopotului": "șopot",
    "nemaișopotind": "șopoti",
    "nemaișopotindu": "șopoti",
    "neșopotind": "șopoti",
    "neșopotindu": "șopoti",
    "șopotea": "șopoti",
    "șopoteai": "șopoti",
    "șopoteam": "șopoti",
    "șopotească": "șopoti",
    "șopoteați": "șopoti",
    "șopoteau": "șopoti",
    "șopotesc": "șopoti",
    "șopotește": "șopoti",
    "șopotești": "șopoti",
    "șopotii": "șopoti",
    "șopotim": "șopoti",
    "șopotind": "șopoti",
    "șopotindu": "șopoti",
    "șopotiră": "șopoti",
    "șopotirăm": "șopoti",
    "șopotirăți": "șopoti",
    "șopotise": "șopoti",
    "șopotisem": "șopoti",
    "șopotiseră": "șopoti",
    "șopotiserăm": "șopoti",
    "șopotiserăți": "șopoti",
    "șopotiseși": "șopoti",
    "șopotiși": "șopoti",
    "șopotit": "șopoti",
    "șopotiți": "șopoti",
    "șopotirea": "șopotire",
    "șopotireo": "șopotire",
    "șopotiri": "șopotire",
    "șopotirii": "șopotire",
    "șopotirile": "șopotire",
    "șopotirilor": "șopotire",
    "șopotita": "șopotit",
    "șopotită": "șopotit",
    "șopotite": "șopotit",
    "șopotitei": "șopotit",
    "șopotitele": "șopotit",
    "șopotitelor": "șopotit",
    "șopotiți": "șopotit",
    "șopotiții": "șopotit",
    "șopotiților": "șopotit",
    "șopotito": "șopotit",
    "șopotitul": "șopotit",
    "șopotitule": "șopotit",
    "șopotitului": "șopotit",
    "soprani": "sopran",
    "sopranii": "sopran",
    "sopranilor": "sopran",
    "sopranul": "sopran",
    "sopranului": "sopran",
    "soprana": "soprană",
    "soprane": "soprană",
    "sopranei": "soprană",
    "sopranele": "soprană",
    "sopranelor": "soprană",
    "șoproane": "șopron",
    "șoproanele": "șopron",
    "șoproanelor": "șopron",
    "șopronul": "șopron",
    "șopronului": "șopron",
    "nemaișoptind": "șopti",
    "nemaișoptindu": "șopti",
    "neșoptind": "șopti",
    "neșoptindu": "șopti",
    "șoptea": "șopti",
    "șopteai": "șopti",
    "șopteam": "șopti",
    "șoptească": "șopti",
    "șopteați": "șopti",
    "șopteau": "șopti",
    "șoptesc": "șopti",
    "șoptește": "șopti",
    "șoptești": "șopti",
    "șoptii": "șopti",
    "șoptim": "șopti",
    "șoptind": "șopti",
    "șoptindu": "șopti",
    "șoptiră": "șopti",
    "șoptirăm": "șopti",
    "șoptirăți": "șopti",
    "șoptise": "șopti",
    "șoptisem": "șopti",
    "șoptiseră": "șopti",
    "șoptiserăm": "șopti",
    "șoptiserăți": "șopti",
    "șoptiseși": "șopti",
    "șoptiși": "șopti",
    "șoptit": "șopti",
    "șoptiți": "șopti",
    "șoptirea": "șoptire",
    "șoptireo": "șoptire",
    "șoptiri": "șoptire",
    "șoptirii": "șoptire",
    "șoptirile": "șoptire",
    "șoptirilor": "șoptire",
    "șoptită": "șoptit",
    "șoptite": "șoptit",
    "șoptiți": "șoptit",
    "sora": "soră",
    "surori": "soră",
    "surorii": "soră",
    "surorile": "soră",
    "surorilor": "soră",
    "Soranei": "Sorana",
    "nemaisorbind": "sorbi",
    "nemaisorbindu": "sorbi",
    "nesorbind": "sorbi",
    "nesorbindu": "sorbi",
    "soarbă": "sorbi",
    "soarbe": "sorbi",
    "sorb": "sorbi",
    "sorbea": "sorbi",
    "sorbeai": "sorbi",
    "sorbeam": "sorbi",
    "sorbeați": "sorbi",
    "sorbeau": "sorbi",
    "sorbii": "sorbi",
    "sorbim": "sorbi",
    "sorbind": "sorbi",
    "sorbindu": "sorbi",
    "sorbiră": "sorbi",
    "sorbirăm": "sorbi",
    "sorbirăți": "sorbi",
    "sorbise": "sorbi",
    "sorbisem": "sorbi",
    "sorbiseră": "sorbi",
    "sorbiserăm": "sorbi",
    "sorbiserăți": "sorbi",
    "sorbiseși": "sorbi",
    "sorbiși": "sorbi",
    "sorbit": "sorbi",
    "sorbiți": "sorbi",
    "sorbită": "sorbit",
    "sorbite": "sorbit",
    "sorbiți": "sorbit",
    "sorbitura": "sorbitură",
    "sorbituri": "sorbitură",
    "sorbiturii": "sorbitură",
    "sorbiturile": "sorbitură",
    "sorbiturilor": "sorbitură",
    "sorcova": "sorcovă",
    "sorcove": "sorcovă",
    "sorcovei": "sorcovă",
    "sorcovele": "sorcovă",
    "sorcovelor": "sorcovă",
    "nemaisorcovind": "sorcovi",
    "nemaisorcovindu": "sorcovi",
    "nesorcovind": "sorcovi",
    "nesorcovindu": "sorcovi",
    "sorcovea": "sorcovi",
    "sorcoveai": "sorcovi",
    "sorcoveam": "sorcovi",
    "sorcovească": "sorcovi",
    "sorcoveați": "sorcovi",
    "sorcoveau": "sorcovi",
    "sorcovesc": "sorcovi",
    "sorcovește": "sorcovi",
    "sorcovești": "sorcovi",
    "sorcovii": "sorcovi",
    "sorcovim": "sorcovi",
    "sorcovind": "sorcovi",
    "sorcovindu": "sorcovi",
    "sorcoviră": "sorcovi",
    "sorcovirăm": "sorcovi",
    "sorcovirăți": "sorcovi",
    "sorcovise": "sorcovi",
    "sorcovisem": "sorcovi",
    "sorcoviseră": "sorcovi",
    "sorcoviserăm": "sorcovi",
    "sorcoviserăți": "sorcovi",
    "sorcoviseși": "sorcovi",
    "sorcoviși": "sorcovi",
    "sorcovit": "sorcovi",
    "sorcoviți": "sorcovi",
    "sorcovită": "sorcovit",
    "sorcovite": "sorcovit",
    "sorcoviți": "sorcovit",
    "sordida": "sordid",
    "sordidă": "sordid",
    "sordide": "sordid",
    "sordidei": "sordid",
    "sordidele": "sordid",
    "sordidelor": "sordid",
    "sordidul": "sordid",
    "sordidului": "sordid",
    "sordizi": "sordid",
    "sordizii": "sordid",
    "sordizilor": "sordid",
    "șorecari": "șorecar",
    "șorecarii": "șorecar",
    "șorecarilor": "șorecar",
    "șorecarul": "șorecar",
    "șorecarului": "șorecar",
    "sorgintea": "sorginte",
    "sorginți": "sorginte",
    "sorginții": "sorginte",
    "sorgințile": "sorginte",
    "sorginților": "sorginte",
    "șoricari": "șoricar",
    "șoricarii": "șoricar",
    "șoricarilor": "șoricar",
    "șoricarul": "șoricar",
    "șoricarului": "șoricar",
    "șoriceasca": "șoricesc",
    "șoricească": "șoricesc",
    "șoricescul": "șoricesc",
    "șoricescului": "șoricesc",
    "șoricești": "șoricesc",
    "șoriceștii": "șoricesc",
    "șoriceștile": "șoricesc",
    "șoriceștilor": "șoricesc",
    "șorice": "șorici",
    "șoricele": "șorici",
    "șoricelor": "șorici",
    "șoriciul": "șorici",
    "șoriciului": "șorici",
    "șoricioaica": "șoricioaică",
    "șoricioaice": "șoricioaică",
    "șoricioaicei": "șoricioaică",
    "șoricioaicele": "șoricioaică",
    "șoricioaicelor": "șoricioaică",
    "soroace": "soroc",
    "soroacele": "soroc",
    "soroacelor": "soroc",
    "sorocul": "soroc",
    "sorocului": "soroc",
    "nemaisorocind": "soroci",
    "nemaisorocindu": "soroci",
    "nesorocind": "soroci",
    "nesorocindu": "soroci",
    "sorocea": "soroci",
    "soroceai": "soroci",
    "soroceam": "soroci",
    "sorocească": "soroci",
    "soroceați": "soroci",
    "soroceau": "soroci",
    "sorocesc": "soroci",
    "sorocește": "soroci",
    "sorocești": "soroci",
    "sorocii": "soroci",
    "sorocim": "soroci",
    "sorocind": "soroci",
    "sorocindu": "soroci",
    "sorociră": "soroci",
    "sorocirăm": "soroci",
    "sorocirăți": "soroci",
    "sorocise": "soroci",
    "sorocisem": "soroci",
    "sorociseră": "soroci",
    "sorociserăm": "soroci",
    "sorociserăți": "soroci",
    "sorociseși": "soroci",
    "sorociși": "soroci",
    "sorocit": "soroci",
    "sorociți": "soroci",
    "sorocita": "sorocit",
    "sorocită": "sorocit",
    "sorocite": "sorocit",
    "sorocitei": "sorocit",
    "sorocitele": "sorocit",
    "sorocitelor": "sorocit",
    "sorociți": "sorocit",
    "sorociții": "sorocit",
    "sorociților": "sorocit",
    "sorocitul": "sorocit",
    "sorocitului": "sorocit",
    "sortul": "sort",
    "sortului": "sort",
    "sorturi": "sort",
    "sorturile": "sort",
    "sorturilor": "sort",
    "sorți": "sorț",
    "sorții": "sorț",
    "sorților": "sorț",
    "sorțul": "sorț",
    "sorțului": "sorț",
    "șortul": "șort",
    "șortului": "șort",
    "șorturi": "șort",
    "șorturile": "șort",
    "șorturilor": "șort",
    "șorțul": "șorț",
    "șorțului": "șorț",
    "șorțuri": "șorț",
    "șorțurile": "șorț",
    "șorțurilor": "șorț",
    "nemaisortând": "sorta",
    "nemaisortându": "sorta",
    "nesortând": "sorta",
    "nesortându": "sorta",
    "sortă": "sorta",
    "sortai": "sorta",
    "sortam": "sorta",
    "sortăm": "sorta",
    "sortând": "sorta",
    "sortându": "sorta",
    "sortară": "sorta",
    "sortarăm": "sorta",
    "sortarăți": "sorta",
    "sortase": "sorta",
    "sortasem": "sorta",
    "sortaseră": "sorta",
    "sortaserăm": "sorta",
    "sortaserăți": "sorta",
    "sortaseși": "sorta",
    "sortași": "sorta",
    "sortat": "sorta",
    "sortați": "sorta",
    "sortau": "sorta",
    "sortează": "sorta",
    "sortez": "sorta",
    "sorteze": "sorta",
    "sortezi": "sorta",
    "sortarea": "sortare",
    "sortări": "sortare",
    "sortării": "sortare",
    "sortările": "sortare",
    "sortărilor": "sortare",
    "sortată": "sortat",
    "sortate": "sortat",
    "sortați": "sortat",
    "nemaisortind": "sorti",
    "nemaisortindu": "sorti",
    "nesortind": "sorti",
    "nesortindu": "sorti",
    "sortea": "sorti",
    "sorteai": "sorti",
    "sorteam": "sorti",
    "sortească": "sorti",
    "sorteați": "sorti",
    "sorteau": "sorti",
    "sortesc": "sorti",
    "sortește": "sorti",
    "sortești": "sorti",
    "sortii": "sorti",
    "sortim": "sorti",
    "sortind": "sorti",
    "sortindu": "sorti",
    "sortiră": "sorti",
    "sortirăm": "sorti",
    "sortirăți": "sorti",
    "sortise": "sorti",
    "sortisem": "sorti",
    "sortiseră": "sorti",
    "sortiserăm": "sorti",
    "sortiserăți": "sorti",
    "sortiseși": "sorti",
    "sortiși": "sorti",
    "sortit": "sorti",
    "sortiți": "sorti",
    "sortimente": "sortiment",
    "sortimentele": "sortiment",
    "sortimentelor": "sortiment",
    "sortimentul": "sortiment",
    "sortimentului": "sortiment",
    "sortirea": "sortire",
    "sortireo": "sortire",
    "sortiri": "sortire",
    "sortirii": "sortire",
    "sortirile": "sortire",
    "sortirilor": "sortire",
    "sortita": "sortit",
    "sortită": "sortit",
    "sortite": "sortit",
    "sortitei": "sortit",
    "sortitele": "sortit",
    "sortitelor": "sortit",
    "sortiți": "sortit",
    "sortiții": "sortit",
    "sortiților": "sortit",
    "sortito": "sortit",
    "sortitul": "sortit",
    "sortitule": "sortit",
    "sortitului": "sortit",
    "sosul": "sos",
    "sosului": "sos",
    "sosuri": "sos",
    "sosurile": "sos",
    "sosurilor": "sos",
    "șoseaua": "șosea",
    "șosele": "șosea",
    "șoselei": "șosea",
    "șoselele": "șosea",
    "șoselelor": "șosea",
    "șos.": "șoseaua",
    "șoseta": "șosetă",
    "șosete": "șosetă",
    "șosetei": "șosetă",
    "șosetele": "șosetă",
    "șosetelor": "șosetă",
    "nemaisosind": "sosi",
    "nemaisosindu": "sosi",
    "nesosind": "sosi",
    "nesosindu": "sosi",
    "sosea": "sosi",
    "soseai": "sosi",
    "soseam": "sosi",
    "sosească": "sosi",
    "soseați": "sosi",
    "soseau": "sosi",
    "sosesc": "sosi",
    "sosește": "sosi",
    "sosești": "sosi",
    "sosii": "sosi",
    "sosim": "sosi",
    "sosind": "sosi",
    "sosindu": "sosi",
    "sosiră": "sosi",
    "sosirăm": "sosi",
    "sosirăți": "sosi",
    "sosise": "sosi",
    "sosisem": "sosi",
    "sosiseră": "sosi",
    "sosiserăm": "sosi",
    "sosiserăți": "sosi",
    "sosiseși": "sosi",
    "sosiși": "sosi",
    "sosit": "sosi",
    "sosiți": "sosi",
    "sosiera": "sosieră",
    "sosiere": "sosieră",
    "sosierei": "sosieră",
    "sosierele": "sosieră",
    "sosierelor": "sosieră",
    "sosirea": "sosire",
    "sosireo": "sosire",
    "sosiri": "sosire",
    "sosirii": "sosire",
    "sosirile": "sosire",
    "sosirilor": "sosire",
    "sosita": "sosit",
    "sosită": "sosit",
    "sosite": "sosit",
    "sositei": "sosit",
    "sositele": "sosit",
    "sositelor": "sosit",
    "sosiți": "sosit",
    "sosiții": "sosit",
    "sosiților": "sosit",
    "sosito": "sosit",
    "sositul": "sosit",
    "sositule": "sosit",
    "sositului": "sosit",
    "șoșoni": "șoșon",
    "șoșonii": "șoșon",
    "șoșonilor": "șoșon",
    "șoșonul": "șoșon",
    "șoșonului": "șoșon",
    "soți": "soț",
    "soții": "soț",
    "soților": "soț",
    "soțu'": "soț",
    "soțul": "soț",
    "soțului": "soț",
    "soteul": "sote",
    "soteului": "sote",
    "soteuri": "sote",
    "soteurile": "sote",
    "soteurilor": "sote",
    "soția": "soție",
    "soției": "soție",
    "soții": "soție",
    "soțiile": "soție",
    "soțiilor": "soție",
    "șotia": "șotie",
    "șotiei": "șotie",
    "șotii": "șotie",
    "șotiile": "șotie",
    "șotiilor": "șotie",
    "soțioara": "soțioară",
    "soțioare": "soțioară",
    "soțioarei": "soțioară",
    "soțioarele": "soțioară",
    "soțioarelor": "soțioară",
    "soțiori": "soțior",
    "soțiorii": "soțior",
    "soțiorilor": "soțior",
    "soțiorul": "soțior",
    "soțiorului": "soțior",
    "șotroane": "șotron",
    "șotroanele": "șotron",
    "șotroanelor": "șotron",
    "șotronul": "șotron",
    "șotronului": "șotron",
    "nemaișovăind": "șovăi",
    "nemaișovăindu": "șovăi",
    "neșovăind": "șovăi",
    "neșovăindu": "șovăi",
    "șovăia": "șovăi",
    "șovăiai": "șovăi",
    "șovăiam": "șovăi",
    "șovăiați": "șovăi",
    "șovăiau": "șovăi",
    "șovăie": "șovăi",
    "șovăii": "șovăi",
    "șovăim": "șovăi",
    "șovăind": "șovăi",
    "șovăindu": "șovăi",
    "șovăiră": "șovăi",
    "șovăirăm": "șovăi",
    "șovăirăți": "șovăi",
    "șovăise": "șovăi",
    "șovăisem": "șovăi",
    "șovăiseră": "șovăi",
    "șovăiserăm": "șovăi",
    "șovăiserăți": "șovăi",
    "șovăiseși": "șovăi",
    "șovăiși": "șovăi",
    "șovăit": "șovăi",
    "șovăiți": "șovăi",
    "șovăiala": "șovăială",
    "șovăieli": "șovăială",
    "șovăielii": "șovăială",
    "șovăielile": "șovăială",
    "șovăielilor": "șovăială",
    "șovăielnica": "șovăielnic",
    "șovăielnică": "șovăielnic",
    "șovăielnice": "șovăielnic",
    "șovăielnicei": "șovăielnic",
    "șovăielnicele": "șovăielnic",
    "șovăielnicelor": "șovăielnic",
    "șovăielnici": "șovăielnic",
    "șovăielnicii": "șovăielnic",
    "șovăielnicilor": "șovăielnic",
    "șovăielnicul": "șovăielnic",
    "șovăielnicului": "șovăielnic",
    "șovăirea": "șovăire",
    "șovăiri": "șovăire",
    "șovăirii": "șovăire",
    "șovăirile": "șovăire",
    "șovăirilor": "șovăire",
    "șovăita": "șovăit",
    "șovăită": "șovăit",
    "șovăite": "șovăit",
    "șovăitei": "șovăit",
    "șovăitele": "șovăit",
    "șovăitelor": "șovăit",
    "șovăiți": "șovăit",
    "șovăiții": "șovăit",
    "șovăiților": "șovăit",
    "șovăito": "șovăit",
    "șovăitul": "șovăit",
    "șovăitule": "șovăit",
    "șovăitului": "șovăit",
    "șovăitoare": "șovăitor",
    "șovăitoarea": "șovăitor",
    "șovăitoarei": "șovăitor",
    "șovăitoarele": "șovăitor",
    "șovăitoarelor": "șovăitor",
    "șovăitori": "șovăitor",
    "șovăitorii": "șovăitor",
    "șovăitorilor": "șovăitor",
    "șovăitorul": "șovăitor",
    "șovăitorului": "șovăitor",
    "soviete": "soviet",
    "sovietele": "soviet",
    "sovietelor": "soviet",
    "sovietul": "soviet",
    "sovietului": "soviet",
    "sovietici": "sovietic",
    "sovieticii": "sovietic",
    "sovieticilor": "sovietic",
    "sovieticul": "sovietic",
    "sovieticului": "sovietic",
    "sovietica": "sovietică",
    "sovietice": "sovietică",
    "sovieticei": "sovietică",
    "sovieticele": "sovietică",
    "sovieticelor": "sovietică",
    "șovina": "șovin",
    "șovină": "șovin",
    "șovine": "șovin",
    "șovinei": "șovin",
    "șovinele": "șovin",
    "șovinelor": "șovin",
    "șovini": "șovin",
    "șovinii": "șovin",
    "șovinilor": "șovin",
    "șovinul": "șovin",
    "șovinului": "șovin",
    "șovina": "șovină",
    "șovine": "șovină",
    "șovinei": "șovină",
    "șovinele": "șovină",
    "șovinelor": "șovină",
    "șovinismul": "șovinism",
    "șovinismului": "șovinism",
    "șovinista": "șovinist",
    "șovinistă": "șovinist",
    "șoviniste": "șovinist",
    "șovinistei": "șovinist",
    "șovinistele": "șovinist",
    "șovinistelor": "șovinist",
    "șoviniști": "șovinist",
    "șoviniștii": "șovinist",
    "șoviniștilor": "șovinist",
    "șovinistul": "șovinist",
    "șovinistului": "șovinist",
    "șovinista": "șovinistă",
    "șoviniste": "șovinistă",
    "șovinistei": "șovinistă",
    "șovinistele": "șovinistă",
    "șovinistelor": "șovinistă",
    "sovoane": "sovon",
    "sovoanele": "sovon",
    "sovoanelor": "sovon",
    "sovonul": "sovon",
    "sovonului": "sovon",
    "șpaclul": "șpaclu",
    "șpaclului": "șpaclu",
    "șpacluri": "șpaclu",
    "șpaclurile": "șpaclu",
    "șpaclurilor": "șpaclu",
    "spada": "spadă",
    "spade": "spadă",
    "spadei": "spadă",
    "spadele": "spadă",
    "spadelor": "spadă",
    "spadasini": "spadasin",
    "spadasinii": "spadasin",
    "spadasinilor": "spadasin",
    "spadasinul": "spadasin",
    "spadasinului": "spadasin",
    "șpaga": "șpagă",
    "șpăgi": "șpagă",
    "șpăgii": "șpagă",
    "șpăgile": "șpagă",
    "șpăgilor": "șpagă",
    "șpagate": "șpagat",
    "șpagatele": "șpagat",
    "șpagatelor": "șpagat",
    "șpagatul": "șpagat",
    "șpagatului": "șpagat",
    "spaghetele": "spaghete",
    "spaghetelor": "spaghete",
    "spahii": "spahiu",
    "spahiii": "spahiu",
    "spahiilor": "spahiu",
    "spahiul": "spahiu",
    "spahiului": "spahiu",
    "spaima": "spaimă",
    "spaime": "spaimă",
    "spaimei": "spaimă",
    "spaimele": "spaimă",
    "spaimelor": "spaimă",
    "spăimântata": "spăimântat",
    "spăimântată": "spăimântat",
    "spăimântate": "spăimântat",
    "spăimântatei": "spăimântat",
    "spăimântatele": "spăimântat",
    "spăimântatelor": "spăimântat",
    "spăimântați": "spăimântat",
    "spăimântații": "spăimântat",
    "spăimântaților": "spăimântat",
    "spăimântatul": "spăimântat",
    "spăimântatului": "spăimântat",
    "nemaispălând": "spăla",
    "nemaispălându": "spăla",
    "nespălând": "spăla",
    "nespălându": "spăla",
    "spăl": "spăla",
    "spală": "spăla",
    "spălă": "spăla",
    "spălai": "spăla",
    "spălam": "spăla",
    "spălăm": "spăla",
    "spălând": "spăla",
    "spălându": "spăla",
    "spălară": "spăla",
    "spălarăm": "spăla",
    "spălarăți": "spăla",
    "spălase": "spăla",
    "spălasem": "spăla",
    "spălaseră": "spăla",
    "spălaserăm": "spăla",
    "spălaserăți": "spăla",
    "spălaseși": "spăla",
    "spălași": "spăla",
    "spălat": "spăla",
    "spălați": "spăla",
    "spălau": "spăla",
    "spele": "spăla",
    "speli": "spăla",
    "nemaispălăcind": "spălăci",
    "nemaispălăcindu": "spălăci",
    "nespălăcind": "spălăci",
    "nespălăcindu": "spălăci",
    "spălăcea": "spălăci",
    "spălăceai": "spălăci",
    "spălăceam": "spălăci",
    "spălăcească": "spălăci",
    "spălăceați": "spălăci",
    "spălăceau": "spălăci",
    "spălăcesc": "spălăci",
    "spălăcește": "spălăci",
    "spălăcești": "spălăci",
    "spălăcii": "spălăci",
    "spălăcim": "spălăci",
    "spălăcind": "spălăci",
    "spălăcindu": "spălăci",
    "spălăciră": "spălăci",
    "spălăcirăm": "spălăci",
    "spălăcirăți": "spălăci",
    "spălăcise": "spălăci",
    "spălăcisem": "spălăci",
    "spălăciseră": "spălăci",
    "spălăciserăm": "spălăci",
    "spălăciserăți": "spălăci",
    "spălăciseși": "spălăci",
    "spălăciși": "spălăci",
    "spălăcit": "spălăci",
    "spălăciți": "spălăci",
    "spălăcirea": "spălăcire",
    "spălăcireo": "spălăcire",
    "spălăciri": "spălăcire",
    "spălăcirii": "spălăcire",
    "spălăcirile": "spălăcire",
    "spălăcirilor": "spălăcire",
    "spălăcita": "spălăcit",
    "spălăcită": "spălăcit",
    "spălăcite": "spălăcit",
    "spălăcitei": "spălăcit",
    "spălăcitele": "spălăcit",
    "spălăcitelor": "spălăcit",
    "spălăciți": "spălăcit",
    "spălăciții": "spălăcit",
    "spălăciților": "spălăcit",
    "spălăcito": "spălăcit",
    "spălăcitul": "spălăcit",
    "spălăcitule": "spălăcit",
    "spălăcitului": "spălăcit",
    "spălarea": "spălare",
    "spălareo": "spălare",
    "spălări": "spălare",
    "spălării": "spălare",
    "spălările": "spălare",
    "spălărilor": "spălare",
    "spălata": "spălat",
    "spălată": "spălat",
    "spălate": "spălat",
    "spălatei": "spălat",
    "spălatele": "spălat",
    "spălatelor": "spălat",
    "spălați": "spălat",
    "spălații": "spălat",
    "spălaților": "spălat",
    "spălato": "spălat",
    "spălatul": "spălat",
    "spălatule": "spălat",
    "spălatului": "spălat",
    "spălătoare": "spălător",
    "spălătoarele": "spălător",
    "spălătoarelor": "spălător",
    "spălătorul": "spălător",
    "spălătorului": "spălător",
    "spălătoreasa": "spălătoreasă",
    "spălătorese": "spălătoreasă",
    "spălătoresei": "spălătoreasă",
    "spălătoresele": "spălătoreasă",
    "spălătoreselor": "spălătoreasă",
    "spălătoria": "spălătorie",
    "spălătoriei": "spălătorie",
    "spălătorii": "spălătorie",
    "spălătoriile": "spălătorie",
    "spălătoriilor": "spălătorie",
    "spălătura": "spălătură",
    "spălături": "spălătură",
    "spălăturii": "spălătură",
    "spălăturile": "spălătură",
    "spălăturilor": "spălătură",
    "spaliere": "spalier",
    "spalierele": "spalier",
    "spalierelor": "spalier",
    "spalierul": "spalier",
    "spalierului": "spalier",
    "șpaltul": "șpalt",
    "șpaltului": "șpalt",
    "șpalturi": "șpalt",
    "șpalturile": "șpalt",
    "șpalturilor": "șpalt",
    "spâna": "spân",
    "spână": "spân",
    "spâne": "spân",
    "spânei": "spân",
    "spânele": "spân",
    "spânelor": "spân",
    "spâni": "spân",
    "spânii": "spân",
    "spânilor": "spân",
    "spânul": "spân",
    "spânului": "spân",
    "șpanul": "șpan",
    "șpanului": "șpan",
    "șpanuri": "șpan",
    "șpanurile": "șpan",
    "șpanurilor": "șpan",
    "spanace": "spanac",
    "spanacele": "spanac",
    "spanacelor": "spanac",
    "spanacul": "spanac",
    "spanacului": "spanac",
    "spânatica": "spânatic",
    "spânatică": "spânatic",
    "spânatice": "spânatic",
    "spânaticei": "spânatic",
    "spânaticele": "spânatic",
    "spânaticelor": "spânatic",
    "spânatici": "spânatic",
    "spânaticii": "spânatic",
    "spânaticilor": "spânatic",
    "spânaticul": "spânatic",
    "spânaticului": "spânatic",
    "spanca": "spancă",
    "spance": "spancă",
    "spancei": "spancă",
    "spancele": "spancă",
    "spancelor": "spancă",
    "Spanie": "Spania",
    "Spaniei": "Spania",
    "spaniolă": "spaniol",
    "spaniole": "spaniol",
    "spanioli": "spaniol",
    "spaniolii": "spaniol",
    "spaniolilor": "spaniol",
    "spaniolul": "spaniol",
    "spaniolului": "spaniol",
    "spaniola": "spaniolă",
    "spaniole": "spaniolă",
    "spaniolei": "spaniolă",
    "spaniolele": "spaniolă",
    "spaniolelor": "spaniolă",
    "nemaispânzurând": "spânzura",
    "nemaispânzurându": "spânzura",
    "nespânzurând": "spânzura",
    "nespânzurându": "spânzura",
    "spânzur": "spânzura",
    "spânzură": "spânzura",
    "spânzurai": "spânzura",
    "spânzuram": "spânzura",
    "spânzurăm": "spânzura",
    "spânzurând": "spânzura",
    "spânzurându": "spânzura",
    "spânzurară": "spânzura",
    "spânzurarăm": "spânzura",
    "spânzurarăți": "spânzura",
    "spânzurase": "spânzura",
    "spânzurasem": "spânzura",
    "spânzuraseră": "spânzura",
    "spânzuraserăm": "spânzura",
    "spânzuraserăți": "spânzura",
    "spânzuraseși": "spânzura",
    "spânzurași": "spânzura",
    "spânzurat": "spânzura",
    "spânzurați": "spânzura",
    "spânzurau": "spânzura",
    "spânzure": "spânzura",
    "spânzuri": "spânzura",
    "spânzurarea": "spânzurare",
    "spânzurareo": "spânzurare",
    "spânzurări": "spânzurare",
    "spânzurării": "spânzurare",
    "spânzurările": "spânzurare",
    "spânzurărilor": "spânzurare",
    "spânzurata": "spânzurat",
    "spânzurată": "spânzurat",
    "spânzurate": "spânzurat",
    "spânzuratei": "spânzurat",
    "spânzuratele": "spânzurat",
    "spânzuratelor": "spânzurat",
    "spânzurați": "spânzurat",
    "spânzurații": "spânzurat",
    "spânzuraților": "spânzurat",
    "spânzurato": "spânzurat",
    "spânzuratul": "spânzurat",
    "spânzuratule": "spânzurat",
    "spânzuratului": "spânzurat",
    "spânzurătoarea": "spânzurătoare",
    "spânzurători": "spânzurătoare",
    "spânzurătorii": "spânzurătoare",
    "spânzurătorile": "spânzurătoare",
    "spânzurătorilor": "spânzurătoare",
    "sparangheli": "sparanghel",
    "sparanghelii": "sparanghel",
    "sparanghelilor": "sparanghel",
    "sparanghelul": "sparanghel",
    "sparanghelului": "sparanghel",
    "nemaispârcuind": "spârcui",
    "nemaispârcuindu": "spârcui",
    "nespârcuind": "spârcui",
    "nespârcuindu": "spârcui",
    "spârcuia": "spârcui",
    "spârcuiai": "spârcui",
    "spârcuiam": "spârcui",
    "spârcuiască": "spârcui",
    "spârcuiați": "spârcui",
    "spârcuiau": "spârcui",
    "spârcuiesc": "spârcui",
    "spârcuiește": "spârcui",
    "spârcuiești": "spârcui",
    "spârcuii": "spârcui",
    "spârcuim": "spârcui",
    "spârcuind": "spârcui",
    "spârcuindu": "spârcui",
    "spârcuiră": "spârcui",
    "spârcuirăm": "spârcui",
    "spârcuirăți": "spârcui",
    "spârcuise": "spârcui",
    "spârcuisem": "spârcui",
    "spârcuiseră": "spârcui",
    "spârcuiserăm": "spârcui",
    "spârcuiserăți": "spârcui",
    "spârcuiseși": "spârcui",
    "spârcuiși": "spârcui",
    "spârcuit": "spârcui",
    "spârcuiți": "spârcui",
    "spârcuită": "spârcuit",
    "spârcuite": "spârcuit",
    "spârcuiți": "spârcuit",
    "spărgătoarea": "spărgătoare",
    "spărgătoarei": "spărgătoare",
    "spărgătoarele": "spărgătoare",
    "spărgătoarelor": "spărgătoare",
    "spărgătoare": "spărgător",
    "spărgătoarea": "spărgător",
    "spărgătoarei": "spărgător",
    "spărgătoarele": "spărgător",
    "spărgătoarelor": "spărgător",
    "spărgători": "spărgător",
    "spărgătorii": "spărgător",
    "spărgătorilor": "spărgător",
    "spărgătorul": "spărgător",
    "spărgătorului": "spărgător",
    "nemaispărgând": "sparge",
    "nemaispărgându": "sparge",
    "nespărgând": "sparge",
    "nespărgându": "sparge",
    "sparg": "sparge",
    "spargă": "sparge",
    "spărgând": "sparge",
    "spărgându": "sparge",
    "spărgea": "sparge",
    "spărgeai": "sparge",
    "spărgeam": "sparge",
    "spărgeați": "sparge",
    "spărgeau": "sparge",
    "spargem": "sparge",
    "spargeți": "sparge",
    "spargi": "sparge",
    "sparse": "sparge",
    "spărsei": "sparge",
    "sparseră": "sparge",
    "sparserăm": "sparge",
    "sparserăți": "sparge",
    "spărsese": "sparge",
    "spărsesem": "sparge",
    "spărseseră": "sparge",
    "spărseserăm": "sparge",
    "spărseserăți": "sparge",
    "spărseseși": "sparge",
    "spărseși": "sparge",
    "spart": "sparge",
    "spargerea": "spargere",
    "spargereo": "spargere",
    "spargeri": "spargere",
    "spargerii": "spargere",
    "spargerile": "spargere",
    "spargerilor": "spargere",
    "sparta": "spart",
    "spartă": "spart",
    "sparte": "spart",
    "spartei": "spart",
    "spartele": "spart",
    "spartelor": "spart",
    "sparți": "spart",
    "sparții": "spart",
    "sparților": "spart",
    "sparto": "spart",
    "spartul": "spart",
    "spartule": "spart",
    "spartului": "spart",
    "spartachiada": "spartachiadă",
    "spartachiade": "spartachiadă",
    "spartachiadei": "spartachiadă",
    "spartachiadele": "spartachiadă",
    "spartachiadelor": "spartachiadă",
    "spartana": "spartan",
    "spartană": "spartan",
    "spartane": "spartan",
    "spartanei": "spartan",
    "spartanele": "spartan",
    "spartanelor": "spartan",
    "spartani": "spartan",
    "spartanii": "spartan",
    "spartanilor": "spartan",
    "spartanul": "spartan",
    "spartanului": "spartan",
    "spartana": "spartană",
    "spartane": "spartană",
    "spartanei": "spartană",
    "spartanele": "spartană",
    "spartanelor": "spartană",
    "spărtura": "spărtură",
    "spărturi": "spărtură",
    "spărturii": "spărtură",
    "spărturile": "spărtură",
    "spărturilor": "spărtură",
    "spășiți": "spășit",
    "spășiții": "spășit",
    "spășiților": "spășit",
    "spășitul": "spășit",
    "spășitului": "spășit",
    "spasme": "spasm",
    "spasmele": "spasm",
    "spasmelor": "spasm",
    "spasmul": "spasm",
    "spasmului": "spasm",
    "spasmodica": "spasmodic",
    "spasmodică": "spasmodic",
    "spasmodice": "spasmodic",
    "spasmodicei": "spasmodic",
    "spasmodicele": "spasmodic",
    "spasmodicelor": "spasmodic",
    "spasmodici": "spasmodic",
    "spasmodicii": "spasmodic",
    "spasmodicilor": "spasmodic",
    "spasmodicul": "spasmodic",
    "spasmodicului": "spasmodic",
    "spațul": "spaț",
    "spațului": "spaț",
    "spațuri": "spaț",
    "spațurile": "spaț",
    "spațurilor": "spaț",
    "spata": "spată",
    "spate": "spată",
    "spatele": "spată",
    "spatelor": "spată",
    "spete": "spată",
    "spetei": "spată",
    "spetele": "spată",
    "spetelor": "spată",
    "spătare": "spătar",
    "spătarele": "spătar",
    "spătarelor": "spătar",
    "spătari": "spătar",
    "spătarii": "spătar",
    "spătarilor": "spătar",
    "spătarul": "spătar",
    "spătarului": "spătar",
    "spătăreasca": "spătăresc",
    "spătărească": "spătăresc",
    "spătărescul": "spătăresc",
    "spătărescului": "spătăresc",
    "spătărești": "spătăresc",
    "spătăreștii": "spătăresc",
    "spătăreștile": "spătăresc",
    "spătăreștilor": "spătăresc",
    "spătăria": "spătărie",
    "spătăriei": "spătărie",
    "spătării": "spătărie",
    "spătăriile": "spătărie",
    "spătăriilor": "spătărie",
    "spatele": "spate",
    "spatelor": "spate",
    "spatelui": "spate",
    "nemaispațiind": "spația",
    "nemaispațiindu": "spația",
    "nespațiind": "spația",
    "nespațiindu": "spația",
    "spațiai": "spația",
    "spațiam": "spația",
    "spațiară": "spația",
    "spațiarăm": "spația",
    "spațiarăți": "spația",
    "spațiase": "spația",
    "spațiasem": "spația",
    "spațiaseră": "spația",
    "spațiaserăm": "spația",
    "spațiaserăți": "spația",
    "spațiaseși": "spația",
    "spațiași": "spația",
    "spațiat": "spația",
    "spațiați": "spația",
    "spațiau": "spația",
    "spațiază": "spația",
    "spație": "spația",
    "spațiem": "spația",
    "spațiez": "spația",
    "spațieze": "spația",
    "spațiezi": "spația",
    "spațiind": "spația",
    "spațiindu": "spația",
    "spațiala": "spațial",
    "spațială": "spațial",
    "spațiale": "spațial",
    "spațialei": "spațial",
    "spațialele": "spațial",
    "spațialelor": "spațial",
    "spațiali": "spațial",
    "spațialii": "spațial",
    "spațialilor": "spațial",
    "spațialul": "spațial",
    "spațialului": "spațial",
    "spațiată": "spațiat",
    "spațiate": "spațiat",
    "spațiați": "spațiat",
    "spațioasa": "spațios",
    "spațioasă": "spațios",
    "spațioase": "spațios",
    "spațioasei": "spațios",
    "spațioasele": "spațios",
    "spațioaselor": "spațios",
    "spațioși": "spațios",
    "spațioșii": "spațios",
    "spațioșilor": "spațios",
    "spațiosul": "spațios",
    "spațiosului": "spațios",
    "spații": "spațiu",
    "spațiile": "spațiu",
    "spațiilor": "spațiu",
    "spațiul": "spațiu",
    "spațiului": "spațiu",
    "spătoasa": "spătos",
    "spătoasă": "spătos",
    "spătoase": "spătos",
    "spătoasei": "spătos",
    "spătoasele": "spătos",
    "spătoaselor": "spătos",
    "spătoși": "spătos",
    "spătoșii": "spătos",
    "spătoșilor": "spătos",
    "spătosul": "spătos",
    "spătosului": "spătos",
    "spatula": "spatulă",
    "spatule": "spatulă",
    "spatulei": "spatulă",
    "spatulele": "spatulă",
    "spatulelor": "spatulă",
    "speciala": "special",
    "specială": "special",
    "speciale": "special",
    "specialei": "special",
    "specialele": "special",
    "specialelor": "special",
    "speciali": "special",
    "specialii": "special",
    "specialilor": "special",
    "specialul": "special",
    "specialului": "special",
    "specialista": "specialist",
    "specialistă": "specialist",
    "specialiste": "specialist",
    "specialistei": "specialist",
    "specialistele": "specialist",
    "specialistelor": "specialist",
    "specialiști": "specialist",
    "specialiștii": "specialist",
    "specialiștilor": "specialist",
    "specialistul": "specialist",
    "specialistului": "specialist",
    "specialista": "specialistă",
    "specialiste": "specialistă",
    "specialistei": "specialistă",
    "specialistele": "specialistă",
    "specialistelor": "specialistă",
    "specialitatea": "specialitate",
    "specialități": "specialitate",
    "specialității": "specialitate",
    "specialitățile": "specialitate",
    "specialităților": "specialitate",
    "nemaispecializând": "specializa",
    "nemaispecializându": "specializa",
    "nespecializând": "specializa",
    "nespecializându": "specializa",
    "specializă": "specializa",
    "specializai": "specializa",
    "specializam": "specializa",
    "specializăm": "specializa",
    "specializând": "specializa",
    "specializându": "specializa",
    "specializară": "specializa",
    "specializarăm": "specializa",
    "specializarăți": "specializa",
    "specializase": "specializa",
    "specializasem": "specializa",
    "specializaseră": "specializa",
    "specializaserăm": "specializa",
    "specializaserăți": "specializa",
    "specializaseși": "specializa",
    "specializași": "specializa",
    "specializat": "specializa",
    "specializați": "specializa",
    "specializau": "specializa",
    "specializează": "specializa",
    "specializez": "specializa",
    "specializeze": "specializa",
    "specializezi": "specializa",
    "specializarea": "specializare",
    "specializareo": "specializare",
    "specializări": "specializare",
    "specializării": "specializare",
    "specializările": "specializare",
    "specializărilor": "specializare",
    "specializată": "specializat",
    "specializate": "specializat",
    "specializați": "specializat",
    "specia": "specie",
    "speciei": "specie",
    "specii": "specie",
    "speciile": "specie",
    "speciilor": "specie",
    "specifica": "specific",
    "specifică": "specific",
    "specifice": "specific",
    "specificei": "specific",
    "specificele": "specific",
    "specificelor": "specific",
    "specifici": "specific",
    "specificii": "specific",
    "specificilor": "specific",
    "specificul": "specific",
    "specificului": "specific",
    "nemaispecificând": "specifica",
    "nemaispecificându": "specifica",
    "nespecificând": "specifica",
    "nespecificându": "specifica",
    "specific": "specifica",
    "specifică": "specifica",
    "specificai": "specifica",
    "specificam": "specifica",
    "specificăm": "specifica",
    "specificând": "specifica",
    "specificându": "specifica",
    "specificară": "specifica",
    "specificarăm": "specifica",
    "specificarăți": "specifica",
    "specificase": "specifica",
    "specificasem": "specifica",
    "specificaseră": "specifica",
    "specificaserăm": "specifica",
    "specificaserăți": "specifica",
    "specificaseși": "specifica",
    "specificași": "specifica",
    "specificat": "specifica",
    "specificați": "specifica",
    "specificau": "specifica",
    "specifice": "specifica",
    "specifici": "specifica",
    "specificarea": "specificare",
    "specificări": "specificare",
    "specificării": "specificare",
    "specificările": "specificare",
    "specificărilor": "specificare",
    "specificată": "specificat",
    "specificate": "specificat",
    "specificați": "specificat",
    "specificația": "specificație",
    "specificației": "specificație",
    "specificații": "specificație",
    "specificațiile": "specificație",
    "specificațiilor": "specificație",
    "specimene": "specimen",
    "specimenele": "specimen",
    "specimenelor": "specimen",
    "specimenul": "specimen",
    "specimenului": "specimen",
    "spectacole": "spectacol",
    "spectacolele": "spectacol",
    "spectacolelor": "spectacol",
    "spectacolul": "spectacol",
    "spectacolului": "spectacol",
    "spectaculara": "spectacular",
    "spectaculară": "spectacular",
    "spectaculare": "spectacular",
    "spectacularei": "spectacular",
    "spectacularele": "spectacular",
    "spectacularelor": "spectacular",
    "spectaculari": "spectacular",
    "spectacularii": "spectacular",
    "spectacularilor": "spectacular",
    "spectacularul": "spectacular",
    "spectacularului": "spectacular",
    "spectaculoasa": "spectaculos",
    "spectaculoasă": "spectaculos",
    "spectaculoase": "spectaculos",
    "spectaculoasei": "spectaculos",
    "spectaculoasele": "spectaculos",
    "spectaculoaselor": "spectaculos",
    "spectaculoși": "spectaculos",
    "spectaculoșii": "spectaculos",
    "spectaculoșilor": "spectaculos",
    "spectaculosul": "spectaculos",
    "spectaculosului": "spectaculos",
    "spectaculozitatea": "spectaculozitate",
    "spectaculozități": "spectaculozitate",
    "spectaculozității": "spectaculozitate",
    "spectaculozitățile": "spectaculozitate",
    "spectaculozităților": "spectaculozitate",
    "spectatoarea": "spectatoare",
    "spectatoarei": "spectatoare",
    "spectatoarele": "spectatoare",
    "spectatoarelor": "spectatoare",
    "spectatori": "spectator",
    "spectatorii": "spectator",
    "spectatorilor": "spectator",
    "spectatorul": "spectator",
    "spectatorului": "spectator",
    "spectrala": "spectral",
    "spectrală": "spectral",
    "spectrale": "spectral",
    "spectralei": "spectral",
    "spectralele": "spectral",
    "spectralelor": "spectral",
    "spectrali": "spectral",
    "spectralii": "spectral",
    "spectralilor": "spectral",
    "spectralul": "spectral",
    "spectralului": "spectral",
    "spectrofotometria": "spectrofotometrie",
    "spectrofotometriei": "spectrofotometrie",
    "spectrofotometrii": "spectrofotometrie",
    "spectrofotometriile": "spectrofotometrie",
    "spectrofotometriilor": "spectrofotometrie",
    "spectrografe": "spectrograf",
    "spectrografele": "spectrograf",
    "spectrografelor": "spectrograf",
    "spectrograful": "spectrograf",
    "spectrografului": "spectrograf",
    "spectrometre": "spectrometru",
    "spectrometrele": "spectrometru",
    "spectrometrelor": "spectrometru",
    "spectrometrul": "spectrometru",
    "spectrometrului": "spectrometru",
    "spectroscoape": "spectroscop",
    "spectroscoapele": "spectroscop",
    "spectroscoapelor": "spectroscop",
    "spectroscopul": "spectroscop",
    "spectroscopului": "spectroscop",
    "spectroscopica": "spectroscopic",
    "spectroscopică": "spectroscopic",
    "spectroscopice": "spectroscopic",
    "spectroscopicei": "spectroscopic",
    "spectroscopicele": "spectroscopic",
    "spectroscopicelor": "spectroscopic",
    "spectroscopici": "spectroscopic",
    "spectroscopicii": "spectroscopic",
    "spectroscopicilor": "spectroscopic",
    "spectroscopicul": "spectroscopic",
    "spectroscopicului": "spectroscopic",
    "spectroscopia": "spectroscopie",
    "spectroscopiei": "spectroscopie",
    "spectroscopii": "spectroscopie",
    "spectroscopiile": "spectroscopie",
    "spectroscopiilor": "spectroscopie",
    "spectre": "spectru",
    "spectrele": "spectru",
    "spectrelor": "spectru",
    "spectrul": "spectru",
    "spectrului": "spectru",
    "nemaispeculând": "specula",
    "nemaispeculându": "specula",
    "nespeculând": "specula",
    "nespeculându": "specula",
    "speculă": "specula",
    "speculai": "specula",
    "speculam": "specula",
    "speculăm": "specula",
    "speculând": "specula",
    "speculându": "specula",
    "speculară": "specula",
    "specularăm": "specula",
    "specularăți": "specula",
    "speculase": "specula",
    "speculasem": "specula",
    "speculaseră": "specula",
    "speculaserăm": "specula",
    "speculaserăți": "specula",
    "speculaseși": "specula",
    "speculași": "specula",
    "speculat": "specula",
    "speculați": "specula",
    "speculau": "specula",
    "speculează": "specula",
    "speculez": "specula",
    "speculeze": "specula",
    "speculezi": "specula",
    "specula": "speculă",
    "specule": "speculă",
    "speculei": "speculă",
    "speculele": "speculă",
    "speculelor": "speculă",
    "specularea": "speculare",
    "speculări": "speculare",
    "speculării": "speculare",
    "speculările": "speculare",
    "speculărilor": "speculare",
    "speculată": "speculat",
    "speculate": "speculat",
    "speculați": "speculat",
    "speculația": "speculație",
    "speculației": "speculație",
    "speculații": "speculație",
    "speculațiile": "speculație",
    "speculațiilor": "speculație",
    "speculativa": "speculativ",
    "speculativă": "speculativ",
    "speculative": "speculativ",
    "speculativei": "speculativ",
    "speculativele": "speculativ",
    "speculativelor": "speculativ",
    "speculativi": "speculativ",
    "speculativii": "speculativ",
    "speculativilor": "speculativ",
    "speculativul": "speculativ",
    "speculativului": "speculativ",
    "spelunca": "speluncă",
    "spelunci": "speluncă",
    "speluncii": "speluncă",
    "speluncile": "speluncă",
    "speluncilor": "speluncă",
    "speologi": "speolog",
    "speologii": "speolog",
    "speologilor": "speolog",
    "speologul": "speolog",
    "speologului": "speolog",
    "speologica": "speologic",
    "speologică": "speologic",
    "speologice": "speologic",
    "speologicei": "speologic",
    "speologicele": "speologic",
    "speologicelor": "speologic",
    "speologici": "speologic",
    "speologicii": "speologic",
    "speologicilor": "speologic",
    "speologicul": "speologic",
    "speologicului": "speologic",
    "speologia": "speologie",
    "speologiei": "speologie",
    "speologii": "speologie",
    "speologiile": "speologie",
    "speologiilor": "speologie",
    "nemaisperând": "spera",
    "nemaisperându": "spera",
    "nesperând": "spera",
    "nesperându": "spera",
    "sper": "spera",
    "speră": "spera",
    "sperai": "spera",
    "speram": "spera",
    "sperăm": "spera",
    "sperând": "spera",
    "sperându": "spera",
    "sperară": "spera",
    "sperarăm": "spera",
    "sperarăți": "spera",
    "sperase": "spera",
    "sperasem": "spera",
    "speraseră": "spera",
    "speraserăm": "spera",
    "speraserăți": "spera",
    "speraseși": "spera",
    "sperași": "spera",
    "sperat": "spera",
    "sperați": "spera",
    "sperau": "spera",
    "spere": "spera",
    "speri": "spera",
    "șperacle": "șperaclu",
    "șperaclele": "șperaclu",
    "șperaclelor": "șperaclu",
    "șperaclul": "șperaclu",
    "șperaclului": "șperaclu",
    "speranța": "speranță",
    "speranțe": "speranță",
    "speranței": "speranță",
    "speranțele": "speranță",
    "speranțelor": "speranță",
    "sperată": "sperat",
    "sperate": "sperat",
    "sperați": "sperat",
    "nemaisperiind": "speria",
    "nemaisperiindu": "speria",
    "nesperiind": "speria",
    "nesperiindu": "speria",
    "speriai": "speria",
    "speriam": "speria",
    "speriară": "speria",
    "speriarăm": "speria",
    "speriarăți": "speria",
    "speriase": "speria",
    "speriasem": "speria",
    "speriaseră": "speria",
    "speriaserăm": "speria",
    "speriaserăți": "speria",
    "speriaseși": "speria",
    "speriași": "speria",
    "speriat": "speria",
    "speriați": "speria",
    "speriau": "speria",
    "sperie": "speria",
    "speriem": "speria",
    "sperii": "speria",
    "speriind": "speria",
    "speriindu": "speria",
    "speriata": "speriat",
    "speriată": "speriat",
    "speriate": "speriat",
    "speriatei": "speriat",
    "speriatele": "speriat",
    "speriatelor": "speriat",
    "speriați": "speriat",
    "speriații": "speriat",
    "speriaților": "speriat",
    "speriato": "speriat",
    "speriatul": "speriat",
    "speriatule": "speriat",
    "speriatului": "speriat",
    "sperietoarea": "sperietoare",
    "sperietori": "sperietoare",
    "sperietorii": "sperietoare",
    "sperietorile": "sperietoare",
    "sperietorilor": "sperietoare",
    "sperietura": "sperietură",
    "sperieturi": "sperietură",
    "sperieturii": "sperietură",
    "sperieturile": "sperietură",
    "sperieturilor": "sperietură",
    "sperioasa": "sperios",
    "sperioasă": "sperios",
    "sperioase": "sperios",
    "sperioasei": "sperios",
    "sperioasele": "sperios",
    "sperioaselor": "sperios",
    "sperioși": "sperios",
    "sperioșii": "sperios",
    "sperioșilor": "sperios",
    "speriosul": "sperios",
    "speriosului": "sperios",
    "sperjuri": "sperjur",
    "sperjurii": "sperjur",
    "sperjurilor": "sperjur",
    "sperjurul": "sperjur",
    "sperjurului": "sperjur",
    "sperjura": "sperjură",
    "sperjure": "sperjură",
    "sperjurei": "sperjură",
    "sperjurele": "sperjură",
    "sperjurelor": "sperjură",
    "sperma": "spermă",
    "sperme": "spermă",
    "spermei": "spermă",
    "spermele": "spermă",
    "spermelor": "spermă",
    "spermatica": "spermatic",
    "spermatică": "spermatic",
    "spermatice": "spermatic",
    "spermaticei": "spermatic",
    "spermaticele": "spermatic",
    "spermaticelor": "spermatic",
    "spermatici": "spermatic",
    "spermaticii": "spermatic",
    "spermaticilor": "spermatic",
    "spermaticul": "spermatic",
    "spermaticului": "spermatic",
    "spermatofita": "spermatofită",
    "spermatofite": "spermatofită",
    "spermatofitei": "spermatofită",
    "spermatofitele": "spermatofită",
    "spermatofitelor": "spermatofită",
    "spermatozoidul": "spermatozoid",
    "spermatozoidului": "spermatozoid",
    "spermatozoizi": "spermatozoid",
    "spermatozoizii": "spermatozoid",
    "spermatozoizilor": "spermatozoid",
    "șperțul": "șperț",
    "șperțului": "șperț",
    "șperțuri": "șperț",
    "șperțurile": "șperț",
    "șperțurilor": "șperț",
    "șperțari": "șperțar",
    "șperțarii": "șperțar",
    "șperțarilor": "șperțar",
    "șperțarul": "șperțar",
    "șperțarului": "șperțar",
    "nemaișperțuind": "șperțui",
    "nemaișperțuindu": "șperțui",
    "neșperțuind": "șperțui",
    "neșperțuindu": "șperțui",
    "șperțuia": "șperțui",
    "șperțuiai": "șperțui",
    "șperțuiam": "șperțui",
    "șperțuiască": "șperțui",
    "șperțuiați": "șperțui",
    "șperțuiau": "șperțui",
    "șperțuiesc": "șperțui",
    "șperțuiește": "șperțui",
    "șperțuiești": "șperțui",
    "șperțuii": "șperțui",
    "șperțuim": "șperțui",
    "șperțuind": "șperțui",
    "șperțuindu": "șperțui",
    "șperțuiră": "șperțui",
    "șperțuirăm": "șperțui",
    "șperțuirăți": "șperțui",
    "șperțuise": "șperțui",
    "șperțuisem": "șperțui",
    "șperțuiseră": "șperțui",
    "șperțuiserăm": "șperțui",
    "șperțuiserăți": "șperțui",
    "șperțuiseși": "șperțui",
    "șperțuiși": "șperțui",
    "șperțuit": "șperțui",
    "șperțuiți": "șperțui",
    "șperțuiala": "șperțuială",
    "șperțuialo": "șperțuială",
    "șperțuieli": "șperțuială",
    "șperțuielii": "șperțuială",
    "șperțuielile": "șperțuială",
    "șperțuielilor": "șperțuială",
    "șperțuită": "șperțuit",
    "șperțuite": "șperțuit",
    "șperțuiți": "șperțuit",
    "speța": "speță",
    "spețe": "speță",
    "speței": "speță",
    "spețele": "speță",
    "spețelor": "speță",
    "speteaza": "spetează",
    "speteze": "spetează",
    "spetezei": "spetează",
    "spetezele": "spetează",
    "spetezelor": "spetează",
    "nemaispetind": "speti",
    "nemaispetindu": "speti",
    "nespetind": "speti",
    "nespetindu": "speti",
    "spetea": "speti",
    "speteai": "speti",
    "speteam": "speti",
    "spetească": "speti",
    "speteați": "speti",
    "speteau": "speti",
    "spetesc": "speti",
    "spetește": "speti",
    "spetești": "speti",
    "spetii": "speti",
    "spetim": "speti",
    "spetind": "speti",
    "spetindu": "speti",
    "spetiră": "speti",
    "spetirăm": "speti",
    "spetirăți": "speti",
    "spetise": "speti",
    "spetisem": "speti",
    "spetiseră": "speti",
    "spetiserăm": "speti",
    "spetiserăți": "speti",
    "spetiseși": "speti",
    "spetiși": "speti",
    "spetit": "speti",
    "spetiți": "speti",
    "spetită": "spetit",
    "spetite": "spetit",
    "spetiți": "spetit",
    "spice": "spic",
    "spicele": "spic",
    "spicelor": "spic",
    "spicul": "spic",
    "spicului": "spic",
    "spicheri": "spicher",
    "spicherii": "spicher",
    "spicherilor": "spicher",
    "spicherul": "spicher",
    "spicherului": "spicher",
    "spicherița": "spicheriță",
    "spicherițe": "spicheriță",
    "spicheriței": "spicheriță",
    "spicherițele": "spicheriță",
    "spicherițelor": "spicheriță",
    "șpilul": "șpil",
    "șpilului": "șpil",
    "șpiluri": "șpil",
    "șpilurile": "șpil",
    "șpilurilor": "șpil",
    "nemaispilcuind": "spilcui",
    "nemaispilcuindu": "spilcui",
    "nespilcuind": "spilcui",
    "nespilcuindu": "spilcui",
    "spilcuia": "spilcui",
    "spilcuiai": "spilcui",
    "spilcuiam": "spilcui",
    "spilcuiască": "spilcui",
    "spilcuiați": "spilcui",
    "spilcuiau": "spilcui",
    "spilcuiesc": "spilcui",
    "spilcuiește": "spilcui",
    "spilcuiești": "spilcui",
    "spilcuii": "spilcui",
    "spilcuim": "spilcui",
    "spilcuind": "spilcui",
    "spilcuindu": "spilcui",
    "spilcuiră": "spilcui",
    "spilcuirăm": "spilcui",
    "spilcuirăți": "spilcui",
    "spilcuise": "spilcui",
    "spilcuisem": "spilcui",
    "spilcuiseră": "spilcui",
    "spilcuiserăm": "spilcui",
    "spilcuiserăți": "spilcui",
    "spilcuiseși": "spilcui",
    "spilcuiși": "spilcui",
    "spilcuit": "spilcui",
    "spilcuiți": "spilcui",
    "spilcuită": "spilcuit",
    "spilcuite": "spilcuit",
    "spilcuiți": "spilcuit",
    "spini": "spin",
    "spinii": "spin",
    "spinilor": "spin",
    "spinul": "spin",
    "spinului": "spin",
    "spinala": "spinal",
    "spinală": "spinal",
    "spinale": "spinal",
    "spinalei": "spinal",
    "spinalele": "spinal",
    "spinalelor": "spinal",
    "spinali": "spinal",
    "spinalii": "spinal",
    "spinalilor": "spinal",
    "spinalul": "spinal",
    "spinalului": "spinal",
    "spinarea": "spinare",
    "spinări": "spinare",
    "spinării": "spinare",
    "spinările": "spinare",
    "spinărilor": "spinare",
    "spinăria": "spinărie",
    "spinăriei": "spinărie",
    "spinării": "spinărie",
    "spinăriile": "spinărie",
    "spinăriilor": "spinărie",
    "spineli": "spinel",
    "spinelii": "spinel",
    "spinelilor": "spinel",
    "spinelul": "spinel",
    "spinelului": "spinel",
    "spinoasa": "spinos",
    "spinoasă": "spinos",
    "spinoase": "spinos",
    "spinoasei": "spinos",
    "spinoasele": "spinos",
    "spinoaselor": "spinos",
    "spinoși": "spinos",
    "spinoșii": "spinos",
    "spinoșilor": "spinos",
    "spinosul": "spinos",
    "spinosului": "spinos",
    "nemaispintecând": "spinteca",
    "nemaispintecându": "spinteca",
    "nespintecând": "spinteca",
    "nespintecându": "spinteca",
    "spintec": "spinteca",
    "spintecă": "spinteca",
    "spintecai": "spinteca",
    "spintecam": "spinteca",
    "spintecăm": "spinteca",
    "spintecând": "spinteca",
    "spintecându": "spinteca",
    "spintecară": "spinteca",
    "spintecarăm": "spinteca",
    "spintecarăți": "spinteca",
    "spintecase": "spinteca",
    "spintecasem": "spinteca",
    "spintecaseră": "spinteca",
    "spintecaserăm": "spinteca",
    "spintecaserăți": "spinteca",
    "spintecaseși": "spinteca",
    "spintecași": "spinteca",
    "spintecat": "spinteca",
    "spintecați": "spinteca",
    "spintecau": "spinteca",
    "spintece": "spinteca",
    "spinteci": "spinteca",
    "spintecarea": "spintecare",
    "spintecareo": "spintecare",
    "spintecări": "spintecare",
    "spintecării": "spintecare",
    "spintecările": "spintecare",
    "spintecărilor": "spintecare",
    "spintecata": "spintecat",
    "spintecată": "spintecat",
    "spintecate": "spintecat",
    "spintecatei": "spintecat",
    "spintecatele": "spintecat",
    "spintecatelor": "spintecat",
    "spintecați": "spintecat",
    "spintecații": "spintecat",
    "spintecaților": "spintecat",
    "spintecato": "spintecat",
    "spintecatul": "spintecat",
    "spintecatule": "spintecat",
    "spintecatului": "spintecat",
    "spintecătura": "spintecătură",
    "spintecături": "spintecătură",
    "spintecăturii": "spintecătură",
    "spintecăturile": "spintecătură",
    "spintecăturilor": "spintecătură",
    "spioana": "spioană",
    "spioane": "spioană",
    "spioanei": "spioană",
    "spioanele": "spioană",
    "spioanelor": "spioană",
    "spioni": "spion",
    "spionii": "spion",
    "spionilor": "spion",
    "spionul": "spion",
    "spionului": "spion",
    "nemaispionând": "spiona",
    "nemaispionându": "spiona",
    "nespionând": "spiona",
    "nespionându": "spiona",
    "spionă": "spiona",
    "spionai": "spiona",
    "spionam": "spiona",
    "spionăm": "spiona",
    "spionând": "spiona",
    "spionându": "spiona",
    "spionară": "spiona",
    "spionarăm": "spiona",
    "spionarăți": "spiona",
    "spionase": "spiona",
    "spionasem": "spiona",
    "spionaseră": "spiona",
    "spionaserăm": "spiona",
    "spionaserăți": "spiona",
    "spionaseși": "spiona",
    "spionași": "spiona",
    "spionat": "spiona",
    "spionați": "spiona",
    "spionau": "spiona",
    "spionează": "spiona",
    "spionez": "spiona",
    "spioneze": "spiona",
    "spionezi": "spiona",
    "spionaje": "spionaj",
    "spionajele": "spionaj",
    "spionajelor": "spionaj",
    "spionajul": "spionaj",
    "spionajului": "spionaj",
    "spionarea": "spionare",
    "spionareo": "spionare",
    "spionări": "spionare",
    "spionării": "spionare",
    "spionările": "spionare",
    "spionărilor": "spionare",
    "spionată": "spionat",
    "spionate": "spionat",
    "spionați": "spionat",
    "spira": "spiră",
    "spire": "spiră",
    "spirei": "spiră",
    "spirele": "spiră",
    "spirelor": "spiră",
    "spiraiul": "spirai",
    "spiraiului": "spirai",
    "spiraiuri": "spirai",
    "spiraiurile": "spirai",
    "spiraiurilor": "spirai",
    "spirala": "spirală",
    "spirale": "spirală",
    "spiralei": "spirală",
    "spiralele": "spirală",
    "spiralelor": "spirală",
    "spiranta": "spirant",
    "spirantă": "spirant",
    "spirante": "spirant",
    "spirantei": "spirant",
    "spirantele": "spirant",
    "spirantelor": "spirant",
    "spiranți": "spirant",
    "spiranții": "spirant",
    "spiranților": "spirant",
    "spirantul": "spirant",
    "spirantului": "spirant",
    "spiriduși": "spiriduș",
    "spiridușii": "spiriduș",
    "spiridușilor": "spiriduș",
    "spiridușul": "spiriduș",
    "spiridușului": "spiriduș",
    "spirili": "spiril",
    "spirilii": "spiril",
    "spirililor": "spiril",
    "spirilul": "spiril",
    "spirilului": "spiril",
    "spirite": "spirit",
    "spiritele": "spirit",
    "spiritelor": "spirit",
    "spiritul": "spirit",
    "spiritului": "spirit",
    "spiritismul": "spiritism",
    "spiritismului": "spiritism",
    "spiritiști": "spiritist",
    "spiritiștii": "spiritist",
    "spiritiștilor": "spiritist",
    "spiritistul": "spiritist",
    "spiritistului": "spiritist",
    "spiritista": "spiritistă",
    "spiritiste": "spiritistă",
    "spiritistei": "spiritistă",
    "spiritistele": "spiritistă",
    "spiritistelor": "spiritistă",
    "spirituala": "spiritual",
    "spirituală": "spiritual",
    "spirituale": "spiritual",
    "spiritualei": "spiritual",
    "spiritualele": "spiritual",
    "spiritualelor": "spiritual",
    "spirituali": "spiritual",
    "spiritualii": "spiritual",
    "spiritualilor": "spiritual",
    "spiritualul": "spiritual",
    "spiritualului": "spiritual",
    "spiritualismul": "spiritualism",
    "spiritualismului": "spiritualism",
    "spiritualitatea": "spiritualitate",
    "spiritualități": "spiritualitate",
    "spiritualității": "spiritualitate",
    "spiritualitățile": "spiritualitate",
    "spiritualităților": "spiritualitate",
    "nemaispiritualizând": "spiritualiza",
    "nemaispiritualizându": "spiritualiza",
    "nespiritualizând": "spiritualiza",
    "nespiritualizându": "spiritualiza",
    "spiritualiză": "spiritualiza",
    "spiritualizai": "spiritualiza",
    "spiritualizam": "spiritualiza",
    "spiritualizăm": "spiritualiza",
    "spiritualizând": "spiritualiza",
    "spiritualizându": "spiritualiza",
    "spiritualizară": "spiritualiza",
    "spiritualizarăm": "spiritualiza",
    "spiritualizarăți": "spiritualiza",
    "spiritualizase": "spiritualiza",
    "spiritualizasem": "spiritualiza",
    "spiritualizaseră": "spiritualiza",
    "spiritualizaserăm": "spiritualiza",
    "spiritualizaserăți": "spiritualiza",
    "spiritualizaseși": "spiritualiza",
    "spiritualizași": "spiritualiza",
    "spiritualizat": "spiritualiza",
    "spiritualizați": "spiritualiza",
    "spiritualizau": "spiritualiza",
    "spiritualizează": "spiritualiza",
    "spiritualizez": "spiritualiza",
    "spiritualizeze": "spiritualiza",
    "spiritualizezi": "spiritualiza",
    "spiritualizată": "spiritualizat",
    "spiritualizate": "spiritualizat",
    "spiritualizați": "spiritualizat",
    "spirocheți": "spirochet",
    "spirocheții": "spirochet",
    "spirocheților": "spirochet",
    "spirochetul": "spirochet",
    "spirochetului": "spirochet",
    "spirometre": "spirometru",
    "spirometrele": "spirometru",
    "spirometrelor": "spirometru",
    "spirometrul": "spirometru",
    "spirometrului": "spirometru",
    "spirtul": "spirt",
    "spirtului": "spirt",
    "spirtiera": "spirtieră",
    "spirtiere": "spirtieră",
    "spirtierei": "spirtieră",
    "spirtierele": "spirtieră",
    "spirtierelor": "spirtieră",
    "spirtoasa": "spirtos",
    "spirtoasă": "spirtos",
    "spirtoase": "spirtos",
    "spirtoasei": "spirtos",
    "spirtoasele": "spirtos",
    "spirtoaselor": "spirtos",
    "spirtoși": "spirtos",
    "spirtoșii": "spirtos",
    "spirtoșilor": "spirtos",
    "spirtosul": "spirtos",
    "spirtosului": "spirtos",
    "șpițul": "șpiț",
    "șpițului": "șpiț",
    "șpițuri": "șpiț",
    "șpițurile": "șpiț",
    "șpițurilor": "șpiț",
    "spița": "spiță",
    "spițe": "spiță",
    "spiței": "spiță",
    "spițele": "spiță",
    "spițelor": "spiță",
    "spitale": "spital",
    "spitalele": "spital",
    "spitalelor": "spital",
    "spitalul": "spital",
    "spitalului": "spital",
    "spt.": "spital",
    "nemaispitalizând": "spitaliza",
    "nemaispitalizându": "spitaliza",
    "nespitalizând": "spitaliza",
    "nespitalizându": "spitaliza",
    "spitaliză": "spitaliza",
    "spitalizai": "spitaliza",
    "spitalizam": "spitaliza",
    "spitalizăm": "spitaliza",
    "spitalizând": "spitaliza",
    "spitalizându": "spitaliza",
    "spitalizară": "spitaliza",
    "spitalizarăm": "spitaliza",
    "spitalizarăți": "spitaliza",
    "spitalizase": "spitaliza",
    "spitalizasem": "spitaliza",
    "spitalizaseră": "spitaliza",
    "spitalizaserăm": "spitaliza",
    "spitalizaserăți": "spitaliza",
    "spitalizaseși": "spitaliza",
    "spitalizași": "spitaliza",
    "spitalizat": "spitaliza",
    "spitalizați": "spitaliza",
    "spitalizau": "spitaliza",
    "spitalizează": "spitaliza",
    "spitalizez": "spitaliza",
    "spitalizeze": "spitaliza",
    "spitalizezi": "spitaliza",
    "spitalizarea": "spitalizare",
    "spitalizări": "spitalizare",
    "spitalizării": "spitalizare",
    "spitalizările": "spitalizare",
    "spitalizărilor": "spitalizare",
    "spitalizată": "spitalizat",
    "spitalizate": "spitalizat",
    "spitalizați": "spitalizat",
    "spițeri": "spițer",
    "spițerii": "spițer",
    "spițerilor": "spițer",
    "spițerul": "spițer",
    "spițerului": "spițer",
    "spițeria": "spițerie",
    "spițeriei": "spițerie",
    "spițerii": "spițerie",
    "spițeriile": "spițerie",
    "spițeriilor": "spițerie",
    "splaiul": "splai",
    "splaiului": "splai",
    "splaiuri": "splai",
    "splaiurile": "splai",
    "splaiurilor": "splai",
    "splendida": "splendid",
    "splendidă": "splendid",
    "splendide": "splendid",
    "splendidei": "splendid",
    "splendidele": "splendid",
    "splendidelor": "splendid",
    "splendidul": "splendid",
    "splendidului": "splendid",
    "splendizi": "splendid",
    "splendizii": "splendid",
    "splendizilor": "splendid",
    "splendoarea": "splendoare",
    "splendori": "splendoare",
    "splendorii": "splendoare",
    "splendorile": "splendoare",
    "splendorilor": "splendoare",
    "splenica": "splenic",
    "splenică": "splenic",
    "splenice": "splenic",
    "splenicei": "splenic",
    "splenicele": "splenic",
    "splenicelor": "splenic",
    "splenici": "splenic",
    "splenicii": "splenic",
    "splenicilor": "splenic",
    "splenicul": "splenic",
    "splenicului": "splenic",
    "splina": "splină",
    "spline": "splină",
    "splinei": "splină",
    "splinele": "splină",
    "splinelor": "splină",
    "splintul": "splint",
    "splintului": "splint",
    "splinturi": "splint",
    "splinturile": "splint",
    "splinturilor": "splint",
    "șplintul": "șplint",
    "șplintului": "șplint",
    "șplinturi": "șplint",
    "șplinturile": "șplint",
    "șplinturilor": "șplint",
    "nemaispoind": "spoi",
    "nemaispoindu": "spoi",
    "nespoind": "spoi",
    "nespoindu": "spoi",
    "spoia": "spoi",
    "spoiai": "spoi",
    "spoiam": "spoi",
    "spoiască": "spoi",
    "spoiați": "spoi",
    "spoiau": "spoi",
    "spoiesc": "spoi",
    "spoiește": "spoi",
    "spoiești": "spoi",
    "spoii": "spoi",
    "spoim": "spoi",
    "spoind": "spoi",
    "spoindu": "spoi",
    "spoiră": "spoi",
    "spoirăm": "spoi",
    "spoirăți": "spoi",
    "spoise": "spoi",
    "spoisem": "spoi",
    "spoiseră": "spoi",
    "spoiserăm": "spoi",
    "spoiserăți": "spoi",
    "spoiseși": "spoi",
    "spoiși": "spoi",
    "spoit": "spoi",
    "spoiți": "spoi",
    "spoiala": "spoială",
    "spoieli": "spoială",
    "spoielii": "spoială",
    "spoielile": "spoială",
    "spoielilor": "spoială",
    "spoită": "spoit",
    "spoite": "spoit",
    "spoiți": "spoit",
    "spoliatoarea": "spoliatoare",
    "spoliatoarei": "spoliatoare",
    "spoliatoarele": "spoliatoare",
    "spoliatoarelor": "spoliatoare",
    "spoliatori": "spoliator",
    "spoliatorii": "spoliator",
    "spoliatorilor": "spoliator",
    "spoliatorul": "spoliator",
    "spoliatorului": "spoliator",
    "spondilita": "spondilită",
    "spondilite": "spondilită",
    "spondilitei": "spondilită",
    "spondilitele": "spondilită",
    "spondilitelor": "spondilită",
    "spondiloza": "spondiloză",
    "spondiloze": "spondiloză",
    "spondilozei": "spondiloză",
    "spondilozele": "spondiloză",
    "spondilozelor": "spondiloză",
    "spongieri": "spongier",
    "spongierii": "spongier",
    "spongierilor": "spongier",
    "spongierul": "spongier",
    "spongierului": "spongier",
    "spongioasa": "spongios",
    "spongioasă": "spongios",
    "spongioase": "spongios",
    "spongioasei": "spongios",
    "spongioasele": "spongios",
    "spongioaselor": "spongios",
    "spongioși": "spongios",
    "spongioșii": "spongios",
    "spongioșilor": "spongios",
    "spongiosul": "spongios",
    "spongiosului": "spongios",
    "sponsorizarea": "sponsorizare",
    "sponsorizări": "sponsorizare",
    "sponsorizării": "sponsorizare",
    "sponsorizările": "sponsorizare",
    "sponsorizărilor": "sponsorizare",
    "spontana": "spontan",
    "spontană": "spontan",
    "spontane": "spontan",
    "spontanei": "spontan",
    "spontanele": "spontan",
    "spontanelor": "spontan",
    "spontani": "spontan",
    "spontanii": "spontan",
    "spontanilor": "spontan",
    "spontanul": "spontan",
    "spontanului": "spontan",
    "spontaneitatea": "spontaneitate",
    "spontaneități": "spontaneitate",
    "spontaneității": "spontaneitate",
    "spontaneitățile": "spontaneitate",
    "spontaneităților": "spontaneitate",
    "spori": "spor",
    "sporii": "spor",
    "sporilor": "spor",
    "sporul": "spor",
    "sporului": "spor",
    "sporuri": "spor",
    "sporurile": "spor",
    "sporurilor": "spor",
    "sporadica": "sporadic",
    "sporadică": "sporadic",
    "sporadice": "sporadic",
    "sporadicei": "sporadic",
    "sporadicele": "sporadic",
    "sporadicelor": "sporadic",
    "sporadici": "sporadic",
    "sporadicii": "sporadic",
    "sporadicilor": "sporadic",
    "sporadicul": "sporadic",
    "sporadicului": "sporadic",
    "sporangele": "sporange",
    "sporangelui": "sporange",
    "sporangi": "sporange",
    "sporangii": "sporange",
    "sporangilor": "sporange",
    "nemaisporind": "spori",
    "nemaisporindu": "spori",
    "nesporind": "spori",
    "nesporindu": "spori",
    "sporea": "spori",
    "sporeai": "spori",
    "spoream": "spori",
    "sporească": "spori",
    "sporeați": "spori",
    "sporeau": "spori",
    "sporesc": "spori",
    "sporește": "spori",
    "sporești": "spori",
    "sporii": "spori",
    "sporim": "spori",
    "sporind": "spori",
    "sporindu": "spori",
    "sporiră": "spori",
    "sporirăm": "spori",
    "sporirăți": "spori",
    "sporise": "spori",
    "sporisem": "spori",
    "sporiseră": "spori",
    "sporiserăm": "spori",
    "sporiserăți": "spori",
    "sporiseși": "spori",
    "sporiși": "spori",
    "sporit": "spori",
    "sporiți": "spori",
    "sporifera": "sporifer",
    "sporiferă": "sporifer",
    "sporifere": "sporifer",
    "sporiferei": "sporifer",
    "sporiferele": "sporifer",
    "sporiferelor": "sporifer",
    "sporiferi": "sporifer",
    "sporiferii": "sporifer",
    "sporiferilor": "sporifer",
    "sporiferul": "sporifer",
    "sporiferului": "sporifer",
    "sporirea": "sporire",
    "sporiri": "sporire",
    "sporirii": "sporire",
    "sporirile": "sporire",
    "sporirilor": "sporire",
    "sporită": "sporit",
    "sporite": "sporit",
    "sporiți": "sporit",
    "spornica": "spornic",
    "spornică": "spornic",
    "spornice": "spornic",
    "spornicei": "spornic",
    "spornicele": "spornic",
    "spornicelor": "spornic",
    "spornici": "spornic",
    "nemaisporovăind": "sporovăi",
    "nemaisporovăindu": "sporovăi",
    "nesporovăind": "sporovăi",
    "nesporovăindu": "sporovăi",
    "sporovăia": "sporovăi",
    "sporovăiai": "sporovăi",
    "sporovăiam": "sporovăi",
    "sporovăiască": "sporovăi",
    "sporovăiați": "sporovăi",
    "sporovăiau": "sporovăi",
    "sporovăie": "sporovăi",
    "sporovăiesc": "sporovăi",
    "sporovăiește": "sporovăi",
    "sporovăiești": "sporovăi",
    "sporovăii": "sporovăi",
    "sporovăim": "sporovăi",
    "sporovăind": "sporovăi",
    "sporovăindu": "sporovăi",
    "sporovăiră": "sporovăi",
    "sporovăirăm": "sporovăi",
    "sporovăirăți": "sporovăi",
    "sporovăise": "sporovăi",
    "sporovăisem": "sporovăi",
    "sporovăiseră": "sporovăi",
    "sporovăiserăm": "sporovăi",
    "sporovăiserăți": "sporovăi",
    "sporovăiseși": "sporovăi",
    "sporovăiși": "sporovăi",
    "sporovăit": "sporovăi",
    "sporovăiți": "sporovăi",
    "sporovăitu": "sporovăi",
    "sporovăirea": "sporovăire",
    "sporovăiri": "sporovăire",
    "sporovăirii": "sporovăire",
    "sporovăirile": "sporovăire",
    "sporovăirilor": "sporovăire",
    "sporovăită": "sporovăit",
    "sporovăite": "sporovăit",
    "sporovăiți": "sporovăit",
    "sporozoare": "sporozoar",
    "sporozoarele": "sporozoar",
    "sporozoarelor": "sporozoar",
    "sporozoarul": "sporozoar",
    "sporozoarului": "sporozoar",
    "sportul": "sport",
    "sportului": "sport",
    "sporturi": "sport",
    "sporturile": "sport",
    "sporturilor": "sport",
    "sportiva": "sportiv",
    "sportivă": "sportiv",
    "sportive": "sportiv",
    "sportivei": "sportiv",
    "sportivele": "sportiv",
    "sportivelor": "sportiv",
    "sportivi": "sportiv",
    "sportivii": "sportiv",
    "sportivilor": "sportiv",
    "sportivul": "sportiv",
    "sportivului": "sportiv",
    "sportiva": "sportivă",
    "sportive": "sportivă",
    "sportivei": "sportivă",
    "sportivele": "sportivă",
    "sportivelor": "sportivă",
    "sportivitatea": "sportivitate",
    "sportivități": "sportivitate",
    "sportivității": "sportivitate",
    "sportivitățile": "sportivitate",
    "sportivităților": "sportivitate",
    "sporulata": "sporulat",
    "sporulată": "sporulat",
    "sporulate": "sporulat",
    "sporulatei": "sporulat",
    "sporulatele": "sporulat",
    "sporulatelor": "sporulat",
    "sporulați": "sporulat",
    "sporulații": "sporulat",
    "sporulaților": "sporulat",
    "sporulatul": "sporulat",
    "sporulatului": "sporulat",
    "spotul": "spot",
    "spotului": "spot",
    "spoturi": "spot",
    "spoturile": "spot",
    "spoturilor": "spot",
    "spovedania": "spovedanie",
    "spovedaniei": "spovedanie",
    "spovedanii": "spovedanie",
    "spovedaniile": "spovedanie",
    "spovedaniilor": "spovedanie",
    "nemaispovedind": "spovedi",
    "nemaispovedindu": "spovedi",
    "nespovedind": "spovedi",
    "nespovedindu": "spovedi",
    "spovedea": "spovedi",
    "spovedeai": "spovedi",
    "spovedeam": "spovedi",
    "spovedească": "spovedi",
    "spovedeați": "spovedi",
    "spovedeau": "spovedi",
    "spovedesc": "spovedi",
    "spovedește": "spovedi",
    "spovedești": "spovedi",
    "spovedii": "spovedi",
    "spovedim": "spovedi",
    "spovedind": "spovedi",
    "spovedindu": "spovedi",
    "spovediră": "spovedi",
    "spovedirăm": "spovedi",
    "spovedirăți": "spovedi",
    "spovedise": "spovedi",
    "spovedisem": "spovedi",
    "spovediseră": "spovedi",
    "spovediserăm": "spovedi",
    "spovediserăți": "spovedi",
    "spovediseși": "spovedi",
    "spovediși": "spovedi",
    "spovedit": "spovedi",
    "spovediți": "spovedi",
    "spovedirea": "spovedire",
    "spovediri": "spovedire",
    "spovedirii": "spovedire",
    "spovedirile": "spovedire",
    "spovedirilor": "spovedire",
    "spovedită": "spovedit",
    "spovedite": "spovedit",
    "spovediți": "spovedit",
    "șpraițul": "șpraiț",
    "șpraițului": "șpraiț",
    "șpraițuri": "șpraiț",
    "șpraițurile": "șpraiț",
    "șpraițurilor": "șpraiț",
    "sprânceana": "sprânceană",
    "sprâncene": "sprânceană",
    "sprâncenei": "sprânceană",
    "sprâncenele": "sprânceană",
    "sprâncenelor": "sprânceană",
    "sprâncenata": "sprâncenat",
    "sprâncenată": "sprâncenat",
    "sprâncenate": "sprâncenat",
    "sprâncenatei": "sprâncenat",
    "sprâncenatele": "sprâncenat",
    "sprâncenatelor": "sprâncenat",
    "sprâncenați": "sprâncenat",
    "sprâncenații": "sprâncenat",
    "sprâncenaților": "sprâncenat",
    "sprâncenatul": "sprâncenat",
    "sprâncenatului": "sprâncenat",
    "sprijine": "sprijin",
    "sprijinele": "sprijin",
    "sprijinelor": "sprijin",
    "sprijinul": "sprijin",
    "sprijinului": "sprijin",
    "nemaisprijinind": "sprijini",
    "nemaisprijinindu": "sprijini",
    "nesprijinind": "sprijini",
    "nesprijinindu": "sprijini",
    "sprijin": "sprijini",
    "sprijină": "sprijini",
    "sprijine": "sprijini",
    "sprijinea": "sprijini",
    "sprijineai": "sprijini",
    "sprijineam": "sprijini",
    "sprijineați": "sprijini",
    "sprijineau": "sprijini",
    "sprijinii": "sprijini",
    "sprijinim": "sprijini",
    "sprijinind": "sprijini",
    "sprijinindu": "sprijini",
    "sprijiniră": "sprijini",
    "sprijinirăm": "sprijini",
    "sprijinirăți": "sprijini",
    "sprijinise": "sprijini",
    "sprijinisem": "sprijini",
    "sprijiniseră": "sprijini",
    "sprijiniserăm": "sprijini",
    "sprijiniserăți": "sprijini",
    "sprijiniseși": "sprijini",
    "sprijiniși": "sprijini",
    "sprijinit": "sprijini",
    "sprijiniți": "sprijini",
    "sprijinirea": "sprijinire",
    "sprijinireo": "sprijinire",
    "sprijiniri": "sprijinire",
    "sprijinirii": "sprijinire",
    "sprijinirile": "sprijinire",
    "sprijinirilor": "sprijinire",
    "sprijinita": "sprijinit",
    "sprijinită": "sprijinit",
    "sprijinite": "sprijinit",
    "sprijinitei": "sprijinit",
    "sprijinitele": "sprijinit",
    "sprijinitelor": "sprijinit",
    "sprijiniți": "sprijinit",
    "sprijiniții": "sprijinit",
    "sprijiniților": "sprijinit",
    "sprijinito": "sprijinit",
    "sprijinitul": "sprijinit",
    "sprijinitule": "sprijinit",
    "sprijinitului": "sprijinit",
    "sprintul": "sprint",
    "sprintului": "sprint",
    "sprinturi": "sprint",
    "sprinturile": "sprint",
    "sprinturilor": "sprint",
    "nemaisprintând": "sprinta",
    "nemaisprintându": "sprinta",
    "nesprintând": "sprinta",
    "nesprintându": "sprinta",
    "sprintă": "sprinta",
    "sprintai": "sprinta",
    "sprintam": "sprinta",
    "sprintăm": "sprinta",
    "sprintând": "sprinta",
    "sprintându": "sprinta",
    "sprintară": "sprinta",
    "sprintarăm": "sprinta",
    "sprintarăți": "sprinta",
    "sprintase": "sprinta",
    "sprintasem": "sprinta",
    "sprintaseră": "sprinta",
    "sprintaserăm": "sprinta",
    "sprintaserăți": "sprinta",
    "sprintaseși": "sprinta",
    "sprintași": "sprinta",
    "sprintat": "sprinta",
    "sprintați": "sprinta",
    "sprintau": "sprinta",
    "sprintează": "sprinta",
    "sprintez": "sprinta",
    "sprinteze": "sprinta",
    "sprintezi": "sprinta",
    "sprințara": "sprințar",
    "sprințară": "sprințar",
    "sprințare": "sprințar",
    "sprințarei": "sprințar",
    "sprințarele": "sprințar",
    "sprințarelor": "sprințar",
    "sprințari": "sprințar",
    "sprințarii": "sprințar",
    "sprințarilor": "sprințar",
    "sprințarul": "sprințar",
    "sprințarului": "sprințar",
    "sprintată": "sprintat",
    "sprintate": "sprintat",
    "sprintați": "sprintat",
    "sprintena": "sprinten",
    "sprintenă": "sprinten",
    "sprintene": "sprinten",
    "sprintenei": "sprinten",
    "sprintenele": "sprinten",
    "sprintenelor": "sprinten",
    "sprinteni": "sprinten",
    "sprintenii": "sprinten",
    "sprintenilor": "sprinten",
    "sprintenul": "sprinten",
    "sprintenului": "sprinten",
    "sprinteneala": "sprinteneală",
    "sprinteneli": "sprinteneală",
    "sprintenelii": "sprinteneală",
    "sprintenelile": "sprinteneală",
    "sprintenelilor": "sprinteneală",
    "sprinteri": "sprinter",
    "sprinterii": "sprinter",
    "sprinterilor": "sprinter",
    "sprinterul": "sprinter",
    "sprinterului": "sprinter",
    "sprintera": "sprinteră",
    "sprintere": "sprinteră",
    "sprinterei": "sprinteră",
    "sprinterele": "sprinteră",
    "sprinterelor": "sprinteră",
    "șprițul": "șpriț",
    "șprițului": "șpriț",
    "șprițuri": "șpriț",
    "șprițurile": "șpriț",
    "șprițurilor": "șpriț",
    "nemaișprițuind": "șprițui",
    "nemaișprițuindu": "șprițui",
    "neșprițuind": "șprițui",
    "neșprițuindu": "șprițui",
    "șprițuia": "șprițui",
    "șprițuiai": "șprițui",
    "șprițuiam": "șprițui",
    "șprițuiască": "șprițui",
    "șprițuiați": "șprițui",
    "șprițuiau": "șprițui",
    "șprițuiesc": "șprițui",
    "șprițuiește": "șprițui",
    "șprițuiești": "șprițui",
    "șprițuii": "șprițui",
    "șprițuim": "șprițui",
    "șprițuind": "șprițui",
    "șprițuindu": "șprițui",
    "șprițuiră": "șprițui",
    "șprițuirăm": "șprițui",
    "șprițuirăți": "șprițui",
    "șprițuise": "șprițui",
    "șprițuisem": "șprițui",
    "șprițuiseră": "șprițui",
    "șprițuiserăm": "șprițui",
    "șprițuiserăți": "șprițui",
    "șprițuiseși": "șprițui",
    "șprițuiși": "șprițui",
    "șprițuit": "șprițui",
    "șprițuiți": "șprițui",
    "șprițuirea": "șprițuire",
    "șprițuireo": "șprițuire",
    "șprițuiri": "șprițuire",
    "șprițuirii": "șprițuire",
    "șprițuirile": "șprițuire",
    "șprițuirilor": "șprițuire",
    "șprițuita": "șprițuit",
    "șprițuită": "șprițuit",
    "șprițuite": "șprițuit",
    "șprițuitei": "șprițuit",
    "șprițuitele": "șprițuit",
    "șprițuitelor": "șprițuit",
    "șprițuiți": "șprițuit",
    "șprițuiții": "șprițuit",
    "șprițuiților": "șprițuit",
    "șprițuito": "șprițuit",
    "șprițuitul": "șprițuit",
    "șprițuitule": "șprițuit",
    "șprițuitului": "șprițuit",
    "nemaispulberând": "spulbera",
    "nemaispulberându": "spulbera",
    "nespulberând": "spulbera",
    "nespulberându": "spulbera",
    "spulber": "spulbera",
    "spulberă": "spulbera",
    "spulberai": "spulbera",
    "spulberam": "spulbera",
    "spulberăm": "spulbera",
    "spulberând": "spulbera",
    "spulberându": "spulbera",
    "spulberară": "spulbera",
    "spulberarăm": "spulbera",
    "spulberarăți": "spulbera",
    "spulberase": "spulbera",
    "spulberasem": "spulbera",
    "spulberaseră": "spulbera",
    "spulberaserăm": "spulbera",
    "spulberaserăți": "spulbera",
    "spulberaseși": "spulbera",
    "spulberași": "spulbera",
    "spulberat": "spulbera",
    "spulberați": "spulbera",
    "spulberau": "spulbera",
    "spulbere": "spulbera",
    "spulberi": "spulbera",
    "spulberată": "spulberat",
    "spulberate": "spulberat",
    "spulberați": "spulberat",
    "nemaispumând": "spuma",
    "nemaispumându": "spuma",
    "nespumând": "spuma",
    "nespumându": "spuma",
    "spumă": "spuma",
    "spumai": "spuma",
    "spumam": "spuma",
    "spumăm": "spuma",
    "spumând": "spuma",
    "spumându": "spuma",
    "spumară": "spuma",
    "spumarăm": "spuma",
    "spumarăți": "spuma",
    "spumase": "spuma",
    "spumasem": "spuma",
    "spumaseră": "spuma",
    "spumaserăm": "spuma",
    "spumaserăți": "spuma",
    "spumaseși": "spuma",
    "spumași": "spuma",
    "spumat": "spuma",
    "spumați": "spuma",
    "spumau": "spuma",
    "spumează": "spuma",
    "spumez": "spuma",
    "spumeze": "spuma",
    "spumezi": "spuma",
    "spuma": "spumă",
    "spume": "spumă",
    "spumei": "spumă",
    "spumele": "spumă",
    "spumelor": "spumă",
    "spumanți": "spumant",
    "spumanții": "spumant",
    "spumanților": "spumant",
    "spumantul": "spumant",
    "spumantului": "spumant",
    "spumată": "spumat",
    "spumate": "spumat",
    "spumați": "spumat",
    "nemaispumegând": "spumega",
    "nemaispumegându": "spumega",
    "nespumegând": "spumega",
    "nespumegându": "spumega",
    "spumeg": "spumega",
    "spumegă": "spumega",
    "spumegai": "spumega",
    "spumegam": "spumega",
    "spumegăm": "spumega",
    "spumegând": "spumega",
    "spumegându": "spumega",
    "spumegară": "spumega",
    "spumegarăm": "spumega",
    "spumegarăți": "spumega",
    "spumegase": "spumega",
    "spumegasem": "spumega",
    "spumegaseră": "spumega",
    "spumegaserăm": "spumega",
    "spumegaserăți": "spumega",
    "spumegaseși": "spumega",
    "spumegași": "spumega",
    "spumegat": "spumega",
    "spumegați": "spumega",
    "spumegau": "spumega",
    "spumege": "spumega",
    "spumegi": "spumega",
    "spumegată": "spumegat",
    "spumegate": "spumegat",
    "spumegați": "spumegat",
    "nemaispunând": "spune",
    "nemaispunându": "spune",
    "nespunând": "spune",
    "nespunându": "spune",
    "nespus": "spune",
    "spui": "spune",
    "spun": "spune",
    "spună": "spune",
    "spunând": "spune",
    "spunându": "spune",
    "spunea": "spune",
    "spuneai": "spune",
    "spuneam": "spune",
    "spuneați": "spune",
    "spuneau": "spune",
    "spunem": "spune",
    "spuneți": "spune",
    "spus": "spune",
    "spuse": "spune",
    "spusei": "spune",
    "spuseră": "spune",
    "spuserăm": "spune",
    "spuserăți": "spune",
    "spusese": "spune",
    "spusesem": "spune",
    "spuseseră": "spune",
    "spuseserăm": "spune",
    "spuseserăți": "spune",
    "spuseseși": "spune",
    "spuseși": "spune",
    "nemaispurcând": "spurca",
    "nemaispurcându": "spurca",
    "nespurcând": "spurca",
    "nespurcându": "spurca",
    "spurc": "spurca",
    "spurcă": "spurca",
    "spurcai": "spurca",
    "spurcam": "spurca",
    "spurcăm": "spurca",
    "spurcând": "spurca",
    "spurcându": "spurca",
    "spurcară": "spurca",
    "spurcarăm": "spurca",
    "spurcarăți": "spurca",
    "spurcase": "spurca",
    "spurcasem": "spurca",
    "spurcaseră": "spurca",
    "spurcaserăm": "spurca",
    "spurcaserăți": "spurca",
    "spurcaseși": "spurca",
    "spurcași": "spurca",
    "spurcat": "spurca",
    "spurcați": "spurca",
    "spurcau": "spurca",
    "spurce": "spurca",
    "spurci": "spurca",
    "spurcăciunea": "spurcăciune",
    "spurcăciuni": "spurcăciune",
    "spurcăciunii": "spurcăciune",
    "spurcăciunile": "spurcăciune",
    "spurcăciunilor": "spurcăciune",
    "spurcarea": "spurcare",
    "spurcări": "spurcare",
    "spurcării": "spurcare",
    "spurcările": "spurcare",
    "spurcărilor": "spurcare",
    "spurcata": "spurcat",
    "spurcată": "spurcat",
    "spurcate": "spurcat",
    "spurcatei": "spurcat",
    "spurcatele": "spurcat",
    "spurcatelor": "spurcat",
    "spurcați": "spurcat",
    "spurcații": "spurcat",
    "spurcaților": "spurcat",
    "spurcatul": "spurcat",
    "spurcatului": "spurcat",
    "spusa": "spus",
    "spusă": "spus",
    "spuse": "spus",
    "spusei": "spus",
    "spusele": "spus",
    "spuselor": "spus",
    "spuși": "spus",
    "spușii": "spus",
    "spușilor": "spus",
    "spusul": "spus",
    "spusului": "spus",
    "spusa": "spusă",
    "spuse": "spusă",
    "spusei": "spusă",
    "spusele": "spusă",
    "spuselor": "spusă",
    "spuza": "spuză",
    "spuze": "spuză",
    "spuzei": "spuză",
    "spuzeala": "spuzeală",
    "spuzeli": "spuzeală",
    "spuzelii": "spuzeală",
    "spuzelile": "spuzeală",
    "spuzelilor": "spuzeală",
    "nemaispuzind": "spuzi",
    "nemaispuzindu": "spuzi",
    "nespuzind": "spuzi",
    "nespuzindu": "spuzi",
    "spuzea": "spuzi",
    "spuzeai": "spuzi",
    "spuzeam": "spuzi",
    "spuzească": "spuzi",
    "spuzeați": "spuzi",
    "spuzeau": "spuzi",
    "spuzesc": "spuzi",
    "spuzește": "spuzi",
    "spuzești": "spuzi",
    "spuzii": "spuzi",
    "spuzim": "spuzi",
    "spuzind": "spuzi",
    "spuzindu": "spuzi",
    "spuziră": "spuzi",
    "spuzirăm": "spuzi",
    "spuzirăți": "spuzi",
    "spuzise": "spuzi",
    "spuzisem": "spuzi",
    "spuziseră": "spuzi",
    "spuziserăm": "spuzi",
    "spuziserăți": "spuzi",
    "spuziseși": "spuzi",
    "spuziși": "spuzi",
    "spuzit": "spuzi",
    "spuziți": "spuzi",
    "spuzită": "spuzit",
    "spuzite": "spuzit",
    "spuziți": "spuzit",
    "șrapnele": "șrapnel",
    "șrapnelele": "șrapnel",
    "șrapnelelor": "șrapnel",
    "șrapnelul": "șrapnel",
    "șrapnelului": "șrapnel",
    "șrotul": "șrot",
    "șrotului": "șrot",
    "șroturi": "șrot",
    "șroturile": "șrot",
    "șroturilor": "șrot",
    "nemaistând": "sta",
    "nemaistându": "sta",
    "nestând": "sta",
    "nestându": "sta",
    "stă": "sta",
    "stai": "sta",
    "stăm": "sta",
    "stând": "sta",
    "stându": "sta",
    "stat": "sta",
    "stătea": "sta",
    "stăteai": "sta",
    "stăteam": "sta",
    "stăteați": "sta",
    "stăteau": "sta",
    "stați": "sta",
    "stătu": "sta",
    "stătui": "sta",
    "stătură": "sta",
    "stăturăm": "sta",
    "stăturăți": "sta",
    "stătuse": "sta",
    "stătusem": "sta",
    "stătuseră": "sta",
    "stătuserăm": "sta",
    "stătuserăți": "sta",
    "stătuseși": "sta",
    "stătuși": "sta",
    "stau": "sta",
    "stea": "sta",
    "ștabi": "ștab",
    "ștabii": "ștab",
    "ștabilor": "ștab",
    "ștabul": "ștab",
    "ștabului": "ștab",
    "stabila": "stabil",
    "stabilă": "stabil",
    "stabile": "stabil",
    "stabilei": "stabil",
    "stabilele": "stabil",
    "stabilelor": "stabil",
    "stabili": "stabil",
    "stabilii": "stabil",
    "stabililor": "stabil",
    "stabilul": "stabil",
    "stabilului": "stabil",
    "nemaistabilind": "stabili",
    "nemaistabilindu": "stabili",
    "nestabilind": "stabili",
    "nestabilindu": "stabili",
    "stabilea": "stabili",
    "stabileai": "stabili",
    "stabileam": "stabili",
    "stabilească": "stabili",
    "stabileați": "stabili",
    "stabileau": "stabili",
    "stabilesc": "stabili",
    "stabilește": "stabili",
    "stabilești": "stabili",
    "stabilii": "stabili",
    "stabilim": "stabili",
    "stabilind": "stabili",
    "stabilindu": "stabili",
    "stabiliră": "stabili",
    "stabilirăm": "stabili",
    "stabilirăți": "stabili",
    "stabilise": "stabili",
    "stabilisem": "stabili",
    "stabiliseră": "stabili",
    "stabiliserăm": "stabili",
    "stabiliserăți": "stabili",
    "stabiliseși": "stabili",
    "stabiliși": "stabili",
    "stabilit": "stabili",
    "stabiliți": "stabili",
    "stabilirea": "stabilire",
    "stabilireo": "stabilire",
    "stabiliri": "stabilire",
    "stabilirii": "stabilire",
    "stabilirile": "stabilire",
    "stabilirilor": "stabilire",
    "stabilită": "stabilit",
    "stabilite": "stabilit",
    "stabiliți": "stabilit",
    "stabilitatea": "stabilitate",
    "stabilități": "stabilitate",
    "stabilității": "stabilitate",
    "stabilitățile": "stabilitate",
    "stabilităților": "stabilitate",
    "nemaistabilizând": "stabiliza",
    "nemaistabilizându": "stabiliza",
    "nestabilizând": "stabiliza",
    "nestabilizându": "stabiliza",
    "stabiliză": "stabiliza",
    "stabilizai": "stabiliza",
    "stabilizam": "stabiliza",
    "stabilizăm": "stabiliza",
    "stabilizând": "stabiliza",
    "stabilizându": "stabiliza",
    "stabilizară": "stabiliza",
    "stabilizarăm": "stabiliza",
    "stabilizarăți": "stabiliza",
    "stabilizase": "stabiliza",
    "stabilizasem": "stabiliza",
    "stabilizaseră": "stabiliza",
    "stabilizaserăm": "stabiliza",
    "stabilizaserăți": "stabiliza",
    "stabilizaseși": "stabiliza",
    "stabilizași": "stabiliza",
    "stabilizat": "stabiliza",
    "stabilizați": "stabiliza",
    "stabilizau": "stabiliza",
    "stabilizează": "stabiliza",
    "stabilizez": "stabiliza",
    "stabilizeze": "stabiliza",
    "stabilizezi": "stabiliza",
    "stabilizată": "stabilizat",
    "stabilizate": "stabilizat",
    "stabilizați": "stabilizat",
    "stabilizatoare": "stabilizator",
    "stabilizatoarele": "stabilizator",
    "stabilizatoarelor": "stabilizator",
    "stabilizatori": "stabilizator",
    "stabilizatorii": "stabilizator",
    "stabilizatorilor": "stabilizator",
    "stabilizatorul": "stabilizator",
    "stabilizatorului": "stabilizator",
    "stacana": "stacană",
    "stacane": "stacană",
    "stacanei": "stacană",
    "stacanele": "stacană",
    "stacanelor": "stacană",
    "ștacheta": "ștachetă",
    "ștachete": "ștachetă",
    "ștachetei": "ștachetă",
    "ștachetele": "ștachetă",
    "ștachetelor": "ștachetă",
    "stacojia": "stacojiu",
    "stacojie": "stacojiu",
    "stacojiei": "stacojiu",
    "stacojii": "stacojiu",
    "stacojiii": "stacojiu",
    "stacojiile": "stacojiu",
    "stacojiilor": "stacojiu",
    "stacojiul": "stacojiu",
    "stacojiului": "stacojiu",
    "stadia": "stadie",
    "stadiei": "stadie",
    "stadii": "stadie",
    "stadiile": "stadie",
    "stadiilor": "stadie",
    "stadimetria": "stadimetrie",
    "stadimetriei": "stadimetrie",
    "stadimetrii": "stadimetrie",
    "stadimetriile": "stadimetrie",
    "stadimetriilor": "stadimetrie",
    "stadioane": "stadion",
    "stadioanele": "stadion",
    "stadioanelor": "stadion",
    "stadionul": "stadion",
    "stadionului": "stadion",
    "stadii": "stadiu",
    "stadiile": "stadiu",
    "stadiilor": "stadiu",
    "stadiul": "stadiu",
    "stadiului": "stadiu",
    "ștafeta": "ștafetă",
    "ștafete": "ștafetă",
    "ștafetei": "ștafetă",
    "ștafetele": "ștafetă",
    "ștafetelor": "ștafetă",
    "stafida": "stafidă",
    "stafide": "stafidă",
    "stafidei": "stafidă",
    "stafidele": "stafidă",
    "stafidelor": "stafidă",
    "nemaistafidind": "stafidi",
    "nemaistafidindu": "stafidi",
    "nestafidind": "stafidi",
    "nestafidindu": "stafidi",
    "stafidea": "stafidi",
    "stafideai": "stafidi",
    "stafideam": "stafidi",
    "stafidească": "stafidi",
    "stafideați": "stafidi",
    "stafideau": "stafidi",
    "stafidesc": "stafidi",
    "stafidește": "stafidi",
    "stafidești": "stafidi",
    "stafidii": "stafidi",
    "stafidim": "stafidi",
    "stafidind": "stafidi",
    "stafidindu": "stafidi",
    "stafidiră": "stafidi",
    "stafidirăm": "stafidi",
    "stafidirăți": "stafidi",
    "stafidise": "stafidi",
    "stafidisem": "stafidi",
    "stafidiseră": "stafidi",
    "stafidiserăm": "stafidi",
    "stafidiserăți": "stafidi",
    "stafidiseși": "stafidi",
    "stafidiși": "stafidi",
    "stafidit": "stafidi",
    "stafidiți": "stafidi",
    "stafidită": "stafidit",
    "stafidite": "stafidit",
    "stafidiți": "stafidit",
    "stafia": "stafie",
    "stafiei": "stafie",
    "stafii": "stafie",
    "stafiile": "stafie",
    "stafiilor": "stafie",
    "stafilococi": "stafilococ",
    "stafilococii": "stafilococ",
    "stafilococilor": "stafilococ",
    "stafilococul": "stafilococ",
    "stafilococului": "stafilococ",
    "stagiara": "stagiar",
    "stagiară": "stagiar",
    "stagiare": "stagiar",
    "stagiarei": "stagiar",
    "stagiarele": "stagiar",
    "stagiarelor": "stagiar",
    "stagiari": "stagiar",
    "stagiarii": "stagiar",
    "stagiarilor": "stagiar",
    "stagiarul": "stagiar",
    "stagiarului": "stagiar",
    "stagii": "stagiu",
    "stagiile": "stagiu",
    "stagiilor": "stagiu",
    "stagiul": "stagiu",
    "stagiului": "stagiu",
    "stagiunea": "stagiune",
    "stagiuni": "stagiune",
    "stagiunii": "stagiune",
    "stagiunile": "stagiune",
    "stagiunilor": "stagiune",
    "nemaistagnând": "stagna",
    "nemaistagnându": "stagna",
    "nestagnând": "stagna",
    "nestagnându": "stagna",
    "stagnă": "stagna",
    "stagnai": "stagna",
    "stagnam": "stagna",
    "stagnăm": "stagna",
    "stagnând": "stagna",
    "stagnându": "stagna",
    "stagnară": "stagna",
    "stagnarăm": "stagna",
    "stagnarăți": "stagna",
    "stagnase": "stagna",
    "stagnasem": "stagna",
    "stagnaseră": "stagna",
    "stagnaserăm": "stagna",
    "stagnaserăți": "stagna",
    "stagnaseși": "stagna",
    "stagnași": "stagna",
    "stagnat": "stagna",
    "stagnați": "stagna",
    "stagnau": "stagna",
    "stagnează": "stagna",
    "stagnez": "stagna",
    "stagneze": "stagna",
    "stagnezi": "stagna",
    "stagnarea": "stagnare",
    "stagnareo": "stagnare",
    "stagnări": "stagnare",
    "stagnării": "stagnare",
    "stagnările": "stagnare",
    "stagnărilor": "stagnare",
    "stagnată": "stagnat",
    "stagnate": "stagnat",
    "stagnați": "stagnat",
    "ștaiful": "ștaif",
    "ștaifului": "ștaif",
    "ștaifuri": "ștaif",
    "ștaifurile": "ștaif",
    "ștaifurilor": "ștaif",
    "stalul": "stal",
    "stalului": "stal",
    "staluri": "stal",
    "stalurile": "stal",
    "stalurilor": "stal",
    "stalactita": "stalactită",
    "stalactite": "stalactită",
    "stalactitei": "stalactită",
    "stalactitele": "stalactită",
    "stalactitelor": "stalactită",
    "stalagmita": "stalagmită",
    "stalagmite": "stalagmită",
    "stalagmitei": "stalagmită",
    "stalagmitele": "stalagmită",
    "stalagmitelor": "stalagmită",
    "stâlceala": "stâlceală",
    "stâlceli": "stâlceală",
    "stâlcelii": "stâlceală",
    "stâlcelile": "stâlceală",
    "stâlcelilor": "stâlceală",
    "nemaistâlcind": "stâlci",
    "nemaistâlcindu": "stâlci",
    "nestâlcind": "stâlci",
    "nestâlcindu": "stâlci",
    "stâlcea": "stâlci",
    "stâlceai": "stâlci",
    "stâlceam": "stâlci",
    "stâlcească": "stâlci",
    "stâlceați": "stâlci",
    "stâlceau": "stâlci",
    "stâlcesc": "stâlci",
    "stâlcește": "stâlci",
    "stâlcești": "stâlci",
    "stâlcii": "stâlci",
    "stâlcim": "stâlci",
    "stâlcind": "stâlci",
    "stâlcindu": "stâlci",
    "stâlciră": "stâlci",
    "stâlcirăm": "stâlci",
    "stâlcirăți": "stâlci",
    "stâlcise": "stâlci",
    "stâlcisem": "stâlci",
    "stâlciseră": "stâlci",
    "stâlciserăm": "stâlci",
    "stâlciserăți": "stâlci",
    "stâlciseși": "stâlci",
    "stâlciși": "stâlci",
    "stâlcit": "stâlci",
    "stâlciți": "stâlci",
    "stâlcită": "stâlcit",
    "stâlcite": "stâlcit",
    "stâlciți": "stâlcit",
    "stâlpi": "stâlp",
    "stâlpii": "stâlp",
    "stâlpilor": "stâlp",
    "stâlpul": "stâlp",
    "stâlpului": "stâlp",
    "stamba": "stambă",
    "stambei": "stambă",
    "stămburi": "stambă",
    "stămburile": "stambă",
    "stămburilor": "stambă",
    "stamina": "stamină",
    "stamine": "stamină",
    "staminei": "stamină",
    "staminele": "stamină",
    "staminelor": "stamină",
    "staminifera": "staminifer",
    "staminiferă": "staminifer",
    "staminifere": "staminifer",
    "staminiferei": "staminifer",
    "staminiferele": "staminifer",
    "staminiferelor": "staminifer",
    "staminiferi": "staminifer",
    "staminiferii": "staminifer",
    "staminiferilor": "staminifer",
    "staminiferul": "staminifer",
    "staminiferului": "staminifer",
    "nemaistampând": "stampa",
    "nemaistampându": "stampa",
    "nestampând": "stampa",
    "nestampându": "stampa",
    "stampă": "stampa",
    "stampai": "stampa",
    "stampam": "stampa",
    "stampăm": "stampa",
    "stampând": "stampa",
    "stampându": "stampa",
    "stampară": "stampa",
    "stamparăm": "stampa",
    "stamparăți": "stampa",
    "stampase": "stampa",
    "stampasem": "stampa",
    "stampaseră": "stampa",
    "stampaserăm": "stampa",
    "stampaserăți": "stampa",
    "stampaseși": "stampa",
    "stampași": "stampa",
    "stampat": "stampa",
    "stampați": "stampa",
    "stampau": "stampa",
    "stampează": "stampa",
    "stampez": "stampa",
    "stampeze": "stampa",
    "stampezi": "stampa",
    "stampa": "stampă",
    "stampe": "stampă",
    "stampei": "stampă",
    "stampele": "stampă",
    "stampelor": "stampă",
    "stamparea": "stampare",
    "stampări": "stampare",
    "stampării": "stampare",
    "stampările": "stampare",
    "stampărilor": "stampare",
    "stampată": "stampat",
    "stampate": "stampat",
    "stampați": "stampat",
    "nemaiștampilând": "ștampila",
    "nemaiștampilându": "ștampila",
    "neștampilând": "ștampila",
    "neștampilându": "ștampila",
    "ștampilă": "ștampila",
    "ștampilai": "ștampila",
    "ștampilam": "ștampila",
    "ștampilăm": "ștampila",
    "ștampilând": "ștampila",
    "ștampilându": "ștampila",
    "ștampilară": "ștampila",
    "ștampilarăm": "ștampila",
    "ștampilarăți": "ștampila",
    "ștampilase": "ștampila",
    "ștampilasem": "ștampila",
    "ștampilaseră": "ștampila",
    "ștampilaserăm": "ștampila",
    "ștampilaserăți": "ștampila",
    "ștampilaseși": "ștampila",
    "ștampilași": "ștampila",
    "ștampilat": "ștampila",
    "ștampilați": "ștampila",
    "ștampilau": "ștampila",
    "ștampilează": "ștampila",
    "ștampilez": "ștampila",
    "ștampileze": "ștampila",
    "ștampilezi": "ștampila",
    "ștampila": "ștampilă",
    "ștampile": "ștampilă",
    "ștampilei": "ștampilă",
    "ștampilele": "ștampilă",
    "ștampilelor": "ștampilă",
    "ștampilată": "ștampilat",
    "ștampilate": "ștampilat",
    "ștampilați": "ștampilat",
    "stana": "stană",
    "stane": "stană",
    "stanei": "stană",
    "stanele": "stană",
    "stanelor": "stană",
    "stâna": "stână",
    "stâne": "stână",
    "stânei": "stână",
    "stânele": "stână",
    "stânelor": "stână",
    "stânca": "stâncă",
    "stânci": "stâncă",
    "stâncii": "stâncă",
    "stâncile": "stâncă",
    "stâncilor": "stâncă",
    "stăncuța": "stăncuță",
    "stăncuțe": "stăncuță",
    "stăncuței": "stăncuță",
    "stăncuțele": "stăncuță",
    "stăncuțelor": "stăncuță",
    "standul": "stand",
    "standului": "stand",
    "standuri": "stand",
    "standurile": "stand",
    "standurilor": "stand",
    "standarde": "standard",
    "standardele": "standard",
    "standardelor": "standard",
    "standardul": "standard",
    "standardului": "standard",
    "nemaistandardizând": "standardiza",
    "nemaistandardizându": "standardiza",
    "nestandardizând": "standardiza",
    "nestandardizându": "standardiza",
    "standardiză": "standardiza",
    "standardizai": "standardiza",
    "standardizam": "standardiza",
    "standardizăm": "standardiza",
    "standardizând": "standardiza",
    "standardizându": "standardiza",
    "standardizară": "standardiza",
    "standardizarăm": "standardiza",
    "standardizarăți": "standardiza",
    "standardizase": "standardiza",
    "standardizasem": "standardiza",
    "standardizaseră": "standardiza",
    "standardizaserăm": "standardiza",
    "standardizaserăți": "standardiza",
    "standardizaseși": "standardiza",
    "standardizași": "standardiza",
    "standardizat": "standardiza",
    "standardizați": "standardiza",
    "standardizau": "standardiza",
    "standardizează": "standardiza",
    "standardizez": "standardiza",
    "standardizeze": "standardiza",
    "standardizezi": "standardiza",
    "standardizată": "standardizat",
    "standardizate": "standardizat",
    "standardizați": "standardizat",
    "stânga": "stâng",
    "stângă": "stâng",
    "stânge": "stâng",
    "stângei": "stâng",
    "stângele": "stâng",
    "stângelor": "stâng",
    "stângi": "stâng",
    "stângii": "stâng",
    "stângilor": "stâng",
    "stângul": "stâng",
    "stângului": "stâng",
    "stânga": "stângă",
    "stângei": "stângă",
    "ștanga": "ștangă",
    "ștăngi": "ștangă",
    "ștăngii": "ștangă",
    "ștăngile": "ștangă",
    "ștăngilor": "ștangă",
    "stângace": "stângaci",
    "stângacea": "stângaci",
    "stângacei": "stângaci",
    "stângacele": "stângaci",
    "stângacelor": "stângaci",
    "stângacii": "stângaci",
    "stângacilor": "stângaci",
    "stângaciul": "stângaci",
    "stângaciului": "stângaci",
    "stângăcia": "stângăcie",
    "stângăciei": "stângăcie",
    "stângăcii": "stângăcie",
    "stângăciile": "stângăcie",
    "stângăciilor": "stângăcie",
    "stângismul": "stângism",
    "stângismului": "stângism",
    "stângiști": "stângist",
    "stângiștii": "stângist",
    "stângiștilor": "stângist",
    "stângistul": "stângist",
    "stângistului": "stângist",
    "stângista": "stângistă",
    "stângiste": "stângistă",
    "stângistei": "stângistă",
    "stângistele": "stângistă",
    "stângistelor": "stângistă",
    "stanica": "stanic",
    "stanică": "stanic",
    "stanice": "stanic",
    "stanicei": "stanic",
    "stanicele": "stanic",
    "stanicelor": "stanic",
    "stanici": "stanic",
    "stanicii": "stanic",
    "stanicilor": "stanic",
    "stanicul": "stanic",
    "stanicului": "stanic",
    "stanifera": "stanifer",
    "staniferă": "stanifer",
    "stanifere": "stanifer",
    "staniferei": "stanifer",
    "staniferele": "stanifer",
    "staniferelor": "stanifer",
    "staniferi": "stanifer",
    "staniferii": "stanifer",
    "staniferilor": "stanifer",
    "staniferul": "stanifer",
    "staniferului": "stanifer",
    "staniolul": "staniol",
    "staniolului": "staniol",
    "Sn": "staniu",
    "staniul": "staniu",
    "staniului": "staniu",
    "stânjeni": "stânjen",
    "stânjenii": "stânjen",
    "stânjenilor": "stânjen",
    "stânjenul": "stânjen",
    "stânjenului": "stânjen",
    "stânjeneala": "stânjeneală",
    "stânjeneli": "stânjeneală",
    "stânjenelii": "stânjeneală",
    "stânjenelile": "stânjeneală",
    "stânjenelilor": "stânjeneală",
    "stânjenei": "stânjenel",
    "stânjeneii": "stânjenel",
    "stânjeneilor": "stânjenel",
    "stânjenelul": "stânjenel",
    "stânjenelului": "stânjenel",
    "nemaistânjenind": "stânjeni",
    "nemaistânjenindu": "stânjeni",
    "nestânjenind": "stânjeni",
    "nestânjenindu": "stânjeni",
    "stânjenea": "stânjeni",
    "stânjeneai": "stânjeni",
    "stânjeneam": "stânjeni",
    "stânjenească": "stânjeni",
    "stânjeneați": "stânjeni",
    "stânjeneau": "stânjeni",
    "stânjenesc": "stânjeni",
    "stânjenește": "stânjeni",
    "stânjenești": "stânjeni",
    "stânjenii": "stânjeni",
    "stânjenim": "stânjeni",
    "stânjenind": "stânjeni",
    "stânjenindu": "stânjeni",
    "stânjeniră": "stânjeni",
    "stânjenirăm": "stânjeni",
    "stânjenirăți": "stânjeni",
    "stânjenise": "stânjeni",
    "stânjenisem": "stânjeni",
    "stânjeniseră": "stânjeni",
    "stânjeniserăm": "stânjeni",
    "stânjeniserăți": "stânjeni",
    "stânjeniseși": "stânjeni",
    "stânjeniși": "stânjeni",
    "stânjenit": "stânjeni",
    "stânjeniți": "stânjeni",
    "stânjenirea": "stânjenire",
    "stânjenireo": "stânjenire",
    "stânjeniri": "stânjenire",
    "stânjenirii": "stânjenire",
    "stânjenirile": "stânjenire",
    "stânjenirilor": "stânjenire",
    "stânjenita": "stânjenit",
    "stânjenită": "stânjenit",
    "stânjenite": "stânjenit",
    "stânjenitei": "stânjenit",
    "stânjenitele": "stânjenit",
    "stânjenitelor": "stânjenit",
    "stânjeniți": "stânjenit",
    "stânjeniții": "stânjenit",
    "stânjeniților": "stânjenit",
    "stânjenito": "stânjenit",
    "stânjenitul": "stânjenit",
    "stânjenitule": "stânjenit",
    "stânjenitului": "stânjenit",
    "stânjenitoare": "stânjenitor",
    "stânjenitoarea": "stânjenitor",
    "stânjenitoarei": "stânjenitor",
    "stânjenitoarele": "stânjenitor",
    "stânjenitoarelor": "stânjenitor",
    "stânjenitori": "stânjenitor",
    "stânjenitorii": "stânjenitor",
    "stânjenitorilor": "stânjenitor",
    "stânjenitorul": "stânjenitor",
    "stânjenitorului": "stânjenitor",
    "stânjenia": "stânjeniu",
    "stânjenie": "stânjeniu",
    "stânjeniei": "stânjeniu",
    "stânjenii": "stânjeniu",
    "stânjeniii": "stânjeniu",
    "stânjeniile": "stânjeniu",
    "stânjeniilor": "stânjeniu",
    "stânjeniul": "stânjeniu",
    "stânjeniului": "stânjeniu",
    "stănoaga": "stănoagă",
    "stănoage": "stănoagă",
    "stănoagei": "stănoagă",
    "stănoagele": "stănoagă",
    "stănoagelor": "stănoagă",
    "stanța": "stanță",
    "stanțe": "stanță",
    "stanței": "stanță",
    "stanțele": "stanță",
    "stanțelor": "stanță",
    "nemaiștanțând": "ștanța",
    "nemaiștanțându": "ștanța",
    "neștanțând": "ștanța",
    "neștanțându": "ștanța",
    "ștanță": "ștanța",
    "ștanțai": "ștanța",
    "ștanțam": "ștanța",
    "ștanțăm": "ștanța",
    "ștanțând": "ștanța",
    "ștanțându": "ștanța",
    "ștanțară": "ștanța",
    "ștanțarăm": "ștanța",
    "ștanțarăți": "ștanța",
    "ștanțase": "ștanța",
    "ștanțasem": "ștanța",
    "ștanțaseră": "ștanța",
    "ștanțaserăm": "ștanța",
    "ștanțaserăți": "ștanța",
    "ștanțaseși": "ștanța",
    "ștanțași": "ștanța",
    "ștanțat": "ștanța",
    "ștanțați": "ștanța",
    "ștanțau": "ștanța",
    "ștanțează": "ștanța",
    "ștanțez": "ștanța",
    "ștanțeze": "ștanța",
    "ștanțezi": "ștanța",
    "ștanța": "ștanță",
    "ștanțe": "ștanță",
    "ștanței": "ștanță",
    "ștanțele": "ștanță",
    "ștanțelor": "ștanță",
    "ștanțată": "ștanțat",
    "ștanțate": "ștanțat",
    "ștanțați": "ștanțat",
    "stăpâni": "stăpân",
    "stăpânii": "stăpân",
    "stăpânilor": "stăpân",
    "stăpânul": "stăpân",
    "stăpânului": "stăpân",
    "stăpâna": "stăpână",
    "stăpâne": "stăpână",
    "stăpânei": "stăpână",
    "stăpânele": "stăpână",
    "stăpânelor": "stăpână",
    "nemaistăpânind": "stăpâni",
    "nemaistăpânindu": "stăpâni",
    "nestăpânind": "stăpâni",
    "nestăpânindu": "stăpâni",
    "stăpânea": "stăpâni",
    "stăpâneai": "stăpâni",
    "stăpâneam": "stăpâni",
    "stăpânească": "stăpâni",
    "stăpâneați": "stăpâni",
    "stăpâneau": "stăpâni",
    "stăpânesc": "stăpâni",
    "stăpânește": "stăpâni",
    "stăpânești": "stăpâni",
    "stăpânii": "stăpâni",
    "stăpânim": "stăpâni",
    "stăpânind": "stăpâni",
    "stăpânindu": "stăpâni",
    "stăpâniră": "stăpâni",
    "stăpânirăm": "stăpâni",
    "stăpânirăți": "stăpâni",
    "stăpânise": "stăpâni",
    "stăpânisem": "stăpâni",
    "stăpâniseră": "stăpâni",
    "stăpâniserăm": "stăpâni",
    "stăpâniserăți": "stăpâni",
    "stăpâniseși": "stăpâni",
    "stăpâniși": "stăpâni",
    "stăpânit": "stăpâni",
    "stăpâniți": "stăpâni",
    "stăpânirea": "stăpânire",
    "stăpânireo": "stăpânire",
    "stăpâniri": "stăpânire",
    "stăpânirii": "stăpânire",
    "stăpânirile": "stăpânire",
    "stăpânirilor": "stăpânire",
    "stăpânita": "stăpânit",
    "stăpânită": "stăpânit",
    "stăpânite": "stăpânit",
    "stăpânitei": "stăpânit",
    "stăpânitele": "stăpânit",
    "stăpânitelor": "stăpânit",
    "stăpâniți": "stăpânit",
    "stăpâniții": "stăpânit",
    "stăpâniților": "stăpânit",
    "stăpânito": "stăpânit",
    "stăpânitul": "stăpânit",
    "stăpânitule": "stăpânit",
    "stăpânitului": "stăpânit",
    "stăpânitoarea": "stăpânitoare",
    "stăpânitoarei": "stăpânitoare",
    "stăpânitoarele": "stăpânitoare",
    "stăpânitoarelor": "stăpânitoare",
    "stăpânitoare": "stăpânitor",
    "stăpânitoarea": "stăpânitor",
    "stăpânitoarei": "stăpânitor",
    "stăpânitoarele": "stăpânitor",
    "stăpânitoarelor": "stăpânitor",
    "stăpânitoareo": "stăpânitor",
    "stăpânitori": "stăpânitor",
    "stăpânitorii": "stăpânitor",
    "stăpânitorilor": "stăpânitor",
    "stăpânitorul": "stăpânitor",
    "stăpânitorule": "stăpânitor",
    "stăpânitorului": "stăpânitor",
    "starul": "star",
    "starului": "star",
    "staruri": "star",
    "starurile": "star",
    "starurilor": "star",
    "stârci": "stârc",
    "stârcii": "stârc",
    "stârcilor": "stârc",
    "stârcul": "stârc",
    "stârcului": "stârc",
    "starea": "stare",
    "stări": "stare",
    "stării": "stare",
    "stările": "stare",
    "stărilor": "stare",
    "stareți": "stareț",
    "stareții": "stareț",
    "stareților": "stareț",
    "starețul": "stareț",
    "starețului": "stareț",
    "stareța": "stareță",
    "starețe": "stareță",
    "stareței": "stareță",
    "starețele": "stareță",
    "starețelor": "stareță",
    "stăreția": "stăreție",
    "stăreției": "stăreție",
    "stăreții": "stăreție",
    "stărețiile": "stăreție",
    "stărețiilor": "stăreție",
    "nemaistârnind": "stârni",
    "nemaistârnindu": "stârni",
    "nestârnind": "stârni",
    "nestârnindu": "stârni",
    "stârnea": "stârni",
    "stârneai": "stârni",
    "stârneam": "stârni",
    "stârnească": "stârni",
    "stârneați": "stârni",
    "stârneau": "stârni",
    "stârnesc": "stârni",
    "stârnește": "stârni",
    "stârnești": "stârni",
    "stârnii": "stârni",
    "stârnim": "stârni",
    "stârnind": "stârni",
    "stârnindu": "stârni",
    "stârniră": "stârni",
    "stârnirăm": "stârni",
    "stârnirăți": "stârni",
    "stârnise": "stârni",
    "stârnisem": "stârni",
    "stârniseră": "stârni",
    "stârniserăm": "stârni",
    "stârniserăți": "stârni",
    "stârniseși": "stârni",
    "stârniși": "stârni",
    "stârnit": "stârni",
    "stârniți": "stârni",
    "stârnirea": "stârnire",
    "stârnireo": "stârnire",
    "stârniri": "stârnire",
    "stârnirii": "stârnire",
    "stârnirile": "stârnire",
    "stârnirilor": "stârnire",
    "stârnită": "stârnit",
    "stârnite": "stârnit",
    "stârniți": "stârnit",
    "stârnitoare": "stârnitor",
    "stârnitoarea": "stârnitor",
    "stârnitoarei": "stârnitor",
    "stârnitoarele": "stârnitor",
    "stârnitoarelor": "stârnitor",
    "stârnitori": "stârnitor",
    "stârnitorii": "stârnitor",
    "stârnitorilor": "stârnitor",
    "stârnitorul": "stârnitor",
    "stârnitorului": "stârnitor",
    "starostele": "staroste",
    "starostelui": "staroste",
    "starosti": "staroste",
    "starostii": "staroste",
    "starostilor": "staroste",
    "nemaistârpind": "stârpi",
    "nemaistârpindu": "stârpi",
    "nestârpind": "stârpi",
    "nestârpindu": "stârpi",
    "stârpea": "stârpi",
    "stârpeai": "stârpi",
    "stârpeam": "stârpi",
    "stârpească": "stârpi",
    "stârpeați": "stârpi",
    "stârpeau": "stârpi",
    "stârpesc": "stârpi",
    "stârpește": "stârpi",
    "stârpești": "stârpi",
    "stârpii": "stârpi",
    "stârpim": "stârpi",
    "stârpind": "stârpi",
    "stârpindu": "stârpi",
    "stârpiră": "stârpi",
    "stârpirăm": "stârpi",
    "stârpirăți": "stârpi",
    "stârpise": "stârpi",
    "stârpisem": "stârpi",
    "stârpiseră": "stârpi",
    "stârpiserăm": "stârpi",
    "stârpiserăți": "stârpi",
    "stârpiseși": "stârpi",
    "stârpiși": "stârpi",
    "stârpit": "stârpi",
    "stârpiți": "stârpi",
    "stârpirea": "stârpire",
    "stârpireo": "stârpire",
    "stârpiri": "stârpire",
    "stârpirii": "stârpire",
    "stârpirile": "stârpire",
    "stârpirilor": "stârpire",
    "stârpita": "stârpit",
    "stârpită": "stârpit",
    "stârpite": "stârpit",
    "stârpitei": "stârpit",
    "stârpitele": "stârpit",
    "stârpitelor": "stârpit",
    "stârpiți": "stârpit",
    "stârpiții": "stârpit",
    "stârpiților": "stârpit",
    "stârpito": "stârpit",
    "stârpitul": "stârpit",
    "stârpitule": "stârpit",
    "stârpitului": "stârpit",
    "stârpitura": "stârpitură",
    "stârpituri": "stârpitură",
    "stârpiturii": "stârpitură",
    "stârpiturile": "stârpitură",
    "stârpiturilor": "stârpitură",
    "stârpituro": "stârpitură",
    "startul": "start",
    "startului": "start",
    "starturi": "start",
    "starturile": "start",
    "starturilor": "start",
    "startere": "starter",
    "starterele": "starter",
    "starterelor": "starter",
    "starteri": "starter",
    "starterii": "starter",
    "starterilor": "starter",
    "starterul": "starter",
    "starterului": "starter",
    "nemaistăruind": "stărui",
    "nemaistăruindu": "stărui",
    "nestăruind": "stărui",
    "nestăruindu": "stărui",
    "stăruia": "stărui",
    "stăruiai": "stărui",
    "stăruiam": "stărui",
    "stăruiați": "stărui",
    "stăruiau": "stărui",
    "stăruie": "stărui",
    "stăruii": "stărui",
    "stăruim": "stărui",
    "stăruind": "stărui",
    "stăruindu": "stărui",
    "stăruiră": "stărui",
    "stăruirăm": "stărui",
    "stăruirăți": "stărui",
    "stăruise": "stărui",
    "stăruisem": "stărui",
    "stăruiseră": "stărui",
    "stăruiserăm": "stărui",
    "stăruiserăți": "stărui",
    "stăruiseși": "stărui",
    "stăruiși": "stărui",
    "stăruit": "stărui",
    "stăruiți": "stărui",
    "stăruința": "stăruință",
    "stăruințe": "stăruință",
    "stăruinței": "stăruință",
    "stăruințele": "stăruință",
    "stăruințelor": "stăruință",
    "stăruită": "stăruit",
    "stăruite": "stăruit",
    "stăruiți": "stăruit",
    "stârvul": "stârv",
    "stârvului": "stârv",
    "stârvuri": "stârv",
    "stârvurile": "stârv",
    "stârvurilor": "stârv",
    "stasul": "stas",
    "stasului": "stas",
    "stasuri": "stas",
    "stasurile": "stas",
    "stasurilor": "stas",
    "stată": "stat",
    "state": "stat",
    "statele": "stat",
    "statelor": "stat",
    "stați": "stat",
    "statul": "stat",
    "statului": "stat",
    "ștate": "ștat",
    "ștatele": "ștat",
    "ștatelor": "ștat",
    "ștatul": "ștat",
    "ștatului": "ștat",
    "statala": "statal",
    "statală": "statal",
    "statale": "statal",
    "statalei": "statal",
    "statalele": "statal",
    "statalelor": "statal",
    "statali": "statal",
    "statalii": "statal",
    "statalilor": "statal",
    "statalul": "statal",
    "statalului": "statal",
    "stătătoare": "stătător",
    "stătătoarea": "stătător",
    "stătătoarei": "stătător",
    "stătătoarele": "stătător",
    "stătătoarelor": "stătător",
    "stătători": "stătător",
    "stătătorii": "stătător",
    "stătătorilor": "stătător",
    "stătătorul": "stătător",
    "stătătorului": "stătător",
    "Statelor_Unite": "Statele_Unite",
    "S.U.A.": "Statele_Unite_ale_Americii",
    "Statelor_Unite_ale_Americii": "Statele_Unite_ale_Americii",
    "SUA": "Statele_Unite_ale_Americii",
    "statica": "static",
    "statică": "static",
    "statice": "static",
    "staticei": "static",
    "staticele": "static",
    "staticelor": "static",
    "statici": "static",
    "staticii": "static",
    "staticilor": "static",
    "staticul": "static",
    "staticului": "static",
    "stația": "stație",
    "stației": "stație",
    "stații": "stație",
    "stațiile": "stație",
    "stațiilor": "stație",
    "nemaistaționând": "staționa",
    "nemaistaționându": "staționa",
    "nestaționând": "staționa",
    "nestaționându": "staționa",
    "staționă": "staționa",
    "staționai": "staționa",
    "staționam": "staționa",
    "staționăm": "staționa",
    "staționând": "staționa",
    "staționându": "staționa",
    "staționară": "staționa",
    "staționarăm": "staționa",
    "staționarăți": "staționa",
    "staționase": "staționa",
    "staționasem": "staționa",
    "staționaseră": "staționa",
    "staționaserăm": "staționa",
    "staționaserăți": "staționa",
    "staționaseși": "staționa",
    "staționași": "staționa",
    "staționat": "staționa",
    "staționați": "staționa",
    "staționau": "staționa",
    "staționează": "staționa",
    "staționez": "staționa",
    "staționeze": "staționa",
    "staționezi": "staționa",
    "staționara": "staționar",
    "staționară": "staționar",
    "staționare": "staționar",
    "staționarei": "staționar",
    "staționarele": "staționar",
    "staționarelor": "staționar",
    "staționari": "staționar",
    "staționarii": "staționar",
    "staționarilor": "staționar",
    "staționarul": "staționar",
    "staționarului": "staționar",
    "staționată": "staționat",
    "staționate": "staționat",
    "staționați": "staționat",
    "statistică": "statistic",
    "statistice": "statistic",
    "statistici": "statistic",
    "statisticii": "statistic",
    "statisticilor": "statistic",
    "statisticul": "statistic",
    "statisticului": "statistic",
    "statistica": "statistică",
    "statistici": "statistică",
    "statisticii": "statistică",
    "statisticile": "statistică",
    "statisticilor": "statistică",
    "statisticianul": "statistician",
    "statisticianului": "statistician",
    "statisticieni": "statistician",
    "statisticienii": "statistician",
    "statisticienilor": "statistician",
    "statisticiana": "statisticiană",
    "statisticiene": "statisticiană",
    "statisticienei": "statisticiană",
    "statisticienele": "statisticiană",
    "statisticienelor": "statisticiană",
    "stațiunea": "stațiune",
    "stațiuni": "stațiune",
    "stațiunii": "stațiune",
    "stațiunile": "stațiune",
    "stațiunilor": "stațiune",
    "stative": "stativ",
    "stativele": "stativ",
    "stativelor": "stativ",
    "stativul": "stativ",
    "stativului": "stativ",
    "statoare": "stator",
    "statoarele": "stator",
    "statoarelor": "stator",
    "statorul": "stator",
    "statorului": "stator",
    "statoreactoare": "statoreactor",
    "statoreactoarele": "statoreactor",
    "statoreactoarelor": "statoreactor",
    "statoreactorul": "statoreactor",
    "statoreactorului": "statoreactor",
    "statornica": "statornic",
    "statornică": "statornic",
    "statornice": "statornic",
    "statornicei": "statornic",
    "statornicele": "statornic",
    "statornicelor": "statornic",
    "statornici": "statornic",
    "statornicii": "statornic",
    "statornicilor": "statornic",
    "statornicul": "statornic",
    "statornicului": "statornic",
    "nemaistatornicind": "statornici",
    "nemaistatornicindu": "statornici",
    "nestatornicind": "statornici",
    "nestatornicindu": "statornici",
    "statornicea": "statornici",
    "statorniceai": "statornici",
    "statorniceam": "statornici",
    "statornicească": "statornici",
    "statorniceați": "statornici",
    "statorniceau": "statornici",
    "statornicesc": "statornici",
    "statornicește": "statornici",
    "statornicești": "statornici",
    "statornicii": "statornici",
    "statornicim": "statornici",
    "statornicind": "statornici",
    "statornicindu": "statornici",
    "statorniciră": "statornici",
    "statornicirăm": "statornici",
    "statornicirăți": "statornici",
    "statornicise": "statornici",
    "statornicisem": "statornici",
    "statorniciseră": "statornici",
    "statorniciserăm": "statornici",
    "statorniciserăți": "statornici",
    "statorniciseși": "statornici",
    "statorniciși": "statornici",
    "statornicit": "statornici",
    "statorniciți": "statornici",
    "statornicia": "statornicie",
    "statorniciei": "statornicie",
    "statornicii": "statornicie",
    "statorniciile": "statornicie",
    "statorniciilor": "statornicie",
    "statornicită": "statornicit",
    "statornicite": "statornicit",
    "statorniciți": "statornicit",
    "statoscoape": "statoscop",
    "statoscoapele": "statoscop",
    "statoscoapelor": "statoscop",
    "statoscopul": "statoscop",
    "statoscopului": "statoscop",
    "nemaistatuând": "statua",
    "nemaistatuându": "statua",
    "nestatuând": "statua",
    "nestatuându": "statua",
    "statuă": "statua",
    "statuai": "statua",
    "statuam": "statua",
    "statuăm": "statua",
    "statuând": "statua",
    "statuându": "statua",
    "statuară": "statua",
    "statuarăm": "statua",
    "statuarăți": "statua",
    "statuase": "statua",
    "statuasem": "statua",
    "statuaseră": "statua",
    "statuaserăm": "statua",
    "statuaserăți": "statua",
    "statuaseși": "statua",
    "statuași": "statua",
    "statuat": "statua",
    "statuați": "statua",
    "statuau": "statua",
    "statuează": "statua",
    "statuez": "statua",
    "statueze": "statua",
    "statuezi": "statua",
    "statuara": "statuar",
    "statuară": "statuar",
    "statuare": "statuar",
    "statuarei": "statuar",
    "statuarele": "statuar",
    "statuarelor": "statuar",
    "statuari": "statuar",
    "statuarii": "statuar",
    "statuarilor": "statuar",
    "statuarul": "statuar",
    "statuarului": "statuar",
    "statuată": "statuat",
    "statuate": "statuat",
    "statuați": "statuat",
    "statueta": "statuetă",
    "statuete": "statuetă",
    "statuetei": "statuetă",
    "statuetele": "statuetă",
    "statuetelor": "statuetă",
    "statui": "statuie",
    "statuia": "statuie",
    "statuii": "statuie",
    "statuile": "statuie",
    "statuilor": "statuie",
    "statura": "statură",
    "staturi": "statură",
    "staturii": "statură",
    "staturile": "statură",
    "staturilor": "statură",
    "statute": "statut",
    "statutele": "statut",
    "statutelor": "statut",
    "statutul": "statut",
    "statutului": "statut",
    "stătuta": "stătut",
    "stătută": "stătut",
    "stătute": "stătut",
    "stătutei": "stătut",
    "stătutele": "stătut",
    "stătutelor": "stătut",
    "stătuți": "stătut",
    "stătuții": "stătut",
    "stătuților": "stătut",
    "stătutul": "stătut",
    "stătutului": "stătut",
    "staule": "staul",
    "staulele": "staul",
    "staulelor": "staul",
    "staulul": "staul",
    "staulului": "staul",
    "stava": "stavă",
    "stave": "stavă",
    "stavei": "stavă",
    "stavele": "stavă",
    "stavelor": "stavă",
    "stavila": "stavilă",
    "stavile": "stavilă",
    "stavilei": "stavilă",
    "stavilele": "stavilă",
    "stavilelor": "stavilă",
    "stăvilare": "stăvilar",
    "stăvilarele": "stăvilar",
    "stăvilarelor": "stăvilar",
    "stăvilarul": "stăvilar",
    "stăvilarului": "stăvilar",
    "nemaistăvilind": "stăvili",
    "nemaistăvilindu": "stăvili",
    "nestăvilind": "stăvili",
    "nestăvilindu": "stăvili",
    "stăvilea": "stăvili",
    "stăvileai": "stăvili",
    "stăvileam": "stăvili",
    "stăvilească": "stăvili",
    "stăvileați": "stăvili",
    "stăvileau": "stăvili",
    "stăvilesc": "stăvili",
    "stăvilește": "stăvili",
    "stăvilești": "stăvili",
    "stăvilii": "stăvili",
    "stăvilim": "stăvili",
    "stăvilind": "stăvili",
    "stăvilindu": "stăvili",
    "stăviliră": "stăvili",
    "stăvilirăm": "stăvili",
    "stăvilirăți": "stăvili",
    "stăvilise": "stăvili",
    "stăvilisem": "stăvili",
    "stăviliseră": "stăvili",
    "stăviliserăm": "stăvili",
    "stăviliserăți": "stăvili",
    "stăviliseși": "stăvili",
    "stăviliși": "stăvili",
    "stăvilit": "stăvili",
    "stăviliți": "stăvili",
    "stăvilită": "stăvilit",
    "stăvilite": "stăvilit",
    "stăviliți": "stăvilit",
    "stavridul": "stavrid",
    "stavridului": "stavrid",
    "stavrizi": "stavrid",
    "stavrizii": "stavrid",
    "stavrizilor": "stavrid",
    "staza": "stază",
    "staze": "stază",
    "stazei": "stază",
    "stazele": "stază",
    "stazelor": "stază",
    "steaua": "stea",
    "stele": "stea",
    "stelei": "stea",
    "stelele": "stea",
    "stelelor": "stea",
    "steagul": "steag",
    "steagului": "steag",
    "steaguri": "steag",
    "steagurile": "steag",
    "steagurilor": "steag",
    "șteampul": "șteamp",
    "șteampului": "șteamp",
    "șteampuri": "șteamp",
    "șteampurile": "șteamp",
    "șteampurilor": "șteamp",
    "steatoza": "steatoză",
    "steatoze": "steatoză",
    "steatozei": "steatoză",
    "steatozele": "steatoză",
    "steatozelor": "steatoză",
    "stebla": "steblă",
    "steble": "steblă",
    "steblei": "steblă",
    "steblele": "steblă",
    "steblelor": "steblă",
    "ștecăre": "ștecăr",
    "ștecărele": "ștecăr",
    "ștecărelor": "ștecăr",
    "ștecărul": "ștecăr",
    "ștecărului": "ștecăr",
    "Şt.": "Ştefan",
    "Ştefane": "Ştefan",
    "stegari": "stegar",
    "stegarii": "stegar",
    "stegarilor": "stegar",
    "stegarul": "stegar",
    "stegarului": "stegar",
    "stegozauri": "stegozaur",
    "stegozaurii": "stegozaur",
    "stegozaurilor": "stegozaur",
    "stegozaurul": "stegozaur",
    "stegozaurului": "stegozaur",
    "steiul": "stei",
    "steiului": "stei",
    "steiuri": "stei",
    "steiurile": "stei",
    "steiurilor": "stei",
    "stejari": "stejar",
    "stejarii": "stejar",
    "stejarilor": "stejar",
    "stejarul": "stejar",
    "stejarului": "stejar",
    "stejărișul": "stejăriș",
    "stejărișului": "stejăriș",
    "stejărișuri": "stejăriș",
    "stejărișurile": "stejăriș",
    "stejărișurilor": "stejăriș",
    "Stelei": "Stela",
    "stelaje": "stelaj",
    "stelajele": "stelaj",
    "stelajelor": "stelaj",
    "stelajul": "stelaj",
    "stelajului": "stelaj",
    "stelara": "stelar",
    "stelară": "stelar",
    "stelare": "stelar",
    "stelarei": "stelar",
    "stelarele": "stelar",
    "stelarelor": "stelar",
    "stelari": "stelar",
    "stelarii": "stelar",
    "stelarilor": "stelar",
    "stelarul": "stelar",
    "stelarului": "stelar",
    "steluța": "steluță",
    "steluțe": "steluță",
    "steluței": "steluță",
    "steluțele": "steluță",
    "steluțelor": "steluță",
    "stema": "stemă",
    "steme": "stemă",
    "stemei": "stemă",
    "stemele": "stemă",
    "stemelor": "stemă",
    "nemaiștemuind": "ștemui",
    "nemaiștemuindu": "ștemui",
    "neștemuind": "ștemui",
    "neștemuindu": "ștemui",
    "ștemuia": "ștemui",
    "ștemuiai": "ștemui",
    "ștemuiam": "ștemui",
    "ștemuiască": "ștemui",
    "ștemuiați": "ștemui",
    "ștemuiau": "ștemui",
    "ștemuiesc": "ștemui",
    "ștemuiește": "ștemui",
    "ștemuiești": "ștemui",
    "ștemuii": "ștemui",
    "ștemuim": "ștemui",
    "ștemuind": "ștemui",
    "ștemuindu": "ștemui",
    "ștemuiră": "ștemui",
    "ștemuirăm": "ștemui",
    "ștemuirăți": "ștemui",
    "ștemuise": "ștemui",
    "ștemuisem": "ștemui",
    "ștemuiseră": "ștemui",
    "ștemuiserăm": "ștemui",
    "ștemuiserăți": "ștemui",
    "ștemuiseși": "ștemui",
    "ștemuiși": "ștemui",
    "ștemuit": "ștemui",
    "ștemuiți": "ștemui",
    "ștemuirea": "ștemuire",
    "ștemuireo": "ștemuire",
    "ștemuiri": "ștemuire",
    "ștemuirii": "ștemuire",
    "ștemuirile": "ștemuire",
    "ștemuirilor": "ștemuire",
    "ștemuită": "ștemuit",
    "ștemuite": "ștemuit",
    "ștemuiți": "ștemuit",
    "ștemuitoare": "ștemuitor",
    "ștemuitoarea": "ștemuitor",
    "ștemuitoarei": "ștemuitor",
    "ștemuitoarele": "ștemuitor",
    "ștemuitoarelor": "ștemuitor",
    "ștemuitoareo": "ștemuitor",
    "ștemuitori": "ștemuitor",
    "ștemuitorii": "ștemuitor",
    "ștemuitorilor": "ștemuitor",
    "ștemuitorul": "ștemuitor",
    "ștemuitorule": "ștemuitor",
    "ștemuitorului": "ștemuitor",
    "stenodactilografi": "stenodactilograf",
    "stenodactilografii": "stenodactilograf",
    "stenodactilografilor": "stenodactilograf",
    "stenodactilograful": "stenodactilograf",
    "stenodactilografului": "stenodactilograf",
    "stenodactilografa": "stenodactilografă",
    "stenodactilografe": "stenodactilografă",
    "stenodactilografei": "stenodactilografă",
    "stenodactilografele": "stenodactilografă",
    "stenodactilografelor": "stenodactilografă",
    "stenodactilografia": "stenodactilografie",
    "stenodactilografiei": "stenodactilografie",
    "stenodactilografii": "stenodactilografie",
    "stenodactilografiile": "stenodactilografie",
    "stenodactilografiilor": "stenodactilografie",
    "stenografi": "stenograf",
    "stenografii": "stenograf",
    "stenografilor": "stenograf",
    "stenograful": "stenograf",
    "stenografului": "stenograf",
    "stenografa": "stenografă",
    "stenografe": "stenografă",
    "stenografei": "stenografă",
    "stenografele": "stenografă",
    "stenografelor": "stenografă",
    "nemaistenografiind": "stenografia",
    "nemaistenografiindu": "stenografia",
    "nestenografiind": "stenografia",
    "nestenografiindu": "stenografia",
    "stenografiai": "stenografia",
    "stenografiam": "stenografia",
    "stenografiară": "stenografia",
    "stenografiarăm": "stenografia",
    "stenografiarăți": "stenografia",
    "stenografiase": "stenografia",
    "stenografiasem": "stenografia",
    "stenografiaseră": "stenografia",
    "stenografiaserăm": "stenografia",
    "stenografiaserăți": "stenografia",
    "stenografiaseși": "stenografia",
    "stenografiași": "stenografia",
    "stenografiat": "stenografia",
    "stenografiați": "stenografia",
    "stenografiau": "stenografia",
    "stenografiază": "stenografia",
    "stenografie": "stenografia",
    "stenografiem": "stenografia",
    "stenografiez": "stenografia",
    "stenografieze": "stenografia",
    "stenografiezi": "stenografia",
    "stenografiind": "stenografia",
    "stenografiindu": "stenografia",
    "stenografiată": "stenografiat",
    "stenografiate": "stenografiat",
    "stenografiați": "stenografiat",
    "stenografica": "stenografic",
    "stenografică": "stenografic",
    "stenografice": "stenografic",
    "stenograficei": "stenografic",
    "stenograficele": "stenografic",
    "stenograficelor": "stenografic",
    "stenografici": "stenografic",
    "stenografia": "stenografie",
    "stenografiei": "stenografie",
    "stenografii": "stenografie",
    "stenografiile": "stenografie",
    "stenografiilor": "stenografie",
    "stenograma": "stenogramă",
    "stenograme": "stenogramă",
    "stenogramei": "stenogramă",
    "stenogramele": "stenogramă",
    "stenogramelor": "stenogramă",
    "stenotipul": "stenotip",
    "stenotipului": "stenotip",
    "stenotipuri": "stenotip",
    "stenotipurile": "stenotip",
    "stenotipurilor": "stenotip",
    "stenotipia": "stenotipie",
    "stenotipiei": "stenotipie",
    "stenotipii": "stenotipie",
    "stenotipiile": "stenotipie",
    "stenotipiilor": "stenotipie",
    "stenotipiști": "stenotipist",
    "stenotipiștii": "stenotipist",
    "stenotipiștilor": "stenotipist",
    "stenotipistul": "stenotipist",
    "stenotipistului": "stenotipist",
    "stenotipista": "stenotipistă",
    "stenotipiste": "stenotipistă",
    "stenotipistei": "stenotipistă",
    "stenotipistele": "stenotipistă",
    "stenotipistelor": "stenotipistă",
    "stenoza": "stenoză",
    "stenoze": "stenoză",
    "stenozei": "stenoză",
    "stenozele": "stenoză",
    "stenozelor": "stenoză",
    "stentori": "stentor",
    "stentorii": "stentor",
    "stentorilor": "stentor",
    "stentorul": "stentor",
    "stentorului": "stentor",
    "stepul": "step",
    "stepului": "step",
    "stepuri": "step",
    "stepurile": "step",
    "stepurilor": "step",
    "stepa": "stepă",
    "stepe": "stepă",
    "stepei": "stepă",
    "stepele": "stepă",
    "stepelor": "stepă",
    "steri": "ster",
    "sterii": "ster",
    "sterilor": "ster",
    "sterul": "ster",
    "sterului": "ster",
    "stereocinematografia": "stereocinematografie",
    "stereocinematografiei": "stereocinematografie",
    "stereocinematografii": "stereocinematografie",
    "stereocinematografiile": "stereocinematografie",
    "stereocinematografiilor": "stereocinematografie",
    "stereocromia": "stereocromie",
    "stereocromiei": "stereocromie",
    "stereocromii": "stereocromie",
    "stereocromiile": "stereocromie",
    "stereocromiilor": "stereocromie",
    "stereofonia": "stereofonie",
    "stereofoniei": "stereofonie",
    "stereofonii": "stereofonie",
    "stereofoniile": "stereofonie",
    "stereofoniilor": "stereofonie",
    "stereofotografia": "stereofotografie",
    "stereofotografiei": "stereofotografie",
    "stereofotografii": "stereofotografie",
    "stereofotografiile": "stereofotografie",
    "stereofotografiilor": "stereofotografie",
    "stereografica": "stereografic",
    "stereografică": "stereografic",
    "stereografice": "stereografic",
    "stereograficei": "stereografic",
    "stereograficele": "stereografic",
    "stereograficelor": "stereografic",
    "stereografici": "stereografic",
    "stereograficii": "stereografic",
    "stereograficilor": "stereografic",
    "stereograficul": "stereografic",
    "stereograficului": "stereografic",
    "stereograma": "stereogramă",
    "stereograme": "stereogramă",
    "stereogramei": "stereogramă",
    "stereogramele": "stereogramă",
    "stereogramelor": "stereogramă",
    "stereometrica": "stereometric",
    "stereometrică": "stereometric",
    "stereometrice": "stereometric",
    "stereometricei": "stereometric",
    "stereometricele": "stereometric",
    "stereometricelor": "stereometric",
    "stereometrici": "stereometric",
    "stereometricii": "stereometric",
    "stereometricilor": "stereometric",
    "stereometricul": "stereometric",
    "stereometricului": "stereometric",
    "stereometria": "stereometrie",
    "stereometriei": "stereometrie",
    "stereometrii": "stereometrie",
    "stereometriile": "stereometrie",
    "stereometriilor": "stereometrie",
    "stereometre": "stereometru",
    "stereometrele": "stereometru",
    "stereometrelor": "stereometru",
    "stereometrul": "stereometru",
    "stereometrului": "stereometru",
    "stereoscoape": "stereoscop",
    "stereoscoapele": "stereoscop",
    "stereoscoapelor": "stereoscop",
    "stereoscopul": "stereoscop",
    "stereoscopului": "stereoscop",
    "stereoscopica": "stereoscopic",
    "stereoscopică": "stereoscopic",
    "stereoscopice": "stereoscopic",
    "stereoscopicei": "stereoscopic",
    "stereoscopicele": "stereoscopic",
    "stereoscopicelor": "stereoscopic",
    "stereoscopici": "stereoscopic",
    "stereoscopicii": "stereoscopic",
    "stereoscopicilor": "stereoscopic",
    "stereoscopicul": "stereoscopic",
    "stereoscopicului": "stereoscopic",
    "stereoscopia": "stereoscopie",
    "stereoscopiei": "stereoscopie",
    "stereoscopii": "stereoscopie",
    "stereoscopiile": "stereoscopie",
    "stereoscopiilor": "stereoscopie",
    "stereotipa": "stereotip",
    "stereotipă": "stereotip",
    "stereotipe": "stereotip",
    "stereotipei": "stereotip",
    "stereotipele": "stereotip",
    "stereotipelor": "stereotip",
    "stereotipi": "stereotip",
    "stereotipii": "stereotip",
    "stereotipilor": "stereotip",
    "stereotipul": "stereotip",
    "stereotipului": "stereotip",
    "stereotipuri": "stereotip",
    "stereotipurile": "stereotip",
    "stereotipurilor": "stereotip",
    "stereotipica": "stereotipic",
    "stereotipică": "stereotipic",
    "stereotipice": "stereotipic",
    "stereotipicei": "stereotipic",
    "stereotipicele": "stereotipic",
    "stereotipicelor": "stereotipic",
    "stereotipici": "stereotipic",
    "stereotipicii": "stereotipic",
    "stereotipicilor": "stereotipic",
    "stereotipicul": "stereotipic",
    "stereotipicului": "stereotipic",
    "stereotipia": "stereotipie",
    "stereotipiei": "stereotipie",
    "stereotipii": "stereotipie",
    "stereotipiile": "stereotipie",
    "stereotipiilor": "stereotipie",
    "stereotomica": "stereotomic",
    "stereotomică": "stereotomic",
    "stereotomice": "stereotomic",
    "stereotomicei": "stereotomic",
    "stereotomicele": "stereotomic",
    "stereotomicelor": "stereotomic",
    "stereotomici": "stereotomic",
    "stereotomicii": "stereotomic",
    "stereotomicilor": "stereotomic",
    "stereotomicul": "stereotomic",
    "stereotomicului": "stereotomic",
    "ștergare": "ștergar",
    "ștergarele": "ștergar",
    "ștergarelor": "ștergar",
    "ștergarul": "ștergar",
    "ștergarului": "ștergar",
    "ștergătoare": "ștergător",
    "ștergătoarele": "ștergător",
    "ștergătoarelor": "ștergător",
    "ștergători": "ștergător",
    "ștergătorii": "ștergător",
    "ștergătorilor": "ștergător",
    "ștergătorul": "ștergător",
    "ștergătorului": "ștergător",
    "nemaiștergând": "șterge",
    "nemaiștergându": "șterge",
    "neștergând": "șterge",
    "neștergându": "șterge",
    "șteargă": "șterge",
    "șterg": "șterge",
    "ștergând": "șterge",
    "ștergându": "șterge",
    "ștergea": "șterge",
    "ștergeai": "șterge",
    "ștergeam": "șterge",
    "ștergeați": "șterge",
    "ștergeau": "șterge",
    "ștergem": "șterge",
    "ștergeți": "șterge",
    "ștergi": "șterge",
    "șters": "șterge",
    "șterse": "șterge",
    "ștersei": "șterge",
    "șterseră": "șterge",
    "șterserăm": "șterge",
    "șterserăți": "șterge",
    "ștersese": "șterge",
    "ștersesem": "șterge",
    "șterseseră": "șterge",
    "șterseserăm": "șterge",
    "șterseserăți": "șterge",
    "șterseseși": "șterge",
    "șterseși": "șterge",
    "ștergerea": "ștergere",
    "ștergereo": "ștergere",
    "ștergeri": "ștergere",
    "ștergerii": "ștergere",
    "ștergerile": "ștergere",
    "ștergerilor": "ștergere",
    "sterila": "steril",
    "sterilă": "steril",
    "sterile": "steril",
    "sterilei": "steril",
    "sterilele": "steril",
    "sterilelor": "steril",
    "sterili": "steril",
    "sterilii": "steril",
    "sterililor": "steril",
    "sterilul": "steril",
    "sterilului": "steril",
    "sterilitatea": "sterilitate",
    "sterilități": "sterilitate",
    "sterilității": "sterilitate",
    "sterilitățile": "sterilitate",
    "sterilităților": "sterilitate",
    "nemaisterilizând": "steriliza",
    "nemaisterilizându": "steriliza",
    "nesterilizând": "steriliza",
    "nesterilizându": "steriliza",
    "steriliză": "steriliza",
    "sterilizai": "steriliza",
    "sterilizam": "steriliza",
    "sterilizăm": "steriliza",
    "sterilizând": "steriliza",
    "sterilizându": "steriliza",
    "sterilizară": "steriliza",
    "sterilizarăm": "steriliza",
    "sterilizarăți": "steriliza",
    "sterilizase": "steriliza",
    "sterilizasem": "steriliza",
    "sterilizaseră": "steriliza",
    "sterilizaserăm": "steriliza",
    "sterilizaserăți": "steriliza",
    "sterilizaseși": "steriliza",
    "sterilizași": "steriliza",
    "sterilizat": "steriliza",
    "sterilizați": "steriliza",
    "sterilizau": "steriliza",
    "sterilizează": "steriliza",
    "sterilizez": "steriliza",
    "sterilizeze": "steriliza",
    "sterilizezi": "steriliza",
    "sterilizată": "sterilizat",
    "sterilizate": "sterilizat",
    "sterilizați": "sterilizat",
    "sterilizatoare": "sterilizator",
    "sterilizatoarele": "sterilizator",
    "sterilizatoarelor": "sterilizator",
    "sterilizatorul": "sterilizator",
    "sterilizatorului": "sterilizator",
    "sterlina": "sterlină",
    "sterline": "sterlină",
    "sterlinei": "sterlină",
    "sterlinele": "sterlină",
    "sterlinelor": "sterlină",
    "sternul": "stern",
    "sternului": "stern",
    "sternuri": "stern",
    "sternurile": "stern",
    "sternurilor": "stern",
    "sternala": "sternal",
    "sternală": "sternal",
    "sternale": "sternal",
    "sternalei": "sternal",
    "sternalele": "sternal",
    "sternalelor": "sternal",
    "sternali": "sternal",
    "sternalii": "sternal",
    "sternalilor": "sternal",
    "sternalul": "sternal",
    "sternalului": "sternal",
    "steroli": "sterol",
    "sterolii": "sterol",
    "sterolilor": "sterol",
    "sterolul": "sterol",
    "sterolului": "sterol",
    "stearpa": "sterp",
    "stearpă": "sterp",
    "sterpe": "sterp",
    "sterpei": "sterp",
    "sterpele": "sterp",
    "sterpelor": "sterp",
    "sterpi": "sterp",
    "sterpii": "sterp",
    "sterpilor": "sterp",
    "sterpul": "sterp",
    "sterpului": "sterp",
    "nemaișterpelind": "șterpeli",
    "nemaișterpelindu": "șterpeli",
    "neșterpelind": "șterpeli",
    "neșterpelindu": "șterpeli",
    "șterpelea": "șterpeli",
    "șterpeleai": "șterpeli",
    "șterpeleam": "șterpeli",
    "șterpelească": "șterpeli",
    "șterpeleați": "șterpeli",
    "șterpeleau": "șterpeli",
    "șterpelesc": "șterpeli",
    "șterpelește": "șterpeli",
    "șterpelești": "șterpeli",
    "șterpelii": "șterpeli",
    "șterpelim": "șterpeli",
    "șterpelind": "șterpeli",
    "șterpelindu": "șterpeli",
    "șterpeliră": "șterpeli",
    "șterpelirăm": "șterpeli",
    "șterpelirăți": "șterpeli",
    "șterpelise": "șterpeli",
    "șterpelisem": "șterpeli",
    "șterpeliseră": "șterpeli",
    "șterpeliserăm": "șterpeli",
    "șterpeliserăți": "șterpeli",
    "șterpeliseși": "șterpeli",
    "șterpeliși": "șterpeli",
    "șterpelit": "șterpeli",
    "șterpeliți": "șterpeli",
    "șterpelirea": "șterpelire",
    "șterpelireo": "șterpelire",
    "șterpeliri": "șterpelire",
    "șterpelirii": "șterpelire",
    "șterpelirile": "șterpelire",
    "șterpelirilor": "șterpelire",
    "șterpelită": "șterpelit",
    "șterpelite": "șterpelit",
    "șterpeliți": "șterpelit",
    "ștearsă": "șters",
    "șterse": "șters",
    "șterși": "șters",
    "ștersătura": "ștersătură",
    "ștersături": "ștersătură",
    "ștersăturii": "ștersătură",
    "ștersăturile": "ștersătură",
    "ștersăturilor": "ștersătură",
    "stetoscoape": "stetoscop",
    "stetoscoapele": "stetoscop",
    "stetoscoapelor": "stetoscop",
    "stetoscopul": "stetoscop",
    "stetoscopului": "stetoscop",
    "stetoscopia": "stetoscopie",
    "stetoscopiei": "stetoscopie",
    "stetoscopii": "stetoscopie",
    "stetoscopiile": "stetoscopie",
    "stetoscopiilor": "stetoscopie",
    "ștevia": "ștevie",
    "șteviei": "ștevie",
    "ștevii": "ștevie",
    "șteviile": "ștevie",
    "șteviilor": "ștevie",
    "stewardesa": "stewardesă",
    "stewardese": "stewardesă",
    "stewardesei": "stewardesă",
    "stewardesele": "stewardesă",
    "stewardeselor": "stewardesă",
    "nemaiștiind": "ști",
    "nemaiștiindu": "ști",
    "neștiind": "ști",
    "neștiindu": "ști",
    "știa": "ști",
    "știai": "ști",
    "știam": "ști",
    "știați": "ști",
    "știau": "ști",
    "știe": "ști",
    "știi": "ști",
    "știind": "ști",
    "știindu": "ști",
    "știm": "ști",
    "știți": "ști",
    "știu": "ști",
    "știui": "ști",
    "știură": "ști",
    "știurăm": "ști",
    "știurăți": "ști",
    "știuse": "ști",
    "știusem": "ști",
    "știuseră": "ști",
    "știuserăm": "ști",
    "știuserăți": "ști",
    "știuseși": "ști",
    "știuși": "ști",
    "știut": "ști",
    "stibiul": "stibiu",
    "stibiului": "stibiu",
    "sticla": "sticlă",
    "sticle": "sticlă",
    "sticlei": "sticlă",
    "sticlele": "sticlă",
    "sticlelor": "sticlă",
    "sticlari": "sticlar",
    "sticlarii": "sticlar",
    "sticlarilor": "sticlar",
    "sticlarul": "sticlar",
    "sticlarului": "sticlar",
    "sticlăria": "sticlărie",
    "sticlăriei": "sticlărie",
    "sticlării": "sticlărie",
    "sticlăriile": "sticlărie",
    "sticlăriilor": "sticlărie",
    "nemaisticlind": "sticli",
    "nemaisticlindu": "sticli",
    "nesticlind": "sticli",
    "nesticlindu": "sticli",
    "sticlea": "sticli",
    "sticleai": "sticli",
    "sticleam": "sticli",
    "sticlească": "sticli",
    "sticleați": "sticli",
    "sticleau": "sticli",
    "sticlesc": "sticli",
    "sticlește": "sticli",
    "sticlești": "sticli",
    "sticlii": "sticli",
    "sticlim": "sticli",
    "sticlind": "sticli",
    "sticlindu": "sticli",
    "sticliră": "sticli",
    "sticlirăm": "sticli",
    "sticlirăți": "sticli",
    "sticlise": "sticli",
    "sticlisem": "sticli",
    "sticliseră": "sticli",
    "sticliserăm": "sticli",
    "sticliserăți": "sticli",
    "sticliseși": "sticli",
    "sticliși": "sticli",
    "sticlit": "sticli",
    "sticliți": "sticli",
    "sticlită": "sticlit",
    "sticlite": "sticlit",
    "sticliți": "sticlit",
    "sticloasa": "sticlos",
    "sticloasă": "sticlos",
    "sticloase": "sticlos",
    "sticloasei": "sticlos",
    "sticloasele": "sticlos",
    "sticloaselor": "sticlos",
    "sticloși": "sticlos",
    "sticloșii": "sticlos",
    "sticloșilor": "sticlos",
    "sticlosul": "sticlos",
    "sticlosului": "sticlos",
    "sticluța": "sticluță",
    "sticluțe": "sticluță",
    "sticluței": "sticluță",
    "sticluțele": "sticluță",
    "sticluțelor": "sticluță",
    "știftul": "știft",
    "știftului": "știft",
    "știfturi": "știft",
    "știfturile": "știft",
    "știfturilor": "știft",
    "stigmate": "stigmat",
    "stigmatele": "stigmat",
    "stigmatelor": "stigmat",
    "stigmatul": "stigmat",
    "stigmatului": "stigmat",
    "stigmatismul": "stigmatism",
    "stigmatismului": "stigmatism",
    "nemaistigmatizând": "stigmatiza",
    "nemaistigmatizându": "stigmatiza",
    "nestigmatizând": "stigmatiza",
    "nestigmatizându": "stigmatiza",
    "stigmatiză": "stigmatiza",
    "stigmatizai": "stigmatiza",
    "stigmatizam": "stigmatiza",
    "stigmatizăm": "stigmatiza",
    "stigmatizând": "stigmatiza",
    "stigmatizându": "stigmatiza",
    "stigmatizară": "stigmatiza",
    "stigmatizarăm": "stigmatiza",
    "stigmatizarăți": "stigmatiza",
    "stigmatizase": "stigmatiza",
    "stigmatizasem": "stigmatiza",
    "stigmatizaseră": "stigmatiza",
    "stigmatizaserăm": "stigmatiza",
    "stigmatizaserăți": "stigmatiza",
    "stigmatizaseși": "stigmatiza",
    "stigmatizași": "stigmatiza",
    "stigmatizat": "stigmatiza",
    "stigmatizați": "stigmatiza",
    "stigmatizau": "stigmatiza",
    "stigmatizează": "stigmatiza",
    "stigmatizez": "stigmatiza",
    "stigmatizeze": "stigmatiza",
    "stigmatizezi": "stigmatiza",
    "stigmatizată": "stigmatizat",
    "stigmatizate": "stigmatizat",
    "stigmatizați": "stigmatizat",
    "stihul": "stih",
    "stihului": "stih",
    "stihuri": "stih",
    "stihurile": "stih",
    "stihurilor": "stih",
    "stihare": "stihar",
    "stiharele": "stihar",
    "stiharelor": "stihar",
    "stiharul": "stihar",
    "stiharului": "stihar",
    "stihia": "stihie",
    "stihiei": "stihie",
    "stihii": "stihie",
    "stihiile": "stihie",
    "stihiilor": "stihie",
    "stihuia": "stihui",
    "stihuiai": "stihui",
    "stihuiam": "stihui",
    "stihuiați": "stihui",
    "stihuiau": "stihui",
    "stihuiesc": "stihui",
    "stihuiește": "stihui",
    "stihuii": "stihui",
    "stihuim": "stihui",
    "stihuind": "stihui",
    "stihuindu": "stihui",
    "stihuiră": "stihui",
    "stihuirăm": "stihui",
    "stihuirăți": "stihui",
    "stihuise": "stihui",
    "stihuisem": "stihui",
    "stihuiseră": "stihui",
    "stihuiserăm": "stihui",
    "stihuiserăți": "stihui",
    "stihuiseși": "stihui",
    "stihuiși": "stihui",
    "stihuit": "stihui",
    "stihuiți": "stihui",
    "stihuitu": "stihui",
    "stihuită": "stihuit",
    "stihuite": "stihuit",
    "stihuiți": "stihuit",
    "știința": "știință",
    "științe": "știință",
    "științei": "știință",
    "științele": "știință",
    "științelor": "știință",
    "jur.": "științe_juridice",
    "șt.nat.": "științele_naturii",
    "științifica": "științific",
    "științifică": "științific",
    "științifice": "științific",
    "științificei": "științific",
    "științificele": "științific",
    "științificelor": "științific",
    "științifici": "științific",
    "științificii": "științific",
    "științificilor": "științific",
    "științificul": "științific",
    "științificului": "științific",
    "stilul": "stil",
    "stilului": "stil",
    "stiluri": "stil",
    "stilurile": "stil",
    "stilurilor": "stil",
    "stilete": "stilet",
    "stiletele": "stilet",
    "stiletelor": "stilet",
    "stiletul": "stilet",
    "stiletului": "stilet",
    "stiliști": "stilist",
    "stiliștii": "stilist",
    "stiliștilor": "stilist",
    "stilistul": "stilist",
    "stilistului": "stilist",
    "stilista": "stilistă",
    "stiliste": "stilistă",
    "stilistei": "stilistă",
    "stilistele": "stilistă",
    "stilistelor": "stilistă",
    "stilistica": "stilistic",
    "stilistică": "stilistic",
    "stilistice": "stilistic",
    "stilistici": "stilistic",
    "stilistica": "stilistică",
    "stilistice": "stilistică",
    "stilisticei": "stilistică",
    "stilisticele": "stilistică",
    "stilisticelor": "stilistică",
    "nemaistilizând": "stiliza",
    "nemaistilizându": "stiliza",
    "nestilizând": "stiliza",
    "nestilizându": "stiliza",
    "stiliză": "stiliza",
    "stilizai": "stiliza",
    "stilizam": "stiliza",
    "stilizăm": "stiliza",
    "stilizând": "stiliza",
    "stilizându": "stiliza",
    "stilizară": "stiliza",
    "stilizarăm": "stiliza",
    "stilizarăți": "stiliza",
    "stilizase": "stiliza",
    "stilizasem": "stiliza",
    "stilizaseră": "stiliza",
    "stilizaserăm": "stiliza",
    "stilizaserăți": "stiliza",
    "stilizaseși": "stiliza",
    "stilizași": "stiliza",
    "stilizat": "stiliza",
    "stilizați": "stiliza",
    "stilizau": "stiliza",
    "stilizează": "stiliza",
    "stilizez": "stiliza",
    "stilizeze": "stiliza",
    "stilizezi": "stiliza",
    "stilizată": "stilizat",
    "stilizate": "stilizat",
    "stilizați": "stilizat",
    "stiloul": "stilou",
    "stiloului": "stilou",
    "stilouri": "stilou",
    "stilourile": "stilou",
    "stilourilor": "stilou",
    "nemaistimând": "stima",
    "nemaistimându": "stima",
    "nestimând": "stima",
    "nestimându": "stima",
    "stimă": "stima",
    "stimai": "stima",
    "stimam": "stima",
    "stimăm": "stima",
    "stimând": "stima",
    "stimându": "stima",
    "stimară": "stima",
    "stimarăm": "stima",
    "stimarăți": "stima",
    "stimase": "stima",
    "stimasem": "stima",
    "stimaseră": "stima",
    "stimaserăm": "stima",
    "stimaserăți": "stima",
    "stimaseși": "stima",
    "stimași": "stima",
    "stimat": "stima",
    "stimați": "stima",
    "stimau": "stima",
    "stimează": "stima",
    "stimez": "stima",
    "stimeze": "stima",
    "stimezi": "stima",
    "știma": "știmă",
    "știme": "știmă",
    "știmei": "știmă",
    "știmele": "știmă",
    "știmelor": "știmă",
    "stimabili": "stimabil",
    "stimabilii": "stimabil",
    "stimabililor": "stimabil",
    "stimabilul": "stimabil",
    "stimabilului": "stimabil",
    "stimabila": "stimabilă",
    "stimabile": "stimabilă",
    "stimabilei": "stimabilă",
    "stimabilele": "stimabilă",
    "stimabilelor": "stimabilă",
    "stimată": "stimat",
    "stimate": "stimat",
    "stimați": "stimat",
    "stimuli": "stimul",
    "stimulii": "stimul",
    "stimulilor": "stimul",
    "stimulul": "stimul",
    "stimulului": "stimul",
    "nemaistimulând": "stimula",
    "nemaistimulându": "stimula",
    "nestimulând": "stimula",
    "nestimulându": "stimula",
    "stimulă": "stimula",
    "stimulai": "stimula",
    "stimulam": "stimula",
    "stimulăm": "stimula",
    "stimulând": "stimula",
    "stimulându": "stimula",
    "stimulară": "stimula",
    "stimularăm": "stimula",
    "stimularăți": "stimula",
    "stimulase": "stimula",
    "stimulasem": "stimula",
    "stimulaseră": "stimula",
    "stimulaserăm": "stimula",
    "stimulaserăți": "stimula",
    "stimulaseși": "stimula",
    "stimulași": "stimula",
    "stimulat": "stimula",
    "stimulați": "stimula",
    "stimulau": "stimula",
    "stimulează": "stimula",
    "stimulez": "stimula",
    "stimuleze": "stimula",
    "stimulezi": "stimula",
    "stimularea": "stimulare",
    "stimulări": "stimulare",
    "stimulării": "stimulare",
    "stimulările": "stimulare",
    "stimulărilor": "stimulare",
    "stimulată": "stimulat",
    "stimulate": "stimulat",
    "stimulați": "stimulat",
    "stimulatori": "stimulator",
    "stimulatorii": "stimulator",
    "stimulatorilor": "stimulator",
    "stimulatorul": "stimulator",
    "stimulatorului": "stimulator",
    "stimulente": "stimulent",
    "stimulentele": "stimulent",
    "stimulentelor": "stimulent",
    "stimulentul": "stimulent",
    "stimulentului": "stimulent",
    "stindarde": "stindard",
    "stindardele": "stindard",
    "stindardelor": "stindard",
    "stindardul": "stindard",
    "stindardului": "stindard",
    "stingătoare": "stingător",
    "stingătoarele": "stingător",
    "stingătoarelor": "stingător",
    "stingătorul": "stingător",
    "stingătorului": "stingător",
    "nemaistingând": "stinge",
    "nemaistingându": "stinge",
    "nestingând": "stinge",
    "nestingându": "stinge",
    "sting": "stinge",
    "stingă": "stinge",
    "stingând": "stinge",
    "stingându": "stinge",
    "stingea": "stinge",
    "stingeai": "stinge",
    "stingeam": "stinge",
    "stingeați": "stinge",
    "stingeau": "stinge",
    "stingem": "stinge",
    "stingeți": "stinge",
    "stingi": "stinge",
    "stins": "stinge",
    "stinse": "stinge",
    "stinsei": "stinge",
    "stinseră": "stinge",
    "stinserăm": "stinge",
    "stinserăți": "stinge",
    "stinsese": "stinge",
    "stinsesem": "stinge",
    "stinseseră": "stinge",
    "stinseserăm": "stinge",
    "stinseserăți": "stinge",
    "stinseseși": "stinge",
    "stinseși": "stinge",
    "stingerea": "stingere",
    "stingereo": "stingere",
    "stingeri": "stingere",
    "stingerii": "stingere",
    "stingerile": "stingere",
    "stingerilor": "stingere",
    "stinghera": "stingher",
    "stingheră": "stingher",
    "stinghere": "stingher",
    "stingherei": "stingher",
    "stingherele": "stingher",
    "stingherelor": "stingher",
    "stingheri": "stingher",
    "stingherii": "stingher",
    "stingherilor": "stingher",
    "stingherul": "stingher",
    "stingherului": "stingher",
    "stinghereala": "stinghereală",
    "stinghereli": "stinghereală",
    "stingherelii": "stinghereală",
    "stingherelile": "stinghereală",
    "stingherelilor": "stinghereală",
    "nemaistingherind": "stingheri",
    "nemaistingherindu": "stingheri",
    "nestingherind": "stingheri",
    "nestingherindu": "stingheri",
    "stingherea": "stingheri",
    "stinghereai": "stingheri",
    "stingheream": "stingheri",
    "stingherească": "stingheri",
    "stinghereați": "stingheri",
    "stinghereau": "stingheri",
    "stingheresc": "stingheri",
    "stingherește": "stingheri",
    "stingherești": "stingheri",
    "stingherii": "stingheri",
    "stingherim": "stingheri",
    "stingherind": "stingheri",
    "stingherindu": "stingheri",
    "stingheriră": "stingheri",
    "stingherirăm": "stingheri",
    "stingherirăți": "stingheri",
    "stingherise": "stingheri",
    "stingherisem": "stingheri",
    "stingheriseră": "stingheri",
    "stingheriserăm": "stingheri",
    "stingheriserăți": "stingheri",
    "stingheriseși": "stingheri",
    "stingheriși": "stingheri",
    "stingherit": "stingheri",
    "stingheriți": "stingheri",
    "stingherirea": "stingherire",
    "stingherireo": "stingherire",
    "stingheriri": "stingherire",
    "stingheririi": "stingherire",
    "stingheririle": "stingherire",
    "stingheririlor": "stingherire",
    "stingherita": "stingherit",
    "stingherită": "stingherit",
    "stingherite": "stingherit",
    "stingheritei": "stingherit",
    "stingheritele": "stingherit",
    "stingheritelor": "stingherit",
    "stingheriți": "stingherit",
    "stingheriții": "stingherit",
    "stingheriților": "stingherit",
    "stingherito": "stingherit",
    "stingheritul": "stingherit",
    "stingheritule": "stingherit",
    "stingheritului": "stingherit",
    "stinghia": "stinghie",
    "stinghiei": "stinghie",
    "stinghii": "stinghie",
    "stinghiile": "stinghie",
    "stinghiilor": "stinghie",
    "stinsă": "stins",
    "stinse": "stins",
    "stinși": "stins",
    "stinșii": "stins",
    "stinșilor": "stins",
    "stinsul": "stins",
    "stinsului": "stins",
    "stipela": "stipelă",
    "stipele": "stipelă",
    "stipelei": "stipelă",
    "stipelele": "stipelă",
    "stipelelor": "stipelă",
    "nemaistipendiind": "stipendia",
    "nemaistipendiindu": "stipendia",
    "nestipendiind": "stipendia",
    "nestipendiindu": "stipendia",
    "stipendiai": "stipendia",
    "stipendiam": "stipendia",
    "stipendiară": "stipendia",
    "stipendiarăm": "stipendia",
    "stipendiarăți": "stipendia",
    "stipendiase": "stipendia",
    "stipendiasem": "stipendia",
    "stipendiaseră": "stipendia",
    "stipendiaserăm": "stipendia",
    "stipendiaserăți": "stipendia",
    "stipendiaseși": "stipendia",
    "stipendiași": "stipendia",
    "stipendiat": "stipendia",
    "stipendiați": "stipendia",
    "stipendiau": "stipendia",
    "stipendiază": "stipendia",
    "stipendie": "stipendia",
    "stipendiem": "stipendia",
    "stipendiez": "stipendia",
    "stipendieze": "stipendia",
    "stipendiezi": "stipendia",
    "stipendiind": "stipendia",
    "stipendiindu": "stipendia",
    "stipendiată": "stipendiat",
    "stipendiate": "stipendiat",
    "stipendiați": "stipendiat",
    "stipendii": "stipendiu",
    "stipendiile": "stipendiu",
    "stipendiilor": "stipendiu",
    "stipendiul": "stipendiu",
    "stipendiului": "stipendiu",
    "nemaistipulând": "stipula",
    "nemaistipulându": "stipula",
    "nestipulând": "stipula",
    "nestipulându": "stipula",
    "stipulă": "stipula",
    "stipulai": "stipula",
    "stipulam": "stipula",
    "stipulăm": "stipula",
    "stipulând": "stipula",
    "stipulându": "stipula",
    "stipulară": "stipula",
    "stipularăm": "stipula",
    "stipularăți": "stipula",
    "stipulase": "stipula",
    "stipulasem": "stipula",
    "stipulaseră": "stipula",
    "stipulaserăm": "stipula",
    "stipulaserăți": "stipula",
    "stipulaseși": "stipula",
    "stipulași": "stipula",
    "stipulat": "stipula",
    "stipulați": "stipula",
    "stipulau": "stipula",
    "stipulează": "stipula",
    "stipulez": "stipula",
    "stipuleze": "stipula",
    "stipulezi": "stipula",
    "stipulată": "stipulat",
    "stipulate": "stipulat",
    "stipulați": "stipulat",
    "stipulația": "stipulație",
    "stipulației": "stipulație",
    "stipulații": "stipulație",
    "stipulațiile": "stipulație",
    "stipulațiilor": "stipulație",
    "știrul": "știr",
    "știrului": "știr",
    "știrba": "știrb",
    "știrbă": "știrb",
    "știrbe": "știrb",
    "știrbei": "știrb",
    "știrbele": "știrb",
    "știrbelor": "știrb",
    "știrbi": "știrb",
    "știrbii": "știrb",
    "știrbilor": "știrb",
    "știrbul": "știrb",
    "știrbului": "știrb",
    "nemaiștirbind": "știrbi",
    "nemaiștirbindu": "știrbi",
    "neștirbind": "știrbi",
    "neștirbindu": "știrbi",
    "știrbea": "știrbi",
    "știrbeai": "știrbi",
    "știrbeam": "știrbi",
    "știrbească": "știrbi",
    "știrbeați": "știrbi",
    "știrbeau": "știrbi",
    "știrbesc": "știrbi",
    "știrbește": "știrbi",
    "știrbești": "știrbi",
    "știrbii": "știrbi",
    "știrbim": "știrbi",
    "știrbind": "știrbi",
    "știrbindu": "știrbi",
    "știrbiră": "știrbi",
    "știrbirăm": "știrbi",
    "știrbirăți": "știrbi",
    "știrbise": "știrbi",
    "știrbisem": "știrbi",
    "știrbiseră": "știrbi",
    "știrbiserăm": "știrbi",
    "știrbiserăți": "știrbi",
    "știrbiseși": "știrbi",
    "știrbiși": "știrbi",
    "știrbit": "știrbi",
    "știrbiți": "știrbi",
    "știrbirea": "știrbire",
    "știrbireo": "știrbire",
    "știrbiri": "știrbire",
    "știrbirii": "știrbire",
    "știrbirile": "știrbire",
    "știrbirilor": "știrbire",
    "știrbita": "știrbit",
    "știrbită": "știrbit",
    "știrbite": "știrbit",
    "știrbitei": "știrbit",
    "știrbitele": "știrbit",
    "știrbitelor": "știrbit",
    "știrbiți": "știrbit",
    "știrbiții": "știrbit",
    "știrbiților": "știrbit",
    "știrbito": "știrbit",
    "știrbitul": "știrbit",
    "știrbitule": "știrbit",
    "știrbitului": "știrbit",
    "știrbitura": "știrbitură",
    "știrbituri": "știrbitură",
    "știrbiturii": "știrbitură",
    "știrbiturile": "știrbitură",
    "știrbiturilor": "știrbitură",
    "știrea": "știre",
    "știri": "știre",
    "știrii": "știre",
    "știrile": "știre",
    "știrilor": "știre",
    "stireni": "stiren",
    "stirenii": "stiren",
    "stirenilor": "stiren",
    "stirenul": "stiren",
    "stirenului": "stiren",
    "stirpea": "stirpe",
    "stirpei": "stirpe",
    "stirpele": "stirpe",
    "stirpelor": "stirpe",
    "știubeie": "știubei",
    "știubeiele": "știubei",
    "știubeielor": "știubei",
    "știubeiul": "știubei",
    "știubeiului": "știubei",
    "știuca": "știucă",
    "știuci": "știucă",
    "știucii": "știucă",
    "știucile": "știucă",
    "știucilor": "știucă",
    "știuletele": "știulete",
    "știuletelui": "știulete",
    "știuleți": "știulete",
    "știuleții": "știulete",
    "știuleților": "știulete",
    "știută": "știut",
    "știute": "știut",
    "știuți": "știut",
    "știutoare": "știutor",
    "știutoarea": "știutor",
    "știutoarei": "știutor",
    "știutoarele": "știutor",
    "știutoarelor": "știutor",
    "știutori": "știutor",
    "știutorii": "știutor",
    "știutorilor": "știutor",
    "știutorul": "știutor",
    "știutorului": "știutor",
    "stiva": "stivă",
    "stive": "stivă",
    "stivei": "stivă",
    "stivele": "stivă",
    "stivelor": "stivă",
    "nemaistivuind": "stivui",
    "nemaistivuindu": "stivui",
    "nestivuind": "stivui",
    "nestivuindu": "stivui",
    "stivuia": "stivui",
    "stivuiai": "stivui",
    "stivuiam": "stivui",
    "stivuiască": "stivui",
    "stivuiați": "stivui",
    "stivuiau": "stivui",
    "stivuiesc": "stivui",
    "stivuiește": "stivui",
    "stivuiești": "stivui",
    "stivuii": "stivui",
    "stivuim": "stivui",
    "stivuind": "stivui",
    "stivuindu": "stivui",
    "stivuiră": "stivui",
    "stivuirăm": "stivui",
    "stivuirăți": "stivui",
    "stivuise": "stivui",
    "stivuisem": "stivui",
    "stivuiseră": "stivui",
    "stivuiserăm": "stivui",
    "stivuiserăți": "stivui",
    "stivuiseși": "stivui",
    "stivuiși": "stivui",
    "stivuit": "stivui",
    "stivuiți": "stivui",
    "stivuirea": "stivuire",
    "stivuireo": "stivuire",
    "stivuiri": "stivuire",
    "stivuirii": "stivuire",
    "stivuirile": "stivuire",
    "stivuirilor": "stivuire",
    "stivuita": "stivuit",
    "stivuită": "stivuit",
    "stivuite": "stivuit",
    "stivuitei": "stivuit",
    "stivuitele": "stivuit",
    "stivuitelor": "stivuit",
    "stivuiți": "stivuit",
    "stivuiții": "stivuit",
    "stivuiților": "stivuit",
    "stivuito": "stivuit",
    "stivuitul": "stivuit",
    "stivuitule": "stivuit",
    "stivuitului": "stivuit",
    "nemaistorcând": "stoarce",
    "nemaistorcându": "stoarce",
    "nestorcând": "stoarce",
    "nestorcându": "stoarce",
    "stoarcă": "stoarce",
    "stoarcem": "stoarce",
    "stoarceți": "stoarce",
    "stoarse": "stoarce",
    "stoarseră": "stoarce",
    "stoarserăm": "stoarce",
    "stoarserăți": "stoarce",
    "storc": "stoarce",
    "storcând": "stoarce",
    "storcându": "stoarce",
    "storcea": "stoarce",
    "storceai": "stoarce",
    "storceam": "stoarce",
    "storceați": "stoarce",
    "storceau": "stoarce",
    "storci": "stoarce",
    "stors": "stoarce",
    "storsei": "stoarce",
    "storsese": "stoarce",
    "storsesem": "stoarce",
    "storseseră": "stoarce",
    "storseserăm": "stoarce",
    "storseserăți": "stoarce",
    "storseseși": "stoarce",
    "storseși": "stoarce",
    "stoarcerea": "stoarcere",
    "stoarcereo": "stoarcere",
    "stoarceri": "stoarcere",
    "stoarcerii": "stoarcere",
    "stoarcerile": "stoarcere",
    "stoarcerilor": "stoarcere",
    "stocul": "stoc",
    "stocului": "stoc",
    "stocuri": "stoc",
    "stocurile": "stoc",
    "stocurilor": "stoc",
    "nemaistocând": "stoca",
    "nemaistocându": "stoca",
    "nestocând": "stoca",
    "nestocându": "stoca",
    "stocă": "stoca",
    "stocai": "stoca",
    "stocam": "stoca",
    "stocăm": "stoca",
    "stocând": "stoca",
    "stocându": "stoca",
    "stocară": "stoca",
    "stocarăm": "stoca",
    "stocarăți": "stoca",
    "stocase": "stoca",
    "stocasem": "stoca",
    "stocaseră": "stoca",
    "stocaserăm": "stoca",
    "stocaserăți": "stoca",
    "stocaseși": "stoca",
    "stocași": "stoca",
    "stocat": "stoca",
    "stocați": "stoca",
    "stocau": "stoca",
    "stochează": "stoca",
    "stochez": "stoca",
    "stocheze": "stoca",
    "stochezi": "stoca",
    "stocaje": "stocaj",
    "stocajele": "stocaj",
    "stocajelor": "stocaj",
    "stocajul": "stocaj",
    "stocajului": "stocaj",
    "stocastica": "stocastic",
    "stocastică": "stocastic",
    "stocastice": "stocastic",
    "stocasticei": "stocastic",
    "stocasticele": "stocastic",
    "stocasticelor": "stocastic",
    "stocastici": "stocastic",
    "stocasticii": "stocastic",
    "stocasticilor": "stocastic",
    "stocasticul": "stocastic",
    "stocasticului": "stocastic",
    "stocată": "stocat",
    "stocate": "stocat",
    "stocați": "stocat",
    "stoechiometrica": "stoechiometric",
    "stoechiometrică": "stoechiometric",
    "stoechiometrice": "stoechiometric",
    "stoechiometricei": "stoechiometric",
    "stoechiometricele": "stoechiometric",
    "stoechiometricelor": "stoechiometric",
    "stoechiometrici": "stoechiometric",
    "stoechiometricii": "stoechiometric",
    "stoechiometricilor": "stoechiometric",
    "stoechiometricul": "stoechiometric",
    "stoechiometricului": "stoechiometric",
    "stofa": "stofă",
    "stofe": "stofă",
    "stofei": "stofă",
    "stofele": "stofă",
    "stofelor": "stofă",
    "stogul": "stog",
    "stogului": "stog",
    "stoguri": "stog",
    "stogurile": "stog",
    "stogurilor": "stog",
    "stoica": "stoic",
    "stoică": "stoic",
    "stoice": "stoic",
    "stoicei": "stoic",
    "stoicele": "stoic",
    "stoicelor": "stoic",
    "stoici": "stoic",
    "stoicii": "stoic",
    "stoicilor": "stoic",
    "stoicul": "stoic",
    "stoicului": "stoic",
    "stoica": "stoică",
    "stoice": "stoică",
    "stoicei": "stoică",
    "stoicele": "stoică",
    "stoicelor": "stoică",
    "stoicismul": "stoicism",
    "stoicismului": "stoicism",
    "stolul": "stol",
    "stolului": "stol",
    "stoluri": "stol",
    "stolurile": "stol",
    "stolurilor": "stol",
    "stolnici": "stolnic",
    "stolnicii": "stolnic",
    "stolnicilor": "stolnic",
    "stolnicul": "stolnic",
    "stolnicului": "stolnic",
    "stoloni": "stolon",
    "stolonii": "stolon",
    "stolonilor": "stolon",
    "stolonul": "stolon",
    "stolonului": "stolon",
    "stomacul": "stomac",
    "stomacului": "stomac",
    "stomacuri": "stomac",
    "stomacurile": "stomac",
    "stomacurilor": "stomac",
    "stomata": "stomată",
    "stomate": "stomată",
    "stomatei": "stomată",
    "stomatele": "stomată",
    "stomatelor": "stomată",
    "stomatita": "stomatită",
    "stomatite": "stomatită",
    "stomatitei": "stomatită",
    "stomatitele": "stomatită",
    "stomatitelor": "stomatită",
    "stomatologi": "stomatolog",
    "stomatologii": "stomatolog",
    "stomatologilor": "stomatolog",
    "stomatologul": "stomatolog",
    "stomatologului": "stomatolog",
    "stomatologica": "stomatologic",
    "stomatologică": "stomatologic",
    "stomatologice": "stomatologic",
    "stomatologicei": "stomatologic",
    "stomatologicele": "stomatologic",
    "stomatologicelor": "stomatologic",
    "stomatologici": "stomatologic",
    "stomatologicii": "stomatologic",
    "stomatologicilor": "stomatologic",
    "stomatologicul": "stomatologic",
    "stomatologicului": "stomatologic",
    "stomatologia": "stomatologie",
    "stomatologiei": "stomatologie",
    "stomatologii": "stomatologie",
    "stopul": "stop",
    "stopului": "stop",
    "stopuri": "stop",
    "stopurile": "stop",
    "stopurilor": "stop",
    "nemaistopând": "stopa",
    "nemaistopându": "stopa",
    "nestopând": "stopa",
    "nestopându": "stopa",
    "stopă": "stopa",
    "stopai": "stopa",
    "stopam": "stopa",
    "stopăm": "stopa",
    "stopând": "stopa",
    "stopându": "stopa",
    "stopară": "stopa",
    "stoparăm": "stopa",
    "stoparăți": "stopa",
    "stopase": "stopa",
    "stopasem": "stopa",
    "stopaseră": "stopa",
    "stopaserăm": "stopa",
    "stopaserăți": "stopa",
    "stopaseși": "stopa",
    "stopași": "stopa",
    "stopat": "stopa",
    "stopați": "stopa",
    "stopau": "stopa",
    "stopează": "stopa",
    "stopez": "stopa",
    "stopeze": "stopa",
    "stopezi": "stopa",
    "stoparea": "stopare",
    "stopări": "stopare",
    "stopării": "stopare",
    "stopările": "stopare",
    "stopată": "stopat",
    "stopate": "stopat",
    "stopați": "stopat",
    "stoperi": "stoper",
    "stoperii": "stoper",
    "stoperilor": "stoper",
    "stoperul": "stoper",
    "stoperului": "stoper",
    "storul": "stor",
    "storului": "stor",
    "storuri": "stor",
    "storurile": "stor",
    "storurilor": "stor",
    "storcirea": "storcire",
    "storciri": "storcire",
    "storcirii": "storcire",
    "storcirile": "storcire",
    "storcirilor": "storcire",
    "stoarsă": "stors",
    "stoarse": "stors",
    "storși": "stors",
    "storsul": "stors",
    "storsului": "stors",
    "nemaistrăbătând": "străbate",
    "nemaistrăbătându": "străbate",
    "nestrăbătând": "străbate",
    "nestrăbătându": "străbate",
    "străbat": "străbate",
    "străbată": "străbate",
    "străbătând": "străbate",
    "străbătându": "străbate",
    "străbătea": "străbate",
    "străbăteai": "străbate",
    "străbăteam": "străbate",
    "străbăteați": "străbate",
    "străbăteau": "străbate",
    "străbatem": "străbate",
    "străbateți": "străbate",
    "străbați": "străbate",
    "străbătu": "străbate",
    "străbătui": "străbate",
    "străbătură": "străbate",
    "străbăturăm": "străbate",
    "străbăturăți": "străbate",
    "străbătuse": "străbate",
    "străbătusem": "străbate",
    "străbătuseră": "străbate",
    "străbătuserăm": "străbate",
    "străbătuserăți": "străbate",
    "străbătuseși": "străbate",
    "străbătuși": "străbate",
    "străbătut": "străbate",
    "străbaterea": "străbatere",
    "străbătută": "străbătut",
    "străbătute": "străbătut",
    "străbătuți": "străbătut",
    "strabismul": "strabism",
    "strabismului": "strabism",
    "strabometre": "strabometru",
    "strabometrele": "strabometru",
    "strabometrelor": "strabometru",
    "strabometrul": "strabometru",
    "strabometrului": "strabometru",
    "străbuna": "străbun",
    "străbună": "străbun",
    "străbune": "străbun",
    "străbunei": "străbun",
    "străbunele": "străbun",
    "străbunelor": "străbun",
    "străbuni": "străbun",
    "străbunii": "străbun",
    "străbunilor": "străbun",
    "străbunul": "străbun",
    "străbunului": "străbun",
    "străbuna": "străbună",
    "străbune": "străbună",
    "străbunei": "străbună",
    "străbunele": "străbună",
    "străbunelor": "străbună",
    "străbunici": "străbunic",
    "străbunicii": "străbunic",
    "străbunicilor": "străbunic",
    "străbunicul": "străbunic",
    "străbunicului": "străbunic",
    "străbunica": "străbunică",
    "străbunice": "străbunică",
    "străbunicei": "străbunică",
    "străbunicele": "străbunică",
    "străbunicelor": "străbunică",
    "strachina": "strachină",
    "străchini": "strachină",
    "străchinii": "strachină",
    "străchinile": "strachină",
    "străchinilor": "strachină",
    "str.": "strada",
    "strada": "stradă",
    "străzi": "stradă",
    "străzii": "stradă",
    "străzile": "stradă",
    "străzilor": "stradă",
    "stradala": "stradal",
    "stradală": "stradal",
    "stradale": "stradal",
    "stradalei": "stradal",
    "stradalele": "stradal",
    "stradalelor": "stradal",
    "stradali": "stradal",
    "stradalii": "stradal",
    "stradalilor": "stradal",
    "stradalul": "stradal",
    "stradalului": "stradal",
    "strădalnica": "strădalnic",
    "strădalnică": "strădalnic",
    "strădalnice": "strădalnic",
    "strădalnicei": "strădalnic",
    "strădalnicele": "strădalnic",
    "strădalnicelor": "strădalnic",
    "strădalnici": "strădalnic",
    "strădalnicii": "strădalnic",
    "strădalnicilor": "strădalnic",
    "strădalnicul": "strădalnic",
    "strădalnicului": "strădalnic",
    "strădania": "strădanie",
    "strădaniei": "strădanie",
    "strădanii": "strădanie",
    "strădaniile": "strădanie",
    "strădaniilor": "strădanie",
    "stradela": "stradelă",
    "stradele": "stradelă",
    "stradelei": "stradelă",
    "stradelele": "stradelă",
    "stradelelor": "stradelă",
    "nemaistrăduind": "strădui",
    "nemaistrăduindu": "strădui",
    "nestrăduind": "strădui",
    "nestrăduindu": "strădui",
    "străduia": "strădui",
    "străduiai": "strădui",
    "străduiam": "strădui",
    "străduiască": "strădui",
    "străduiați": "strădui",
    "străduiau": "strădui",
    "străduiesc": "strădui",
    "străduiește": "strădui",
    "străduiești": "strădui",
    "străduii": "strădui",
    "străduim": "strădui",
    "străduind": "strădui",
    "străduindu": "strădui",
    "străduiră": "strădui",
    "străduirăm": "strădui",
    "străduirăți": "strădui",
    "străduise": "strădui",
    "străduisem": "strădui",
    "străduiseră": "strădui",
    "străduiserăm": "strădui",
    "străduiserăți": "strădui",
    "străduiseși": "strădui",
    "străduiși": "strădui",
    "străduit": "strădui",
    "străduiți": "strădui",
    "străduința": "străduință",
    "străduințe": "străduință",
    "străduinței": "străduință",
    "străduințele": "străduință",
    "străduințelor": "străduință",
    "străduită": "străduit",
    "străduite": "străduit",
    "străduiți": "străduit",
    "străduitoare": "străduitor",
    "străduitoarea": "străduitor",
    "străduitoarei": "străduitor",
    "străduitoarele": "străduitor",
    "străduitoarelor": "străduitor",
    "străduitori": "străduitor",
    "străduitorii": "străduitor",
    "străduitorilor": "străduitor",
    "străduitorul": "străduitor",
    "străduitorului": "străduitor",
    "străduța": "străduță",
    "străduțe": "străduță",
    "străduței": "străduță",
    "străduțele": "străduță",
    "străduțelor": "străduță",
    "nemaistrăfulgerând": "străfulgera",
    "nemaistrăfulgerându": "străfulgera",
    "nestrăfulgerând": "străfulgera",
    "nestrăfulgerându": "străfulgera",
    "străfulger": "străfulgera",
    "străfulgeră": "străfulgera",
    "străfulgerai": "străfulgera",
    "străfulgeram": "străfulgera",
    "străfulgerăm": "străfulgera",
    "străfulgerând": "străfulgera",
    "străfulgerându": "străfulgera",
    "străfulgerară": "străfulgera",
    "străfulgerarăm": "străfulgera",
    "străfulgerarăți": "străfulgera",
    "străfulgerase": "străfulgera",
    "străfulgerasem": "străfulgera",
    "străfulgeraseră": "străfulgera",
    "străfulgeraserăm": "străfulgera",
    "străfulgeraserăți": "străfulgera",
    "străfulgeraseși": "străfulgera",
    "străfulgerași": "străfulgera",
    "străfulgerat": "străfulgera",
    "străfulgerați": "străfulgera",
    "străfulgerau": "străfulgera",
    "străfulgere": "străfulgera",
    "străfulgeri": "străfulgera",
    "străfulgerată": "străfulgerat",
    "străfulgerate": "străfulgerat",
    "străfulgerați": "străfulgerat",
    "străfundul": "străfund",
    "străfundului": "străfund",
    "străfunduri": "străfund",
    "străfundurile": "străfund",
    "străfundurilor": "străfund",
    "străgălia": "străgălie",
    "străgăliei": "străgălie",
    "străgălii": "străgălie",
    "străgăliile": "străgălie",
    "străgăliilor": "străgălie",
    "straie": "strai",
    "straiele": "strai",
    "straielor": "strai",
    "straiul": "strai",
    "straiului": "strai",
    "straiuri": "strai",
    "straiurile": "strai",
    "straiurilor": "strai",
    "ștraiful": "ștraif",
    "ștraifului": "ștraif",
    "ștraifuri": "ștraif",
    "ștraifurile": "ștraif",
    "ștraifurilor": "ștraif",
    "străina": "străin",
    "străină": "străin",
    "străine": "străin",
    "străinei": "străin",
    "străinele": "străin",
    "străinelor": "străin",
    "străini": "străin",
    "străinii": "străin",
    "străinilor": "străin",
    "străinul": "străin",
    "străinului": "străin",
    "străina": "străină",
    "străine": "străină",
    "străinei": "străină",
    "străinele": "străină",
    "străinelor": "străină",
    "străinătatea": "străinătate",
    "străinătăți": "străinătate",
    "străinătății": "străinătate",
    "străinătățile": "străinătate",
    "străinătăților": "străinătate",
    "straița": "straiță",
    "straițe": "straiță",
    "straiței": "straiță",
    "straițele": "straiță",
    "straițelor": "straiță",
    "straja": "strajă",
    "străji": "strajă",
    "străjii": "strajă",
    "străjile": "strajă",
    "străjilor": "strajă",
    "străjeri": "străjer",
    "străjerii": "străjer",
    "străjerilor": "străjer",
    "străjerul": "străjer",
    "străjerului": "străjer",
    "nemaistrăjuind": "străjui",
    "nemaistrăjuindu": "străjui",
    "nestrăjuind": "străjui",
    "nestrăjuindu": "străjui",
    "străjuia": "străjui",
    "străjuiai": "străjui",
    "străjuiam": "străjui",
    "străjuiască": "străjui",
    "străjuiați": "străjui",
    "străjuiau": "străjui",
    "străjuiesc": "străjui",
    "străjuiește": "străjui",
    "străjuiești": "străjui",
    "străjuii": "străjui",
    "străjuim": "străjui",
    "străjuind": "străjui",
    "străjuindu": "străjui",
    "străjuiră": "străjui",
    "străjuirăm": "străjui",
    "străjuirăți": "străjui",
    "străjuise": "străjui",
    "străjuisem": "străjui",
    "străjuiseră": "străjui",
    "străjuiserăm": "străjui",
    "străjuiserăți": "străjui",
    "străjuiseși": "străjui",
    "străjuiși": "străjui",
    "străjuit": "străjui",
    "străjuiți": "străjui",
    "străjuită": "străjuit",
    "străjuite": "străjuit",
    "străjuiți": "străjuit",
    "nemaistrălucind": "străluci",
    "nemaistrălucindu": "străluci",
    "nestrălucind": "străluci",
    "nestrălucindu": "străluci",
    "strălucea": "străluci",
    "străluceai": "străluci",
    "străluceam": "străluci",
    "strălucească": "străluci",
    "străluceați": "străluci",
    "străluceau": "străluci",
    "strălucesc": "străluci",
    "strălucește": "străluci",
    "strălucești": "străluci",
    "strălucii": "străluci",
    "strălucim": "străluci",
    "strălucind": "străluci",
    "strălucindu": "străluci",
    "străluciră": "străluci",
    "strălucirăm": "străluci",
    "strălucirăți": "străluci",
    "strălucise": "străluci",
    "strălucisem": "străluci",
    "străluciseră": "străluci",
    "străluciserăm": "străluci",
    "străluciserăți": "străluci",
    "străluciseși": "străluci",
    "străluciși": "străluci",
    "strălucit": "străluci",
    "străluciți": "străluci",
    "strălucirea": "strălucire",
    "străluciri": "strălucire",
    "strălucirii": "strălucire",
    "strălucirile": "strălucire",
    "strălucirilor": "strălucire",
    "strălucita": "strălucit",
    "strălucită": "strălucit",
    "strălucite": "strălucit",
    "strălucitei": "strălucit",
    "strălucitele": "strălucit",
    "strălucitelor": "strălucit",
    "străluciți": "strălucit",
    "străluciții": "strălucit",
    "străluciților": "strălucit",
    "strălucitul": "strălucit",
    "strălucitului": "strălucit",
    "strălucitoare": "strălucitor",
    "strălucitoarea": "strălucitor",
    "strălucitoarei": "strălucitor",
    "strălucitoarele": "strălucitor",
    "strălucitoarelor": "strălucitor",
    "strălucitori": "strălucitor",
    "strălucitorii": "strălucitor",
    "strălucitorilor": "strălucitor",
    "strălucitorul": "strălucitor",
    "strălucitorului": "strălucitor",
    "strâmba": "strâmb",
    "strâmbă": "strâmb",
    "strâmbe": "strâmb",
    "strâmbei": "strâmb",
    "strâmbele": "strâmb",
    "strâmbelor": "strâmb",
    "strâmbi": "strâmb",
    "strâmbii": "strâmb",
    "strâmbilor": "strâmb",
    "strâmbul": "strâmb",
    "strâmbului": "strâmb",
    "nemaistrâmbând": "strâmba",
    "nemaistrâmbându": "strâmba",
    "nestrâmbând": "strâmba",
    "nestrâmbându": "strâmba",
    "strâmb": "strâmba",
    "strâmbă": "strâmba",
    "strâmbai": "strâmba",
    "strâmbam": "strâmba",
    "strâmbăm": "strâmba",
    "strâmbând": "strâmba",
    "strâmbându": "strâmba",
    "strâmbară": "strâmba",
    "strâmbarăm": "strâmba",
    "strâmbarăți": "strâmba",
    "strâmbase": "strâmba",
    "strâmbasem": "strâmba",
    "strâmbaseră": "strâmba",
    "strâmbaserăm": "strâmba",
    "strâmbaserăți": "strâmba",
    "strâmbaseși": "strâmba",
    "strâmbași": "strâmba",
    "strâmbat": "strâmba",
    "strâmbați": "strâmba",
    "strâmbau": "strâmba",
    "strâmbe": "strâmba",
    "strâmbi": "strâmba",
    "strâmbată": "strâmbat",
    "strâmbate": "strâmbat",
    "strâmbați": "strâmbat",
    "strâmbătatea": "strâmbătate",
    "strâmbătăți": "strâmbătate",
    "strâmbătății": "strâmbătate",
    "strâmbătățile": "strâmbătate",
    "strâmbătăților": "strâmbătate",
    "strâmbătura": "strâmbătură",
    "strâmbături": "strâmbătură",
    "strâmbăturii": "strâmbătură",
    "strâmbăturile": "strâmbătură",
    "strâmbăturilor": "strâmbătură",
    "strămoașa": "strămoașă",
    "strămoașe": "strămoașă",
    "strămoașei": "strămoașă",
    "strămoașele": "strămoașă",
    "strămoașelor": "strămoașă",
    "strămoși": "strămoș",
    "strămoșii": "strămoș",
    "strămoșilor": "strămoș",
    "strămoșul": "strămoș",
    "strămoșului": "strămoș",
    "strămoșeasca": "strămoșesc",
    "strămoșească": "strămoșesc",
    "strămoșescul": "strămoșesc",
    "strămoșescului": "strămoșesc",
    "strămoșești": "strămoșesc",
    "strămoșeștii": "strămoșesc",
    "strămoșeștile": "strămoșesc",
    "strămoșeștilor": "strămoșesc",
    "strâmta": "strâmt",
    "strâmtă": "strâmt",
    "strâmte": "strâmt",
    "strâmtei": "strâmt",
    "strâmtele": "strâmt",
    "strâmtelor": "strâmt",
    "strâmți": "strâmt",
    "strâmții": "strâmt",
    "strâmților": "strâmt",
    "strâmtul": "strâmt",
    "strâmtului": "strâmt",
    "nemaistrâmtând": "strâmta",
    "nemaistrâmtându": "strâmta",
    "nestrâmtând": "strâmta",
    "nestrâmtându": "strâmta",
    "strâmtă": "strâmta",
    "strâmtai": "strâmta",
    "strâmtam": "strâmta",
    "strâmtăm": "strâmta",
    "strâmtând": "strâmta",
    "strâmtându": "strâmta",
    "strâmtară": "strâmta",
    "strâmtarăm": "strâmta",
    "strâmtarăți": "strâmta",
    "strâmtase": "strâmta",
    "strâmtasem": "strâmta",
    "strâmtaseră": "strâmta",
    "strâmtaserăm": "strâmta",
    "strâmtaserăți": "strâmta",
    "strâmtaseși": "strâmta",
    "strâmtași": "strâmta",
    "strâmtat": "strâmta",
    "strâmtați": "strâmta",
    "strâmtau": "strâmta",
    "strâmtează": "strâmta",
    "strâmtez": "strâmta",
    "strâmteze": "strâmta",
    "strâmtezi": "strâmta",
    "strâmtată": "strâmtat",
    "strâmtate": "strâmtat",
    "strâmtați": "strâmtat",
    "strâmtoarea": "strâmtoare",
    "strâmtori": "strâmtoare",
    "strâmtorii": "strâmtoare",
    "strâmtorile": "strâmtoare",
    "strâmtorilor": "strâmtoare",
    "nemaistrâmtorând": "strâmtora",
    "nemaistrâmtorându": "strâmtora",
    "nestrâmtorând": "strâmtora",
    "nestrâmtorându": "strâmtora",
    "strâmtoră": "strâmtora",
    "strâmtorai": "strâmtora",
    "strâmtoram": "strâmtora",
    "strâmtorăm": "strâmtora",
    "strâmtorând": "strâmtora",
    "strâmtorându": "strâmtora",
    "strâmtorară": "strâmtora",
    "strâmtorarăm": "strâmtora",
    "strâmtorarăți": "strâmtora",
    "strâmtorase": "strâmtora",
    "strâmtorasem": "strâmtora",
    "strâmtoraseră": "strâmtora",
    "strâmtoraserăm": "strâmtora",
    "strâmtoraserăți": "strâmtora",
    "strâmtoraseși": "strâmtora",
    "strâmtorași": "strâmtora",
    "strâmtorat": "strâmtora",
    "strâmtorați": "strâmtora",
    "strâmtorau": "strâmtora",
    "strâmtorează": "strâmtora",
    "strâmtorez": "strâmtora",
    "strâmtoreze": "strâmtora",
    "strâmtorezi": "strâmtora",
    "strâmtorarea": "strâmtorare",
    "strâmtorări": "strâmtorare",
    "strâmtorării": "strâmtorare",
    "strâmtorările": "strâmtorare",
    "strâmtorărilor": "strâmtorare",
    "strâmtorată": "strâmtorat",
    "strâmtorate": "strâmtorat",
    "strâmtorați": "strâmtorat",
    "nemaistrămutând": "strămuta",
    "nemaistrămutându": "strămuta",
    "nestrămutând": "strămuta",
    "nestrămutându": "strămuta",
    "strămut": "strămuta",
    "strămută": "strămuta",
    "strămutai": "strămuta",
    "strămutam": "strămuta",
    "strămutăm": "strămuta",
    "strămutând": "strămuta",
    "strămutându": "strămuta",
    "strămutară": "strămuta",
    "strămutarăm": "strămuta",
    "strămutarăți": "strămuta",
    "strămutase": "strămuta",
    "strămutasem": "strămuta",
    "strămutaseră": "strămuta",
    "strămutaserăm": "strămuta",
    "strămutaserăți": "strămuta",
    "strămutaseși": "strămuta",
    "strămutași": "strămuta",
    "strămutat": "strămuta",
    "strămutați": "strămuta",
    "strămutau": "strămuta",
    "strămute": "strămuta",
    "strămuți": "strămuta",
    "strămutarea": "strămutare",
    "strămutări": "strămutare",
    "strămutării": "strămutare",
    "strămutările": "strămutare",
    "strămutărilor": "strămutare",
    "strămutată": "strămutat",
    "strămutate": "strămutat",
    "strămutați": "strămutat",
    "strana": "strană",
    "strane": "strană",
    "stranei": "strană",
    "stranele": "strană",
    "stranelor": "strană",
    "ștrandul": "ștrand",
    "ștrandului": "ștrand",
    "ștranduri": "ștrand",
    "ștrandurile": "ștrand",
    "ștrandurilor": "ștrand",
    "strănepoata": "strănepoată",
    "strănepoate": "strănepoată",
    "strănepoatei": "strănepoată",
    "strănepoatele": "strănepoată",
    "strănepoatelor": "strănepoată",
    "strănepoți": "strănepot",
    "strănepoții": "strănepot",
    "strănepoților": "strănepot",
    "strănepotul": "strănepot",
    "strănepotului": "strănepot",
    "strângătoarea": "strângătoare",
    "strângătoarei": "strângătoare",
    "strângătoarele": "strângătoare",
    "strângătoarelor": "strângătoare",
    "strângătoare": "strângător",
    "strângătoarea": "strângător",
    "strângătoarei": "strângător",
    "strângătoarele": "strângător",
    "strângătoarelor": "strângător",
    "strângători": "strângător",
    "strângătorii": "strângător",
    "strângătorilor": "strângător",
    "strângătorul": "strângător",
    "strângătorului": "strângător",
    "nemaistrângând": "strânge",
    "nemaistrângându": "strânge",
    "nestrângând": "strânge",
    "nestrângându": "strânge",
    "strâng": "strânge",
    "strângă": "strânge",
    "strângând": "strânge",
    "strângându": "strânge",
    "strângea": "strânge",
    "strângeai": "strânge",
    "strângeam": "strânge",
    "strângeați": "strânge",
    "strângeau": "strânge",
    "strângem": "strânge",
    "strângeți": "strânge",
    "strângi": "strânge",
    "strâns": "strânge",
    "strânse": "strânge",
    "strânsei": "strânge",
    "strânseră": "strânge",
    "strânserăm": "strânge",
    "strânserăți": "strânge",
    "strânsese": "strânge",
    "strânsesem": "strânge",
    "strânseseră": "strânge",
    "strânseserăm": "strânge",
    "strânseserăți": "strânge",
    "strânseseși": "strânge",
    "strânseși": "strânge",
    "strângerea": "strângere",
    "strângeri": "strângere",
    "strângerii": "strângere",
    "strângerile": "strângere",
    "strângerilor": "strângere",
    "nemaistrangulând": "strangula",
    "nemaistrangulându": "strangula",
    "nestrangulând": "strangula",
    "nestrangulându": "strangula",
    "strangulă": "strangula",
    "strangulai": "strangula",
    "strangulam": "strangula",
    "strangulăm": "strangula",
    "strangulând": "strangula",
    "strangulându": "strangula",
    "strangulară": "strangula",
    "strangularăm": "strangula",
    "strangularăți": "strangula",
    "strangulase": "strangula",
    "strangulasem": "strangula",
    "strangulaseră": "strangula",
    "strangulaserăm": "strangula",
    "strangulaserăți": "strangula",
    "strangulaseși": "strangula",
    "strangulași": "strangula",
    "strangulat": "strangula",
    "strangulați": "strangula",
    "strangulau": "strangula",
    "strangulează": "strangula",
    "strangulez": "strangula",
    "stranguleze": "strangula",
    "strangulezi": "strangula",
    "strangularea": "strangulare",
    "strangulări": "strangulare",
    "strangulării": "strangulare",
    "strangulările": "strangulare",
    "strangulărilor": "strangulare",
    "strangulată": "strangulat",
    "strangulate": "strangulat",
    "strangulați": "strangulat",
    "strania": "straniu",
    "stranie": "straniu",
    "straniei": "straniu",
    "stranii": "straniu",
    "straniii": "straniu",
    "straniile": "straniu",
    "straniilor": "straniu",
    "straniul": "straniu",
    "straniului": "straniu",
    "strânsă": "strâns",
    "strânse": "strâns",
    "strânși": "strâns",
    "strânsul": "strâns",
    "strânsului": "strâns",
    "strânsoarea": "strânsoare",
    "strânsori": "strânsoare",
    "strânsorii": "strânsoare",
    "strânsorile": "strânsoare",
    "strânsorilor": "strânsoare",
    "strânsura": "strânsură",
    "strânsuri": "strânsură",
    "strânsurii": "strânsură",
    "strânsurile": "strânsură",
    "strânsurilor": "strânsură",
    "strănutul": "strănut",
    "strănutului": "strănut",
    "strănuturi": "strănut",
    "strănuturile": "strănut",
    "strănuturilor": "strănut",
    "nemaistrănutând": "strănuta",
    "nemaistrănutându": "strănuta",
    "nestrănutând": "strănuta",
    "nestrănutându": "strănuta",
    "strănut": "strănuta",
    "strănută": "strănuta",
    "strănutai": "strănuta",
    "strănutam": "strănuta",
    "strănutăm": "strănuta",
    "strănutând": "strănuta",
    "strănutându": "strănuta",
    "strănutară": "strănuta",
    "strănutarăm": "strănuta",
    "strănutarăți": "strănuta",
    "strănutase": "strănuta",
    "strănutasem": "strănuta",
    "strănutaseră": "strănuta",
    "strănutaserăm": "strănuta",
    "strănutaserăți": "strănuta",
    "strănutaseși": "strănuta",
    "strănutași": "strănuta",
    "strănutat": "strănuta",
    "strănutați": "strănuta",
    "strănutau": "strănuta",
    "strănute": "strănuta",
    "strănuți": "strănuta",
    "strănutată": "strănutat",
    "strănutate": "strănutat",
    "strănutați": "strănutat",
    "strapontinul": "strapontin",
    "strapontinului": "strapontin",
    "strapontina": "strapontină",
    "strapontine": "strapontină",
    "strapontinei": "strapontină",
    "strapontinele": "strapontină",
    "strapontinelor": "strapontină",
    "străpungătoare": "străpungător",
    "străpungătoarea": "străpungător",
    "străpungătoarei": "străpungător",
    "străpungătoarele": "străpungător",
    "străpungătoarelor": "străpungător",
    "străpungători": "străpungător",
    "străpungătorii": "străpungător",
    "străpungătorilor": "străpungător",
    "străpungătorul": "străpungător",
    "străpungătorului": "străpungător",
    "nemaistrăpungând": "străpunge",
    "nemaistrăpungându": "străpunge",
    "nestrăpungând": "străpunge",
    "nestrăpungându": "străpunge",
    "străpung": "străpunge",
    "străpungă": "străpunge",
    "străpungând": "străpunge",
    "străpungându": "străpunge",
    "străpungea": "străpunge",
    "străpungeai": "străpunge",
    "străpungeam": "străpunge",
    "străpungeați": "străpunge",
    "străpungeau": "străpunge",
    "străpungem": "străpunge",
    "străpungeți": "străpunge",
    "străpungi": "străpunge",
    "străpuns": "străpunge",
    "străpunse": "străpunge",
    "străpunsei": "străpunge",
    "străpunseră": "străpunge",
    "străpunserăm": "străpunge",
    "străpunserăți": "străpunge",
    "străpunsese": "străpunge",
    "străpunsesem": "străpunge",
    "străpunseseră": "străpunge",
    "străpunseserăm": "străpunge",
    "străpunseserăți": "străpunge",
    "străpunseseși": "străpunge",
    "străpunseși": "străpunge",
    "străpunsă": "străpuns",
    "străpunse": "străpuns",
    "străpunși": "străpuns",
    "strasul": "stras",
    "strasului": "stras",
    "strasuri": "stras",
    "strasurile": "stras",
    "strasurilor": "stras",
    "strașnica": "strașnic",
    "strașnică": "strașnic",
    "strașnice": "strașnic",
    "strașnicei": "strașnic",
    "strașnicele": "strașnic",
    "strașnicelor": "strașnic",
    "strașnici": "strașnic",
    "strașnicii": "strașnic",
    "strașnicilor": "strașnic",
    "strașnicul": "strașnic",
    "strașnicului": "strașnic",
    "strășnicia": "strășnicie",
    "strășniciei": "strășnicie",
    "strășnicii": "strășnicie",
    "strășniciile": "strășnicie",
    "strășniciilor": "strășnicie",
    "stratul": "strat",
    "stratului": "strat",
    "straturi": "strat",
    "straturile": "strat",
    "straturilor": "strat",
    "stratagema": "stratagemă",
    "stratageme": "stratagemă",
    "stratagemei": "stratagemă",
    "stratagemele": "stratagemă",
    "stratagemelor": "stratagemă",
    "strategi": "strateg",
    "strategii": "strateg",
    "strategilor": "strateg",
    "strategul": "strateg",
    "strategului": "strateg",
    "strategica": "strategic",
    "strategică": "strategic",
    "strategice": "strategic",
    "strategicei": "strategic",
    "strategicele": "strategic",
    "strategicelor": "strategic",
    "strategici": "strategic",
    "strategicii": "strategic",
    "strategicilor": "strategic",
    "strategicul": "strategic",
    "strategicului": "strategic",
    "strategia": "strategie",
    "strategiei": "strategie",
    "strategii": "strategie",
    "nemaistratificând": "stratifica",
    "nemaistratificându": "stratifica",
    "nestratificând": "stratifica",
    "nestratificându": "stratifica",
    "stratific": "stratifica",
    "stratifică": "stratifica",
    "stratificai": "stratifica",
    "stratificam": "stratifica",
    "stratificăm": "stratifica",
    "stratificând": "stratifica",
    "stratificându": "stratifica",
    "stratificară": "stratifica",
    "stratificarăm": "stratifica",
    "stratificarăți": "stratifica",
    "stratificase": "stratifica",
    "stratificasem": "stratifica",
    "stratificaseră": "stratifica",
    "stratificaserăm": "stratifica",
    "stratificaserăți": "stratifica",
    "stratificaseși": "stratifica",
    "stratificași": "stratifica",
    "stratificat": "stratifica",
    "stratificați": "stratifica",
    "stratificau": "stratifica",
    "stratifice": "stratifica",
    "stratifici": "stratifica",
    "stratificarea": "stratificare",
    "stratificareo": "stratificare",
    "stratificări": "stratificare",
    "stratificării": "stratificare",
    "stratificările": "stratificare",
    "stratificărilor": "stratificare",
    "stratificata": "stratificat",
    "stratificată": "stratificat",
    "stratificate": "stratificat",
    "stratificatei": "stratificat",
    "stratificatele": "stratificat",
    "stratificatelor": "stratificat",
    "stratificați": "stratificat",
    "stratificații": "stratificat",
    "stratificaților": "stratificat",
    "stratificato": "stratificat",
    "stratificatul": "stratificat",
    "stratificatule": "stratificat",
    "stratificatului": "stratificat",
    "stratosfera": "stratosferă",
    "stratosfere": "stratosferă",
    "stratosferei": "stratosferă",
    "stratosferele": "stratosferă",
    "stratosferelor": "stratosferă",
    "stratosferica": "stratosferic",
    "stratosferică": "stratosferic",
    "stratosferice": "stratosferic",
    "stratosfericei": "stratosferic",
    "stratosfericele": "stratosferic",
    "stratosfericelor": "stratosferic",
    "stratosferici": "stratosferic",
    "stratosfericii": "stratosferic",
    "stratosfericilor": "stratosferic",
    "stratosfericul": "stratosferic",
    "stratosfericului": "stratosferic",
    "stratusul": "stratus",
    "stratusului": "stratus",
    "străveche": "străvechi",
    "străvechea": "străvechi",
    "străvechii": "străvechi",
    "străvechile": "străvechi",
    "străvechilor": "străvechi",
    "străvechiul": "străvechi",
    "străvechiului": "străvechi",
    "străvezimea": "străvezime",
    "străvezimi": "străvezime",
    "străvezimii": "străvezime",
    "străvezimile": "străvezime",
    "străvezimilor": "străvezime",
    "străvezia": "străveziu",
    "străvezie": "străveziu",
    "străveziei": "străveziu",
    "străvezii": "străveziu",
    "străveziii": "străveziu",
    "străveziile": "străveziu",
    "străveziilor": "străveziu",
    "străveziul": "străveziu",
    "străveziului": "străveziu",
    "ștreangul": "ștreang",
    "ștreangului": "ștreang",
    "ștreanguri": "ștreang",
    "ștreangurile": "ștreang",
    "ștreangurilor": "ștreang",
    "streașina": "streașină",
    "streșini": "streașină",
    "streșinii": "streașină",
    "streșinile": "streașină",
    "streșinilor": "streașină",
    "strechea": "streche",
    "strechei": "streche",
    "strechele": "streche",
    "strechelor": "streche",
    "nemaistrecurând": "strecura",
    "nemaistrecurându": "strecura",
    "nestrecurând": "strecura",
    "nestrecurându": "strecura",
    "strecoară": "strecura",
    "strecoare": "strecura",
    "strecor": "strecura",
    "strecori": "strecura",
    "strecură": "strecura",
    "strecurai": "strecura",
    "strecuram": "strecura",
    "strecurăm": "strecura",
    "strecurând": "strecura",
    "strecurându": "strecura",
    "strecurară": "strecura",
    "strecurarăm": "strecura",
    "strecurarăți": "strecura",
    "strecurase": "strecura",
    "strecurasem": "strecura",
    "strecuraseră": "strecura",
    "strecuraserăm": "strecura",
    "strecuraserăți": "strecura",
    "strecuraseși": "strecura",
    "strecurași": "strecura",
    "strecurat": "strecura",
    "strecurați": "strecura",
    "strecurau": "strecura",
    "strecurarea": "strecurare",
    "strecurareo": "strecurare",
    "strecurări": "strecurare",
    "strecurării": "strecurare",
    "strecurările": "strecurare",
    "strecurărilor": "strecurare",
    "strecurata": "strecurat",
    "strecurată": "strecurat",
    "strecurate": "strecurat",
    "strecuratei": "strecurat",
    "strecuratele": "strecurat",
    "strecuratelor": "strecurat",
    "strecurați": "strecurat",
    "strecurații": "strecurat",
    "strecuraților": "strecurat",
    "strecurato": "strecurat",
    "strecuratul": "strecurat",
    "strecuratule": "strecurat",
    "strecuratului": "strecurat",
    "strecurătoarea": "strecurătoare",
    "strecurătoarele": "strecurătoare",
    "strecurători": "strecurătoare",
    "strecurătorii": "strecurătoare",
    "strecurătorilor": "strecurătoare",
    "ștrengari": "ștrengar",
    "ștrengarii": "ștrengar",
    "ștrengarilor": "ștrengar",
    "ștrengarul": "ștrengar",
    "ștrengarului": "ștrengar",
    "ștrengăria": "ștrengărie",
    "ștrengăriei": "ștrengărie",
    "ștrengării": "ștrengărie",
    "ștrengăriile": "ștrengărie",
    "ștrengăriilor": "ștrengărie",
    "ștrengărița": "ștrengăriță",
    "ștrengărițe": "ștrengăriță",
    "ștrengăriței": "ștrengăriță",
    "ștrengărițele": "ștrengăriță",
    "ștrengărițelor": "ștrengăriță",
    "strepezeala": "strepezeală",
    "strepezeli": "strepezeală",
    "strepezelii": "strepezeală",
    "strepezelile": "strepezeală",
    "strepezelilor": "strepezeală",
    "nemaistrepezind": "strepezi",
    "nemaistrepezindu": "strepezi",
    "nestrepezind": "strepezi",
    "nestrepezindu": "strepezi",
    "strepezea": "strepezi",
    "strepezeai": "strepezi",
    "strepezeam": "strepezi",
    "strepezească": "strepezi",
    "strepezeați": "strepezi",
    "strepezeau": "strepezi",
    "strepezesc": "strepezi",
    "strepezește": "strepezi",
    "strepezești": "strepezi",
    "strepezii": "strepezi",
    "strepezim": "strepezi",
    "strepezind": "strepezi",
    "strepezindu": "strepezi",
    "strepeziră": "strepezi",
    "strepezirăm": "strepezi",
    "strepezirăți": "strepezi",
    "strepezise": "strepezi",
    "strepezisem": "strepezi",
    "strepeziseră": "strepezi",
    "strepeziserăm": "strepezi",
    "strepeziserăți": "strepezi",
    "strepeziseși": "strepezi",
    "strepeziși": "strepezi",
    "strepezit": "strepezi",
    "strepeziți": "strepezi",
    "strepezirea": "strepezire",
    "strepeziri": "strepezire",
    "strepezirii": "strepezire",
    "strepezirile": "strepezire",
    "strepezirilor": "strepezire",
    "strepezita": "strepezit",
    "strepezită": "strepezit",
    "strepezite": "strepezit",
    "strepezitei": "strepezit",
    "strepezitele": "strepezit",
    "strepezitelor": "strepezit",
    "strepeziți": "strepezit",
    "strepeziții": "strepezit",
    "strepeziților": "strepezit",
    "strepezito": "strepezit",
    "strepezitul": "strepezit",
    "strepezitule": "strepezit",
    "strepezitului": "strepezit",
    "streptococi": "streptococ",
    "streptococii": "streptococ",
    "streptococilor": "streptococ",
    "streptococul": "streptococ",
    "streptococului": "streptococ",
    "streptococica": "streptococic",
    "streptococică": "streptococic",
    "streptococice": "streptococic",
    "streptococicei": "streptococic",
    "streptococicele": "streptococic",
    "streptococicelor": "streptococic",
    "streptococici": "streptococic",
    "streptococicii": "streptococic",
    "streptococicilor": "streptococic",
    "streptococicul": "streptococic",
    "streptococicului": "streptococic",
    "streptomicina": "streptomicină",
    "streptomicine": "streptomicină",
    "streptomicinei": "streptomicină",
    "streptomicinele": "streptomicină",
    "streptomicinelor": "streptomicină",
    "stresul": "stres",
    "stresului": "stres",
    "stresuri": "stres",
    "stresurile": "stres",
    "stresurilor": "stres",
    "stresantă": "stresant",
    "stresante": "stresant",
    "stresanți": "stresant",
    "striația": "striație",
    "striației": "striație",
    "striații": "striație",
    "striațiile": "striație",
    "striațiilor": "striație",
    "nemaistricând": "strica",
    "nemaistricându": "strica",
    "nestricând": "strica",
    "nestricându": "strica",
    "stric": "strica",
    "strică": "strica",
    "stricai": "strica",
    "stricam": "strica",
    "stricăm": "strica",
    "stricând": "strica",
    "stricându": "strica",
    "stricară": "strica",
    "stricarăm": "strica",
    "stricarăți": "strica",
    "stricase": "strica",
    "stricasem": "strica",
    "stricaseră": "strica",
    "stricaserăm": "strica",
    "stricaserăți": "strica",
    "stricaseși": "strica",
    "stricași": "strica",
    "stricat": "strica",
    "stricați": "strica",
    "stricau": "strica",
    "strice": "strica",
    "strici": "strica",
    "stricăcioasa": "stricăcios",
    "stricăcioasă": "stricăcios",
    "stricăcioase": "stricăcios",
    "stricăcioasei": "stricăcios",
    "stricăcioasele": "stricăcios",
    "stricăcioaselor": "stricăcios",
    "stricăcioși": "stricăcios",
    "stricăcioșii": "stricăcios",
    "stricăcioșilor": "stricăcios",
    "stricăciosul": "stricăcios",
    "stricăciosului": "stricăcios",
    "stricăciunea": "stricăciune",
    "stricăciuni": "stricăciune",
    "stricăciunii": "stricăciune",
    "stricăciunile": "stricăciune",
    "stricăciunilor": "stricăciune",
    "stricarea": "stricare",
    "stricareo": "stricare",
    "stricări": "stricare",
    "stricării": "stricare",
    "stricările": "stricare",
    "stricărilor": "stricare",
    "stricata": "stricat",
    "stricată": "stricat",
    "stricate": "stricat",
    "stricatei": "stricat",
    "stricatele": "stricat",
    "stricatelor": "stricat",
    "stricați": "stricat",
    "stricații": "stricat",
    "stricaților": "stricat",
    "stricato": "stricat",
    "stricatul": "stricat",
    "stricatule": "stricat",
    "stricatului": "stricat",
    "stricnina": "stricnină",
    "stricnine": "stricnină",
    "stricninei": "stricnină",
    "stricta": "strict",
    "strictă": "strict",
    "stricte": "strict",
    "strictei": "strict",
    "strictele": "strict",
    "strictelor": "strict",
    "stricți": "strict",
    "stricții": "strict",
    "stricților": "strict",
    "strictul": "strict",
    "strictului": "strict",
    "strictețea": "strictețe",
    "stricteți": "strictețe",
    "stricteții": "strictețe",
    "s.s.": "stricto_sensu",
    "stricturarea": "stricturare",
    "stricturări": "stricturare",
    "stricturării": "stricturare",
    "stricturările": "stricturare",
    "stricturărilor": "stricturare",
    "stridenta": "strident",
    "stridentă": "strident",
    "stridente": "strident",
    "stridentei": "strident",
    "stridentele": "strident",
    "stridentelor": "strident",
    "stridenți": "strident",
    "stridenții": "strident",
    "stridenților": "strident",
    "stridentul": "strident",
    "stridentului": "strident",
    "stridența": "stridență",
    "stridențe": "stridență",
    "stridenței": "stridență",
    "stridențele": "stridență",
    "stridențelor": "stridență",
    "stridia": "stridie",
    "stridiei": "stridie",
    "stridii": "stridie",
    "stridiile": "stridie",
    "stridiilor": "stridie",
    "nemaistrigând": "striga",
    "nemaistrigându": "striga",
    "nestrigând": "striga",
    "nestrigându": "striga",
    "strig": "striga",
    "strigă": "striga",
    "strigai": "striga",
    "strigam": "striga",
    "strigăm": "striga",
    "strigând": "striga",
    "strigându": "striga",
    "strigară": "striga",
    "strigarăm": "striga",
    "strigarăți": "striga",
    "strigase": "striga",
    "strigasem": "striga",
    "strigaseră": "striga",
    "strigaserăm": "striga",
    "strigaserăți": "striga",
    "strigaseși": "striga",
    "strigași": "striga",
    "strigat": "striga",
    "strigați": "striga",
    "strigau": "striga",
    "strige": "striga",
    "strigi": "striga",
    "strigarea": "strigare",
    "strigări": "strigare",
    "strigării": "strigare",
    "strigările": "strigare",
    "strigărilor": "strigare",
    "strigata": "strigat",
    "strigată": "strigat",
    "strigate": "strigat",
    "strigatei": "strigat",
    "strigatele": "strigat",
    "strigatelor": "strigat",
    "strigați": "strigat",
    "strigații": "strigat",
    "strigaților": "strigat",
    "strigato": "strigat",
    "strigatul": "strigat",
    "strigatule": "strigat",
    "strigatului": "strigat",
    "strigăte": "strigăt",
    "strigătele": "strigăt",
    "strigătelor": "strigăt",
    "strigătul": "strigăt",
    "strigătului": "strigăt",
    "strigătoare": "strigător",
    "strigătoarea": "strigător",
    "strigătoarei": "strigător",
    "strigătoarele": "strigător",
    "strigătoarelor": "strigător",
    "strigători": "strigător",
    "strigătorii": "strigător",
    "strigătorilor": "strigător",
    "strigătorul": "strigător",
    "strigătorului": "strigător",
    "strigătura": "strigătură",
    "strigături": "strigătură",
    "strigăturii": "strigătură",
    "strigăturile": "strigătură",
    "strigăturilor": "strigătură",
    "strigoaica": "strigoaică",
    "strigoaice": "strigoaică",
    "strigoaicei": "strigoaică",
    "strigoaicele": "strigoaică",
    "strigoaicelor": "strigoaică",
    "strigoii": "strigoi",
    "strigoilor": "strigoi",
    "strigoiul": "strigoi",
    "strigoiului": "strigoi",
    "stringenta": "stringent",
    "stringentă": "stringent",
    "stringente": "stringent",
    "stringentei": "stringent",
    "stringentele": "stringent",
    "stringentelor": "stringent",
    "stringenți": "stringent",
    "stringenții": "stringent",
    "stringenților": "stringent",
    "stringentul": "stringent",
    "stringentului": "stringent",
    "stringența": "stringență",
    "stringențe": "stringență",
    "stringenței": "stringență",
    "stringențele": "stringență",
    "stringențelor": "stringență",
    "nemaistrivind": "strivi",
    "nemaistrivindu": "strivi",
    "nestrivind": "strivi",
    "nestrivindu": "strivi",
    "strivea": "strivi",
    "striveai": "strivi",
    "striveam": "strivi",
    "strivească": "strivi",
    "striveați": "strivi",
    "striveau": "strivi",
    "strivesc": "strivi",
    "strivește": "strivi",
    "strivești": "strivi",
    "strivii": "strivi",
    "strivim": "strivi",
    "strivind": "strivi",
    "strivindu": "strivi",
    "striviră": "strivi",
    "strivirăm": "strivi",
    "strivirăți": "strivi",
    "strivise": "strivi",
    "strivisem": "strivi",
    "striviseră": "strivi",
    "striviserăm": "strivi",
    "striviserăți": "strivi",
    "striviseși": "strivi",
    "striviși": "strivi",
    "strivit": "strivi",
    "striviți": "strivi",
    "strivirea": "strivire",
    "strivireo": "strivire",
    "striviri": "strivire",
    "strivirii": "strivire",
    "strivirile": "strivire",
    "strivirilor": "strivire",
    "strivita": "strivit",
    "strivită": "strivit",
    "strivite": "strivit",
    "strivitei": "strivit",
    "strivitele": "strivit",
    "strivitelor": "strivit",
    "striviți": "strivit",
    "striviții": "strivit",
    "striviților": "strivit",
    "strivito": "strivit",
    "strivitul": "strivit",
    "strivitule": "strivit",
    "strivitului": "strivit",
    "stroboscoape": "stroboscop",
    "stroboscoapele": "stroboscop",
    "stroboscoapelor": "stroboscop",
    "stroboscopul": "stroboscop",
    "stroboscopului": "stroboscop",
    "stroboscopia": "stroboscopie",
    "stroboscopiei": "stroboscopie",
    "stroboscopii": "stroboscopie",
    "stroboscopiile": "stroboscopie",
    "stroboscopiilor": "stroboscopie",
    "strofa": "strofă",
    "strofe": "strofă",
    "strofei": "strofă",
    "strofele": "strofă",
    "strofelor": "strofă",
    "strongili": "strongil",
    "strongilii": "strongil",
    "strongililor": "strongil",
    "strongilul": "strongil",
    "strongilului": "strongil",
    "strongiloza": "strongiloză",
    "strongiloze": "strongiloză",
    "strongilozei": "strongiloză",
    "strongilozele": "strongiloză",
    "strongilozelor": "strongiloză",
    "stronțianitul": "stronțianit",
    "stronțianitului": "stronțianit",
    "Sr": "stronțiu",
    "stronțiul": "stronțiu",
    "stronțiului": "stronțiu",
    "stropi": "strop",
    "stropii": "strop",
    "stropilor": "strop",
    "stropul": "strop",
    "stropului": "strop",
    "nemaistropind": "stropi",
    "nemaistropindu": "stropi",
    "nestropind": "stropi",
    "nestropindu": "stropi",
    "stropea": "stropi",
    "stropeai": "stropi",
    "stropeam": "stropi",
    "stropească": "stropi",
    "stropeați": "stropi",
    "stropeau": "stropi",
    "stropesc": "stropi",
    "stropește": "stropi",
    "stropești": "stropi",
    "stropii": "stropi",
    "stropim": "stropi",
    "stropind": "stropi",
    "stropindu": "stropi",
    "stropiră": "stropi",
    "stropirăm": "stropi",
    "stropirăți": "stropi",
    "stropise": "stropi",
    "stropisem": "stropi",
    "stropiseră": "stropi",
    "stropiserăm": "stropi",
    "stropiserăți": "stropi",
    "stropiseși": "stropi",
    "stropiși": "stropi",
    "stropit": "stropi",
    "stropiți": "stropi",
    "stropită": "stropit",
    "stropite": "stropit",
    "stropiți": "stropit",
    "stropitoarea": "stropitoare",
    "stropitori": "stropitoare",
    "stropitorii": "stropitoare",
    "stropitorile": "stropitoare",
    "stropitorilor": "stropitoare",
    "stropșeala": "stropșeală",
    "stropșeli": "stropșeală",
    "stropșelii": "stropșeală",
    "stropșelile": "stropșeală",
    "stropșelilor": "stropșeală",
    "nemaistropșind": "stropși",
    "nemaistropșindu": "stropși",
    "nestropșind": "stropși",
    "nestropșindu": "stropși",
    "stropșea": "stropși",
    "stropșeai": "stropși",
    "stropșeam": "stropși",
    "stropșească": "stropși",
    "stropșeați": "stropși",
    "stropșeau": "stropși",
    "stropșesc": "stropși",
    "stropșește": "stropși",
    "stropșești": "stropși",
    "stropșii": "stropși",
    "stropșim": "stropși",
    "stropșind": "stropși",
    "stropșindu": "stropși",
    "stropșiră": "stropși",
    "stropșirăm": "stropși",
    "stropșirăți": "stropși",
    "stropșise": "stropși",
    "stropșisem": "stropși",
    "stropșiseră": "stropși",
    "stropșiserăm": "stropși",
    "stropșiserăți": "stropși",
    "stropșiseși": "stropși",
    "stropșiși": "stropși",
    "stropșit": "stropși",
    "stropșiți": "stropși",
    "stropșită": "stropșit",
    "stropșite": "stropșit",
    "stropșiți": "stropșit",
    "nemaistructurând": "structura",
    "nemaistructurându": "structura",
    "nestructurând": "structura",
    "nestructurându": "structura",
    "structură": "structura",
    "structurai": "structura",
    "structuram": "structura",
    "structurăm": "structura",
    "structurând": "structura",
    "structurându": "structura",
    "structurară": "structura",
    "structurarăm": "structura",
    "structurarăți": "structura",
    "structurase": "structura",
    "structurasem": "structura",
    "structuraseră": "structura",
    "structuraserăm": "structura",
    "structuraserăți": "structura",
    "structuraseși": "structura",
    "structurași": "structura",
    "structurat": "structura",
    "structurați": "structura",
    "structurau": "structura",
    "structurează": "structura",
    "structurez": "structura",
    "structureze": "structura",
    "structurezi": "structura",
    "structura": "structură",
    "structuri": "structură",
    "structurii": "structură",
    "structurile": "structură",
    "structurilor": "structură",
    "structurală": "structural",
    "structurale": "structural",
    "structurali": "structural",
    "structuralismul": "structuralism",
    "structuralismului": "structuralism",
    "structuraliști": "structuralist",
    "structuraliștii": "structuralist",
    "structuraliștilor": "structuralist",
    "structuralistul": "structuralist",
    "structuralistului": "structuralist",
    "structuralista": "structuralistă",
    "structuraliste": "structuralistă",
    "structuralistei": "structuralistă",
    "structuralistele": "structuralistă",
    "structuralistelor": "structuralistă",
    "structurarea": "structurare",
    "structurări": "structurare",
    "structurării": "structurare",
    "structurările": "structurare",
    "structurărilor": "structurare",
    "structurată": "structurat",
    "structurate": "structurat",
    "structurați": "structurat",
    "ștrudele": "ștrudel",
    "ștrudelele": "ștrudel",
    "ștrudelelor": "ștrudel",
    "ștrudelul": "ștrudel",
    "ștrudelului": "ștrudel",
    "strugurele": "strugure",
    "strugurelui": "strugure",
    "struguri": "strugure",
    "strugurii": "strugure",
    "strugurilor": "strugure",
    "struna": "strună",
    "strune": "strună",
    "strunei": "strună",
    "strunele": "strună",
    "strunelor": "strună",
    "strungul": "strung",
    "strungului": "strung",
    "strunguri": "strung",
    "strungurile": "strung",
    "strungurilor": "strung",
    "strunga": "strungă",
    "strungi": "strungă",
    "strungii": "strungă",
    "strungile": "strungă",
    "strungilor": "strungă",
    "strungari": "strungar",
    "strungarii": "strungar",
    "strungarilor": "strungar",
    "strungarul": "strungar",
    "strungarului": "strungar",
    "strungăreața": "strungăreață",
    "strungărețe": "strungăreață",
    "strungăreței": "strungăreață",
    "strungărețele": "strungăreață",
    "strungărețelor": "strungăreață",
    "strungăria": "strungărie",
    "strungăriei": "strungărie",
    "strungării": "strungărie",
    "strungăriile": "strungărie",
    "strungăriilor": "strungărie",
    "nemaistrunind": "struni",
    "nemaistrunindu": "struni",
    "nestrunind": "struni",
    "nestrunindu": "struni",
    "strunea": "struni",
    "struneai": "struni",
    "struneam": "struni",
    "strunească": "struni",
    "struneați": "struni",
    "struneau": "struni",
    "strunesc": "struni",
    "strunește": "struni",
    "strunești": "struni",
    "strunii": "struni",
    "strunim": "struni",
    "strunind": "struni",
    "strunindu": "struni",
    "struniră": "struni",
    "strunirăm": "struni",
    "strunirăți": "struni",
    "strunise": "struni",
    "strunisem": "struni",
    "struniseră": "struni",
    "struniserăm": "struni",
    "struniserăți": "struni",
    "struniseși": "struni",
    "struniși": "struni",
    "strunit": "struni",
    "struniți": "struni",
    "strunită": "strunit",
    "strunite": "strunit",
    "struniți": "strunit",
    "nemaistrunjind": "strunji",
    "nemaistrunjindu": "strunji",
    "nestrunjind": "strunji",
    "nestrunjindu": "strunji",
    "strunjea": "strunji",
    "strunjeai": "strunji",
    "strunjeam": "strunji",
    "strunjească": "strunji",
    "strunjeați": "strunji",
    "strunjeau": "strunji",
    "strunjesc": "strunji",
    "strunjește": "strunji",
    "strunjești": "strunji",
    "strunjii": "strunji",
    "strunjim": "strunji",
    "strunjind": "strunji",
    "strunjindu": "strunji",
    "strunjiră": "strunji",
    "strunjirăm": "strunji",
    "strunjirăți": "strunji",
    "strunjise": "strunji",
    "strunjisem": "strunji",
    "strunjiseră": "strunji",
    "strunjiserăm": "strunji",
    "strunjiserăți": "strunji",
    "strunjiseși": "strunji",
    "strunjiși": "strunji",
    "strunjit": "strunji",
    "strunjiți": "strunji",
    "strunjirea": "strunjire",
    "strunjireo": "strunjire",
    "strunjiri": "strunjire",
    "strunjirii": "strunjire",
    "strunjirile": "strunjire",
    "strunjirilor": "strunjire",
    "strunjita": "strunjit",
    "strunjită": "strunjit",
    "strunjite": "strunjit",
    "strunjitei": "strunjit",
    "strunjitele": "strunjit",
    "strunjitelor": "strunjit",
    "strunjiți": "strunjit",
    "strunjiții": "strunjit",
    "strunjiților": "strunjit",
    "strunjito": "strunjit",
    "strunjitul": "strunjit",
    "strunjitule": "strunjit",
    "strunjitului": "strunjit",
    "struți": "struț",
    "struții": "struț",
    "struților": "struț",
    "struțul": "struț",
    "struțului": "struț",
    "stucul": "stuc",
    "stucului": "stuc",
    "stucatura": "stucatură",
    "stucaturi": "stucatură",
    "stucaturii": "stucatură",
    "stucaturile": "stucatură",
    "stucaturilor": "stucatură",
    "stud.": "student",
    "studenți": "student",
    "studenții": "student",
    "studenților": "student",
    "studentul": "student",
    "studentului": "student",
    "studenta": "studentă",
    "studente": "studentă",
    "studentei": "studentă",
    "studentele": "studentă",
    "studentelor": "studentă",
    "studențescul": "studențesc",
    "studențescului": "studențesc",
    "studențești": "studențesc",
    "studențeștii": "studențesc",
    "studențeștilor": "studențesc",
    "studenția": "studenție",
    "studenției": "studenție",
    "studenții": "studenție",
    "studențiile": "studenție",
    "studențiilor": "studenție",
    "studențimea": "studențime",
    "studențimi": "studențime",
    "studențimii": "studențime",
    "studențimile": "studențime",
    "studențimilor": "studențime",
    "nemaistudiind": "studia",
    "nemaistudiindu": "studia",
    "nestudiind": "studia",
    "nestudiindu": "studia",
    "studiai": "studia",
    "studiam": "studia",
    "studiară": "studia",
    "studiarăm": "studia",
    "studiarăți": "studia",
    "studiase": "studia",
    "studiasem": "studia",
    "studiaseră": "studia",
    "studiaserăm": "studia",
    "studiaserăți": "studia",
    "studiaseși": "studia",
    "studiași": "studia",
    "studiat": "studia",
    "studiați": "studia",
    "studiau": "studia",
    "studiază": "studia",
    "studie": "studia",
    "studiem": "studia",
    "studiez": "studia",
    "studieze": "studia",
    "studiezi": "studia",
    "studiind": "studia",
    "studiindu": "studia",
    "studiata": "studiat",
    "studiată": "studiat",
    "studiate": "studiat",
    "studiatei": "studiat",
    "studiatele": "studiat",
    "studiatelor": "studiat",
    "studiați": "studiat",
    "studiații": "studiat",
    "studiaților": "studiat",
    "studiato": "studiat",
    "studiatul": "studiat",
    "studiatule": "studiat",
    "studiatului": "studiat",
    "studierea": "studiere",
    "studiereo": "studiere",
    "studieri": "studiere",
    "studierii": "studiere",
    "studierile": "studiere",
    "studierilor": "studiere",
    "studioul": "studio",
    "studioului": "studio",
    "studiouri": "studio",
    "studiourile": "studio",
    "studiourilor": "studio",
    "studioasa": "studios",
    "studioasă": "studios",
    "studioase": "studios",
    "studioasei": "studios",
    "studioasele": "studios",
    "studioaselor": "studios",
    "studioși": "studios",
    "studioșii": "studios",
    "studioșilor": "studios",
    "studiosul": "studios",
    "studiosului": "studios",
    "studii": "studiu",
    "studiile": "studiu",
    "studiilor": "studiu",
    "studiul": "studiu",
    "studiului": "studiu",
    "stuful": "stuf",
    "stufului": "stuf",
    "stufuri": "stuf",
    "stufurile": "stuf",
    "stufurilor": "stuf",
    "stufăria": "stufărie",
    "stufăriei": "stufărie",
    "stufării": "stufărie",
    "stufăriile": "stufărie",
    "stufăriilor": "stufărie",
    "stufărișul": "stufăriș",
    "stufărișului": "stufăriș",
    "stufărișuri": "stufăriș",
    "stufărișurile": "stufăriș",
    "stufărișurilor": "stufăriș",
    "stufatul": "stufat",
    "stufatului": "stufat",
    "stufaturi": "stufat",
    "stufaturile": "stufat",
    "stufaturilor": "stufat",
    "stufitul": "stufit",
    "stufitului": "stufit",
    "stufoasa": "stufos",
    "stufoasă": "stufos",
    "stufoase": "stufos",
    "stufoasei": "stufos",
    "stufoasele": "stufos",
    "stufoaselor": "stufos",
    "stufoși": "stufos",
    "stufoșii": "stufos",
    "stufoșilor": "stufos",
    "stufosul": "stufos",
    "stufosului": "stufos",
    "stupi": "stup",
    "stupii": "stup",
    "stupilor": "stup",
    "stupul": "stup",
    "stupului": "stup",
    "stupari": "stupar",
    "stuparii": "stupar",
    "stuparilor": "stupar",
    "stuparul": "stupar",
    "stuparului": "stupar",
    "stupăria": "stupărie",
    "stupăriei": "stupărie",
    "stupării": "stupărie",
    "stupăriile": "stupărie",
    "stupăriilor": "stupărie",
    "stupăritul": "stupărit",
    "stupăritului": "stupărit",
    "stupefacția": "stupefacție",
    "stupefacției": "stupefacție",
    "stupefacții": "stupefacție",
    "stupefacțiile": "stupefacție",
    "stupefacțiilor": "stupefacție",
    "nemaistupefiind": "stupefia",
    "nemaistupefiindu": "stupefia",
    "nestupefiind": "stupefia",
    "nestupefiindu": "stupefia",
    "stupefiai": "stupefia",
    "stupefiam": "stupefia",
    "stupefiară": "stupefia",
    "stupefiarăm": "stupefia",
    "stupefiarăți": "stupefia",
    "stupefiase": "stupefia",
    "stupefiasem": "stupefia",
    "stupefiaseră": "stupefia",
    "stupefiaserăm": "stupefia",
    "stupefiaserăți": "stupefia",
    "stupefiaseși": "stupefia",
    "stupefiași": "stupefia",
    "stupefiat": "stupefia",
    "stupefiați": "stupefia",
    "stupefiau": "stupefia",
    "stupefiază": "stupefia",
    "stupefie": "stupefia",
    "stupefiem": "stupefia",
    "stupefiez": "stupefia",
    "stupefieze": "stupefia",
    "stupefiezi": "stupefia",
    "stupefiind": "stupefia",
    "stupefiindu": "stupefia",
    "stupefianta": "stupefiant",
    "stupefiantă": "stupefiant",
    "stupefiante": "stupefiant",
    "stupefiantei": "stupefiant",
    "stupefiantele": "stupefiant",
    "stupefiantelor": "stupefiant",
    "stupefianți": "stupefiant",
    "stupefianții": "stupefiant",
    "stupefianților": "stupefiant",
    "stupefiantul": "stupefiant",
    "stupefiantului": "stupefiant",
    "stupefiată": "stupefiat",
    "stupefiate": "stupefiat",
    "stupefiați": "stupefiat",
    "nemaistupind": "stupi",
    "nemaistupindu": "stupi",
    "nestupind": "stupi",
    "nestupindu": "stupi",
    "stupea": "stupi",
    "stupeai": "stupi",
    "stupeam": "stupi",
    "stupească": "stupi",
    "stupeați": "stupi",
    "stupeau": "stupi",
    "stupesc": "stupi",
    "stupește": "stupi",
    "stupești": "stupi",
    "stupii": "stupi",
    "stupim": "stupi",
    "stupind": "stupi",
    "stupindu": "stupi",
    "stupiră": "stupi",
    "stupirăm": "stupi",
    "stupirăți": "stupi",
    "stupise": "stupi",
    "stupisem": "stupi",
    "stupiseră": "stupi",
    "stupiserăm": "stupi",
    "stupiserăți": "stupi",
    "stupiseși": "stupi",
    "stupiși": "stupi",
    "stupit": "stupi",
    "stupiți": "stupi",
    "stupida": "stupid",
    "stupidă": "stupid",
    "stupide": "stupid",
    "stupidei": "stupid",
    "stupidele": "stupid",
    "stupidelor": "stupid",
    "stupidul": "stupid",
    "stupidului": "stupid",
    "stupizi": "stupid",
    "stupizii": "stupid",
    "stupizilor": "stupid",
    "stupiditatea": "stupiditate",
    "stupidități": "stupiditate",
    "stupidității": "stupiditate",
    "stupiditățile": "stupiditate",
    "stupidităților": "stupiditate",
    "stupina": "stupină",
    "stupine": "stupină",
    "stupinei": "stupină",
    "stupinele": "stupină",
    "stupinelor": "stupină",
    "stupită": "stupit",
    "stupite": "stupit",
    "stupiți": "stupit",
    "stupizenia": "stupizenie",
    "stupizeniei": "stupizenie",
    "stupizenii": "stupizenie",
    "stupizeniile": "stupizenie",
    "stupizeniilor": "stupizenie",
    "stupoarea": "stupoare",
    "stupori": "stupoare",
    "stuporii": "stupoare",
    "stuporile": "stupoare",
    "stuporilor": "stupoare",
    "sturioni": "sturion",
    "sturionii": "sturion",
    "sturionilor": "sturion",
    "sturionul": "sturion",
    "sturionului": "sturion",
    "sturzi": "sturz",
    "sturzii": "sturz",
    "sturzilor": "sturz",
    "sturzul": "sturz",
    "sturzului": "sturz",
    "ștuțul": "ștuț",
    "ștuțului": "ștuț",
    "ștuțuri": "ștuț",
    "ștuțurile": "ștuț",
    "ștuțurilor": "ștuț",
    "Styxul": "Styx",
    "Styxului": "Styx",
    "suava": "suav",
    "suavă": "suav",
    "suave": "suav",
    "suavei": "suav",
    "suavele": "suav",
    "suavelor": "suav",
    "suavi": "suav",
    "suavii": "suav",
    "suavilor": "suav",
    "suavul": "suav",
    "suavului": "suav",
    "suavitatea": "suavitate",
    "suavități": "suavitate",
    "suavității": "suavitate",
    "suavitățile": "suavitate",
    "suavităților": "suavitate",
    "șuba": "șubă",
    "șube": "șubă",
    "șubei": "șubă",
    "șubele": "șubă",
    "șubelor": "șubă",
    "subacvatica": "subacvatic",
    "subacvatică": "subacvatic",
    "subacvatice": "subacvatic",
    "subacvaticei": "subacvatic",
    "subacvaticele": "subacvatic",
    "subacvaticelor": "subacvatic",
    "subacvatici": "subacvatic",
    "subacvaticii": "subacvatic",
    "subacvaticilor": "subacvatic",
    "subacvaticul": "subacvatic",
    "subacvaticului": "subacvatic",
    "nemaisubalimentând": "subalimenta",
    "nemaisubalimentându": "subalimenta",
    "nesubalimentând": "subalimenta",
    "nesubalimentându": "subalimenta",
    "subalimentă": "subalimenta",
    "subalimentai": "subalimenta",
    "subalimentam": "subalimenta",
    "subalimentăm": "subalimenta",
    "subalimentând": "subalimenta",
    "subalimentându": "subalimenta",
    "subalimentară": "subalimenta",
    "subalimentarăm": "subalimenta",
    "subalimentarăți": "subalimenta",
    "subalimentase": "subalimenta",
    "subalimentasem": "subalimenta",
    "subalimentaseră": "subalimenta",
    "subalimentaserăm": "subalimenta",
    "subalimentaserăți": "subalimenta",
    "subalimentaseși": "subalimenta",
    "subalimentași": "subalimenta",
    "subalimentat": "subalimenta",
    "subalimentați": "subalimenta",
    "subalimentau": "subalimenta",
    "subalimentează": "subalimenta",
    "subalimentez": "subalimenta",
    "subalimenteze": "subalimenta",
    "subalimentezi": "subalimenta",
    "subalimentată": "subalimentat",
    "subalimentate": "subalimentat",
    "subalimentați": "subalimentat",
    "subalpina": "subalpin",
    "subalpină": "subalpin",
    "subalpine": "subalpin",
    "subalpinei": "subalpin",
    "subalpinele": "subalpin",
    "subalpinelor": "subalpin",
    "subalpini": "subalpin",
    "subalterna": "subaltern",
    "subalternă": "subaltern",
    "subalterne": "subaltern",
    "subalternei": "subaltern",
    "subalternele": "subaltern",
    "subalternelor": "subaltern",
    "subalterni": "subaltern",
    "subalternii": "subaltern",
    "subalternilor": "subaltern",
    "subalternul": "subaltern",
    "subalternului": "subaltern",
    "subalterna": "subalternă",
    "subalterne": "subalternă",
    "subalternei": "subalternă",
    "subalternele": "subalternă",
    "subalternelor": "subalternă",
    "subansamblul": "subansamblu",
    "subansamblului": "subansamblu",
    "subansambluri": "subansamblu",
    "subansamblurile": "subansamblu",
    "subansamblurilor": "subansamblu",
    "nemaisubapreciind": "subaprecia",
    "nemaisubapreciindu": "subaprecia",
    "nesubapreciind": "subaprecia",
    "nesubapreciindu": "subaprecia",
    "subapreciai": "subaprecia",
    "subapreciam": "subaprecia",
    "subapreciară": "subaprecia",
    "subapreciarăm": "subaprecia",
    "subapreciarăți": "subaprecia",
    "subapreciase": "subaprecia",
    "subapreciasem": "subaprecia",
    "subapreciaseră": "subaprecia",
    "subapreciaserăm": "subaprecia",
    "subapreciaserăți": "subaprecia",
    "subapreciaseși": "subaprecia",
    "subapreciași": "subaprecia",
    "subapreciat": "subaprecia",
    "subapreciați": "subaprecia",
    "subapreciau": "subaprecia",
    "subapreciază": "subaprecia",
    "subaprecie": "subaprecia",
    "subapreciem": "subaprecia",
    "subapreciez": "subaprecia",
    "subaprecieze": "subaprecia",
    "subapreciezi": "subaprecia",
    "subapreciind": "subaprecia",
    "subapreciindu": "subaprecia",
    "subapreciată": "subapreciat",
    "subapreciate": "subapreciat",
    "subapreciați": "subapreciat",
    "nemaisubarendând": "subarenda",
    "nemaisubarendându": "subarenda",
    "nesubarendând": "subarenda",
    "nesubarendându": "subarenda",
    "subarendă": "subarenda",
    "subarendai": "subarenda",
    "subarendam": "subarenda",
    "subarendăm": "subarenda",
    "subarendând": "subarenda",
    "subarendându": "subarenda",
    "subarendară": "subarenda",
    "subarendarăm": "subarenda",
    "subarendarăți": "subarenda",
    "subarendase": "subarenda",
    "subarendasem": "subarenda",
    "subarendaseră": "subarenda",
    "subarendaserăm": "subarenda",
    "subarendaserăți": "subarenda",
    "subarendaseși": "subarenda",
    "subarendași": "subarenda",
    "subarendat": "subarenda",
    "subarendați": "subarenda",
    "subarendau": "subarenda",
    "subarendează": "subarenda",
    "subarendez": "subarenda",
    "subarendeze": "subarenda",
    "subarendezi": "subarenda",
    "subarendată": "subarendat",
    "subarendate": "subarendat",
    "subarendați": "subarendat",
    "subcapitole": "subcapitol",
    "subcapitolele": "subcapitol",
    "subcapitolelor": "subcapitol",
    "subcapitolul": "subcapitol",
    "subcapitolului": "subcapitol",
    "subcarpatica": "subcarpatic",
    "subcarpatică": "subcarpatic",
    "subcarpatice": "subcarpatic",
    "subcarpaticei": "subcarpatic",
    "subcarpaticele": "subcarpatic",
    "subcarpaticelor": "subcarpatic",
    "subcarpatici": "subcarpatic",
    "subcarpaticii": "subcarpatic",
    "subcarpaticilor": "subcarpatic",
    "subcarpaticul": "subcarpatic",
    "subcarpaticului": "subcarpatic",
    "subchiriași": "subchiriaș",
    "subchiriașii": "subchiriaș",
    "subchiriașilor": "subchiriaș",
    "subchiriașul": "subchiriaș",
    "subchiriașului": "subchiriaș",
    "subchiriașa": "subchiriașă",
    "subchiriașe": "subchiriașă",
    "subchiriașei": "subchiriașă",
    "subchiriașele": "subchiriașă",
    "subchiriașelor": "subchiriașă",
    "subclasa": "subclasă",
    "subclase": "subclasă",
    "subclasei": "subclasă",
    "subclasele": "subclasă",
    "subclaselor": "subclasă",
    "subcomisari": "subcomisar",
    "subcomisarii": "subcomisar",
    "subcomisarilor": "subcomisar",
    "subcomisarul": "subcomisar",
    "subcomisarului": "subcomisar",
    "subcomisia": "subcomisie",
    "subcomisiei": "subcomisie",
    "subcomisii": "subcomisie",
    "subcomisiile": "subcomisie",
    "subcomisiilor": "subcomisie",
    "subconștienți": "subconștient",
    "subconștienții": "subconștient",
    "subconștienților": "subconștient",
    "subconștientul": "subconștient",
    "subconștientului": "subconștient",
    "subcorticala": "subcortical",
    "subcorticală": "subcortical",
    "subcorticale": "subcortical",
    "subcorticalei": "subcortical",
    "subcorticalele": "subcortical",
    "subcorticalelor": "subcortical",
    "subcorticali": "subcortical",
    "subcorticalii": "subcortical",
    "subcorticalilor": "subcortical",
    "subcorticalul": "subcortical",
    "subcorticalului": "subcortical",
    "subcutanata": "subcutanat",
    "subcutanată": "subcutanat",
    "subcutanate": "subcutanat",
    "subcutanatei": "subcutanat",
    "subcutanatele": "subcutanat",
    "subcutanatelor": "subcutanat",
    "subcutanați": "subcutanat",
    "subcutanații": "subcutanat",
    "subcutanaților": "subcutanat",
    "subcutanatul": "subcutanat",
    "subcutanatului": "subcutanat",
    "subdezvoltarea": "subdezvoltare",
    "subdezvoltări": "subdezvoltare",
    "subdezvoltării": "subdezvoltare",
    "subdezvoltările": "subdezvoltare",
    "subdezvoltărilor": "subdezvoltare",
    "subdezvoltata": "subdezvoltat",
    "subdezvoltată": "subdezvoltat",
    "subdezvoltate": "subdezvoltat",
    "subdezvoltatei": "subdezvoltat",
    "subdezvoltatele": "subdezvoltat",
    "subdezvoltatelor": "subdezvoltat",
    "subdezvoltați": "subdezvoltat",
    "subdezvoltații": "subdezvoltat",
    "subdezvoltaților": "subdezvoltat",
    "subdezvoltatul": "subdezvoltat",
    "subdezvoltatului": "subdezvoltat",
    "subdialecte": "subdialect",
    "subdialectele": "subdialect",
    "subdialectelor": "subdialect",
    "subdialectul": "subdialect",
    "subdialectului": "subdialect",
    "subdimensionata": "subdimensionat",
    "subdimensionată": "subdimensionat",
    "subdimensionate": "subdimensionat",
    "subdimensionatei": "subdimensionat",
    "subdimensionatele": "subdimensionat",
    "subdimensionatelor": "subdimensionat",
    "subdimensionați": "subdimensionat",
    "subdimensionații": "subdimensionat",
    "subdimensionaților": "subdimensionat",
    "subdimensionatul": "subdimensionat",
    "subdimensionatului": "subdimensionat",
    "subdirectori": "subdirector",
    "subdirectorii": "subdirector",
    "subdirectorilor": "subdirector",
    "subdirectorul": "subdirector",
    "subdirectorului": "subdirector",
    "subdivid": "subdivide",
    "subdividă": "subdivide",
    "subdividem": "subdivide",
    "subdivideți": "subdivide",
    "subdivizi": "subdivide",
    "subdiviză": "subdiviza",
    "subdivizai": "subdiviza",
    "subdivizam": "subdiviza",
    "subdivizăm": "subdiviza",
    "subdivizând": "subdiviza",
    "subdivizându": "subdiviza",
    "subdivizară": "subdiviza",
    "subdivizarăm": "subdiviza",
    "subdivizarăți": "subdiviza",
    "subdivizase": "subdiviza",
    "subdivizasem": "subdiviza",
    "subdivizaseră": "subdiviza",
    "subdivizaserăm": "subdiviza",
    "subdivizaserăți": "subdiviza",
    "subdivizaseși": "subdiviza",
    "subdivizași": "subdiviza",
    "subdivizat": "subdiviza",
    "subdivizați": "subdiviza",
    "subdivizatu": "subdiviza",
    "subdivizau": "subdiviza",
    "subdivizează": "subdiviza",
    "subdivizez": "subdiviza",
    "subdivizeze": "subdiviza",
    "subdivizezi": "subdiviza",
    "subdivizarea": "subdivizare",
    "subdivizareo": "subdivizare",
    "subdivizări": "subdivizare",
    "subdivizării": "subdivizare",
    "subdivizările": "subdivizare",
    "subdivizărilor": "subdivizare",
    "subdivizata": "subdivizat",
    "subdivizată": "subdivizat",
    "subdivizate": "subdivizat",
    "subdivizatei": "subdivizat",
    "subdivizatele": "subdivizat",
    "subdivizatelor": "subdivizat",
    "subdivizați": "subdivizat",
    "subdivizații": "subdivizat",
    "subdivizaților": "subdivizat",
    "subdivizato": "subdivizat",
    "subdivizatul": "subdivizat",
    "subdivizatule": "subdivizat",
    "subdivizatului": "subdivizat",
    "subdivizibila": "subdivizibil",
    "subdivizibilă": "subdivizibil",
    "subdivizibile": "subdivizibil",
    "subdivizibilei": "subdivizibil",
    "subdivizibilele": "subdivizibil",
    "subdivizibilelor": "subdivizibil",
    "subdivizibili": "subdivizibil",
    "subdivizibilii": "subdivizibil",
    "subdivizibililor": "subdivizibil",
    "subdivizibilo": "subdivizibil",
    "subdivizibilul": "subdivizibil",
    "subdivizibilule": "subdivizibil",
    "subdivizibilului": "subdivizibil",
    "subdivizibilitatea": "subdivizibilitate",
    "subdivizibilitateo": "subdivizibilitate",
    "subdivizibilități": "subdivizibilitate",
    "subdivizibilității": "subdivizibilitate",
    "subdivizibilitățile": "subdivizibilitate",
    "subdivizibilităților": "subdivizibilitate",
    "subdivizia": "subdivizie",
    "subdiviziei": "subdivizie",
    "subdivizii": "subdivizie",
    "subdiviziile": "subdivizie",
    "subdiviziilor": "subdivizie",
    "subdiviziunea": "subdiviziune",
    "subdiviziuni": "subdiviziune",
    "subdiviziunii": "subdiviziune",
    "subdiviziunile": "subdiviziune",
    "subdiviziunilor": "subdiviziune",
    "șubere": "șuber",
    "șuberele": "șuber",
    "șuberelor": "șuber",
    "șuberul": "șuber",
    "șuberului": "șuber",
    "nemaisubestimând": "subestima",
    "nemaisubestimându": "subestima",
    "nesubestimând": "subestima",
    "nesubestimându": "subestima",
    "subestimă": "subestima",
    "subestimai": "subestima",
    "subestimam": "subestima",
    "subestimăm": "subestima",
    "subestimând": "subestima",
    "subestimându": "subestima",
    "subestimară": "subestima",
    "subestimarăm": "subestima",
    "subestimarăți": "subestima",
    "subestimase": "subestima",
    "subestimasem": "subestima",
    "subestimaseră": "subestima",
    "subestimaserăm": "subestima",
    "subestimaserăți": "subestima",
    "subestimaseși": "subestima",
    "subestimași": "subestima",
    "subestimat": "subestima",
    "subestimați": "subestima",
    "subestimau": "subestima",
    "subestimează": "subestima",
    "subestimez": "subestima",
    "subestimeze": "subestima",
    "subestimezi": "subestima",
    "subestimata": "subestimat",
    "subestimată": "subestimat",
    "subestimate": "subestimat",
    "subestimatei": "subestimat",
    "subestimatele": "subestimat",
    "subestimatelor": "subestimat",
    "subestimați": "subestimat",
    "subestimații": "subestimat",
    "subestimaților": "subestimat",
    "subestimatul": "subestimat",
    "subestimatului": "subestimat",
    "nemaisubevaluând": "subevalua",
    "nemaisubevaluându": "subevalua",
    "nesubevaluând": "subevalua",
    "nesubevaluându": "subevalua",
    "subevaluă": "subevalua",
    "subevaluai": "subevalua",
    "subevaluam": "subevalua",
    "subevaluăm": "subevalua",
    "subevaluând": "subevalua",
    "subevaluându": "subevalua",
    "subevaluară": "subevalua",
    "subevaluarăm": "subevalua",
    "subevaluarăți": "subevalua",
    "subevaluase": "subevalua",
    "subevaluasem": "subevalua",
    "subevaluaseră": "subevalua",
    "subevaluaserăm": "subevalua",
    "subevaluaserăți": "subevalua",
    "subevaluaseși": "subevalua",
    "subevaluași": "subevalua",
    "subevaluat": "subevalua",
    "subevaluați": "subevalua",
    "subevaluau": "subevalua",
    "subevaluează": "subevalua",
    "subevaluez": "subevalua",
    "subevalueze": "subevalua",
    "subevaluezi": "subevalua",
    "subevaluată": "subevaluat",
    "subevaluate": "subevaluat",
    "subevaluați": "subevaluat",
    "subiecte": "subiect",
    "subiectele": "subiect",
    "subiectelor": "subiect",
    "subiectul": "subiect",
    "subiectului": "subiect",
    "subiectiva": "subiectiv",
    "subiectivă": "subiectiv",
    "subiective": "subiectiv",
    "subiectivei": "subiectiv",
    "subiectivele": "subiectiv",
    "subiectivelor": "subiectiv",
    "subiectivi": "subiectiv",
    "subiectivii": "subiectiv",
    "subiectivilor": "subiectiv",
    "subiectivul": "subiectiv",
    "subiectivului": "subiectiv",
    "subiectivisme": "subiectivism",
    "subiectivismele": "subiectivism",
    "subiectivismelor": "subiectivism",
    "subiectivismul": "subiectivism",
    "subiectivismului": "subiectivism",
    "subiectivista": "subiectivist",
    "subiectivistă": "subiectivist",
    "subiectiviste": "subiectivist",
    "subiectivistei": "subiectivist",
    "subiectivistele": "subiectivist",
    "subiectivistelor": "subiectivist",
    "subiectiviști": "subiectivist",
    "subiectiviștii": "subiectivist",
    "subiectiviștilor": "subiectivist",
    "subiectivistul": "subiectivist",
    "subiectivistului": "subiectivist",
    "subiectivista": "subiectivistă",
    "subiectiviste": "subiectivistă",
    "subiectivistei": "subiectivistă",
    "subiectivistele": "subiectivistă",
    "subiectivistelor": "subiectivistă",
    "nemaisubîmpărțind": "subîmpărți",
    "nemaisubîmpărțindu": "subîmpărți",
    "nesubîmpărțind": "subîmpărți",
    "nesubîmpărțindu": "subîmpărți",
    "subîmpart": "subîmpărți",
    "subîmpartă": "subîmpărți",
    "subîmparte": "subîmpărți",
    "subîmpărțea": "subîmpărți",
    "subîmpărțeai": "subîmpărți",
    "subîmpărțeam": "subîmpărți",
    "subîmpărțeați": "subîmpărți",
    "subîmpărțeau": "subîmpărți",
    "subîmparți": "subîmpărți",
    "subîmpărții": "subîmpărți",
    "subîmpărțim": "subîmpărți",
    "subîmpărțind": "subîmpărți",
    "subîmpărțindu": "subîmpărți",
    "subîmpărțiră": "subîmpărți",
    "subîmpărțirăm": "subîmpărți",
    "subîmpărțirăți": "subîmpărți",
    "subîmpărțise": "subîmpărți",
    "subîmpărțisem": "subîmpărți",
    "subîmpărțiseră": "subîmpărți",
    "subîmpărțiserăm": "subîmpărți",
    "subîmpărțiserăți": "subîmpărți",
    "subîmpărțiseși": "subîmpărți",
    "subîmpărțiși": "subîmpărți",
    "subîmpărțit": "subîmpărți",
    "subîmpărțiți": "subîmpărți",
    "subîmpărțirea": "subîmpărțire",
    "subîmpărțireo": "subîmpărțire",
    "subîmpărțiri": "subîmpărțire",
    "subîmpărțirii": "subîmpărțire",
    "subîmpărțirile": "subîmpărțire",
    "subîmpărțirilor": "subîmpărțire",
    "subîmpărțită": "subîmpărțit",
    "subîmpărțite": "subîmpărțit",
    "subîmpărțiți": "subîmpărțit",
    "nemaisubînchiriind": "subînchiria",
    "nemaisubînchiriindu": "subînchiria",
    "nesubînchiriind": "subînchiria",
    "nesubînchiriindu": "subînchiria",
    "subînchiriai": "subînchiria",
    "subînchiriam": "subînchiria",
    "subînchiriară": "subînchiria",
    "subînchiriarăm": "subînchiria",
    "subînchiriarăți": "subînchiria",
    "subînchiriase": "subînchiria",
    "subînchiriasem": "subînchiria",
    "subînchiriaseră": "subînchiria",
    "subînchiriaserăm": "subînchiria",
    "subînchiriaserăți": "subînchiria",
    "subînchiriaseși": "subînchiria",
    "subînchiriași": "subînchiria",
    "subînchiriat": "subînchiria",
    "subînchiriați": "subînchiria",
    "subînchiriau": "subînchiria",
    "subînchiriază": "subînchiria",
    "subînchirie": "subînchiria",
    "subînchiriem": "subînchiria",
    "subînchiriez": "subînchiria",
    "subînchirieze": "subînchiria",
    "subînchiriezi": "subînchiria",
    "subînchiriind": "subînchiria",
    "subînchiriindu": "subînchiria",
    "subînchiriată": "subînchiriat",
    "subînchiriate": "subînchiriat",
    "subînchiriați": "subînchiriat",
    "nemaisubînțelegând": "subînțelege",
    "nemaisubînțelegându": "subînțelege",
    "nesubînțelegând": "subînțelege",
    "nesubînțelegându": "subînțelege",
    "subînțeleagă": "subînțelege",
    "subînțeleg": "subînțelege",
    "subînțelegând": "subînțelege",
    "subînțelegându": "subînțelege",
    "subînțelegea": "subînțelege",
    "subînțelegeai": "subînțelege",
    "subînțelegeam": "subînțelege",
    "subînțelegeați": "subînțelege",
    "subînțelegeau": "subînțelege",
    "subînțelegem": "subînțelege",
    "subînțelegeți": "subînțelege",
    "subînțelegi": "subînțelege",
    "subînțeles": "subînțelege",
    "subînțelese": "subînțelege",
    "subînțelesei": "subînțelege",
    "subînțeleseră": "subînțelege",
    "subînțeleserăm": "subînțelege",
    "subînțeleserăți": "subînțelege",
    "subînțelesese": "subînțelege",
    "subînțelesesem": "subînțelege",
    "subînțeleseseră": "subînțelege",
    "subînțeleseserăm": "subînțelege",
    "subînțeleseserăți": "subînțelege",
    "subînțeleseseși": "subînțelege",
    "subînțeleseși": "subînțelege",
    "subînțeleasa": "subînțeles",
    "subînțeleasă": "subînțeles",
    "subînțelese": "subînțeles",
    "subînțelesei": "subînțeles",
    "subînțelesele": "subînțeles",
    "subînțeleselor": "subînțeles",
    "subînțeleși": "subînțeles",
    "subînțeleșii": "subînțeles",
    "subînțeleșilor": "subînțeles",
    "subînțelesul": "subînțeles",
    "subînțelesului": "subînțeles",
    "subînțelesuri": "subînțeles",
    "subînțelesurile": "subînțeles",
    "subînțelesurilor": "subînțeles",
    "nemaisubintitulând": "subintitula",
    "nemaisubintitulându": "subintitula",
    "nesubintitulând": "subintitula",
    "nesubintitulându": "subintitula",
    "subintitulă": "subintitula",
    "subintitulai": "subintitula",
    "subintitulam": "subintitula",
    "subintitulăm": "subintitula",
    "subintitulând": "subintitula",
    "subintitulându": "subintitula",
    "subintitulară": "subintitula",
    "subintitularăm": "subintitula",
    "subintitularăți": "subintitula",
    "subintitulase": "subintitula",
    "subintitulasem": "subintitula",
    "subintitulaseră": "subintitula",
    "subintitulaserăm": "subintitula",
    "subintitulaserăți": "subintitula",
    "subintitulaseși": "subintitula",
    "subintitulași": "subintitula",
    "subintitulat": "subintitula",
    "subintitulați": "subintitula",
    "subintitulau": "subintitula",
    "subintitulează": "subintitula",
    "subintitulez": "subintitula",
    "subintituleze": "subintitula",
    "subintitulezi": "subintitula",
    "subintitulată": "subintitulat",
    "subintitulate": "subintitulat",
    "subintitulați": "subintitulat",
    "subita": "subit",
    "subită": "subit",
    "subite": "subit",
    "subitei": "subit",
    "subitele": "subit",
    "subitelor": "subit",
    "subiți": "subit",
    "subiții": "subit",
    "subiților": "subit",
    "subitul": "subit",
    "subitului": "subit",
    "subjonctiva": "subjonctiv",
    "subjonctivă": "subjonctiv",
    "subjonctive": "subjonctiv",
    "subjonctivei": "subjonctiv",
    "subjonctivele": "subjonctiv",
    "subjonctivelor": "subjonctiv",
    "subjonctivi": "subjonctiv",
    "subjonctivii": "subjonctiv",
    "subjonctivilor": "subjonctiv",
    "subjonctivul": "subjonctiv",
    "subjonctivului": "subjonctiv",
    "nemaisubjugând": "subjuga",
    "nemaisubjugându": "subjuga",
    "nesubjugând": "subjuga",
    "nesubjugându": "subjuga",
    "subjug": "subjuga",
    "subjugă": "subjuga",
    "subjugai": "subjuga",
    "subjugam": "subjuga",
    "subjugăm": "subjuga",
    "subjugând": "subjuga",
    "subjugându": "subjuga",
    "subjugară": "subjuga",
    "subjugarăm": "subjuga",
    "subjugarăți": "subjuga",
    "subjugase": "subjuga",
    "subjugasem": "subjuga",
    "subjugaseră": "subjuga",
    "subjugaserăm": "subjuga",
    "subjugaserăți": "subjuga",
    "subjugaseși": "subjuga",
    "subjugași": "subjuga",
    "subjugat": "subjuga",
    "subjugați": "subjuga",
    "subjugau": "subjuga",
    "subjuge": "subjuga",
    "subjugi": "subjuga",
    "subjugată": "subjugat",
    "subjugate": "subjugat",
    "subjugați": "subjugat",
    "șublere": "șubler",
    "șublerele": "șubler",
    "șublerelor": "șubler",
    "șublerul": "șubler",
    "șublerului": "șubler",
    "sublima": "sublim",
    "sublimă": "sublim",
    "sublime": "sublim",
    "sublimei": "sublim",
    "sublimele": "sublim",
    "sublimelor": "sublim",
    "sublimi": "sublim",
    "sublimii": "sublim",
    "sublimilor": "sublim",
    "sublimul": "sublim",
    "sublimului": "sublim",
    "nemaisublimând": "sublima",
    "nemaisublimându": "sublima",
    "nesublimând": "sublima",
    "nesublimându": "sublima",
    "sublimă": "sublima",
    "sublimai": "sublima",
    "sublimam": "sublima",
    "sublimăm": "sublima",
    "sublimând": "sublima",
    "sublimându": "sublima",
    "sublimară": "sublima",
    "sublimarăm": "sublima",
    "sublimarăți": "sublima",
    "sublimase": "sublima",
    "sublimasem": "sublima",
    "sublimaseră": "sublima",
    "sublimaserăm": "sublima",
    "sublimaserăți": "sublima",
    "sublimaseși": "sublima",
    "sublimași": "sublima",
    "sublimat": "sublima",
    "sublimați": "sublima",
    "sublimau": "sublima",
    "sublimează": "sublima",
    "sublimez": "sublima",
    "sublimeze": "sublima",
    "sublimezi": "sublima",
    "sublimată": "sublimat",
    "sublimate": "sublimat",
    "sublimați": "sublimat",
    "sublimatul": "sublimat",
    "sublimatului": "sublimat",
    "sublinguala": "sublingual",
    "sublinguală": "sublingual",
    "sublinguale": "sublingual",
    "sublingualei": "sublingual",
    "sublingualele": "sublingual",
    "sublingualelor": "sublingual",
    "sublinguali": "sublingual",
    "sublingualii": "sublingual",
    "sublingualilor": "sublingual",
    "sublingualul": "sublingual",
    "sublingualului": "sublingual",
    "nemaisubliniind": "sublinia",
    "nemaisubliniindu": "sublinia",
    "nesubliniind": "sublinia",
    "nesubliniindu": "sublinia",
    "subliniai": "sublinia",
    "subliniam": "sublinia",
    "subliniară": "sublinia",
    "subliniarăm": "sublinia",
    "subliniarăți": "sublinia",
    "subliniase": "sublinia",
    "subliniasem": "sublinia",
    "subliniaseră": "sublinia",
    "subliniaserăm": "sublinia",
    "subliniaserăți": "sublinia",
    "subliniaseși": "sublinia",
    "subliniași": "sublinia",
    "subliniat": "sublinia",
    "subliniați": "sublinia",
    "subliniau": "sublinia",
    "subliniază": "sublinia",
    "sublinie": "sublinia",
    "subliniem": "sublinia",
    "subliniez": "sublinia",
    "sublinieze": "sublinia",
    "subliniezi": "sublinia",
    "subliniind": "sublinia",
    "subliniindu": "sublinia",
    "subliniată": "subliniat",
    "subliniate": "subliniat",
    "subliniați": "subliniat",
    "sublinierea": "subliniere",
    "sublinieri": "subliniere",
    "sublinierii": "subliniere",
    "sublinierile": "subliniere",
    "sublinierilor": "subliniere",
    "slt.": "sublocotenent",
    "sublocotenenți": "sublocotenent",
    "sublocotenenții": "sublocotenent",
    "sublocotenenților": "sublocotenent",
    "sublocotenentul": "sublocotenent",
    "sublocotenentului": "sublocotenent",
    "submarina": "submarin",
    "submarină": "submarin",
    "submarine": "submarin",
    "submarinei": "submarin",
    "submarinele": "submarin",
    "submarinelor": "submarin",
    "submarini": "submarin",
    "submarinii": "submarin",
    "submarinilor": "submarin",
    "submarinul": "submarin",
    "submarinului": "submarin",
    "submersibila": "submersibil",
    "submersibilă": "submersibil",
    "submersibile": "submersibil",
    "submersibilei": "submersibil",
    "submersibilele": "submersibil",
    "submersibilelor": "submersibil",
    "submersibili": "submersibil",
    "submersibilii": "submersibil",
    "submersibililor": "submersibil",
    "submersibilul": "submersibil",
    "submersibilului": "submersibil",
    "submersiunea": "submersiune",
    "submersiuni": "submersiune",
    "submersiunii": "submersiune",
    "submersiunile": "submersiune",
    "submersiunilor": "submersiune",
    "nemaisubminând": "submina",
    "nemaisubminându": "submina",
    "nesubminând": "submina",
    "nesubminându": "submina",
    "submină": "submina",
    "subminai": "submina",
    "subminam": "submina",
    "subminăm": "submina",
    "subminând": "submina",
    "subminându": "submina",
    "subminară": "submina",
    "subminarăm": "submina",
    "subminarăți": "submina",
    "subminase": "submina",
    "subminasem": "submina",
    "subminaseră": "submina",
    "subminaserăm": "submina",
    "subminaserăți": "submina",
    "subminaseși": "submina",
    "subminași": "submina",
    "subminat": "submina",
    "subminați": "submina",
    "subminau": "submina",
    "subminează": "submina",
    "subminez": "submina",
    "submineze": "submina",
    "subminezi": "submina",
    "subminarea": "subminare",
    "subminareo": "subminare",
    "subminări": "subminare",
    "subminării": "subminare",
    "subminările": "subminare",
    "subminărilor": "subminare",
    "subminata": "subminat",
    "subminată": "subminat",
    "subminate": "subminat",
    "subminatei": "subminat",
    "subminatele": "subminat",
    "subminatelor": "subminat",
    "subminați": "subminat",
    "subminații": "subminat",
    "subminaților": "subminat",
    "subminato": "subminat",
    "subminatul": "subminat",
    "subminatule": "subminat",
    "subminatului": "subminat",
    "submultipli": "submultiplu",
    "submultiplii": "submultiplu",
    "submultiplilor": "submultiplu",
    "submultiplul": "submultiplu",
    "submultiplului": "submultiplu",
    "subnutrita": "subnutrit",
    "subnutrită": "subnutrit",
    "subnutrite": "subnutrit",
    "subnutritei": "subnutrit",
    "subnutritele": "subnutrit",
    "subnutritelor": "subnutrit",
    "subnutriți": "subnutrit",
    "subnutriții": "subnutrit",
    "subnutriților": "subnutrit",
    "subnutritul": "subnutrit",
    "subnutritului": "subnutrit",
    "subnutriția": "subnutriție",
    "subnutriției": "subnutriție",
    "subnutriții": "subnutriție",
    "subnutrițiile": "subnutriție",
    "subnutrițiilor": "subnutriție",
    "subofițeri": "subofițer",
    "subofițerii": "subofițer",
    "subofițerilor": "subofițer",
    "subofițerul": "subofițer",
    "subofițerului": "subofițer",
    "subordine": "subordin",
    "subordinele": "subordin",
    "subordinelor": "subordin",
    "subordinile": "subordin",
    "subordinilor": "subordin",
    "subordinul": "subordin",
    "subordinului": "subordin",
    "subordinea": "subordine",
    "subordinei": "subordine",
    "subordini": "subordine",
    "nemaisubordonând": "subordona",
    "nemaisubordonându": "subordona",
    "nesubordonând": "subordona",
    "nesubordonându": "subordona",
    "subordonă": "subordona",
    "subordonai": "subordona",
    "subordonam": "subordona",
    "subordonăm": "subordona",
    "subordonând": "subordona",
    "subordonându": "subordona",
    "subordonară": "subordona",
    "subordonarăm": "subordona",
    "subordonarăți": "subordona",
    "subordonase": "subordona",
    "subordonasem": "subordona",
    "subordonaseră": "subordona",
    "subordonaserăm": "subordona",
    "subordonaserăți": "subordona",
    "subordonaseși": "subordona",
    "subordonași": "subordona",
    "subordonat": "subordona",
    "subordonați": "subordona",
    "subordonau": "subordona",
    "subordonează": "subordona",
    "subordonez": "subordona",
    "subordoneze": "subordona",
    "subordonezi": "subordona",
    "subordonarea": "subordonare",
    "subordonări": "subordonare",
    "subordonării": "subordonare",
    "subordonările": "subordonare",
    "subordonărilor": "subordonare",
    "subordonata": "subordonat",
    "subordonată": "subordonat",
    "subordonate": "subordonat",
    "subordonatei": "subordonat",
    "subordonatele": "subordonat",
    "subordonatelor": "subordonat",
    "subordonați": "subordonat",
    "subordonații": "subordonat",
    "subordonaților": "subordonat",
    "subordonatul": "subordonat",
    "subordonatului": "subordonat",
    "subpământeana": "subpământean",
    "subpământeană": "subpământean",
    "subpământeanul": "subpământean",
    "subpământeanului": "subpământean",
    "subpământene": "subpământean",
    "subpământenei": "subpământean",
    "subpământenele": "subpământean",
    "subpământenelor": "subpământean",
    "subpământeni": "subpământean",
    "subpământenii": "subpământean",
    "subpământenilor": "subpământean",
    "subpământeana": "subpământeană",
    "subpământene": "subpământeană",
    "subpământenei": "subpământeană",
    "subpământenele": "subpământeană",
    "subpământenelor": "subpământeană",
    "subpopulata": "subpopulat",
    "subpopulată": "subpopulat",
    "subpopulate": "subpopulat",
    "subpopulatei": "subpopulat",
    "subpopulatele": "subpopulat",
    "subpopulatelor": "subpopulat",
    "subpopulați": "subpopulat",
    "subpopulații": "subpopulat",
    "subpopulaților": "subpopulat",
    "subpopulatul": "subpopulat",
    "subpopulatului": "subpopulat",
    "subprefecți": "subprefect",
    "subprefecții": "subprefect",
    "subprefecților": "subprefect",
    "subprefectul": "subprefect",
    "subprefectului": "subprefect",
    "subpresiunea": "subpresiune",
    "subpresiuni": "subpresiune",
    "subpresiunii": "subpresiune",
    "subpresiunile": "subpresiune",
    "subpresiunilor": "subpresiune",
    "șubreda": "șubred",
    "șubredă": "șubred",
    "șubrede": "șubred",
    "șubredei": "șubred",
    "șubredele": "șubred",
    "șubredelor": "șubred",
    "șubredul": "șubred",
    "șubredului": "șubred",
    "șubrezi": "șubred",
    "șubrezii": "șubred",
    "șubrezilor": "șubred",
    "subredactori": "subredactor",
    "subredactorii": "subredactor",
    "subredactorilor": "subredactor",
    "subredactorul": "subredactor",
    "subredactorului": "subredactor",
    "subregnul": "subregn",
    "subregnului": "subregn",
    "subregnuri": "subregn",
    "subregnurile": "subregn",
    "subregnurilor": "subregn",
    "subreta": "subretă",
    "subrete": "subretă",
    "subretei": "subretă",
    "subretele": "subretă",
    "subretelor": "subretă",
    "șubrezenia": "șubrezenie",
    "șubrezeniei": "șubrezenie",
    "șubrezenii": "șubrezenie",
    "șubrezeniile": "șubrezenie",
    "șubrezeniilor": "șubrezenie",
    "șubrezea": "șubrezi",
    "șubrezeai": "șubrezi",
    "șubrezeam": "șubrezi",
    "șubrezească": "șubrezi",
    "șubrezeați": "șubrezi",
    "șubrezeau": "șubrezi",
    "șubrezesc": "șubrezi",
    "șubrezește": "șubrezi",
    "șubrezești": "șubrezi",
    "șubrezii": "șubrezi",
    "șubrezim": "șubrezi",
    "șubrezind": "șubrezi",
    "șubrezindu": "șubrezi",
    "șubreziră": "șubrezi",
    "șubrezirăm": "șubrezi",
    "șubrezirăți": "șubrezi",
    "șubrezise": "șubrezi",
    "șubrezisem": "șubrezi",
    "șubreziseră": "șubrezi",
    "șubreziserăm": "șubrezi",
    "șubreziserăți": "șubrezi",
    "șubreziseși": "șubrezi",
    "șubreziși": "șubrezi",
    "șubrezit": "șubrezi",
    "șubreziți": "șubrezi",
    "șubrezirea": "șubrezire",
    "șubreziri": "șubrezire",
    "șubrezirii": "șubrezire",
    "șubrezirile": "șubrezire",
    "șubrezirilor": "șubrezire",
    "șubrezita": "șubrezit",
    "șubrezită": "șubrezit",
    "șubrezite": "șubrezit",
    "șubrezitei": "șubrezit",
    "șubrezitele": "șubrezit",
    "șubrezitelor": "șubrezit",
    "șubreziți": "șubrezit",
    "șubreziții": "șubrezit",
    "șubreziților": "șubrezit",
    "șubrezitul": "șubrezit",
    "șubrezitului": "șubrezit",
    "nemaisubscriind": "subscrie",
    "nemaisubscriindu": "subscrie",
    "nesubscriind": "subscrie",
    "nesubscriindu": "subscrie",
    "subscria": "subscrie",
    "subscriai": "subscrie",
    "subscriam": "subscrie",
    "subscriați": "subscrie",
    "subscriau": "subscrie",
    "subscriem": "subscrie",
    "subscrieți": "subscrie",
    "subscrii": "subscrie",
    "subscriind": "subscrie",
    "subscriindu": "subscrie",
    "subscris": "subscrie",
    "subscrise": "subscrie",
    "subscrisei": "subscrie",
    "subscriseră": "subscrie",
    "subscriserăm": "subscrie",
    "subscriserăți": "subscrie",
    "subscrisese": "subscrie",
    "subscrisesem": "subscrie",
    "subscriseseră": "subscrie",
    "subscriseserăm": "subscrie",
    "subscriseserăți": "subscrie",
    "subscriseseși": "subscrie",
    "subscriseși": "subscrie",
    "subscriu": "subscrie",
    "subscrierea": "subscriere",
    "subscrieri": "subscriere",
    "subscrierii": "subscriere",
    "subscrierile": "subscriere",
    "subscrierilor": "subscriere",
    "subscripția": "subscripție",
    "subscripției": "subscripție",
    "subscripții": "subscripție",
    "subscripțiile": "subscripție",
    "subscripțiilor": "subscripție",
    "subscrisă": "subscris",
    "subscrise": "subscris",
    "subscriși": "subscris",
    "subsecretari": "subsecretar",
    "subsecretarii": "subsecretar",
    "subsecretarilor": "subsecretar",
    "subsecretarul": "subsecretar",
    "subsecretarului": "subsecretar",
    "subsecția": "subsecție",
    "subsecției": "subsecție",
    "subsecții": "subsecție",
    "subsecțiile": "subsecție",
    "subsecțiilor": "subsecție",
    "subsemnați": "subsemnat",
    "subsemnații": "subsemnat",
    "subsemnaților": "subsemnat",
    "subsemnatul": "subsemnat",
    "subsemnatului": "subsemnat",
    "subsemnata": "subsemnată",
    "subsemnate": "subsemnată",
    "subsemnatei": "subsemnată",
    "subsemnatele": "subsemnată",
    "subsemnatelor": "subsemnată",
    "subsidiara": "subsidiar",
    "subsidiară": "subsidiar",
    "subsidiare": "subsidiar",
    "subsidiarei": "subsidiar",
    "subsidiarele": "subsidiar",
    "subsidiarelor": "subsidiar",
    "subsidiari": "subsidiar",
    "subsidiarii": "subsidiar",
    "subsidiarilor": "subsidiar",
    "subsidiarul": "subsidiar",
    "subsidiarului": "subsidiar",
    "subsolul": "subsol",
    "subsolului": "subsol",
    "subsoluri": "subsol",
    "subsolurile": "subsol",
    "subsolurilor": "subsol",
    "subspecia": "subspecie",
    "subspeciei": "subspecie",
    "subspecii": "subspecie",
    "subspeciile": "subspecie",
    "subspeciilor": "subspecie",
    "substanța": "substanță",
    "substanțe": "substanță",
    "substanței": "substanță",
    "substanțele": "substanță",
    "substanțelor": "substanță",
    "substanțiala": "substanțial",
    "substanțială": "substanțial",
    "substanțiale": "substanțial",
    "substanțialei": "substanțial",
    "substanțialele": "substanțial",
    "substanțialelor": "substanțial",
    "substanțiali": "substanțial",
    "substanțialii": "substanțial",
    "substanțialilor": "substanțial",
    "substanțialul": "substanțial",
    "substanțialului": "substanțial",
    "substanțialitatea": "substanțialitate",
    "substanțialități": "substanțialitate",
    "substanțialității": "substanțialitate",
    "substanțialitățile": "substanțialitate",
    "substanțialităților": "substanțialitate",
    "s.": "substantiv",
    "subst.": "substantiv",
    "substantive": "substantiv",
    "substantivele": "substantiv",
    "substantivelor": "substantiv",
    "substantivul": "substantiv",
    "substantivului": "substantiv",
    "nemaisubstantivizând": "substantiviza",
    "nemaisubstantivizându": "substantiviza",
    "nesubstantivizând": "substantiviza",
    "nesubstantivizându": "substantiviza",
    "substantiviză": "substantiviza",
    "substantivizai": "substantiviza",
    "substantivizam": "substantiviza",
    "substantivizăm": "substantiviza",
    "substantivizând": "substantiviza",
    "substantivizându": "substantiviza",
    "substantivizară": "substantiviza",
    "substantivizarăm": "substantiviza",
    "substantivizarăți": "substantiviza",
    "substantivizase": "substantiviza",
    "substantivizasem": "substantiviza",
    "substantivizaseră": "substantiviza",
    "substantivizaserăm": "substantiviza",
    "substantivizaserăți": "substantiviza",
    "substantivizaseși": "substantiviza",
    "substantivizași": "substantiviza",
    "substantivizat": "substantiviza",
    "substantivizați": "substantiviza",
    "substantivizau": "substantiviza",
    "substantivizează": "substantiviza",
    "substantivizez": "substantiviza",
    "substantivizeze": "substantiviza",
    "substantivizezi": "substantiviza",
    "substantivizată": "substantivizat",
    "substantivizate": "substantivizat",
    "substantivizați": "substantivizat",
    "substituenți": "substituent",
    "substituenții": "substituent",
    "substituenților": "substituent",
    "substituentul": "substituent",
    "substituentului": "substituent",
    "nemaisubstituind": "substitui",
    "nemaisubstituindu": "substitui",
    "nesubstituind": "substitui",
    "nesubstituindu": "substitui",
    "substituia": "substitui",
    "substituiai": "substitui",
    "substituiam": "substitui",
    "substituiați": "substitui",
    "substituiau": "substitui",
    "substituie": "substitui",
    "substituii": "substitui",
    "substituim": "substitui",
    "substituind": "substitui",
    "substituindu": "substitui",
    "substituiră": "substitui",
    "substituirăm": "substitui",
    "substituirăți": "substitui",
    "substituise": "substitui",
    "substituisem": "substitui",
    "substituiseră": "substitui",
    "substituiserăm": "substitui",
    "substituiserăți": "substitui",
    "substituiseși": "substitui",
    "substituiși": "substitui",
    "substituit": "substitui",
    "substituiți": "substitui",
    "substituită": "substituit",
    "substituite": "substituit",
    "substituiți": "substituit",
    "substituți": "substitut",
    "substituții": "substitut",
    "substituților": "substitut",
    "substitutul": "substitut",
    "substitutului": "substitut",
    "substituția": "substituție",
    "substituției": "substituție",
    "substituții": "substituție",
    "substituțiile": "substituție",
    "substituțiilor": "substituție",
    "substratul": "substrat",
    "substratului": "substrat",
    "substraturi": "substrat",
    "substraturile": "substrat",
    "substraturilor": "substrat",
    "nemaisubsumând": "subsuma",
    "nemaisubsumându": "subsuma",
    "nesubsumând": "subsuma",
    "nesubsumându": "subsuma",
    "subsumă": "subsuma",
    "subsumai": "subsuma",
    "subsumam": "subsuma",
    "subsumăm": "subsuma",
    "subsumând": "subsuma",
    "subsumându": "subsuma",
    "subsumară": "subsuma",
    "subsumarăm": "subsuma",
    "subsumarăți": "subsuma",
    "subsumase": "subsuma",
    "subsumasem": "subsuma",
    "subsumaseră": "subsuma",
    "subsumaserăm": "subsuma",
    "subsumaserăți": "subsuma",
    "subsumaseși": "subsuma",
    "subsumași": "subsuma",
    "subsumat": "subsuma",
    "subsumați": "subsuma",
    "subsumau": "subsuma",
    "subsumează": "subsuma",
    "subsumez": "subsuma",
    "subsumeze": "subsuma",
    "subsumezi": "subsuma",
    "subsumată": "subsumat",
    "subsumate": "subsumat",
    "subsumați": "subsumat",
    "subsuoara": "subsuoară",
    "subsuori": "subsuoară",
    "subsuorii": "subsuoară",
    "subsuorile": "subsuoară",
    "subsuorilor": "subsuoară",
    "subterana": "subteran",
    "subterană": "subteran",
    "subterane": "subteran",
    "subteranei": "subteran",
    "subteranele": "subteran",
    "subteranelor": "subteran",
    "subterani": "subteran",
    "subteranii": "subteran",
    "subteranilor": "subteran",
    "subteranul": "subteran",
    "subteranului": "subteran",
    "subterana": "subterană",
    "subterane": "subterană",
    "subteranei": "subterană",
    "subteranele": "subterană",
    "subteranelor": "subterană",
    "subterfugii": "subterfugiu",
    "subterfugiile": "subterfugiu",
    "subterfugiilor": "subterfugiu",
    "subterfugiul": "subterfugiu",
    "subterfugiului": "subterfugiu",
    "nemaisubțiind": "subția",
    "nemaisubțiindu": "subția",
    "nesubțiind": "subția",
    "nesubțiindu": "subția",
    "subțiai": "subția",
    "subțiam": "subția",
    "subțiară": "subția",
    "subțiarăm": "subția",
    "subțiarăți": "subția",
    "subțiase": "subția",
    "subțiasem": "subția",
    "subțiaseră": "subția",
    "subțiaserăm": "subția",
    "subțiaserăți": "subția",
    "subțiaseși": "subția",
    "subțiași": "subția",
    "subțiat": "subția",
    "subțiați": "subția",
    "subțiau": "subția",
    "subțiază": "subția",
    "subție": "subția",
    "subțiem": "subția",
    "subțiez": "subția",
    "subțieze": "subția",
    "subțiezi": "subția",
    "subțiind": "subția",
    "subțiindu": "subția",
    "subțiata": "subțiat",
    "subțiată": "subțiat",
    "subțiate": "subțiat",
    "subțiatei": "subțiat",
    "subțiatele": "subțiat",
    "subțiatelor": "subțiat",
    "subțiați": "subțiat",
    "subțiații": "subțiat",
    "subțiaților": "subțiat",
    "subțiato": "subțiat",
    "subțiatul": "subțiat",
    "subțiatule": "subțiat",
    "subțiatului": "subțiat",
    "subțierea": "subțiere",
    "subțiereo": "subțiere",
    "subțieri": "subțiere",
    "subțierii": "subțiere",
    "subțierile": "subțiere",
    "subțierilor": "subțiere",
    "subtila": "subtil",
    "subtilă": "subtil",
    "subtile": "subtil",
    "subtilei": "subtil",
    "subtilele": "subtil",
    "subtilelor": "subtil",
    "subtili": "subtil",
    "subtilii": "subtil",
    "subtililor": "subtil",
    "subtilul": "subtil",
    "subtilului": "subtil",
    "subtilitatea": "subtilitate",
    "subtilități": "subtilitate",
    "subtilității": "subtilitate",
    "subtilitățile": "subtilitate",
    "subtilităților": "subtilitate",
    "nemaisubtilizând": "subtiliza",
    "nemaisubtilizându": "subtiliza",
    "nesubtilizând": "subtiliza",
    "nesubtilizându": "subtiliza",
    "subtiliză": "subtiliza",
    "subtilizai": "subtiliza",
    "subtilizam": "subtiliza",
    "subtilizăm": "subtiliza",
    "subtilizând": "subtiliza",
    "subtilizându": "subtiliza",
    "subtilizară": "subtiliza",
    "subtilizarăm": "subtiliza",
    "subtilizarăți": "subtiliza",
    "subtilizase": "subtiliza",
    "subtilizasem": "subtiliza",
    "subtilizaseră": "subtiliza",
    "subtilizaserăm": "subtiliza",
    "subtilizaserăți": "subtiliza",
    "subtilizaseși": "subtiliza",
    "subtilizași": "subtiliza",
    "subtilizat": "subtiliza",
    "subtilizați": "subtiliza",
    "subtilizau": "subtiliza",
    "subtilizează": "subtiliza",
    "subtilizez": "subtiliza",
    "subtilizeze": "subtiliza",
    "subtilizezi": "subtiliza",
    "subtilizată": "subtilizat",
    "subtilizate": "subtilizat",
    "subtilizați": "subtilizat",
    "subțioara": "subțioară",
    "subțiori": "subțioară",
    "subțiorii": "subțioară",
    "subțiorile": "subțioară",
    "subțiorilor": "subțioară",
    "subțirea": "subțire",
    "subțirele": "subțire",
    "subțirelui": "subțire",
    "subțiri": "subțire",
    "subțirii": "subțire",
    "subțirile": "subțire",
    "subțirilor": "subțire",
    "subțirimea": "subțirime",
    "subțirimi": "subțirime",
    "subțirimii": "subțirime",
    "subțirimile": "subțirime",
    "subțirimilor": "subțirime",
    "subtitlul": "subtitlu",
    "subtitlului": "subtitlu",
    "subtitluri": "subtitlu",
    "subtitlurile": "subtitlu",
    "subtitlurilor": "subtitlu",
    "subtropicala": "subtropical",
    "subtropicală": "subtropical",
    "subtropicale": "subtropical",
    "subtropicalei": "subtropical",
    "subtropicalele": "subtropical",
    "subtropicalelor": "subtropical",
    "subtropicali": "subtropical",
    "subtropicalii": "subtropical",
    "subtropicalilor": "subtropical",
    "subtropicalul": "subtropical",
    "subtropicalului": "subtropical",
    "subumană": "subuman",
    "subumane": "subuman",
    "subumani": "subuman",
    "subunitara": "subunitar",
    "subunitară": "subunitar",
    "subunitare": "subunitar",
    "subunitarei": "subunitar",
    "subunitarele": "subunitar",
    "subunitarelor": "subunitar",
    "subunitari": "subunitar",
    "subunitarii": "subunitar",
    "subunitarilor": "subunitar",
    "subunitarul": "subunitar",
    "subunitarului": "subunitar",
    "subunitatea": "subunitate",
    "subunități": "subunitate",
    "subunității": "subunitate",
    "subunitățile": "subunitate",
    "subunităților": "subunitate",
    "suburbana": "suburban",
    "suburbană": "suburban",
    "suburbane": "suburban",
    "suburbanei": "suburban",
    "suburbanele": "suburban",
    "suburbanelor": "suburban",
    "suburbani": "suburban",
    "suburbanii": "suburban",
    "suburbanilor": "suburban",
    "suburbanul": "suburban",
    "suburbanului": "suburban",
    "suburbia": "suburbie",
    "suburbiei": "suburbie",
    "suburbii": "suburbie",
    "suburbiile": "suburbie",
    "suburbiilor": "suburbie",
    "subvenția": "subvenție",
    "subvenției": "subvenție",
    "subvenții": "subvenție",
    "subvențiile": "subvenție",
    "subvențiilor": "subvenție",
    "nemaisubvenționând": "subvenționa",
    "nemaisubvenționându": "subvenționa",
    "nesubvenționând": "subvenționa",
    "nesubvenționându": "subvenționa",
    "subvenționă": "subvenționa",
    "subvenționai": "subvenționa",
    "subvenționam": "subvenționa",
    "subvenționăm": "subvenționa",
    "subvenționând": "subvenționa",
    "subvenționându": "subvenționa",
    "subvenționară": "subvenționa",
    "subvenționarăm": "subvenționa",
    "subvenționarăți": "subvenționa",
    "subvenționase": "subvenționa",
    "subvenționasem": "subvenționa",
    "subvenționaseră": "subvenționa",
    "subvenționaserăm": "subvenționa",
    "subvenționaserăți": "subvenționa",
    "subvenționaseși": "subvenționa",
    "subvenționași": "subvenționa",
    "subvenționat": "subvenționa",
    "subvenționați": "subvenționa",
    "subvenționau": "subvenționa",
    "subvenționează": "subvenționa",
    "subvenționez": "subvenționa",
    "subvenționeze": "subvenționa",
    "subvenționezi": "subvenționa",
    "subvenționată": "subvenționat",
    "subvenționate": "subvenționat",
    "subvenționați": "subvenționat",
    "subversiunea": "subversiune",
    "subversiuni": "subversiune",
    "subversiunii": "subversiune",
    "subversiunile": "subversiune",
    "subversiunilor": "subversiune",
    "subversiva": "subversiv",
    "subversivă": "subversiv",
    "subversive": "subversiv",
    "subversivei": "subversiv",
    "subversivele": "subversiv",
    "subversivelor": "subversiv",
    "subversivi": "subversiv",
    "subversivii": "subversiv",
    "subversivilor": "subversiv",
    "subversivul": "subversiv",
    "subversivului": "subversiv",
    "nemaisubzistând": "subzista",
    "nemaisubzistându": "subzista",
    "nesubzistând": "subzista",
    "nesubzistându": "subzista",
    "subzist": "subzista",
    "subzistă": "subzista",
    "subzistai": "subzista",
    "subzistam": "subzista",
    "subzistăm": "subzista",
    "subzistând": "subzista",
    "subzistându": "subzista",
    "subzistară": "subzista",
    "subzistarăm": "subzista",
    "subzistarăți": "subzista",
    "subzistase": "subzista",
    "subzistasem": "subzista",
    "subzistaseră": "subzista",
    "subzistaserăm": "subzista",
    "subzistaserăți": "subzista",
    "subzistaseși": "subzista",
    "subzistași": "subzista",
    "subzistat": "subzista",
    "subzistați": "subzista",
    "subzistau": "subzista",
    "subziste": "subzista",
    "subziști": "subzista",
    "subzistată": "subzistat",
    "subzistate": "subzistat",
    "subzistați": "subzistat",
    "subzistenta": "subzistent",
    "subzistentă": "subzistent",
    "subzistente": "subzistent",
    "subzistentei": "subzistent",
    "subzistentele": "subzistent",
    "subzistentelor": "subzistent",
    "subzistenți": "subzistent",
    "subzistenții": "subzistent",
    "subzistenților": "subzistent",
    "subzistentul": "subzistent",
    "subzistentului": "subzistent",
    "subzistența": "subzistență",
    "subzistențe": "subzistență",
    "subzistenței": "subzistență",
    "subzistențele": "subzistență",
    "subzistențelor": "subzistență",
    "sucul": "suc",
    "sucului": "suc",
    "sucuri": "suc",
    "sucurile": "suc",
    "sucurilor": "suc",
    "sucala": "sucală",
    "sucale": "sucală",
    "sucalei": "sucală",
    "sucalele": "sucală",
    "sucalelor": "sucală",
    "nemaisucălind": "sucăli",
    "nemaisucălindu": "sucăli",
    "nesucălind": "sucăli",
    "nesucălindu": "sucăli",
    "sucălea": "sucăli",
    "sucăleai": "sucăli",
    "sucăleam": "sucăli",
    "sucălească": "sucăli",
    "sucăleați": "sucăli",
    "sucăleau": "sucăli",
    "sucălesc": "sucăli",
    "sucălește": "sucăli",
    "sucălești": "sucăli",
    "sucălii": "sucăli",
    "sucălim": "sucăli",
    "sucălind": "sucăli",
    "sucălindu": "sucăli",
    "sucăliră": "sucăli",
    "sucălirăm": "sucăli",
    "sucălirăți": "sucăli",
    "sucălise": "sucăli",
    "sucălisem": "sucăli",
    "sucăliseră": "sucăli",
    "sucăliserăm": "sucăli",
    "sucăliserăți": "sucăli",
    "sucăliseși": "sucăli",
    "sucăliși": "sucăli",
    "sucălit": "sucăli",
    "sucăliți": "sucăli",
    "sucălită": "sucălit",
    "sucălite": "sucălit",
    "sucăliți": "sucălit",
    "nemaisuccedând": "succeda",
    "nemaisuccedându": "succeda",
    "nesuccedând": "succeda",
    "nesuccedându": "succeda",
    "succed": "succeda",
    "succedă": "succeda",
    "succedai": "succeda",
    "succedam": "succeda",
    "succedăm": "succeda",
    "succedând": "succeda",
    "succedându": "succeda",
    "succedară": "succeda",
    "succedarăm": "succeda",
    "succedarăți": "succeda",
    "succedase": "succeda",
    "succedasem": "succeda",
    "succedaseră": "succeda",
    "succedaserăm": "succeda",
    "succedaserăți": "succeda",
    "succedaseși": "succeda",
    "succedași": "succeda",
    "succedat": "succeda",
    "succedați": "succeda",
    "succedau": "succeda",
    "succede": "succeda",
    "succezi": "succeda",
    "succedată": "succedat",
    "succedate": "succedat",
    "succedați": "succedat",
    "succese": "succes",
    "succesele": "succes",
    "succeselor": "succes",
    "succesul": "succes",
    "succesului": "succes",
    "succesibila": "succesibil",
    "succesibilă": "succesibil",
    "succesibile": "succesibil",
    "succesibilei": "succesibil",
    "succesibilele": "succesibil",
    "succesibilelor": "succesibil",
    "succesibili": "succesibil",
    "succesibilii": "succesibil",
    "succesibililor": "succesibil",
    "succesibilul": "succesibil",
    "succesibilului": "succesibil",
    "succesiunea": "succesiune",
    "succesiuni": "succesiune",
    "succesiunii": "succesiune",
    "succesiunile": "succesiune",
    "succesiunilor": "succesiune",
    "succesiva": "succesiv",
    "succesivă": "succesiv",
    "succesive": "succesiv",
    "succesivei": "succesiv",
    "succesivele": "succesiv",
    "succesivelor": "succesiv",
    "succesivi": "succesiv",
    "succesivii": "succesiv",
    "succesivilor": "succesiv",
    "succesivul": "succesiv",
    "succesivului": "succesiv",
    "succesoarea": "succesoare",
    "succesoarei": "succesoare",
    "succesoarele": "succesoare",
    "succesoarelor": "succesoare",
    "succesori": "succesor",
    "succesorii": "succesor",
    "succesorilor": "succesor",
    "succesorul": "succesor",
    "succesorului": "succesor",
    "succinta": "succint",
    "succintă": "succint",
    "succinte": "succint",
    "succintei": "succint",
    "succintele": "succint",
    "succintelor": "succint",
    "succinți": "succint",
    "succinții": "succint",
    "succinților": "succint",
    "succintul": "succint",
    "succintului": "succint",
    "suceala": "suceală",
    "suceli": "suceală",
    "sucelii": "suceală",
    "sucelile": "suceală",
    "sucelilor": "suceală",
    "Sucevei": "Suceava",
    "suceveana": "sucevean",
    "suceveană": "sucevean",
    "suceveanul": "sucevean",
    "suceveanului": "sucevean",
    "sucevene": "sucevean",
    "sucevenei": "sucevean",
    "sucevenele": "sucevean",
    "sucevenelor": "sucevean",
    "suceveni": "sucevean",
    "sucevenii": "sucevean",
    "sucevenilor": "sucevean",
    "nemaisucind": "suci",
    "nemaisucindu": "suci",
    "nesucind": "suci",
    "nesucindu": "suci",
    "sucea": "suci",
    "suceai": "suci",
    "suceam": "suci",
    "sucească": "suci",
    "suceați": "suci",
    "suceau": "suci",
    "sucesc": "suci",
    "sucește": "suci",
    "sucești": "suci",
    "sucii": "suci",
    "sucim": "suci",
    "sucind": "suci",
    "sucindu": "suci",
    "suciră": "suci",
    "sucirăm": "suci",
    "sucirăți": "suci",
    "sucise": "suci",
    "sucisem": "suci",
    "suciseră": "suci",
    "suciserăm": "suci",
    "suciserăți": "suci",
    "suciseși": "suci",
    "suciși": "suci",
    "sucit": "suci",
    "suciți": "suci",
    "sucită": "sucit",
    "sucite": "sucit",
    "suciți": "sucit",
    "sucitoare": "sucitor",
    "sucitoarele": "sucitor",
    "sucitoarelor": "sucitor",
    "sucitorul": "sucitor",
    "sucitorului": "sucitor",
    "sucitura": "sucitură",
    "sucituri": "sucitură",
    "suciturii": "sucitură",
    "suciturile": "sucitură",
    "suciturilor": "sucitură",
    "nemaisucombând": "sucomba",
    "nemaisucombându": "sucomba",
    "nesucombând": "sucomba",
    "nesucombându": "sucomba",
    "sucomb": "sucomba",
    "sucombă": "sucomba",
    "sucombai": "sucomba",
    "sucombam": "sucomba",
    "sucombăm": "sucomba",
    "sucombând": "sucomba",
    "sucombându": "sucomba",
    "sucombară": "sucomba",
    "sucombarăm": "sucomba",
    "sucombarăți": "sucomba",
    "sucombase": "sucomba",
    "sucombasem": "sucomba",
    "sucombaseră": "sucomba",
    "sucombaserăm": "sucomba",
    "sucombaserăți": "sucomba",
    "sucombaseși": "sucomba",
    "sucombași": "sucomba",
    "sucombat": "sucomba",
    "sucombați": "sucomba",
    "sucombau": "sucomba",
    "sucombe": "sucomba",
    "sucombi": "sucomba",
    "sucombată": "sucombat",
    "sucombate": "sucombat",
    "sucombați": "sucombat",
    "suculenta": "suculent",
    "suculentă": "suculent",
    "suculente": "suculent",
    "suculentei": "suculent",
    "suculentele": "suculent",
    "suculentelor": "suculent",
    "suculenți": "suculent",
    "suculenții": "suculent",
    "suculenților": "suculent",
    "suculentul": "suculent",
    "suculentului": "suculent",
    "suculența": "suculență",
    "suculențe": "suculență",
    "suculenței": "suculență",
    "suculențele": "suculență",
    "suculențelor": "suculență",
    "suc.": "sucursală",
    "sucursala": "sucursală",
    "sucursale": "sucursală",
    "sucursalei": "sucursală",
    "sucursalele": "sucursală",
    "sucursalelor": "sucursală",
    "S": "sud",
    "sudul": "sud",
    "sudului": "sud",
    "S.E.": "Sud_Est",
    "SE": "Sud_Est",
    "nemaisudând": "suda",
    "nemaisudându": "suda",
    "nesudând": "suda",
    "nesudându": "suda",
    "sudă": "suda",
    "sudai": "suda",
    "sudam": "suda",
    "sudăm": "suda",
    "sudând": "suda",
    "sudându": "suda",
    "sudară": "suda",
    "sudarăm": "suda",
    "sudarăți": "suda",
    "sudase": "suda",
    "sudasem": "suda",
    "sudaseră": "suda",
    "sudaserăm": "suda",
    "sudaserăți": "suda",
    "sudaseși": "suda",
    "sudași": "suda",
    "sudat": "suda",
    "sudați": "suda",
    "sudau": "suda",
    "sudează": "suda",
    "sudez": "suda",
    "sudeze": "suda",
    "sudezi": "suda",
    "sudalma": "sudalmă",
    "sudălmi": "sudalmă",
    "sudălmii": "sudalmă",
    "sudălmile": "sudalmă",
    "sudălmilor": "sudalmă",
    "sudată": "sudat",
    "sudate": "sudat",
    "sudați": "sudat",
    "sudația": "sudație",
    "sudației": "sudație",
    "sudații": "sudație",
    "sudațiile": "sudație",
    "sudațiilor": "sudație",
    "sud-estul": "sud-est",
    "sud-estului": "sud-est",
    "sudista": "sudist",
    "sudistă": "sudist",
    "sudiste": "sudist",
    "sudistei": "sudist",
    "sudistele": "sudist",
    "sudistelor": "sudist",
    "sudiști": "sudist",
    "sudiștii": "sudist",
    "sudiștilor": "sudist",
    "sudistul": "sudist",
    "sudistului": "sudist",
    "sudoarea": "sudoare",
    "sudori": "sudoare",
    "sudorii": "sudoare",
    "sudorile": "sudoare",
    "sudorilor": "sudoare",
    "sudori": "sudor",
    "sudorii": "sudor",
    "sudorilor": "sudor",
    "sudorul": "sudor",
    "sudorului": "sudor",
    "sudoripara": "sudoripară",
    "sudoripare": "sudoripară",
    "sudoriparei": "sudoripară",
    "sudoriparele": "sudoripară",
    "sudoriparelor": "sudoripară",
    "sudorița": "sudoriță",
    "sudorițe": "sudoriță",
    "sudoriței": "sudoriță",
    "sudorițele": "sudoriță",
    "sudorițelor": "sudoriță",
    "nemaisuduind": "sudui",
    "nemaisuduindu": "sudui",
    "nesuduind": "sudui",
    "nesuduindu": "sudui",
    "suduia": "sudui",
    "suduiai": "sudui",
    "suduiam": "sudui",
    "suduiați": "sudui",
    "suduiau": "sudui",
    "suduie": "sudui",
    "suduii": "sudui",
    "suduim": "sudui",
    "suduind": "sudui",
    "suduindu": "sudui",
    "suduiră": "sudui",
    "suduirăm": "sudui",
    "suduirăți": "sudui",
    "suduise": "sudui",
    "suduisem": "sudui",
    "suduiseră": "sudui",
    "suduiserăm": "sudui",
    "suduiserăți": "sudui",
    "suduiseși": "sudui",
    "suduiși": "sudui",
    "suduit": "sudui",
    "suduiți": "sudui",
    "suduită": "suduit",
    "suduite": "suduit",
    "suduiți": "suduit",
    "sudura": "sudură",
    "suduri": "sudură",
    "sudurii": "sudură",
    "sudurile": "sudură",
    "sudurilor": "sudură",
    "sud-vestul": "sud-vest",
    "sud-vestului": "sud-vest",
    "suedeza": "suedez",
    "suedeză": "suedez",
    "suedeze": "suedez",
    "suedezei": "suedez",
    "suedezele": "suedez",
    "suedezelor": "suedez",
    "suedezi": "suedez",
    "suedezii": "suedez",
    "suedezilor": "suedez",
    "suedezul": "suedez",
    "suedezului": "suedez",
    "suedeza": "suedeză",
    "suedeze": "suedeză",
    "suedezei": "suedeză",
    "suedezele": "suedeză",
    "suedezelor": "suedeză",
    "Suediei": "Suedia",
    "șueta": "șuetă",
    "șuete": "șuetă",
    "șuetei": "șuetă",
    "șuetele": "șuetă",
    "șuetelor": "șuetă",
    "nemaisuferind": "suferi",
    "nemaisuferindu": "suferi",
    "nesuferind": "suferi",
    "nesuferindu": "suferi",
    "sufăr": "suferi",
    "suferă": "suferi",
    "sufere": "suferi",
    "suferea": "suferi",
    "sufereai": "suferi",
    "sufeream": "suferi",
    "sufereați": "suferi",
    "sufereau": "suferi",
    "suferii": "suferi",
    "suferim": "suferi",
    "suferind": "suferi",
    "suferindu": "suferi",
    "suferiră": "suferi",
    "suferirăm": "suferi",
    "suferirăți": "suferi",
    "suferise": "suferi",
    "suferisem": "suferi",
    "suferiseră": "suferi",
    "suferiserăm": "suferi",
    "suferiserăți": "suferi",
    "suferiseși": "suferi",
    "suferiși": "suferi",
    "suferit": "suferi",
    "suferiți": "suferi",
    "suferinda": "suferind",
    "suferindă": "suferind",
    "suferinde": "suferind",
    "suferindei": "suferind",
    "suferindele": "suferind",
    "suferindelor": "suferind",
    "suferindul": "suferind",
    "suferindului": "suferind",
    "suferinzi": "suferind",
    "suferinzii": "suferind",
    "suferinzilor": "suferind",
    "suferinda": "suferindă",
    "suferinde": "suferindă",
    "suferindei": "suferindă",
    "suferindele": "suferindă",
    "suferindelor": "suferindă",
    "suferința": "suferință",
    "suferințe": "suferință",
    "suferinței": "suferință",
    "suferințele": "suferință",
    "suferințelor": "suferință",
    "suferită": "suferit",
    "suferite": "suferit",
    "suferiți": "suferit",
    "suferitori": "suferitor",
    "suferitorii": "suferitor",
    "suferitorilor": "suferitor",
    "suferitorul": "suferitor",
    "suferitorului": "suferitor",
    "sufertașe": "sufertaș",
    "sufertașele": "sufertaș",
    "sufertașelor": "sufertaș",
    "sufertașul": "sufertaș",
    "sufertașului": "sufertaș",
    "suficienta": "suficient",
    "suficientă": "suficient",
    "suficiente": "suficient",
    "suficientei": "suficient",
    "suficientele": "suficient",
    "suficientelor": "suficient",
    "suficienți": "suficient",
    "suficienții": "suficient",
    "suficienților": "suficient",
    "suficientul": "suficient",
    "suficientului": "suficient",
    "suficiența": "suficiență",
    "suficiențe": "suficiență",
    "suficienței": "suficiență",
    "suficiențele": "suficiență",
    "suficiențelor": "suficiență",
    "sufisme": "sufism",
    "sufismele": "sufism",
    "sufismelor": "sufism",
    "sufismul": "sufism",
    "sufismului": "sufism",
    "sufitul": "sufit",
    "sufitului": "sufit",
    "sufituri": "sufit",
    "sufiturile": "sufit",
    "sufiturilor": "sufit",
    "sufita": "sufită",
    "sufite": "sufită",
    "sufitei": "sufită",
    "sufitele": "sufită",
    "sufitelor": "sufită",
    "suf.": "sufix",
    "sufixe": "sufix",
    "sufixele": "sufix",
    "sufixelor": "sufix",
    "sufixul": "sufix",
    "sufixului": "sufix",
    "nemaisufixând": "sufixa",
    "nemaisufixându": "sufixa",
    "nesufixând": "sufixa",
    "nesufixându": "sufixa",
    "sufixă": "sufixa",
    "sufixai": "sufixa",
    "sufixam": "sufixa",
    "sufixăm": "sufixa",
    "sufixând": "sufixa",
    "sufixându": "sufixa",
    "sufixară": "sufixa",
    "sufixarăm": "sufixa",
    "sufixarăți": "sufixa",
    "sufixase": "sufixa",
    "sufixasem": "sufixa",
    "sufixaseră": "sufixa",
    "sufixaserăm": "sufixa",
    "sufixaserăți": "sufixa",
    "sufixaseși": "sufixa",
    "sufixași": "sufixa",
    "sufixat": "sufixa",
    "sufixați": "sufixa",
    "sufixau": "sufixa",
    "sufixează": "sufixa",
    "sufixez": "sufixa",
    "sufixeze": "sufixa",
    "sufixezi": "sufixa",
    "sufixată": "sufixat",
    "sufixate": "sufixat",
    "sufixați": "sufixat",
    "nemaisuflând": "sufla",
    "nemaisuflându": "sufla",
    "nesuflând": "sufla",
    "nesuflându": "sufla",
    "suflă": "sufla",
    "suflai": "sufla",
    "suflam": "sufla",
    "suflăm": "sufla",
    "suflând": "sufla",
    "suflându": "sufla",
    "suflară": "sufla",
    "suflarăm": "sufla",
    "suflarăți": "sufla",
    "suflase": "sufla",
    "suflasem": "sufla",
    "suflaseră": "sufla",
    "suflaserăm": "sufla",
    "suflaserăți": "sufla",
    "suflaseși": "sufla",
    "suflași": "sufla",
    "suflat": "sufla",
    "suflați": "sufla",
    "suflau": "sufla",
    "sufle": "sufla",
    "sufli": "sufla",
    "suflu": "sufla",
    "suflaiul": "suflai",
    "suflaiului": "suflai",
    "suflaiuri": "suflai",
    "suflaiurile": "suflai",
    "suflaiurilor": "suflai",
    "suflanta": "suflantă",
    "suflante": "suflantă",
    "suflantei": "suflantă",
    "suflantele": "suflantă",
    "suflantelor": "suflantă",
    "suflarea": "suflare",
    "suflareo": "suflare",
    "suflări": "suflare",
    "suflării": "suflare",
    "suflările": "suflare",
    "suflărilor": "suflare",
    "suflată": "suflat",
    "suflate": "suflat",
    "suflați": "suflat",
    "suflatul": "suflat",
    "suflatului": "suflat",
    "suflătoare": "suflător",
    "suflătoarele": "suflător",
    "suflătoarelor": "suflător",
    "suflători": "suflător",
    "suflătorii": "suflător",
    "suflătorilor": "suflător",
    "suflătorul": "suflător",
    "suflătorului": "suflător",
    "nemaisuflecând": "sufleca",
    "nemaisuflecându": "sufleca",
    "nesuflecând": "sufleca",
    "nesuflecându": "sufleca",
    "suflec": "sufleca",
    "suflecă": "sufleca",
    "suflecai": "sufleca",
    "suflecam": "sufleca",
    "suflecăm": "sufleca",
    "suflecând": "sufleca",
    "suflecându": "sufleca",
    "suflecară": "sufleca",
    "suflecarăm": "sufleca",
    "suflecarăți": "sufleca",
    "suflecase": "sufleca",
    "suflecasem": "sufleca",
    "suflecaseră": "sufleca",
    "suflecaserăm": "sufleca",
    "suflecaserăți": "sufleca",
    "suflecaseși": "sufleca",
    "suflecași": "sufleca",
    "suflecat": "sufleca",
    "suflecați": "sufleca",
    "suflecau": "sufleca",
    "suflece": "sufleca",
    "sufleci": "sufleca",
    "suflecarea": "suflecare",
    "suflecareo": "suflecare",
    "suflecări": "suflecare",
    "suflecării": "suflecare",
    "suflecările": "suflecare",
    "suflecărilor": "suflecare",
    "suflecata": "suflecat",
    "suflecată": "suflecat",
    "suflecate": "suflecat",
    "suflecatei": "suflecat",
    "suflecatele": "suflecat",
    "suflecatelor": "suflecat",
    "suflecați": "suflecat",
    "suflecații": "suflecat",
    "suflecaților": "suflecat",
    "suflecato": "suflecat",
    "suflecatul": "suflecat",
    "suflecatule": "suflecat",
    "suflecatului": "suflecat",
    "sufleori": "sufleor",
    "sufleorii": "sufleor",
    "sufleorilor": "sufleor",
    "sufleorul": "sufleor",
    "sufleorului": "sufleor",
    "suflete": "suflet",
    "sufletele": "suflet",
    "sufletelor": "suflet",
    "sufletu": "suflet",
    "sufletu'": "suflet",
    "sufletul": "suflet",
    "sufletului": "suflet",
    "sufleteasca": "sufletesc",
    "sufletească": "sufletesc",
    "sufletescul": "sufletesc",
    "sufletescului": "sufletesc",
    "sufletești": "sufletesc",
    "sufleteștii": "sufletesc",
    "sufleteștile": "sufletesc",
    "sufleteștilor": "sufletesc",
    "sufleul": "sufleu",
    "sufleului": "sufleu",
    "sufleuri": "sufleu",
    "sufleurile": "sufleu",
    "sufleurilor": "sufleu",
    "suflul": "suflu",
    "suflului": "suflu",
    "sufluri": "suflu",
    "suflurile": "suflu",
    "suflurilor": "suflu",
    "suflura": "suflură",
    "sufluri": "suflură",
    "suflurii": "suflură",
    "suflurile": "suflură",
    "suflurilor": "suflură",
    "nemaisufocând": "sufoca",
    "nemaisufocându": "sufoca",
    "nesufocând": "sufoca",
    "nesufocându": "sufoca",
    "sufoc": "sufoca",
    "sufocă": "sufoca",
    "sufocai": "sufoca",
    "sufocam": "sufoca",
    "sufocăm": "sufoca",
    "sufocând": "sufoca",
    "sufocându": "sufoca",
    "sufocară": "sufoca",
    "sufocarăm": "sufoca",
    "sufocarăți": "sufoca",
    "sufocase": "sufoca",
    "sufocasem": "sufoca",
    "sufocaseră": "sufoca",
    "sufocaserăm": "sufoca",
    "sufocaserăți": "sufoca",
    "sufocaseși": "sufoca",
    "sufocași": "sufoca",
    "sufocat": "sufoca",
    "sufocați": "sufoca",
    "sufocau": "sufoca",
    "sufoce": "sufoca",
    "sufoci": "sufoca",
    "sufocanta": "sufocant",
    "sufocantă": "sufocant",
    "sufocante": "sufocant",
    "sufocantei": "sufocant",
    "sufocantele": "sufocant",
    "sufocantelor": "sufocant",
    "sufocantul": "sufocant",
    "sufocantului": "sufocant",
    "sufocarea": "sufocare",
    "sufocareo": "sufocare",
    "sufocări": "sufocare",
    "sufocării": "sufocare",
    "sufocările": "sufocare",
    "sufocărilor": "sufocare",
    "sufocata": "sufocat",
    "sufocată": "sufocat",
    "sufocate": "sufocat",
    "sufocatei": "sufocat",
    "sufocatele": "sufocat",
    "sufocatelor": "sufocat",
    "sufocați": "sufocat",
    "sufocații": "sufocat",
    "sufocaților": "sufocat",
    "sufocato": "sufocat",
    "sufocatul": "sufocat",
    "sufocatule": "sufocat",
    "sufocatului": "sufocat",
    "sufrageria": "sufragerie",
    "sufrageriei": "sufragerie",
    "sufragerii": "sufragerie",
    "sufrageriile": "sufragerie",
    "sufrageriilor": "sufragerie",
    "sufragii": "sufragiu",
    "sufragiile": "sufragiu",
    "sufragiilor": "sufragiu",
    "sufragiul": "sufragiu",
    "sufragiului": "sufragiu",
    "sugace": "sugaci",
    "sugacea": "sugaci",
    "sugacei": "sugaci",
    "sugacele": "sugaci",
    "sugacelor": "sugaci",
    "sugacii": "sugaci",
    "sugacilor": "sugaci",
    "sugaciul": "sugaci",
    "sugaciului": "sugaci",
    "sugari": "sugar",
    "sugarii": "sugar",
    "sugarilor": "sugar",
    "sugarul": "sugar",
    "sugarului": "sugar",
    "sugativa": "sugativă",
    "sugative": "sugativă",
    "sugativei": "sugativă",
    "sugativele": "sugativă",
    "sugativelor": "sugativă",
    "sugătoarea": "sugătoare",
    "sugătoarele": "sugătoare",
    "sugătoarelor": "sugătoare",
    "sugători": "sugătoare",
    "sugătorii": "sugătoare",
    "nemaisugând": "suge",
    "nemaisugându": "suge",
    "nesugând": "suge",
    "nesugându": "suge",
    "sug": "suge",
    "sugă": "suge",
    "sugând": "suge",
    "sugându": "suge",
    "sugea": "suge",
    "sugeai": "suge",
    "sugeam": "suge",
    "sugeați": "suge",
    "sugeau": "suge",
    "sugem": "suge",
    "sugeți": "suge",
    "sugi": "suge",
    "supse": "suge",
    "supsei": "suge",
    "supseră": "suge",
    "supserăm": "suge",
    "supserăți": "suge",
    "supsese": "suge",
    "supsesem": "suge",
    "supseseră": "suge",
    "supseserăm": "suge",
    "supseserăți": "suge",
    "supseseși": "suge",
    "supseși": "suge",
    "supt": "suge",
    "nemaisugerând": "sugera",
    "nemaisugerându": "sugera",
    "nesugerând": "sugera",
    "nesugerându": "sugera",
    "sugeră": "sugera",
    "sugerai": "sugera",
    "sugeram": "sugera",
    "sugerăm": "sugera",
    "sugerând": "sugera",
    "sugerându": "sugera",
    "sugerară": "sugera",
    "sugerarăm": "sugera",
    "sugerarăți": "sugera",
    "sugerase": "sugera",
    "sugerasem": "sugera",
    "sugeraseră": "sugera",
    "sugeraserăm": "sugera",
    "sugeraserăți": "sugera",
    "sugeraseși": "sugera",
    "sugerași": "sugera",
    "sugerat": "sugera",
    "sugerați": "sugera",
    "sugerau": "sugera",
    "sugerează": "sugera",
    "sugerez": "sugera",
    "sugereze": "sugera",
    "sugerezi": "sugera",
    "sugerarea": "sugerare",
    "sugerareo": "sugerare",
    "sugerări": "sugerare",
    "sugerării": "sugerare",
    "sugerările": "sugerare",
    "sugerărilor": "sugerare",
    "sugerată": "sugerat",
    "sugerate": "sugerat",
    "sugerați": "sugerat",
    "sugestibilitatea": "sugestibilitate",
    "sugestibilități": "sugestibilitate",
    "sugestibilității": "sugestibilitate",
    "sugestibilitățile": "sugestibilitate",
    "sugestibilităților": "sugestibilitate",
    "sugestia": "sugestie",
    "sugestiei": "sugestie",
    "sugestii": "sugestie",
    "sugestiile": "sugestie",
    "sugestiilor": "sugestie",
    "nemaisugestionând": "sugestiona",
    "nemaisugestionându": "sugestiona",
    "nesugestionând": "sugestiona",
    "nesugestionându": "sugestiona",
    "sugestionă": "sugestiona",
    "sugestionai": "sugestiona",
    "sugestionam": "sugestiona",
    "sugestionăm": "sugestiona",
    "sugestionând": "sugestiona",
    "sugestionându": "sugestiona",
    "sugestionară": "sugestiona",
    "sugestionarăm": "sugestiona",
    "sugestionarăți": "sugestiona",
    "sugestionase": "sugestiona",
    "sugestionasem": "sugestiona",
    "sugestionaseră": "sugestiona",
    "sugestionaserăm": "sugestiona",
    "sugestionaserăți": "sugestiona",
    "sugestionaseși": "sugestiona",
    "sugestionași": "sugestiona",
    "sugestionat": "sugestiona",
    "sugestionați": "sugestiona",
    "sugestionau": "sugestiona",
    "sugestionează": "sugestiona",
    "sugestionez": "sugestiona",
    "sugestioneze": "sugestiona",
    "sugestionezi": "sugestiona",
    "sugestionată": "sugestionat",
    "sugestionate": "sugestionat",
    "sugestionați": "sugestionat",
    "sugestiva": "sugestiv",
    "sugestivă": "sugestiv",
    "sugestive": "sugestiv",
    "sugestivei": "sugestiv",
    "sugestivele": "sugestiv",
    "sugestivelor": "sugestiv",
    "sugestivi": "sugestiv",
    "sugestivii": "sugestiv",
    "sugestivilor": "sugestiv",
    "sugestivul": "sugestiv",
    "sugestivului": "sugestiv",
    "sughițul": "sughiț",
    "sughițului": "sughiț",
    "sughițuri": "sughiț",
    "sughițurile": "sughiț",
    "sughițurilor": "sughiț",
    "nemaisughițând": "sughița",
    "nemaisughițându": "sughița",
    "nesughițând": "sughița",
    "nesughițându": "sughița",
    "sughiț": "sughița",
    "sughiță": "sughița",
    "sughițai": "sughița",
    "sughițam": "sughița",
    "sughițăm": "sughița",
    "sughițând": "sughița",
    "sughițându": "sughița",
    "sughițară": "sughița",
    "sughițarăm": "sughița",
    "sughițarăți": "sughița",
    "sughițase": "sughița",
    "sughițasem": "sughița",
    "sughițaseră": "sughița",
    "sughițaserăm": "sughița",
    "sughițaserăți": "sughița",
    "sughițaseși": "sughița",
    "sughițași": "sughița",
    "sughițat": "sughița",
    "sughițați": "sughița",
    "sughițau": "sughița",
    "sughițe": "sughița",
    "sughiți": "sughița",
    "sughițată": "sughițat",
    "sughițate": "sughițat",
    "sughițați": "sughițat",
    "sugiucul": "sugiuc",
    "sugiucului": "sugiuc",
    "sugiucuri": "sugiuc",
    "sugiucurile": "sugiuc",
    "sugiucurilor": "sugiuc",
    "nemaisugrumând": "sugruma",
    "nemaisugrumându": "sugruma",
    "nesugrumând": "sugruma",
    "nesugrumându": "sugruma",
    "sugrum": "sugruma",
    "sugrumă": "sugruma",
    "sugrumai": "sugruma",
    "sugrumam": "sugruma",
    "sugrumăm": "sugruma",
    "sugrumând": "sugruma",
    "sugrumându": "sugruma",
    "sugrumară": "sugruma",
    "sugrumarăm": "sugruma",
    "sugrumarăți": "sugruma",
    "sugrumase": "sugruma",
    "sugrumasem": "sugruma",
    "sugrumaseră": "sugruma",
    "sugrumaserăm": "sugruma",
    "sugrumaserăți": "sugruma",
    "sugrumaseși": "sugruma",
    "sugrumași": "sugruma",
    "sugrumat": "sugruma",
    "sugrumați": "sugruma",
    "sugrumau": "sugruma",
    "sugrume": "sugruma",
    "sugrumi": "sugruma",
    "sugrumarea": "sugrumare",
    "sugrumareo": "sugrumare",
    "sugrumări": "sugrumare",
    "sugrumării": "sugrumare",
    "sugrumările": "sugrumare",
    "sugrumărilor": "sugrumare",
    "sugrumata": "sugrumat",
    "sugrumată": "sugrumat",
    "sugrumate": "sugrumat",
    "sugrumatei": "sugrumat",
    "sugrumatele": "sugrumat",
    "sugrumatelor": "sugrumat",
    "sugrumați": "sugrumat",
    "sugrumații": "sugrumat",
    "sugrumaților": "sugrumat",
    "sugrumato": "sugrumat",
    "sugrumatul": "sugrumat",
    "sugrumatule": "sugrumat",
    "sugrumatului": "sugrumat",
    "sugrumătura": "sugrumătură",
    "sugrumături": "sugrumătură",
    "sugrumăturii": "sugrumătură",
    "sugrumăturile": "sugrumătură",
    "sugrumăturilor": "sugrumătură",
    "șugubățul": "șugubăț",
    "șugubățului": "șugubăț",
    "șugubeața": "șugubăț",
    "șugubeață": "șugubăț",
    "șugubețe": "șugubăț",
    "șugubeței": "șugubăț",
    "șugubețele": "șugubăț",
    "șugubețelor": "șugubăț",
    "șugubeți": "șugubăț",
    "șugubeții": "șugubăț",
    "șugubeților": "șugubăț",
    "șugubeți": "șugubeț",
    "șugubeții": "șugubeț",
    "șugubeților": "șugubeț",
    "șugubețul": "șugubeț",
    "șugubețului": "șugubeț",
    "șuguia": "șugui",
    "șuguiai": "șugui",
    "șuguiam": "șugui",
    "șuguiați": "șugui",
    "șuguiau": "șugui",
    "șuguie": "șugui",
    "șuguii": "șugui",
    "șuguim": "șugui",
    "șuguind": "șugui",
    "șuguindu": "șugui",
    "șuguiră": "șugui",
    "șuguirăm": "șugui",
    "șuguirăți": "șugui",
    "șuguise": "șugui",
    "șuguisem": "șugui",
    "șuguiseră": "șugui",
    "șuguiserăm": "șugui",
    "șuguiserăți": "șugui",
    "șuguiseși": "șugui",
    "șuguiși": "șugui",
    "șuguit": "șugui",
    "șuguiți": "șugui",
    "șuguitu": "șugui",
    "șuguită": "șuguit",
    "șuguite": "șuguit",
    "șuguiți": "șuguit",
    "suhatul": "suhat",
    "suhatului": "suhat",
    "suhaturi": "suhat",
    "suhaturile": "suhat",
    "suhaturilor": "suhat",
    "nemaisuind": "sui",
    "nemaisuindu": "sui",
    "nesuind": "sui",
    "nesuindu": "sui",
    "suia": "sui",
    "suiai": "sui",
    "suiam": "sui",
    "suiați": "sui",
    "suiau": "sui",
    "suie": "sui",
    "suii": "sui",
    "suim": "sui",
    "suind": "sui",
    "suindu": "sui",
    "suiră": "sui",
    "suirăm": "sui",
    "suirăți": "sui",
    "suise": "sui",
    "suisem": "sui",
    "suiseră": "sui",
    "suiserăm": "sui",
    "suiserăți": "sui",
    "suiseși": "sui",
    "suiși": "sui",
    "suit": "sui",
    "suiți": "sui",
    "șuia": "șui",
    "șuie": "șui",
    "șuiei": "șui",
    "șuiele": "șui",
    "șuielor": "șui",
    "șuii": "șui",
    "șuilor": "șui",
    "șuiul": "șui",
    "șuiului": "șui",
    "suicidul": "suicid",
    "suicidului": "suicid",
    "șuiere": "șuier",
    "șuierele": "șuier",
    "șuierelor": "șuier",
    "șuierul": "șuier",
    "șuierului": "șuier",
    "nemaișuierând": "șuiera",
    "nemaișuierându": "șuiera",
    "neșuierând": "șuiera",
    "neșuierându": "șuiera",
    "șuier": "șuiera",
    "șuieră": "șuiera",
    "șuierai": "șuiera",
    "șuieram": "șuiera",
    "șuierăm": "șuiera",
    "șuierând": "șuiera",
    "șuierându": "șuiera",
    "șuierară": "șuiera",
    "șuierarăm": "șuiera",
    "șuierarăți": "șuiera",
    "șuierase": "șuiera",
    "șuierasem": "șuiera",
    "șuieraseră": "șuiera",
    "șuieraserăm": "șuiera",
    "șuieraserăți": "șuiera",
    "șuieraseși": "șuiera",
    "șuierași": "șuiera",
    "șuierat": "șuiera",
    "șuierați": "șuiera",
    "șuierau": "șuiera",
    "șuiere": "șuiera",
    "șuieri": "șuiera",
    "șuierarea": "șuierare",
    "șuierareo": "șuierare",
    "șuierări": "șuierare",
    "șuierării": "șuierare",
    "șuierările": "șuierare",
    "șuierărilor": "șuierare",
    "șuierata": "șuierat",
    "șuierată": "șuierat",
    "șuierate": "șuierat",
    "șuieratei": "șuierat",
    "șuieratele": "șuierat",
    "șuieratelor": "șuierat",
    "șuierați": "șuierat",
    "șuierații": "șuierat",
    "șuieraților": "șuierat",
    "șuierato": "șuierat",
    "șuieratul": "șuierat",
    "șuieratule": "șuierat",
    "șuieratului": "șuierat",
    "șuierătoare": "șuierător",
    "șuierătoarea": "șuierător",
    "șuierătoarei": "șuierător",
    "șuierătoarele": "șuierător",
    "șuierătoarelor": "șuierător",
    "șuierători": "șuierător",
    "șuierătorii": "șuierător",
    "șuierătorilor": "șuierător",
    "șuierătorul": "șuierător",
    "șuierătorului": "șuierător",
    "șuierătura": "șuierătură",
    "șuierături": "șuierătură",
    "șuierăturii": "șuierătură",
    "șuierăturile": "șuierătură",
    "șuierăturilor": "șuierătură",
    "șuierăturo": "șuierătură",
    "suișul": "suiș",
    "suișului": "suiș",
    "suișuri": "suiș",
    "suișurile": "suiș",
    "suișurilor": "suiș",
    "suită": "suit",
    "suite": "suit",
    "suiți": "suit",
    "suitul": "suit",
    "suitului": "suit",
    "suita": "suită",
    "suite": "suită",
    "suitei": "suită",
    "suitele": "suită",
    "suitelor": "suită",
    "sulul": "sul",
    "sulului": "sul",
    "suluri": "sul",
    "sulurile": "sul",
    "sulurilor": "sul",
    "sula": "sulă",
    "sule": "sulă",
    "sulei": "sulă",
    "sulele": "sulă",
    "sulelor": "sulă",
    "nemaisulemenind": "sulemeni",
    "nemaisulemenindu": "sulemeni",
    "nesulemenind": "sulemeni",
    "nesulemenindu": "sulemeni",
    "sulemenea": "sulemeni",
    "sulemeneai": "sulemeni",
    "sulemeneam": "sulemeni",
    "sulemenească": "sulemeni",
    "sulemeneați": "sulemeni",
    "sulemeneau": "sulemeni",
    "sulemenesc": "sulemeni",
    "sulemenește": "sulemeni",
    "sulemenești": "sulemeni",
    "sulemenii": "sulemeni",
    "sulemenim": "sulemeni",
    "sulemenind": "sulemeni",
    "sulemenindu": "sulemeni",
    "sulemeniră": "sulemeni",
    "sulemenirăm": "sulemeni",
    "sulemenirăți": "sulemeni",
    "sulemenise": "sulemeni",
    "sulemenisem": "sulemeni",
    "sulemeniseră": "sulemeni",
    "sulemeniserăm": "sulemeni",
    "sulemeniserăți": "sulemeni",
    "sulemeniseși": "sulemeni",
    "sulemeniși": "sulemeni",
    "sulemenit": "sulemeni",
    "sulemeniți": "sulemeni",
    "sulemenita": "sulemenit",
    "sulemenită": "sulemenit",
    "sulemenite": "sulemenit",
    "sulemenitei": "sulemenit",
    "sulemenitele": "sulemenit",
    "sulemenitelor": "sulemenit",
    "sulemeniți": "sulemenit",
    "sulemeniții": "sulemenit",
    "sulemeniților": "sulemenit",
    "sulemenitul": "sulemenit",
    "sulemenitului": "sulemenit",
    "S": "sulf",
    "sulful": "sulf",
    "sulfului": "sulf",
    "sulfamida": "sulfamidă",
    "sulfamide": "sulfamidă",
    "sulfamidei": "sulfamidă",
    "sulfamidele": "sulfamidă",
    "sulfamidelor": "sulfamidă",
    "sulfați": "sulfat",
    "sulfații": "sulfat",
    "sulfaților": "sulfat",
    "sulfatul": "sulfat",
    "sulfatului": "sulfat",
    "nemaisulfatând": "sulfata",
    "nemaisulfatându": "sulfata",
    "nesulfatând": "sulfata",
    "nesulfatându": "sulfata",
    "sulfată": "sulfata",
    "sulfatai": "sulfata",
    "sulfatam": "sulfata",
    "sulfatăm": "sulfata",
    "sulfatând": "sulfata",
    "sulfatându": "sulfata",
    "sulfatară": "sulfata",
    "sulfatarăm": "sulfata",
    "sulfatarăți": "sulfata",
    "sulfatase": "sulfata",
    "sulfatasem": "sulfata",
    "sulfataseră": "sulfata",
    "sulfataserăm": "sulfata",
    "sulfataserăți": "sulfata",
    "sulfataseși": "sulfata",
    "sulfatași": "sulfata",
    "sulfatat": "sulfata",
    "sulfatați": "sulfata",
    "sulfatau": "sulfata",
    "sulfatează": "sulfata",
    "sulfatez": "sulfata",
    "sulfateze": "sulfata",
    "sulfatezi": "sulfata",
    "sulfatată": "sulfatat",
    "sulfatate": "sulfatat",
    "sulfatați": "sulfatat",
    "sulfhidrica": "sulfhidric",
    "sulfhidrică": "sulfhidric",
    "sulfhidrice": "sulfhidric",
    "sulfhidricei": "sulfhidric",
    "sulfhidricele": "sulfhidric",
    "sulfhidricelor": "sulfhidric",
    "sulfhidrici": "sulfhidric",
    "sulfhidricii": "sulfhidric",
    "sulfhidricilor": "sulfhidric",
    "sulfhidricul": "sulfhidric",
    "sulfhidricului": "sulfhidric",
    "sulfina": "sulfină",
    "sulfine": "sulfină",
    "sulfinei": "sulfină",
    "sulfinele": "sulfină",
    "sulfinelor": "sulfină",
    "sulfiți": "sulfit",
    "sulfiții": "sulfit",
    "sulfiților": "sulfit",
    "sulfitul": "sulfit",
    "sulfitului": "sulfit",
    "sulfitarea": "sulfitare",
    "sulfitări": "sulfitare",
    "sulfitării": "sulfitare",
    "sulfitările": "sulfitare",
    "sulfitărilor": "sulfitare",
    "nemaisulfurând": "sulfura",
    "nemaisulfurându": "sulfura",
    "nesulfurând": "sulfura",
    "nesulfurându": "sulfura",
    "sulfură": "sulfura",
    "sulfurai": "sulfura",
    "sulfuram": "sulfura",
    "sulfurăm": "sulfura",
    "sulfurând": "sulfura",
    "sulfurându": "sulfura",
    "sulfurară": "sulfura",
    "sulfurarăm": "sulfura",
    "sulfurarăți": "sulfura",
    "sulfurase": "sulfura",
    "sulfurasem": "sulfura",
    "sulfuraseră": "sulfura",
    "sulfuraserăm": "sulfura",
    "sulfuraserăți": "sulfura",
    "sulfuraseși": "sulfura",
    "sulfurași": "sulfura",
    "sulfurat": "sulfura",
    "sulfurați": "sulfura",
    "sulfurau": "sulfura",
    "sulfurează": "sulfura",
    "sulfurez": "sulfura",
    "sulfureze": "sulfura",
    "sulfurezi": "sulfura",
    "sulfura": "sulfură",
    "sulfuri": "sulfură",
    "sulfurii": "sulfură",
    "sulfurile": "sulfură",
    "sulfurilor": "sulfură",
    "sulfurată": "sulfurat",
    "sulfurate": "sulfurat",
    "sulfurați": "sulfurat",
    "sulfurica": "sulfuric",
    "sulfurică": "sulfuric",
    "sulfurice": "sulfuric",
    "sulfuricei": "sulfuric",
    "sulfuricele": "sulfuric",
    "sulfuricelor": "sulfuric",
    "sulfurici": "sulfuric",
    "sulfuricii": "sulfuric",
    "sulfuricilor": "sulfuric",
    "sulfuricul": "sulfuric",
    "sulfuricului": "sulfuric",
    "sulfuroasa": "sulfuros",
    "sulfuroasă": "sulfuros",
    "sulfuroase": "sulfuros",
    "sulfuroasei": "sulfuros",
    "sulfuroasele": "sulfuros",
    "sulfuroaselor": "sulfuros",
    "sulfuroși": "sulfuros",
    "sulfuroșii": "sulfuros",
    "sulfuroșilor": "sulfuros",
    "sulfurosul": "sulfuros",
    "sulfurosului": "sulfuros",
    "sulimanul": "suliman",
    "sulimanului": "suliman",
    "sulimanuri": "suliman",
    "sulimanurile": "suliman",
    "sulimanurilor": "suliman",
    "nemaisulimenind": "sulimeni",
    "nemaisulimenindu": "sulimeni",
    "nesulimenind": "sulimeni",
    "nesulimenindu": "sulimeni",
    "sulimenea": "sulimeni",
    "sulimeneai": "sulimeni",
    "sulimeneam": "sulimeni",
    "sulimenească": "sulimeni",
    "sulimeneați": "sulimeni",
    "sulimeneau": "sulimeni",
    "sulimenesc": "sulimeni",
    "sulimenește": "sulimeni",
    "sulimenești": "sulimeni",
    "sulimenii": "sulimeni",
    "sulimenim": "sulimeni",
    "sulimenind": "sulimeni",
    "sulimenindu": "sulimeni",
    "sulimeniră": "sulimeni",
    "sulimenirăm": "sulimeni",
    "sulimenirăți": "sulimeni",
    "sulimenise": "sulimeni",
    "sulimenisem": "sulimeni",
    "sulimeniseră": "sulimeni",
    "sulimeniserăm": "sulimeni",
    "sulimeniserăți": "sulimeni",
    "sulimeniseși": "sulimeni",
    "sulimeniși": "sulimeni",
    "sulimenit": "sulimeni",
    "sulimeniți": "sulimeni",
    "sulimenită": "sulimenit",
    "sulimenite": "sulimenit",
    "sulimeniți": "sulimenit",
    "sulița": "suliță",
    "sulițe": "suliță",
    "suliței": "suliță",
    "sulițele": "suliță",
    "sulițelor": "suliță",
    "sulițași": "sulițaș",
    "sulițașii": "sulițaș",
    "sulițașilor": "sulițaș",
    "sulițașul": "sulițaș",
    "sulițașului": "sulițaș",
    "sultani": "sultan",
    "sultanii": "sultan",
    "sultanilor": "sultan",
    "sultanul": "sultan",
    "sultanului": "sultan",
    "sultanate": "sultanat",
    "sultanatele": "sultanat",
    "sultanatelor": "sultanat",
    "sultanatul": "sultanat",
    "sultanatului": "sultanat",
    "suma": "sumă",
    "sume": "sumă",
    "sumei": "sumă",
    "sumele": "sumă",
    "sumelor": "sumă",
    "sumane": "suman",
    "sumanele": "suman",
    "sumanelor": "suman",
    "sumanul": "suman",
    "sumanului": "suman",
    "sumara": "sumar",
    "sumară": "sumar",
    "sumare": "sumar",
    "sumarei": "sumar",
    "sumarele": "sumar",
    "sumarelor": "sumar",
    "sumari": "sumar",
    "sumarii": "sumar",
    "sumarilor": "sumar",
    "sumarul": "sumar",
    "sumarului": "sumar",
    "sumbra": "sumbru",
    "sumbră": "sumbru",
    "sumbre": "sumbru",
    "sumbrei": "sumbru",
    "sumbrele": "sumbru",
    "sumbrelor": "sumbru",
    "sumbri": "sumbru",
    "sumbrii": "sumbru",
    "sumbrilor": "sumbru",
    "sumbrul": "sumbru",
    "sumbrului": "sumbru",
    "sumedenia": "sumedenie",
    "sumedeniei": "sumedenie",
    "sumedenii": "sumedenie",
    "sumedeniile": "sumedenie",
    "sumedeniilor": "sumedenie",
    "sumeasa": "sumes",
    "sumeasă": "sumes",
    "sumese": "sumes",
    "sumesei": "sumes",
    "sumesele": "sumes",
    "sumeselor": "sumes",
    "sumeși": "sumes",
    "sumeșii": "sumes",
    "sumeșilor": "sumes",
    "sumesul": "sumes",
    "sumesului": "sumes",
    "nemaisunând": "suna",
    "nemaisunându": "suna",
    "nesunând": "suna",
    "nesunându": "suna",
    "sun": "suna",
    "sună": "suna",
    "sunai": "suna",
    "sunam": "suna",
    "sunăm": "suna",
    "sunând": "suna",
    "sunându": "suna",
    "sunară": "suna",
    "sunarăm": "suna",
    "sunarăți": "suna",
    "sunase": "suna",
    "sunasem": "suna",
    "sunaseră": "suna",
    "sunaserăm": "suna",
    "sunaserăți": "suna",
    "sunaseși": "suna",
    "sunași": "suna",
    "sunat": "suna",
    "sunați": "suna",
    "sunau": "suna",
    "sune": "suna",
    "suni": "suna",
    "sunată": "sunat",
    "sunate": "sunat",
    "sunați": "sunat",
    "sunătoarea": "sunătoare",
    "sunători": "sunătoare",
    "sunătorii": "sunătoare",
    "șunca": "șuncă",
    "șunci": "șuncă",
    "șuncii": "șuncă",
    "șuncile": "șuncă",
    "șuncilor": "șuncă",
    "sunete": "sunet",
    "sunetele": "sunet",
    "sunetelor": "sunet",
    "sunetul": "sunet",
    "sunetului": "sunet",
    "șuntul": "șunt",
    "șuntului": "șunt",
    "șunturi": "șunt",
    "șunturile": "șunt",
    "șunturilor": "șunt",
    "supa": "supă",
    "supe": "supă",
    "supei": "supă",
    "supele": "supă",
    "supelor": "supă",
    "supapa": "supapă",
    "supape": "supapă",
    "supapei": "supapă",
    "supapele": "supapă",
    "supapelor": "supapă",
    "nemaisupărând": "supăra",
    "nemaisupărându": "supăra",
    "nesupărând": "supăra",
    "nesupărându": "supăra",
    "supăr": "supăra",
    "supără": "supăra",
    "supărai": "supăra",
    "supăram": "supăra",
    "supărăm": "supăra",
    "supărând": "supăra",
    "supărându": "supăra",
    "supărară": "supăra",
    "supărarăm": "supăra",
    "supărarăți": "supăra",
    "supărase": "supăra",
    "supărasem": "supăra",
    "supăraseră": "supăra",
    "supăraserăm": "supăra",
    "supăraserăți": "supăra",
    "supăraseși": "supăra",
    "supărași": "supăra",
    "supărat": "supăra",
    "supărați": "supăra",
    "supărau": "supăra",
    "supere": "supăra",
    "superi": "supăra",
    "supărarea": "supărare",
    "supărări": "supărare",
    "supărării": "supărare",
    "supărările": "supărare",
    "supărărilor": "supărare",
    "supărata": "supărat",
    "supărată": "supărat",
    "supărate": "supărat",
    "supăratei": "supărat",
    "supăratele": "supărat",
    "supăratelor": "supărat",
    "supărați": "supărat",
    "supărații": "supărat",
    "supăraților": "supărat",
    "supărato": "supărat",
    "supăratul": "supărat",
    "supăratule": "supărat",
    "supăratului": "supărat",
    "supărătoare": "supărător",
    "supărătoarea": "supărător",
    "supărătoarei": "supărător",
    "supărătoarele": "supărător",
    "supărătoarelor": "supărător",
    "supărători": "supărător",
    "supărătorii": "supărător",
    "supărătorilor": "supărător",
    "supărătorul": "supărător",
    "supărătorului": "supărător",
    "superba": "superb",
    "superbă": "superb",
    "superbe": "superb",
    "superbei": "superb",
    "superbele": "superb",
    "superbelor": "superb",
    "superbi": "superb",
    "superbii": "superb",
    "superbilor": "superb",
    "superbul": "superb",
    "superbului": "superb",
    "superficiala": "superficial",
    "superficială": "superficial",
    "superficiale": "superficial",
    "superficialei": "superficial",
    "superficialele": "superficial",
    "superficialelor": "superficial",
    "superficiali": "superficial",
    "superficialii": "superficial",
    "superficialilor": "superficial",
    "superficialul": "superficial",
    "superficialului": "superficial",
    "superficialitatea": "superficialitate",
    "superficialități": "superficialitate",
    "superficialității": "superficialitate",
    "superficialitățile": "superficialitate",
    "superficialităților": "superficialitate",
    "superfina": "superfin",
    "superfină": "superfin",
    "superfine": "superfin",
    "superfinei": "superfin",
    "superfinele": "superfin",
    "superfinelor": "superfin",
    "superfini": "superfin",
    "superfinii": "superfin",
    "superfinilor": "superfin",
    "superfinul": "superfin",
    "superfinului": "superfin",
    "superflua": "superfluu",
    "superfluă": "superfluu",
    "superflue": "superfluu",
    "superfluei": "superfluu",
    "superfluele": "superfluu",
    "superfluelor": "superfluu",
    "superflui": "superfluu",
    "superfluii": "superfluu",
    "superfluilor": "superfluu",
    "superfluul": "superfluu",
    "superfluului": "superfluu",
    "superfosfați": "superfosfat",
    "superfosfații": "superfosfat",
    "superfosfaților": "superfosfat",
    "superfosfatul": "superfosfat",
    "superfosfatului": "superfosfat",
    "superioara": "superior",
    "superioară": "superior",
    "superioare": "superior",
    "superioarei": "superior",
    "superioarele": "superior",
    "superioarelor": "superior",
    "superiori": "superior",
    "superiorii": "superior",
    "superiorilor": "superior",
    "superiorul": "superior",
    "superiorului": "superior",
    "superioritatea": "superioritate",
    "superiorități": "superioritate",
    "superiorității": "superioritate",
    "superioritățile": "superioritate",
    "superiorităților": "superioritate",
    "superlativa": "superlativ",
    "superlativă": "superlativ",
    "superlative": "superlativ",
    "superlativei": "superlativ",
    "superlativele": "superlativ",
    "superlativelor": "superlativ",
    "superlativi": "superlativ",
    "superlativii": "superlativ",
    "superlativilor": "superlativ",
    "superlativul": "superlativ",
    "superlativului": "superlativ",
    "supernova": "supernovă",
    "supernove": "supernovă",
    "supernovei": "supernovă",
    "supernovele": "supernovă",
    "supernovelor": "supernovă",
    "superputerea": "superputere",
    "superputeri": "superputere",
    "superputerii": "superputere",
    "superputerile": "superputere",
    "superputerilor": "superputere",
    "supersonica": "supersonic",
    "supersonică": "supersonic",
    "supersonice": "supersonic",
    "supersonicei": "supersonic",
    "supersonicele": "supersonic",
    "supersonicelor": "supersonic",
    "supersonici": "supersonic",
    "supersonicii": "supersonic",
    "supersonicilor": "supersonic",
    "supersonicul": "supersonic",
    "supersonicului": "supersonic",
    "superstiția": "superstiție",
    "superstiției": "superstiție",
    "superstiții": "superstiție",
    "superstițiile": "superstiție",
    "superstițiilor": "superstiție",
    "superstițioasa": "superstițios",
    "superstițioasă": "superstițios",
    "superstițioase": "superstițios",
    "superstițioasei": "superstițios",
    "superstițioasele": "superstițios",
    "superstițioaselor": "superstițios",
    "superstițioși": "superstițios",
    "superstițioșii": "superstițios",
    "superstițioșilor": "superstițios",
    "superstițiosul": "superstițios",
    "superstițiosului": "superstițios",
    "superușoară": "superușor",
    "supeul": "supeu",
    "supeului": "supeu",
    "supeuri": "supeu",
    "supeurile": "supeu",
    "supeurilor": "supeu",
    "supiera": "supieră",
    "supiere": "supieră",
    "supierei": "supieră",
    "supierele": "supieră",
    "supierelor": "supieră",
    "supine": "supin",
    "supinele": "supin",
    "supinelor": "supin",
    "supinul": "supin",
    "supinului": "supin",
    "supleanta": "supleant",
    "supleantă": "supleant",
    "supleante": "supleant",
    "supleantei": "supleant",
    "supleantele": "supleant",
    "supleantelor": "supleant",
    "supleanți": "supleant",
    "supleanții": "supleant",
    "supleanților": "supleant",
    "supleantul": "supleant",
    "supleantului": "supleant",
    "supleanta": "supleantă",
    "supleante": "supleantă",
    "supleantei": "supleantă",
    "supleantele": "supleantă",
    "supleantelor": "supleantă",
    "suplețea": "suplețe",
    "supleți": "suplețe",
    "supleții": "suplețe",
    "supletiva": "supletiv",
    "supletivă": "supletiv",
    "supletive": "supletiv",
    "supletivei": "supletiv",
    "supletivele": "supletiv",
    "supletivelor": "supletiv",
    "supletivi": "supletiv",
    "supletivii": "supletiv",
    "supletivilor": "supletiv",
    "supletivul": "supletiv",
    "supletivului": "supletiv",
    "suplicii": "supliciu",
    "supliciile": "supliciu",
    "supliciilor": "supliciu",
    "supliciul": "supliciu",
    "supliciului": "supliciu",
    "suplimente": "supliment",
    "suplimentele": "supliment",
    "suplimentelor": "supliment",
    "suplimentul": "supliment",
    "suplimentului": "supliment",
    "suplimentara": "suplimentar",
    "suplimentară": "suplimentar",
    "suplimentare": "suplimentar",
    "suplimentarei": "suplimentar",
    "suplimentarele": "suplimentar",
    "suplimentarelor": "suplimentar",
    "suplimentari": "suplimentar",
    "suplimentarii": "suplimentar",
    "suplimentarilor": "suplimentar",
    "suplimentarul": "suplimentar",
    "suplimentarului": "suplimentar",
    "suplimentarea": "suplimentare",
    "suplimentări": "suplimentare",
    "suplimentării": "suplimentare",
    "suplimentările": "suplimentare",
    "suplimentărilor": "suplimentare",
    "nemaisuplinind": "suplini",
    "nemaisuplinindu": "suplini",
    "nesuplinind": "suplini",
    "nesuplinindu": "suplini",
    "suplinea": "suplini",
    "suplineai": "suplini",
    "suplineam": "suplini",
    "suplinească": "suplini",
    "suplineați": "suplini",
    "suplineau": "suplini",
    "suplinesc": "suplini",
    "suplinește": "suplini",
    "suplinești": "suplini",
    "suplinii": "suplini",
    "suplinim": "suplini",
    "suplinind": "suplini",
    "suplinindu": "suplini",
    "supliniră": "suplini",
    "suplinirăm": "suplini",
    "suplinirăți": "suplini",
    "suplinise": "suplini",
    "suplinisem": "suplini",
    "supliniseră": "suplini",
    "supliniserăm": "suplini",
    "supliniserăți": "suplini",
    "supliniseși": "suplini",
    "supliniși": "suplini",
    "suplinit": "suplini",
    "supliniți": "suplini",
    "suplinirea": "suplinire",
    "supliniri": "suplinire",
    "suplinirii": "suplinire",
    "suplinirile": "suplinire",
    "suplinirilor": "suplinire",
    "suplinită": "suplinit",
    "suplinite": "suplinit",
    "supliniți": "suplinit",
    "suplinitoarea": "suplinitoare",
    "suplinitoarei": "suplinitoare",
    "suplinitoarele": "suplinitoare",
    "suplinitoarelor": "suplinitoare",
    "suplinitori": "suplinitor",
    "suplinitorii": "suplinitor",
    "suplinitorilor": "suplinitor",
    "suplinitorul": "suplinitor",
    "suplinitorului": "suplinitor",
    "supla": "suplu",
    "suplă": "suplu",
    "suple": "suplu",
    "suplei": "suplu",
    "suplele": "suplu",
    "suplelor": "suplu",
    "supli": "suplu",
    "suplii": "suplu",
    "suplilor": "suplu",
    "suplul": "suplu",
    "suplului": "suplu",
    "suportul": "suport",
    "suportului": "suport",
    "suporturi": "suport",
    "suporturile": "suport",
    "suporturilor": "suport",
    "nemaisuportând": "suporta",
    "nemaisuportându": "suporta",
    "nesuportând": "suporta",
    "nesuportându": "suporta",
    "nesuportat": "suporta",
    "suport": "suporta",
    "suportă": "suporta",
    "suportai": "suporta",
    "suportam": "suporta",
    "suportăm": "suporta",
    "suportând": "suporta",
    "suportându": "suporta",
    "suportară": "suporta",
    "suportarăm": "suporta",
    "suportarăți": "suporta",
    "suportase": "suporta",
    "suportasem": "suporta",
    "suportaseră": "suporta",
    "suportaserăm": "suporta",
    "suportaserăți": "suporta",
    "suportaseși": "suporta",
    "suportași": "suporta",
    "suportat": "suporta",
    "suportați": "suporta",
    "suportau": "suporta",
    "suporte": "suporta",
    "suporți": "suporta",
    "suportabila": "suportabil",
    "suportabilă": "suportabil",
    "suportabile": "suportabil",
    "suportabilei": "suportabil",
    "suportabilele": "suportabil",
    "suportabilelor": "suportabil",
    "suportabili": "suportabil",
    "suportabilii": "suportabil",
    "suportabililor": "suportabil",
    "suportabilul": "suportabil",
    "suportabilului": "suportabil",
    "suportarea": "suportare",
    "suportări": "suportare",
    "suportării": "suportare",
    "suportată": "suportat",
    "suportate": "suportat",
    "suportați": "suportat",
    "suporteri": "suporter",
    "suporterii": "suporter",
    "suporterilor": "suporter",
    "suporterul": "suporter",
    "suporterului": "suporter",
    "supoziția": "supoziție",
    "supoziției": "supoziție",
    "supoziții": "supoziție",
    "supozițiile": "supoziție",
    "supozițiilor": "supoziție",
    "supozitoare": "supozitor",
    "supozitoarele": "supozitor",
    "supozitoarelor": "supozitor",
    "supozitorul": "supozitor",
    "supozitorului": "supozitor",
    "s.s.": "supra_scriptum",
    "supraabundenta": "supraabundent",
    "supraabundentă": "supraabundent",
    "supraabundente": "supraabundent",
    "supraabundentei": "supraabundent",
    "supraabundentele": "supraabundent",
    "supraabundentelor": "supraabundent",
    "supraabundenți": "supraabundent",
    "supraabundenții": "supraabundent",
    "supraabundenților": "supraabundent",
    "supraabundentul": "supraabundent",
    "supraabundentului": "supraabundent",
    "supraaglomerata": "supraaglomerat",
    "supraaglomerată": "supraaglomerat",
    "supraaglomerate": "supraaglomerat",
    "supraaglomeratei": "supraaglomerat",
    "supraaglomeratele": "supraaglomerat",
    "supraaglomeratelor": "supraaglomerat",
    "supraaglomerați": "supraaglomerat",
    "supraaglomerații": "supraaglomerat",
    "supraaglomeraților": "supraaglomerat",
    "supraaglomeratul": "supraaglomerat",
    "supraaglomeratului": "supraaglomerat",
    "nemaisupraalimentând": "supraalimenta",
    "nemaisupraalimentându": "supraalimenta",
    "nesupraalimentând": "supraalimenta",
    "nesupraalimentându": "supraalimenta",
    "supraalimentă": "supraalimenta",
    "supraalimentai": "supraalimenta",
    "supraalimentam": "supraalimenta",
    "supraalimentăm": "supraalimenta",
    "supraalimentând": "supraalimenta",
    "supraalimentându": "supraalimenta",
    "supraalimentară": "supraalimenta",
    "supraalimentarăm": "supraalimenta",
    "supraalimentarăți": "supraalimenta",
    "supraalimentase": "supraalimenta",
    "supraalimentasem": "supraalimenta",
    "supraalimentaseră": "supraalimenta",
    "supraalimentaserăm": "supraalimenta",
    "supraalimentaserăți": "supraalimenta",
    "supraalimentaseși": "supraalimenta",
    "supraalimentași": "supraalimenta",
    "supraalimentat": "supraalimenta",
    "supraalimentați": "supraalimenta",
    "supraalimentau": "supraalimenta",
    "supraalimentează": "supraalimenta",
    "supraalimentez": "supraalimenta",
    "supraalimenteze": "supraalimenta",
    "supraalimentezi": "supraalimenta",
    "supraalimentarea": "supraalimentare",
    "supraalimentări": "supraalimentare",
    "supraalimentării": "supraalimentare",
    "supraalimentările": "supraalimentare",
    "supraalimentărilor": "supraalimentare",
    "supraalimentată": "supraalimentat",
    "supraalimentate": "supraalimentat",
    "supraalimentați": "supraalimentat",
    "supraalimentația": "supraalimentație",
    "supraalimentației": "supraalimentație",
    "supraalimentații": "supraalimentație",
    "supraalimentațiile": "supraalimentație",
    "supraalimentațiilor": "supraalimentație",
    "supracoperta": "supracopertă",
    "supracoperte": "supracopertă",
    "supracopertei": "supracopertă",
    "supracopertele": "supracopertă",
    "supracopertelor": "supracopertă",
    "nemaisupraestimând": "supraestima",
    "nemaisupraestimându": "supraestima",
    "nesupraestimând": "supraestima",
    "nesupraestimându": "supraestima",
    "supraestimă": "supraestima",
    "supraestimai": "supraestima",
    "supraestimam": "supraestima",
    "supraestimăm": "supraestima",
    "supraestimând": "supraestima",
    "supraestimându": "supraestima",
    "supraestimară": "supraestima",
    "supraestimarăm": "supraestima",
    "supraestimarăți": "supraestima",
    "supraestimase": "supraestima",
    "supraestimasem": "supraestima",
    "supraestimaseră": "supraestima",
    "supraestimaserăm": "supraestima",
    "supraestimaserăți": "supraestima",
    "supraestimaseși": "supraestima",
    "supraestimași": "supraestima",
    "supraestimat": "supraestima",
    "supraestimați": "supraestima",
    "supraestimau": "supraestima",
    "supraestimează": "supraestima",
    "supraestimez": "supraestima",
    "supraestimeze": "supraestima",
    "supraestimezi": "supraestima",
    "supraestimată": "supraestimat",
    "supraestimate": "supraestimat",
    "supraestimați": "supraestimat",
    "suprafața": "suprafață",
    "suprafețe": "suprafață",
    "suprafeței": "suprafață",
    "suprafețele": "suprafață",
    "suprafețelor": "suprafață",
    "nemaisupraîncălzind": "supraîncălzi",
    "nemaisupraîncălzindu": "supraîncălzi",
    "nesupraîncălzind": "supraîncălzi",
    "nesupraîncălzindu": "supraîncălzi",
    "supraîncălzea": "supraîncălzi",
    "supraîncălzeai": "supraîncălzi",
    "supraîncălzeam": "supraîncălzi",
    "supraîncălzească": "supraîncălzi",
    "supraîncălzeați": "supraîncălzi",
    "supraîncălzeau": "supraîncălzi",
    "supraîncălzesc": "supraîncălzi",
    "supraîncălzește": "supraîncălzi",
    "supraîncălzești": "supraîncălzi",
    "supraîncălzii": "supraîncălzi",
    "supraîncălzim": "supraîncălzi",
    "supraîncălzind": "supraîncălzi",
    "supraîncălzindu": "supraîncălzi",
    "supraîncălziră": "supraîncălzi",
    "supraîncălzirăm": "supraîncălzi",
    "supraîncălzirăți": "supraîncălzi",
    "supraîncălzise": "supraîncălzi",
    "supraîncălzisem": "supraîncălzi",
    "supraîncălziseră": "supraîncălzi",
    "supraîncălziserăm": "supraîncălzi",
    "supraîncălziserăți": "supraîncălzi",
    "supraîncălziseși": "supraîncălzi",
    "supraîncălziși": "supraîncălzi",
    "supraîncălzit": "supraîncălzi",
    "supraîncălziți": "supraîncălzi",
    "supraîncălzită": "supraîncălzit",
    "supraîncălzite": "supraîncălzit",
    "supraîncălziți": "supraîncălzit",
    "nemaisupraîncărcând": "supraîncărca",
    "nemaisupraîncărcându": "supraîncărca",
    "nesupraîncărcând": "supraîncărca",
    "nesupraîncărcându": "supraîncărca",
    "supraîncarc": "supraîncărca",
    "supraîncarcă": "supraîncărca",
    "supraîncărcă": "supraîncărca",
    "supraîncărcai": "supraîncărca",
    "supraîncărcam": "supraîncărca",
    "supraîncărcăm": "supraîncărca",
    "supraîncărcând": "supraîncărca",
    "supraîncărcându": "supraîncărca",
    "supraîncărcară": "supraîncărca",
    "supraîncărcarăm": "supraîncărca",
    "supraîncărcarăți": "supraîncărca",
    "supraîncărcase": "supraîncărca",
    "supraîncărcasem": "supraîncărca",
    "supraîncărcaseră": "supraîncărca",
    "supraîncărcaserăm": "supraîncărca",
    "supraîncărcaserăți": "supraîncărca",
    "supraîncărcaseși": "supraîncărca",
    "supraîncărcași": "supraîncărca",
    "supraîncărcat": "supraîncărca",
    "supraîncărcați": "supraîncărca",
    "supraîncărcau": "supraîncărca",
    "supraîncarce": "supraîncărca",
    "supraîncarci": "supraîncărca",
    "supraîncărcată": "supraîncărcat",
    "supraîncărcate": "supraîncărcat",
    "supraîncărcați": "supraîncărcat",
    "nemaisupralicitând": "supralicita",
    "nemaisupralicitându": "supralicita",
    "nesupralicitând": "supralicita",
    "nesupralicitându": "supralicita",
    "supralicită": "supralicita",
    "supralicitai": "supralicita",
    "supralicitam": "supralicita",
    "supralicităm": "supralicita",
    "supralicitând": "supralicita",
    "supralicitându": "supralicita",
    "supralicitară": "supralicita",
    "supralicitarăm": "supralicita",
    "supralicitarăți": "supralicita",
    "supralicitase": "supralicita",
    "supralicitasem": "supralicita",
    "supralicitaseră": "supralicita",
    "supralicitaserăm": "supralicita",
    "supralicitaserăți": "supralicita",
    "supralicitaseși": "supralicita",
    "supralicitași": "supralicita",
    "supralicitat": "supralicita",
    "supralicitați": "supralicita",
    "supralicitau": "supralicita",
    "supralicitează": "supralicita",
    "supralicitez": "supralicita",
    "supraliciteze": "supralicita",
    "supralicitezi": "supralicita",
    "supralicitată": "supralicitat",
    "supralicitate": "supralicitat",
    "supralicitați": "supralicitat",
    "supranaturala": "supranatural",
    "supranaturală": "supranatural",
    "supranaturale": "supranatural",
    "supranaturalei": "supranatural",
    "supranaturalele": "supranatural",
    "supranaturalelor": "supranatural",
    "supranaturali": "supranatural",
    "supranaturalii": "supranatural",
    "supranaturalilor": "supranatural",
    "supranaturalul": "supranatural",
    "supranaturalului": "supranatural",
    "supranumele": "supranume",
    "supranumelor": "supranume",
    "supranumelui": "supranume",
    "supranumerara": "supranumerar",
    "supranumerară": "supranumerar",
    "supranumerare": "supranumerar",
    "supranumerarei": "supranumerar",
    "supranumerarele": "supranumerar",
    "supranumerarelor": "supranumerar",
    "supranumerari": "supranumerar",
    "supranumerarii": "supranumerar",
    "supranumerarilor": "supranumerar",
    "supranumerarul": "supranumerar",
    "supranumerarului": "supranumerar",
    "nemaisupranumind": "supranumi",
    "nemaisupranumindu": "supranumi",
    "nesupranumind": "supranumi",
    "nesupranumindu": "supranumi",
    "supranumea": "supranumi",
    "supranumeai": "supranumi",
    "supranumeam": "supranumi",
    "supranumească": "supranumi",
    "supranumeați": "supranumi",
    "supranumeau": "supranumi",
    "supranumesc": "supranumi",
    "supranumește": "supranumi",
    "supranumești": "supranumi",
    "supranumii": "supranumi",
    "supranumim": "supranumi",
    "supranumind": "supranumi",
    "supranumindu": "supranumi",
    "supranumiră": "supranumi",
    "supranumirăm": "supranumi",
    "supranumirăți": "supranumi",
    "supranumise": "supranumi",
    "supranumisem": "supranumi",
    "supranumiseră": "supranumi",
    "supranumiserăm": "supranumi",
    "supranumiserăți": "supranumi",
    "supranumiseși": "supranumi",
    "supranumiși": "supranumi",
    "supranumit": "supranumi",
    "supranumiți": "supranumi",
    "supranumită": "supranumit",
    "supranumite": "supranumit",
    "supranumiți": "supranumit",
    "supraomeneasca": "supraomenesc",
    "supraomenească": "supraomenesc",
    "supraomenescul": "supraomenesc",
    "supraomenescului": "supraomenesc",
    "supraomenești": "supraomenesc",
    "supraomeneștii": "supraomenesc",
    "supraomeneștile": "supraomenesc",
    "supraomeneștilor": "supraomenesc",
    "supraordonata": "supraordonat",
    "supraordonată": "supraordonat",
    "supraordonate": "supraordonat",
    "supraordonatei": "supraordonat",
    "supraordonatele": "supraordonat",
    "supraordonatelor": "supraordonat",
    "supraordonați": "supraordonat",
    "supraordonații": "supraordonat",
    "supraordonaților": "supraordonat",
    "supraordonatul": "supraordonat",
    "supraordonatului": "supraordonat",
    "suprapământeasca": "suprapământesc",
    "suprapământească": "suprapământesc",
    "suprapământescul": "suprapământesc",
    "suprapământescului": "suprapământesc",
    "suprapământești": "suprapământesc",
    "suprapământeștii": "suprapământesc",
    "suprapământeștile": "suprapământesc",
    "suprapământeștilor": "suprapământesc",
    "supraponderala": "supraponderal",
    "supraponderală": "supraponderal",
    "supraponderale": "supraponderal",
    "supraponderalei": "supraponderal",
    "supraponderalele": "supraponderal",
    "supraponderalelor": "supraponderal",
    "supraponderali": "supraponderal",
    "supraponderalii": "supraponderal",
    "supraponderalilor": "supraponderal",
    "supraponderalul": "supraponderal",
    "supraponderalului": "supraponderal",
    "suprapopulata": "suprapopulat",
    "suprapopulată": "suprapopulat",
    "suprapopulate": "suprapopulat",
    "suprapopulatei": "suprapopulat",
    "suprapopulatele": "suprapopulat",
    "suprapopulatelor": "suprapopulat",
    "suprapopulați": "suprapopulat",
    "suprapopulații": "suprapopulat",
    "suprapopulaților": "suprapopulat",
    "suprapopulatul": "suprapopulat",
    "suprapopulatului": "suprapopulat",
    "suprapopulația": "suprapopulație",
    "suprapopulației": "suprapopulație",
    "suprapopulații": "suprapopulație",
    "suprapopulațiile": "suprapopulație",
    "suprapopulațiilor": "suprapopulație",
    "suprapresiunea": "suprapresiune",
    "suprapresiuni": "suprapresiune",
    "suprapresiunii": "suprapresiune",
    "suprapresiunile": "suprapresiune",
    "suprapresiunilor": "suprapresiune",
    "supraprețul": "suprapreț",
    "supraprețului": "suprapreț",
    "supraprețuri": "suprapreț",
    "supraprețurile": "suprapreț",
    "supraprețurilor": "suprapreț",
    "supraproducția": "supraproducție",
    "supraproducției": "supraproducție",
    "supraproducții": "supraproducție",
    "supraproducțiile": "supraproducție",
    "supraproducțiilor": "supraproducție",
    "supraprofitul": "supraprofit",
    "supraprofitului": "supraprofit",
    "supraprofituri": "supraprofit",
    "supraprofiturile": "supraprofit",
    "supraprofiturilor": "supraprofit",
    "nemaisuprapunând": "suprapune",
    "nemaisuprapunându": "suprapune",
    "nesuprapunând": "suprapune",
    "nesuprapunându": "suprapune",
    "suprapui": "suprapune",
    "suprapun": "suprapune",
    "suprapună": "suprapune",
    "suprapunând": "suprapune",
    "suprapunându": "suprapune",
    "suprapunea": "suprapune",
    "suprapuneai": "suprapune",
    "suprapuneam": "suprapune",
    "suprapuneați": "suprapune",
    "suprapuneau": "suprapune",
    "suprapunem": "suprapune",
    "suprapuneți": "suprapune",
    "suprapus": "suprapune",
    "suprapuse": "suprapune",
    "suprapusei": "suprapune",
    "suprapuseră": "suprapune",
    "suprapuserăm": "suprapune",
    "suprapuserăți": "suprapune",
    "suprapusese": "suprapune",
    "suprapusesem": "suprapune",
    "suprapuseseră": "suprapune",
    "suprapuseserăm": "suprapune",
    "suprapuseserăți": "suprapune",
    "suprapuseseși": "suprapune",
    "suprapuseși": "suprapune",
    "suprapunerea": "suprapunere",
    "suprapunereo": "suprapunere",
    "suprapuneri": "suprapunere",
    "suprapunerii": "suprapunere",
    "suprapunerile": "suprapunere",
    "suprapunerilor": "suprapunere",
    "suprapusa": "suprapus",
    "suprapusă": "suprapus",
    "suprapuse": "suprapus",
    "suprapusei": "suprapus",
    "suprapusele": "suprapus",
    "suprapuselor": "suprapus",
    "suprapuși": "suprapus",
    "suprapușii": "suprapus",
    "suprapușilor": "suprapus",
    "suprapusul": "suprapus",
    "suprapusului": "suprapus",
    "suprarealismul": "suprarealism",
    "suprarealismului": "suprarealism",
    "suprarealista": "suprarealist",
    "suprarealistă": "suprarealist",
    "suprarealiste": "suprarealist",
    "suprarealistei": "suprarealist",
    "suprarealistele": "suprarealist",
    "suprarealistelor": "suprarealist",
    "suprarealiști": "suprarealist",
    "suprarealiștii": "suprarealist",
    "suprarealiștilor": "suprarealist",
    "suprarealistul": "suprarealist",
    "suprarealistului": "suprarealist",
    "suprarealista": "suprarealistă",
    "suprarealiste": "suprarealistă",
    "suprarealistei": "suprarealistă",
    "suprarealistele": "suprarealistă",
    "suprarealistelor": "suprarealistă",
    "suprarenala": "suprarenal",
    "suprarenală": "suprarenal",
    "suprarenale": "suprarenal",
    "suprarenalei": "suprarenal",
    "suprarenalele": "suprarenal",
    "suprarenalelor": "suprarenal",
    "suprarenali": "suprarenal",
    "suprarenalii": "suprarenal",
    "suprarenalilor": "suprarenal",
    "suprarenalul": "suprarenal",
    "suprarenalului": "suprarenal",
    "suprasensibila": "suprasensibil",
    "suprasensibilă": "suprasensibil",
    "suprasensibile": "suprasensibil",
    "suprasensibilei": "suprasensibil",
    "suprasensibilele": "suprasensibil",
    "suprasensibilelor": "suprasensibil",
    "suprasensibili": "suprasensibil",
    "suprasensibilii": "suprasensibil",
    "suprasensibililor": "suprasensibil",
    "suprasensibilul": "suprasensibil",
    "suprasensibilului": "suprasensibil",
    "suprastructura": "suprastructură",
    "suprastructuri": "suprastructură",
    "suprastructurii": "suprastructură",
    "suprastructurile": "suprastructură",
    "suprastructurilor": "suprastructură",
    "nemaisuprataxând": "suprataxa",
    "nemaisuprataxându": "suprataxa",
    "nesuprataxând": "suprataxa",
    "nesuprataxându": "suprataxa",
    "suprataxă": "suprataxa",
    "suprataxai": "suprataxa",
    "suprataxam": "suprataxa",
    "suprataxăm": "suprataxa",
    "suprataxând": "suprataxa",
    "suprataxându": "suprataxa",
    "suprataxară": "suprataxa",
    "suprataxarăm": "suprataxa",
    "suprataxarăți": "suprataxa",
    "suprataxase": "suprataxa",
    "suprataxasem": "suprataxa",
    "suprataxaseră": "suprataxa",
    "suprataxaserăm": "suprataxa",
    "suprataxaserăți": "suprataxa",
    "suprataxaseși": "suprataxa",
    "suprataxași": "suprataxa",
    "suprataxat": "suprataxa",
    "suprataxați": "suprataxa",
    "suprataxau": "suprataxa",
    "suprataxează": "suprataxa",
    "suprataxez": "suprataxa",
    "suprataxeze": "suprataxa",
    "suprataxezi": "suprataxa",
    "suprataxa": "suprataxă",
    "suprataxe": "suprataxă",
    "suprataxei": "suprataxă",
    "suprataxele": "suprataxă",
    "suprataxelor": "suprataxă",
    "suprataxată": "suprataxat",
    "suprataxate": "suprataxat",
    "suprataxați": "suprataxat",
    "supratensiunea": "supratensiune",
    "supratensiuni": "supratensiune",
    "supratensiunii": "supratensiune",
    "supratensiunile": "supratensiune",
    "supratensiunilor": "supratensiune",
    "supraumana": "suprauman",
    "supraumană": "suprauman",
    "supraumane": "suprauman",
    "supraumanei": "suprauman",
    "supraumanele": "suprauman",
    "supraumanelor": "suprauman",
    "supraumani": "suprauman",
    "supraumanii": "suprauman",
    "supraumanilor": "suprauman",
    "supraumanul": "suprauman",
    "supraumanului": "suprauman",
    "supraunitari": "supraunitar",
    "supraunitarii": "supraunitar",
    "supraunitarilor": "supraunitar",
    "supraunitarul": "supraunitar",
    "supraunitarului": "supraunitar",
    "nemaisupraveghind": "supraveghea",
    "nemaisupraveghindu": "supraveghea",
    "nesupraveghind": "supraveghea",
    "nesupraveghindu": "supraveghea",
    "supraveghe": "supraveghea",
    "supravegheai": "supraveghea",
    "supravegheam": "supraveghea",
    "supravegheară": "supraveghea",
    "supraveghearăm": "supraveghea",
    "supraveghearăți": "supraveghea",
    "supraveghease": "supraveghea",
    "supravegheasem": "supraveghea",
    "supravegheaseră": "supraveghea",
    "supravegheaserăm": "supraveghea",
    "supravegheaserăți": "supraveghea",
    "supravegheaseși": "supraveghea",
    "supravegheași": "supraveghea",
    "supravegheat": "supraveghea",
    "supravegheați": "supraveghea",
    "supravegheau": "supraveghea",
    "supraveghează": "supraveghea",
    "supraveghem": "supraveghea",
    "supraveghez": "supraveghea",
    "supravegheze": "supraveghea",
    "supraveghezi": "supraveghea",
    "supraveghind": "supraveghea",
    "supraveghindu": "supraveghea",
    "supravegheată": "supravegheat",
    "supravegheate": "supravegheat",
    "supravegheați": "supravegheat",
    "supravegherea": "supraveghere",
    "supravegheri": "supraveghere",
    "supravegherii": "supraveghere",
    "supravegherile": "supraveghere",
    "supravegherilor": "supraveghere",
    "supraveghetoarea": "supraveghetoare",
    "supraveghetoarei": "supraveghetoare",
    "supraveghetoarele": "supraveghetoare",
    "supraveghetoarelor": "supraveghetoare",
    "supraveghetoareo": "supraveghetoare",
    "supraveghetori": "supraveghetor",
    "supraveghetorii": "supraveghetor",
    "supraveghetorilor": "supraveghetor",
    "supraveghetorul": "supraveghetor",
    "supraveghetorule": "supraveghetor",
    "supraveghetorului": "supraveghetor",
    "nemaisupraviețuind": "supraviețui",
    "nemaisupraviețuindu": "supraviețui",
    "nesupraviețuind": "supraviețui",
    "nesupraviețuindu": "supraviețui",
    "supraviețuia": "supraviețui",
    "supraviețuiai": "supraviețui",
    "supraviețuiam": "supraviețui",
    "supraviețuiască": "supraviețui",
    "supraviețuiați": "supraviețui",
    "supraviețuiau": "supraviețui",
    "supraviețuiesc": "supraviețui",
    "supraviețuiește": "supraviețui",
    "supraviețuiești": "supraviețui",
    "supraviețuii": "supraviețui",
    "supraviețuim": "supraviețui",
    "supraviețuind": "supraviețui",
    "supraviețuindu": "supraviețui",
    "supraviețuiră": "supraviețui",
    "supraviețuirăm": "supraviețui",
    "supraviețuirăți": "supraviețui",
    "supraviețuise": "supraviețui",
    "supraviețuisem": "supraviețui",
    "supraviețuiseră": "supraviețui",
    "supraviețuiserăm": "supraviețui",
    "supraviețuiserăți": "supraviețui",
    "supraviețuiseși": "supraviețui",
    "supraviețuiși": "supraviețui",
    "supraviețuit": "supraviețui",
    "supraviețuiți": "supraviețui",
    "supraviețuirea": "supraviețuire",
    "supraviețuireo": "supraviețuire",
    "supraviețuiri": "supraviețuire",
    "supraviețuirii": "supraviețuire",
    "supraviețuirile": "supraviețuire",
    "supraviețuirilor": "supraviețuire",
    "supraviețuită": "supraviețuit",
    "supraviețuite": "supraviețuit",
    "supraviețuiți": "supraviețuit",
    "supraviețuitoarea": "supraviețuitoare",
    "supraviețuitoarei": "supraviețuitoare",
    "supraviețuitoarele": "supraviețuitoare",
    "supraviețuitoarelor": "supraviețuitoare",
    "supraviețuitori": "supraviețuitor",
    "supraviețuitorii": "supraviețuitor",
    "supraviețuitorilor": "supraviețuitor",
    "supraviețuitorul": "supraviețuitor",
    "supraviețuitorului": "supraviețuitor",
    "suprema": "suprem",
    "supremă": "suprem",
    "supreme": "suprem",
    "supremei": "suprem",
    "supremele": "suprem",
    "supremelor": "suprem",
    "supremi": "suprem",
    "supremii": "suprem",
    "supremilor": "suprem",
    "supremul": "suprem",
    "supremului": "suprem",
    "supremația": "supremație",
    "supremației": "supremație",
    "supremații": "supremație",
    "supremațiile": "supremație",
    "supremațiilor": "supremație",
    "nemaisuprimând": "suprima",
    "nemaisuprimându": "suprima",
    "nesuprimând": "suprima",
    "nesuprimându": "suprima",
    "suprim": "suprima",
    "suprimă": "suprima",
    "suprimai": "suprima",
    "suprimam": "suprima",
    "suprimăm": "suprima",
    "suprimând": "suprima",
    "suprimându": "suprima",
    "suprimară": "suprima",
    "suprimarăm": "suprima",
    "suprimarăți": "suprima",
    "suprimase": "suprima",
    "suprimasem": "suprima",
    "suprimaseră": "suprima",
    "suprimaserăm": "suprima",
    "suprimaserăți": "suprima",
    "suprimaseși": "suprima",
    "suprimași": "suprima",
    "suprimat": "suprima",
    "suprimați": "suprima",
    "suprimau": "suprima",
    "suprime": "suprima",
    "suprimi": "suprima",
    "suprimarea": "suprimare",
    "suprimareo": "suprimare",
    "suprimări": "suprimare",
    "suprimării": "suprimare",
    "suprimările": "suprimare",
    "suprimărilor": "suprimare",
    "suprimata": "suprimat",
    "suprimată": "suprimat",
    "suprimate": "suprimat",
    "suprimatei": "suprimat",
    "suprimatele": "suprimat",
    "suprimatelor": "suprimat",
    "suprimați": "suprimat",
    "suprimații": "suprimat",
    "suprimaților": "suprimat",
    "suprimato": "suprimat",
    "suprimatul": "suprimat",
    "suprimatule": "suprimat",
    "suprimatului": "suprimat",
    "suptă": "supt",
    "supte": "supt",
    "supți": "supt",
    "suptul": "supt",
    "suptului": "supt",
    "supturi": "supt",
    "supturile": "supt",
    "supturilor": "supt",
    "nemaisupunând": "supune",
    "nemaisupunându": "supune",
    "nesupunând": "supune",
    "nesupunându": "supune",
    "supui": "supune",
    "supun": "supune",
    "supună": "supune",
    "supunând": "supune",
    "supunându": "supune",
    "supunea": "supune",
    "supuneai": "supune",
    "supuneam": "supune",
    "supuneați": "supune",
    "supuneau": "supune",
    "supunem": "supune",
    "supuneți": "supune",
    "supus": "supune",
    "supuse": "supune",
    "supusei": "supune",
    "supuseră": "supune",
    "supuserăm": "supune",
    "supuserăți": "supune",
    "supusese": "supune",
    "supusesem": "supune",
    "supuseseră": "supune",
    "supuseserăm": "supune",
    "supuseserăți": "supune",
    "supuseseși": "supune",
    "supuseși": "supune",
    "supunerea": "supunere",
    "supunereo": "supunere",
    "supuneri": "supunere",
    "supunerii": "supunere",
    "supunerile": "supunere",
    "supunerilor": "supunere",
    "nemaisupurând": "supura",
    "nemaisupurându": "supura",
    "nesupurând": "supura",
    "nesupurându": "supura",
    "supură": "supura",
    "supurai": "supura",
    "supuram": "supura",
    "supurăm": "supura",
    "supurând": "supura",
    "supurându": "supura",
    "supurară": "supura",
    "supurarăm": "supura",
    "supurarăți": "supura",
    "supurase": "supura",
    "supurasem": "supura",
    "supuraseră": "supura",
    "supuraserăm": "supura",
    "supuraserăți": "supura",
    "supuraseși": "supura",
    "supurași": "supura",
    "supurat": "supura",
    "supurați": "supura",
    "supurau": "supura",
    "supurează": "supura",
    "supurez": "supura",
    "supureze": "supura",
    "supurezi": "supura",
    "supurată": "supurat",
    "supurate": "supurat",
    "supurați": "supurat",
    "supurația": "supurație",
    "supurației": "supurație",
    "supurații": "supurație",
    "supurațiile": "supurație",
    "supurațiilor": "supurație",
    "supusa": "supus",
    "supusă": "supus",
    "supuse": "supus",
    "supusei": "supus",
    "supusele": "supus",
    "supuselor": "supus",
    "supuși": "supus",
    "supușii": "supus",
    "supușilor": "supus",
    "supusul": "supus",
    "supusului": "supus",
    "supusa": "supusă",
    "supuse": "supusă",
    "supusei": "supusă",
    "supusele": "supusă",
    "supuselor": "supusă",
    "supușenia": "supușenie",
    "supușeniei": "supușenie",
    "supușenii": "supușenie",
    "supușeniile": "supușenie",
    "supușeniilor": "supușenie",
    "sura": "sur",
    "sură": "sur",
    "sure": "sur",
    "surei": "sur",
    "surele": "sur",
    "surelor": "sur",
    "suri": "sur",
    "șura": "șură",
    "șure": "șură",
    "șurei": "șură",
    "șurele": "șură",
    "șurelor": "șură",
    "nemaisurâzând": "surâde",
    "nemaisurâzându": "surâde",
    "nesurâzând": "surâde",
    "nesurâzându": "surâde",
    "surâd": "surâde",
    "surâdă": "surâde",
    "surâdea": "surâde",
    "surâdeai": "surâde",
    "surâdeam": "surâde",
    "surâdeați": "surâde",
    "surâdeau": "surâde",
    "surâdem": "surâde",
    "surâdeți": "surâde",
    "surâs": "surâde",
    "surâse": "surâde",
    "surâsei": "surâde",
    "surâseră": "surâde",
    "surâserăm": "surâde",
    "surâserăți": "surâde",
    "surâsese": "surâde",
    "surâsesem": "surâde",
    "surâseseră": "surâde",
    "surâseserăm": "surâde",
    "surâseserăți": "surâde",
    "surâseseși": "surâde",
    "surâseși": "surâde",
    "surâzând": "surâde",
    "surâzându": "surâde",
    "surâzi": "surâde",
    "surâsă": "surâs",
    "surâse": "surâs",
    "surâși": "surâs",
    "surâsul": "surâs",
    "surâsului": "surâs",
    "surâsuri": "surâs",
    "surâsurile": "surâs",
    "surâsurilor": "surâs",
    "surata": "surată",
    "surate": "surată",
    "suratei": "surată",
    "suratele": "surată",
    "suratelor": "surată",
    "surâzătoare": "surâzător",
    "surâzătoarea": "surâzător",
    "surâzătoarei": "surâzător",
    "surâzătoarele": "surâzător",
    "surâzătoarelor": "surâzător",
    "surâzători": "surâzător",
    "surâzătorii": "surâzător",
    "surâzătorilor": "surâzător",
    "surâzătorul": "surâzător",
    "surâzătorului": "surâzător",
    "surceaua": "surcea",
    "surcele": "surcea",
    "surcelei": "surcea",
    "surcelele": "surcea",
    "surcelelor": "surcea",
    "surda": "surd",
    "surdă": "surd",
    "surde": "surd",
    "surdei": "surd",
    "surdele": "surd",
    "surdelor": "surd",
    "surdul": "surd",
    "surdului": "surd",
    "surzi": "surd",
    "surzii": "surd",
    "surzilor": "surd",
    "surdina": "surdină",
    "surdine": "surdină",
    "surdinei": "surdină",
    "surdinele": "surdină",
    "surdinelor": "surdină",
    "surditatea": "surditate",
    "surdități": "surditate",
    "surdității": "surditate",
    "surditățile": "surditate",
    "surdităților": "surditate",
    "surdomuți": "surdomut",
    "surdomuții": "surdomut",
    "surdomuților": "surdomut",
    "surdomutul": "surdomut",
    "surdomutului": "surdomut",
    "surdomuta": "surdomută",
    "surdomute": "surdomută",
    "surdomutei": "surdomută",
    "surdomutele": "surdomută",
    "surdomutelor": "surdomută",
    "nemaisurfilând": "surfila",
    "nemaisurfilându": "surfila",
    "nesurfilând": "surfila",
    "nesurfilându": "surfila",
    "surfilă": "surfila",
    "surfilai": "surfila",
    "surfilam": "surfila",
    "surfilăm": "surfila",
    "surfilând": "surfila",
    "surfilându": "surfila",
    "surfilară": "surfila",
    "surfilarăm": "surfila",
    "surfilarăți": "surfila",
    "surfilase": "surfila",
    "surfilasem": "surfila",
    "surfilaseră": "surfila",
    "surfilaserăm": "surfila",
    "surfilaserăți": "surfila",
    "surfilaseși": "surfila",
    "surfilași": "surfila",
    "surfilat": "surfila",
    "surfilați": "surfila",
    "surfilau": "surfila",
    "surfilează": "surfila",
    "surfilez": "surfila",
    "surfileze": "surfila",
    "surfilezi": "surfila",
    "surfilată": "surfilat",
    "surfilate": "surfilat",
    "surfilați": "surfilat",
    "surghiunul": "surghiun",
    "surghiunului": "surghiun",
    "surghiunuri": "surghiun",
    "surghiunurile": "surghiun",
    "surghiunurilor": "surghiun",
    "nemaisurghiunind": "surghiuni",
    "nemaisurghiunindu": "surghiuni",
    "nesurghiunind": "surghiuni",
    "nesurghiunindu": "surghiuni",
    "surghiunea": "surghiuni",
    "surghiuneai": "surghiuni",
    "surghiuneam": "surghiuni",
    "surghiunească": "surghiuni",
    "surghiuneați": "surghiuni",
    "surghiuneau": "surghiuni",
    "surghiunesc": "surghiuni",
    "surghiunește": "surghiuni",
    "surghiunești": "surghiuni",
    "surghiunii": "surghiuni",
    "surghiunim": "surghiuni",
    "surghiunind": "surghiuni",
    "surghiunindu": "surghiuni",
    "surghiuniră": "surghiuni",
    "surghiunirăm": "surghiuni",
    "surghiunirăți": "surghiuni",
    "surghiunise": "surghiuni",
    "surghiunisem": "surghiuni",
    "surghiuniseră": "surghiuni",
    "surghiuniserăm": "surghiuni",
    "surghiuniserăți": "surghiuni",
    "surghiuniseși": "surghiuni",
    "surghiuniși": "surghiuni",
    "surghiunit": "surghiuni",
    "surghiuniți": "surghiuni",
    "surghiunită": "surghiunit",
    "surghiunite": "surghiunit",
    "surghiuniți": "surghiunit",
    "surghiuniții": "surghiunit",
    "surghiuniților": "surghiunit",
    "surghiunitul": "surghiunit",
    "surghiunitului": "surghiunit",
    "surghiunita": "surghiunită",
    "surghiunite": "surghiunită",
    "surghiunitei": "surghiunită",
    "surghiunitele": "surghiunită",
    "surghiunitelor": "surghiunită",
    "surioara": "surioară",
    "surioare": "surioară",
    "surioarei": "surioară",
    "surioarele": "surioară",
    "surioarelor": "surioară",
    "surla": "surlă",
    "surle": "surlă",
    "surlei": "surlă",
    "surlele": "surlă",
    "surlelor": "surlă",
    "nemaisurmenând": "surmena",
    "nemaisurmenându": "surmena",
    "nesurmenând": "surmena",
    "nesurmenându": "surmena",
    "surmenă": "surmena",
    "surmenai": "surmena",
    "surmenam": "surmena",
    "surmenăm": "surmena",
    "surmenând": "surmena",
    "surmenându": "surmena",
    "surmenară": "surmena",
    "surmenarăm": "surmena",
    "surmenarăți": "surmena",
    "surmenase": "surmena",
    "surmenasem": "surmena",
    "surmenaseră": "surmena",
    "surmenaserăm": "surmena",
    "surmenaserăți": "surmena",
    "surmenaseși": "surmena",
    "surmenași": "surmena",
    "surmenat": "surmena",
    "surmenați": "surmena",
    "surmenau": "surmena",
    "surmenează": "surmena",
    "surmenez": "surmena",
    "surmeneze": "surmena",
    "surmenezi": "surmena",
    "surmenajul": "surmenaj",
    "surmenajului": "surmenaj",
    "surmenajuri": "surmenaj",
    "surmenajurile": "surmenaj",
    "surmenajurilor": "surmenaj",
    "surmenată": "surmenat",
    "surmenate": "surmenat",
    "surmenați": "surmenat",
    "surmontă": "surmonta",
    "surmontai": "surmonta",
    "surmontam": "surmonta",
    "surmontăm": "surmonta",
    "surmontând": "surmonta",
    "surmontându": "surmonta",
    "surmontară": "surmonta",
    "surmontarăm": "surmonta",
    "surmontarăți": "surmonta",
    "surmontase": "surmonta",
    "surmontasem": "surmonta",
    "surmontaseră": "surmonta",
    "surmontaserăm": "surmonta",
    "surmontaserăți": "surmonta",
    "surmontaseși": "surmonta",
    "surmontași": "surmonta",
    "surmontat": "surmonta",
    "surmontați": "surmonta",
    "surmontau": "surmonta",
    "surmontează": "surmonta",
    "surmontez": "surmonta",
    "surmonteze": "surmonta",
    "surmontezi": "surmonta",
    "surmontată": "surmontat",
    "surmontate": "surmontat",
    "surmontați": "surmontat",
    "surogate": "surogat",
    "surogatele": "surogat",
    "surogatelor": "surogat",
    "surogatul": "surogat",
    "surogatului": "surogat",
    "nemaisurpând": "surpa",
    "nemaisurpându": "surpa",
    "nesurpând": "surpa",
    "nesurpându": "surpa",
    "surp": "surpa",
    "surpă": "surpa",
    "surpai": "surpa",
    "surpam": "surpa",
    "surpăm": "surpa",
    "surpând": "surpa",
    "surpându": "surpa",
    "surpară": "surpa",
    "surparăm": "surpa",
    "surparăți": "surpa",
    "surpase": "surpa",
    "surpasem": "surpa",
    "surpaseră": "surpa",
    "surpaserăm": "surpa",
    "surpaserăți": "surpa",
    "surpaseși": "surpa",
    "surpași": "surpa",
    "surpat": "surpa",
    "surpați": "surpa",
    "surpau": "surpa",
    "surpe": "surpa",
    "surpi": "surpa",
    "surpată": "surpat",
    "surpate": "surpat",
    "surpați": "surpat",
    "surpatul": "surpat",
    "surpatului": "surpat",
    "surpătura": "surpătură",
    "surpături": "surpătură",
    "surpăturii": "surpătură",
    "surpăturile": "surpătură",
    "surpăturilor": "surpătură",
    "surplusul": "surplus",
    "surplusului": "surplus",
    "surplusuri": "surplus",
    "surplusurile": "surplus",
    "surplusurilor": "surplus",
    "nemaisurprinzând": "surprinde",
    "nemaisurprinzându": "surprinde",
    "nesurprinzând": "surprinde",
    "nesurprinzându": "surprinde",
    "surprind": "surprinde",
    "surprindă": "surprinde",
    "surprindea": "surprinde",
    "surprindeai": "surprinde",
    "surprindeam": "surprinde",
    "surprindeați": "surprinde",
    "surprindeau": "surprinde",
    "surprindem": "surprinde",
    "surprindeți": "surprinde",
    "surprins": "surprinde",
    "surprinse": "surprinde",
    "surprinsei": "surprinde",
    "surprinseră": "surprinde",
    "surprinserăm": "surprinde",
    "surprinserăți": "surprinde",
    "surprinsese": "surprinde",
    "surprinsesem": "surprinde",
    "surprinseseră": "surprinde",
    "surprinseserăm": "surprinde",
    "surprinseserăți": "surprinde",
    "surprinseseși": "surprinde",
    "surprinseși": "surprinde",
    "surprinzând": "surprinde",
    "surprinzându": "surprinde",
    "surprinzi": "surprinde",
    "surprinderea": "surprindere",
    "surprindereo": "surprindere",
    "surprinderi": "surprindere",
    "surprinderii": "surprindere",
    "surprinderile": "surprindere",
    "surprinderilor": "surprindere",
    "surprinsă": "surprins",
    "surprinse": "surprins",
    "surprinși": "surprins",
    "surprinșii": "surprins",
    "surprinșilor": "surprins",
    "surprinsul": "surprins",
    "surprinsului": "surprins",
    "surprinzătoare": "surprinzător",
    "surprinzătoarea": "surprinzător",
    "surprinzătoarei": "surprinzător",
    "surprinzătoarele": "surprinzător",
    "surprinzătoarelor": "surprinzător",
    "surprinzători": "surprinzător",
    "surprinzătorii": "surprinzător",
    "surprinzătorilor": "surprinzător",
    "surprinzătorul": "surprinzător",
    "surprinzătorului": "surprinzător",
    "surpriza": "surpriză",
    "surprize": "surpriză",
    "surprizei": "surpriză",
    "surprizele": "surpriză",
    "surprizelor": "surpriză",
    "sursa": "sursă",
    "surse": "sursă",
    "sursei": "sursă",
    "sursele": "sursă",
    "surselor": "sursă",
    "surtuce": "surtuc",
    "surtucele": "surtuc",
    "surtucelor": "surtuc",
    "surtucul": "surtuc",
    "surtucului": "surtuc",
    "surtucari": "surtucar",
    "surtucarii": "surtucar",
    "surtucarilor": "surtucar",
    "surtucarul": "surtucar",
    "surtucarului": "surtucar",
    "șurubul": "șurub",
    "șurubului": "șurub",
    "șuruburi": "șurub",
    "șuruburile": "șurub",
    "șuruburilor": "șurub",
    "șurubari": "șurubar",
    "șurubarii": "șurubar",
    "șurubarilor": "șurubar",
    "șurubarul": "șurubar",
    "șurubarului": "șurubar",
    "șurubăria": "șurubărie",
    "șurubăriei": "șurubărie",
    "șurubării": "șurubărie",
    "șurubăriile": "șurubărie",
    "șurubăriilor": "șurubărie",
    "șurubelnița": "șurubelniță",
    "șurubelnițe": "șurubelniță",
    "șurubelniței": "șurubelniță",
    "șurubelnițele": "șurubelniță",
    "șurubelnițelor": "șurubelniță",
    "surugii": "surugiu",
    "surugiii": "surugiu",
    "surugiilor": "surugiu",
    "surugiul": "surugiu",
    "surugiului": "surugiu",
    "nemaisurvenind": "surveni",
    "nemaisurvenindu": "surveni",
    "nesurvenind": "surveni",
    "nesurvenindu": "surveni",
    "survenea": "surveni",
    "surveneai": "surveni",
    "surveneam": "surveni",
    "surveneați": "surveni",
    "surveneau": "surveni",
    "survenii": "surveni",
    "survenim": "surveni",
    "survenind": "surveni",
    "survenindu": "surveni",
    "surveniră": "surveni",
    "survenirăm": "surveni",
    "survenirăți": "surveni",
    "survenise": "surveni",
    "survenisem": "surveni",
    "surveniseră": "surveni",
    "surveniserăm": "surveni",
    "surveniserăți": "surveni",
    "surveniseși": "surveni",
    "surveniși": "surveni",
    "survenit": "surveni",
    "surveniți": "surveni",
    "survii": "surveni",
    "survin": "surveni",
    "survină": "surveni",
    "survine": "surveni",
    "survino": "surveni",
    "survenită": "survenit",
    "survenite": "survenit",
    "surveniți": "survenit",
    "survolă": "survola",
    "survolai": "survola",
    "survolam": "survola",
    "survolăm": "survola",
    "survolând": "survola",
    "survolându": "survola",
    "survolară": "survola",
    "survolarăm": "survola",
    "survolarăți": "survola",
    "survolase": "survola",
    "survolasem": "survola",
    "survolaseră": "survola",
    "survolaserăm": "survola",
    "survolaserăți": "survola",
    "survolaseși": "survola",
    "survolași": "survola",
    "survolat": "survola",
    "survolați": "survola",
    "survolatu": "survola",
    "survolau": "survola",
    "survolează": "survola",
    "survolez": "survola",
    "survoleze": "survola",
    "survolezi": "survola",
    "survolată": "survolat",
    "survolate": "survolat",
    "survolați": "survolat",
    "surzenia": "surzenie",
    "surzeniei": "surzenie",
    "surzenii": "surzenie",
    "nemaisurzind": "surzi",
    "nemaisurzindu": "surzi",
    "nesurzind": "surzi",
    "nesurzindu": "surzi",
    "surzea": "surzi",
    "surzeai": "surzi",
    "surzeam": "surzi",
    "surzească": "surzi",
    "surzeați": "surzi",
    "surzeau": "surzi",
    "surzesc": "surzi",
    "surzește": "surzi",
    "surzești": "surzi",
    "surzii": "surzi",
    "surzim": "surzi",
    "surzind": "surzi",
    "surzindu": "surzi",
    "surziră": "surzi",
    "surzirăm": "surzi",
    "surzirăți": "surzi",
    "surzise": "surzi",
    "surzisem": "surzi",
    "surziseră": "surzi",
    "surziserăm": "surzi",
    "surziserăți": "surzi",
    "surziseși": "surzi",
    "surziși": "surzi",
    "surzit": "surzi",
    "surziți": "surzi",
    "surzită": "surzit",
    "surzite": "surzit",
    "surziți": "surzit",
    "susul": "sus",
    "susaiul": "susai",
    "susaiului": "susai",
    "susanul": "susan",
    "susanului": "susan",
    "șușaneaua": "șușanea",
    "șușanele": "șușanea",
    "șușanelei": "șușanea",
    "șușanelele": "șușanea",
    "șușanelelor": "șușanea",
    "susceptibila": "susceptibil",
    "susceptibilă": "susceptibil",
    "susceptibile": "susceptibil",
    "susceptibilei": "susceptibil",
    "susceptibilele": "susceptibil",
    "susceptibilelor": "susceptibil",
    "susceptibili": "susceptibil",
    "susceptibilii": "susceptibil",
    "susceptibililor": "susceptibil",
    "susceptibilul": "susceptibil",
    "susceptibilului": "susceptibil",
    "susceptibilitatea": "susceptibilitate",
    "susceptibilități": "susceptibilitate",
    "susceptibilității": "susceptibilitate",
    "susceptibilitățile": "susceptibilitate",
    "susceptibilităților": "susceptibilitate",
    "nemaisuscitând": "suscita",
    "nemaisuscitându": "suscita",
    "nesuscitând": "suscita",
    "nesuscitându": "suscita",
    "suscit": "suscita",
    "suscită": "suscita",
    "suscitai": "suscita",
    "suscitam": "suscita",
    "suscităm": "suscita",
    "suscitând": "suscita",
    "suscitându": "suscita",
    "suscitară": "suscita",
    "suscitarăm": "suscita",
    "suscitarăți": "suscita",
    "suscitase": "suscita",
    "suscitasem": "suscita",
    "suscitaseră": "suscita",
    "suscitaserăm": "suscita",
    "suscitaserăți": "suscita",
    "suscitaseși": "suscita",
    "suscitași": "suscita",
    "suscitat": "suscita",
    "suscitați": "suscita",
    "suscitau": "suscita",
    "suscite": "suscita",
    "susciți": "suscita",
    "suscitată": "suscitat",
    "suscitate": "suscitat",
    "suscitați": "suscitat",
    "sus-citata": "sus-citat",
    "sus-citată": "sus-citat",
    "sus-citate": "sus-citat",
    "sus-citatei": "sus-citat",
    "sus-citatele": "sus-citat",
    "sus-citatelor": "sus-citat",
    "sus-citați": "sus-citat",
    "sus-citații": "sus-citat",
    "sus-citaților": "sus-citat",
    "sus-citatul": "sus-citat",
    "sus-citatului": "sus-citat",
    "sus-menționata": "sus-menționat",
    "sus-menționată": "sus-menționat",
    "sus-menționate": "sus-menționat",
    "sus-menționatei": "sus-menționat",
    "sus-menționatele": "sus-menționat",
    "sus-menționatelor": "sus-menționat",
    "sus-menționați": "sus-menționat",
    "sus-menționații": "sus-menționat",
    "sus-menționaților": "sus-menționat",
    "sus-menționatul": "sus-menționat",
    "sus-menționatului": "sus-menționat",
    "sus-numita": "sus-numit",
    "sus-numită": "sus-numit",
    "sus-numite": "sus-numit",
    "sus-numitei": "sus-numit",
    "sus-numitele": "sus-numit",
    "sus-numitelor": "sus-numit",
    "sus-numiți": "sus-numit",
    "sus-numiții": "sus-numit",
    "sus-numiților": "sus-numit",
    "sus-numitul": "sus-numit",
    "sus-numitului": "sus-numit",
    "șușoteala": "șușoteală",
    "șușotealo": "șușoteală",
    "șușoteli": "șușoteală",
    "șușotelii": "șușoteală",
    "șușotelile": "șușoteală",
    "șușotelilor": "șușoteală",
    "nemaișușotind": "șușoti",
    "nemaișușotindu": "șușoti",
    "neșușotind": "șușoti",
    "neșușotindu": "șușoti",
    "șușotea": "șușoti",
    "șușoteai": "șușoti",
    "șușoteam": "șușoti",
    "șușotească": "șușoti",
    "șușoteați": "șușoti",
    "șușoteau": "șușoti",
    "șușotesc": "șușoti",
    "șușotește": "șușoti",
    "șușotești": "șușoti",
    "șușotii": "șușoti",
    "șușotim": "șușoti",
    "șușotind": "șușoti",
    "șușotindu": "șușoti",
    "șușotiră": "șușoti",
    "șușotirăm": "șușoti",
    "șușotirăți": "șușoti",
    "șușotise": "șușoti",
    "șușotisem": "șușoti",
    "șușotiseră": "șușoti",
    "șușotiserăm": "șușoti",
    "șușotiserăți": "șușoti",
    "șușotiseși": "șușoti",
    "șușotiși": "șușoti",
    "șușotit": "șușoti",
    "șușotiți": "șușoti",
    "șușotirea": "șușotire",
    "șușotireo": "șușotire",
    "șușotiri": "șușotire",
    "șușotirii": "șușotire",
    "șușotirile": "șușotire",
    "șușotirilor": "șușotire",
    "șușotită": "șușotit",
    "șușotite": "șușotit",
    "șușotiți": "șușotit",
    "suspecta": "suspect",
    "suspectă": "suspect",
    "suspecte": "suspect",
    "suspectei": "suspect",
    "suspectele": "suspect",
    "suspectelor": "suspect",
    "suspecți": "suspect",
    "suspecții": "suspect",
    "suspecților": "suspect",
    "suspectul": "suspect",
    "suspectului": "suspect",
    "nemaisuspectând": "suspecta",
    "nemaisuspectându": "suspecta",
    "nesuspectând": "suspecta",
    "nesuspectându": "suspecta",
    "suspectă": "suspecta",
    "suspectai": "suspecta",
    "suspectam": "suspecta",
    "suspectăm": "suspecta",
    "suspectând": "suspecta",
    "suspectându": "suspecta",
    "suspectară": "suspecta",
    "suspectarăm": "suspecta",
    "suspectarăți": "suspecta",
    "suspectase": "suspecta",
    "suspectasem": "suspecta",
    "suspectaseră": "suspecta",
    "suspectaserăm": "suspecta",
    "suspectaserăți": "suspecta",
    "suspectaseși": "suspecta",
    "suspectași": "suspecta",
    "suspectat": "suspecta",
    "suspectați": "suspecta",
    "suspectau": "suspecta",
    "suspectează": "suspecta",
    "suspectez": "suspecta",
    "suspecteze": "suspecta",
    "suspectezi": "suspecta",
    "suspectată": "suspectat",
    "suspectate": "suspectat",
    "suspectați": "suspectat",
    "nemaisuspendând": "suspenda",
    "nemaisuspendându": "suspenda",
    "nesuspendând": "suspenda",
    "nesuspendându": "suspenda",
    "suspend": "suspenda",
    "suspendă": "suspenda",
    "suspendai": "suspenda",
    "suspendam": "suspenda",
    "suspendăm": "suspenda",
    "suspendând": "suspenda",
    "suspendându": "suspenda",
    "suspendară": "suspenda",
    "suspendarăm": "suspenda",
    "suspendarăți": "suspenda",
    "suspendase": "suspenda",
    "suspendasem": "suspenda",
    "suspendaseră": "suspenda",
    "suspendaserăm": "suspenda",
    "suspendaserăți": "suspenda",
    "suspendaseși": "suspenda",
    "suspendași": "suspenda",
    "suspendat": "suspenda",
    "suspendați": "suspenda",
    "suspendau": "suspenda",
    "suspende": "suspenda",
    "suspenzi": "suspenda",
    "suspendarea": "suspendare",
    "suspendareo": "suspendare",
    "suspendări": "suspendare",
    "suspendării": "suspendare",
    "suspendările": "suspendare",
    "suspendărilor": "suspendare",
    "suspendata": "suspendat",
    "suspendată": "suspendat",
    "suspendate": "suspendat",
    "suspendatei": "suspendat",
    "suspendatele": "suspendat",
    "suspendatelor": "suspendat",
    "suspendați": "suspendat",
    "suspendații": "suspendat",
    "suspendaților": "suspendat",
    "suspendato": "suspendat",
    "suspendatul": "suspendat",
    "suspendatule": "suspendat",
    "suspendatului": "suspendat",
    "suspensia": "suspensie",
    "suspensiei": "suspensie",
    "suspensii": "suspensie",
    "suspensiile": "suspensie",
    "suspensiilor": "suspensie",
    "suspensiva": "suspensiv",
    "suspensivă": "suspensiv",
    "suspensive": "suspensiv",
    "suspensivei": "suspensiv",
    "suspensivele": "suspensiv",
    "suspensivelor": "suspensiv",
    "suspensivi": "suspensiv",
    "suspensivii": "suspensiv",
    "suspensivilor": "suspensiv",
    "suspensivul": "suspensiv",
    "suspensivului": "suspensiv",
    "suspicioasa": "suspicios",
    "suspicioasă": "suspicios",
    "suspicioase": "suspicios",
    "suspicioasei": "suspicios",
    "suspicioasele": "suspicios",
    "suspicioaselor": "suspicios",
    "suspicioși": "suspicios",
    "suspicioșii": "suspicios",
    "suspicioșilor": "suspicios",
    "suspiciosul": "suspicios",
    "suspiciosului": "suspicios",
    "suspiciunea": "suspiciune",
    "suspiciuni": "suspiciune",
    "suspiciunii": "suspiciune",
    "suspiciunile": "suspiciune",
    "suspiciunilor": "suspiciune",
    "suspine": "suspin",
    "suspinele": "suspin",
    "suspinelor": "suspin",
    "suspinul": "suspin",
    "suspinului": "suspin",
    "nemaisuspinând": "suspina",
    "nemaisuspinându": "suspina",
    "nesuspinând": "suspina",
    "nesuspinându": "suspina",
    "suspin": "suspina",
    "suspină": "suspina",
    "suspinai": "suspina",
    "suspinam": "suspina",
    "suspinăm": "suspina",
    "suspinând": "suspina",
    "suspinându": "suspina",
    "suspinară": "suspina",
    "suspinarăm": "suspina",
    "suspinarăți": "suspina",
    "suspinase": "suspina",
    "suspinasem": "suspina",
    "suspinaseră": "suspina",
    "suspinaserăm": "suspina",
    "suspinaserăți": "suspina",
    "suspinaseși": "suspina",
    "suspinași": "suspina",
    "suspinat": "suspina",
    "suspinați": "suspina",
    "suspinau": "suspina",
    "suspine": "suspina",
    "suspini": "suspina",
    "suspinată": "suspinat",
    "suspinate": "suspinat",
    "suspinați": "suspinat",
    "sus-pusa": "sus-pus",
    "sus-pusă": "sus-pus",
    "sus-puse": "sus-pus",
    "sus-pusei": "sus-pus",
    "sus-pusele": "sus-pus",
    "sus-puselor": "sus-pus",
    "sus-puși": "sus-pus",
    "sus-pușii": "sus-pus",
    "sus-pușilor": "sus-pus",
    "sus-pusul": "sus-pus",
    "sus-pusului": "sus-pus",
    "sustentația": "sustentație",
    "sustentației": "sustentație",
    "sustentații": "sustentație",
    "sustentațiile": "sustentație",
    "sustentațiilor": "sustentație",
    "susținătoarea": "susținătoare",
    "susținătoarei": "susținătoare",
    "susținătoarele": "susținătoare",
    "susținătoarelor": "susținătoare",
    "susținătoare": "susținător",
    "susținătoarea": "susținător",
    "susținătoarei": "susținător",
    "susținătoarele": "susținător",
    "susținătoarelor": "susținător",
    "susținători": "susținător",
    "susținătorii": "susținător",
    "susținătorilor": "susținător",
    "susținătorul": "susținător",
    "susținătorului": "susținător",
    "nemaisusținând": "susține",
    "nemaisusținându": "susține",
    "nesusținând": "susține",
    "nesusținându": "susține",
    "susții": "susține",
    "susțin": "susține",
    "susțină": "susține",
    "susținând": "susține",
    "susținându": "susține",
    "susținea": "susține",
    "susțineai": "susține",
    "susțineam": "susține",
    "susțineați": "susține",
    "susțineau": "susține",
    "susținem": "susține",
    "susțineți": "susține",
    "susținu": "susține",
    "susținui": "susține",
    "susținură": "susține",
    "susținurăm": "susține",
    "susținurăți": "susține",
    "susținuse": "susține",
    "susținusem": "susține",
    "susținuseră": "susține",
    "susținuserăm": "susține",
    "susținuserăți": "susține",
    "susținuseși": "susține",
    "susținuși": "susține",
    "susținut": "susține",
    "susținerea": "susținere",
    "susținereo": "susținere",
    "susțineri": "susținere",
    "susținerii": "susținere",
    "susținerile": "susținere",
    "susținerilor": "susținere",
    "susținuta": "susținut",
    "susținută": "susținut",
    "susținute": "susținut",
    "susținutei": "susținut",
    "susținutele": "susținut",
    "susținutelor": "susținut",
    "susținuți": "susținut",
    "susținuții": "susținut",
    "susținuților": "susținut",
    "susținuto": "susținut",
    "susținutul": "susținut",
    "susținutule": "susținut",
    "susținutului": "susținut",
    "nemaisustrăgând": "sustrage",
    "nemaisustrăgându": "sustrage",
    "nesustrăgând": "sustrage",
    "nesustrăgându": "sustrage",
    "sustrag": "sustrage",
    "sustragă": "sustrage",
    "sustrăgând": "sustrage",
    "sustrăgându": "sustrage",
    "sustrăgea": "sustrage",
    "sustrăgeai": "sustrage",
    "sustrăgeam": "sustrage",
    "sustrăgeați": "sustrage",
    "sustrăgeau": "sustrage",
    "sustragem": "sustrage",
    "sustrageți": "sustrage",
    "sustragi": "sustrage",
    "sustras": "sustrage",
    "sustrase": "sustrage",
    "sustrăsei": "sustrage",
    "sustraseră": "sustrage",
    "sustraserăm": "sustrage",
    "sustraserăți": "sustrage",
    "sustrăsese": "sustrage",
    "sustrăsesem": "sustrage",
    "sustrăseseră": "sustrage",
    "sustrăseserăm": "sustrage",
    "sustrăseserăți": "sustrage",
    "sustrăseseși": "sustrage",
    "sustrăseși": "sustrage",
    "sustragerea": "sustragere",
    "sustrageri": "sustragere",
    "sustragerii": "sustragere",
    "sustragerile": "sustragere",
    "sustragerilor": "sustragere",
    "sustrasă": "sustras",
    "sustrase": "sustras",
    "sustrași": "sustras",
    "susure": "susur",
    "susurele": "susur",
    "susurelor": "susur",
    "susurul": "susur",
    "susurului": "susur",
    "nemaisusurând": "susura",
    "nemaisusurându": "susura",
    "nesusurând": "susura",
    "nesusurându": "susura",
    "susur": "susura",
    "susură": "susura",
    "susurai": "susura",
    "susuram": "susura",
    "susurăm": "susura",
    "susurând": "susura",
    "susurându": "susura",
    "susurară": "susura",
    "susurarăm": "susura",
    "susurarăți": "susura",
    "susurase": "susura",
    "susurasem": "susura",
    "susuraseră": "susura",
    "susuraserăm": "susura",
    "susuraserăți": "susura",
    "susuraseși": "susura",
    "susurași": "susura",
    "susurat": "susura",
    "susurați": "susura",
    "susurau": "susura",
    "susure": "susura",
    "susuri": "susura",
    "susurată": "susurat",
    "susurate": "susurat",
    "susurați": "susurat",
    "sus-zisa": "sus-zis",
    "sus-zisă": "sus-zis",
    "sus-zise": "sus-zis",
    "sus-zisei": "sus-zis",
    "sus-zisele": "sus-zis",
    "sus-ziselor": "sus-zis",
    "sus-ziși": "sus-zis",
    "sus-zișii": "sus-zis",
    "sus-zișilor": "sus-zis",
    "sus-zisul": "sus-zis",
    "sus-zisului": "sus-zis",
    "șutul": "șut",
    "șutului": "șut",
    "șuturi": "șut",
    "șuturile": "șut",
    "șuturilor": "șut",
    "suta": "sută",
    "sutălea": "sută",
    "sute": "sută",
    "sutei": "sută",
    "sutele": "sută",
    "sutelor": "sută",
    "nemaișutând": "șuta",
    "nemaișutându": "șuta",
    "neșutând": "șuta",
    "neșutându": "șuta",
    "șută": "șuta",
    "șutai": "șuta",
    "șutam": "șuta",
    "șutăm": "șuta",
    "șutând": "șuta",
    "șutându": "șuta",
    "șutară": "șuta",
    "șutarăm": "șuta",
    "șutarăți": "șuta",
    "șutase": "șuta",
    "șutasem": "șuta",
    "șutaseră": "șuta",
    "șutaserăm": "șuta",
    "șutaserăți": "șuta",
    "șutaseși": "șuta",
    "șutași": "șuta",
    "șutat": "șuta",
    "șutați": "șuta",
    "șutau": "șuta",
    "șutează": "șuta",
    "șutez": "șuta",
    "șuteze": "șuta",
    "șutezi": "șuta",
    "sutana": "sutană",
    "sutane": "sutană",
    "sutanei": "sutană",
    "sutanele": "sutană",
    "sutanelor": "sutană",
    "șutată": "șutat",
    "șutate": "șutat",
    "șutați": "șutat",
    "sutiene": "sutien",
    "sutienele": "sutien",
    "sutienelor": "sutien",
    "sutienul": "sutien",
    "sutienului": "sutien",
    "sutimea": "sutime",
    "sutimi": "sutime",
    "sutimii": "sutime",
    "sutimile": "sutime",
    "sutimilor": "sutime",
    "nemaisuturând": "sutura",
    "nemaisuturându": "sutura",
    "nesuturând": "sutura",
    "nesuturându": "sutura",
    "sutură": "sutura",
    "suturai": "sutura",
    "suturam": "sutura",
    "suturăm": "sutura",
    "suturând": "sutura",
    "suturându": "sutura",
    "suturară": "sutura",
    "suturarăm": "sutura",
    "suturarăți": "sutura",
    "suturase": "sutura",
    "suturasem": "sutura",
    "suturaseră": "sutura",
    "suturaserăm": "sutura",
    "suturaserăți": "sutura",
    "suturaseși": "sutura",
    "suturași": "sutura",
    "suturat": "sutura",
    "suturați": "sutura",
    "suturau": "sutura",
    "suturează": "sutura",
    "suturez": "sutura",
    "sutureze": "sutura",
    "suturezi": "sutura",
    "sutura": "sutură",
    "suturi": "sutură",
    "suturii": "sutură",
    "suturile": "sutură",
    "suturilor": "sutură",
    "suturată": "suturat",
    "suturate": "suturat",
    "suturați": "suturat",
    "suvace": "suvac",
    "suvacele": "suvac",
    "suvacelor": "suvac",
    "suvacul": "suvac",
    "suvacului": "suvac",
    "suveica": "suveică",
    "suveici": "suveică",
    "suveicii": "suveică",
    "suveicile": "suveică",
    "suveicilor": "suveică",
    "suvenire": "suvenir",
    "suvenirele": "suvenir",
    "suvenirelor": "suvenir",
    "suvenirul": "suvenir",
    "suvenirului": "suvenir",
    "suverana": "suveran",
    "suverană": "suveran",
    "suverane": "suveran",
    "suveranei": "suveran",
    "suveranele": "suveran",
    "suveranelor": "suveran",
    "suverani": "suveran",
    "suveranii": "suveran",
    "suveranilor": "suveran",
    "suveranul": "suveran",
    "suveranului": "suveran",
    "suverana": "suverană",
    "suverane": "suverană",
    "suveranei": "suverană",
    "suveranele": "suverană",
    "suveranelor": "suverană",
    "suveranitatea": "suveranitate",
    "suveranități": "suveranitate",
    "suveranității": "suveranitate",
    "suveranitățile": "suveranitate",
    "suveranităților": "suveranitate",
    "șuvița": "șuviță",
    "șuvițe": "șuviță",
    "șuviței": "șuviță",
    "șuvițele": "șuviță",
    "șuvițelor": "șuviță",
    "șuvoaie": "șuvoi",
    "șuvoaiele": "șuvoi",
    "șuvoaielor": "șuvoi",
    "șuvoiul": "șuvoi",
    "șuvoiului": "șuvoi",
    "suzerani": "suzeran",
    "suzeranii": "suzeran",
    "suzeranilor": "suzeran",
    "suzeranul": "suzeran",
    "suzeranului": "suzeran",
    "suzerana": "suzerană",
    "suzerane": "suzerană",
    "suzeranei": "suzerană",
    "suzeranele": "suzerană",
    "suzeranelor": "suzerană",
    "suzeranitatea": "suzeranitate",
    "suzeranități": "suzeranitate",
    "suzeranității": "suzeranitate",
    "suzeranitățile": "suzeranitate",
    "suzeranităților": "suzeranitate",
    "șvaba": "șvab",
    "șvabă": "șvab",
    "șvabe": "șvab",
    "șvabei": "șvab",
    "șvabele": "șvab",
    "șvabelor": "șvab",
    "șvabi": "șvab",
    "șvabii": "șvab",
    "șvabilor": "șvab",
    "șvabul": "șvab",
    "șvabului": "șvab",
    "șvaba": "șvabă",
    "șvabe": "șvabă",
    "șvabei": "șvabă",
    "șvabele": "șvabă",
    "șvabelor": "șvabă",
    "șvăbească": "șvăbesc",
    "șvăbești": "șvăbesc",
    "șvaițerul": "șvaițer",
    "șvaițerului": "șvaițer",
    "șvarțul": "șvarț",
    "șvarțului": "șvarț",
    "șvarțuri": "șvarț",
    "șvarțurile": "șvarț",
    "șvarțurilor": "șvarț",
    "svastica": "svastică",
    "svastici": "svastică",
    "svasticii": "svastică",
    "svasticile": "svastică",
    "svasticilor": "svastică",
    "svetere": "sveter",
    "sveterele": "sveter",
    "sveterelor": "sveter",
    "sveterul": "sveter",
    "sveterului": "sveter",
    "svingul": "sving",
    "svingului": "sving",
    "svinguri": "sving",
    "svingurile": "sving",
    "svingurilor": "sving",
    "tabacul": "tabac",
    "tabacului": "tabac",
    "tăbăcari": "tăbăcar",
    "tăbăcarii": "tăbăcar",
    "tăbăcarilor": "tăbăcar",
    "tăbăcarul": "tăbăcar",
    "tăbăcarului": "tăbăcar",
    "tăbăcăria": "tăbăcărie",
    "tăbăcăriei": "tăbăcărie",
    "tăbăcării": "tăbăcărie",
    "tăbăcăriile": "tăbăcărie",
    "tăbăcăriilor": "tăbăcărie",
    "tabachera": "tabacheră",
    "tabachere": "tabacheră",
    "tabacherei": "tabacheră",
    "tabacherele": "tabacheră",
    "tabacherelor": "tabacheră",
    "tabachero": "tabacheră",
    "nemaităbăcind": "tăbăci",
    "nemaităbăcindu": "tăbăci",
    "netăbăcind": "tăbăci",
    "netăbăcindu": "tăbăci",
    "tăbăcea": "tăbăci",
    "tăbăceai": "tăbăci",
    "tăbăceam": "tăbăci",
    "tăbăcească": "tăbăci",
    "tăbăceați": "tăbăci",
    "tăbăceau": "tăbăci",
    "tăbăcesc": "tăbăci",
    "tăbăcește": "tăbăci",
    "tăbăcești": "tăbăci",
    "tăbăcii": "tăbăci",
    "tăbăcim": "tăbăci",
    "tăbăcind": "tăbăci",
    "tăbăcindu": "tăbăci",
    "tăbăciră": "tăbăci",
    "tăbăcirăm": "tăbăci",
    "tăbăcirăți": "tăbăci",
    "tăbăcise": "tăbăci",
    "tăbăcisem": "tăbăci",
    "tăbăciseră": "tăbăci",
    "tăbăciserăm": "tăbăci",
    "tăbăciserăți": "tăbăci",
    "tăbăciseși": "tăbăci",
    "tăbăciși": "tăbăci",
    "tăbăcit": "tăbăci",
    "tăbăciți": "tăbăci",
    "tăbăcitu": "tăbăci",
    "tăbăcirea": "tăbăcire",
    "tăbăciri": "tăbăcire",
    "tăbăcirii": "tăbăcire",
    "tăbăcirile": "tăbăcire",
    "tăbăcita": "tăbăcit",
    "tăbăcită": "tăbăcit",
    "tăbăcite": "tăbăcit",
    "tăbăcitei": "tăbăcit",
    "tăbăcitele": "tăbăcit",
    "tăbăcitelor": "tăbăcit",
    "tăbăciți": "tăbăcit",
    "tăbăciții": "tăbăcit",
    "tăbăciților": "tăbăcit",
    "tăbăcitul": "tăbăcit",
    "tăbăcitului": "tăbăcit",
    "tabagismul": "tabagism",
    "tabagismului": "tabagism",
    "tabăra": "tabără",
    "tabere": "tabără",
    "taberei": "tabără",
    "taberele": "tabără",
    "taberelor": "tabără",
    "tăbărâta": "tăbărât",
    "tăbărâtă": "tăbărât",
    "tăbărâte": "tăbărât",
    "tăbărâtei": "tăbărât",
    "tăbărâtele": "tăbărât",
    "tăbărâtelor": "tăbărât",
    "tăbărâți": "tăbărât",
    "tăbărâții": "tăbărât",
    "tăbărâților": "tăbărât",
    "tăbărâtul": "tăbărât",
    "tăbărâtului": "tăbărât",
    "nemaităbărând": "tăbărî",
    "nemaităbărându": "tăbărî",
    "netăbărând": "tăbărî",
    "netăbărându": "tăbărî",
    "tabăr": "tăbărî",
    "tabără": "tăbărî",
    "tăbăra": "tăbărî",
    "tăbărai": "tăbărî",
    "tăbărâi": "tăbărî",
    "tăbăram": "tăbărî",
    "tăbărâm": "tăbărî",
    "tăbărând": "tăbărî",
    "tăbărându": "tăbărî",
    "tăbărâră": "tăbărî",
    "tăbărârăm": "tăbărî",
    "tăbărârăți": "tăbărî",
    "tăbărâse": "tăbărî",
    "tăbărâsem": "tăbărî",
    "tăbărâseră": "tăbărî",
    "tăbărâserăm": "tăbărî",
    "tăbărâserăți": "tăbărî",
    "tăbărâseși": "tăbărî",
    "tăbărâși": "tăbărî",
    "tăbărât": "tăbărî",
    "tăbărați": "tăbărî",
    "tăbărâți": "tăbărî",
    "tăbărâtu": "tăbărî",
    "tăbărau": "tăbărî",
    "tabere": "tăbărî",
    "taberi": "tăbărî",
    "tabele": "tabel",
    "tabelele": "tabel",
    "tabelelor": "tabel",
    "tabelul": "tabel",
    "tabelului": "tabel",
    "tabela": "tabelă",
    "tabele": "tabelă",
    "tabelei": "tabelă",
    "tabelele": "tabelă",
    "tabelelor": "tabelă",
    "tabelo": "tabelă",
    "tabelara": "tabelar",
    "tabelară": "tabelar",
    "tabelare": "tabelar",
    "tabelarei": "tabelar",
    "tabelarele": "tabelar",
    "tabelarelor": "tabelar",
    "tabelari": "tabelar",
    "tabelarii": "tabelar",
    "tabelarilor": "tabelar",
    "tabelarul": "tabelar",
    "tabelarului": "tabelar",
    "tabesul": "tabes",
    "tabesului": "tabes",
    "tabesuri": "tabes",
    "tabesurile": "tabes",
    "tabesurilor": "tabes",
    "tabietul": "tabiet",
    "tabietului": "tabiet",
    "tabieturi": "tabiet",
    "tabieturile": "tabiet",
    "tabieturilor": "tabiet",
    "tabla": "tablă",
    "table": "tablă",
    "tablei": "tablă",
    "tablele": "tablă",
    "tablelor": "tablă",
    "tablo": "tablă",
    "tableta": "tabletă",
    "tablete": "tabletă",
    "tabletei": "tabletă",
    "tabletele": "tabletă",
    "tabletelor": "tabletă",
    "tableto": "tabletă",
    "tăblia": "tăblie",
    "tăbliei": "tăblie",
    "tăblii": "tăblie",
    "tăbliile": "tăblie",
    "tăbliilor": "tăblie",
    "tăblio": "tăblie",
    "tabliere": "tablier",
    "tablierele": "tablier",
    "tablierelor": "tablier",
    "tablierul": "tablier",
    "tablierului": "tablier",
    "tăblița": "tăbliță",
    "tăblițe": "tăbliță",
    "tăbliței": "tăbliță",
    "tăblițele": "tăbliță",
    "tăblițelor": "tăbliță",
    "tabloul": "tablou",
    "tabloului": "tablou",
    "tablouri": "tablou",
    "tablourile": "tablou",
    "tablourilor": "tablou",
    "taboriții": "taboriți",
    "taboriților": "taboriți",
    "tabuul": "tabu",
    "tabuului": "tabu",
    "tabuuri": "tabu",
    "tabuurile": "tabu",
    "tabuurilor": "tabu",
    "tabulara": "tabular",
    "tabulară": "tabular",
    "tabulare": "tabular",
    "tabularei": "tabular",
    "tabularele": "tabular",
    "tabularelor": "tabular",
    "tabulari": "tabular",
    "tabularii": "tabular",
    "tabularilor": "tabular",
    "tabularul": "tabular",
    "tabularului": "tabular",
    "tăburele": "tăburel",
    "tăburelele": "tăburel",
    "tăburelelor": "tăburel",
    "tăburelul": "tăburel",
    "tăburelului": "tăburel",
    "taburete": "taburet",
    "taburetele": "taburet",
    "taburetelor": "taburet",
    "taburetul": "taburet",
    "taburetule": "taburet",
    "taburetului": "taburet",
    "nemaițăcănind": "țăcăni",
    "nemaițăcănindu": "țăcăni",
    "nețăcănind": "țăcăni",
    "nețăcănindu": "țăcăni",
    "țăcăn": "țăcăni",
    "țăcăne": "țăcăni",
    "țăcănea": "țăcăni",
    "țăcăneai": "țăcăni",
    "țăcăneam": "țăcăni",
    "țăcăneați": "țăcăni",
    "țăcăneau": "țăcăni",
    "țăcănii": "țăcăni",
    "țăcănim": "țăcăni",
    "țăcănind": "țăcăni",
    "țăcănindu": "țăcăni",
    "țăcăniră": "țăcăni",
    "țăcănirăm": "țăcăni",
    "țăcănirăți": "țăcăni",
    "țăcănise": "țăcăni",
    "țăcănisem": "țăcăni",
    "țăcăniseră": "țăcăni",
    "țăcăniserăm": "țăcăni",
    "țăcăniserăți": "țăcăni",
    "țăcăniseși": "țăcăni",
    "țăcăniși": "țăcăni",
    "țăcănit": "țăcăni",
    "țăcăniți": "țăcăni",
    "țăcănita": "țăcănit",
    "țăcănită": "țăcănit",
    "țăcănite": "țăcănit",
    "țăcănitei": "țăcănit",
    "țăcănitele": "țăcănit",
    "țăcănitelor": "țăcănit",
    "țăcăniți": "țăcănit",
    "țăcăniții": "țăcănit",
    "țăcăniților": "țăcănit",
    "țăcănitul": "țăcănit",
    "țăcănitului": "țăcănit",
    "nemaităcând": "tăcea",
    "nemaităcându": "tăcea",
    "netăcând": "tăcea",
    "netăcându": "tăcea",
    "tac": "tăcea",
    "tacă": "tăcea",
    "tăcând": "tăcea",
    "tăcându": "tăcea",
    "tace": "tăcea",
    "tăceai": "tăcea",
    "tăceam": "tăcea",
    "tăceați": "tăcea",
    "tăceau": "tăcea",
    "tăcem": "tăcea",
    "tăceți": "tăcea",
    "taci": "tăcea",
    "tăcu": "tăcea",
    "tăcui": "tăcea",
    "tăcură": "tăcea",
    "tăcurăm": "tăcea",
    "tăcurăți": "tăcea",
    "tăcuse": "tăcea",
    "tăcusem": "tăcea",
    "tăcuseră": "tăcea",
    "tăcuserăm": "tăcea",
    "tăcuserăți": "tăcea",
    "tăcuseși": "tăcea",
    "tăcuși": "tăcea",
    "tăcut": "tăcea",
    "tăcutu": "tăcea",
    "tăcerea": "tăcere",
    "tăcereo": "tăcere",
    "tăceri": "tăcere",
    "tăcerii": "tăcere",
    "tăcerile": "tăcere",
    "tăcerilor": "tăcere",
    "nemaitachinând": "tachina",
    "nemaitachinându": "tachina",
    "netachinând": "tachina",
    "netachinându": "tachina",
    "tachină": "tachina",
    "tachinai": "tachina",
    "tachinam": "tachina",
    "tachinăm": "tachina",
    "tachinând": "tachina",
    "tachinându": "tachina",
    "tachinară": "tachina",
    "tachinarăm": "tachina",
    "tachinarăți": "tachina",
    "tachinase": "tachina",
    "tachinasem": "tachina",
    "tachinaseră": "tachina",
    "tachinaserăm": "tachina",
    "tachinaserăți": "tachina",
    "tachinaseși": "tachina",
    "tachinași": "tachina",
    "tachinat": "tachina",
    "tachinați": "tachina",
    "tachinatu": "tachina",
    "tachinau": "tachina",
    "tachinează": "tachina",
    "tachinez": "tachina",
    "tachineze": "tachina",
    "tachinezi": "tachina",
    "tachinarea": "tachinare",
    "tachinări": "tachinare",
    "tachinării": "tachinare",
    "tachinările": "tachinare",
    "tachinata": "tachinat",
    "tachinată": "tachinat",
    "tachinate": "tachinat",
    "tachinatei": "tachinat",
    "tachinatele": "tachinat",
    "tachinatelor": "tachinat",
    "tachinați": "tachinat",
    "tachinații": "tachinat",
    "tachinaților": "tachinat",
    "tachinatul": "tachinat",
    "tachinatului": "tachinat",
    "tacita": "tacit",
    "tacită": "tacit",
    "tacite": "tacit",
    "tacitei": "tacit",
    "tacitele": "tacit",
    "tacitelor": "tacit",
    "taciți": "tacit",
    "taciții": "tacit",
    "taciților": "tacit",
    "tacito": "tacit",
    "tacitul": "tacit",
    "tacitule": "tacit",
    "tacitului": "tacit",
    "taciturna": "taciturn",
    "taciturnă": "taciturn",
    "taciturne": "taciturn",
    "taciturnei": "taciturn",
    "taciturnele": "taciturn",
    "taciturnelor": "taciturn",
    "taciturni": "taciturn",
    "taciturnii": "taciturn",
    "taciturnilor": "taciturn",
    "taciturnul": "taciturn",
    "taciturnului": "taciturn",
    "tăciunele": "tăciune",
    "tăciunelui": "tăciune",
    "tăciuni": "tăciune",
    "tăciunii": "tăciune",
    "tăciunilor": "tăciune",
    "taclalele": "taclale",
    "taclalelor": "taclale",
    "tactul": "tact",
    "tactului": "tact",
    "tacturi": "tact",
    "tacturile": "tact",
    "tacturilor": "tact",
    "tactica": "tactic",
    "tactică": "tactic",
    "tactice": "tactic",
    "tacticei": "tactic",
    "tacticele": "tactic",
    "tacticelor": "tactic",
    "tactici": "tactic",
    "tacticii": "tactic",
    "tacticilor": "tactic",
    "tacticul": "tactic",
    "tacticului": "tactic",
    "tacticoasa": "tacticos",
    "tacticoasă": "tacticos",
    "tacticoase": "tacticos",
    "tacticoasei": "tacticos",
    "tacticoasele": "tacticos",
    "tacticoaselor": "tacticos",
    "tacticoși": "tacticos",
    "tacticoșii": "tacticos",
    "tacticoșilor": "tacticos",
    "tacticosul": "tacticos",
    "tacticosului": "tacticos",
    "tactila": "tactil",
    "tactilă": "tactil",
    "tactile": "tactil",
    "tactilei": "tactil",
    "tactilele": "tactil",
    "tactilelor": "tactil",
    "tactili": "tactil",
    "tactilii": "tactil",
    "tactililor": "tactil",
    "tactilul": "tactil",
    "tactilului": "tactil",
    "tăcuta": "tăcut",
    "tăcută": "tăcut",
    "tăcute": "tăcut",
    "tăcutei": "tăcut",
    "tăcutele": "tăcut",
    "tăcutelor": "tăcut",
    "tăcuți": "tăcut",
    "tăcuții": "tăcut",
    "tăcuților": "tăcut",
    "tăcuto": "tăcut",
    "tăcutul": "tăcut",
    "tăcutule": "tăcut",
    "tăcutului": "tăcut",
    "tadjico-afgana": "tadjico-afgan",
    "tadjico-afgană": "tadjico-afgan",
    "tadjico-afgane": "tadjico-afgan",
    "tadjico-afganei": "tadjico-afgan",
    "tadjico-afganele": "tadjico-afgan",
    "tadjico-afganelor": "tadjico-afgan",
    "tadjico-afgani": "tadjico-afgan",
    "tadjico-afganii": "tadjico-afgan",
    "tadjico-afganilor": "tadjico-afgan",
    "tadjico-afganul": "tadjico-afgan",
    "tadjico-afganului": "tadjico-afgan",
    "tadjică": "tadjik",
    "tadjice": "tadjik",
    "tadjicei": "tadjik",
    "tadjicele": "tadjik",
    "tadjicelor": "tadjik",
    "tadjici": "tadjik",
    "tadjicii": "tadjik",
    "tadjicilor": "tadjik",
    "tadjika": "tadjik",
    "tadjikul": "tadjik",
    "tadjikului": "tadjik",
    "tadjice": "tadjikă",
    "tadjicei": "tadjikă",
    "tadjicele": "tadjikă",
    "tadjicelor": "tadjikă",
    "tadjika": "tadjikă",
    "tafturi": "taftur",
    "tafturile": "taftur",
    "tafturilor": "taftur",
    "tafturul": "taftur",
    "tafturului": "taftur",
    "nemaităgăduind": "tăgădui",
    "nemaităgăduindu": "tăgădui",
    "netăgăduind": "tăgădui",
    "netăgăduindu": "tăgădui",
    "netăgăduit": "tăgădui",
    "tăgăduia": "tăgădui",
    "tăgăduiai": "tăgădui",
    "tăgăduiam": "tăgădui",
    "tăgăduiască": "tăgădui",
    "tăgăduiați": "tăgădui",
    "tăgăduiau": "tăgădui",
    "tăgăduiesc": "tăgădui",
    "tăgăduiește": "tăgădui",
    "tăgăduiești": "tăgădui",
    "tăgăduii": "tăgădui",
    "tăgăduim": "tăgădui",
    "tăgăduind": "tăgădui",
    "tăgăduindu": "tăgădui",
    "tăgăduiră": "tăgădui",
    "tăgăduirăm": "tăgădui",
    "tăgăduirăți": "tăgădui",
    "tăgăduise": "tăgădui",
    "tăgăduisem": "tăgădui",
    "tăgăduiseră": "tăgădui",
    "tăgăduiserăm": "tăgădui",
    "tăgăduiserăți": "tăgădui",
    "tăgăduiseși": "tăgădui",
    "tăgăduiși": "tăgădui",
    "tăgăduit": "tăgădui",
    "tăgăduiți": "tăgădui",
    "tăgăduitu": "tăgădui",
    "tăgăduirea": "tăgăduire",
    "tăgăduiri": "tăgăduire",
    "tăgăduirii": "tăgăduire",
    "tăgăduirile": "tăgăduire",
    "tăgăduita": "tăgăduit",
    "tăgăduită": "tăgăduit",
    "tăgăduite": "tăgăduit",
    "tăgăduitei": "tăgăduit",
    "tăgăduitele": "tăgăduit",
    "tăgăduitelor": "tăgăduit",
    "tăgăduiți": "tăgăduit",
    "tăgăduiții": "tăgăduit",
    "tăgăduiților": "tăgăduit",
    "tăgăduitul": "tăgăduit",
    "tăgăduitului": "tăgăduit",
    "tăgârța": "tăgârță",
    "tăgârțe": "tăgârță",
    "tăgârței": "tăgârță",
    "tăgârțele": "tăgârță",
    "tăgârțelor": "tăgârță",
    "tagma": "tagmă",
    "tagme": "tagmă",
    "tagmei": "tagmă",
    "tagmele": "tagmă",
    "tagmelor": "tagmă",
    "tahânul": "tahân",
    "tahânului": "tahân",
    "tahânuri": "tahân",
    "tahânurile": "tahân",
    "tahânurilor": "tahân",
    "tahicardia": "tahicardie",
    "tahicardiei": "tahicardie",
    "tahicardii": "tahicardie",
    "tahicardiile": "tahicardie",
    "tahicardiilor": "tahicardie",
    "tahipneea": "tahipnee",
    "tahipneei": "tahipnee",
    "tahipneele": "tahipnee",
    "tahipneelor": "tahipnee",
    "nemaităind": "tăia",
    "nemaităindu": "tăia",
    "netăind": "tăia",
    "netăindu": "tăia",
    "tai": "tăia",
    "tăiai": "tăia",
    "tăiam": "tăia",
    "tăiară": "tăia",
    "tăiarăm": "tăia",
    "tăiarăți": "tăia",
    "tăiase": "tăia",
    "tăiasem": "tăia",
    "tăiaseră": "tăia",
    "tăiaserăm": "tăia",
    "tăiaserăți": "tăia",
    "tăiaseși": "tăia",
    "tăiași": "tăia",
    "tăiat": "tăia",
    "tăiați": "tăia",
    "tăiatu": "tăia",
    "tăiau": "tăia",
    "taie": "tăia",
    "tăie": "tăia",
    "tăiem": "tăia",
    "tăind": "tăia",
    "tăindu": "tăia",
    "tăiabilă": "tăiabil",
    "tăiabile": "tăiabil",
    "tăiabili": "tăiabil",
    "tăiata": "tăiat",
    "tăiată": "tăiat",
    "tăiate": "tăiat",
    "tăiatei": "tăiat",
    "tăiatele": "tăiat",
    "tăiatelor": "tăiat",
    "tăiați": "tăiat",
    "tăiații": "tăiat",
    "tăiaților": "tăiat",
    "tăiatul": "tăiat",
    "tăiatului": "tăiat",
    "taica": "taică",
    "taicii": "taică",
    "tăicuța": "taică",
    "tăicuță": "taică",
    "tăicuței": "taică",
    "tăicuți": "taică",
    "tăicuții": "taică",
    "tăicuților": "taică",
    "tăierea": "tăiere",
    "tăieri": "tăiere",
    "tăierii": "tăiere",
    "tăierile": "tăiere",
    "tăierilor": "tăiere",
    "tăietoarea": "tăietoare",
    "tăietoarei": "tăietoare",
    "tăietoarele": "tăietoare",
    "tăietoarelor": "tăietoare",
    "tăietoare": "tăietor",
    "tăietoarea": "tăietor",
    "tăietoarei": "tăietor",
    "tăietoarele": "tăietor",
    "tăietoarelor": "tăietor",
    "tăietori": "tăietor",
    "tăietorii": "tăietor",
    "tăietorilor": "tăietor",
    "tăietorul": "tăietor",
    "tăietorului": "tăietor",
    "tăietura": "tăietură",
    "tăieturi": "tăietură",
    "tăieturii": "tăietură",
    "tăieturile": "tăietură",
    "tăieturilor": "tăietură",
    "taifasul": "taifas",
    "taifasului": "taifas",
    "taifasuri": "taifas",
    "taifasurile": "taifas",
    "taifasurilor": "taifas",
    "taifunul": "taifun",
    "taifunului": "taifun",
    "taifunuri": "taifun",
    "taifunurile": "taifun",
    "taifunurilor": "taifun",
    "taigale": "taiga",
    "taigalei": "taiga",
    "taigalele": "taiga",
    "taigalelor": "taiga",
    "taigaua": "taiga",
    "taim-auturi": "taim-aut",
    "tainul": "tain",
    "tainului": "tain",
    "tainuri": "tain",
    "tainurile": "tain",
    "tainurilor": "tain",
    "taina": "taină",
    "taine": "taină",
    "tainei": "taină",
    "tainele": "taină",
    "tainelor": "taină",
    "tainica": "tainic",
    "tainică": "tainic",
    "tainice": "tainic",
    "tainicei": "tainic",
    "tainicele": "tainic",
    "tainicelor": "tainic",
    "tainici": "tainic",
    "tainicii": "tainic",
    "tainicilor": "tainic",
    "tainicul": "tainic",
    "tainicului": "tainic",
    "tainița": "tainiță",
    "tainițe": "tainiță",
    "tainiței": "tainiță",
    "tainițele": "tainiță",
    "tainițelor": "tainiță",
    "nemaităinuind": "tăinui",
    "nemaităinuindu": "tăinui",
    "netăinuind": "tăinui",
    "netăinuindu": "tăinui",
    "tăinuia": "tăinui",
    "tăinuiai": "tăinui",
    "tăinuiam": "tăinui",
    "tăinuiască": "tăinui",
    "tăinuiați": "tăinui",
    "tăinuiau": "tăinui",
    "tăinuiesc": "tăinui",
    "tăinuiește": "tăinui",
    "tăinuiești": "tăinui",
    "tăinuii": "tăinui",
    "tăinuim": "tăinui",
    "tăinuind": "tăinui",
    "tăinuindu": "tăinui",
    "tăinuiră": "tăinui",
    "tăinuirăm": "tăinui",
    "tăinuirăți": "tăinui",
    "tăinuise": "tăinui",
    "tăinuisem": "tăinui",
    "tăinuiseră": "tăinui",
    "tăinuiserăm": "tăinui",
    "tăinuiserăți": "tăinui",
    "tăinuiseși": "tăinui",
    "tăinuiși": "tăinui",
    "tăinuit": "tăinui",
    "tăinuiți": "tăinui",
    "tăinuitu": "tăinui",
    "tăinuirea": "tăinuire",
    "tăinuiri": "tăinuire",
    "tăinuirii": "tăinuire",
    "tăinuirile": "tăinuire",
    "tăinuita": "tăinuit",
    "tăinuită": "tăinuit",
    "tăinuite": "tăinuit",
    "tăinuitei": "tăinuit",
    "tăinuitele": "tăinuit",
    "tăinuitelor": "tăinuit",
    "tăinuiți": "tăinuit",
    "tăinuiții": "tăinuit",
    "tăinuiților": "tăinuit",
    "tăinuitul": "tăinuit",
    "tăinuitului": "tăinuit",
    "taioare": "taior",
    "taioarele": "taior",
    "taioarelor": "taior",
    "taiorul": "taior",
    "taiorului": "taior",
    "tăioasa": "tăios",
    "tăioasă": "tăios",
    "tăioase": "tăios",
    "tăioasei": "tăios",
    "tăioasele": "tăios",
    "tăioaselor": "tăios",
    "tăioaso": "tăios",
    "tăioși": "tăios",
    "tăioșii": "tăios",
    "tăioșilor": "tăios",
    "tăiosul": "tăios",
    "tăiosule": "tăios",
    "tăiosului": "tăios",
    "tăișul": "tăiș",
    "tăișului": "tăiș",
    "tăișuri": "tăiș",
    "tăișurile": "tăiș",
    "tăișurilor": "tăiș",
    "Taiwanul": "Taiwan",
    "talajul": "talaj",
    "talajului": "talaj",
    "talajuri": "talaj",
    "talajurile": "talaj",
    "talajurilor": "talaj",
    "talamusul": "talamus",
    "talamusului": "talamus",
    "talamusuri": "talamus",
    "talamusurile": "talamus",
    "talamusurilor": "talamus",
    "talanți": "talant",
    "talanții": "talant",
    "talanților": "talant",
    "talantul": "talant",
    "talantului": "talant",
    "talașul": "talaș",
    "talașule": "talaș",
    "talașului": "talaș",
    "talașuri": "talaș",
    "talașurile": "talaș",
    "talașurilor": "talaș",
    "talasografia": "talasografie",
    "talasografiei": "talasografie",
    "talasografii": "talasografie",
    "talasografiile": "talasografie",
    "talasografiilor": "talasografie",
    "talasoterapia": "talasoterapie",
    "talasoterapiei": "talasoterapie",
    "talasoterapii": "talasoterapie",
    "talasoterapiile": "talasoterapie",
    "talasoterapiilor": "talasoterapie",
    "talazul": "talaz",
    "talazului": "talaz",
    "talazuri": "talaz",
    "talazurile": "talaz",
    "talazurilor": "talaz",
    "nemaitălăzuind": "tălăzui",
    "nemaitălăzuindu": "tălăzui",
    "netălăzuind": "tălăzui",
    "netălăzuindu": "tălăzui",
    "tălăzuia": "tălăzui",
    "tălăzuiai": "tălăzui",
    "tălăzuiam": "tălăzui",
    "tălăzuiască": "tălăzui",
    "tălăzuiați": "tălăzui",
    "tălăzuiau": "tălăzui",
    "tălăzuiesc": "tălăzui",
    "tălăzuiește": "tălăzui",
    "tălăzuiești": "tălăzui",
    "tălăzuii": "tălăzui",
    "tălăzuim": "tălăzui",
    "tălăzuind": "tălăzui",
    "tălăzuindu": "tălăzui",
    "tălăzuiră": "tălăzui",
    "tălăzuirăm": "tălăzui",
    "tălăzuirăți": "tălăzui",
    "tălăzuise": "tălăzui",
    "tălăzuisem": "tălăzui",
    "tălăzuiseră": "tălăzui",
    "tălăzuiserăm": "tălăzui",
    "tălăzuiserăți": "tălăzui",
    "tălăzuiseși": "tălăzui",
    "tălăzuiși": "tălăzui",
    "tălăzuit": "tălăzui",
    "tălăzuiți": "tălăzui",
    "tălăzuitu": "tălăzui",
    "tălăzuirea": "tălăzuire",
    "tălăzuiri": "tălăzuire",
    "tălăzuirii": "tălăzuire",
    "tălăzuirile": "tălăzuire",
    "tălăzuita": "tălăzuit",
    "tălăzuită": "tălăzuit",
    "tălăzuite": "tălăzuit",
    "tălăzuitei": "tălăzuit",
    "tălăzuitele": "tălăzuit",
    "tălăzuitelor": "tălăzuit",
    "tălăzuiți": "tălăzuit",
    "tălăzuiții": "tălăzuit",
    "tălăzuiților": "tălăzuit",
    "tălăzuitul": "tălăzuit",
    "tălăzuitului": "tălăzuit",
    "tâlcul": "tâlc",
    "tâlcului": "tâlc",
    "tâlcuri": "tâlc",
    "tâlcurile": "tâlc",
    "tâlcurilor": "tâlc",
    "talciocul": "talcioc",
    "talciocului": "talcioc",
    "talciocuri": "talcioc",
    "talciocurile": "talcioc",
    "talciocurilor": "talcioc",
    "nemaitâlcuind": "tâlcui",
    "nemaitâlcuindu": "tâlcui",
    "netâlcuind": "tâlcui",
    "netâlcuindu": "tâlcui",
    "tâlcuia": "tâlcui",
    "tâlcuiai": "tâlcui",
    "tâlcuiam": "tâlcui",
    "tâlcuiască": "tâlcui",
    "tâlcuiați": "tâlcui",
    "tâlcuiau": "tâlcui",
    "tâlcuiesc": "tâlcui",
    "tâlcuiește": "tâlcui",
    "tâlcuiești": "tâlcui",
    "tâlcuii": "tâlcui",
    "tâlcuim": "tâlcui",
    "tâlcuind": "tâlcui",
    "tâlcuindu": "tâlcui",
    "tâlcuiră": "tâlcui",
    "tâlcuirăm": "tâlcui",
    "tâlcuirăți": "tâlcui",
    "tâlcuise": "tâlcui",
    "tâlcuisem": "tâlcui",
    "tâlcuiseră": "tâlcui",
    "tâlcuiserăm": "tâlcui",
    "tâlcuiserăți": "tâlcui",
    "tâlcuiseși": "tâlcui",
    "tâlcuiși": "tâlcui",
    "tâlcuit": "tâlcui",
    "tâlcuiți": "tâlcui",
    "tâlcuitu": "tâlcui",
    "tâlcuirea": "tâlcuire",
    "tâlcuiri": "tâlcuire",
    "tâlcuirii": "tâlcuire",
    "tâlcuirile": "tâlcuire",
    "tâlcuita": "tâlcuit",
    "tâlcuită": "tâlcuit",
    "tâlcuite": "tâlcuit",
    "tâlcuitei": "tâlcuit",
    "tâlcuitele": "tâlcuit",
    "tâlcuitelor": "tâlcuit",
    "tâlcuiți": "tâlcuit",
    "tâlcuiții": "tâlcuit",
    "tâlcuiților": "tâlcuit",
    "tâlcuitul": "tâlcuit",
    "tâlcuitului": "tâlcuit",
    "talente": "talent",
    "talentele": "talent",
    "talentelor": "talent",
    "talentul": "talent",
    "talentului": "talent",
    "talentata": "talentat",
    "talentată": "talentat",
    "talentate": "talentat",
    "talentatei": "talentat",
    "talentatele": "talentat",
    "talentatelor": "talentat",
    "talentați": "talentat",
    "talentații": "talentat",
    "talentaților": "talentat",
    "talentatul": "talentat",
    "talentatului": "talentat",
    "talere": "taler",
    "talerele": "taler",
    "talerelor": "taler",
    "talerul": "taler",
    "talerului": "taler",
    "talgere": "talger",
    "talgerele": "talger",
    "talgerelor": "talger",
    "talgerul": "talger",
    "talgerului": "talger",
    "tâlhari": "tâlhar",
    "tâlharii": "tâlhar",
    "tâlharilor": "tâlhar",
    "tâlharul": "tâlhar",
    "tâlharului": "tâlhar",
    "tâlhăria": "tâlhărie",
    "tâlhăriei": "tâlhărie",
    "tâlhării": "tâlhărie",
    "tâlhăriile": "tâlhărie",
    "tâlhăriilor": "tâlhărie",
    "tâlhărita": "tâlhărit",
    "tâlhărită": "tâlhărit",
    "tâlhărite": "tâlhărit",
    "tâlhăritei": "tâlhărit",
    "tâlhăritele": "tâlhărit",
    "tâlhăritelor": "tâlhărit",
    "tâlhăriți": "tâlhărit",
    "tâlhăriții": "tâlhărit",
    "tâlhăriților": "tâlhărit",
    "tâlhăritul": "tâlhărit",
    "tâlhăritului": "tâlhărit",
    "talia": "talie",
    "taliei": "talie",
    "talii": "talie",
    "taliile": "talie",
    "taliilor": "talie",
    "talioane": "talion",
    "talioanele": "talion",
    "talioanelor": "talion",
    "talionul": "talion",
    "talionului": "talion",
    "talismane": "talisman",
    "talismanele": "talisman",
    "talismanelor": "talisman",
    "talismanul": "talisman",
    "talismanului": "talisman",
    "taliul": "taliu",
    "taliului": "taliu",
    "Tl": "taliu",
    "tălmacii": "tălmaci",
    "tălmacilor": "tălmaci",
    "tălmaciul": "tălmaci",
    "tălmaciului": "tălmaci",
    "nemaitălmăcind": "tălmăci",
    "nemaitălmăcindu": "tălmăci",
    "netălmăcind": "tălmăci",
    "netălmăcindu": "tălmăci",
    "tălmăcea": "tălmăci",
    "tălmăceai": "tălmăci",
    "tălmăceam": "tălmăci",
    "tălmăcească": "tălmăci",
    "tălmăceați": "tălmăci",
    "tălmăceau": "tălmăci",
    "tălmăcesc": "tălmăci",
    "tălmăcește": "tălmăci",
    "tălmăcești": "tălmăci",
    "tălmăcii": "tălmăci",
    "tălmăcim": "tălmăci",
    "tălmăcind": "tălmăci",
    "tălmăcindu": "tălmăci",
    "tălmăciră": "tălmăci",
    "tălmăcirăm": "tălmăci",
    "tălmăcirăți": "tălmăci",
    "tălmăcise": "tălmăci",
    "tălmăcisem": "tălmăci",
    "tălmăciseră": "tălmăci",
    "tălmăciserăm": "tălmăci",
    "tălmăciserăți": "tălmăci",
    "tălmăciseși": "tălmăci",
    "tălmăciși": "tălmăci",
    "tălmăcit": "tălmăci",
    "tălmăciți": "tălmăci",
    "tălmăcitu": "tălmăci",
    "tălmăcirea": "tălmăcire",
    "tălmăciri": "tălmăcire",
    "tălmăcirii": "tălmăcire",
    "tălmăcirile": "tălmăcire",
    "tălmăcita": "tălmăcit",
    "tălmăcită": "tălmăcit",
    "tălmăcite": "tălmăcit",
    "tălmăcitei": "tălmăcit",
    "tălmăcitele": "tălmăcit",
    "tălmăcitelor": "tălmăcit",
    "tălmăciți": "tălmăcit",
    "tălmăciții": "tălmăcit",
    "tălmăciților": "tălmăcit",
    "tălmăcitul": "tălmăcit",
    "tălmăcitului": "tălmăcit",
    "taloane": "talon",
    "taloanele": "talon",
    "taloanelor": "talon",
    "talonul": "talon",
    "talonului": "talon",
    "nemaitalonând": "talona",
    "nemaitalonându": "talona",
    "netalonând": "talona",
    "netalonându": "talona",
    "talonă": "talona",
    "talonai": "talona",
    "talonam": "talona",
    "talonăm": "talona",
    "talonând": "talona",
    "talonându": "talona",
    "talonară": "talona",
    "talonarăm": "talona",
    "talonarăți": "talona",
    "talonase": "talona",
    "talonasem": "talona",
    "talonaseră": "talona",
    "talonaserăm": "talona",
    "talonaserăți": "talona",
    "talonaseși": "talona",
    "talonași": "talona",
    "talonat": "talona",
    "talonați": "talona",
    "talonatu": "talona",
    "talonau": "talona",
    "talonează": "talona",
    "talonez": "talona",
    "taloneze": "talona",
    "talonezi": "talona",
    "talonarea": "talonare",
    "talonareo": "talonare",
    "talonări": "talonare",
    "talonării": "talonare",
    "talonările": "talonare",
    "talonărilor": "talonare",
    "talonata": "talonat",
    "talonată": "talonat",
    "talonate": "talonat",
    "talonatei": "talonat",
    "talonatele": "talonat",
    "talonatelor": "talonat",
    "talonați": "talonat",
    "talonații": "talonat",
    "talonaților": "talonat",
    "talonato": "talonat",
    "talonatul": "talonat",
    "talonatule": "talonat",
    "talonatului": "talonat",
    "taloneta": "talonetă",
    "talonete": "talonetă",
    "talonetei": "talonetă",
    "talonetele": "talonetă",
    "talonetelor": "talonetă",
    "talpa": "talpă",
    "tălpi": "talpă",
    "tălpii": "talpă",
    "tălpile": "talpă",
    "tălpilor": "talpă",
    "talpo": "talpă",
    "tălpășița": "tălpășiță",
    "tălpășițe": "tălpășiță",
    "tălpășiței": "tălpășiță",
    "tălpășițele": "tălpășiță",
    "tălpășițelor": "tălpășiță",
    "tălpuia": "tălpui",
    "tălpuiai": "tălpui",
    "tălpuiam": "tălpui",
    "tălpuiați": "tălpui",
    "tălpuiau": "tălpui",
    "tălpuiesc": "tălpui",
    "tălpuiește": "tălpui",
    "tălpuii": "tălpui",
    "tălpuim": "tălpui",
    "tălpuind": "tălpui",
    "tălpuindu": "tălpui",
    "tălpuiră": "tălpui",
    "tălpuirăm": "tălpui",
    "tălpuirăți": "tălpui",
    "tălpuise": "tălpui",
    "tălpuisem": "tălpui",
    "tălpuiseră": "tălpui",
    "tălpuiserăm": "tălpui",
    "tălpuiserăți": "tălpui",
    "tălpuiseși": "tălpui",
    "tălpuiși": "tălpui",
    "tălpuit": "tălpui",
    "tălpuiți": "tălpui",
    "tălpuitu": "tălpui",
    "tălpuirea": "tălpuire",
    "tălpuiri": "tălpuire",
    "tălpuirii": "tălpuire",
    "tălpuirile": "tălpuire",
    "tălpuirilor": "tălpuire",
    "tălpuită": "tălpuit",
    "tălpuite": "tălpuit",
    "tălpuiți": "tălpuit",
    "taluzul": "taluz",
    "taluzului": "taluz",
    "taluzuri": "taluz",
    "taluzurile": "taluz",
    "taluzurilor": "taluz",
    "nemaitămăduind": "tămădui",
    "nemaitămăduindu": "tămădui",
    "netămăduind": "tămădui",
    "netămăduindu": "tămădui",
    "tămăduia": "tămădui",
    "tămăduiai": "tămădui",
    "tămăduiam": "tămădui",
    "tămăduiască": "tămădui",
    "tămăduiați": "tămădui",
    "tămăduiau": "tămădui",
    "tămăduiesc": "tămădui",
    "tămăduiește": "tămădui",
    "tămăduiești": "tămădui",
    "tămăduii": "tămădui",
    "tămăduim": "tămădui",
    "tămăduind": "tămădui",
    "tămăduindu": "tămădui",
    "tămăduiră": "tămădui",
    "tămăduirăm": "tămădui",
    "tămăduirăți": "tămădui",
    "tămăduise": "tămădui",
    "tămăduisem": "tămădui",
    "tămăduiseră": "tămădui",
    "tămăduiserăm": "tămădui",
    "tămăduiserăți": "tămădui",
    "tămăduiseși": "tămădui",
    "tămăduiși": "tămădui",
    "tămăduit": "tămădui",
    "tămăduiți": "tămădui",
    "tămăduitu": "tămădui",
    "tămăduirea": "tămăduire",
    "tămăduiri": "tămăduire",
    "tămăduirii": "tămăduire",
    "tămăduirile": "tămăduire",
    "tămăduita": "tămăduit",
    "tămăduită": "tămăduit",
    "tămăduite": "tămăduit",
    "tămăduitei": "tămăduit",
    "tămăduitele": "tămăduit",
    "tămăduitelor": "tămăduit",
    "tămăduiți": "tămăduit",
    "tămăduiții": "tămăduit",
    "tămăduiților": "tămăduit",
    "tămăduitul": "tămăduit",
    "tămăduitului": "tămăduit",
    "tămăduitoarea": "tămăduitoare",
    "tămăduitoarei": "tămăduitoare",
    "tămăduitoarele": "tămăduitoare",
    "tămăduitoarelor": "tămăduitoare",
    "tămăduitoare": "tămăduitor",
    "tămăduitoarea": "tămăduitor",
    "tămăduitoarei": "tămăduitor",
    "tămăduitoarele": "tămăduitor",
    "tămăduitoarelor": "tămăduitor",
    "tămăduitori": "tămăduitor",
    "tămăduitorii": "tămăduitor",
    "tămăduitorilor": "tămăduitor",
    "tămăduitorul": "tămăduitor",
    "tămăduitorului": "tămăduitor",
    "nemaitămâiind": "tămâia",
    "nemaitămâiindu": "tămâia",
    "netămâiind": "tămâia",
    "netămâiindu": "tămâia",
    "tămâiai": "tămâia",
    "tămâiam": "tămâia",
    "tămâiară": "tămâia",
    "tămâiarăm": "tămâia",
    "tămâiarăți": "tămâia",
    "tămâiase": "tămâia",
    "tămâiasem": "tămâia",
    "tămâiaseră": "tămâia",
    "tămâiaserăm": "tămâia",
    "tămâiaserăți": "tămâia",
    "tămâiaseși": "tămâia",
    "tămâiași": "tămâia",
    "tămâiat": "tămâia",
    "tămâiați": "tămâia",
    "tămâiatu": "tămâia",
    "tămâiau": "tămâia",
    "tămâiază": "tămâia",
    "tămâie": "tămâia",
    "tămâiem": "tămâia",
    "tămâiez": "tămâia",
    "tămâieze": "tămâia",
    "tămâiezi": "tămâia",
    "tămâind": "tămâia",
    "tămâindu": "tămâia",
    "tămâiata": "tămâiat",
    "tămâiată": "tămâiat",
    "tămâiate": "tămâiat",
    "tămâiatei": "tămâiat",
    "tămâiatele": "tămâiat",
    "tămâiatelor": "tămâiat",
    "tămâiați": "tămâiat",
    "tămâiații": "tămâiat",
    "tămâiaților": "tămâiat",
    "tămâiatul": "tămâiat",
    "tămâiatului": "tămâiat",
    "tămâia": "tămâie",
    "tămâiei": "tămâie",
    "tămâiele": "tămâie",
    "tămâii": "tămâie",
    "tămâilor": "tămâie",
    "tămâierea": "tămâiere",
    "tămâieri": "tămâiere",
    "tămâierii": "tămâiere",
    "tămâierile": "tămâiere",
    "țambale": "țambal",
    "țambalele": "țambal",
    "țambalelor": "țambal",
    "țambalul": "țambal",
    "țambalului": "țambal",
    "țambalagii": "țambalagiu",
    "țambalagiii": "țambalagiu",
    "țambalagiilor": "țambalagiu",
    "țambalagiul": "țambalagiu",
    "țambalagiului": "țambalagiu",
    "tamburi": "tambur",
    "tamburii": "tambur",
    "tamburilor": "tambur",
    "tamburul": "tambur",
    "tamburului": "tambur",
    "tambur-majori": "tambur-major",
    "tâmpa": "tâmp",
    "tâmpă": "tâmp",
    "tâmpe": "tâmp",
    "tâmpei": "tâmp",
    "tâmpele": "tâmp",
    "tâmpelor": "tâmp",
    "tâmpi": "tâmp",
    "tâmpii": "tâmp",
    "tâmpilor": "tâmp",
    "tâmpul": "tâmp",
    "tâmpului": "tâmp",
    "tâmpenia": "tâmpenie",
    "tâmpeniei": "tâmpenie",
    "tâmpenii": "tâmpenie",
    "tâmpeniile": "tâmpenie",
    "tâmpeniilor": "tâmpenie",
    "nemaitâmpind": "tâmpi",
    "nemaitâmpindu": "tâmpi",
    "netâmpind": "tâmpi",
    "netâmpindu": "tâmpi",
    "tâmpea": "tâmpi",
    "tâmpeai": "tâmpi",
    "tâmpeam": "tâmpi",
    "tâmpească": "tâmpi",
    "tâmpeați": "tâmpi",
    "tâmpeau": "tâmpi",
    "tâmpesc": "tâmpi",
    "tâmpește": "tâmpi",
    "tâmpești": "tâmpi",
    "tâmpii": "tâmpi",
    "tâmpim": "tâmpi",
    "tâmpind": "tâmpi",
    "tâmpindu": "tâmpi",
    "tâmpiră": "tâmpi",
    "tâmpirăm": "tâmpi",
    "tâmpirăți": "tâmpi",
    "tâmpise": "tâmpi",
    "tâmpisem": "tâmpi",
    "tâmpiseră": "tâmpi",
    "tâmpiserăm": "tâmpi",
    "tâmpiserăți": "tâmpi",
    "tâmpiseși": "tâmpi",
    "tâmpiși": "tâmpi",
    "tâmpit": "tâmpi",
    "tâmpiți": "tâmpi",
    "tâmpitu": "tâmpi",
    "tâmpirea": "tâmpire",
    "tâmpiri": "tâmpire",
    "tâmpirii": "tâmpire",
    "tâmpirile": "tâmpire",
    "tâmpita": "tâmpit",
    "tâmpită": "tâmpit",
    "tâmpite": "tâmpit",
    "tâmpitei": "tâmpit",
    "tâmpitele": "tâmpit",
    "tâmpitelor": "tâmpit",
    "tâmpiți": "tâmpit",
    "tâmpiții": "tâmpit",
    "tâmpiților": "tâmpit",
    "tâmpitul": "tâmpit",
    "tâmpitului": "tâmpit",
    "tâmpita": "tâmpită",
    "tâmpite": "tâmpită",
    "tâmpitei": "tâmpită",
    "tâmpitele": "tâmpită",
    "tâmpitelor": "tâmpită",
    "tâmpito": "tâmpită",
    "tâmpla": "tâmplă",
    "tâmple": "tâmplă",
    "tâmplei": "tâmplă",
    "tâmplele": "tâmplă",
    "tâmplelor": "tâmplă",
    "tâmplo": "tâmplă",
    "tâmplăria": "tâmplărie",
    "tâmplăriei": "tâmplărie",
    "tâmplării": "tâmplărie",
    "tâmplăriile": "tâmplărie",
    "tâmplăriilor": "tâmplărie",
    "nemaitamponând": "tampona",
    "nemaitamponându": "tampona",
    "netamponând": "tampona",
    "netamponându": "tampona",
    "tamponă": "tampona",
    "tamponai": "tampona",
    "tamponam": "tampona",
    "tamponăm": "tampona",
    "tamponând": "tampona",
    "tamponându": "tampona",
    "tamponară": "tampona",
    "tamponarăm": "tampona",
    "tamponarăți": "tampona",
    "tamponase": "tampona",
    "tamponasem": "tampona",
    "tamponaseră": "tampona",
    "tamponaserăm": "tampona",
    "tamponaserăți": "tampona",
    "tamponaseși": "tampona",
    "tamponași": "tampona",
    "tamponat": "tampona",
    "tamponați": "tampona",
    "tamponatu": "tampona",
    "tamponau": "tampona",
    "tamponează": "tampona",
    "tamponez": "tampona",
    "tamponeze": "tampona",
    "tamponezi": "tampona",
    "tamponarea": "tamponare",
    "tamponări": "tamponare",
    "tamponării": "tamponare",
    "tamponările": "tamponare",
    "tamponata": "tamponat",
    "tamponată": "tamponat",
    "tamponate": "tamponat",
    "tamponatei": "tamponat",
    "tamponatele": "tamponat",
    "tamponatelor": "tamponat",
    "tamponați": "tamponat",
    "tamponații": "tamponat",
    "tamponaților": "tamponat",
    "tamponatul": "tamponat",
    "tamponatului": "tamponat",
    "tam-tamul": "tam-tam",
    "tam-tamului": "tam-tam",
    "tam-tamuri": "tam-tam",
    "tam-tamurile": "tam-tam",
    "tam-tamurilor": "tam-tam",
    "tananți": "tanant",
    "tananții": "tanant",
    "tananților": "tanant",
    "tanantul": "tanant",
    "tanantului": "tanant",
    "tânăra": "tânăr",
    "tânără": "tânăr",
    "tânăro": "tânăr",
    "tânărul": "tânăr",
    "tânărule": "tânăr",
    "tânărului": "tânăr",
    "tinere": "tânăr",
    "tinerei": "tânăr",
    "tinerele": "tânăr",
    "tinerelor": "tânăr",
    "tineri": "tânăr",
    "tinerii": "tânăr",
    "tinerilor": "tânăr",
    "tânăra": "tânără",
    "tânăro": "tânără",
    "tinere": "tânără",
    "tinerei": "tânără",
    "tinerele": "tânără",
    "tinerelor": "tânără",
    "tancul": "tanc",
    "tancului": "tanc",
    "tancuri": "tanc",
    "tancurile": "tanc",
    "tancurilor": "tanc",
    "țânci": "țânc",
    "țâncii": "țânc",
    "țâncilor": "țânc",
    "țâncul": "țânc",
    "țâncului": "țânc",
    "tancheta": "tanchetă",
    "tanchete": "tanchetă",
    "tanchetei": "tanchetă",
    "tanchetele": "tanchetă",
    "tanchetelor": "tanchetă",
    "nemaitândălind": "tândăli",
    "nemaitândălindu": "tândăli",
    "netândălind": "tândăli",
    "netândălindu": "tândăli",
    "tândălea": "tândăli",
    "tândăleai": "tândăli",
    "tândăleam": "tândăli",
    "tândălească": "tândăli",
    "tândăleați": "tândăli",
    "tândăleau": "tândăli",
    "tândălesc": "tândăli",
    "tândălește": "tândăli",
    "tândălești": "tândăli",
    "tândălii": "tândăli",
    "tândălim": "tândăli",
    "tândălind": "tândăli",
    "tândălindu": "tândăli",
    "tândăliră": "tândăli",
    "tândălirăm": "tândăli",
    "tândălirăți": "tândăli",
    "tândălise": "tândăli",
    "tândălisem": "tândăli",
    "tândăliseră": "tândăli",
    "tândăliserăm": "tândăli",
    "tândăliserăți": "tândăli",
    "tândăliseși": "tândăli",
    "tândăliși": "tândăli",
    "tândălit": "tândăli",
    "tândăliți": "tândăli",
    "tândălitu": "tândăli",
    "tândălirea": "tândălire",
    "tândăliri": "tândălire",
    "tândălirii": "tândălire",
    "tândălirile": "tândălire",
    "tândălita": "tândălit",
    "tândălită": "tândălit",
    "tândălite": "tândălit",
    "tândălitei": "tândălit",
    "tândălitele": "tândălit",
    "tândălitelor": "tândălit",
    "tândăliți": "tândălit",
    "tândăliții": "tândălit",
    "tândăliților": "tândălit",
    "tândălitul": "tândălit",
    "tândălitului": "tândălit",
    "țandăra": "țandără",
    "țăndărei": "țandără",
    "țăndărele": "țandără",
    "țăndărelor": "țandără",
    "țăndări": "țandără",
    "țăndării": "țandără",
    "țăndările": "țandără",
    "țăndărilor": "țandără",
    "țăndărele": "țăndărică",
    "țăndărelei": "țăndărică",
    "țăndărica": "țăndărică",
    "tandrețea": "tandrețe",
    "tandreți": "tandrețe",
    "tandreții": "tandrețe",
    "tandrețile": "tandrețe",
    "tandreților": "tandrețe",
    "tandra": "tandru",
    "tandră": "tandru",
    "tandre": "tandru",
    "tandrei": "tandru",
    "tandrele": "tandru",
    "tandrelor": "tandru",
    "tandri": "tandru",
    "tandrii": "tandru",
    "tandrilor": "tandru",
    "tandrul": "tandru",
    "tandrului": "tandru",
    "tangaje": "tangaj",
    "tangajele": "tangaj",
    "tangajelor": "tangaj",
    "tangajul": "tangaj",
    "tangajului": "tangaj",
    "tangenta": "tangent",
    "tangentă": "tangent",
    "tangente": "tangent",
    "tangentei": "tangent",
    "tangentele": "tangent",
    "tangentelor": "tangent",
    "tangenți": "tangent",
    "tangenții": "tangent",
    "tangenților": "tangent",
    "tangentul": "tangent",
    "tangentului": "tangent",
    "tg": "tangentă",
    "tangența": "tangență",
    "tangențe": "tangență",
    "tangenței": "tangență",
    "tangențele": "tangență",
    "tangențelor": "tangență",
    "tangențiala": "tangențial",
    "tangențială": "tangențial",
    "tangențiale": "tangențial",
    "tangențialei": "tangențial",
    "tangențialele": "tangențial",
    "tangențialelor": "tangențial",
    "tangențiali": "tangențial",
    "tangențialii": "tangențial",
    "tangențialilor": "tangențial",
    "tangențialul": "tangențial",
    "tangențialului": "tangențial",
    "Tangerul": "Tanger",
    "Tangerului": "Tanger",
    "nemaitânguind": "tângui",
    "nemaitânguindu": "tângui",
    "netânguind": "tângui",
    "netânguindu": "tângui",
    "tânguia": "tângui",
    "tânguiai": "tângui",
    "tânguiam": "tângui",
    "tânguiască": "tângui",
    "tânguiați": "tângui",
    "tânguiau": "tângui",
    "tânguie": "tângui",
    "tânguiesc": "tângui",
    "tânguiește": "tângui",
    "tânguiești": "tângui",
    "tânguii": "tângui",
    "tânguim": "tângui",
    "tânguind": "tângui",
    "tânguindu": "tângui",
    "tânguiră": "tângui",
    "tânguirăm": "tângui",
    "tânguirăți": "tângui",
    "tânguise": "tângui",
    "tânguisem": "tângui",
    "tânguiseră": "tângui",
    "tânguiserăm": "tângui",
    "tânguiserăți": "tângui",
    "tânguiseși": "tângui",
    "tânguiși": "tângui",
    "tânguit": "tângui",
    "tânguiți": "tângui",
    "tânguitu": "tângui",
    "tânguirea": "tânguire",
    "tânguiri": "tânguire",
    "tânguirii": "tânguire",
    "tânguirile": "tânguire",
    "tânguita": "tânguit",
    "tânguită": "tânguit",
    "tânguite": "tânguit",
    "tânguitei": "tânguit",
    "tânguitele": "tânguit",
    "tânguitelor": "tânguit",
    "tânguiți": "tânguit",
    "tânguiții": "tânguit",
    "tânguiților": "tânguit",
    "tânguitul": "tânguit",
    "tânguitului": "tânguit",
    "tânguitoare": "tânguitor",
    "tânguitoarea": "tânguitor",
    "tânguitoarei": "tânguitor",
    "tânguitoarele": "tânguitor",
    "tânguitoarelor": "tânguitor",
    "tânguitori": "tânguitor",
    "tânguitorii": "tânguitor",
    "tânguitorilor": "tânguitor",
    "tânguitorul": "tânguitor",
    "tânguitorului": "tânguitor",
    "taninul": "tanin",
    "taninului": "tanin",
    "taninuri": "tanin",
    "taninurile": "tanin",
    "taninurilor": "tanin",
    "tânjala": "tânjală",
    "tânjeli": "tânjală",
    "tânjelii": "tânjală",
    "tânjelile": "tânjală",
    "tânjelilor": "tânjală",
    "nemaitânjind": "tânji",
    "nemaitânjindu": "tânji",
    "netânjind": "tânji",
    "netânjindu": "tânji",
    "tânjea": "tânji",
    "tânjeai": "tânji",
    "tânjeam": "tânji",
    "tânjească": "tânji",
    "tânjeați": "tânji",
    "tânjeau": "tânji",
    "tânjesc": "tânji",
    "tânjește": "tânji",
    "tânjești": "tânji",
    "tânjii": "tânji",
    "tânjim": "tânji",
    "tânjind": "tânji",
    "tânjindu": "tânji",
    "tânjiră": "tânji",
    "tânjirăm": "tânji",
    "tânjirăți": "tânji",
    "tânjise": "tânji",
    "tânjisem": "tânji",
    "tânjiseră": "tânji",
    "tânjiserăm": "tânji",
    "tânjiserăți": "tânji",
    "tânjiseși": "tânji",
    "tânjiși": "tânji",
    "tânjit": "tânji",
    "tânjiți": "tânji",
    "tânjitu": "tânji",
    "tânjirea": "tânjire",
    "tânjiri": "tânjire",
    "tânjirii": "tânjire",
    "tânjirile": "tânjire",
    "tânjita": "tânjit",
    "tânjită": "tânjit",
    "tânjite": "tânjit",
    "tânjitei": "tânjit",
    "tânjitele": "tânjit",
    "tânjitelor": "tânjit",
    "tânjiți": "tânjit",
    "tânjiții": "tânjit",
    "tânjiților": "tânjit",
    "tânjitul": "tânjit",
    "tânjitului": "tânjit",
    "tansportatori": "tansportator",
    "tansportatorii": "tansportator",
    "tansportatorilor": "tansportator",
    "tansportatorul": "tansportator",
    "tansportatorului": "tansportator",
    "Ta": "tantal",
    "tantalul": "tantal",
    "tantalului": "tantal",
    "țânțari": "țânțar",
    "țânțarii": "țânțar",
    "țânțarilor": "țânțar",
    "țânțarul": "țânțar",
    "țânțarului": "țânțar",
    "țânțărași": "țânțăraș",
    "țânțărașii": "țânțăraș",
    "țânțărașilor": "țânțăraș",
    "țânțărașul": "țânțăraș",
    "țânțărașului": "țânțăraș",
    "țânțărimea": "țânțărime",
    "țânțărimi": "țânțărime",
    "țânțărimii": "țânțărime",
    "țânțărimile": "țânțărime",
    "țânțărimilor": "țânțărime",
    "tantiema": "tantiemă",
    "tantieme": "tantiemă",
    "tantiemei": "tantiemă",
    "tantiemele": "tantiemă",
    "tantiemelor": "tantiemă",
    "țanțoșa": "țanțoș",
    "țanțoșă": "țanțoș",
    "țanțoșe": "țanțoș",
    "țanțoșei": "țanțoș",
    "țanțoșele": "țanțoș",
    "țanțoșelor": "țanțoș",
    "țanțoși": "țanțoș",
    "țanțoșii": "țanțoș",
    "țanțoșilor": "țanțoș",
    "țanțoșul": "țanțoș",
    "țanțoșului": "țanțoș",
    "țapi": "țap",
    "țapii": "țap",
    "țapilor": "țap",
    "țapul": "țap",
    "țapului": "țap",
    "nemaitapând": "tapa",
    "nemaitapându": "tapa",
    "netapând": "tapa",
    "netapându": "tapa",
    "tapă": "tapa",
    "tapai": "tapa",
    "tapam": "tapa",
    "tapăm": "tapa",
    "tapând": "tapa",
    "tapându": "tapa",
    "tapară": "tapa",
    "taparăm": "tapa",
    "taparăți": "tapa",
    "tapase": "tapa",
    "tapasem": "tapa",
    "tapaseră": "tapa",
    "tapaserăm": "tapa",
    "tapaserăți": "tapa",
    "tapaseși": "tapa",
    "tapași": "tapa",
    "tapat": "tapa",
    "tapați": "tapa",
    "tapatu": "tapa",
    "tapau": "tapa",
    "tapează": "tapa",
    "tapez": "tapa",
    "tapeze": "tapa",
    "tapezi": "tapa",
    "tapaje": "tapaj",
    "tapajele": "tapaj",
    "tapajelor": "tapaj",
    "tapajul": "tapaj",
    "tapajului": "tapaj",
    "taparea": "tapare",
    "tapări": "tapare",
    "tapării": "tapare",
    "tapările": "tapare",
    "tapata": "tapat",
    "tapată": "tapat",
    "tapate": "tapat",
    "tapatei": "tapat",
    "tapatele": "tapat",
    "tapatelor": "tapat",
    "tapați": "tapat",
    "tapații": "tapat",
    "tapaților": "tapat",
    "tapatul": "tapat",
    "tapatului": "tapat",
    "tapete": "tapet",
    "tapetele": "tapet",
    "tapetelor": "tapet",
    "tapetul": "tapet",
    "tapetului": "tapet",
    "nemaitapetând": "tapeta",
    "nemaitapetându": "tapeta",
    "netapetând": "tapeta",
    "netapetându": "tapeta",
    "tapetă": "tapeta",
    "tapetai": "tapeta",
    "tapetam": "tapeta",
    "tapetăm": "tapeta",
    "tapetând": "tapeta",
    "tapetându": "tapeta",
    "tapetară": "tapeta",
    "tapetarăm": "tapeta",
    "tapetarăți": "tapeta",
    "tapetase": "tapeta",
    "tapetasem": "tapeta",
    "tapetaseră": "tapeta",
    "tapetaserăm": "tapeta",
    "tapetaserăți": "tapeta",
    "tapetaseși": "tapeta",
    "tapetași": "tapeta",
    "tapetat": "tapeta",
    "tapetați": "tapeta",
    "tapetatu": "tapeta",
    "tapetau": "tapeta",
    "tapetează": "tapeta",
    "tapetez": "tapeta",
    "tapeteze": "tapeta",
    "tapetezi": "tapeta",
    "tapetarea": "tapetare",
    "tapetări": "tapetare",
    "tapetării": "tapetare",
    "tapetările": "tapetare",
    "tapetata": "tapetat",
    "tapetată": "tapetat",
    "tapetate": "tapetat",
    "tapetatei": "tapetat",
    "tapetatele": "tapetat",
    "tapetatelor": "tapetat",
    "tapetați": "tapetat",
    "tapetații": "tapetat",
    "tapetaților": "tapetat",
    "tapetatul": "tapetat",
    "tapetatului": "tapetat",
    "nemaitapisând": "tapisa",
    "nemaitapisându": "tapisa",
    "netapisând": "tapisa",
    "netapisându": "tapisa",
    "tapisă": "tapisa",
    "tapisai": "tapisa",
    "tapisam": "tapisa",
    "tapisăm": "tapisa",
    "tapisând": "tapisa",
    "tapisându": "tapisa",
    "tapisară": "tapisa",
    "tapisarăm": "tapisa",
    "tapisarăți": "tapisa",
    "tapisase": "tapisa",
    "tapisasem": "tapisa",
    "tapisaseră": "tapisa",
    "tapisaserăm": "tapisa",
    "tapisaserăți": "tapisa",
    "tapisaseși": "tapisa",
    "tapisași": "tapisa",
    "tapisat": "tapisa",
    "tapisați": "tapisa",
    "tapisatu": "tapisa",
    "tapisau": "tapisa",
    "tapisează": "tapisa",
    "tapisez": "tapisa",
    "tapiseze": "tapisa",
    "tapisezi": "tapisa",
    "tapisarea": "tapisare",
    "tapisări": "tapisare",
    "tapisării": "tapisare",
    "tapisările": "tapisare",
    "tapisata": "tapisat",
    "tapisată": "tapisat",
    "tapisate": "tapisat",
    "tapisatei": "tapisat",
    "tapisatele": "tapisat",
    "tapisatelor": "tapisat",
    "tapisați": "tapisat",
    "tapisații": "tapisat",
    "tapisaților": "tapisat",
    "tapisatul": "tapisat",
    "tapisatului": "tapisat",
    "tapiseria": "tapiserie",
    "tapiseriei": "tapiserie",
    "tapiserii": "tapiserie",
    "tapiseriile": "tapiserie",
    "tapiseriilor": "tapiserie",
    "nemaitapițând": "tapița",
    "nemaitapițându": "tapița",
    "netapițând": "tapița",
    "netapițându": "tapița",
    "tapiță": "tapița",
    "tapițai": "tapița",
    "tapițam": "tapița",
    "tapițăm": "tapița",
    "tapițând": "tapița",
    "tapițându": "tapița",
    "tapițară": "tapița",
    "tapițarăm": "tapița",
    "tapițarăți": "tapița",
    "tapițase": "tapița",
    "tapițasem": "tapița",
    "tapițaseră": "tapița",
    "tapițaserăm": "tapița",
    "tapițaserăți": "tapița",
    "tapițaseși": "tapița",
    "tapițași": "tapița",
    "tapițat": "tapița",
    "tapițați": "tapița",
    "tapițatu": "tapița",
    "tapițau": "tapița",
    "tapițează": "tapița",
    "tapițez": "tapița",
    "tapițeze": "tapița",
    "tapițezi": "tapița",
    "tapițarea": "tapițare",
    "tapițări": "tapițare",
    "tapițării": "tapițare",
    "tapițările": "tapițare",
    "tapițata": "tapițat",
    "tapițată": "tapițat",
    "tapițate": "tapițat",
    "tapițatei": "tapițat",
    "tapițatele": "tapițat",
    "tapițatelor": "tapițat",
    "tapițați": "tapițat",
    "tapițații": "tapițat",
    "tapițaților": "tapițat",
    "tapițatul": "tapițat",
    "tapițatului": "tapițat",
    "tapițeri": "tapițer",
    "tapițerii": "tapițer",
    "tapițerilor": "tapițer",
    "tapițerul": "tapițer",
    "tapițerului": "tapițer",
    "tapițeria": "tapițerie",
    "tapițeriei": "tapițerie",
    "tapițerii": "tapițerie",
    "tapițeriile": "tapițerie",
    "tapițeriilor": "tapițerie",
    "tăpșane": "tăpșan",
    "tăpșanele": "tăpșan",
    "tăpșanelor": "tăpșan",
    "tăpșanul": "tăpșan",
    "tăpșanului": "tăpșan",
    "nemaităpșind": "tăpși",
    "nemaităpșindu": "tăpși",
    "netăpșind": "tăpși",
    "netăpșindu": "tăpși",
    "tăpșea": "tăpși",
    "tăpșeai": "tăpși",
    "tăpșeam": "tăpși",
    "tăpșească": "tăpși",
    "tăpșeați": "tăpși",
    "tăpșeau": "tăpși",
    "tăpșesc": "tăpși",
    "tăpșește": "tăpși",
    "tăpșești": "tăpși",
    "tăpșii": "tăpși",
    "tăpșim": "tăpși",
    "tăpșind": "tăpși",
    "tăpșindu": "tăpși",
    "tăpșiră": "tăpși",
    "tăpșirăm": "tăpși",
    "tăpșirăți": "tăpși",
    "tăpșise": "tăpși",
    "tăpșisem": "tăpși",
    "tăpșiseră": "tăpși",
    "tăpșiserăm": "tăpși",
    "tăpșiserăți": "tăpși",
    "tăpșiseși": "tăpși",
    "tăpșiși": "tăpși",
    "tăpșit": "tăpși",
    "tăpșiți": "tăpși",
    "tăpșitu": "tăpși",
    "tăpșirea": "tăpșire",
    "tăpșiri": "tăpșire",
    "tăpșirii": "tăpșire",
    "tăpșirile": "tăpșire",
    "tăpșita": "tăpșit",
    "tăpșită": "tăpșit",
    "tăpșite": "tăpșit",
    "tăpșitei": "tăpșit",
    "tăpșitele": "tăpșit",
    "tăpșitelor": "tăpșit",
    "tăpșiți": "tăpșit",
    "tăpșiții": "tăpșit",
    "tăpșiților": "tăpșit",
    "tăpșitul": "tăpșit",
    "tăpșitului": "tăpșit",
    "țari": "țar",
    "țarii": "țar",
    "țarilor": "țar",
    "țarul": "țar",
    "țarului": "țar",
    "țâri": "țâr",
    "țârii": "țâr",
    "țârilor": "țâr",
    "țârul": "țâr",
    "țârului": "țâr",
    "tara": "tară",
    "tare": "tară",
    "tarei": "tară",
    "tarele": "tară",
    "tarelor": "tară",
    "țara": "țară",
    "țări": "țară",
    "țării": "țară",
    "țările": "țară",
    "țărilor": "țară",
    "țâra": "țâră",
    "țâre": "țâră",
    "țârei": "țâră",
    "țârele": "țâră",
    "țârelor": "țâră",
    "taraba": "tarabă",
    "tarabe": "tarabă",
    "tarabei": "tarabă",
    "tarabele": "tarabă",
    "tarabelor": "tarabă",
    "tarabo": "tarabă",
    "tărăboiul": "tărăboi",
    "tărăboiului": "tărăboi",
    "tărăboiuri": "tărăboi",
    "tărăboiurile": "tărăboi",
    "tărăboiurilor": "tărăboi",
    "taraci": "tarac",
    "taracii": "tarac",
    "taracilor": "tarac",
    "taracul": "tarac",
    "taracului": "tarac",
    "taraful": "taraf",
    "tarafului": "taraf",
    "tarafuri": "taraf",
    "tarafurile": "taraf",
    "tarafurilor": "taraf",
    "nemaitărăgănând": "tărăgăna",
    "nemaitărăgănându": "tărăgăna",
    "netărăgănând": "tărăgăna",
    "netărăgănându": "tărăgăna",
    "tărăgănă": "tărăgăna",
    "tărăgănai": "tărăgăna",
    "tărăgănam": "tărăgăna",
    "tărăgănăm": "tărăgăna",
    "tărăgănând": "tărăgăna",
    "tărăgănându": "tărăgăna",
    "tărăgănară": "tărăgăna",
    "tărăgănarăm": "tărăgăna",
    "tărăgănarăți": "tărăgăna",
    "tărăgănase": "tărăgăna",
    "tărăgănasem": "tărăgăna",
    "tărăgănaseră": "tărăgăna",
    "tărăgănaserăm": "tărăgăna",
    "tărăgănaserăți": "tărăgăna",
    "tărăgănaseși": "tărăgăna",
    "tărăgănași": "tărăgăna",
    "tărăgănat": "tărăgăna",
    "tărăgănați": "tărăgăna",
    "tărăgănatu": "tărăgăna",
    "tărăgănau": "tărăgăna",
    "tărăgănează": "tărăgăna",
    "tărăgănez": "tărăgăna",
    "tărăgăneze": "tărăgăna",
    "tărăgănezi": "tărăgăna",
    "tărăgănarea": "tărăgănare",
    "tărăgănări": "tărăgănare",
    "tărăgănării": "tărăgănare",
    "tărăgănările": "tărăgănare",
    "tărăgănata": "tărăgănat",
    "tărăgănată": "tărăgănat",
    "tărăgănate": "tărăgănat",
    "tărăgănatei": "tărăgănat",
    "tărăgănatele": "tărăgănat",
    "tărăgănatelor": "tărăgănat",
    "tărăgănați": "tărăgănat",
    "tărăgănații": "tărăgănat",
    "tărăgănaților": "tărăgănat",
    "tărăgănatul": "tărăgănat",
    "tărăgănatului": "tărăgănat",
    "taragotul": "taragot",
    "taragotului": "taragot",
    "taragoturi": "taragot",
    "taragoturile": "taragot",
    "taragoturilor": "taragot",
    "nemaitârâind": "târâi",
    "nemaitârâindu": "târâi",
    "netârâind": "târâi",
    "netârâindu": "târâi",
    "târâia": "târâi",
    "târâiai": "târâi",
    "târâiam": "târâi",
    "târâiască": "târâi",
    "târâiați": "târâi",
    "târâiau": "târâi",
    "târâiesc": "târâi",
    "târâiește": "târâi",
    "târâiești": "târâi",
    "târâii": "târâi",
    "târâim": "târâi",
    "târâind": "târâi",
    "târâindu": "târâi",
    "târâiră": "târâi",
    "târâirăm": "târâi",
    "târâirăți": "târâi",
    "târâise": "târâi",
    "târâisem": "târâi",
    "târâiseră": "târâi",
    "târâiserăm": "târâi",
    "târâiserăți": "târâi",
    "târâiseși": "târâi",
    "târâiși": "târâi",
    "târâit": "târâi",
    "târâiți": "târâi",
    "târâitu": "târâi",
    "țârâia": "țârâi",
    "țârâiai": "țârâi",
    "țârâiam": "țârâi",
    "țârâiați": "țârâi",
    "țârâiau": "țârâi",
    "țârâie": "țârâi",
    "țârâii": "țârâi",
    "țârâim": "țârâi",
    "țârâind": "țârâi",
    "țârâindu": "țârâi",
    "țârâiră": "țârâi",
    "țârâirăm": "țârâi",
    "țârâirăți": "țârâi",
    "țârâise": "țârâi",
    "țârâisem": "țârâi",
    "țârâiseră": "țârâi",
    "țârâiserăm": "țârâi",
    "țârâiserăți": "țârâi",
    "țârâiseși": "țârâi",
    "țârâiși": "țârâi",
    "țârâit": "țârâi",
    "țârâiți": "țârâi",
    "țârâitu": "țârâi",
    "târâiala": "târâială",
    "târâialo": "târâială",
    "târâieli": "târâială",
    "târâielii": "târâială",
    "târâielile": "târâială",
    "târâielilor": "târâială",
    "târâirea": "târâire",
    "târâireo": "târâire",
    "târâiri": "târâire",
    "târâirii": "târâire",
    "târâirile": "târâire",
    "târâirilor": "târâire",
    "târâita": "târâit",
    "târâită": "târâit",
    "târâite": "târâit",
    "târâitei": "târâit",
    "târâitele": "târâit",
    "târâitelor": "târâit",
    "târâiți": "târâit",
    "târâiții": "târâit",
    "târâiților": "târâit",
    "târâito": "târâit",
    "târâitul": "târâit",
    "târâitule": "târâit",
    "târâitului": "târâit",
    "țârâită": "țârâit",
    "țârâite": "țârâit",
    "țârâiți": "țârâit",
    "tărâmul": "tărâm",
    "tărâmului": "tărâm",
    "tărâmuri": "tărâm",
    "tărâmurile": "tărâm",
    "tărâmurilor": "tărâm",
    "țărani": "țăran",
    "țăranii": "țăran",
    "țăranilor": "țăran",
    "țăranul": "țăran",
    "țăranului": "țăran",
    "țărâna": "țărână",
    "țărânei": "țărână",
    "țărânele": "țărână",
    "țărânelor": "țărână",
    "țărâni": "țărână",
    "țăranca": "țărancă",
    "țărance": "țărancă",
    "țărancele": "țărancă",
    "țărancelor": "țărancă",
    "țărănci": "țărancă",
    "țărăncii": "țărancă",
    "țărăncile": "țărancă",
    "țărăncilor": "țărancă",
    "țărăneasca": "țărănesc",
    "țărănească": "țărănesc",
    "țărănescul": "țărănesc",
    "țărănescului": "țărănesc",
    "țărănești": "țărănesc",
    "țărăneștii": "țărănesc",
    "țărăneștile": "țărănesc",
    "țărăneștilor": "țărănesc",
    "țărănia": "țărănie",
    "țărăniei": "țărănie",
    "țărănii": "țărănie",
    "țărăniile": "țărănie",
    "țărăniilor": "țărănie",
    "țărănimea": "țărănime",
    "țărănimi": "țărănime",
    "țărănimii": "țărănime",
    "țărănimile": "țărănime",
    "țărănimilor": "țărănime",
    "țărănisme": "țărănism",
    "țărănismele": "țărănism",
    "țărănismelor": "țărănism",
    "țărănismul": "țărănism",
    "țărănismului": "țărănism",
    "țărănista": "țărănist",
    "țărănistă": "țărănist",
    "țărăniste": "țărănist",
    "țărănistei": "țărănist",
    "țărănistele": "țărănist",
    "țărănistelor": "țărănist",
    "țărăniști": "țărănist",
    "țărăniștii": "țărănist",
    "țărăniștilor": "țărănist",
    "țărănistul": "țărănist",
    "țărănistului": "țărănist",
    "țărânoasa": "țărânos",
    "țărânoasă": "țărânos",
    "țărânoase": "țărânos",
    "țărânoasei": "țărânos",
    "țărânoasele": "țărânos",
    "țărânoaselor": "țărânos",
    "țărânoși": "țărânos",
    "țărânoșii": "țărânos",
    "țărânoșilor": "țărânos",
    "țărânosul": "țărânos",
    "țărânosului": "țărânos",
    "țărănoasa": "țărănos",
    "țărănoasă": "țărănos",
    "țărănoase": "țărănos",
    "țărănoasei": "țărănos",
    "țărănoasele": "țărănos",
    "țărănoaselor": "țărănos",
    "țărănoși": "țărănos",
    "țărănoșii": "țărănos",
    "țărănoșilor": "țărănos",
    "țărănosul": "țărănos",
    "țărănosului": "țărănos",
    "tarantela": "tarantelă",
    "tarantele": "tarantelă",
    "tarantelei": "tarantelă",
    "tarantelele": "tarantelă",
    "tarantelelor": "tarantelă",
    "târârea": "târâre",
    "târâri": "târâre",
    "târârii": "târâre",
    "târârile": "târâre",
    "târârilor": "târâre",
    "tarași": "taraș",
    "tarașii": "taraș",
    "tarașilor": "taraș",
    "tarașul": "taraș",
    "tarașului": "taraș",
    "tărășenia": "tărășenie",
    "tărășeniei": "tărășenie",
    "tărășenii": "tărășenie",
    "tărășeniile": "tărășenie",
    "tărășeniilor": "tărășenie",
    "tarata": "tarat",
    "tarată": "tarat",
    "tarate": "tarat",
    "taratei": "tarat",
    "taratele": "tarat",
    "taratelor": "tarat",
    "tarați": "tarat",
    "tarații": "tarat",
    "taraților": "tarat",
    "taratul": "tarat",
    "taratului": "tarat",
    "târâta": "târât",
    "târâtă": "târât",
    "târâte": "târât",
    "târâtei": "târât",
    "târâtele": "târât",
    "târâtelor": "târât",
    "târâți": "târât",
    "târâții": "târât",
    "târâților": "târât",
    "târâtul": "târât",
    "târâtului": "târât",
    "târâtoarea": "târâtoare",
    "târâtoarei": "târâtoare",
    "târâtoarele": "târâtoare",
    "târâtoarelor": "târâtoare",
    "târâtoare": "târâtor",
    "târâtoarea": "târâtor",
    "târâtoarei": "târâtor",
    "târâtoarele": "târâtor",
    "târâtoarelor": "târâtor",
    "târâtori": "târâtor",
    "târâtorii": "târâtor",
    "târâtorilor": "târâtor",
    "târâtorul": "târâtor",
    "târâtorului": "târâtor",
    "târâtura": "târâtură",
    "târâturi": "târâtură",
    "târâturii": "târâtură",
    "târâturile": "târâtură",
    "târâturilor": "târâtură",
    "tărbaca": "tărbacă",
    "tărbace": "tărbacă",
    "tărbacei": "tărbacă",
    "tărbacele": "tărbacă",
    "tărbacelor": "tărbacă",
    "țarcul": "țarc",
    "țarcului": "țarc",
    "țarcuri": "țarc",
    "țarcurile": "țarc",
    "țarcurilor": "țarc",
    "tărcata": "tărcat",
    "tărcată": "tărcat",
    "tărcate": "tărcat",
    "tărcatei": "tărcat",
    "tărcatele": "tărcat",
    "tărcatelor": "tărcat",
    "tărcați": "tărcat",
    "tărcații": "tărcat",
    "tărcatul": "tărcat",
    "tărcatului": "tărcat",
    "tardiva": "tardiv",
    "tardivă": "tardiv",
    "tardive": "tardiv",
    "tardivei": "tardiv",
    "tardivele": "tardiv",
    "tardivelor": "tardiv",
    "tardivi": "tardiv",
    "tardivii": "tardiv",
    "tardivilor": "tardiv",
    "tardivul": "tardiv",
    "tardivului": "tardiv",
    "tarea": "tare",
    "tarele": "tare",
    "tarelui": "tare",
    "tari": "tare",
    "tarii": "tare",
    "tarile": "tare",
    "tarilor": "tare",
    "târfa": "târfă",
    "târfe": "târfă",
    "târfei": "târfă",
    "târfele": "târfă",
    "târfelor": "târfă",
    "târgul": "târg",
    "târgului": "târg",
    "târguri": "târg",
    "târgurile": "târg",
    "târgurilor": "târg",
    "TG.": "târg",
    "targa": "targă",
    "tărgi": "targă",
    "tărgii": "targă",
    "tărgile": "targă",
    "tărgilor": "targă",
    "târg-nemțeana": "târg-nemțean",
    "târg-nemțeană": "târg-nemțean",
    "târg-nemțeanul": "târg-nemțean",
    "târg-nemțeanului": "târg-nemțean",
    "târg-nemțene": "târg-nemțean",
    "târg-nemțenei": "târg-nemțean",
    "târg-nemțenele": "târg-nemțean",
    "târg-nemțenelor": "târg-nemțean",
    "târg-nemțeni": "târg-nemțean",
    "târg-nemțenii": "târg-nemțean",
    "târg-nemțenilor": "târg-nemțean",
    "târgoveața": "târgoveață",
    "târgovețe": "târgoveață",
    "târgoveței": "târgoveață",
    "târgovețele": "târgoveață",
    "târgovețelor": "târgoveață",
    "târgoveți": "târgoveț",
    "târgoveții": "târgoveț",
    "târgoveților": "târgoveț",
    "târgovețul": "târgoveț",
    "târgovețului": "târgoveț",
    "târgovișteana": "târgoviștean",
    "târgovișteană": "târgoviștean",
    "târgovișteanul": "târgoviștean",
    "târgovișteanului": "târgoviștean",
    "târgoviștene": "târgoviștean",
    "târgoviștenei": "târgoviștean",
    "târgoviștenele": "târgoviștean",
    "târgoviștenelor": "târgoviștean",
    "târgovișteni": "târgoviștean",
    "târgoviștenii": "târgoviștean",
    "târgoviștenilor": "târgoviștean",
    "târgovișteanca": "târgovișteancă",
    "târgoviștence": "târgovișteancă",
    "târgoviștencei": "târgovișteancă",
    "târgoviștencele": "târgovișteancă",
    "târgoviștencelor": "târgovișteancă",
    "târgșoare": "târgșor",
    "târgșoarele": "târgșor",
    "târgșoarelor": "târgșor",
    "târgșorul": "târgșor",
    "târgșorului": "târgșor",
    "Tg": "Târgu",
    "Tg.": "Târgu",
    "nemaitârguind": "târgui",
    "nemaitârguindu": "târgui",
    "netârguind": "târgui",
    "netârguindu": "târgui",
    "târguia": "târgui",
    "târguiai": "târgui",
    "târguiam": "târgui",
    "târguiască": "târgui",
    "târguiați": "târgui",
    "târguiau": "târgui",
    "târguiesc": "târgui",
    "târguiește": "târgui",
    "târguiești": "târgui",
    "târguii": "târgui",
    "târguim": "târgui",
    "târguind": "târgui",
    "târguindu": "târgui",
    "târguiră": "târgui",
    "târguirăm": "târgui",
    "târguirăți": "târgui",
    "târguise": "târgui",
    "târguisem": "târgui",
    "târguiseră": "târgui",
    "târguiserăm": "târgui",
    "târguiserăți": "târgui",
    "târguiseși": "târgui",
    "târguiși": "târgui",
    "târguit": "târgui",
    "târguiți": "târgui",
    "târguitu": "târgui",
    "târguiala": "târguială",
    "târguialo": "târguială",
    "târguieli": "târguială",
    "târguielii": "târguială",
    "târguielile": "târguială",
    "târguielilor": "târguială",
    "târguirea": "târguire",
    "târguireo": "târguire",
    "târguiri": "târguire",
    "târguirii": "târguire",
    "târguirile": "târguire",
    "târguirilor": "târguire",
    "târguita": "târguit",
    "târguită": "târguit",
    "târguite": "târguit",
    "târguitei": "târguit",
    "târguitele": "târguit",
    "târguitelor": "târguit",
    "târguiți": "târguit",
    "târguiții": "târguit",
    "târguiților": "târguit",
    "târguito": "târguit",
    "târguitul": "târguit",
    "târguitule": "târguit",
    "târguitului": "târguit",
    "Târgu-Mureșul": "Târgu-Mureș",
    "Târgu-Mureșului": "Târgu-Mureș",
    "Târgu-Neamțul": "Târgu-Neamț",
    "Târgu-Neamțului": "Târgu-Neamț",
    "tărhatul": "tărhat",
    "tărhatului": "tărhat",
    "tărhaturi": "tărhat",
    "tărhaturile": "tărhat",
    "tărhaturilor": "tărhat",
    "târa": "târî",
    "târai": "târî",
    "târâi": "târî",
    "târam": "târî",
    "târâm": "târî",
    "târând": "târî",
    "târându": "târî",
    "târâră": "târî",
    "târârăm": "târî",
    "târârăți": "târî",
    "târăsc": "târî",
    "târască": "târî",
    "târâse": "târî",
    "târâsem": "târî",
    "târâseră": "târî",
    "târâserăm": "târî",
    "târâserăți": "târî",
    "târâseși": "târî",
    "târâși": "târî",
    "târăște": "târî",
    "târăști": "târî",
    "târât": "târî",
    "târați": "târî",
    "târâți": "târî",
    "târâtu": "târî",
    "târau": "târî",
    "tăria": "tărie",
    "tăriei": "tărie",
    "tării": "tărie",
    "tăriile": "tărie",
    "tăriilor": "tărie",
    "tarife": "tarif",
    "tarifele": "tarif",
    "tarifelor": "tarif",
    "tariful": "tarif",
    "tarifului": "tarif",
    "tarifara": "tarifar",
    "tarifară": "tarifar",
    "tarifare": "tarifar",
    "tarifarei": "tarifar",
    "tarifarele": "tarifar",
    "tarifarelor": "tarifar",
    "tarifari": "tarifar",
    "tarifarii": "tarifar",
    "tarifarilor": "tarifar",
    "tarifarul": "tarifar",
    "tarifarului": "tarifar",
    "țarina": "țarină",
    "țarine": "țarină",
    "țarinei": "țarină",
    "țarinele": "țarină",
    "țarinelor": "țarină",
    "țarismele": "țarism",
    "țarismelor": "țarism",
    "țarista": "țarist",
    "țaristă": "țarist",
    "țariste": "țarist",
    "țaristei": "țarist",
    "țaristele": "țarist",
    "țaristelor": "țarist",
    "țariști": "țarist",
    "țariștii": "țarist",
    "țariștilor": "țarist",
    "țaristul": "țarist",
    "țaristului": "țarist",
    "târla": "târlă",
    "târle": "târlă",
    "târlei": "târlă",
    "târlele": "târlă",
    "târlelor": "târlă",
    "târlicii": "târlici",
    "târlicilor": "târlici",
    "țărmul": "țărm",
    "țărmului": "țărm",
    "țărmuri": "țărm",
    "țărmurile": "țărm",
    "țărmurilor": "țărm",
    "tarnița": "tarniță",
    "tarnițe": "tarniță",
    "tarniței": "tarniță",
    "tarnițele": "tarniță",
    "tarnițelor": "tarniță",
    "nemaitârnosind": "târnosi",
    "nemaitârnosindu": "târnosi",
    "netârnosind": "târnosi",
    "netârnosindu": "târnosi",
    "târnosea": "târnosi",
    "târnoseai": "târnosi",
    "târnoseam": "târnosi",
    "târnosească": "târnosi",
    "târnoseați": "târnosi",
    "târnoseau": "târnosi",
    "târnosesc": "târnosi",
    "târnosește": "târnosi",
    "târnosești": "târnosi",
    "târnosii": "târnosi",
    "târnosim": "târnosi",
    "târnosind": "târnosi",
    "târnosindu": "târnosi",
    "târnosiră": "târnosi",
    "târnosirăm": "târnosi",
    "târnosirăți": "târnosi",
    "târnosise": "târnosi",
    "târnosisem": "târnosi",
    "târnosiseră": "târnosi",
    "târnosiserăm": "târnosi",
    "târnosiserăți": "târnosi",
    "târnosiseși": "târnosi",
    "târnosiși": "târnosi",
    "târnosit": "târnosi",
    "târnosiți": "târnosi",
    "târnositu": "târnosi",
    "târnosirea": "târnosire",
    "târnosiri": "târnosire",
    "târnosirii": "târnosire",
    "târnosirile": "târnosire",
    "târnosita": "târnosit",
    "târnosită": "târnosit",
    "târnosite": "târnosit",
    "târnositei": "târnosit",
    "târnositele": "târnosit",
    "târnositelor": "târnosit",
    "târnosiți": "târnosit",
    "târnosiții": "târnosit",
    "târnosiților": "târnosit",
    "târnositul": "târnosit",
    "târnositului": "târnosit",
    "tarodul": "tarod",
    "tarodului": "tarod",
    "taroduri": "tarod",
    "tarodurile": "tarod",
    "tarodurilor": "tarod",
    "târși": "târș",
    "târșii": "târș",
    "târșilor": "târș",
    "târșul": "târș",
    "târșului": "târș",
    "nemaitârșâind": "târșâi",
    "nemaitârșâindu": "târșâi",
    "netârșâind": "târșâi",
    "netârșâindu": "târșâi",
    "târșâia": "târșâi",
    "târșâiai": "târșâi",
    "târșâiam": "târșâi",
    "târșâiați": "târșâi",
    "târșâiau": "târșâi",
    "târșâie": "târșâi",
    "târșâii": "târșâi",
    "târșâim": "târșâi",
    "târșâind": "târșâi",
    "târșâindu": "târșâi",
    "târșâiră": "târșâi",
    "târșâirăm": "târșâi",
    "târșâirăți": "târșâi",
    "târșâise": "târșâi",
    "târșâisem": "târșâi",
    "târșâiseră": "târșâi",
    "târșâiserăm": "târșâi",
    "târșâiserăți": "târșâi",
    "târșâiseși": "târșâi",
    "târșâiși": "târșâi",
    "târșâit": "târșâi",
    "târșâiți": "târșâi",
    "târșâitu": "târșâi",
    "târșâiala": "târșâială",
    "târșâieli": "târșâială",
    "târșâielii": "târșâială",
    "târșâielile": "târșâială",
    "târșâielilor": "târșâială",
    "târșâirea": "târșâire",
    "târșâireo": "târșâire",
    "târșâiri": "târșâire",
    "târșâirii": "târșâire",
    "târșâirile": "târșâire",
    "târșâirilor": "târșâire",
    "târșâita": "târșâit",
    "târșâită": "târșâit",
    "târșâite": "târșâit",
    "târșâitei": "târșâit",
    "târșâitele": "târșâit",
    "târșâitelor": "târșâit",
    "târșâiți": "târșâit",
    "târșâiții": "târșâit",
    "târșâiților": "târșâit",
    "târșâito": "târșâit",
    "târșâitul": "târșâit",
    "târșâitule": "târșâit",
    "târșâitului": "târșâit",
    "tartare": "tartar",
    "tartarele": "tartar",
    "tartarelor": "tartar",
    "tartarul": "tartar",
    "tartarului": "tartar",
    "tartori": "tartor",
    "tartorii": "tartor",
    "tartorilor": "tartor",
    "tartorul": "tartor",
    "tartorului": "tartor",
    "tartrul": "tartru",
    "tartrului": "tartru",
    "tartruri": "tartru",
    "tartrurile": "tartru",
    "tartrurilor": "tartru",
    "țăruși": "țăruș",
    "țărușii": "țăruș",
    "țărușilor": "țăruș",
    "țărușul": "țăruș",
    "țărușului": "țăruș",
    "târzia": "târziu",
    "târzie": "târziu",
    "târziei": "târziu",
    "târzii": "târziu",
    "târziii": "târziu",
    "târziile": "târziu",
    "târziilor": "târziu",
    "târzio": "târziu",
    "târziul": "târziu",
    "târziule": "târziu",
    "târziului": "târziu",
    "nemaitasând": "tasa",
    "nemaitasându": "tasa",
    "netasând": "tasa",
    "netasându": "tasa",
    "tasă": "tasa",
    "tasai": "tasa",
    "tasam": "tasa",
    "tasăm": "tasa",
    "tasând": "tasa",
    "tasându": "tasa",
    "tasară": "tasa",
    "tasarăm": "tasa",
    "tasarăți": "tasa",
    "tasase": "tasa",
    "tasasem": "tasa",
    "tasaseră": "tasa",
    "tasaserăm": "tasa",
    "tasaserăți": "tasa",
    "tasaseși": "tasa",
    "tasași": "tasa",
    "tasat": "tasa",
    "tasați": "tasa",
    "tasatu": "tasa",
    "tasau": "tasa",
    "tasează": "tasa",
    "tasez": "tasa",
    "taseze": "tasa",
    "tasezi": "tasa",
    "tasarea": "tasare",
    "tasări": "tasare",
    "tasării": "tasare",
    "tasările": "tasare",
    "tasata": "tasat",
    "tasată": "tasat",
    "tasate": "tasat",
    "tasatei": "tasat",
    "tasatele": "tasat",
    "tasatelor": "tasat",
    "tasați": "tasat",
    "tasații": "tasat",
    "tasaților": "tasat",
    "tasatul": "tasat",
    "tasatului": "tasat",
    "nemaițâșnind": "țâșni",
    "nemaițâșnindu": "țâșni",
    "nețâșnind": "țâșni",
    "nețâșnindu": "țâșni",
    "țâșnea": "țâșni",
    "țâșneai": "țâșni",
    "țâșneam": "țâșni",
    "țâșnească": "țâșni",
    "țâșneați": "țâșni",
    "țâșneau": "țâșni",
    "țâșnesc": "țâșni",
    "țâșnește": "țâșni",
    "țâșnești": "țâșni",
    "țâșnii": "țâșni",
    "țâșnim": "țâșni",
    "țâșnind": "țâșni",
    "țâșnindu": "țâșni",
    "țâșniră": "țâșni",
    "țâșnirăm": "țâșni",
    "țâșnirăți": "țâșni",
    "țâșnise": "țâșni",
    "țâșnisem": "țâșni",
    "țâșniseră": "țâșni",
    "țâșniserăm": "țâșni",
    "țâșniserăți": "țâșni",
    "țâșniseși": "țâșni",
    "țâșniși": "țâșni",
    "țâșnit": "țâșni",
    "țâșniți": "țâșni",
    "țâșnirea": "țâșnire",
    "țâșnireo": "țâșnire",
    "țâșniri": "țâșnire",
    "țâșnirii": "țâșnire",
    "țâșnirile": "țâșnire",
    "țâșnirilor": "țâșnire",
    "țâșnită": "țâșnit",
    "țâșnite": "țâșnit",
    "țâșniți": "țâșnit",
    "țâșnitoare": "țâșnitor",
    "țâșnitoarea": "țâșnitor",
    "țâșnitoarei": "țâșnitor",
    "țâșnitoarele": "țâșnitor",
    "țâșnitoarelor": "țâșnitor",
    "țâșnitoareo": "țâșnitor",
    "țâșnitori": "țâșnitor",
    "țâșnitorii": "țâșnitor",
    "țâșnitorilor": "țâșnitor",
    "țâșnitorul": "țâșnitor",
    "țâșnitorule": "țâșnitor",
    "țâșnitorului": "țâșnitor",
    "tata": "tată",
    "tatăl": "tată",
    "tatălui": "tată",
    "tatei": "tată",
    "tați": "tată",
    "tații": "tată",
    "taților": "tată",
    "țața": "țață",
    "țațe": "țață",
    "țaței": "țață",
    "țațele": "țață",
    "țațelor": "țață",
    "țâța": "țâță",
    "țâțe": "țâță",
    "țâței": "țâță",
    "țâțele": "țâță",
    "țâțelor": "țâță",
    "țâțâia": "țâțâi",
    "țâțâiai": "țâțâi",
    "țâțâiam": "țâțâi",
    "țâțâiați": "țâțâi",
    "țâțâiau": "țâțâi",
    "țâțâie": "țâțâi",
    "țâțâii": "țâțâi",
    "țâțâim": "țâțâi",
    "țâțâind": "țâțâi",
    "țâțâindu": "țâțâi",
    "țâțâiră": "țâțâi",
    "țâțâirăm": "țâțâi",
    "țâțâirăți": "țâțâi",
    "țâțâise": "țâțâi",
    "țâțâisem": "țâțâi",
    "țâțâiseră": "țâțâi",
    "țâțâiserăm": "țâțâi",
    "țâțâiserăți": "țâțâi",
    "țâțâiseși": "țâțâi",
    "țâțâiși": "țâțâi",
    "țâțâit": "țâțâi",
    "țâțâiți": "țâțâi",
    "țâțâitu": "țâțâi",
    "țâțâită": "țâțâit",
    "țâțâite": "țâțâit",
    "țâțâiți": "țâțâit",
    "tătici": "tătic",
    "tăticii": "tătic",
    "tăticilor": "tătic",
    "tăticul": "tătic",
    "tăticului": "tătic",
    "nemaitatonând": "tatona",
    "nemaitatonându": "tatona",
    "netatonând": "tatona",
    "netatonându": "tatona",
    "tatonă": "tatona",
    "tatonai": "tatona",
    "tatonam": "tatona",
    "tatonăm": "tatona",
    "tatonând": "tatona",
    "tatonându": "tatona",
    "tatonară": "tatona",
    "tatonarăm": "tatona",
    "tatonarăți": "tatona",
    "tatonase": "tatona",
    "tatonasem": "tatona",
    "tatonaseră": "tatona",
    "tatonaserăm": "tatona",
    "tatonaserăți": "tatona",
    "tatonaseși": "tatona",
    "tatonași": "tatona",
    "tatonat": "tatona",
    "tatonați": "tatona",
    "tatonatu": "tatona",
    "tatonau": "tatona",
    "tatonează": "tatona",
    "tatonez": "tatona",
    "tatoneze": "tatona",
    "tatonezi": "tatona",
    "tatonarea": "tatonare",
    "tatonări": "tatonare",
    "tatonării": "tatonare",
    "tatonările": "tatonare",
    "tatonata": "tatonat",
    "tatonată": "tatonat",
    "tatonate": "tatonat",
    "tatonatei": "tatonat",
    "tatonatele": "tatonat",
    "tatonatelor": "tatonat",
    "tatonați": "tatonat",
    "tatonații": "tatonat",
    "tatonaților": "tatonat",
    "tatonatul": "tatonat",
    "tatonatului": "tatonat",
    "nemaitatuând": "tatua",
    "nemaitatuându": "tatua",
    "netatuând": "tatua",
    "netatuându": "tatua",
    "tatuă": "tatua",
    "tatuai": "tatua",
    "tatuam": "tatua",
    "tatuăm": "tatua",
    "tatuând": "tatua",
    "tatuându": "tatua",
    "tatuară": "tatua",
    "tatuarăm": "tatua",
    "tatuarăți": "tatua",
    "tatuase": "tatua",
    "tatuasem": "tatua",
    "tatuaseră": "tatua",
    "tatuaserăm": "tatua",
    "tatuaserăți": "tatua",
    "tatuaseși": "tatua",
    "tatuași": "tatua",
    "tatuat": "tatua",
    "tatuați": "tatua",
    "tatuatu": "tatua",
    "tatuau": "tatua",
    "tatuează": "tatua",
    "tatuez": "tatua",
    "tatueze": "tatua",
    "tatuezi": "tatua",
    "tatuaje": "tatuaj",
    "tatuajele": "tatuaj",
    "tatuajelor": "tatuaj",
    "tatuajul": "tatuaj",
    "tatuajului": "tatuaj",
    "tatuarea": "tatuare",
    "tatuări": "tatuare",
    "tatuării": "tatuare",
    "tatuările": "tatuare",
    "tatuata": "tatuat",
    "tatuată": "tatuat",
    "tatuate": "tatuat",
    "tatuatei": "tatuat",
    "tatuatele": "tatuat",
    "tatuatelor": "tatuat",
    "tatuați": "tatuat",
    "tatuații": "tatuat",
    "tatuaților": "tatuat",
    "tatuatul": "tatuat",
    "tatuatului": "tatuat",
    "tătuca": "tătucă",
    "tătuci": "tătucă",
    "tătucii": "tătucă",
    "tătucilor": "tătucă",
    "tătucului": "tătucă",
    "ta": "tău",
    "tăi": "tău",
    "tale": "tău",
    "taumaturgi": "taumaturg",
    "taumaturgii": "taumaturg",
    "taumaturgilor": "taumaturg",
    "taumaturgul": "taumaturg",
    "taumaturgului": "taumaturg",
    "taumaturgia": "taumaturgie",
    "taumaturgiei": "taumaturgie",
    "taumaturgii": "taumaturgie",
    "taumaturgiile": "taumaturgie",
    "taumaturgiilor": "taumaturgie",
    "tauri": "taur",
    "taurii": "taur",
    "taurilor": "taur",
    "taurul": "taur",
    "taurului": "taur",
    "tautologia": "tautologie",
    "tautologiei": "tautologie",
    "tautologii": "tautologie",
    "tautologiile": "tautologie",
    "tautologiilor": "tautologie",
    "tava": "tavă",
    "tăvi": "tavă",
    "tăvii": "tavă",
    "tăvile": "tavă",
    "tăvilor": "tavă",
    "tavo": "tavă",
    "tăvăleala": "tăvăleală",
    "tăvăleli": "tăvăleală",
    "tăvălelii": "tăvăleală",
    "tăvălelile": "tăvăleală",
    "tăvălelilor": "tăvăleală",
    "tăvălea": "tăvăli",
    "tăvăleai": "tăvăli",
    "tăvăleam": "tăvăli",
    "tăvălească": "tăvăli",
    "tăvăleați": "tăvăli",
    "tăvăleau": "tăvăli",
    "tăvălesc": "tăvăli",
    "tăvălește": "tăvăli",
    "tăvălești": "tăvăli",
    "tăvălii": "tăvăli",
    "tăvălim": "tăvăli",
    "tăvălind": "tăvăli",
    "tăvălindu": "tăvăli",
    "tăvăliră": "tăvăli",
    "tăvălirăm": "tăvăli",
    "tăvălirăți": "tăvăli",
    "tăvălise": "tăvăli",
    "tăvălisem": "tăvăli",
    "tăvăliseră": "tăvăli",
    "tăvăliserăm": "tăvăli",
    "tăvăliserăți": "tăvăli",
    "tăvăliseși": "tăvăli",
    "tăvăliși": "tăvăli",
    "tăvălit": "tăvăli",
    "tăvăliți": "tăvăli",
    "tăvălitu": "tăvăli",
    "tăvălita": "tăvălit",
    "tăvălită": "tăvălit",
    "tăvălite": "tăvălit",
    "tăvălitei": "tăvălit",
    "tăvălitele": "tăvălit",
    "tăvălitelor": "tăvălit",
    "tăvăliți": "tăvălit",
    "tăvăliții": "tăvălit",
    "tăvăliților": "tăvălit",
    "tăvălitul": "tăvălit",
    "tăvălitului": "tăvălit",
    "tăvălugi": "tăvălug",
    "tăvălugii": "tăvălug",
    "tăvălugilor": "tăvălug",
    "tăvălugul": "tăvălug",
    "tăvălugului": "tăvălug",
    "tavane": "tavan",
    "tavanele": "tavan",
    "tavanelor": "tavan",
    "tavanul": "tavan",
    "tavanule": "tavan",
    "tavanului": "tavan",
    "taverna": "tavernă",
    "taverne": "tavernă",
    "tavernei": "tavernă",
    "tavernele": "tavernă",
    "tavernelor": "tavernă",
    "taxă": "taxa",
    "taxai": "taxa",
    "taxam": "taxa",
    "taxăm": "taxa",
    "taxând": "taxa",
    "taxându": "taxa",
    "taxară": "taxa",
    "taxarăm": "taxa",
    "taxarăți": "taxa",
    "taxase": "taxa",
    "taxasem": "taxa",
    "taxaseră": "taxa",
    "taxaserăm": "taxa",
    "taxaserăți": "taxa",
    "taxaseși": "taxa",
    "taxași": "taxa",
    "taxat": "taxa",
    "taxați": "taxa",
    "taxatu": "taxa",
    "taxau": "taxa",
    "taxează": "taxa",
    "taxez": "taxa",
    "taxeze": "taxa",
    "taxezi": "taxa",
    "taxa": "taxă",
    "taxe": "taxă",
    "taxei": "taxă",
    "taxele": "taxă",
    "taxelor": "taxă",
    "TVA": "taxa_pe_valoare_adăugată",
    "taxarea": "taxare",
    "taxări": "taxare",
    "taxării": "taxare",
    "taxările": "taxare",
    "taxărilor": "taxare",
    "taxata": "taxat",
    "taxată": "taxat",
    "taxate": "taxat",
    "taxatei": "taxat",
    "taxatele": "taxat",
    "taxatelor": "taxat",
    "taxați": "taxat",
    "taxații": "taxat",
    "taxaților": "taxat",
    "taxatul": "taxat",
    "taxatului": "taxat",
    "taxiul": "taxi",
    "taxiului": "taxi",
    "taxiuri": "taxi",
    "taxiurile": "taxi",
    "taxiurilor": "taxi",
    "taximetre": "taximetru",
    "taximetrele": "taximetru",
    "taximetrelor": "taximetru",
    "taximetrul": "taximetru",
    "taximetrului": "taximetru",
    "teaca": "teacă",
    "teci": "teacă",
    "tecii": "teacă",
    "tecile": "teacă",
    "tecilor": "teacă",
    "teafăra": "teafăr",
    "teafără": "teafăr",
    "teafărul": "teafăr",
    "teafărului": "teafăr",
    "tefere": "teafăr",
    "teferei": "teafăr",
    "teferele": "teafăr",
    "teferelor": "teafăr",
    "teferi": "teafăr",
    "teferii": "teafăr",
    "teferilor": "teafăr",
    "teama": "teamă",
    "teme": "teamă",
    "temei": "teamă",
    "teancul": "teanc",
    "teancule": "teanc",
    "teancului": "teanc",
    "teancuri": "teanc",
    "teancurile": "teanc",
    "teancurilor": "teanc",
    "teapa": "teapă",
    "tepe": "teapă",
    "tepei": "teapă",
    "țeapa": "țeapă",
    "țepe": "țeapă",
    "țepei": "țeapă",
    "țepele": "țeapă",
    "țepelor": "țeapă",
    "țeapăna": "țeapăn",
    "țeapănă": "țeapăn",
    "țeapănul": "țeapăn",
    "țeapănului": "țeapăn",
    "țepene": "țeapăn",
    "țepenei": "țeapăn",
    "țepenele": "țeapăn",
    "țepenelor": "țeapăn",
    "țepeni": "țeapăn",
    "țepenii": "țeapăn",
    "țepenilor": "țeapăn",
    "teara": "teară",
    "teri": "teară",
    "terii": "teară",
    "terile": "teară",
    "terilor": "teară",
    "tearfa": "tearfă",
    "terfe": "tearfă",
    "terfei": "tearfă",
    "terfele": "tearfă",
    "terfelor": "tearfă",
    "teascul": "teasc",
    "teascului": "teasc",
    "teascuri": "teasc",
    "teascurile": "teasc",
    "teascurilor": "teasc",
    "țeasta": "țeastă",
    "țeste": "țeastă",
    "țestei": "țeastă",
    "țestele": "țeastă",
    "țestelor": "țeastă",
    "teatrala": "teatral",
    "teatrală": "teatral",
    "teatrale": "teatral",
    "teatralei": "teatral",
    "teatralele": "teatral",
    "teatralelor": "teatral",
    "teatrali": "teatral",
    "teatralii": "teatral",
    "teatralilor": "teatral",
    "teatralul": "teatral",
    "teatralului": "teatral",
    "teatrologia": "teatrologie",
    "teatrologiei": "teatrologie",
    "teatrologii": "teatrologie",
    "teatrologiile": "teatrologie",
    "teatrologiilor": "teatrologie",
    "teatre": "teatru",
    "teatrele": "teatru",
    "teatrelor": "teatru",
    "teatrul": "teatru",
    "teatrului": "teatru",
    "țeava": "țeavă",
    "țevi": "țeavă",
    "țevii": "țeavă",
    "țevile": "țeavă",
    "țevilor": "țeavă",
    "tebani": "teban",
    "tebanii": "teban",
    "tebanilor": "teban",
    "tebanul": "teban",
    "tebanului": "teban",
    "tebecista": "tebecist",
    "tebecistă": "tebecist",
    "tebeciste": "tebecist",
    "tebecistei": "tebecist",
    "tebecistele": "tebecist",
    "tebecistelor": "tebecist",
    "tebeciști": "tebecist",
    "tebeciștii": "tebecist",
    "tebeciștilor": "tebecist",
    "tebecistul": "tebecist",
    "tebecistului": "tebecist",
    "tebecista": "tebecistă",
    "tebeciste": "tebecistă",
    "tebecistei": "tebecistă",
    "tebecistele": "tebecistă",
    "tebecistelor": "tebecistă",
    "Techirghiolul": "Techirghiol",
    "Techirghiolului": "Techirghiol",
    "tectonica": "tectonic",
    "tectonică": "tectonic",
    "tectonice": "tectonic",
    "tectonicei": "tectonic",
    "tectonicele": "tectonic",
    "tectonicelor": "tectonic",
    "tectonici": "tectonic",
    "tectonicii": "tectonic",
    "tectonicilor": "tectonic",
    "tectonicul": "tectonic",
    "tectonicului": "tectonic",
    "tectonica": "tectonică",
    "tectonici": "tectonică",
    "tectonicii": "tectonică",
    "Tecuciul": "Tecuci",
    "Tecuciului": "Tecuci",
    "tedeumul": "tedeum",
    "tedeumului": "tedeum",
    "tedeumuri": "tedeum",
    "tedeumurile": "tedeum",
    "tedeumurilor": "tedeum",
    "tegumente": "tegument",
    "tegumentele": "tegument",
    "tegumentelor": "tegument",
    "tegumentul": "tegument",
    "tegumentului": "tegument",
    "Teheranul": "Teheran",
    "Teheranului": "Teheran",
    "tehnica": "tehnic",
    "tehnică": "tehnic",
    "tehnice": "tehnic",
    "tehnici": "tehnic",
    "tehnicii": "tehnic",
    "tehnicile": "tehnic",
    "tehnicilor": "tehnic",
    "tehnicul": "tehnic",
    "tehnicului": "tehnic",
    "tehn.": "tehnică",
    "tehnica": "tehnică",
    "tehnici": "tehnică",
    "tehnicii": "tehnică",
    "tehnicile": "tehnică",
    "tehnicilor": "tehnică",
    "tehnicianul": "tehnician",
    "tehnicianului": "tehnician",
    "tehnicieni": "tehnician",
    "tehnicienii": "tehnician",
    "tehnicienilor": "tehnician",
    "tehniciana": "tehniciană",
    "tehniciene": "tehniciană",
    "tehnicienei": "tehniciană",
    "tehnicienele": "tehniciană",
    "tehnicienelor": "tehniciană",
    "tehnicitatea": "tehnicitate",
    "tehnicități": "tehnicitate",
    "tehnicității": "tehnicitate",
    "tehnicitățile": "tehnicitate",
    "tehnicităților": "tehnicitate",
    "tehnico-economica": "tehnico-economic",
    "tehnico-economică": "tehnico-economic",
    "tehnico-economice": "tehnico-economic",
    "tehnico-economicei": "tehnico-economic",
    "tehnico-economicele": "tehnico-economic",
    "tehnico-economicelor": "tehnico-economic",
    "tehnico-economici": "tehnico-economic",
    "tehnico-economicii": "tehnico-economic",
    "tehnico-economicilor": "tehnico-economic",
    "tehnico-economicul": "tehnico-economic",
    "tehnico-economicului": "tehnico-economic",
    "tehnicolora": "tehnicolor",
    "tehnicoloră": "tehnicolor",
    "tehnicolore": "tehnicolor",
    "tehnicolorei": "tehnicolor",
    "tehnicolorele": "tehnicolor",
    "tehnicolorelor": "tehnicolor",
    "tehnicolori": "tehnicolor",
    "tehnicolorii": "tehnicolor",
    "tehnicolorilor": "tehnicolor",
    "tehnicolorul": "tehnicolor",
    "tehnicolorului": "tehnicolor",
    "tehnicoștiințifica": "tehnicoștiințific",
    "tehnicoștiințifică": "tehnicoștiințific",
    "tehnicoștiințifice": "tehnicoștiințific",
    "tehnicoștiințificei": "tehnicoștiințific",
    "tehnicoștiințificele": "tehnicoștiințific",
    "tehnicoștiințificelor": "tehnicoștiințific",
    "tehnicoștiințifici": "tehnicoștiințific",
    "tehnicoștiințificii": "tehnicoștiințific",
    "tehnicoștiințificilor": "tehnicoștiințific",
    "tehnicoștiințificul": "tehnicoștiințific",
    "tehnicoștiințificului": "tehnicoștiințific",
    "tehnologi": "tehnolog",
    "tehnologii": "tehnolog",
    "tehnologilor": "tehnolog",
    "tehnologul": "tehnolog",
    "tehnologului": "tehnolog",
    "tehnologica": "tehnologic",
    "tehnologică": "tehnologic",
    "tehnologice": "tehnologic",
    "tehnologicei": "tehnologic",
    "tehnologicele": "tehnologic",
    "tehnologicelor": "tehnologic",
    "tehnologici": "tehnologic",
    "tehnologicii": "tehnologic",
    "tehnologicilor": "tehnologic",
    "tehnologico": "tehnologic",
    "tehnologicul": "tehnologic",
    "tehnologicule": "tehnologic",
    "tehnologicului": "tehnologic",
    "tehnologia": "tehnologie",
    "tehnologiei": "tehnologie",
    "tehnologii": "tehnologie",
    "tehnologiile": "tehnologie",
    "tehnologiilor": "tehnologie",
    "tehnoredactarea": "tehnoredactare",
    "tehnoredactări": "tehnoredactare",
    "tehnoredactării": "tehnoredactare",
    "tehnoredactările": "tehnoredactare",
    "tehnoredactărilor": "tehnoredactare",
    "teii": "tei",
    "teilor": "tei",
    "teiul": "tei",
    "teiului": "tei",
    "teismul": "teism",
    "teismului": "teism",
    "tejgheao": "tejghea",
    "tejgheaua": "tejghea",
    "tejghele": "tejghea",
    "tejghelei": "tejghea",
    "tejghelele": "tejghea",
    "tejghelelor": "tejghea",
    "țelul": "țel",
    "țelului": "țel",
    "țeluri": "țel",
    "țelurile": "țel",
    "țelurilor": "țel",
    "telali": "telal",
    "telalii": "telal",
    "telalilor": "telal",
    "telalul": "telal",
    "telalului": "telal",
    "teleaga": "teleagă",
    "telegi": "teleagă",
    "telegii": "teleagă",
    "telegile": "teleagă",
    "telegilor": "teleagă",
    "telebivizoare": "telebivizor",
    "telebivizoarele": "telebivizor",
    "telebivizoarelor": "telebivizor",
    "telebivizorul": "telebivizor",
    "telebivizorului": "telebivizor",
    "telecomanda": "telecomandă",
    "telecomenzi": "telecomandă",
    "telecomenzii": "telecomandă",
    "telecomenzile": "telecomandă",
    "telecomenzilor": "telecomandă",
    "telecomunicația": "telecomunicație",
    "telecomunicației": "telecomunicație",
    "telecomunicații": "telecomunicație",
    "telecomunicațiile": "telecomunicație",
    "telecomunicațiilor": "telecomunicație",
    "tele-ecrane": "tele-ecran",
    "tele-ecranele": "tele-ecran",
    "tele-ecranelor": "tele-ecran",
    "tele-ecranul": "tele-ecran",
    "tele-ecranului": "tele-ecran",
    "teleferice": "teleferic",
    "telefericele": "teleferic",
    "telefericelor": "teleferic",
    "telefericul": "teleferic",
    "telefericului": "teleferic",
    "telefilme": "telefilm",
    "telefilmele": "telefilm",
    "telefilmelor": "telefilm",
    "telefilmul": "telefilm",
    "telefilmului": "telefilm",
    "tel.": "telefon",
    "telefoane": "telefon",
    "telefoanele": "telefon",
    "telefoanelor": "telefon",
    "telefonul": "telefon",
    "telefonului": "telefon",
    "telefonă": "telefona",
    "telefonai": "telefona",
    "telefonam": "telefona",
    "telefonăm": "telefona",
    "telefonând": "telefona",
    "telefonându": "telefona",
    "telefonară": "telefona",
    "telefonarăm": "telefona",
    "telefonarăți": "telefona",
    "telefonase": "telefona",
    "telefonasem": "telefona",
    "telefonaseră": "telefona",
    "telefonaserăm": "telefona",
    "telefonaserăți": "telefona",
    "telefonaseși": "telefona",
    "telefonași": "telefona",
    "telefonat": "telefona",
    "telefonați": "telefona",
    "telefonatu": "telefona",
    "telefonau": "telefona",
    "telefonează": "telefona",
    "telefonez": "telefona",
    "telefoneze": "telefona",
    "telefonezi": "telefona",
    "telefonată": "telefonat",
    "telefonate": "telefonat",
    "telefonați": "telefonat",
    "telefonica": "telefonic",
    "telefonică": "telefonic",
    "telefonice": "telefonic",
    "telefonicei": "telefonic",
    "telefonicele": "telefonic",
    "telefonicelor": "telefonic",
    "telefonici": "telefonic",
    "telefonicii": "telefonic",
    "telefonicilor": "telefonic",
    "telefonicul": "telefonic",
    "telefonicului": "telefonic",
    "telefotografia": "telefotografie",
    "telefotografiei": "telefotografie",
    "telefotografii": "telefotografie",
    "telefotografiile": "telefotografie",
    "telefotografiilor": "telefotografie",
    "telegari": "telegar",
    "telegarii": "telegar",
    "telegarilor": "telegar",
    "telegarul": "telegar",
    "telegarului": "telegar",
    "telegenica": "telegenic",
    "telegenică": "telegenic",
    "telegenice": "telegenic",
    "telegenicei": "telegenic",
    "telegenicele": "telegenic",
    "telegenicelor": "telegenic",
    "telegenici": "telegenic",
    "telegenicii": "telegenic",
    "telegenicilor": "telegenic",
    "telegenicul": "telegenic",
    "telegenicului": "telegenic",
    "nemaiteleghidând": "teleghida",
    "nemaiteleghidându": "teleghida",
    "neteleghidând": "teleghida",
    "neteleghidându": "teleghida",
    "teleghidă": "teleghida",
    "teleghidai": "teleghida",
    "teleghidam": "teleghida",
    "teleghidăm": "teleghida",
    "teleghidând": "teleghida",
    "teleghidându": "teleghida",
    "teleghidară": "teleghida",
    "teleghidarăm": "teleghida",
    "teleghidarăți": "teleghida",
    "teleghidase": "teleghida",
    "teleghidasem": "teleghida",
    "teleghidaseră": "teleghida",
    "teleghidaserăm": "teleghida",
    "teleghidaserăți": "teleghida",
    "teleghidaseși": "teleghida",
    "teleghidași": "teleghida",
    "teleghidat": "teleghida",
    "teleghidați": "teleghida",
    "teleghidatu": "teleghida",
    "teleghidau": "teleghida",
    "teleghidează": "teleghida",
    "teleghidez": "teleghida",
    "teleghideze": "teleghida",
    "teleghidezi": "teleghida",
    "teleghidarea": "teleghidare",
    "teleghidări": "teleghidare",
    "teleghidării": "teleghidare",
    "teleghidările": "teleghidare",
    "teleghidata": "teleghidat",
    "teleghidată": "teleghidat",
    "teleghidate": "teleghidat",
    "teleghidatei": "teleghidat",
    "teleghidatele": "teleghidat",
    "teleghidatelor": "teleghidat",
    "teleghidați": "teleghidat",
    "teleghidații": "teleghidat",
    "teleghidaților": "teleghidat",
    "teleghidatul": "teleghidat",
    "teleghidatului": "teleghidat",
    "telegrafe": "telegraf",
    "telegrafele": "telegraf",
    "telegrafelor": "telegraf",
    "telegraful": "telegraf",
    "telegrafului": "telegraf",
    "telegrafiata": "telegrafiat",
    "telegrafiată": "telegrafiat",
    "telegrafiate": "telegrafiat",
    "telegrafiatei": "telegrafiat",
    "telegrafiatele": "telegrafiat",
    "telegrafiatelor": "telegrafiat",
    "telegrafiați": "telegrafiat",
    "telegrafiații": "telegrafiat",
    "telegrafiaților": "telegrafiat",
    "telegrafiatul": "telegrafiat",
    "telegrafiatului": "telegrafiat",
    "telegrafica": "telegrafic",
    "telegrafică": "telegrafic",
    "telegrafice": "telegrafic",
    "telegraficei": "telegrafic",
    "telegraficele": "telegrafic",
    "telegraficelor": "telegrafic",
    "telegrafici": "telegrafic",
    "telegraficii": "telegrafic",
    "telegraficilor": "telegrafic",
    "telegraficul": "telegrafic",
    "telegraficului": "telegrafic",
    "telegrama": "telegramă",
    "telegrame": "telegramă",
    "telegramei": "telegramă",
    "telegramele": "telegramă",
    "telegramelor": "telegramă",
    "teleimprimatoare": "teleimprimator",
    "teleimprimatoarele": "teleimprimator",
    "teleimprimatoarelor": "teleimprimator",
    "teleimprimatorul": "teleimprimator",
    "teleimprimatorului": "teleimprimator",
    "telejurnale": "telejurnal",
    "telejurnalele": "telejurnal",
    "telejurnalelor": "telejurnal",
    "telejurnalul": "telejurnal",
    "telejurnalului": "telejurnal",
    "telemetria": "telemetrie",
    "telemetriei": "telemetrie",
    "telemetrii": "telemetrie",
    "telemetriile": "telemetrie",
    "telemetriilor": "telemetrie",
    "telemetre": "telemetru",
    "telemetrele": "telemetru",
    "telemetrelor": "telemetru",
    "telemetrul": "telemetru",
    "telemetrului": "telemetru",
    "teleobiective": "teleobiectiv",
    "teleobiectivele": "teleobiectiv",
    "teleobiectivelor": "teleobiectiv",
    "teleobiectivul": "teleobiectiv",
    "teleobiectivului": "teleobiectiv",
    "telepatia": "telepatie",
    "telepatiei": "telepatie",
    "telepatii": "telepatie",
    "telepatiile": "telepatie",
    "telepatiilor": "telepatie",
    "teleprograme": "teleprogram",
    "teleprogramele": "teleprogram",
    "teleprogramelor": "teleprogram",
    "teleprogramul": "teleprogram",
    "teleprogramule": "teleprogram",
    "teleprogramului": "teleprogram",
    "tele-programe": "tele-program",
    "tele-programele": "tele-program",
    "tele-programelor": "tele-program",
    "tele-programul": "tele-program",
    "tele-programului": "tele-program",
    "telescoape": "telescop",
    "telescoapele": "telescop",
    "telescoapelor": "telescop",
    "telescopul": "telescop",
    "telescopului": "telescop",
    "telespectatoarea": "telespectatoare",
    "telespectatoarei": "telespectatoare",
    "telespectatoarele": "telespectatoare",
    "telespectatoarelor": "telespectatoare",
    "telespectatori": "telespectator",
    "telespectatorii": "telespectator",
    "telespectatorilor": "telespectator",
    "telespectatorul": "telespectator",
    "telespectatorului": "telespectator",
    "televizata": "televizat",
    "televizată": "televizat",
    "televizate": "televizat",
    "televizatei": "televizat",
    "televizatele": "televizat",
    "televizatelor": "televizat",
    "televizato": "televizat",
    "televizatul": "televizat",
    "televizatului": "televizat",
    "televiziunea": "televiziune",
    "televiziuni": "televiziune",
    "televiziunii": "televiziune",
    "televiziunile": "televiziune",
    "televiziunilor": "televiziune",
    "TV": "televiziune",
    "TV.": "televiziune",
    "TVM": "Televiziunea_Moldovenească",
    "Televiziune_Română": "Televiziunea_Română",
    "Televiziuni_Române": "Televiziunea_Română",
    "Televiziunii_Române": "Televiziunea_Română",
    "TVR": "Televiziunea_Română",
    "televizoare": "televizor",
    "televizoarele": "televizor",
    "televizoarelor": "televizor",
    "televizorul": "televizor",
    "televizorului": "televizor",
    "tv.": "televizor",
    "televorbitoarea": "televorbitoare",
    "televorbitoarele": "televorbitoare",
    "televorbitoarelor": "televorbitoare",
    "televorbitori": "televorbitor",
    "televorbitorii": "televorbitor",
    "televorbitorilor": "televorbitor",
    "televorbitorul": "televorbitor",
    "televorbitorului": "televorbitor",
    "telexul": "telex",
    "telexului": "telex",
    "telexuri": "telex",
    "telexurile": "telex",
    "telexurilor": "telex",
    "țelina": "țelină",
    "țeline": "țelină",
    "țelinei": "țelină",
    "țelinele": "țelină",
    "țelinelor": "țelină",
    "țelinioara": "țelinioară",
    "țelinioare": "țelinioară",
    "țelinioarei": "țelinioară",
    "țelinioarele": "țelinioară",
    "țelinioarelor": "țelinioară",
    "Te": "telur",
    "telurul": "telur",
    "telurului": "telur",
    "telurica": "teluric",
    "telurică": "teluric",
    "telurice": "teluric",
    "teluricei": "teluric",
    "teluricele": "teluric",
    "teluricelor": "teluric",
    "telurici": "teluric",
    "teluricii": "teluric",
    "teluricilor": "teluric",
    "teluricul": "teluric",
    "teluricului": "teluric",
    "tema": "temă",
    "teme": "temă",
    "temei": "temă",
    "temele": "temă",
    "temelor": "temă",
    "tematica": "tematic",
    "tematică": "tematic",
    "tematice": "tematic",
    "tematicei": "tematic",
    "tematicele": "tematic",
    "tematicelor": "tematic",
    "tematici": "tematic",
    "tematicii": "tematic",
    "tematicilor": "tematic",
    "tematicul": "tematic",
    "tematicului": "tematic",
    "tematica": "tematică",
    "tematicele": "tematică",
    "tematicelor": "tematică",
    "tematici": "tematică",
    "tematicii": "tematică",
    "temătoarea": "temătoare",
    "temătoarei": "temătoare",
    "temătoarele": "temătoare",
    "temătoarelor": "temătoare",
    "temătoareo": "temătoare",
    "temătoare": "temător",
    "temătoarea": "temător",
    "temătoarei": "temător",
    "temătoarele": "temător",
    "temătoarelor": "temător",
    "temătoareo": "temător",
    "temători": "temător",
    "temătorii": "temător",
    "temătorilor": "temător",
    "temătorul": "temător",
    "temătorule": "temător",
    "temătorului": "temător",
    "tembela": "tembel",
    "tembelă": "tembel",
    "tembele": "tembel",
    "tembelei": "tembel",
    "tembelele": "tembel",
    "tembelelor": "tembel",
    "tembeli": "tembel",
    "tembelii": "tembel",
    "tembelilor": "tembel",
    "tembelul": "tembel",
    "tembelule": "tembel",
    "tembelului": "tembel",
    "tembela": "tembelă",
    "tembele": "tembelă",
    "tembelei": "tembelă",
    "tembelele": "tembelă",
    "tembelelor": "tembelă",
    "tembelo": "tembelă",
    "tembelisme": "tembelism",
    "tembelismele": "tembelism",
    "tembelismelor": "tembelism",
    "tembelismul": "tembelism",
    "tembelismului": "tembelism",
    "nemaitemând": "teme",
    "nemaitemându": "teme",
    "netemând": "teme",
    "netemându": "teme",
    "teamă": "teme",
    "tem": "teme",
    "temând": "teme",
    "temându": "teme",
    "temea": "teme",
    "temeai": "teme",
    "temeam": "teme",
    "temeați": "teme",
    "temeau": "teme",
    "temem": "teme",
    "temeți": "teme",
    "temi": "teme",
    "temu": "teme",
    "temui": "teme",
    "temură": "teme",
    "temurăm": "teme",
    "temurăți": "teme",
    "temuse": "teme",
    "temusem": "teme",
    "temuseră": "teme",
    "temuserăm": "teme",
    "temuserăți": "teme",
    "temuseși": "teme",
    "temuși": "teme",
    "temut": "teme",
    "temutu": "teme",
    "temeiul": "temei",
    "temeiului": "temei",
    "temeiuri": "temei",
    "temeiurile": "temei",
    "temeiurilor": "temei",
    "temeinica": "temeinic",
    "temeinică": "temeinic",
    "temeinice": "temeinic",
    "temeinicei": "temeinic",
    "temeinicele": "temeinic",
    "temeinicelor": "temeinic",
    "temeinici": "temeinic",
    "temeinicii": "temeinic",
    "temeinicilor": "temeinic",
    "temeinicul": "temeinic",
    "temeinicului": "temeinic",
    "temeinicia": "temeinicie",
    "temeiniciei": "temeinicie",
    "temeinicii": "temeinicie",
    "temeiniciile": "temeinicie",
    "temeiniciilor": "temeinicie",
    "temelia": "temelie",
    "temeliei": "temelie",
    "temelii": "temelie",
    "temeliile": "temelie",
    "temeliilor": "temelie",
    "temeneaua": "temenea",
    "temenele": "temenea",
    "temenelei": "temenea",
    "temenelele": "temenea",
    "temenelelor": "temenea",
    "temerara": "temerar",
    "temerară": "temerar",
    "temerare": "temerar",
    "temerarei": "temerar",
    "temerarele": "temerar",
    "temerarelor": "temerar",
    "temerari": "temerar",
    "temerarii": "temerar",
    "temerarilor": "temerar",
    "temerarul": "temerar",
    "temerarului": "temerar",
    "temerea": "temere",
    "temereo": "temere",
    "temeri": "temere",
    "temerii": "temere",
    "temerile": "temere",
    "temerilor": "temere",
    "temeritatea": "temeritate",
    "temerități": "temeritate",
    "temerității": "temeritate",
    "temeritățile": "temeritate",
    "temerităților": "temeritate",
    "temniceri": "temnicer",
    "temnicerii": "temnicer",
    "temnicerilor": "temnicer",
    "temnicerul": "temnicer",
    "temnicerului": "temnicer",
    "temnița": "temniță",
    "temnițe": "temniță",
    "temniței": "temniță",
    "temnițele": "temniță",
    "temnițelor": "temniță",
    "nemaitemperând": "tempera",
    "nemaitemperându": "tempera",
    "netemperând": "tempera",
    "netemperându": "tempera",
    "temperă": "tempera",
    "temperai": "tempera",
    "temperam": "tempera",
    "temperăm": "tempera",
    "temperând": "tempera",
    "temperându": "tempera",
    "temperară": "tempera",
    "temperarăm": "tempera",
    "temperarăți": "tempera",
    "temperase": "tempera",
    "temperasem": "tempera",
    "temperaseră": "tempera",
    "temperaserăm": "tempera",
    "temperaserăți": "tempera",
    "temperaseși": "tempera",
    "temperași": "tempera",
    "temperat": "tempera",
    "temperați": "tempera",
    "temperatu": "tempera",
    "temperau": "tempera",
    "temperează": "tempera",
    "temperei": "tempera",
    "temperele": "tempera",
    "temperelor": "tempera",
    "temperez": "tempera",
    "tempereze": "tempera",
    "temperezi": "tempera",
    "temperi": "tempera",
    "temperamente": "temperament",
    "temperamentele": "temperament",
    "temperamentelor": "temperament",
    "temperamentul": "temperament",
    "temperamentului": "temperament",
    "temperamentala": "temperamental",
    "temperamentală": "temperamental",
    "temperamentale": "temperamental",
    "temperamentalei": "temperamental",
    "temperamentalele": "temperamental",
    "temperamentalelor": "temperamental",
    "temperamentali": "temperamental",
    "temperamentalii": "temperamental",
    "temperamentalilor": "temperamental",
    "temperamentalul": "temperamental",
    "temperamentalului": "temperamental",
    "temperanța": "temperanță",
    "temperanțe": "temperanță",
    "temperanței": "temperanță",
    "temperanțele": "temperanță",
    "temperanțelor": "temperanță",
    "temperarea": "temperare",
    "temperări": "temperare",
    "temperării": "temperare",
    "temperările": "temperare",
    "temperata": "temperat",
    "temperată": "temperat",
    "temperate": "temperat",
    "temperatei": "temperat",
    "temperatele": "temperat",
    "temperatelor": "temperat",
    "temperați": "temperat",
    "temperații": "temperat",
    "temperaților": "temperat",
    "temperatul": "temperat",
    "temperatului": "temperat",
    "temperatura": "temperatură",
    "temperaturi": "temperatură",
    "temperaturii": "temperatură",
    "temperaturile": "temperatură",
    "temperaturilor": "temperatură",
    "tempesta": "tempestă",
    "tempeste": "tempestă",
    "tempestei": "tempestă",
    "tempestele": "tempestă",
    "tempestelor": "tempestă",
    "temple": "templu",
    "templele": "templu",
    "templelor": "templu",
    "templul": "templu",
    "templului": "templu",
    "tempoul": "tempo",
    "tempoului": "tempo",
    "tempouri": "tempo",
    "tempourile": "tempo",
    "tempourilor": "tempo",
    "temporala": "temporal",
    "temporală": "temporal",
    "temporale": "temporal",
    "temporalei": "temporal",
    "temporalele": "temporal",
    "temporalelor": "temporal",
    "temporali": "temporal",
    "temporalii": "temporal",
    "temporalilor": "temporal",
    "temporalul": "temporal",
    "temporalului": "temporal",
    "temporalitatea": "temporalitate",
    "temporalități": "temporalitate",
    "temporalității": "temporalitate",
    "temporalitățile": "temporalitate",
    "temporalităților": "temporalitate",
    "temporara": "temporar",
    "temporară": "temporar",
    "temporare": "temporar",
    "temporarei": "temporar",
    "temporarele": "temporar",
    "temporarelor": "temporar",
    "temporari": "temporar",
    "temporarii": "temporar",
    "temporarilor": "temporar",
    "temporarul": "temporar",
    "temporarului": "temporar",
    "temuta": "temut",
    "temută": "temut",
    "temute": "temut",
    "temutei": "temut",
    "temutele": "temut",
    "temutelor": "temut",
    "temuți": "temut",
    "temuții": "temut",
    "temuților": "temut",
    "temuto": "temut",
    "temutul": "temut",
    "temutule": "temut",
    "temutului": "temut",
    "tenul": "ten",
    "tenului": "ten",
    "tenuri": "ten",
    "tenurile": "ten",
    "tenurilor": "ten",
    "tenacele": "tenace",
    "tenacelui": "tenace",
    "tenaci": "tenace",
    "tenacii": "tenace",
    "tenacilor": "tenace",
    "tencuiala": "tencuială",
    "tencuialo": "tencuială",
    "tencuieli": "tencuială",
    "tencuielii": "tencuială",
    "tencuielile": "tencuială",
    "tencuielilor": "tencuială",
    "tencuita": "tencuit",
    "tencuită": "tencuit",
    "tencuite": "tencuit",
    "tencuitei": "tencuit",
    "tencuitele": "tencuit",
    "tencuitelor": "tencuit",
    "tencuiți": "tencuit",
    "tencuiții": "tencuit",
    "tencuiților": "tencuit",
    "tencuitul": "tencuit",
    "tencuitului": "tencuit",
    "tenculețe": "tenculeț",
    "tenculețele": "tenculeț",
    "tenculețelor": "tenculeț",
    "tenculețul": "tenculeț",
    "tenculețului": "tenculeț",
    "tendențioasa": "tendențios",
    "tendențioasă": "tendențios",
    "tendențioase": "tendențios",
    "tendențioasei": "tendențios",
    "tendențioasele": "tendențios",
    "tendențioaselor": "tendențios",
    "tendențioși": "tendențios",
    "tendențioșii": "tendențios",
    "tendențioșilor": "tendențios",
    "tendențiosul": "tendențios",
    "tendențiosului": "tendențios",
    "tendere": "tender",
    "tenderele": "tender",
    "tenderelor": "tender",
    "tenderul": "tender",
    "tenderului": "tender",
    "tendința": "tendință",
    "tendințe": "tendință",
    "tendinței": "tendință",
    "tendințele": "tendință",
    "tendințelor": "tendință",
    "tendoane": "tendon",
    "tendoanele": "tendon",
    "tendoanelor": "tendon",
    "tendonul": "tendon",
    "tendonului": "tendon",
    "tenebra": "tenebră",
    "tenebre": "tenebră",
    "tenebrei": "tenebră",
    "tenebrele": "tenebră",
    "tenebrelor": "tenebră",
    "tenebroasa": "tenebros",
    "tenebroasă": "tenebros",
    "tenebroase": "tenebros",
    "tenebroasei": "tenebros",
    "tenebroasele": "tenebros",
    "tenebroaselor": "tenebros",
    "tenebroși": "tenebros",
    "tenebroșii": "tenebros",
    "tenebroșilor": "tenebros",
    "tenebrosul": "tenebros",
    "tenebrosului": "tenebros",
    "tenismani": "tenisman",
    "tenismanul": "tenisman",
    "tenismanului": "tenisman",
    "tenismeni": "tenisman",
    "tenismenii": "tenisman",
    "tenismenilor": "tenisman",
    "tenori": "tenor",
    "tenorii": "tenor",
    "tenorilor": "tenor",
    "tenorul": "tenor",
    "tenorului": "tenor",
    "tenorala": "tenoral",
    "tenorală": "tenoral",
    "tenorale": "tenoral",
    "tenoralei": "tenoral",
    "tenoralele": "tenoral",
    "tenoralelor": "tenoral",
    "tenorali": "tenoral",
    "tenoralii": "tenoral",
    "tenoralilor": "tenoral",
    "tenoralul": "tenoral",
    "tenoralului": "tenoral",
    "tensiometre": "tensiometru",
    "tensiometrele": "tensiometru",
    "tensiometrelor": "tensiometru",
    "tensiometrul": "tensiometru",
    "tensiometrului": "tensiometru",
    "tensionarea": "tensionare",
    "tensionări": "tensionare",
    "tensionării": "tensionare",
    "tensionările": "tensionare",
    "tensionata": "tensionat",
    "tensionată": "tensionat",
    "tensionate": "tensionat",
    "tensionatei": "tensionat",
    "tensionatele": "tensionat",
    "tensionatelor": "tensionat",
    "tensionați": "tensionat",
    "tensionații": "tensionat",
    "tensionaților": "tensionat",
    "tensionatul": "tensionat",
    "tensionatului": "tensionat",
    "tensiunea": "tensiune",
    "tensiuni": "tensiune",
    "tensiunii": "tensiune",
    "tensiunile": "tensiune",
    "tensiunilor": "tensiune",
    "nemaitentând": "tenta",
    "nemaitentându": "tenta",
    "netentând": "tenta",
    "netentându": "tenta",
    "tentă": "tenta",
    "tentai": "tenta",
    "tentam": "tenta",
    "tentăm": "tenta",
    "tentând": "tenta",
    "tentându": "tenta",
    "tentară": "tenta",
    "tentarăm": "tenta",
    "tentarăți": "tenta",
    "tentase": "tenta",
    "tentasem": "tenta",
    "tentaseră": "tenta",
    "tentaserăm": "tenta",
    "tentaserăți": "tenta",
    "tentaseși": "tenta",
    "tentași": "tenta",
    "tentat": "tenta",
    "tentați": "tenta",
    "tentatu": "tenta",
    "tentau": "tenta",
    "tentează": "tenta",
    "tentez": "tenta",
    "tenteze": "tenta",
    "tentezi": "tenta",
    "tenta": "tentă",
    "tente": "tentă",
    "tentei": "tentă",
    "tentele": "tentă",
    "tentelor": "tentă",
    "tentacule": "tentacul",
    "tentaculele": "tentacul",
    "tentaculelor": "tentacul",
    "tentaculul": "tentacul",
    "tentaculului": "tentacul",
    "tentarea": "tentare",
    "tentări": "tentare",
    "tentării": "tentare",
    "tentările": "tentare",
    "tentata": "tentat",
    "tentată": "tentat",
    "tentate": "tentat",
    "tentatei": "tentat",
    "tentatele": "tentat",
    "tentatelor": "tentat",
    "tentați": "tentat",
    "tentații": "tentat",
    "tentaților": "tentat",
    "tentatul": "tentat",
    "tentatului": "tentat",
    "tentația": "tentație",
    "tentației": "tentație",
    "tentații": "tentație",
    "tentațiile": "tentație",
    "tentațiilor": "tentație",
    "tentativa": "tentativă",
    "tentative": "tentativă",
    "tentativei": "tentativă",
    "tentativele": "tentativă",
    "tentativelor": "tentativă",
    "teocrația": "teocrație",
    "teocrației": "teocrație",
    "teocrații": "teocrație",
    "teocrațiile": "teocrație",
    "teocrațiilor": "teocrație",
    "teogonia": "teogonie",
    "teogoniei": "teogonie",
    "teogonii": "teogonie",
    "teogoniile": "teogonie",
    "teogoniilor": "teogonie",
    "teologi": "teolog",
    "teologii": "teolog",
    "teologilor": "teolog",
    "teologul": "teolog",
    "teologului": "teolog",
    "teologica": "teologic",
    "teologică": "teologic",
    "teologice": "teologic",
    "teologicei": "teologic",
    "teologicele": "teologic",
    "teologicelor": "teologic",
    "teologici": "teologic",
    "teologicii": "teologic",
    "teologicilor": "teologic",
    "teologicul": "teologic",
    "teologicului": "teologic",
    "teologia": "teologie",
    "teologiei": "teologie",
    "teologii": "teologie",
    "teologiile": "teologie",
    "teologiilor": "teologie",
    "teorema": "teoremă",
    "teoreme": "teoremă",
    "teoremei": "teoremă",
    "teoremele": "teoremă",
    "teoremelor": "teoremă",
    "teoretica": "teoretic",
    "teoretică": "teoretic",
    "teoretice": "teoretic",
    "teoreticei": "teoretic",
    "teoreticele": "teoretic",
    "teoreticelor": "teoretic",
    "teoretici": "teoretic",
    "teoreticii": "teoretic",
    "teoreticilor": "teoretic",
    "teoreticul": "teoretic",
    "teoreticului": "teoretic",
    "teoreticianul": "teoretician",
    "teoreticianului": "teoretician",
    "teoreticieni": "teoretician",
    "teoreticienii": "teoretician",
    "teoreticienilor": "teoretician",
    "teoretiză": "teoretiza",
    "teoretizai": "teoretiza",
    "teoretizam": "teoretiza",
    "teoretizăm": "teoretiza",
    "teoretizând": "teoretiza",
    "teoretizându": "teoretiza",
    "teoretizară": "teoretiza",
    "teoretizarăm": "teoretiza",
    "teoretizarăți": "teoretiza",
    "teoretizase": "teoretiza",
    "teoretizasem": "teoretiza",
    "teoretizaseră": "teoretiza",
    "teoretizaserăm": "teoretiza",
    "teoretizaserăți": "teoretiza",
    "teoretizaseși": "teoretiza",
    "teoretizași": "teoretiza",
    "teoretizat": "teoretiza",
    "teoretizați": "teoretiza",
    "teoretizatu": "teoretiza",
    "teoretizau": "teoretiza",
    "teoretizează": "teoretiza",
    "teoretizez": "teoretiza",
    "teoretizeze": "teoretiza",
    "teoretizezi": "teoretiza",
    "teoretizarea": "teoretizare",
    "teoretizări": "teoretizare",
    "teoretizării": "teoretizare",
    "teoretizările": "teoretizare",
    "teoretizata": "teoretizat",
    "teoretizată": "teoretizat",
    "teoretizate": "teoretizat",
    "teoretizatei": "teoretizat",
    "teoretizatele": "teoretizat",
    "teoretizatelor": "teoretizat",
    "teoretizați": "teoretizat",
    "teoretizații": "teoretizat",
    "teoretizaților": "teoretizat",
    "teoretizatul": "teoretizat",
    "teoretizatului": "teoretizat",
    "teoria": "teorie",
    "teoriei": "teorie",
    "teorii": "teorie",
    "teoriile": "teorie",
    "teoriilor": "teorie",
    "teozofia": "teozofie",
    "teozofiei": "teozofie",
    "teozofii": "teozofie",
    "teozofiile": "teozofie",
    "teozofiilor": "teozofie",
    "țepi": "țep",
    "țepii": "țep",
    "țepilor": "țep",
    "țepul": "țep",
    "țepului": "țep",
    "țepoasa": "țepos",
    "țepoasă": "țepos",
    "țepoase": "țepos",
    "țepoasei": "țepos",
    "țepoasele": "țepos",
    "țepoaselor": "țepos",
    "țepoși": "țepos",
    "țepoșii": "țepos",
    "țepoșilor": "țepos",
    "țeposul": "țepos",
    "țeposului": "țepos",
    "teracota": "teracotă",
    "teracote": "teracotă",
    "teracotei": "teracotă",
    "teracotele": "teracotă",
    "teracotelor": "teracotă",
    "teracoto": "teracotă",
    "terapeutica": "terapeutic",
    "terapeutică": "terapeutic",
    "terapeutice": "terapeutic",
    "terapeuticei": "terapeutic",
    "terapeuticele": "terapeutic",
    "terapeuticelor": "terapeutic",
    "terapeutici": "terapeutic",
    "terapeuticii": "terapeutic",
    "terapeuticilor": "terapeutic",
    "terapeuticul": "terapeutic",
    "terapeuticului": "terapeutic",
    "terapeutica": "terapeutică",
    "terapeuticele": "terapeutică",
    "terapeuticelor": "terapeutică",
    "terapeutici": "terapeutică",
    "terapeuticii": "terapeutică",
    "terapia": "terapie",
    "terapiei": "terapie",
    "terapii": "terapie",
    "terapiile": "terapie",
    "terapiilor": "terapie",
    "terasa": "terasă",
    "terase": "terasă",
    "terasei": "terasă",
    "terasele": "terasă",
    "teraselor": "terasă",
    "terasamente": "terasament",
    "terasamentele": "terasament",
    "terasamentelor": "terasament",
    "terasamentul": "terasament",
    "terasamentului": "terasament",
    "teratologia": "teratologie",
    "teratologiei": "teratologie",
    "teratologii": "teratologie",
    "teratologiile": "teratologie",
    "teratologiilor": "teratologie",
    "teratomul": "teratom",
    "teratomului": "teratom",
    "teratomuri": "teratom",
    "teratomurile": "teratom",
    "teratomurilor": "teratom",
    "Tb": "terbiu",
    "terbiul": "terbiu",
    "terbiului": "terbiu",
    "terciul": "terci",
    "terciului": "terci",
    "terciuri": "terci",
    "terciurile": "terci",
    "terciurilor": "terci",
    "terciuia": "terciui",
    "terciuiai": "terciui",
    "terciuiam": "terciui",
    "terciuiați": "terciui",
    "terciuiau": "terciui",
    "terciuiesc": "terciui",
    "terciuiește": "terciui",
    "terciuii": "terciui",
    "terciuim": "terciui",
    "terciuind": "terciui",
    "terciuindu": "terciui",
    "terciuiră": "terciui",
    "terciuirăm": "terciui",
    "terciuirăți": "terciui",
    "terciuise": "terciui",
    "terciuisem": "terciui",
    "terciuiseră": "terciui",
    "terciuiserăm": "terciui",
    "terciuiserăți": "terciui",
    "terciuiseși": "terciui",
    "terciuiși": "terciui",
    "terciuit": "terciui",
    "terciuiți": "terciui",
    "terciuitu": "terciui",
    "terciuită": "terciuit",
    "terciuite": "terciuit",
    "terciuiți": "terciuit",
    "terebentina": "terebentină",
    "terebentine": "terebentină",
    "terebentinei": "terebentină",
    "terebentinele": "terebentină",
    "terebentinelor": "terebentină",
    "terenul": "teren",
    "terenului": "teren",
    "terenuri": "teren",
    "terenurile": "teren",
    "terenurilor": "teren",
    "terestra": "terestru",
    "terestră": "terestru",
    "terestre": "terestru",
    "terestrei": "terestru",
    "terestrele": "terestru",
    "terestrelor": "terestru",
    "tereștri": "terestru",
    "tereștrii": "terestru",
    "tereștrilor": "terestru",
    "terestro": "terestru",
    "terestrul": "terestru",
    "terestrule": "terestru",
    "terestrului": "terestru",
    "nemaiterfelind": "terfeli",
    "nemaiterfelindu": "terfeli",
    "neterfelind": "terfeli",
    "neterfelindu": "terfeli",
    "terfelea": "terfeli",
    "terfeleai": "terfeli",
    "terfeleam": "terfeli",
    "terfelească": "terfeli",
    "terfeleați": "terfeli",
    "terfeleau": "terfeli",
    "terfelesc": "terfeli",
    "terfelește": "terfeli",
    "terfelești": "terfeli",
    "terfelii": "terfeli",
    "terfelim": "terfeli",
    "terfelind": "terfeli",
    "terfelindu": "terfeli",
    "terfeliră": "terfeli",
    "terfelirăm": "terfeli",
    "terfelirăți": "terfeli",
    "terfelise": "terfeli",
    "terfelisem": "terfeli",
    "terfeliseră": "terfeli",
    "terfeliserăm": "terfeli",
    "terfeliserăți": "terfeli",
    "terfeliseși": "terfeli",
    "terfeliși": "terfeli",
    "terfelit": "terfeli",
    "terfeliți": "terfeli",
    "terfelitu": "terfeli",
    "terfelirea": "terfelire",
    "terfeliri": "terfelire",
    "terfelirii": "terfelire",
    "terfelirile": "terfelire",
    "terfelita": "terfelit",
    "terfelită": "terfelit",
    "terfelite": "terfelit",
    "terfelitei": "terfelit",
    "terfelitele": "terfelit",
    "terfelitelor": "terfelit",
    "terfeliți": "terfelit",
    "terfeliții": "terfelit",
    "terfeliților": "terfelit",
    "terfelitul": "terfelit",
    "terfelitului": "terfelit",
    "terfeloage": "terfelog",
    "terfeloagele": "terfelog",
    "terfeloagelor": "terfelog",
    "terfelogul": "terfelog",
    "terfelogului": "terfelog",
    "tergalul": "tergal",
    "tergalului": "tergal",
    "tergaluri": "tergal",
    "tergalurile": "tergal",
    "tergalurilor": "tergal",
    "nemaitergiversând": "tergiversa",
    "nemaitergiversându": "tergiversa",
    "netergiversând": "tergiversa",
    "netergiversându": "tergiversa",
    "tergiversă": "tergiversa",
    "tergiversai": "tergiversa",
    "tergiversam": "tergiversa",
    "tergiversăm": "tergiversa",
    "tergiversând": "tergiversa",
    "tergiversându": "tergiversa",
    "tergiversară": "tergiversa",
    "tergiversarăm": "tergiversa",
    "tergiversarăți": "tergiversa",
    "tergiversase": "tergiversa",
    "tergiversasem": "tergiversa",
    "tergiversaseră": "tergiversa",
    "tergiversaserăm": "tergiversa",
    "tergiversaserăți": "tergiversa",
    "tergiversaseși": "tergiversa",
    "tergiversași": "tergiversa",
    "tergiversat": "tergiversa",
    "tergiversați": "tergiversa",
    "tergiversatu": "tergiversa",
    "tergiversau": "tergiversa",
    "tergiversează": "tergiversa",
    "tergiversez": "tergiversa",
    "tergiverseze": "tergiversa",
    "tergiversezi": "tergiversa",
    "tergiversarea": "tergiversare",
    "tergiversări": "tergiversare",
    "tergiversării": "tergiversare",
    "tergiversările": "tergiversare",
    "tergiversata": "tergiversat",
    "tergiversată": "tergiversat",
    "tergiversate": "tergiversat",
    "tergiversatei": "tergiversat",
    "tergiversatele": "tergiversat",
    "tergiversatelor": "tergiversat",
    "tergiversați": "tergiversat",
    "tergiversații": "tergiversat",
    "tergiversaților": "tergiversat",
    "tergiversatul": "tergiversat",
    "tergiversatului": "tergiversat",
    "teribila": "teribil",
    "teribilă": "teribil",
    "teribile": "teribil",
    "teribilei": "teribil",
    "teribilele": "teribil",
    "teribilelor": "teribil",
    "teribili": "teribil",
    "teribilii": "teribil",
    "teribililor": "teribil",
    "teribilul": "teribil",
    "teribilului": "teribil",
    "teribilisme": "teribilism",
    "teribilismele": "teribilism",
    "teribilismelor": "teribilism",
    "teribilismul": "teribilism",
    "teribilismului": "teribilism",
    "terifianta": "terifiant",
    "terifiantă": "terifiant",
    "terifiante": "terifiant",
    "terifiantei": "terifiant",
    "terifiantele": "terifiant",
    "terifiantelor": "terifiant",
    "terifianți": "terifiant",
    "terifianții": "terifiant",
    "terifianților": "terifiant",
    "terifiantul": "terifiant",
    "terifiantului": "terifiant",
    "teritoriala": "teritorial",
    "teritorială": "teritorial",
    "teritoriale": "teritorial",
    "teritorialei": "teritorial",
    "teritorialele": "teritorial",
    "teritorialelor": "teritorial",
    "teritoriali": "teritorial",
    "teritorialii": "teritorial",
    "teritorialilor": "teritorial",
    "teritorialul": "teritorial",
    "teritorialului": "teritorial",
    "teritorii": "teritoriu",
    "teritoriile": "teritoriu",
    "teritoriilor": "teritoriu",
    "teritoriul": "teritoriu",
    "teritoriului": "teritoriu",
    "termala": "termal",
    "termală": "termal",
    "termale": "termal",
    "termalei": "termal",
    "termalele": "termal",
    "termalelor": "termal",
    "termali": "termal",
    "termalii": "termal",
    "termalilor": "termal",
    "termalul": "termal",
    "termalului": "termal",
    "termele": "terme",
    "termelor": "terme",
    "termene": "termen",
    "termenele": "termen",
    "termenelor": "termen",
    "termeni": "termen",
    "termenii": "termen",
    "termenilor": "termen",
    "termenul": "termen",
    "termenului": "termen",
    "termica": "termic",
    "termică": "termic",
    "termice": "termic",
    "termicei": "termic",
    "termicele": "termic",
    "termicelor": "termic",
    "termici": "termic",
    "termicii": "termic",
    "termicilor": "termic",
    "termicul": "termic",
    "termicului": "termic",
    "nemaitermificând": "termifica",
    "nemaitermificându": "termifica",
    "netermificând": "termifica",
    "netermificându": "termifica",
    "termific": "termifica",
    "termifică": "termifica",
    "termificai": "termifica",
    "termificam": "termifica",
    "termificăm": "termifica",
    "termificând": "termifica",
    "termificându": "termifica",
    "termificară": "termifica",
    "termificarăm": "termifica",
    "termificarăți": "termifica",
    "termificase": "termifica",
    "termificasem": "termifica",
    "termificaseră": "termifica",
    "termificaserăm": "termifica",
    "termificaserăți": "termifica",
    "termificaseși": "termifica",
    "termificași": "termifica",
    "termificat": "termifica",
    "termificați": "termifica",
    "termificatu": "termifica",
    "termificau": "termifica",
    "termifice": "termifica",
    "termifici": "termifica",
    "termificarea": "termificare",
    "termificări": "termificare",
    "termificării": "termificare",
    "termificările": "termificare",
    "termificata": "termificat",
    "termificată": "termificat",
    "termificate": "termificat",
    "termificatei": "termificat",
    "termificatele": "termificat",
    "termificatelor": "termificat",
    "termificați": "termificat",
    "termificații": "termificat",
    "termificaților": "termificat",
    "termificatul": "termificat",
    "termificatului": "termificat",
    "nemaiterminând": "termina",
    "nemaiterminându": "termina",
    "neterminând": "termina",
    "neterminându": "termina",
    "termin": "termina",
    "termină": "termina",
    "terminai": "termina",
    "terminam": "termina",
    "terminăm": "termina",
    "terminând": "termina",
    "terminându": "termina",
    "terminară": "termina",
    "terminarăm": "termina",
    "terminarăți": "termina",
    "terminase": "termina",
    "terminasem": "termina",
    "terminaseră": "termina",
    "terminaserăm": "termina",
    "terminaserăți": "termina",
    "terminaseși": "termina",
    "terminași": "termina",
    "terminat": "termina",
    "terminați": "termina",
    "terminatu": "termina",
    "terminau": "termina",
    "termine": "termina",
    "termini": "termina",
    "terminala": "terminal",
    "terminală": "terminal",
    "terminale": "terminal",
    "terminalei": "terminal",
    "terminalele": "terminal",
    "terminalelor": "terminal",
    "terminali": "terminal",
    "terminalii": "terminal",
    "terminalilor": "terminal",
    "terminalul": "terminal",
    "terminalului": "terminal",
    "terminarea": "terminare",
    "terminareo": "terminare",
    "terminări": "terminare",
    "terminării": "terminare",
    "terminările": "terminare",
    "terminărilor": "terminare",
    "terminata": "terminat",
    "terminată": "terminat",
    "terminate": "terminat",
    "terminatei": "terminat",
    "terminatele": "terminat",
    "terminatelor": "terminat",
    "terminați": "terminat",
    "terminații": "terminat",
    "terminaților": "terminat",
    "terminato": "terminat",
    "terminatul": "terminat",
    "terminatule": "terminat",
    "terminatului": "terminat",
    "terminația": "terminație",
    "terminației": "terminație",
    "terminații": "terminație",
    "terminațiile": "terminație",
    "terminațiilor": "terminație",
    "terminologica": "terminologic",
    "terminologică": "terminologic",
    "terminologice": "terminologic",
    "terminologicei": "terminologic",
    "terminologicele": "terminologic",
    "terminologicelor": "terminologic",
    "terminologici": "terminologic",
    "terminologicii": "terminologic",
    "terminologicilor": "terminologic",
    "terminologicul": "terminologic",
    "terminologicului": "terminologic",
    "terminologia": "terminologie",
    "terminologiei": "terminologie",
    "terminologii": "terminologie",
    "terminologiile": "terminologie",
    "terminologiilor": "terminologie",
    "termocentrala": "termocentrală",
    "termocentrale": "termocentrală",
    "termocentralei": "termocentrală",
    "termocentralele": "termocentrală",
    "termocentralelor": "termocentrală",
    "termocentrale-mamut": "termocentrală-mamut",
    "nemaitermoficând": "termofica",
    "nemaitermoficându": "termofica",
    "netermoficând": "termofica",
    "netermoficându": "termofica",
    "termofic": "termofica",
    "termofică": "termofica",
    "termoficai": "termofica",
    "termoficam": "termofica",
    "termoficăm": "termofica",
    "termoficând": "termofica",
    "termoficându": "termofica",
    "termoficară": "termofica",
    "termoficarăm": "termofica",
    "termoficarăți": "termofica",
    "termoficase": "termofica",
    "termoficasem": "termofica",
    "termoficaseră": "termofica",
    "termoficaserăm": "termofica",
    "termoficaserăți": "termofica",
    "termoficaseși": "termofica",
    "termoficași": "termofica",
    "termoficat": "termofica",
    "termoficați": "termofica",
    "termoficatu": "termofica",
    "termoficau": "termofica",
    "termofice": "termofica",
    "termofici": "termofica",
    "termoficarea": "termoficare",
    "termoficări": "termoficare",
    "termoficării": "termoficare",
    "termoficările": "termoficare",
    "termoficata": "termoficat",
    "termoficată": "termoficat",
    "termoficate": "termoficat",
    "termoficatei": "termoficat",
    "termoficatele": "termoficat",
    "termoficatelor": "termoficat",
    "termoficați": "termoficat",
    "termoficații": "termoficat",
    "termoficaților": "termoficat",
    "termoficatul": "termoficat",
    "termoficatului": "termoficat",
    "termofoare": "termofor",
    "termofoarele": "termofor",
    "termofoarelor": "termofor",
    "termoforul": "termofor",
    "termoforului": "termofor",
    "termogena": "termogen",
    "termogenă": "termogen",
    "termogene": "termogen",
    "termogenei": "termogen",
    "termogenele": "termogen",
    "termogenelor": "termogen",
    "termogeni": "termogen",
    "termogenii": "termogen",
    "termogenilor": "termogen",
    "termogenul": "termogen",
    "termogenului": "termogen",
    "termografe": "termograf",
    "termografele": "termograf",
    "termografelor": "termograf",
    "termograful": "termograf",
    "termografului": "termograf",
    "termologia": "termologie",
    "termologiei": "termologie",
    "termologii": "termologie",
    "termologiile": "termologie",
    "termologiilor": "termologie",
    "termonucleara": "termonuclear",
    "termonucleară": "termonuclear",
    "termonucleare": "termonuclear",
    "termonuclearei": "termonuclear",
    "termonuclearele": "termonuclear",
    "termonuclearelor": "termonuclear",
    "termonucleari": "termonuclear",
    "termonuclearii": "termonuclear",
    "termonuclearilor": "termonuclear",
    "termonuclearul": "termonuclear",
    "termonuclearului": "termonuclear",
    "termotehnica": "termotehnică",
    "termotehnici": "termotehnică",
    "termotehnicii": "termotehnică",
    "termotehnicile": "termotehnică",
    "termotehnicilor": "termotehnică",
    "termoterapia": "termoterapie",
    "termoterapiei": "termoterapie",
    "termoterapii": "termoterapie",
    "termoterapiile": "termoterapie",
    "termoterapiilor": "termoterapie",
    "terna": "tern",
    "ternă": "tern",
    "terne": "tern",
    "ternei": "tern",
    "ternele": "tern",
    "ternelor": "tern",
    "terni": "tern",
    "ternii": "tern",
    "ternilor": "tern",
    "ternul": "tern",
    "ternului": "tern",
    "ternara": "ternar",
    "ternară": "ternar",
    "ternare": "ternar",
    "ternarei": "ternar",
    "ternarele": "ternar",
    "ternarelor": "ternar",
    "ternari": "ternar",
    "ternarii": "ternar",
    "ternarilor": "ternar",
    "ternarul": "ternar",
    "ternarului": "ternar",
    "teroarea": "teroare",
    "terori": "teroare",
    "terorii": "teroare",
    "terorile": "teroare",
    "terorilor": "teroare",
    "terorisme": "terorism",
    "terorismele": "terorism",
    "terorismelor": "terorism",
    "terorismul": "terorism",
    "terorismului": "terorism",
    "terorista": "terorist",
    "teroristă": "terorist",
    "teroriste": "terorist",
    "teroristei": "terorist",
    "teroristele": "terorist",
    "teroristelor": "terorist",
    "teroriști": "terorist",
    "teroriștii": "terorist",
    "teroriștilor": "terorist",
    "teroristul": "terorist",
    "teroristului": "terorist",
    "terorista": "teroristă",
    "teroriste": "teroristă",
    "teroristei": "teroristă",
    "teroristele": "teroristă",
    "teroristelor": "teroristă",
    "nemaiteoretizând": "teroriza",
    "nemaiteoretizându": "teroriza",
    "nemaiterorizând": "teroriza",
    "nemaiterorizându": "teroriza",
    "neteoretizând": "teroriza",
    "neteoretizându": "teroriza",
    "neterorizând": "teroriza",
    "neterorizându": "teroriza",
    "teroriză": "teroriza",
    "terorizai": "teroriza",
    "terorizam": "teroriza",
    "terorizăm": "teroriza",
    "terorizând": "teroriza",
    "terorizându": "teroriza",
    "terorizară": "teroriza",
    "terorizarăm": "teroriza",
    "terorizarăți": "teroriza",
    "terorizase": "teroriza",
    "terorizasem": "teroriza",
    "terorizaseră": "teroriza",
    "terorizaserăm": "teroriza",
    "terorizaserăți": "teroriza",
    "terorizaseși": "teroriza",
    "terorizași": "teroriza",
    "terorizat": "teroriza",
    "terorizați": "teroriza",
    "terorizatu": "teroriza",
    "terorizau": "teroriza",
    "terorizează": "teroriza",
    "terorizez": "teroriza",
    "terorizeze": "teroriza",
    "terorizezi": "teroriza",
    "terorizarea": "terorizare",
    "terorizări": "terorizare",
    "terorizării": "terorizare",
    "terorizările": "terorizare",
    "terorizata": "terorizat",
    "terorizată": "terorizat",
    "terorizate": "terorizat",
    "terorizatei": "terorizat",
    "terorizatele": "terorizat",
    "terorizatelor": "terorizat",
    "terorizați": "terorizat",
    "terorizații": "terorizat",
    "terorizaților": "terorizat",
    "terorizatul": "terorizat",
    "terorizatului": "terorizat",
    "Terre": "Terra",
    "Terrei": "Terra",
    "terța": "terț",
    "terță": "terț",
    "terțe": "terț",
    "terței": "terț",
    "terțele": "terț",
    "terțelor": "terț",
    "terți": "terț",
    "terții": "terț",
    "terților": "terț",
    "terțul": "terț",
    "terțului": "terț",
    "terțete": "terțet",
    "terțetele": "terțet",
    "terțetelor": "terțet",
    "terțetul": "terțet",
    "terțetului": "terțet",
    "terțiara": "terțiar",
    "terțiară": "terțiar",
    "terțiare": "terțiar",
    "terțiarei": "terțiar",
    "terțiarele": "terțiar",
    "terțiarelor": "terțiar",
    "terțiari": "terțiar",
    "terțiarii": "terțiar",
    "terțiarilor": "terțiar",
    "terțiarul": "terțiar",
    "terțiarului": "terțiar",
    "terțina": "terțină",
    "terține": "terțină",
    "terținei": "terțină",
    "terținele": "terțină",
    "terținelor": "terțină",
    "tertipul": "tertip",
    "tertipului": "tertip",
    "tertipuri": "tertip",
    "tertipurile": "tertip",
    "tertipurilor": "tertip",
    "nemaițesălând": "țesăla",
    "nemaițesălându": "țesăla",
    "nețesălând": "țesăla",
    "nețesălându": "țesăla",
    "țesăl": "țesăla",
    "țesălă": "țesăla",
    "țesălai": "țesăla",
    "țesălam": "țesăla",
    "țesălăm": "țesăla",
    "țesălând": "țesăla",
    "țesălându": "țesăla",
    "țesălară": "țesăla",
    "țesălarăm": "țesăla",
    "țesălarăți": "țesăla",
    "țesălase": "țesăla",
    "țesălasem": "țesăla",
    "țesălaseră": "țesăla",
    "țesălaserăm": "țesăla",
    "țesălaserăți": "țesăla",
    "țesălaseși": "țesăla",
    "țesălași": "țesăla",
    "țesălat": "țesăla",
    "țesălați": "țesăla",
    "țesălau": "țesăla",
    "țesăle": "țesăla",
    "țesăli": "țesăla",
    "țesălarea": "țesălare",
    "țesălareo": "țesălare",
    "țesălări": "țesălare",
    "țesălării": "țesălare",
    "țesălările": "țesălare",
    "țesălărilor": "țesălare",
    "țesălata": "țesălat",
    "țesălată": "țesălat",
    "țesălate": "țesălat",
    "țesălatei": "țesălat",
    "țesălatele": "țesălat",
    "țesălatelor": "țesălat",
    "țesălați": "țesălat",
    "țesălații": "țesălat",
    "țesălaților": "țesălat",
    "țesălato": "țesălat",
    "țesălatul": "țesălat",
    "țesălatule": "țesălat",
    "țesălatului": "țesălat",
    "țesătoarea": "țesătoare",
    "țesătoarei": "țesătoare",
    "țesătoarele": "țesătoare",
    "țesătoarelor": "țesătoare",
    "țesătoareo": "țesătoare",
    "țesători": "țesător",
    "țesătorii": "țesător",
    "țesătorilor": "țesător",
    "țesătorul": "țesător",
    "țesătorule": "țesător",
    "țesătorului": "țesător",
    "țesătoria": "țesătorie",
    "țesătoriei": "țesătorie",
    "țesătorii": "țesătorie",
    "țesătoriile": "țesătorie",
    "țesătoriilor": "țesătorie",
    "țesătura": "țesătură",
    "țesături": "țesătură",
    "țesăturii": "țesătură",
    "țesăturile": "țesătură",
    "țesăturilor": "țesătură",
    "țesăturo": "țesătură",
    "tescovina": "tescovină",
    "tescovine": "tescovină",
    "tescovinei": "tescovină",
    "tescovinele": "tescovină",
    "tescovinelor": "tescovină",
    "nemaițesând": "țese",
    "nemaițesându": "țese",
    "nețesând": "țese",
    "nețesându": "țese",
    "țeasă": "țese",
    "țes": "țese",
    "țesând": "țese",
    "țesându": "țese",
    "țesea": "țese",
    "țeseai": "țese",
    "țeseam": "țese",
    "țeseați": "țese",
    "țeseau": "țese",
    "țesem": "țese",
    "țeseți": "țese",
    "țeși": "țese",
    "țesu": "țese",
    "țesui": "țese",
    "țesură": "țese",
    "țesurăm": "țese",
    "țesurăți": "țese",
    "țesuse": "țese",
    "țesusem": "țese",
    "țesuseră": "țese",
    "țesuserăm": "țese",
    "țesuserăți": "țese",
    "țesuseși": "țese",
    "țesuși": "țese",
    "țesut": "țese",
    "nemaiteșind": "teși",
    "nemaiteșindu": "teși",
    "neteșind": "teși",
    "neteșindu": "teși",
    "teșea": "teși",
    "teșeai": "teși",
    "teșeam": "teși",
    "teșească": "teși",
    "teșeați": "teși",
    "teșeau": "teși",
    "teșesc": "teși",
    "teșește": "teși",
    "teșești": "teși",
    "teșii": "teși",
    "teșim": "teși",
    "teșind": "teși",
    "teșindu": "teși",
    "teșiră": "teși",
    "teșirăm": "teși",
    "teșirăți": "teși",
    "teșise": "teși",
    "teșisem": "teși",
    "teșiseră": "teși",
    "teșiserăm": "teși",
    "teșiserăți": "teși",
    "teșiseși": "teși",
    "teșiși": "teși",
    "teșit": "teși",
    "teșiți": "teși",
    "teșitu": "teși",
    "teșirea": "teșire",
    "teșiri": "teșire",
    "teșirii": "teșire",
    "teșirile": "teșire",
    "teșita": "teșit",
    "teșită": "teșit",
    "teșite": "teșit",
    "teșitei": "teșit",
    "teșitele": "teșit",
    "teșitelor": "teșit",
    "teșiți": "teșit",
    "teșiții": "teșit",
    "teșiților": "teșit",
    "teșitul": "teșit",
    "teșitului": "teșit",
    "teste": "test",
    "testele": "test",
    "testelor": "test",
    "testul": "test",
    "testului": "test",
    "țestul": "țest",
    "țestului": "țest",
    "țesturi": "țest",
    "țesturile": "țest",
    "țesturilor": "țest",
    "nemaitestând": "testa",
    "nemaitestându": "testa",
    "netestând": "testa",
    "netestându": "testa",
    "testă": "testa",
    "testai": "testa",
    "testam": "testa",
    "testăm": "testa",
    "testând": "testa",
    "testându": "testa",
    "testară": "testa",
    "testarăm": "testa",
    "testarăți": "testa",
    "testase": "testa",
    "testasem": "testa",
    "testaseră": "testa",
    "testaserăm": "testa",
    "testaserăți": "testa",
    "testaseși": "testa",
    "testași": "testa",
    "testat": "testa",
    "testați": "testa",
    "testatu": "testa",
    "testau": "testa",
    "testează": "testa",
    "testez": "testa",
    "testeze": "testa",
    "testezi": "testa",
    "testamente": "testament",
    "testamentele": "testament",
    "testamentelor": "testament",
    "testamentul": "testament",
    "testamentului": "testament",
    "testamentara": "testamentar",
    "testamentară": "testamentar",
    "testamentare": "testamentar",
    "testamentarei": "testamentar",
    "testamentarele": "testamentar",
    "testamentarelor": "testamentar",
    "testamentari": "testamentar",
    "testamentarii": "testamentar",
    "testamentarilor": "testamentar",
    "testamentarul": "testamentar",
    "testamentarului": "testamentar",
    "testarea": "testare",
    "testări": "testare",
    "testării": "testare",
    "testările": "testare",
    "testata": "testat",
    "testată": "testat",
    "testate": "testat",
    "testatei": "testat",
    "testatele": "testat",
    "testatelor": "testat",
    "testați": "testat",
    "testații": "testat",
    "testaților": "testat",
    "testatul": "testat",
    "testatului": "testat",
    "testicule": "testicul",
    "testiculele": "testicul",
    "testiculelor": "testicul",
    "testiculul": "testicul",
    "testiculului": "testicul",
    "testimoniala": "testimonial",
    "testimonială": "testimonial",
    "testimoniale": "testimonial",
    "testimonialei": "testimonial",
    "testimonialele": "testimonial",
    "testimonialelor": "testimonial",
    "testimoniali": "testimonial",
    "testimonialii": "testimonial",
    "testimonialilor": "testimonial",
    "testimonialul": "testimonial",
    "testimonialului": "testimonial",
    "țestoasa": "țestos",
    "țestoasă": "țestos",
    "țestoase": "țestos",
    "țestoasei": "țestos",
    "țestoasele": "țestos",
    "țestoaselor": "țestos",
    "țestoși": "țestos",
    "țestoșii": "țestos",
    "țestoșilor": "țestos",
    "țestosul": "țestos",
    "țestosului": "țestos",
    "țesută": "țesut",
    "țesute": "țesut",
    "țesuți": "țesut",
    "țesutul": "țesut",
    "țesutului": "țesut",
    "țesuturi": "țesut",
    "țesuturile": "țesut",
    "țesuturilor": "țesut",
    "tetanica": "tetanic",
    "tetanică": "tetanic",
    "tetanice": "tetanic",
    "tetanicei": "tetanic",
    "tetanicele": "tetanic",
    "tetanicelor": "tetanic",
    "tetanici": "tetanic",
    "tetanicii": "tetanic",
    "tetanicilor": "tetanic",
    "tetanicul": "tetanic",
    "tetanicului": "tetanic",
    "tetania": "tetanie",
    "tetaniei": "tetanie",
    "tetanii": "tetanie",
    "tetaniile": "tetanie",
    "tetaniilor": "tetanie",
    "tetanosul": "tetanos",
    "tetanosului": "tetanos",
    "tetanosuri": "tetanos",
    "tetanosurile": "tetanos",
    "tetanosurilor": "tetanos",
    "tetraedre": "tetraedru",
    "tetraedrele": "tetraedru",
    "tetraedrelor": "tetraedru",
    "tetraedrul": "tetraedru",
    "tetraedrului": "tetraedru",
    "tetralogia": "tetralogie",
    "tetralogiei": "tetralogie",
    "tetralogii": "tetralogie",
    "tetralogiile": "tetralogie",
    "tetralogiilor": "tetralogie",
    "teutona": "teuton",
    "teutonă": "teuton",
    "teutone": "teuton",
    "teutonei": "teuton",
    "teutonele": "teuton",
    "teutonelor": "teuton",
    "teutoni": "teuton",
    "teutonii": "teuton",
    "teutonilor": "teuton",
    "teutonul": "teuton",
    "teutonului": "teuton",
    "teutonica": "teutonic",
    "teutonică": "teutonic",
    "teutonice": "teutonic",
    "teutonicei": "teutonic",
    "teutonicele": "teutonic",
    "teutonicelor": "teutonic",
    "teutonici": "teutonic",
    "teutonicii": "teutonic",
    "teutonicilor": "teutonic",
    "teutonicul": "teutonic",
    "teutonicului": "teutonic",
    "țevăria": "țevărie",
    "țevăriei": "țevărie",
    "țevării": "țevărie",
    "țevăriile": "țevărie",
    "țevăriilor": "țevărie",
    "tevatura": "tevatură",
    "tevaturi": "tevatură",
    "tevaturii": "tevatură",
    "tevaturile": "tevatură",
    "tevaturilor": "tevatură",
    "țevișoara": "țevișoară",
    "țevișoare": "țevișoară",
    "țevișoarei": "țevișoară",
    "țevișoarele": "țevișoară",
    "țevișoarelor": "țevișoară",
    "Texasul": "Texas",
    "Texasului": "Texas",
    "texte": "text",
    "textele": "text",
    "textelor": "text",
    "textul": "text",
    "textului": "text",
    "textieri": "textier",
    "textierii": "textier",
    "textierilor": "textier",
    "textierul": "textier",
    "textierului": "textier",
    "textiera": "textieră",
    "textiere": "textieră",
    "textierei": "textieră",
    "textierele": "textieră",
    "textierelor": "textieră",
    "textila": "textil",
    "textilă": "textil",
    "textile": "textil",
    "textilei": "textil",
    "textilele": "textil",
    "textilelor": "textil",
    "textili": "textil",
    "textilii": "textil",
    "textililor": "textil",
    "textilul": "textil",
    "textilului": "textil",
    "textilista": "textilist",
    "textilistă": "textilist",
    "textiliste": "textilist",
    "textilistei": "textilist",
    "textilistele": "textilist",
    "textilistelor": "textilist",
    "textiliști": "textilist",
    "textiliștii": "textilist",
    "textiliștilor": "textilist",
    "textilistul": "textilist",
    "textilistului": "textilist",
    "textilista": "textilistă",
    "textiliste": "textilistă",
    "textilistei": "textilistă",
    "textilistele": "textilistă",
    "textilistelor": "textilistă",
    "textuala": "textual",
    "textuală": "textual",
    "textuale": "textual",
    "textualei": "textual",
    "textualele": "textual",
    "textualelor": "textual",
    "textuali": "textual",
    "textualii": "textual",
    "textualilor": "textual",
    "textualul": "textual",
    "textualului": "textual",
    "textura": "textură",
    "texturi": "textură",
    "texturii": "textură",
    "texturile": "textură",
    "texturilor": "textură",
    "teza": "teză",
    "teze": "teză",
    "tezei": "teză",
    "tezele": "teză",
    "tezelor": "teză",
    "tezaure": "tezaur",
    "tezaurele": "tezaur",
    "tezaurelor": "tezaur",
    "tezaurul": "tezaur",
    "tezaurului": "tezaur",
    "nemaitezaurizând": "tezauriza",
    "nemaitezaurizându": "tezauriza",
    "netezaurizând": "tezauriza",
    "netezaurizându": "tezauriza",
    "tezauriză": "tezauriza",
    "tezaurizai": "tezauriza",
    "tezaurizam": "tezauriza",
    "tezaurizăm": "tezauriza",
    "tezaurizând": "tezauriza",
    "tezaurizându": "tezauriza",
    "tezaurizară": "tezauriza",
    "tezaurizarăm": "tezauriza",
    "tezaurizarăți": "tezauriza",
    "tezaurizase": "tezauriza",
    "tezaurizasem": "tezauriza",
    "tezaurizaseră": "tezauriza",
    "tezaurizaserăm": "tezauriza",
    "tezaurizaserăți": "tezauriza",
    "tezaurizaseși": "tezauriza",
    "tezaurizași": "tezauriza",
    "tezaurizat": "tezauriza",
    "tezaurizați": "tezauriza",
    "tezaurizatu": "tezauriza",
    "tezaurizau": "tezauriza",
    "tezaurizează": "tezauriza",
    "tezaurizez": "tezauriza",
    "tezaurizeze": "tezauriza",
    "tezaurizezi": "tezauriza",
    "tezaurizarea": "tezaurizare",
    "tezaurizări": "tezaurizare",
    "tezaurizării": "tezaurizare",
    "tezaurizările": "tezaurizare",
    "tezaurizata": "tezaurizat",
    "tezaurizată": "tezaurizat",
    "tezaurizate": "tezaurizat",
    "tezaurizatei": "tezaurizat",
    "tezaurizatele": "tezaurizat",
    "tezaurizatelor": "tezaurizat",
    "tezaurizați": "tezaurizat",
    "tezaurizații": "tezaurizat",
    "tezaurizaților": "tezaurizat",
    "tezaurizatul": "tezaurizat",
    "tezaurizatului": "tezaurizat",
    "tezisme": "tezism",
    "tezismele": "tezism",
    "tezismelor": "tezism",
    "tezismul": "tezism",
    "tezismului": "tezism",
    "Th": "thoriu",
    "thoriul": "thoriu",
    "thoriului": "thoriu",
    "tiara": "tiară",
    "tiare": "tiară",
    "tiarei": "tiară",
    "tiarele": "tiară",
    "tiarelor": "tiară",
    "Tibetul": "Tibet",
    "Tibetului": "Tibet",
    "ticul": "tic",
    "ticului": "tic",
    "ticuri": "tic",
    "ticurile": "tic",
    "ticurilor": "tic",
    "nemaiticăind": "ticăi",
    "nemaiticăindu": "ticăi",
    "neticăind": "ticăi",
    "neticăindu": "ticăi",
    "ticăia": "ticăi",
    "ticăiai": "ticăi",
    "ticăiam": "ticăi",
    "ticăiască": "ticăi",
    "ticăiați": "ticăi",
    "ticăiau": "ticăi",
    "ticăiesc": "ticăi",
    "ticăiește": "ticăi",
    "ticăiești": "ticăi",
    "ticăii": "ticăi",
    "ticăim": "ticăi",
    "ticăind": "ticăi",
    "ticăindu": "ticăi",
    "ticăiră": "ticăi",
    "ticăirăm": "ticăi",
    "ticăirăți": "ticăi",
    "ticăise": "ticăi",
    "ticăisem": "ticăi",
    "ticăiseră": "ticăi",
    "ticăiserăm": "ticăi",
    "ticăiserăți": "ticăi",
    "ticăiseși": "ticăi",
    "ticăiși": "ticăi",
    "ticăit": "ticăi",
    "ticăiți": "ticăi",
    "ticăitu": "ticăi",
    "ticăirea": "ticăire",
    "ticăireo": "ticăire",
    "ticăiri": "ticăire",
    "ticăirii": "ticăire",
    "ticăirile": "ticăire",
    "ticăirilor": "ticăire",
    "ticăita": "ticăit",
    "ticăită": "ticăit",
    "ticăite": "ticăit",
    "ticăitei": "ticăit",
    "ticăitele": "ticăit",
    "ticăitelor": "ticăit",
    "ticăiți": "ticăit",
    "ticăiții": "ticăit",
    "ticăiților": "ticăit",
    "ticăitul": "ticăit",
    "ticăitului": "ticăit",
    "ticăituri": "ticăit",
    "ticăiturile": "ticăit",
    "ticăiturilor": "ticăit",
    "ticăloasa": "ticăloasă",
    "ticăloase": "ticăloasă",
    "ticăloasei": "ticăloasă",
    "ticăloasele": "ticăloasă",
    "ticăloaselor": "ticăloasă",
    "ticăloaso": "ticăloasă",
    "ticăloasa": "ticălos",
    "ticăloasă": "ticălos",
    "ticăloase": "ticălos",
    "ticăloasei": "ticălos",
    "ticăloasele": "ticălos",
    "ticăloaselor": "ticălos",
    "ticăloaso": "ticălos",
    "ticăloși": "ticălos",
    "ticăloșii": "ticălos",
    "ticăloșilor": "ticălos",
    "ticălosul": "ticălos",
    "ticălosule": "ticălos",
    "ticălosului": "ticălos",
    "nemaiticăloșind": "ticăloși",
    "nemaiticăloșindu": "ticăloși",
    "neticăloșind": "ticăloși",
    "neticăloșindu": "ticăloși",
    "ticăloșea": "ticăloși",
    "ticăloșeai": "ticăloși",
    "ticăloșeam": "ticăloși",
    "ticăloșească": "ticăloși",
    "ticăloșeați": "ticăloși",
    "ticăloșeau": "ticăloși",
    "ticăloșesc": "ticăloși",
    "ticăloșește": "ticăloși",
    "ticăloșești": "ticăloși",
    "ticăloșii": "ticăloși",
    "ticăloșim": "ticăloși",
    "ticăloșind": "ticăloși",
    "ticăloșindu": "ticăloși",
    "ticăloșiră": "ticăloși",
    "ticăloșirăm": "ticăloși",
    "ticăloșirăți": "ticăloși",
    "ticăloșise": "ticăloși",
    "ticăloșisem": "ticăloși",
    "ticăloșiseră": "ticăloși",
    "ticăloșiserăm": "ticăloși",
    "ticăloșiserăți": "ticăloși",
    "ticăloșiseși": "ticăloși",
    "ticăloșiși": "ticăloși",
    "ticăloșit": "ticăloși",
    "ticăloșiți": "ticăloși",
    "ticăloșitu": "ticăloși",
    "ticăloșia": "ticăloșie",
    "ticăloșiei": "ticăloșie",
    "ticăloșii": "ticăloșie",
    "ticăloșiile": "ticăloșie",
    "ticăloșiilor": "ticăloșie",
    "ticăloșita": "ticăloșit",
    "ticăloșită": "ticăloșit",
    "ticăloșite": "ticăloșit",
    "ticăloșitei": "ticăloșit",
    "ticăloșitele": "ticăloșit",
    "ticăloșitelor": "ticăloșit",
    "ticăloșiți": "ticăloșit",
    "ticăloșiții": "ticăloșit",
    "ticăloșiților": "ticăloșit",
    "ticăloșitul": "ticăloșit",
    "ticăloșitului": "ticăloșit",
    "tichete": "tichet",
    "tichetele": "tichet",
    "tichetelor": "tichet",
    "tichetul": "tichet",
    "tichetului": "tichet",
    "nemaiticluind": "ticlui",
    "nemaiticluindu": "ticlui",
    "neticluind": "ticlui",
    "neticluindu": "ticlui",
    "ticluia": "ticlui",
    "ticluiai": "ticlui",
    "ticluiam": "ticlui",
    "ticluiască": "ticlui",
    "ticluiați": "ticlui",
    "ticluiau": "ticlui",
    "ticluiesc": "ticlui",
    "ticluiește": "ticlui",
    "ticluiești": "ticlui",
    "ticluii": "ticlui",
    "ticluim": "ticlui",
    "ticluind": "ticlui",
    "ticluindu": "ticlui",
    "ticluiră": "ticlui",
    "ticluirăm": "ticlui",
    "ticluirăți": "ticlui",
    "ticluise": "ticlui",
    "ticluisem": "ticlui",
    "ticluiseră": "ticlui",
    "ticluiserăm": "ticlui",
    "ticluiserăți": "ticlui",
    "ticluiseși": "ticlui",
    "ticluiși": "ticlui",
    "ticluit": "ticlui",
    "ticluiți": "ticlui",
    "ticluitu": "ticlui",
    "ticluirea": "ticluire",
    "ticluireo": "ticluire",
    "ticluiri": "ticluire",
    "ticluirii": "ticluire",
    "ticluirile": "ticluire",
    "ticluirilor": "ticluire",
    "ticluita": "ticluit",
    "ticluită": "ticluit",
    "ticluite": "ticluit",
    "ticluitei": "ticluit",
    "ticluitele": "ticluit",
    "ticluitelor": "ticluit",
    "ticluiți": "ticluit",
    "ticluiții": "ticluit",
    "ticluiților": "ticluit",
    "ticluito": "ticluit",
    "ticluitul": "ticluit",
    "ticluitule": "ticluit",
    "ticluitului": "ticluit",
    "nemaiticsind": "ticsi",
    "nemaiticsindu": "ticsi",
    "neticsind": "ticsi",
    "neticsindu": "ticsi",
    "ticsea": "ticsi",
    "ticseai": "ticsi",
    "ticseam": "ticsi",
    "ticsească": "ticsi",
    "ticseați": "ticsi",
    "ticseau": "ticsi",
    "ticsesc": "ticsi",
    "ticsește": "ticsi",
    "ticsești": "ticsi",
    "ticsii": "ticsi",
    "ticsim": "ticsi",
    "ticsind": "ticsi",
    "ticsindu": "ticsi",
    "ticsiră": "ticsi",
    "ticsirăm": "ticsi",
    "ticsirăți": "ticsi",
    "ticsise": "ticsi",
    "ticsisem": "ticsi",
    "ticsiseră": "ticsi",
    "ticsiserăm": "ticsi",
    "ticsiserăți": "ticsi",
    "ticsiseși": "ticsi",
    "ticsiși": "ticsi",
    "ticsit": "ticsi",
    "ticsiți": "ticsi",
    "ticsitu": "ticsi",
    "ticsirea": "ticsire",
    "ticsireo": "ticsire",
    "ticsiri": "ticsire",
    "ticsirii": "ticsire",
    "ticsirile": "ticsire",
    "ticsirilor": "ticsire",
    "ticsita": "ticsit",
    "ticsită": "ticsit",
    "ticsite": "ticsit",
    "ticsitei": "ticsit",
    "ticsitele": "ticsit",
    "ticsitelor": "ticsit",
    "ticsiți": "ticsit",
    "ticsiții": "ticsit",
    "ticsiților": "ticsit",
    "ticsito": "ticsit",
    "ticsitul": "ticsit",
    "ticsitule": "ticsit",
    "ticsitului": "ticsit",
    "tic-tacul": "tic-tac",
    "tic-tacului": "tic-tac",
    "tic-tacuri": "tic-tac",
    "tic-tacurile": "tic-tac",
    "tic-tacurilor": "tic-tac",
    "țidula": "țidulă",
    "țidule": "țidulă",
    "țidulei": "țidulă",
    "țidulele": "țidulă",
    "țidulelor": "țidulă",
    "tifica": "tific",
    "tifică": "tific",
    "tifice": "tific",
    "tificei": "tific",
    "tificele": "tific",
    "tificelor": "tific",
    "tifici": "tific",
    "tificii": "tific",
    "tificilor": "tific",
    "tificul": "tific",
    "tificului": "tific",
    "tifica": "tifică",
    "tifice": "tifică",
    "tificei": "tifică",
    "tificele": "tifică",
    "tificelor": "tifică",
    "tifosul": "tifos",
    "tifosului": "tifos",
    "tifosuri": "tifos",
    "tifosurile": "tifos",
    "tifosurilor": "tifos",
    "tigăi": "tigaie",
    "tigaia": "tigaie",
    "tigăii": "tigaie",
    "tigăile": "tigaie",
    "tigăilor": "tigaie",
    "tigaio": "tigaie",
    "țigani": "țigan",
    "țiganii": "țigan",
    "țiganilor": "țigan",
    "țiganul": "țigan",
    "țiganului": "țigan",
    "țiganca": "țigancă",
    "țigănci": "țigancă",
    "țigăncii": "țigancă",
    "țigăncile": "țigancă",
    "țigăncilor": "țigancă",
    "țigăneasca": "țigănesc",
    "țigănească": "țigănesc",
    "țigănescul": "țigănesc",
    "țigănescului": "țigănesc",
    "țigănești": "țigănesc",
    "țigăneștii": "țigănesc",
    "țigăneștile": "țigănesc",
    "țigăneștilor": "țigănesc",
    "țigănia": "țigănie",
    "țigăniei": "țigănie",
    "țigănii": "țigănie",
    "țigăniile": "țigănie",
    "țigăniilor": "țigănie",
    "țigănimea": "țigănime",
    "țigănimi": "țigănime",
    "țigănimii": "țigănime",
    "țigănimile": "țigănime",
    "țigănimilor": "țigănime",
    "țigănisme": "țigănism",
    "țigănismele": "țigănism",
    "țigănismelor": "țigănism",
    "țigănismul": "țigănism",
    "țigănismului": "țigănism",
    "țigăniști": "țigănist",
    "țigăniștii": "țigănist",
    "țigăniștilor": "țigănist",
    "țigănoasa": "țigănos",
    "țigănoasă": "țigănos",
    "țigănoase": "țigănos",
    "țigănoasei": "țigănos",
    "țigănoasele": "țigănos",
    "țigănoaselor": "țigănos",
    "țigănoși": "țigănos",
    "țigănoșii": "țigănos",
    "țigănoșilor": "țigănos",
    "țigănosul": "țigănos",
    "țigănosului": "țigănos",
    "țigănuși": "țigănuș",
    "țigănușii": "țigănuș",
    "țigănușilor": "țigănuș",
    "țigănușul": "țigănuș",
    "țigănușului": "țigănuș",
    "țigara": "țigară",
    "țigări": "țigară",
    "țigării": "țigară",
    "țigările": "țigară",
    "țigărilor": "țigară",
    "țigarete": "țigaret",
    "țigaretele": "țigaret",
    "țigaretelor": "țigaret",
    "țigaretul": "țigaret",
    "țigaretului": "țigaret",
    "țigareta": "țigaretă",
    "țigarete": "țigaretă",
    "țigaretei": "țigaretă",
    "țigaretele": "țigaretă",
    "țigaretelor": "țigaretă",
    "țigla": "țiglă",
    "țigle": "țiglă",
    "țiglei": "țiglă",
    "țiglele": "țiglă",
    "țiglelor": "țiglă",
    "țiglari": "țiglar",
    "țiglarii": "țiglar",
    "țiglarilor": "țiglar",
    "țiglarul": "țiglar",
    "țiglarului": "țiglar",
    "țiglăria": "țiglărie",
    "țiglăriei": "țiglărie",
    "țiglării": "țiglărie",
    "țiglăriile": "țiglărie",
    "țiglăriilor": "țiglărie",
    "țignale": "țignal",
    "țignalele": "țignal",
    "țignalelor": "țignal",
    "țignalul": "țignal",
    "țignalului": "țignal",
    "tigrișori": "tigrișor",
    "tigrișorii": "tigrișor",
    "tigrișorilor": "tigrișor",
    "tigrișorul": "tigrișor",
    "tigrișorule": "tigrișor",
    "tigrișorului": "tigrișor",
    "tigri": "tigru",
    "tigrii": "tigru",
    "tigrilor": "tigru",
    "tigrul": "tigru",
    "tigrule": "tigru",
    "tigrului": "tigru",
    "tigva": "tigvă",
    "tigve": "tigvă",
    "tigvei": "tigvă",
    "tigvele": "tigvă",
    "tigvelor": "tigvă",
    "tihărăi": "tihăraie",
    "tihăraia": "tihăraie",
    "tihărăii": "tihăraie",
    "tihărăile": "tihăraie",
    "tihărăilor": "tihăraie",
    "tihna": "tihnă",
    "tihne": "tihnă",
    "tihnei": "tihnă",
    "tihnele": "tihnă",
    "tihnelor": "tihnă",
    "nemaitihnind": "tihni",
    "nemaitihnindu": "tihni",
    "netihnind": "tihni",
    "netihnindu": "tihni",
    "tihnea": "tihni",
    "tihneai": "tihni",
    "tihneam": "tihni",
    "tihnească": "tihni",
    "tihneați": "tihni",
    "tihneau": "tihni",
    "tihnesc": "tihni",
    "tihnește": "tihni",
    "tihnești": "tihni",
    "tihnii": "tihni",
    "tihnim": "tihni",
    "tihnind": "tihni",
    "tihnindu": "tihni",
    "tihniră": "tihni",
    "tihnirăm": "tihni",
    "tihnirăți": "tihni",
    "tihnise": "tihni",
    "tihnisem": "tihni",
    "tihniseră": "tihni",
    "tihniserăm": "tihni",
    "tihniserăți": "tihni",
    "tihniseși": "tihni",
    "tihniși": "tihni",
    "tihnit": "tihni",
    "tihniți": "tihni",
    "tihnitu": "tihni",
    "tihnirea": "tihnire",
    "tihniri": "tihnire",
    "tihnirii": "tihnire",
    "tihnirile": "tihnire",
    "tihnita": "tihnit",
    "tihnită": "tihnit",
    "tihnite": "tihnit",
    "tihnitei": "tihnit",
    "tihnitele": "tihnit",
    "tihnitelor": "tihnit",
    "tihniți": "tihnit",
    "tihniții": "tihnit",
    "tihniților": "tihnit",
    "tihnitul": "tihnit",
    "tihnitului": "tihnit",
    "tija": "tijă",
    "tije": "tijă",
    "tijei": "tijă",
    "tijele": "tijă",
    "tijelor": "tijă",
    "tilda": "tildă",
    "tilde": "tildă",
    "tildei": "tildă",
    "tildele": "tildă",
    "tildelor": "tildă",
    "tilinca": "tilincă",
    "tilinci": "tilincă",
    "tilincii": "tilincă",
    "tilincile": "tilincă",
    "tilincilor": "tilincă",
    "timarhia": "timarhie",
    "timbre": "timbru",
    "timbrele": "timbru",
    "timbrelor": "timbru",
    "timbrul": "timbru",
    "timbrule": "timbru",
    "timbrului": "timbru",
    "timida": "timid",
    "timidă": "timid",
    "timide": "timid",
    "timidei": "timid",
    "timidele": "timid",
    "timidelor": "timid",
    "timido": "timid",
    "timidul": "timid",
    "timidule": "timid",
    "timidului": "timid",
    "timizi": "timid",
    "timizii": "timid",
    "timizilor": "timid",
    "timiditatea": "timiditate",
    "timidități": "timiditate",
    "timidității": "timiditate",
    "timiditățile": "timiditate",
    "timidităților": "timiditate",
    "TM": "Timiș",
    "Timișoară": "Timișoara",
    "Timișoare": "Timișoara",
    "Timișoarei": "Timișoara",
    "timocrația": "timocrație",
    "timona": "timonă",
    "timone": "timonă",
    "timonei": "timonă",
    "timonele": "timonă",
    "timonelor": "timonă",
    "timonieri": "timonier",
    "timonierii": "timonier",
    "timonierilor": "timonier",
    "timonierul": "timonier",
    "timonierului": "timonier",
    "timoră": "timora",
    "timorai": "timora",
    "timoram": "timora",
    "timorăm": "timora",
    "timorând": "timora",
    "timorându": "timora",
    "timorară": "timora",
    "timorarăm": "timora",
    "timorarăți": "timora",
    "timorase": "timora",
    "timorasem": "timora",
    "timoraseră": "timora",
    "timoraserăm": "timora",
    "timoraserăți": "timora",
    "timoraseși": "timora",
    "timorași": "timora",
    "timorat": "timora",
    "timorați": "timora",
    "timoratu": "timora",
    "timorau": "timora",
    "timorează": "timora",
    "timorez": "timora",
    "timoreze": "timora",
    "timorezi": "timora",
    "timorarea": "timorare",
    "timorări": "timorare",
    "timorării": "timorare",
    "timorările": "timorare",
    "timorărilor": "timorare",
    "timorata": "timorat",
    "timorată": "timorat",
    "timorate": "timorat",
    "timoratei": "timorat",
    "timoratele": "timorat",
    "timoratelor": "timorat",
    "timorați": "timorat",
    "timorații": "timorat",
    "timoraților": "timorat",
    "timoratul": "timorat",
    "timoratului": "timorat",
    "tim'": "timp",
    "timpi": "timp",
    "timpii": "timp",
    "timpilor": "timp",
    "timpu'": "timp",
    "timpul": "timp",
    "timpule": "timp",
    "timpului": "timp",
    "timpuri": "timp",
    "timpurile": "timp",
    "timpurilor": "timp",
    "timpane": "timpan",
    "timpanele": "timpan",
    "timpanelor": "timpan",
    "timpanul": "timpan",
    "timpanului": "timpan",
    "timpuria": "timpuriu",
    "timpurie": "timpuriu",
    "timpuriei": "timpuriu",
    "timpurii": "timpuriu",
    "timpuriii": "timpuriu",
    "timpuriile": "timpuriu",
    "timpuriilor": "timpuriu",
    "timpuriul": "timpuriu",
    "timpuriului": "timpuriu",
    "tina": "tină",
    "tine": "tină",
    "tinei": "tină",
    "tinele": "tină",
    "tinelor": "tină",
    "tinda": "tindă",
    "tinde": "tindă",
    "tindei": "tindă",
    "tindele": "tindă",
    "tindelor": "tindă",
    "nemaitinzând": "tinde",
    "nemaitinzându": "tinde",
    "netinzând": "tinde",
    "netinzându": "tinde",
    "tind": "tinde",
    "tindă": "tinde",
    "tindea": "tinde",
    "tindeai": "tinde",
    "tindeam": "tinde",
    "tindeați": "tinde",
    "tindeau": "tinde",
    "tindem": "tinde",
    "tindeți": "tinde",
    "tins": "tinde",
    "tinse": "tinde",
    "tinsei": "tinde",
    "tinseră": "tinde",
    "tinserăm": "tinde",
    "tinserăți": "tinde",
    "tinsese": "tinde",
    "tinsesem": "tinde",
    "tinseseră": "tinde",
    "tinseserăm": "tinde",
    "tinseserăți": "tinde",
    "tinseseși": "tinde",
    "tinseși": "tinde",
    "tinsu": "tinde",
    "tinzând": "tinde",
    "tinzându": "tinde",
    "tinzi": "tinde",
    "tinderea": "tindere",
    "tinderi": "tindere",
    "tinderii": "tindere",
    "tinderile": "tindere",
    "nemaiținând": "ține",
    "nemaiținându": "ține",
    "neținând": "ține",
    "neținându": "ține",
    "ții": "ține",
    "țin": "ține",
    "țină": "ține",
    "ținând": "ține",
    "ținându": "ține",
    "ținea": "ține",
    "țineai": "ține",
    "țineam": "ține",
    "țineați": "ține",
    "țineau": "ține",
    "ținem": "ține",
    "țineți": "ține",
    "ținu": "ține",
    "ținui": "ține",
    "ținură": "ține",
    "ținurăm": "ține",
    "ținurăți": "ține",
    "ținuse": "ține",
    "ținusem": "ține",
    "ținuseră": "ține",
    "ținuserăm": "ține",
    "ținuserăți": "ține",
    "ținuseși": "ține",
    "ținuși": "ține",
    "ținut": "ține",
    "ținerea": "ținere",
    "ținereo": "ținere",
    "țineri": "ținere",
    "ținerii": "ținere",
    "ținerile": "ținere",
    "ținerilor": "ținere",
    "tinereao": "tinerea",
    "tinereaua": "tinerea",
    "tinerele": "tinerea",
    "tinerelei": "tinerea",
    "tinerelele": "tinerea",
    "tinerelelor": "tinerea",
    "tinerei": "tinerel",
    "tinereii": "tinerel",
    "tinereilor": "tinerel",
    "tinerelul": "tinerel",
    "tinerelule": "tinerel",
    "tinerelului": "tinerel",
    "tinereasca": "tineresc",
    "tinerească": "tineresc",
    "tinereasco": "tineresc",
    "tinerescul": "tineresc",
    "tinerescule": "tineresc",
    "tinerescului": "tineresc",
    "tinerești": "tineresc",
    "tinereștii": "tineresc",
    "tinereștile": "tineresc",
    "tinereștilor": "tineresc",
    "tineretul": "tineret",
    "tineretule": "tineret",
    "tineretului": "tineret",
    "tinerețea": "tinerețe",
    "tinerețeo": "tinerețe",
    "tinereți": "tinerețe",
    "tinereții": "tinerețe",
    "tinerețile": "tinerețe",
    "tinereților": "tinerețe",
    "tinerica": "tinerică",
    "tinerico": "tinerică",
    "tinerimea": "tinerime",
    "tinerimeo": "tinerime",
    "tinerimi": "tinerime",
    "tinerimii": "tinerime",
    "tineta": "tinetă",
    "tinete": "tinetă",
    "tinetei": "tinetă",
    "tinetele": "tinetă",
    "tinetelor": "tinetă",
    "tinicheao": "tinichea",
    "tinicheaua": "tinichea",
    "tinichele": "tinichea",
    "tinichelei": "tinichea",
    "tinichelele": "tinichea",
    "tinichelelor": "tinichea",
    "tinsă": "tins",
    "tinse": "tins",
    "tinși": "tins",
    "tinsul": "tins",
    "tinsului": "tins",
    "ținta": "țintă",
    "ținte": "țintă",
    "țintei": "țintă",
    "țintele": "țintă",
    "țintelor": "țintă",
    "țintari": "țintar",
    "țintarii": "țintar",
    "țintarilor": "țintar",
    "țintarul": "țintar",
    "țintarului": "țintar",
    "țintași": "țintaș",
    "țintașii": "țintaș",
    "țintașilor": "țintaș",
    "țintașul": "țintaș",
    "țintașului": "țintaș",
    "țintate": "țintat",
    "țintatei": "țintat",
    "țintatele": "țintat",
    "țintatelor": "țintat",
    "țintați": "țintat",
    "țintații": "țintat",
    "țintaților": "țintat",
    "țintatul": "țintat",
    "țintatului": "țintat",
    "nemaițintind": "ținti",
    "nemaițintindu": "ținti",
    "nețintind": "ținti",
    "nețintindu": "ținti",
    "țintea": "ținti",
    "ținteai": "ținti",
    "ținteam": "ținti",
    "țintească": "ținti",
    "ținteați": "ținti",
    "ținteau": "ținti",
    "țintesc": "ținti",
    "țintește": "ținti",
    "țintești": "ținti",
    "țintii": "ținti",
    "țintim": "ținti",
    "țintind": "ținti",
    "țintindu": "ținti",
    "țintiră": "ținti",
    "țintirăm": "ținti",
    "țintirăți": "ținti",
    "țintise": "ținti",
    "țintisem": "ținti",
    "țintiseră": "ținti",
    "țintiserăm": "ținti",
    "țintiserăți": "ținti",
    "țintiseși": "ținti",
    "țintiși": "ținti",
    "țintit": "ținti",
    "țintiți": "ținti",
    "țintirea": "țintire",
    "țintireo": "țintire",
    "țintiri": "țintire",
    "țintirii": "țintire",
    "țintirile": "țintire",
    "țintirilor": "țintire",
    "țintirimul": "țintirim",
    "țintirimului": "țintirim",
    "țintirimuri": "țintirim",
    "țintirimurile": "țintirim",
    "țintirimurilor": "țintirim",
    "țintita": "țintit",
    "țintită": "țintit",
    "țintite": "țintit",
    "țintitei": "țintit",
    "țintitele": "țintit",
    "țintitelor": "țintit",
    "țintiți": "țintit",
    "țintiții": "țintit",
    "țintiților": "țintit",
    "țintito": "țintit",
    "țintitul": "țintit",
    "țintitule": "țintit",
    "țintitului": "țintit",
    "țintitoare": "țintitor",
    "țintitoarea": "țintitor",
    "țintitoarei": "țintitor",
    "țintitoarele": "țintitor",
    "țintitoarelor": "țintitor",
    "țintitoareo": "țintitor",
    "țintitori": "țintitor",
    "țintitorii": "țintitor",
    "țintitorilor": "țintitor",
    "țintitorul": "țintitor",
    "țintitorule": "țintitor",
    "țintitorului": "țintitor",
    "nemaițintuind": "țintui",
    "nemaițintuindu": "țintui",
    "nețintuind": "țintui",
    "nețintuindu": "țintui",
    "țintuia": "țintui",
    "țintuiai": "țintui",
    "țintuiam": "țintui",
    "țintuiască": "țintui",
    "țintuiați": "țintui",
    "țintuiau": "țintui",
    "țintuiesc": "țintui",
    "țintuiește": "țintui",
    "țintuiești": "țintui",
    "țintuii": "țintui",
    "țintuim": "țintui",
    "țintuind": "țintui",
    "țintuindu": "țintui",
    "țintuiră": "țintui",
    "țintuirăm": "țintui",
    "țintuirăți": "țintui",
    "țintuise": "țintui",
    "țintuisem": "țintui",
    "țintuiseră": "țintui",
    "țintuiserăm": "țintui",
    "țintuiserăți": "țintui",
    "țintuiseși": "țintui",
    "țintuiși": "țintui",
    "țintuit": "țintui",
    "țintuiți": "țintui",
    "țintuirea": "țintuire",
    "țintuireo": "țintuire",
    "țintuiri": "țintuire",
    "țintuirii": "țintuire",
    "țintuirile": "țintuire",
    "țintuirilor": "țintuire",
    "țintuita": "țintuit",
    "țintuită": "țintuit",
    "țintuite": "țintuit",
    "țintuitei": "țintuit",
    "țintuitele": "țintuit",
    "țintuitelor": "țintuit",
    "țintuiți": "țintuit",
    "țintuiții": "țintuit",
    "țintuiților": "țintuit",
    "țintuito": "țintuit",
    "țintuitul": "țintuit",
    "țintuitule": "țintuit",
    "țintuitului": "țintuit",
    "ținută": "ținut",
    "ținute": "ținut",
    "ținuți": "ținut",
    "ținutul": "ținut",
    "ținutului": "ținut",
    "ținuturi": "ținut",
    "ținuturile": "ținut",
    "ținuturilor": "ținut",
    "ținuta": "ținută",
    "ținute": "ținută",
    "ținutei": "ținută",
    "ținutele": "ținută",
    "ținutelor": "ținută",
    "tipi": "tip",
    "tipii": "tip",
    "tipilor": "tip",
    "tipu'": "tip",
    "tipu-": "tip",
    "tipul": "tip",
    "tipului": "tip",
    "tipuri": "tip",
    "tipurile": "tip",
    "tipurilor": "tip",
    "tipa": "tipă",
    "tipe": "tipă",
    "tipei": "tipă",
    "tipele": "tipă",
    "tipelor": "tipă",
    "nemaițipând": "țipa",
    "nemaițipându": "țipa",
    "nețipând": "țipa",
    "nețipându": "țipa",
    "țip": "țipa",
    "țipă": "țipa",
    "țipai": "țipa",
    "țipam": "țipa",
    "țipăm": "țipa",
    "țipând": "țipa",
    "țipându": "țipa",
    "țipară": "țipa",
    "țiparăm": "țipa",
    "țiparăți": "țipa",
    "țipase": "țipa",
    "țipasem": "țipa",
    "țipaseră": "țipa",
    "țipaserăm": "țipa",
    "țipaserăți": "țipa",
    "țipaseși": "țipa",
    "țipași": "țipa",
    "țipat": "țipa",
    "țipați": "țipa",
    "țipau": "țipa",
    "țipe": "țipa",
    "țipi": "țipa",
    "tipare": "tipar",
    "tiparele": "tipar",
    "tiparelor": "tipar",
    "tiparul": "tipar",
    "tiparului": "tipar",
    "țipari": "țipar",
    "țiparii": "țipar",
    "țiparilor": "țipar",
    "țiparul": "țipar",
    "țiparului": "țipar",
    "nemaitipărind": "tipări",
    "nemaitipărindu": "tipări",
    "netipărind": "tipări",
    "netipărindu": "tipări",
    "tipărea": "tipări",
    "tipăreai": "tipări",
    "tipăream": "tipări",
    "tipărească": "tipări",
    "tipăreați": "tipări",
    "tipăreau": "tipări",
    "tipăresc": "tipări",
    "tipărește": "tipări",
    "tipărești": "tipări",
    "tipării": "tipări",
    "tipărim": "tipări",
    "tipărind": "tipări",
    "tipărindu": "tipări",
    "tipăriră": "tipări",
    "tipărirăm": "tipări",
    "tipărirăți": "tipări",
    "tipărise": "tipări",
    "tipărisem": "tipări",
    "tipăriseră": "tipări",
    "tipăriserăm": "tipări",
    "tipăriserăți": "tipări",
    "tipăriseși": "tipări",
    "tipăriși": "tipări",
    "tipărit": "tipări",
    "tipăriți": "tipări",
    "tipăritu": "tipări",
    "tipărirea": "tipărire",
    "tipărireo": "tipărire",
    "tipăriri": "tipărire",
    "tipăririi": "tipărire",
    "tipăririle": "tipărire",
    "tipăririlor": "tipărire",
    "tipărita": "tipărit",
    "tipărită": "tipărit",
    "tipărite": "tipărit",
    "tipăritei": "tipărit",
    "tipăritele": "tipărit",
    "tipăritelor": "tipărit",
    "tipăriți": "tipărit",
    "tipăriții": "tipărit",
    "tipăriților": "tipărit",
    "tipăritul": "tipărit",
    "tipăritule": "tipărit",
    "tipăritului": "tipărit",
    "tipăritura": "tipăritură",
    "tipărituri": "tipăritură",
    "tipăriturii": "tipăritură",
    "tipăriturile": "tipăritură",
    "tipăriturilor": "tipăritură",
    "tipărituro": "tipăritură",
    "tiparnița": "tiparniță",
    "tiparnițe": "tiparniță",
    "tiparniței": "tiparniță",
    "tiparnițele": "tiparniță",
    "tiparnițelor": "tiparniță",
    "țipătul": "țipăt",
    "țipătului": "țipăt",
    "țipete": "țipăt",
    "țipetele": "țipăt",
    "țipetelor": "țipăt",
    "țipătoare": "țipător",
    "țipătoarea": "țipător",
    "țipătoarei": "țipător",
    "țipătoarele": "țipător",
    "țipătoarelor": "țipător",
    "țipătoareo": "țipător",
    "țipători": "țipător",
    "țipătorii": "țipător",
    "țipătorilor": "țipător",
    "țipătorul": "țipător",
    "țipătorule": "țipător",
    "țipătorului": "țipător",
    "țipenia": "țipenie",
    "țipeniei": "țipenie",
    "țipenii": "țipenie",
    "țipeniile": "țipenie",
    "țipeniilor": "țipenie",
    "tipesa": "tipesă",
    "tipese": "tipesă",
    "tipesei": "tipesă",
    "tipesele": "tipesă",
    "tipeselor": "tipesă",
    "tipica": "tipic",
    "tipică": "tipic",
    "tipice": "tipic",
    "tipicei": "tipic",
    "tipicele": "tipic",
    "tipicelor": "tipic",
    "tipici": "tipic",
    "tipicii": "tipic",
    "tipicilor": "tipic",
    "tipicul": "tipic",
    "tipicului": "tipic",
    "tipicuri": "tipic",
    "tipicurile": "tipic",
    "tipicurilor": "tipic",
    "tipicari": "tipicar",
    "tipicarii": "tipicar",
    "tipicarilor": "tipicar",
    "tipicarul": "tipicar",
    "tipicarului": "tipicar",
    "tipicara": "tipicară",
    "tipicare": "tipicară",
    "tipicarei": "tipicară",
    "tipicarele": "tipicară",
    "tipicarelor": "tipicară",
    "nemaitipizând": "tipiza",
    "nemaitipizându": "tipiza",
    "netipizând": "tipiza",
    "netipizându": "tipiza",
    "tipiză": "tipiza",
    "tipizai": "tipiza",
    "tipizam": "tipiza",
    "tipizăm": "tipiza",
    "tipizând": "tipiza",
    "tipizându": "tipiza",
    "tipizară": "tipiza",
    "tipizarăm": "tipiza",
    "tipizarăți": "tipiza",
    "tipizase": "tipiza",
    "tipizasem": "tipiza",
    "tipizaseră": "tipiza",
    "tipizaserăm": "tipiza",
    "tipizaserăți": "tipiza",
    "tipizaseși": "tipiza",
    "tipizași": "tipiza",
    "tipizat": "tipiza",
    "tipizați": "tipiza",
    "tipizatu": "tipiza",
    "tipizau": "tipiza",
    "tipizează": "tipiza",
    "tipizez": "tipiza",
    "tipizeze": "tipiza",
    "tipizezi": "tipiza",
    "tipizarea": "tipizare",
    "tipizări": "tipizare",
    "tipizării": "tipizare",
    "tipizările": "tipizare",
    "tipizata": "tipizat",
    "tipizată": "tipizat",
    "tipizate": "tipizat",
    "tipizatei": "tipizat",
    "tipizatele": "tipizat",
    "tipizatelor": "tipizat",
    "tipizați": "tipizat",
    "tipizații": "tipizat",
    "tipizaților": "tipizat",
    "tipizatul": "tipizat",
    "tipizatului": "tipizat",
    "țipla": "țiplă",
    "țiple": "țiplă",
    "țiplei": "țiplă",
    "țiplele": "țiplă",
    "țiplelor": "țiplă",
    "tipografi": "tipograf",
    "tipografii": "tipograf",
    "tipografilor": "tipograf",
    "tipograful": "tipograf",
    "tipografului": "tipograf",
    "tipografica": "tipografic",
    "tipografică": "tipografic",
    "tipografice": "tipografic",
    "tipograficei": "tipografic",
    "tipograficele": "tipografic",
    "tipograficelor": "tipografic",
    "tipografici": "tipografic",
    "tipograficii": "tipografic",
    "tipograficilor": "tipografic",
    "tipograficul": "tipografic",
    "tipograficului": "tipografic",
    "tipografia": "tipografie",
    "tipografiei": "tipografie",
    "tipografii": "tipografie",
    "tipografiile": "tipografie",
    "tipografiilor": "tipografie",
    "tipologica": "tipologic",
    "tipologică": "tipologic",
    "tipologice": "tipologic",
    "tipologicei": "tipologic",
    "tipologicele": "tipologic",
    "tipologicelor": "tipologic",
    "tipologici": "tipologic",
    "tipologicii": "tipologic",
    "tipologicilor": "tipologic",
    "tipologicul": "tipologic",
    "tipologicului": "tipologic",
    "tipologia": "tipologie",
    "tipologiei": "tipologie",
    "tipologii": "tipologie",
    "tipologiile": "tipologie",
    "tipologiilor": "tipologie",
    "tipsia": "tipsie",
    "tipsiei": "tipsie",
    "tipsii": "tipsie",
    "tipsiile": "tipsie",
    "tipsiilor": "tipsie",
    "tirul": "tir",
    "tirului": "tir",
    "tiruri": "tir",
    "tirurile": "tir",
    "tirurilor": "tir",
    "tirada": "tiradă",
    "tirade": "tiradă",
    "tiradei": "tiradă",
    "tiradele": "tiradă",
    "tiradelor": "tiradă",
    "tiraje": "tiraj",
    "tirajele": "tiraj",
    "tirajelor": "tiraj",
    "tirajul": "tiraj",
    "tirajului": "tiraj",
    "tiraliori": "tiralior",
    "tiraliorii": "tiralior",
    "tiraliorilor": "tiralior",
    "tiraliorul": "tiralior",
    "tiraliorului": "tiralior",
    "tirani": "tiran",
    "tiranii": "tiran",
    "tiranilor": "tiran",
    "tiranul": "tiran",
    "tiranului": "tiran",
    "tiranica": "tiranic",
    "tiranică": "tiranic",
    "tiranice": "tiranic",
    "tiranicei": "tiranic",
    "tiranicele": "tiranic",
    "tiranicelor": "tiranic",
    "tiranici": "tiranic",
    "tiranicii": "tiranic",
    "tiranicilor": "tiranic",
    "tiranicul": "tiranic",
    "tiranicului": "tiranic",
    "tirania": "tiranie",
    "tiraniei": "tiranie",
    "tiranii": "tiranie",
    "tiraniile": "tiranie",
    "tiraniilor": "tiranie",
    "tiranio": "tiranie",
    "nemaitiranizând": "tiraniza",
    "nemaitiranizându": "tiraniza",
    "netiranizând": "tiraniza",
    "netiranizându": "tiraniza",
    "tiraniză": "tiraniza",
    "tiranizai": "tiraniza",
    "tiranizam": "tiraniza",
    "tiranizăm": "tiraniza",
    "tiranizând": "tiraniza",
    "tiranizându": "tiraniza",
    "tiranizară": "tiraniza",
    "tiranizarăm": "tiraniza",
    "tiranizarăți": "tiraniza",
    "tiranizase": "tiraniza",
    "tiranizasem": "tiraniza",
    "tiranizaseră": "tiraniza",
    "tiranizaserăm": "tiraniza",
    "tiranizaserăți": "tiraniza",
    "tiranizaseși": "tiraniza",
    "tiranizași": "tiraniza",
    "tiranizat": "tiraniza",
    "tiranizați": "tiraniza",
    "tiranizatu": "tiraniza",
    "tiranizau": "tiraniza",
    "tiranizează": "tiraniza",
    "tiranizez": "tiraniza",
    "tiranizeze": "tiraniza",
    "tiranizezi": "tiraniza",
    "tiranizată": "tiranizat",
    "tiranizate": "tiranizat",
    "tiranizați": "tiranizat",
    "tirbușoane": "tirbușon",
    "tirbușoanele": "tirbușon",
    "tirbușoanelor": "tirbușon",
    "tirbușonul": "tirbușon",
    "tirbușonului": "tirbușon",
    "tiroida": "tiroidă",
    "tiroide": "tiroidă",
    "tiroidei": "tiroidă",
    "tiroidele": "tiroidă",
    "tiroidelor": "tiroidă",
    "tisulara": "tisular",
    "tisulară": "tisular",
    "tisulare": "tisular",
    "tisularei": "tisular",
    "tisularele": "tisular",
    "tisularelor": "tisular",
    "tisulari": "tisular",
    "tisularii": "tisular",
    "tisularilor": "tisular",
    "tisularul": "tisular",
    "tisularului": "tisular",
    "Ti": "titan",
    "titani": "titan",
    "titanii": "titan",
    "titanilor": "titan",
    "titanul": "titan",
    "titanului": "titan",
    "titanica": "titanic",
    "titanică": "titanic",
    "titanice": "titanic",
    "titanicei": "titanic",
    "titanicele": "titanic",
    "titanicelor": "titanic",
    "titanici": "titanic",
    "titanicii": "titanic",
    "titanicilor": "titanic",
    "titanicul": "titanic",
    "titanicului": "titanic",
    "țițeiul": "țiței",
    "țițeiului": "țiței",
    "țițeiuri": "țiței",
    "țițeiurile": "țiței",
    "țițeiurilor": "țiței",
    "titlul": "titlu",
    "titlului": "titlu",
    "titluri": "titlu",
    "titlurile": "titlu",
    "titlurilor": "titlu",
    "nemaititrând": "titra",
    "nemaititrându": "titra",
    "netitrând": "titra",
    "netitrându": "titra",
    "titră": "titra",
    "titrai": "titra",
    "titram": "titra",
    "titrăm": "titra",
    "titrând": "titra",
    "titrându": "titra",
    "titrară": "titra",
    "titrarăm": "titra",
    "titrarăți": "titra",
    "titrase": "titra",
    "titrasem": "titra",
    "titraseră": "titra",
    "titraserăm": "titra",
    "titraserăți": "titra",
    "titraseși": "titra",
    "titrași": "titra",
    "titrat": "titra",
    "titrați": "titra",
    "titratu": "titra",
    "titrau": "titra",
    "titrează": "titra",
    "titrez": "titra",
    "titreze": "titra",
    "titrezi": "titra",
    "titrarea": "titrare",
    "titrări": "titrare",
    "titrării": "titrare",
    "titrările": "titrare",
    "titrata": "titrat",
    "titrată": "titrat",
    "titrate": "titrat",
    "titratei": "titrat",
    "titratele": "titrat",
    "titratelor": "titrat",
    "titrați": "titrat",
    "titrații": "titrat",
    "titraților": "titrat",
    "titratul": "titrat",
    "titratului": "titrat",
    "titrata": "titrată",
    "titrate": "titrată",
    "titratei": "titrată",
    "titratele": "titrată",
    "titratelor": "titrată",
    "titulari": "titular",
    "titularii": "titular",
    "titularilor": "titular",
    "titularul": "titular",
    "titularului": "titular",
    "titulara": "titulară",
    "titulare": "titulară",
    "titularei": "titulară",
    "titularele": "titulară",
    "titularelor": "titulară",
    "nemaititularizând": "titulariza",
    "nemaititularizându": "titulariza",
    "netitularizând": "titulariza",
    "netitularizându": "titulariza",
    "titulariză": "titulariza",
    "titularizai": "titulariza",
    "titularizam": "titulariza",
    "titularizăm": "titulariza",
    "titularizând": "titulariza",
    "titularizându": "titulariza",
    "titularizară": "titulariza",
    "titularizarăm": "titulariza",
    "titularizarăți": "titulariza",
    "titularizase": "titulariza",
    "titularizasem": "titulariza",
    "titularizaseră": "titulariza",
    "titularizaserăm": "titulariza",
    "titularizaserăți": "titulariza",
    "titularizaseși": "titulariza",
    "titularizași": "titulariza",
    "titularizat": "titulariza",
    "titularizați": "titulariza",
    "titularizatu": "titulariza",
    "titularizau": "titulariza",
    "titularizează": "titulariza",
    "titularizez": "titulariza",
    "titularizeze": "titulariza",
    "titularizezi": "titulariza",
    "titularizarea": "titularizare",
    "titularizări": "titularizare",
    "titularizării": "titularizare",
    "titularizările": "titularizare",
    "titularizata": "titularizat",
    "titularizată": "titularizat",
    "titularizate": "titularizat",
    "titularizatei": "titularizat",
    "titularizatele": "titularizat",
    "titularizatelor": "titularizat",
    "titularizați": "titularizat",
    "titularizaților": "titularizat",
    "titularizatul": "titularizat",
    "titularizatului": "titularizat",
    "titularizata": "titularizată",
    "titularizate": "titularizată",
    "titularizatei": "titularizată",
    "titularizatele": "titularizată",
    "titularizatelor": "titularizată",
    "titulatura": "titulatură",
    "titulaturi": "titulatură",
    "titulaturii": "titulatură",
    "titulaturile": "titulatură",
    "titulaturilor": "titulatură",
    "țiuia": "țiui",
    "țiuiai": "țiui",
    "țiuiam": "țiui",
    "țiuiați": "țiui",
    "țiuiau": "țiui",
    "țiuie": "țiui",
    "țiuii": "țiui",
    "țiuim": "țiui",
    "țiuind": "țiui",
    "țiuindu": "țiui",
    "țiuiră": "țiui",
    "țiuirăm": "țiui",
    "țiuirăți": "țiui",
    "țiuise": "țiui",
    "țiuisem": "țiui",
    "țiuiseră": "țiui",
    "țiuiserăm": "țiui",
    "țiuiserăți": "țiui",
    "țiuiseși": "țiui",
    "țiuiși": "țiui",
    "țiuit": "țiui",
    "țiuiți": "țiui",
    "țiuitu": "țiui",
    "țiuită": "țiuit",
    "țiuite": "țiuit",
    "țiuiți": "țiuit",
    "țiuitoare": "țiuitor",
    "țiuitoarea": "țiuitor",
    "țiuitoarei": "țiuitor",
    "țiuitoarele": "țiuitor",
    "țiuitoarelor": "țiuitor",
    "țiuitori": "țiuitor",
    "țiuitorii": "țiuitor",
    "țiuitorilor": "țiuitor",
    "țiuitorul": "țiuitor",
    "țiuitorului": "țiuitor",
    "tivul": "tiv",
    "tivului": "tiv",
    "tivuri": "tiv",
    "tivurile": "tiv",
    "tivurilor": "tiv",
    "tizi": "tiz",
    "tizii": "tiz",
    "tizilor": "tiz",
    "tizul": "tiz",
    "tizului": "tiz",
    "tiza": "tiză",
    "tize": "tiză",
    "tizei": "tiză",
    "tizele": "tiză",
    "tizelor": "tiză",
    "toaca": "toacă",
    "toace": "toacă",
    "toacei": "toacă",
    "toacele": "toacă",
    "toacelor": "toacă",
    "toaleta": "toaletă",
    "toalete": "toaletă",
    "toaletei": "toaletă",
    "toaletele": "toaletă",
    "toaletelor": "toaletă",
    "toamna": "toamnă",
    "toamne": "toamnă",
    "toamnei": "toamnă",
    "toamnele": "toamnă",
    "toamnelor": "toamnă",
    "toamno": "toamnă",
    "toana": "toană",
    "toane": "toană",
    "toanei": "toană",
    "toanele": "toană",
    "toanelor": "toană",
    "toarcă": "toarce",
    "toarcem": "toarce",
    "toarceți": "toarce",
    "toarse": "toarce",
    "toarseră": "toarce",
    "toarserăm": "toarce",
    "toarserăți": "toarce",
    "torc": "toarce",
    "torcând": "toarce",
    "torcându": "toarce",
    "torcea": "toarce",
    "torceai": "toarce",
    "torceam": "toarce",
    "torceați": "toarce",
    "torceau": "toarce",
    "torci": "toarce",
    "tors": "toarce",
    "torsei": "toarce",
    "torsese": "toarce",
    "torsesem": "toarce",
    "torseseră": "toarce",
    "torseserăm": "toarce",
    "torseserăți": "toarce",
    "torseseși": "toarce",
    "torseși": "toarce",
    "torsu": "toarce",
    "toarta": "toartă",
    "toarte": "toartă",
    "toartei": "toartă",
    "toartele": "toartă",
    "toartelor": "toartă",
    "toarto": "toartă",
    "toastul": "toast",
    "toastului": "toast",
    "toasturi": "toast",
    "toasturile": "toast",
    "toasturilor": "toast",
    "nemaitoastând": "toasta",
    "nemaitoastându": "toasta",
    "netoastând": "toasta",
    "netoastându": "toasta",
    "toastă": "toasta",
    "toastai": "toasta",
    "toastam": "toasta",
    "toastăm": "toasta",
    "toastând": "toasta",
    "toastându": "toasta",
    "toastară": "toasta",
    "toastarăm": "toasta",
    "toastarăți": "toasta",
    "toastase": "toasta",
    "toastasem": "toasta",
    "toastaseră": "toasta",
    "toastaserăm": "toasta",
    "toastaserăți": "toasta",
    "toastaseși": "toasta",
    "toastași": "toasta",
    "toastat": "toasta",
    "toastați": "toasta",
    "toastatu": "toasta",
    "toastau": "toasta",
    "toastează": "toasta",
    "toastez": "toasta",
    "toasteze": "toasta",
    "toastezi": "toasta",
    "toastarea": "toastare",
    "toastări": "toastare",
    "toastării": "toastare",
    "toastările": "toastare",
    "toastata": "toastat",
    "toastată": "toastat",
    "toastate": "toastat",
    "toastatei": "toastat",
    "toastatele": "toastat",
    "toastatelor": "toastat",
    "toastați": "toastat",
    "toastații": "toastat",
    "toastaților": "toastat",
    "toastatul": "toastat",
    "toastatului": "toastat",
    "toastata": "toastată",
    "toastate": "toastată",
    "toastatei": "toastată",
    "toastatele": "toastată",
    "toastatelor": "toastată",
    "toba": "tobă",
    "tobe": "tobă",
    "tobei": "tobă",
    "tobele": "tobă",
    "tobelor": "tobă",
    "tobo": "tobă",
    "tobogane": "tobogan",
    "toboganele": "tobogan",
    "toboganelor": "tobogan",
    "toboganul": "tobogan",
    "toboganului": "tobogan",
    "tocul": "toc",
    "tocule": "toc",
    "tocului": "toc",
    "tocuri": "toc",
    "tocurile": "toc",
    "tocurilor": "toc",
    "toace": "toca",
    "toc": "toca",
    "tocă": "toca",
    "tocai": "toca",
    "tocam": "toca",
    "tocăm": "toca",
    "tocând": "toca",
    "tocându": "toca",
    "tocară": "toca",
    "tocarăm": "toca",
    "tocarăți": "toca",
    "tocase": "toca",
    "tocasem": "toca",
    "tocaseră": "toca",
    "tocaserăm": "toca",
    "tocaserăți": "toca",
    "tocaseși": "toca",
    "tocași": "toca",
    "tocat": "toca",
    "tocați": "toca",
    "tocatu": "toca",
    "tocau": "toca",
    "toci": "toca",
    "toca": "tocă",
    "toci": "tocă",
    "tocii": "tocă",
    "tocile": "tocă",
    "tocilor": "tocă",
    "tocana": "tocană",
    "tocane": "tocană",
    "tocanei": "tocană",
    "tocanele": "tocană",
    "tocanelor": "tocană",
    "tocano": "tocană",
    "tocata": "tocat",
    "tocată": "tocat",
    "tocate": "tocat",
    "tocatei": "tocat",
    "tocatele": "tocat",
    "tocatelor": "tocat",
    "tocați": "tocat",
    "tocații": "tocat",
    "tocaților": "tocat",
    "tocatul": "tocat",
    "tocatului": "tocat",
    "tocata": "tocată",
    "tocate": "tocată",
    "tocatei": "tocată",
    "tocatele": "tocată",
    "tocatelor": "tocată",
    "toceala": "toceală",
    "toceli": "toceală",
    "tocelii": "toceală",
    "tocelile": "toceală",
    "nemaitocind": "toci",
    "nemaitocindu": "toci",
    "netocind": "toci",
    "netocindu": "toci",
    "tocea": "toci",
    "toceai": "toci",
    "toceam": "toci",
    "tocească": "toci",
    "toceați": "toci",
    "toceau": "toci",
    "tocesc": "toci",
    "tocește": "toci",
    "tocești": "toci",
    "tocii": "toci",
    "tocim": "toci",
    "tocind": "toci",
    "tocindu": "toci",
    "tociră": "toci",
    "tocirăm": "toci",
    "tocirăți": "toci",
    "tocise": "toci",
    "tocisem": "toci",
    "tociseră": "toci",
    "tociserăm": "toci",
    "tociserăți": "toci",
    "tociseși": "toci",
    "tociși": "toci",
    "tocit": "toci",
    "tociți": "toci",
    "tocitu": "toci",
    "tocirea": "tocire",
    "tociri": "tocire",
    "tocirii": "tocire",
    "tocirile": "tocire",
    "tocita": "tocit",
    "tocită": "tocit",
    "tocite": "tocit",
    "tocitei": "tocit",
    "tocitele": "tocit",
    "tocitelor": "tocit",
    "tociți": "tocit",
    "tociții": "tocit",
    "tociților": "tocit",
    "tocitul": "tocit",
    "tocitului": "tocit",
    "tocma": "tocmai",
    "tocma'": "tocmai",
    "tocmeala": "tocmeală",
    "tocmeli": "tocmeală",
    "tocmelii": "tocmeală",
    "tocmelile": "tocmeală",
    "nemaitocmind": "tocmi",
    "nemaitocmindu": "tocmi",
    "netocmind": "tocmi",
    "netocmindu": "tocmi",
    "tocmea": "tocmi",
    "tocmeai": "tocmi",
    "tocmeam": "tocmi",
    "tocmească": "tocmi",
    "tocmeați": "tocmi",
    "tocmeau": "tocmi",
    "tocmesc": "tocmi",
    "tocmește": "tocmi",
    "tocmești": "tocmi",
    "tocmii": "tocmi",
    "tocmim": "tocmi",
    "tocmind": "tocmi",
    "tocmindu": "tocmi",
    "tocmiră": "tocmi",
    "tocmirăm": "tocmi",
    "tocmirăți": "tocmi",
    "tocmise": "tocmi",
    "tocmisem": "tocmi",
    "tocmiseră": "tocmi",
    "tocmiserăm": "tocmi",
    "tocmiserăți": "tocmi",
    "tocmiseși": "tocmi",
    "tocmiși": "tocmi",
    "tocmit": "tocmi",
    "tocmiți": "tocmi",
    "tocmitu": "tocmi",
    "tocmita": "tocmit",
    "tocmită": "tocmit",
    "tocmite": "tocmit",
    "tocmitei": "tocmit",
    "tocmitele": "tocmit",
    "tocmitelor": "tocmit",
    "tocmiți": "tocmit",
    "tocmiții": "tocmit",
    "tocmiților": "tocmit",
    "tocmitul": "tocmit",
    "tocmitului": "tocmit",
    "toga": "togă",
    "togi": "togă",
    "togii": "togă",
    "togile": "togă",
    "togilor": "togă",
    "tohoarca": "tohoarcă",
    "tohoarce": "tohoarcă",
    "tohoarcei": "tohoarcă",
    "tohoarcele": "tohoarcă",
    "tohoarcelor": "tohoarcă",
    "toiul": "toi",
    "toiului": "toi",
    "toiuri": "toi",
    "toiurile": "toi",
    "toiurilor": "toi",
    "țoiul": "țoi",
    "țoiului": "țoi",
    "țoiuri": "țoi",
    "țoiurile": "țoi",
    "țoiurilor": "țoi",
    "toiagul": "toiag",
    "toiagului": "toiag",
    "toiege": "toiag",
    "toiegele": "toiag",
    "toiegelor": "toiag",
    "tola": "tolă",
    "tole": "tolă",
    "tolei": "tolă",
    "tolele": "tolă",
    "tolelor": "tolă",
    "tolba": "tolbă",
    "tolbe": "tolbă",
    "tolbei": "tolbă",
    "tolbele": "tolbă",
    "tolbelor": "tolbă",
    "nemaitolerând": "tolera",
    "nemaitolerându": "tolera",
    "netolerând": "tolera",
    "netolerându": "tolera",
    "toleră": "tolera",
    "tolerai": "tolera",
    "toleram": "tolera",
    "tolerăm": "tolera",
    "tolerând": "tolera",
    "tolerându": "tolera",
    "tolerară": "tolera",
    "tolerarăm": "tolera",
    "tolerarăți": "tolera",
    "tolerase": "tolera",
    "tolerasem": "tolera",
    "toleraseră": "tolera",
    "toleraserăm": "tolera",
    "toleraserăți": "tolera",
    "toleraseși": "tolera",
    "tolerași": "tolera",
    "tolerat": "tolera",
    "tolerați": "tolera",
    "toleratu": "tolera",
    "tolerau": "tolera",
    "tolerează": "tolera",
    "tolerez": "tolera",
    "tolereze": "tolera",
    "tolerezi": "tolera",
    "toleranta": "tolerant",
    "tolerantă": "tolerant",
    "tolerante": "tolerant",
    "tolerantei": "tolerant",
    "tolerantele": "tolerant",
    "tolerantelor": "tolerant",
    "toleranți": "tolerant",
    "toleranții": "tolerant",
    "toleranților": "tolerant",
    "toleranto": "tolerant",
    "tolerantul": "tolerant",
    "tolerantule": "tolerant",
    "tolerantului": "tolerant",
    "toleranța": "toleranță",
    "toleranțe": "toleranță",
    "toleranței": "toleranță",
    "toleranțele": "toleranță",
    "tolerata": "tolerat",
    "tolerată": "tolerat",
    "tolerate": "tolerat",
    "toleratei": "tolerat",
    "toleratele": "tolerat",
    "toleratelor": "tolerat",
    "tolerați": "tolerat",
    "tolerații": "tolerat",
    "toleraților": "tolerat",
    "toleratul": "tolerat",
    "toleratului": "tolerat",
    "tolerata": "tolerată",
    "tolerate": "tolerată",
    "toleratei": "tolerată",
    "toleratele": "tolerată",
    "toleratelor": "tolerată",
    "toloaca": "toloacă",
    "toloace": "toloacă",
    "toloacei": "toloacă",
    "toloacele": "toloacă",
    "toloacelor": "toloacă",
    "nemaitologind": "tologi",
    "nemaitologindu": "tologi",
    "netologind": "tologi",
    "netologindu": "tologi",
    "tologea": "tologi",
    "tologeai": "tologi",
    "tologeam": "tologi",
    "tologească": "tologi",
    "tologeați": "tologi",
    "tologeau": "tologi",
    "tologesc": "tologi",
    "tologește": "tologi",
    "tologești": "tologi",
    "tologii": "tologi",
    "tologim": "tologi",
    "tologind": "tologi",
    "tologindu": "tologi",
    "tologiră": "tologi",
    "tologirăm": "tologi",
    "tologirăți": "tologi",
    "tologise": "tologi",
    "tologisem": "tologi",
    "tologiseră": "tologi",
    "tologiserăm": "tologi",
    "tologiserăți": "tologi",
    "tologiseși": "tologi",
    "tologiși": "tologi",
    "tologit": "tologi",
    "tologiți": "tologi",
    "tologitu": "tologi",
    "tologita": "tologit",
    "tologită": "tologit",
    "tologite": "tologit",
    "tologitei": "tologit",
    "tologitele": "tologit",
    "tologitelor": "tologit",
    "tologiți": "tologit",
    "tologiții": "tologit",
    "tologiților": "tologit",
    "tologitul": "tologit",
    "tologitului": "tologit",
    "tolomaci": "tolomac",
    "tolomacii": "tolomac",
    "tolomacilor": "tolomac",
    "tolomacul": "tolomac",
    "tolomacului": "tolomac",
    "tolomaca": "tolomacă",
    "tolomace": "tolomacă",
    "tolomacei": "tolomacă",
    "tolomacele": "tolomacă",
    "tolomacelor": "tolomacă",
    "tomul": "tom",
    "tomului": "tom",
    "tomuri": "tom",
    "tomurile": "tom",
    "tomurilor": "tom",
    "tomata": "tomată",
    "tomate": "tomată",
    "tomatei": "tomată",
    "tomatele": "tomată",
    "tomatelor": "tomată",
    "tomberoane": "tomberon",
    "tomberoanele": "tomberon",
    "tomberoanelor": "tomberon",
    "tomberonul": "tomberon",
    "tomberonului": "tomberon",
    "tonul": "ton",
    "tonului": "ton",
    "tonuri": "ton",
    "tonurile": "ton",
    "tonurilor": "ton",
    "t.": "tonă",
    "tona": "tonă",
    "tone": "tonă",
    "tonei": "tonă",
    "tonele": "tonă",
    "tonelor": "tonă",
    "tone-forță": "tonă-forță",
    "tonaje": "tonaj",
    "tonajele": "tonaj",
    "tonajelor": "tonaj",
    "tonajul": "tonaj",
    "tonajului": "tonaj",
    "tone-kilometru": "tonă-kilometru",
    "tonalitatea": "tonalitate",
    "tonalități": "tonalitate",
    "tonalității": "tonalitate",
    "tonalitățile": "tonalitate",
    "tonalităților": "tonalitate",
    "tone-registru": "tonă-registru",
    "tonica": "tonic",
    "tonică": "tonic",
    "tonice": "tonic",
    "tonicei": "tonic",
    "tonicele": "tonic",
    "tonicelor": "tonic",
    "tonici": "tonic",
    "tonicii": "tonic",
    "tonicilor": "tonic",
    "tonicul": "tonic",
    "tonicului": "tonic",
    "nemaitonificând": "tonifica",
    "nemaitonificându": "tonifica",
    "netonificând": "tonifica",
    "netonificându": "tonifica",
    "tonific": "tonifica",
    "tonifică": "tonifica",
    "tonificai": "tonifica",
    "tonificam": "tonifica",
    "tonificăm": "tonifica",
    "tonificând": "tonifica",
    "tonificându": "tonifica",
    "tonificară": "tonifica",
    "tonificarăm": "tonifica",
    "tonificarăți": "tonifica",
    "tonificase": "tonifica",
    "tonificasem": "tonifica",
    "tonificaseră": "tonifica",
    "tonificaserăm": "tonifica",
    "tonificaserăți": "tonifica",
    "tonificaseși": "tonifica",
    "tonificași": "tonifica",
    "tonificat": "tonifica",
    "tonificați": "tonifica",
    "tonificatu": "tonifica",
    "tonificau": "tonifica",
    "tonifice": "tonifica",
    "tonifici": "tonifica",
    "tonificarea": "tonificare",
    "tonificări": "tonificare",
    "tonificării": "tonificare",
    "tonificările": "tonificare",
    "tonificata": "tonificat",
    "tonificată": "tonificat",
    "tonificate": "tonificat",
    "tonificatei": "tonificat",
    "tonificatele": "tonificat",
    "tonificatelor": "tonificat",
    "tonificați": "tonificat",
    "tonificații": "tonificat",
    "tonificaților": "tonificat",
    "tonificatul": "tonificat",
    "tonificatului": "tonificat",
    "tonomate": "tonomat",
    "tonomatele": "tonomat",
    "tonomatelor": "tonomat",
    "tonomatul": "tonomat",
    "tonomatului": "tonomat",
    "toanta": "tont",
    "toantă": "tont",
    "toante": "tont",
    "toantei": "tont",
    "toantele": "tont",
    "toantelor": "tont",
    "tonți": "tont",
    "tonții": "tont",
    "tonților": "tont",
    "tontul": "tont",
    "tontului": "tont",
    "tonusul": "tonus",
    "tonusului": "tonus",
    "tonusuri": "tonus",
    "tonusurile": "tonus",
    "tonusurilor": "tonus",
    "topul": "top",
    "topului": "top",
    "topuri": "top",
    "topurile": "top",
    "topurilor": "top",
    "nemaițopăind": "țopăi",
    "nemaițopăindu": "țopăi",
    "nețopăind": "țopăi",
    "nețopăindu": "țopăi",
    "țopăia": "țopăi",
    "țopăiai": "țopăi",
    "țopăiam": "țopăi",
    "țopăiați": "țopăi",
    "țopăiau": "țopăi",
    "țopăie": "țopăi",
    "țopăii": "țopăi",
    "țopăim": "țopăi",
    "țopăind": "țopăi",
    "țopăindu": "țopăi",
    "țopăiră": "țopăi",
    "țopăirăm": "țopăi",
    "țopăirăți": "țopăi",
    "țopăise": "țopăi",
    "țopăisem": "țopăi",
    "țopăiseră": "țopăi",
    "țopăiserăm": "țopăi",
    "țopăiserăți": "țopăi",
    "țopăiseși": "țopăi",
    "țopăiși": "țopăi",
    "țopăit": "țopăi",
    "țopăiți": "țopăi",
    "țopăita": "țopăit",
    "țopăită": "țopăit",
    "țopăite": "țopăit",
    "țopăitei": "țopăit",
    "țopăitele": "țopăit",
    "țopăitelor": "țopăit",
    "țopăiți": "țopăit",
    "țopăiții": "țopăit",
    "țopăiților": "țopăit",
    "țopăito": "țopăit",
    "țopăitul": "țopăit",
    "țopăitule": "țopăit",
    "țopăitului": "țopăit",
    "țopăitura": "țopăitură",
    "țopăituri": "țopăitură",
    "țopăiturii": "țopăitură",
    "țopăiturile": "țopăitură",
    "țopăiturilor": "țopăitură",
    "țopăituro": "țopăitură",
    "topaze": "topaz",
    "topazele": "topaz",
    "topazelor": "topaz",
    "topazul": "topaz",
    "topazului": "topaz",
    "nemaitopind": "topi",
    "nemaitopindu": "topi",
    "netopind": "topi",
    "netopindu": "topi",
    "topea": "topi",
    "topeai": "topi",
    "topeam": "topi",
    "topească": "topi",
    "topeați": "topi",
    "topeau": "topi",
    "topesc": "topi",
    "topește": "topi",
    "topești": "topi",
    "topii": "topi",
    "topim": "topi",
    "topind": "topi",
    "topindu": "topi",
    "topiră": "topi",
    "topirăm": "topi",
    "topirăți": "topi",
    "topise": "topi",
    "topisem": "topi",
    "topiseră": "topi",
    "topiserăm": "topi",
    "topiserăți": "topi",
    "topiseși": "topi",
    "topiși": "topi",
    "topit": "topi",
    "topiți": "topi",
    "topitu": "topi",
    "topica": "topic",
    "topică": "topic",
    "topice": "topic",
    "topicei": "topic",
    "topicele": "topic",
    "topicelor": "topic",
    "topici": "topic",
    "topicii": "topic",
    "topicilor": "topic",
    "topicul": "topic",
    "topicului": "topic",
    "topica": "topică",
    "topicele": "topică",
    "topici": "topică",
    "topicii": "topică",
    "topicilor": "topică",
    "topirea": "topire",
    "topireo": "topire",
    "topiri": "topire",
    "topirii": "topire",
    "topirile": "topire",
    "topirilor": "topire",
    "topita": "topit",
    "topită": "topit",
    "topite": "topit",
    "topitei": "topit",
    "topitele": "topit",
    "topitelor": "topit",
    "topiți": "topit",
    "topiții": "topit",
    "topiților": "topit",
    "topito": "topit",
    "topitul": "topit",
    "topitule": "topit",
    "topitului": "topit",
    "toplița": "topliță",
    "toplițe": "topliță",
    "topliței": "topliță",
    "toplițele": "topliță",
    "toplițelor": "topliță",
    "topografica": "topografic",
    "topografică": "topografic",
    "topografice": "topografic",
    "topograficei": "topografic",
    "topograficele": "topografic",
    "topograficelor": "topografic",
    "topografici": "topografic",
    "topograficii": "topografic",
    "topograficilor": "topografic",
    "topograficul": "topografic",
    "topograficului": "topografic",
    "top.": "topografie",
    "topografia": "topografie",
    "topografiei": "topografie",
    "topografii": "topografie",
    "topografiile": "topografie",
    "topografiilor": "topografie",
    "Topoloveniul": "Topoloveni",
    "Topoloveniului": "Topoloveni",
    "topometria": "topometrie",
    "topometriei": "topometrie",
    "topometrii": "topometrie",
    "topometriile": "topometrie",
    "topometriilor": "topometrie",
    "toponimica": "toponimic",
    "toponimică": "toponimic",
    "toponimice": "toponimic",
    "toponimicei": "toponimic",
    "toponimicele": "toponimic",
    "toponimicelor": "toponimic",
    "toponimici": "toponimic",
    "toponimicii": "toponimic",
    "toponimicilor": "toponimic",
    "toponimicul": "toponimic",
    "toponimicului": "toponimic",
    "toponimia": "toponimie",
    "toponimiei": "toponimie",
    "toponimii": "toponimie",
    "toponimiile": "toponimie",
    "toponimiilor": "toponimie",
    "topoare": "topor",
    "topoarele": "topor",
    "topoarelor": "topor",
    "toporul": "topor",
    "toporului": "topor",
    "toporâștea": "toporâște",
    "toporâști": "toporâște",
    "toporâștii": "toporâște",
    "toporâștile": "toporâște",
    "toporâștilor": "toporâște",
    "toporișca": "toporișcă",
    "toporișco": "toporișcă",
    "toporiști": "toporișcă",
    "toporiștii": "toporișcă",
    "toporiștile": "toporișcă",
    "toporiștilor": "toporișcă",
    "toptane": "toptan",
    "toptanele": "toptan",
    "toptanelor": "toptan",
    "toptanul": "toptan",
    "toptanului": "toptan",
    "topuzul": "topuz",
    "topuzului": "topuz",
    "topuzuri": "topuz",
    "topuzurile": "topuz",
    "topuzurilor": "topuz",
    "toracele": "torace",
    "toracelor": "torace",
    "toracelui": "torace",
    "toracica": "toracic",
    "toracică": "toracic",
    "toracice": "toracic",
    "toracicei": "toracic",
    "toracicele": "toracic",
    "toracicelor": "toracic",
    "toracici": "toracic",
    "toracicii": "toracic",
    "toracicilor": "toracic",
    "toracicul": "toracic",
    "toracicului": "toracic",
    "toreadori": "toreador",
    "toreadorii": "toreador",
    "toreadorilor": "toreador",
    "toreadorul": "toreador",
    "toreadorului": "toreador",
    "torente": "torent",
    "torentele": "torent",
    "torentelor": "torent",
    "torentul": "torent",
    "torentului": "torent",
    "torențiala": "torențial",
    "torențială": "torențial",
    "torențiale": "torențial",
    "torențialei": "torențial",
    "torențialele": "torențial",
    "torențialelor": "torențial",
    "torențiali": "torențial",
    "torențialii": "torențial",
    "torențialilor": "torențial",
    "torențialul": "torențial",
    "torențialului": "torențial",
    "torida": "torid",
    "toridă": "torid",
    "toride": "torid",
    "toridei": "torid",
    "toridele": "torid",
    "toridelor": "torid",
    "toridul": "torid",
    "toridului": "torid",
    "torizi": "torid",
    "torizii": "torid",
    "torizilor": "torid",
    "toriul": "toriu",
    "toriului": "toriu",
    "tornada": "tornadă",
    "tornade": "tornadă",
    "tornadei": "tornadă",
    "tornadele": "tornadă",
    "tornadelor": "tornadă",
    "toropeala": "toropeală",
    "toropeli": "toropeală",
    "toropelii": "toropeală",
    "toropelile": "toropeală",
    "nemaitoropind": "toropi",
    "nemaitoropindu": "toropi",
    "netoropind": "toropi",
    "netoropindu": "toropi",
    "toropea": "toropi",
    "toropeai": "toropi",
    "toropeam": "toropi",
    "toropească": "toropi",
    "toropeați": "toropi",
    "toropeau": "toropi",
    "toropesc": "toropi",
    "toropește": "toropi",
    "toropești": "toropi",
    "toropii": "toropi",
    "toropim": "toropi",
    "toropind": "toropi",
    "toropindu": "toropi",
    "toropiră": "toropi",
    "toropirăm": "toropi",
    "toropirăți": "toropi",
    "toropise": "toropi",
    "toropisem": "toropi",
    "toropiseră": "toropi",
    "toropiserăm": "toropi",
    "toropiserăți": "toropi",
    "toropiseși": "toropi",
    "toropiși": "toropi",
    "toropit": "toropi",
    "toropiți": "toropi",
    "toropitu": "toropi",
    "toropirea": "toropire",
    "toropiri": "toropire",
    "toropirii": "toropire",
    "toropirile": "toropire",
    "toropita": "toropit",
    "toropită": "toropit",
    "toropite": "toropit",
    "toropitei": "toropit",
    "toropitele": "toropit",
    "toropitelor": "toropit",
    "toropiți": "toropit",
    "toropiții": "toropit",
    "toropiților": "toropit",
    "toropitul": "toropit",
    "toropitului": "toropit",
    "torpila": "torpilă",
    "torpile": "torpilă",
    "torpilei": "torpilă",
    "torpilele": "torpilă",
    "torpilelor": "torpilă",
    "torpiloare": "torpilor",
    "torpiloarele": "torpilor",
    "torpiloarelor": "torpilor",
    "torpilorul": "torpilor",
    "torpilorului": "torpilor",
    "toarsă": "tors",
    "toarse": "tors",
    "torși": "tors",
    "torsul": "tors",
    "torsului": "tors",
    "torsuri": "tors",
    "torsurile": "tors",
    "torsurilor": "tors",
    "torsada": "torsadă",
    "torsade": "torsadă",
    "torsadei": "torsadă",
    "torsadele": "torsadă",
    "torsadelor": "torsadă",
    "tortul": "tort",
    "tortului": "tort",
    "torturi": "tort",
    "torturile": "tort",
    "torturilor": "tort",
    "torța": "torță",
    "torțe": "torță",
    "torței": "torță",
    "torțele": "torță",
    "torțelor": "torță",
    "torționara": "torționar",
    "torționară": "torționar",
    "torționare": "torționar",
    "torționarei": "torționar",
    "torționarele": "torționar",
    "torționarelor": "torționar",
    "torționari": "torționar",
    "torționarii": "torționar",
    "torționarilor": "torționar",
    "torționarul": "torționar",
    "torționarului": "torționar",
    "torționara": "torționară",
    "torționare": "torționară",
    "torționarei": "torționară",
    "torționarele": "torționară",
    "torționarelor": "torționară",
    "nemaitorturând": "tortura",
    "nemaitorturându": "tortura",
    "netorturând": "tortura",
    "netorturându": "tortura",
    "tortură": "tortura",
    "torturai": "tortura",
    "torturam": "tortura",
    "torturăm": "tortura",
    "torturând": "tortura",
    "torturându": "tortura",
    "torturară": "tortura",
    "torturarăm": "tortura",
    "torturarăți": "tortura",
    "torturase": "tortura",
    "torturasem": "tortura",
    "torturaseră": "tortura",
    "torturaserăm": "tortura",
    "torturaserăți": "tortura",
    "torturaseși": "tortura",
    "torturași": "tortura",
    "torturat": "tortura",
    "torturați": "tortura",
    "torturatu": "tortura",
    "torturau": "tortura",
    "torturează": "tortura",
    "torturez": "tortura",
    "tortureze": "tortura",
    "torturezi": "tortura",
    "tortura": "tortură",
    "torturi": "tortură",
    "torturii": "tortură",
    "torturile": "tortură",
    "torturilor": "tortură",
    "torturarea": "torturare",
    "torturări": "torturare",
    "torturării": "torturare",
    "torturările": "torturare",
    "torturata": "torturat",
    "torturată": "torturat",
    "torturate": "torturat",
    "torturatei": "torturat",
    "torturatele": "torturat",
    "torturatelor": "torturat",
    "torturați": "torturat",
    "torturații": "torturat",
    "torturaților": "torturat",
    "torturatul": "torturat",
    "torturatului": "torturat",
    "torturata": "torturată",
    "torturate": "torturată",
    "torturatei": "torturată",
    "torturatele": "torturată",
    "torturatelor": "torturată",
    "cu_toatele": "tot",
    "cu_toții": "tot",
    "to'": "tot",
    "toată": "tot",
    "toate": "tot",
    "toți": "tot",
    "totu": "tot",
    "totu'": "tot",
    "totul": "tot",
    "totului": "tot",
    "tuturor": "tot",
    "tuturora": "tot",
    "totala": "total",
    "totală": "total",
    "totale": "total",
    "totalei": "total",
    "totalele": "total",
    "totalelor": "total",
    "totali": "total",
    "totalii": "total",
    "totalilor": "total",
    "totalo": "total",
    "totalul": "total",
    "totalule": "total",
    "totalului": "total",
    "totaluri": "total",
    "totalurile": "total",
    "totalurilor": "total",
    "totalitara": "totalitar",
    "totalitară": "totalitar",
    "totalitare": "totalitar",
    "totalitarei": "totalitar",
    "totalitarele": "totalitar",
    "totalitarelor": "totalitar",
    "totalitari": "totalitar",
    "totalitarii": "totalitar",
    "totalitarilor": "totalitar",
    "totalitarul": "totalitar",
    "totalitarule": "totalitar",
    "totalitarului": "totalitar",
    "totalitarisme": "totalitarism",
    "totalitarismele": "totalitarism",
    "totalitarismelor": "totalitarism",
    "totalitarismul": "totalitarism",
    "totalitarismului": "totalitarism",
    "totalitarista": "totalitarist",
    "totalitaristă": "totalitarist",
    "totalitariste": "totalitarist",
    "totalitaristei": "totalitarist",
    "totalitaristele": "totalitarist",
    "totalitaristelor": "totalitarist",
    "totalitariști": "totalitarist",
    "totalitariștii": "totalitarist",
    "totalitariștilor": "totalitarist",
    "totalitaristo": "totalitarist",
    "totalitaristul": "totalitarist",
    "totalitaristule": "totalitarist",
    "totalitaristului": "totalitarist",
    "totalitarista": "totalitaristă",
    "totalitariste": "totalitaristă",
    "totalitaristei": "totalitaristă",
    "totalitaristele": "totalitaristă",
    "totalitaristelor": "totalitaristă",
    "totalitaristo": "totalitaristă",
    "totalitatea": "totalitate",
    "totalitateo": "totalitate",
    "totalități": "totalitate",
    "totalității": "totalitate",
    "totalitățile": "totalitate",
    "totalităților": "totalitate",
    "totaliză": "totaliza",
    "totalizai": "totaliza",
    "totalizam": "totaliza",
    "totalizăm": "totaliza",
    "totalizând": "totaliza",
    "totalizându": "totaliza",
    "totalizară": "totaliza",
    "totalizarăm": "totaliza",
    "totalizarăți": "totaliza",
    "totalizase": "totaliza",
    "totalizasem": "totaliza",
    "totalizaseră": "totaliza",
    "totalizaserăm": "totaliza",
    "totalizaserăți": "totaliza",
    "totalizaseși": "totaliza",
    "totalizași": "totaliza",
    "totalizat": "totaliza",
    "totalizați": "totaliza",
    "totalizatu": "totaliza",
    "totalizau": "totaliza",
    "totalizează": "totaliza",
    "totalizez": "totaliza",
    "totalizeze": "totaliza",
    "totalizezi": "totaliza",
    "totalizată": "totalizat",
    "totalizate": "totalizat",
    "totalizați": "totalizat",
    "totemul": "totem",
    "totemului": "totem",
    "totemuri": "totem",
    "totemurile": "totem",
    "totemurilor": "totem",
    "tovarășe": "tovarăș",
    "tovarăși": "tovarăș",
    "tovarășii": "tovarăș",
    "tovarășilor": "tovarăș",
    "tovarășo": "tovarăș",
    "tovarășul": "tovarăș",
    "tovarășule": "tovarăș",
    "tovarășului": "tovarăș",
    "tovarășa": "tovarășă",
    "tovarășe": "tovarășă",
    "tovarășei": "tovarășă",
    "tovarășele": "tovarășă",
    "tovarășelor": "tovarășă",
    "tovărășeasca": "tovărășesc",
    "tovărășească": "tovărășesc",
    "tovărășeasco": "tovărășesc",
    "tovărășescul": "tovărășesc",
    "tovărășescule": "tovărășesc",
    "tovărășescului": "tovărășesc",
    "tovărășești": "tovărășesc",
    "tovărășeștii": "tovărășesc",
    "tovărășeștile": "tovărășesc",
    "tovărășeștilor": "tovărășesc",
    "tovărășia": "tovărășie",
    "tovărășiei": "tovărășie",
    "tovarășii": "tovărășie",
    "tovărășiile": "tovărășie",
    "tovărășiilor": "tovărășie",
    "tovărășio": "tovărășie",
    "tov.": "tovarășul",
    "toxica": "toxic",
    "toxică": "toxic",
    "toxice": "toxic",
    "toxicei": "toxic",
    "toxicele": "toxic",
    "toxicelor": "toxic",
    "toxici": "toxic",
    "toxicii": "toxic",
    "toxicilor": "toxic",
    "toxicul": "toxic",
    "toxicului": "toxic",
    "toxicologia": "toxicologie",
    "toxicologiei": "toxicologie",
    "toxicologii": "toxicologie",
    "toxicologiile": "toxicologie",
    "toxicologiilor": "toxicologie",
    "toxicomani": "toxicoman",
    "toxicomanii": "toxicoman",
    "toxicomanilor": "toxicoman",
    "toxicomanul": "toxicoman",
    "toxicomanului": "toxicoman",
    "toxicomana": "toxicomană",
    "toxicomane": "toxicomană",
    "toxicomanei": "toxicomană",
    "toxicomanele": "toxicomană",
    "toxicomanelor": "toxicomană",
    "toxicomania": "toxicomanie",
    "toxicomaniei": "toxicomanie",
    "toxicomanii": "toxicomanie",
    "toxicomaniile": "toxicomanie",
    "toxicomaniilor": "toxicomanie",
    "toxina": "toxină",
    "toxine": "toxină",
    "toxinei": "toxină",
    "toxinele": "toxină",
    "toxinelor": "toxină",
    "trabucul": "trabuc",
    "trabucului": "trabuc",
    "trabucuri": "trabuc",
    "trabucurile": "trabuc",
    "trabucurilor": "trabuc",
    "traca": "trac",
    "tracă": "trac",
    "trace": "trac",
    "tracei": "trac",
    "tracele": "trac",
    "tracelor": "trac",
    "traci": "trac",
    "tracii": "trac",
    "tracilor": "trac",
    "tracul": "trac",
    "tracului": "trac",
    "tracuri": "trac",
    "tracurile": "trac",
    "tracurilor": "trac",
    "nemaitracasând": "tracasa",
    "nemaitracasându": "tracasa",
    "netracasând": "tracasa",
    "netracasându": "tracasa",
    "tracasă": "tracasa",
    "tracasai": "tracasa",
    "tracasam": "tracasa",
    "tracasăm": "tracasa",
    "tracasând": "tracasa",
    "tracasându": "tracasa",
    "tracasară": "tracasa",
    "tracasarăm": "tracasa",
    "tracasarăți": "tracasa",
    "tracasase": "tracasa",
    "tracasasem": "tracasa",
    "tracasaseră": "tracasa",
    "tracasaserăm": "tracasa",
    "tracasaserăți": "tracasa",
    "tracasaseși": "tracasa",
    "tracasași": "tracasa",
    "tracasat": "tracasa",
    "tracasați": "tracasa",
    "tracasatu": "tracasa",
    "tracasau": "tracasa",
    "tracasează": "tracasa",
    "tracasez": "tracasa",
    "tracaseze": "tracasa",
    "tracasezi": "tracasa",
    "tracasarea": "tracasare",
    "tracasări": "tracasare",
    "tracasării": "tracasare",
    "tracasările": "tracasare",
    "tracasata": "tracasat",
    "tracasată": "tracasat",
    "tracasate": "tracasat",
    "tracasatei": "tracasat",
    "tracasatele": "tracasat",
    "tracasatelor": "tracasat",
    "tracasați": "tracasat",
    "tracasații": "tracasat",
    "tracasaților": "tracasat",
    "tracasatul": "tracasat",
    "tracasatului": "tracasat",
    "tracasata": "tracasată",
    "tracasate": "tracasată",
    "tracasatei": "tracasată",
    "tracasatele": "tracasată",
    "tracasatelor": "tracasată",
    "tracțiunea": "tracțiune",
    "tracțiuni": "tracțiune",
    "tracțiunii": "tracțiune",
    "tracțiunile": "tracțiune",
    "tracțiunilor": "tracțiune",
    "tractoare": "tractor",
    "tractoarele": "tractor",
    "tractoarelor": "tractor",
    "tractorul": "tractor",
    "tractorului": "tractor",
    "tractorista": "tractorist",
    "tractoristă": "tractorist",
    "tractoriste": "tractorist",
    "tractoristei": "tractorist",
    "tractoristele": "tractorist",
    "tractoristelor": "tractorist",
    "tractoriști": "tractorist",
    "tractoriștii": "tractorist",
    "tractoriștilor": "tractorist",
    "tractoristul": "tractorist",
    "tractoristului": "tractorist",
    "tractorista": "tractoristă",
    "tractoriste": "tractoristă",
    "tractoristei": "tractoristă",
    "tractoristele": "tractoristă",
    "tractoristelor": "tractoristă",
    "nemaitrădând": "trăda",
    "nemaitrădându": "trăda",
    "netrădând": "trăda",
    "netrădându": "trăda",
    "trădă": "trăda",
    "trădai": "trăda",
    "trădam": "trăda",
    "trădăm": "trăda",
    "trădând": "trăda",
    "trădându": "trăda",
    "trădară": "trăda",
    "trădarăm": "trăda",
    "trădarăți": "trăda",
    "trădase": "trăda",
    "trădasem": "trăda",
    "trădaseră": "trăda",
    "trădaserăm": "trăda",
    "trădaserăți": "trăda",
    "trădaseși": "trăda",
    "trădași": "trăda",
    "trădat": "trăda",
    "trădați": "trăda",
    "trădatu": "trăda",
    "trădau": "trăda",
    "trădează": "trăda",
    "trădez": "trăda",
    "trădeze": "trăda",
    "trădezi": "trăda",
    "trădarea": "trădare",
    "trădări": "trădare",
    "trădării": "trădare",
    "trădările": "trădare",
    "trădata": "trădat",
    "trădată": "trădat",
    "trădate": "trădat",
    "trădatei": "trădat",
    "trădatele": "trădat",
    "trădatelor": "trădat",
    "trădați": "trădat",
    "trădații": "trădat",
    "trădaților": "trădat",
    "trădatul": "trădat",
    "trădatului": "trădat",
    "trădata": "trădată",
    "trădate": "trădată",
    "trădatei": "trădată",
    "trădatele": "trădată",
    "trădatelor": "trădată",
    "trădătoarea": "trădătoare",
    "trădătoarei": "trădătoare",
    "trădătoarele": "trădătoare",
    "trădătoarelor": "trădătoare",
    "trădătoare": "trădător",
    "trădătoarea": "trădător",
    "trădătoarei": "trădător",
    "trădătoarele": "trădător",
    "trădătoarelor": "trădător",
    "tră-dă-tor": "trădător",
    "trădători": "trădător",
    "trădătorii": "trădător",
    "trădătorilor": "trădător",
    "trădătorul": "trădător",
    "trădătorului": "trădător",
    "trade-unionuri": "trade-union",
    "trade-unionista": "trade-unionist",
    "trade-unionistă": "trade-unionist",
    "trade-unioniste": "trade-unionist",
    "trade-unionistei": "trade-unionist",
    "trade-unionistele": "trade-unionist",
    "trade-unionistelor": "trade-unionist",
    "trade-unioniști": "trade-unionist",
    "trade-unioniștii": "trade-unionist",
    "trade-unioniștilor": "trade-unionist",
    "trade-unionistul": "trade-unionist",
    "trade-unionistului": "trade-unionist",
    "tradiția": "tradiție",
    "tradiției": "tradiție",
    "tradiții": "tradiție",
    "tradițiile": "tradiție",
    "tradițiilor": "tradiție",
    "tradiționala": "tradițional",
    "tradițională": "tradițional",
    "tradiționale": "tradițional",
    "tradiționalei": "tradițional",
    "tradiționalele": "tradițional",
    "tradiționalelor": "tradițional",
    "tradiționali": "tradițional",
    "tradiționalii": "tradițional",
    "tradiționalilor": "tradițional",
    "tradiționalu": "tradițional",
    "tradiționalul": "tradițional",
    "tradiționalului": "tradițional",
    "tradiționalisme": "tradiționalism",
    "tradiționalismele": "tradiționalism",
    "tradiționalismelor": "tradiționalism",
    "tradiționalismul": "tradiționalism",
    "tradiționalismului": "tradiționalism",
    "tradiționalista": "tradiționalist",
    "tradiționalistă": "tradiționalist",
    "tradiționaliste": "tradiționalist",
    "tradiționalistei": "tradiționalist",
    "tradiționalistele": "tradiționalist",
    "tradiționalistelor": "tradiționalist",
    "tradiționaliști": "tradiționalist",
    "tradiționaliștii": "tradiționalist",
    "tradiționaliștilor": "tradiționalist",
    "tradiționalistul": "tradiționalist",
    "tradiționalistului": "tradiționalist",
    "tradiționalista": "tradiționalistă",
    "tradiționaliste": "tradiționalistă",
    "tradiționalistei": "tradiționalistă",
    "tradiționalistele": "tradiționalistă",
    "tradiționalistelor": "tradiționalistă",
    "traducătoarea": "traducătoare",
    "traducătoarei": "traducătoare",
    "traducătoarele": "traducătoare",
    "traducătoarelor": "traducătoare",
    "traducătoare": "traducător",
    "traducătoarea": "traducător",
    "traducătoarei": "traducător",
    "traducătoarele": "traducător",
    "traducătoarelor": "traducător",
    "traducători": "traducător",
    "traducătorii": "traducător",
    "traducătorilor": "traducător",
    "traducătorul": "traducător",
    "traducătorului": "traducător",
    "nemaitraducând": "traduce",
    "nemaitraducându": "traduce",
    "netraducând": "traduce",
    "netraducându": "traduce",
    "netradus": "traduce",
    "tradu": "traduce",
    "traduc": "traduce",
    "traducă": "traduce",
    "traducând": "traduce",
    "traducându": "traduce",
    "traducea": "traduce",
    "traduceai": "traduce",
    "traduceam": "traduce",
    "traduceați": "traduce",
    "traduceau": "traduce",
    "traducem": "traduce",
    "traduceți": "traduce",
    "traduci": "traduce",
    "tradus": "traduce",
    "traduse": "traduce",
    "tradusei": "traduce",
    "traduseră": "traduce",
    "traduserăm": "traduce",
    "traduserăți": "traduce",
    "tradusese": "traduce",
    "tradusesem": "traduce",
    "traduseseră": "traduce",
    "traduseserăm": "traduce",
    "traduseserăți": "traduce",
    "traduseseși": "traduce",
    "traduseși": "traduce",
    "tradusu": "traduce",
    "traducerea": "traducere",
    "traduceri": "traducere",
    "traducerii": "traducere",
    "traducerile": "traducere",
    "traductibila": "traductibil",
    "traductibilă": "traductibil",
    "traductibile": "traductibil",
    "traductibilei": "traductibil",
    "traductibilele": "traductibil",
    "traductibilelor": "traductibil",
    "traductibili": "traductibil",
    "traductibilii": "traductibil",
    "traductibililor": "traductibil",
    "traductibilul": "traductibil",
    "traductibilului": "traductibil",
    "tradusa": "tradus",
    "tradusă": "tradus",
    "traduse": "tradus",
    "tradusei": "tradus",
    "tradusele": "tradus",
    "traduselor": "tradus",
    "traduși": "tradus",
    "tradușii": "tradus",
    "tradușilor": "tradus",
    "tradusul": "tradus",
    "tradusului": "tradus",
    "traficul": "trafic",
    "traficului": "trafic",
    "traficuri": "trafic",
    "traficurile": "trafic",
    "traficurilor": "trafic",
    "nemaitraficând": "trafica",
    "nemaitraficându": "trafica",
    "netraficând": "trafica",
    "netraficându": "trafica",
    "trafică": "trafica",
    "traficai": "trafica",
    "traficam": "trafica",
    "traficăm": "trafica",
    "traficând": "trafica",
    "traficându": "trafica",
    "traficară": "trafica",
    "traficarăm": "trafica",
    "traficarăți": "trafica",
    "traficase": "trafica",
    "traficasem": "trafica",
    "traficaseră": "trafica",
    "traficaserăm": "trafica",
    "traficaserăți": "trafica",
    "traficaseși": "trafica",
    "traficași": "trafica",
    "traficat": "trafica",
    "traficați": "trafica",
    "traficatu": "trafica",
    "traficau": "trafica",
    "trafichează": "trafica",
    "trafichez": "trafica",
    "traficheze": "trafica",
    "trafichezi": "trafica",
    "traficanți": "traficant",
    "traficanții": "traficant",
    "traficanților": "traficant",
    "traficantul": "traficant",
    "traficantului": "traficant",
    "traficanta": "traficantă",
    "traficante": "traficantă",
    "traficantei": "traficantă",
    "traficantele": "traficantă",
    "traficantelor": "traficantă",
    "traficata": "traficat",
    "traficată": "traficat",
    "traficate": "traficat",
    "traficatei": "traficat",
    "traficatele": "traficat",
    "traficatelor": "traficat",
    "traficați": "traficat",
    "traficații": "traficat",
    "traficaților": "traficat",
    "traficatul": "traficat",
    "traficatului": "traficat",
    "trăgace": "trăgaci",
    "trăgacea": "trăgaci",
    "trăgacei": "trăgaci",
    "trăgacele": "trăgaci",
    "trăgacelor": "trăgaci",
    "trăgacii": "trăgaci",
    "trăgacilor": "trăgaci",
    "trăgaciul": "trăgaci",
    "trăgaciului": "trăgaci",
    "trăgătoarea": "trăgătoare",
    "trăgătoarei": "trăgătoare",
    "trăgătoarele": "trăgătoare",
    "trăgătoarelor": "trăgătoare",
    "trăgătoare": "trăgător",
    "trăgătoarea": "trăgător",
    "trăgătoarei": "trăgător",
    "trăgătoarele": "trăgător",
    "trăgătoarelor": "trăgător",
    "trăgători": "trăgător",
    "trăgătorii": "trăgător",
    "trăgătorilor": "trăgător",
    "trăgătorul": "trăgător",
    "trăgătorului": "trăgător",
    "nemaitrăgând": "trage",
    "nemaitrăgându": "trage",
    "netrăgând": "trage",
    "netrăgându": "trage",
    "trag": "trage",
    "tragă": "trage",
    "trăgând": "trage",
    "trăgându": "trage",
    "trăgea": "trage",
    "trăgeai": "trage",
    "trăgeam": "trage",
    "trăgeați": "trage",
    "trăgeau": "trage",
    "tragem": "trage",
    "trageți": "trage",
    "tragi": "trage",
    "tras": "trage",
    "trase": "trage",
    "trăsei": "trage",
    "traseră": "trage",
    "traserăm": "trage",
    "traserăți": "trage",
    "trăsese": "trage",
    "trăsesem": "trage",
    "trăseseră": "trage",
    "trăseserăm": "trage",
    "trăseserăți": "trage",
    "trăseseși": "trage",
    "trăseși": "trage",
    "trasu": "trage",
    "tragediana": "tragedian",
    "tragediană": "tragedian",
    "tragedianul": "tragedian",
    "tragedianului": "tragedian",
    "tragediene": "tragedian",
    "tragedienei": "tragedian",
    "tragedienele": "tragedian",
    "tragedienelor": "tragedian",
    "tragedieni": "tragedian",
    "tragedienii": "tragedian",
    "tragedienilor": "tragedian",
    "tragedia": "tragedie",
    "tragediei": "tragedie",
    "tragedii": "tragedie",
    "tragediile": "tragedie",
    "tragediilor": "tragedie",
    "tragerea": "tragere",
    "tragereo": "tragere",
    "trageri": "tragere",
    "tragerii": "tragere",
    "tragerile": "tragere",
    "tragerilor": "tragere",
    "traghelafi": "traghelaf",
    "tragica": "tragic",
    "tragică": "tragic",
    "tragice": "tragic",
    "tragicei": "tragic",
    "tragicele": "tragic",
    "tragicelor": "tragic",
    "tragici": "tragic",
    "tragicii": "tragic",
    "tragicilor": "tragic",
    "tragicul": "tragic",
    "tragicului": "tragic",
    "tragicomedia": "tragicomedie",
    "tragicomediei": "tragicomedie",
    "tragicomedii": "tragicomedie",
    "tragicomediile": "tragicomedie",
    "tragicomediilor": "tragicomedie",
    "tragicomica": "tragicomic",
    "tragicomică": "tragicomic",
    "tragicomice": "tragicomic",
    "tragicomicei": "tragicomic",
    "tragicomicele": "tragicomic",
    "tragicomicelor": "tragicomic",
    "tragicomici": "tragicomic",
    "tragicomicii": "tragicomic",
    "tragicomicilor": "tragicomic",
    "tragicomicul": "tragicomic",
    "tragicomicului": "tragicomic",
    "tragisme": "tragism",
    "tragismele": "tragism",
    "tragismelor": "tragism",
    "tragismul": "tragism",
    "tragismului": "tragism",
    "traheea": "trahee",
    "traheei": "trahee",
    "trahei": "trahee",
    "traheii": "trahee",
    "traheile": "trahee",
    "traheilor": "trahee",
    "traiul": "trai",
    "traiule": "trai",
    "traiului": "trai",
    "traiuri": "trai",
    "traiurile": "trai",
    "traiurilor": "trai",
    "nemaitrăind": "trăi",
    "nemaitrăindu": "trăi",
    "netrăind": "trăi",
    "netrăindu": "trăi",
    "trăia": "trăi",
    "trăiai": "trăi",
    "trăiam": "trăi",
    "trăiască": "trăi",
    "trăiați": "trăi",
    "trăiau": "trăi",
    "trăiesc": "trăi",
    "trăiește": "trăi",
    "trăiești": "trăi",
    "trăii": "trăi",
    "trăim": "trăi",
    "trăind": "trăi",
    "trăindu": "trăi",
    "trăiră": "trăi",
    "trăirăm": "trăi",
    "trăirăți": "trăi",
    "trăise": "trăi",
    "trăisem": "trăi",
    "trăiseră": "trăi",
    "trăiserăm": "trăi",
    "trăiserăți": "trăi",
    "trăiseși": "trăi",
    "trăiși": "trăi",
    "trăit": "trăi",
    "trăiți": "trăi",
    "trăitu": "trăi",
    "T.": "Traian",
    "traiecte": "traiect",
    "traiectele": "traiect",
    "traiectelor": "traiect",
    "traiectul": "traiect",
    "traiectului": "traiect",
    "traiectoria": "traiectorie",
    "traiectoriei": "traiectorie",
    "traiectorii": "traiectorie",
    "traiectoriile": "traiectorie",
    "traiectoriilor": "traiectorie",
    "traila": "trailă",
    "traile": "trailă",
    "trailei": "trailă",
    "trailele": "trailă",
    "trailelor": "trailă",
    "trainica": "trainic",
    "trainică": "trainic",
    "trainice": "trainic",
    "trainicei": "trainic",
    "trainicele": "trainic",
    "trainicelor": "trainic",
    "trainici": "trainic",
    "trainicii": "trainic",
    "trainicilor": "trainic",
    "trainicul": "trainic",
    "trainicului": "trainic",
    "trăinicia": "trăinicie",
    "trăiniciei": "trăinicie",
    "trăinicii": "trăinicie",
    "trăiniciile": "trăinicie",
    "trăiniciilor": "trăinicie",
    "trăirea": "trăire",
    "trăiri": "trăire",
    "trăirii": "trăire",
    "trăirile": "trăire",
    "trăirilor": "trăire",
    "trăită": "trăit",
    "trăite": "trăit",
    "trăiți": "trăit",
    "trăitoarea": "trăitoare",
    "trăitoarei": "trăitoare",
    "trăitoarele": "trăitoare",
    "trăitoarelor": "trăitoare",
    "trăitoare": "trăitor",
    "trăitoarea": "trăitor",
    "trăitoarei": "trăitor",
    "trăitoarele": "trăitor",
    "trăitoarelor": "trăitor",
    "trăitori": "trăitor",
    "trăitorii": "trăitor",
    "trăitorilor": "trăitor",
    "trăitorul": "trăitor",
    "trăitorului": "trăitor",
    "trama": "tramă",
    "trame": "tramă",
    "tramei": "tramă",
    "tramele": "tramă",
    "tramelor": "tramă",
    "trâmba": "trâmbă",
    "trâmbe": "trâmbă",
    "trâmbei": "trâmbă",
    "trâmbele": "trâmbă",
    "trâmbelor": "trâmbă",
    "nemaitrambalând": "trambala",
    "nemaitrambalându": "trambala",
    "netrambalând": "trambala",
    "netrambalându": "trambala",
    "trambală": "trambala",
    "trambalai": "trambala",
    "trambalam": "trambala",
    "trambalăm": "trambala",
    "trambalând": "trambala",
    "trambalându": "trambala",
    "trambalară": "trambala",
    "trambalarăm": "trambala",
    "trambalarăți": "trambala",
    "trambalase": "trambala",
    "trambalasem": "trambala",
    "trambalaseră": "trambala",
    "trambalaserăm": "trambala",
    "trambalaserăți": "trambala",
    "trambalaseși": "trambala",
    "trambalași": "trambala",
    "trambalat": "trambala",
    "trambalați": "trambala",
    "trambalatu": "trambala",
    "trambalau": "trambala",
    "trambalează": "trambala",
    "trambalez": "trambala",
    "trambaleze": "trambala",
    "trambalezi": "trambala",
    "trambalarea": "trambalare",
    "trambalări": "trambalare",
    "trambalării": "trambalare",
    "trambalările": "trambalare",
    "trambalată": "trambalat",
    "trambalate": "trambalat",
    "trambalați": "trambalat",
    "trâmbiță": "trâmbița",
    "trâmbițai": "trâmbița",
    "trâmbițam": "trâmbița",
    "trâmbițăm": "trâmbița",
    "trâmbițând": "trâmbița",
    "trâmbițându": "trâmbița",
    "trâmbițară": "trâmbița",
    "trâmbițarăm": "trâmbița",
    "trâmbițarăți": "trâmbița",
    "trâmbițase": "trâmbița",
    "trâmbițasem": "trâmbița",
    "trâmbițaseră": "trâmbița",
    "trâmbițaserăm": "trâmbița",
    "trâmbițaserăți": "trâmbița",
    "trâmbițaseși": "trâmbița",
    "trâmbițași": "trâmbița",
    "trâmbițat": "trâmbița",
    "trâmbițați": "trâmbița",
    "trâmbițatu": "trâmbița",
    "trâmbițau": "trâmbița",
    "trâmbițează": "trâmbița",
    "trâmbițez": "trâmbița",
    "trâmbițeze": "trâmbița",
    "trâmbițezi": "trâmbița",
    "trâmbița": "trâmbiță",
    "trâmbițe": "trâmbiță",
    "trâmbiței": "trâmbiță",
    "trâmbițele": "trâmbiță",
    "trâmbițelor": "trâmbiță",
    "trâmbițarea": "trâmbițare",
    "trâmbițări": "trâmbițare",
    "trâmbițării": "trâmbițare",
    "trâmbițările": "trâmbițare",
    "trâmbițata": "trâmbițat",
    "trâmbițată": "trâmbițat",
    "trâmbițate": "trâmbițat",
    "trâmbițatei": "trâmbițat",
    "trâmbițatele": "trâmbițat",
    "trâmbițatelor": "trâmbițat",
    "trâmbițați": "trâmbițat",
    "trâmbițații": "trâmbițat",
    "trâmbițaților": "trâmbițat",
    "trâmbițatul": "trâmbițat",
    "trâmbițatului": "trâmbițat",
    "trambulina": "trambulină",
    "trambuline": "trambulină",
    "trambulinei": "trambulină",
    "trambulinele": "trambulină",
    "trambulinelor": "trambulină",
    "tramcare": "tramcar",
    "tramcarele": "tramcar",
    "tramcarelor": "tramcar",
    "tramcarul": "tramcar",
    "tramcarului": "tramcar",
    "tramvaie": "tramvai",
    "tramvaiele": "tramvai",
    "tramvaielor": "tramvai",
    "tramvaiul": "tramvai",
    "tramvaiului": "tramvai",
    "nemaitrăncănind": "trăncăni",
    "nemaitrăncănindu": "trăncăni",
    "netrăncănind": "trăncăni",
    "netrăncănindu": "trăncăni",
    "trăncănea": "trăncăni",
    "trăncăneai": "trăncăni",
    "trăncăneam": "trăncăni",
    "trăncănească": "trăncăni",
    "trăncăneați": "trăncăni",
    "trăncăneau": "trăncăni",
    "trăncănesc": "trăncăni",
    "trăncănește": "trăncăni",
    "trăncănești": "trăncăni",
    "trăncănii": "trăncăni",
    "trăncănim": "trăncăni",
    "trăncănind": "trăncăni",
    "trăncănindu": "trăncăni",
    "trăncăniră": "trăncăni",
    "trăncănirăm": "trăncăni",
    "trăncănirăți": "trăncăni",
    "trăncănise": "trăncăni",
    "trăncănisem": "trăncăni",
    "trăncăniseră": "trăncăni",
    "trăncăniserăm": "trăncăni",
    "trăncăniserăți": "trăncăni",
    "trăncăniseși": "trăncăni",
    "trăncăniși": "trăncăni",
    "trăncănit": "trăncăni",
    "trăncăniți": "trăncăni",
    "trăncănitu": "trăncăni",
    "trăncănirea": "trăncănire",
    "trăncănireo": "trăncănire",
    "trăncăniri": "trăncănire",
    "trăncănirii": "trăncănire",
    "trăncănirile": "trăncănire",
    "trăncănirilor": "trăncănire",
    "trăncănita": "trăncănit",
    "trăncănită": "trăncănit",
    "trăncănite": "trăncănit",
    "trăncănitei": "trăncănit",
    "trăncănitele": "trăncănit",
    "trăncănitelor": "trăncănit",
    "trăncăniți": "trăncănit",
    "trăncăniții": "trăncănit",
    "trăncăniților": "trăncănit",
    "trăncănito": "trăncănit",
    "trăncănitul": "trăncănit",
    "trăncănitule": "trăncănit",
    "trăncănitului": "trăncănit",
    "tranchilizanta": "tranchilizant",
    "tranchilizantă": "tranchilizant",
    "tranchilizante": "tranchilizant",
    "tranchilizantei": "tranchilizant",
    "tranchilizantele": "tranchilizant",
    "tranchilizantelor": "tranchilizant",
    "tranchilizanți": "tranchilizant",
    "tranchilizanții": "tranchilizant",
    "tranchilizanților": "tranchilizant",
    "tranchilizantul": "tranchilizant",
    "tranchilizantului": "tranchilizant",
    "trandafiri": "trandafir",
    "trandafirii": "trandafir",
    "trandafirilor": "trandafir",
    "trandafirul": "trandafir",
    "trandafirule": "trandafir",
    "trandafirului": "trandafir",
    "trandafiri": "trandafiriu",
    "trandafiria": "trandafiriu",
    "trandafirie": "trandafiriu",
    "trandafiriei": "trandafiriu",
    "trandafirii": "trandafiriu",
    "trandafiriii": "trandafiriu",
    "trandafiriile": "trandafiriu",
    "trandafiriilor": "trandafiriu",
    "trandafiriul": "trandafiriu",
    "trandafiriului": "trandafiriu",
    "trândavi": "trândav",
    "trândavii": "trândav",
    "trândavilor": "trândav",
    "trândavul": "trândav",
    "trândavului": "trândav",
    "nemaitrândăvind": "trândăvi",
    "nemaitrândăvindu": "trândăvi",
    "netrândăvind": "trândăvi",
    "netrândăvindu": "trândăvi",
    "trândăvea": "trândăvi",
    "trândăveai": "trândăvi",
    "trândăveam": "trândăvi",
    "trândăvească": "trândăvi",
    "trândăveați": "trândăvi",
    "trândăveau": "trândăvi",
    "trândăvesc": "trândăvi",
    "trândăvește": "trândăvi",
    "trândăvești": "trândăvi",
    "trândăvii": "trândăvi",
    "trândăvim": "trândăvi",
    "trândăvind": "trândăvi",
    "trândăvindu": "trândăvi",
    "trândăviră": "trândăvi",
    "trândăvirăm": "trândăvi",
    "trândăvirăți": "trândăvi",
    "trândăvise": "trândăvi",
    "trândăvisem": "trândăvi",
    "trândăviseră": "trândăvi",
    "trândăviserăm": "trândăvi",
    "trândăviserăți": "trândăvi",
    "trândăviseși": "trândăvi",
    "trândăviși": "trândăvi",
    "trândăvit": "trândăvi",
    "trândăviți": "trândăvi",
    "trândăvitu": "trândăvi",
    "trândăvia": "trândăvie",
    "trândăviei": "trândăvie",
    "trândăvii": "trândăvie",
    "trândăviile": "trândăvie",
    "trândăviilor": "trândăvie",
    "trândăvirea": "trândăvire",
    "trândăviri": "trândăvire",
    "trândăvirii": "trândăvire",
    "trândăvirile": "trândăvire",
    "trândăvita": "trândăvit",
    "trândăvită": "trândăvit",
    "trândăvite": "trândăvit",
    "trândăvitei": "trândăvit",
    "trândăvitele": "trândăvit",
    "trândăvitelor": "trândăvit",
    "trândăviți": "trândăvit",
    "trândăviții": "trândăvit",
    "trândăviților": "trândăvit",
    "trândăvitul": "trândăvit",
    "trândăvitului": "trândăvit",
    "transa": "transă",
    "transe": "transă",
    "transei": "transă",
    "transele": "transă",
    "transelor": "transă",
    "nemaitranșând": "tranșa",
    "nemaitranșându": "tranșa",
    "netranșând": "tranșa",
    "netranșându": "tranșa",
    "tranșă": "tranșa",
    "tranșai": "tranșa",
    "tranșam": "tranșa",
    "tranșăm": "tranșa",
    "tranșând": "tranșa",
    "tranșându": "tranșa",
    "tranșară": "tranșa",
    "tranșarăm": "tranșa",
    "tranșarăți": "tranșa",
    "tranșase": "tranșa",
    "tranșasem": "tranșa",
    "tranșaseră": "tranșa",
    "tranșaserăm": "tranșa",
    "tranșaserăți": "tranșa",
    "tranșaseși": "tranșa",
    "tranșași": "tranșa",
    "tranșat": "tranșa",
    "tranșați": "tranșa",
    "tranșatu": "tranșa",
    "tranșau": "tranșa",
    "tranșează": "tranșa",
    "tranșez": "tranșa",
    "tranșeze": "tranșa",
    "tranșezi": "tranșa",
    "tranșa": "tranșă",
    "tranșe": "tranșă",
    "tranșei": "tranșă",
    "tranșele": "tranșă",
    "tranșelor": "tranșă",
    "transalpina": "transalpin",
    "transalpină": "transalpin",
    "transalpine": "transalpin",
    "transalpinei": "transalpin",
    "transalpinele": "transalpin",
    "transalpinelor": "transalpin",
    "transalpini": "transalpin",
    "transalpinii": "transalpin",
    "transalpinilor": "transalpin",
    "transalpinul": "transalpin",
    "transalpinului": "transalpin",
    "tranșanta": "tranșant",
    "tranșantă": "tranșant",
    "tranșante": "tranșant",
    "tranșantei": "tranșant",
    "tranșantele": "tranșant",
    "tranșantelor": "tranșant",
    "tranșanți": "tranșant",
    "tranșanții": "tranșant",
    "tranșanților": "tranșant",
    "tranșantul": "tranșant",
    "tranșantului": "tranșant",
    "tranșarea": "tranșare",
    "tranșări": "tranșare",
    "tranșării": "tranșare",
    "tranșările": "tranșare",
    "tranșata": "tranșat",
    "tranșată": "tranșat",
    "tranșate": "tranșat",
    "tranșatei": "tranșat",
    "tranșatele": "tranșat",
    "tranșatelor": "tranșat",
    "tranșați": "tranșat",
    "tranșații": "tranșat",
    "tranșaților": "tranșat",
    "tranșatul": "tranșat",
    "tranșatului": "tranșat",
    "nemaitransbordând": "transborda",
    "nemaitransbordându": "transborda",
    "netransbordând": "transborda",
    "netransbordându": "transborda",
    "transbordă": "transborda",
    "transbordai": "transborda",
    "transbordam": "transborda",
    "transbordăm": "transborda",
    "transbordând": "transborda",
    "transbordându": "transborda",
    "transbordară": "transborda",
    "transbordarăm": "transborda",
    "transbordarăți": "transborda",
    "transbordase": "transborda",
    "transbordasem": "transborda",
    "transbordaseră": "transborda",
    "transbordaserăm": "transborda",
    "transbordaserăți": "transborda",
    "transbordaseși": "transborda",
    "transbordași": "transborda",
    "transbordat": "transborda",
    "transbordați": "transborda",
    "transbordatu": "transborda",
    "transbordau": "transborda",
    "transbordează": "transborda",
    "transbordez": "transborda",
    "transbordeze": "transborda",
    "transbordezi": "transborda",
    "transbordarea": "transbordare",
    "transbordări": "transbordare",
    "transbordării": "transbordare",
    "transbordările": "transbordare",
    "transbordata": "transbordat",
    "transbordată": "transbordat",
    "transbordate": "transbordat",
    "transbordatei": "transbordat",
    "transbordatele": "transbordat",
    "transbordatelor": "transbordat",
    "transbordați": "transbordat",
    "transbordații": "transbordat",
    "transbordaților": "transbordat",
    "transbordatul": "transbordat",
    "transbordatului": "transbordat",
    "transbordata": "transbordată",
    "transbordate": "transbordată",
    "transbordatei": "transbordată",
    "transbordatele": "transbordată",
    "transbordatelor": "transbordată",
    "transcarpatina": "transcarpatin",
    "transcarpatină": "transcarpatin",
    "transcarpatine": "transcarpatin",
    "transcarpatinei": "transcarpatin",
    "transcarpatinele": "transcarpatin",
    "transcarpatinelor": "transcarpatin",
    "transcarpatini": "transcarpatin",
    "transcarpatinii": "transcarpatin",
    "transcarpatinilor": "transcarpatin",
    "transcarpatinul": "transcarpatin",
    "transcarpatinului": "transcarpatin",
    "transcaucaziana": "transcaucazian",
    "transcaucaziană": "transcaucazian",
    "transcaucazianul": "transcaucazian",
    "transcaucazianului": "transcaucazian",
    "transcaucaziene": "transcaucazian",
    "transcaucazienei": "transcaucazian",
    "transcaucazienele": "transcaucazian",
    "transcaucazienelor": "transcaucazian",
    "transcaucazieni": "transcaucazian",
    "transcaucazienii": "transcaucazian",
    "transcaucazienilor": "transcaucazian",
    "transcendenta": "transcendent",
    "transcendentă": "transcendent",
    "transcendente": "transcendent",
    "transcendentei": "transcendent",
    "transcendentele": "transcendent",
    "transcendentelor": "transcendent",
    "transcendenți": "transcendent",
    "transcendenții": "transcendent",
    "transcendenților": "transcendent",
    "transcendentul": "transcendent",
    "transcendentului": "transcendent",
    "transcendentala": "transcendental",
    "transcendentală": "transcendental",
    "transcendentale": "transcendental",
    "transcendentalei": "transcendental",
    "transcendentalele": "transcendental",
    "transcendentalelor": "transcendental",
    "transcendentali": "transcendental",
    "transcendentalii": "transcendental",
    "transcendentalilor": "transcendental",
    "transcendentalul": "transcendental",
    "transcendentalului": "transcendental",
    "nemaitranscriind": "transcrie",
    "nemaitranscriindu": "transcrie",
    "netranscriind": "transcrie",
    "netranscriindu": "transcrie",
    "transcria": "transcrie",
    "transcriai": "transcrie",
    "transcriam": "transcrie",
    "transcriați": "transcrie",
    "transcriau": "transcrie",
    "transcriem": "transcrie",
    "transcrieți": "transcrie",
    "transcrii": "transcrie",
    "transcriind": "transcrie",
    "transcriindu": "transcrie",
    "transcris": "transcrie",
    "transcrise": "transcrie",
    "transcrisei": "transcrie",
    "transcriseră": "transcrie",
    "transcriserăm": "transcrie",
    "transcriserăți": "transcrie",
    "transcrisese": "transcrie",
    "transcrisesem": "transcrie",
    "transcriseseră": "transcrie",
    "transcriseserăm": "transcrie",
    "transcriseserăți": "transcrie",
    "transcriseseși": "transcrie",
    "transcriseși": "transcrie",
    "transcrisu": "transcrie",
    "transcriu": "transcrie",
    "transcrierea": "transcriere",
    "transcrieri": "transcriere",
    "transcrierii": "transcriere",
    "transcrierile": "transcriere",
    "transcrisa": "transcris",
    "transcrisă": "transcris",
    "transcrise": "transcris",
    "transcrisei": "transcris",
    "transcrisele": "transcris",
    "transcriselor": "transcris",
    "transcriși": "transcris",
    "transcrișii": "transcris",
    "transcrișilor": "transcris",
    "transcrisul": "transcris",
    "transcrisului": "transcris",
    "transdanubiana": "transdanubian",
    "transdanubiană": "transdanubian",
    "transdanubianul": "transdanubian",
    "transdanubianului": "transdanubian",
    "transdanubiene": "transdanubian",
    "transdanubienei": "transdanubian",
    "transdanubienele": "transdanubian",
    "transdanubienelor": "transdanubian",
    "transdanubieni": "transdanubian",
    "transdanubienii": "transdanubian",
    "transdanubienilor": "transdanubian",
    "tranșeea": "tranșee",
    "tranșeei": "tranșee",
    "tranșeele": "tranșee",
    "tranșeelor": "tranșee",
    "transferul": "transfer",
    "transferului": "transfer",
    "transferuri": "transfer",
    "transferurile": "transfer",
    "transferurilor": "transfer",
    "nemaitransferând": "transfera",
    "nemaitransferându": "transfera",
    "netransferând": "transfera",
    "netransferându": "transfera",
    "transfer": "transfera",
    "transferă": "transfera",
    "transferai": "transfera",
    "transferam": "transfera",
    "transferăm": "transfera",
    "transferând": "transfera",
    "transferându": "transfera",
    "transferară": "transfera",
    "transferarăm": "transfera",
    "transferarăți": "transfera",
    "transferase": "transfera",
    "transferasem": "transfera",
    "transferaseră": "transfera",
    "transferaserăm": "transfera",
    "transferaserăți": "transfera",
    "transferaseși": "transfera",
    "transferași": "transfera",
    "transferat": "transfera",
    "transferați": "transfera",
    "transferatu": "transfera",
    "transferau": "transfera",
    "transfere": "transfera",
    "transferi": "transfera",
    "transferarea": "transferare",
    "transferări": "transferare",
    "transferării": "transferare",
    "transferările": "transferare",
    "transferata": "transferat",
    "transferată": "transferat",
    "transferate": "transferat",
    "transferatei": "transferat",
    "transferatele": "transferat",
    "transferatelor": "transferat",
    "transferați": "transferat",
    "transferații": "transferat",
    "transferaților": "transferat",
    "transferatul": "transferat",
    "transferatului": "transferat",
    "transferata": "transferată",
    "transferate": "transferată",
    "transferatei": "transferată",
    "transferatele": "transferată",
    "transferatelor": "transferată",
    "transfigură": "transfigura",
    "transfigurai": "transfigura",
    "transfiguram": "transfigura",
    "transfigurăm": "transfigura",
    "transfigurând": "transfigura",
    "transfigurându": "transfigura",
    "transfigurară": "transfigura",
    "transfigurarăm": "transfigura",
    "transfigurarăți": "transfigura",
    "transfigurase": "transfigura",
    "transfigurasem": "transfigura",
    "transfiguraseră": "transfigura",
    "transfiguraserăm": "transfigura",
    "transfiguraserăți": "transfigura",
    "transfiguraseși": "transfigura",
    "transfigurași": "transfigura",
    "transfigurat": "transfigura",
    "transfigurați": "transfigura",
    "transfiguratu": "transfigura",
    "transfigurau": "transfigura",
    "transfigurează": "transfigura",
    "transfigurez": "transfigura",
    "transfigureze": "transfigura",
    "transfigurezi": "transfigura",
    "transfigurarea": "transfigurare",
    "transfigurări": "transfigurare",
    "transfigurării": "transfigurare",
    "transfigurările": "transfigurare",
    "transfigurata": "transfigurat",
    "transfigurată": "transfigurat",
    "transfigurate": "transfigurat",
    "transfiguratei": "transfigurat",
    "transfiguratele": "transfigurat",
    "transfiguratelor": "transfigurat",
    "transfigurați": "transfigurat",
    "transfigurații": "transfigurat",
    "transfiguraților": "transfigurat",
    "transfiguratul": "transfigurat",
    "transfiguratului": "transfigurat",
    "transfigurata": "transfigurată",
    "transfigurate": "transfigurată",
    "transfiguratei": "transfigurată",
    "transfiguratele": "transfigurată",
    "transfiguratelor": "transfigurată",
    "nemaitransformând": "transforma",
    "nemaitransformându": "transforma",
    "netransformând": "transforma",
    "netransformându": "transforma",
    "transform": "transforma",
    "transformă": "transforma",
    "transformai": "transforma",
    "transformam": "transforma",
    "transformăm": "transforma",
    "transformând": "transforma",
    "transformându": "transforma",
    "transformară": "transforma",
    "transformarăm": "transforma",
    "transformarăți": "transforma",
    "transformase": "transforma",
    "transformasem": "transforma",
    "transformaseră": "transforma",
    "transformaserăm": "transforma",
    "transformaserăți": "transforma",
    "transformaseși": "transforma",
    "transformași": "transforma",
    "transformat": "transforma",
    "transformați": "transforma",
    "transformatu": "transforma",
    "transformau": "transforma",
    "transforme": "transforma",
    "transformi": "transforma",
    "transformarea": "transformare",
    "transformareo": "transformare",
    "transformări": "transformare",
    "transformării": "transformare",
    "transformările": "transformare",
    "transformărilor": "transformare",
    "transformata": "transformat",
    "transformată": "transformat",
    "transformate": "transformat",
    "transformatei": "transformat",
    "transformatele": "transformat",
    "transformatelor": "transformat",
    "transformați": "transformat",
    "transformații": "transformat",
    "transformaților": "transformat",
    "transformato": "transformat",
    "transformatul": "transformat",
    "transformatule": "transformat",
    "transformatului": "transformat",
    "transformatoare": "transformator",
    "transformatoarea": "transformator",
    "transformatoarei": "transformator",
    "transformatoarele": "transformator",
    "transformatoarelor": "transformator",
    "transformatoareo": "transformator",
    "transformatori": "transformator",
    "transformatorii": "transformator",
    "transformatorilor": "transformator",
    "transformatorul": "transformator",
    "transformatorule": "transformator",
    "transformatorului": "transformator",
    "transfugi": "transfug",
    "transfugii": "transfug",
    "transfugilor": "transfug",
    "transfugul": "transfug",
    "transfugului": "transfug",
    "transfuzia": "transfuzie",
    "transfuziei": "transfuzie",
    "transfuzii": "transfuzie",
    "transfuziile": "transfuzie",
    "transfuziilor": "transfuzie",
    "transhumanța": "transhumanță",
    "transhumanțe": "transhumanță",
    "transhumanței": "transhumanță",
    "transhumanțele": "transhumanță",
    "transhumanțelor": "transhumanță",
    "transilvana": "transilvan",
    "transilvană": "transilvan",
    "transilvane": "transilvan",
    "transilvanei": "transilvan",
    "transilvanele": "transilvan",
    "transilvanelor": "transilvan",
    "transilvani": "transilvan",
    "transilvanii": "transilvan",
    "transilvanilor": "transilvan",
    "transilvanul": "transilvan",
    "transilvanului": "transilvan",
    "transilvăneana": "transilvănean",
    "transilvăneană": "transilvănean",
    "transilvăneanul": "transilvănean",
    "transilvăneanului": "transilvănean",
    "transilvănene": "transilvănean",
    "transilvănenei": "transilvănean",
    "transilvănenele": "transilvănean",
    "transilvănenelor": "transilvănean",
    "transilvăneni": "transilvănean",
    "transilvănenii": "transilvănean",
    "transilvănenilor": "transilvănean",
    "transilvăneanca": "transilvăneancă",
    "transilvănence": "transilvăneancă",
    "transilvănencei": "transilvăneancă",
    "transilvănencele": "transilvăneancă",
    "transilvănencelor": "transilvăneancă",
    "Transilvanie": "Transilvania",
    "Transilvaniei": "Transilvania",
    "Transilvanii": "Transilvania",
    "translația": "translație",
    "translației": "translație",
    "translații": "translație",
    "translațiile": "translație",
    "translațiilor": "translație",
    "translatoarea": "translatoare",
    "translatoarei": "translatoare",
    "translatoarele": "translatoare",
    "translatoarelor": "translatoare",
    "translatori": "translator",
    "translatorii": "translator",
    "translatorilor": "translator",
    "translatorul": "translator",
    "translatorului": "translator",
    "transliterația": "transliterație",
    "transliterației": "transliterație",
    "transliterații": "transliterație",
    "transliterațiile": "transliterație",
    "transliterațiilor": "transliterație",
    "translucida": "translucid",
    "translucidă": "translucid",
    "translucide": "translucid",
    "translucidei": "translucid",
    "translucidele": "translucid",
    "translucidelor": "translucid",
    "translucidul": "translucid",
    "translucidului": "translucid",
    "translucizi": "translucid",
    "translucizii": "translucid",
    "translucizilor": "translucid",
    "transmisa": "transmis",
    "transmisă": "transmis",
    "transmise": "transmis",
    "transmisei": "transmis",
    "transmisele": "transmis",
    "transmiselor": "transmis",
    "transmiși": "transmis",
    "transmișii": "transmis",
    "transmișilor": "transmis",
    "transmiso": "transmis",
    "transmisul": "transmis",
    "transmisule": "transmis",
    "transmisului": "transmis",
    "transmisibila": "transmisibil",
    "transmisibilă": "transmisibil",
    "transmisibile": "transmisibil",
    "transmisibilei": "transmisibil",
    "transmisibilele": "transmisibil",
    "transmisibilelor": "transmisibil",
    "transmisibili": "transmisibil",
    "transmisibilii": "transmisibil",
    "transmisibililor": "transmisibil",
    "transmisibilul": "transmisibil",
    "transmisibilului": "transmisibil",
    "T.F.F.": "Transmisie_Fără_Fir",
    "nemaitransmițând": "transmite",
    "nemaitransmițându": "transmite",
    "netransmițând": "transmite",
    "netransmițându": "transmite",
    "transmis": "transmite",
    "transmise": "transmite",
    "transmisei": "transmite",
    "transmiseră": "transmite",
    "transmiserăm": "transmite",
    "transmiserăți": "transmite",
    "transmisese": "transmite",
    "transmisesem": "transmite",
    "transmiseseră": "transmite",
    "transmiseserăm": "transmite",
    "transmiseserăți": "transmite",
    "transmiseseși": "transmite",
    "transmiseși": "transmite",
    "transmisu": "transmite",
    "transmit": "transmite",
    "transmită": "transmite",
    "transmițând": "transmite",
    "transmițându": "transmite",
    "transmitea": "transmite",
    "transmiteai": "transmite",
    "transmiteam": "transmite",
    "transmiteați": "transmite",
    "transmiteau": "transmite",
    "transmitem": "transmite",
    "transmiteți": "transmite",
    "transmiți": "transmite",
    "transmiterea": "transmitere",
    "transmitereo": "transmitere",
    "transmiteri": "transmitere",
    "transmiterii": "transmitere",
    "transmiterile": "transmitere",
    "transmiterilor": "transmitere",
    "transmutarea": "transmutare",
    "transmutări": "transmutare",
    "transmutării": "transmutare",
    "transmutările": "transmutare",
    "transmutărilor": "transmutare",
    "transmutata": "transmutat",
    "transmutată": "transmutat",
    "transmutate": "transmutat",
    "transmutatei": "transmutat",
    "transmutatele": "transmutat",
    "transmutatelor": "transmutat",
    "transmutați": "transmutat",
    "transmutații": "transmutat",
    "transmutaților": "transmutat",
    "transmutatul": "transmutat",
    "transmutatului": "transmutat",
    "Transnistrie": "Transnistria",
    "Transnistriei": "Transnistria",
    "Transnistrii": "Transnistria",
    "transparenta": "transparent",
    "transparentă": "transparent",
    "transparente": "transparent",
    "transparentei": "transparent",
    "transparentele": "transparent",
    "transparentelor": "transparent",
    "transparenți": "transparent",
    "transparenții": "transparent",
    "transparenților": "transparent",
    "transparento": "transparent",
    "transparentul": "transparent",
    "transparentule": "transparent",
    "transparentului": "transparent",
    "transparența": "transparență",
    "transparențe": "transparență",
    "transparenței": "transparență",
    "transparențele": "transparență",
    "transparențelor": "transparență",
    "transperante": "transperant",
    "transperantele": "transperant",
    "transperantelor": "transperant",
    "transperantul": "transperant",
    "transperantului": "transperant",
    "nemaitranspirând": "transpira",
    "nemaitranspirându": "transpira",
    "netranspirând": "transpira",
    "netranspirându": "transpira",
    "transpir": "transpira",
    "transpiră": "transpira",
    "transpirai": "transpira",
    "transpiram": "transpira",
    "transpirăm": "transpira",
    "transpirând": "transpira",
    "transpirându": "transpira",
    "transpirară": "transpira",
    "transpirarăm": "transpira",
    "transpirarăți": "transpira",
    "transpirase": "transpira",
    "transpirasem": "transpira",
    "transpiraseră": "transpira",
    "transpiraserăm": "transpira",
    "transpiraserăți": "transpira",
    "transpiraseși": "transpira",
    "transpirași": "transpira",
    "transpirat": "transpira",
    "transpirați": "transpira",
    "transpiratu": "transpira",
    "transpirau": "transpira",
    "transpire": "transpira",
    "transpiri": "transpira",
    "transpirarea": "transpirare",
    "transpirareo": "transpirare",
    "transpirări": "transpirare",
    "transpirării": "transpirare",
    "transpirările": "transpirare",
    "transpirărilor": "transpirare",
    "transpirata": "transpirat",
    "transpirată": "transpirat",
    "transpirate": "transpirat",
    "transpiratei": "transpirat",
    "transpiratele": "transpirat",
    "transpiratelor": "transpirat",
    "transpirați": "transpirat",
    "transpirații": "transpirat",
    "transpiraților": "transpirat",
    "transpirato": "transpirat",
    "transpiratul": "transpirat",
    "transpiratule": "transpirat",
    "transpiratului": "transpirat",
    "transpirata": "transpirată",
    "transpirate": "transpirată",
    "transpiratei": "transpirată",
    "transpiratele": "transpirată",
    "transpiratelor": "transpirată",
    "transpirato": "transpirată",
    "transpirația": "transpirație",
    "transpirației": "transpirație",
    "transpirații": "transpirație",
    "transpirațiile": "transpirație",
    "transpirațiilor": "transpirație",
    "transpirațio": "transpirație",
    "transplantul": "transplant",
    "transplantului": "transplant",
    "transplanturi": "transplant",
    "transplanturile": "transplant",
    "transplanturilor": "transplant",
    "nemaitransplantând": "transplanta",
    "nemaitransplantându": "transplanta",
    "netransplantând": "transplanta",
    "netransplantându": "transplanta",
    "transplantă": "transplanta",
    "transplantai": "transplanta",
    "transplantam": "transplanta",
    "transplantăm": "transplanta",
    "transplantând": "transplanta",
    "transplantându": "transplanta",
    "transplantară": "transplanta",
    "transplantarăm": "transplanta",
    "transplantarăți": "transplanta",
    "transplantase": "transplanta",
    "transplantasem": "transplanta",
    "transplantaseră": "transplanta",
    "transplantaserăm": "transplanta",
    "transplantaserăți": "transplanta",
    "transplantaseși": "transplanta",
    "transplantași": "transplanta",
    "transplantat": "transplanta",
    "transplantați": "transplanta",
    "transplantatu": "transplanta",
    "transplantau": "transplanta",
    "transplantează": "transplanta",
    "transplantez": "transplanta",
    "transplanteze": "transplanta",
    "transplantezi": "transplanta",
    "transplantarea": "transplantare",
    "transplantări": "transplantare",
    "transplantării": "transplantare",
    "transplantările": "transplantare",
    "transplantata": "transplantat",
    "transplantată": "transplantat",
    "transplantate": "transplantat",
    "transplantatei": "transplantat",
    "transplantatele": "transplantat",
    "transplantatelor": "transplantat",
    "transplantați": "transplantat",
    "transplantații": "transplantat",
    "transplantaților": "transplantat",
    "transplantatul": "transplantat",
    "transplantatului": "transplantat",
    "transportul": "transport",
    "transportule": "transport",
    "transportului": "transport",
    "transporturi": "transport",
    "transporturile": "transport",
    "transporturilor": "transport",
    "nemaitransportând": "transporta",
    "nemaitransportându": "transporta",
    "netransportând": "transporta",
    "netransportându": "transporta",
    "transport": "transporta",
    "transportă": "transporta",
    "transportai": "transporta",
    "transportam": "transporta",
    "transportăm": "transporta",
    "transportând": "transporta",
    "transportându": "transporta",
    "transportară": "transporta",
    "transportarăm": "transporta",
    "transportarăți": "transporta",
    "transportase": "transporta",
    "transportasem": "transporta",
    "transportaseră": "transporta",
    "transportaserăm": "transporta",
    "transportaserăți": "transporta",
    "transportaseși": "transporta",
    "transportași": "transporta",
    "transportat": "transporta",
    "transportați": "transporta",
    "transportatu": "transporta",
    "transportau": "transporta",
    "transporte": "transporta",
    "transporți": "transporta",
    "transportarea": "transportare",
    "transportareo": "transportare",
    "transportări": "transportare",
    "transportării": "transportare",
    "transportările": "transportare",
    "transportărilor": "transportare",
    "transportata": "transportat",
    "transportată": "transportat",
    "transportate": "transportat",
    "transportatei": "transportat",
    "transportatele": "transportat",
    "transportatelor": "transportat",
    "transportați": "transportat",
    "transportații": "transportat",
    "transportaților": "transportat",
    "transportato": "transportat",
    "transportatul": "transportat",
    "transportatule": "transportat",
    "transportatului": "transportat",
    "transportatori": "transportator",
    "transportatorii": "transportator",
    "transportatorilor": "transportator",
    "transportatorul": "transportator",
    "transportatorului": "transportator",
    "TAROM": "Transporturi_Aeriene_Române",
    "nemaitranspunând": "transpune",
    "nemaitranspunându": "transpune",
    "netranspunând": "transpune",
    "netranspunându": "transpune",
    "transpui": "transpune",
    "transpun": "transpune",
    "transpună": "transpune",
    "transpunând": "transpune",
    "transpunându": "transpune",
    "transpunea": "transpune",
    "transpuneai": "transpune",
    "transpuneam": "transpune",
    "transpuneați": "transpune",
    "transpuneau": "transpune",
    "transpunem": "transpune",
    "transpuneți": "transpune",
    "transpus": "transpune",
    "transpuse": "transpune",
    "transpusei": "transpune",
    "transpuseră": "transpune",
    "transpuserăm": "transpune",
    "transpuserăți": "transpune",
    "transpusese": "transpune",
    "transpusesem": "transpune",
    "transpuseseră": "transpune",
    "transpuseserăm": "transpune",
    "transpuseserăți": "transpune",
    "transpuseseși": "transpune",
    "transpuseși": "transpune",
    "transpusu": "transpune",
    "transpunerea": "transpunere",
    "transpuneri": "transpunere",
    "transpunerii": "transpunere",
    "transpunerile": "transpunere",
    "transpusa": "transpus",
    "transpusă": "transpus",
    "transpuse": "transpus",
    "transpusei": "transpus",
    "transpusele": "transpus",
    "transpuselor": "transpus",
    "transpuși": "transpus",
    "transpușii": "transpus",
    "transpușilor": "transpus",
    "transpusul": "transpus",
    "transpusului": "transpus",
    "nemaitransvazând": "transvaza",
    "nemaitransvazându": "transvaza",
    "netransvazând": "transvaza",
    "netransvazându": "transvaza",
    "transvază": "transvaza",
    "transvazai": "transvaza",
    "transvazam": "transvaza",
    "transvazăm": "transvaza",
    "transvazând": "transvaza",
    "transvazându": "transvaza",
    "transvazară": "transvaza",
    "transvazarăm": "transvaza",
    "transvazarăți": "transvaza",
    "transvazase": "transvaza",
    "transvazasem": "transvaza",
    "transvazaseră": "transvaza",
    "transvazaserăm": "transvaza",
    "transvazaserăți": "transvaza",
    "transvazaseși": "transvaza",
    "transvazași": "transvaza",
    "transvazat": "transvaza",
    "transvazați": "transvaza",
    "transvazatu": "transvaza",
    "transvazau": "transvaza",
    "transvazează": "transvaza",
    "transvazez": "transvaza",
    "transvazeze": "transvaza",
    "transvazezi": "transvaza",
    "transvazarea": "transvazare",
    "transvazări": "transvazare",
    "transvazării": "transvazare",
    "transvazările": "transvazare",
    "transvazata": "transvazat",
    "transvazată": "transvazat",
    "transvazate": "transvazat",
    "transvazatei": "transvazat",
    "transvazatele": "transvazat",
    "transvazatelor": "transvazat",
    "transvazați": "transvazat",
    "transvazații": "transvazat",
    "transvazaților": "transvazat",
    "transvazatul": "transvazat",
    "transvazatului": "transvazat",
    "transversala": "transversal",
    "transversală": "transversal",
    "transversale": "transversal",
    "transversalei": "transversal",
    "transversalele": "transversal",
    "transversalelor": "transversal",
    "transversali": "transversal",
    "transversalii": "transversal",
    "transversalilor": "transversal",
    "transversalul": "transversal",
    "transversalului": "transversal",
    "trânta": "trântă",
    "trânte": "trântă",
    "trântei": "trântă",
    "trântele": "trântă",
    "trântelor": "trântă",
    "nemaitrântind": "trânti",
    "nemaitrântindu": "trânti",
    "netrântind": "trânti",
    "netrântindu": "trânti",
    "trântea": "trânti",
    "trânteai": "trânti",
    "trânteam": "trânti",
    "trântească": "trânti",
    "trânteați": "trânti",
    "trânteau": "trânti",
    "trântesc": "trânti",
    "trântește": "trânti",
    "trântești": "trânti",
    "trântii": "trânti",
    "trântim": "trânti",
    "trântind": "trânti",
    "trântindu": "trânti",
    "trântiră": "trânti",
    "trântirăm": "trânti",
    "trântirăți": "trânti",
    "trântise": "trânti",
    "trântisem": "trânti",
    "trântiseră": "trânti",
    "trântiserăm": "trânti",
    "trântiserăți": "trânti",
    "trântiseși": "trânti",
    "trântiși": "trânti",
    "trântit": "trânti",
    "trântiți": "trânti",
    "trântitu": "trânti",
    "trântirea": "trântire",
    "trântireo": "trântire",
    "trântiri": "trântire",
    "trântirii": "trântire",
    "trântirile": "trântire",
    "trântirilor": "trântire",
    "trântita": "trântit",
    "trântită": "trântit",
    "trântite": "trântit",
    "trântitei": "trântit",
    "trântitele": "trântit",
    "trântitelor": "trântit",
    "trântiți": "trântit",
    "trântiții": "trântit",
    "trântiților": "trântit",
    "trântito": "trântit",
    "trântitul": "trântit",
    "trântitule": "trântit",
    "trântitului": "trântit",
    "trântori": "trântor",
    "trântorii": "trântor",
    "trântorilor": "trântor",
    "trântorul": "trântor",
    "trântorului": "trântor",
    "tranzacția": "tranzacție",
    "tranzacției": "tranzacție",
    "tranzacții": "tranzacție",
    "tranzacțiile": "tranzacție",
    "tranzacțiilor": "tranzacție",
    "tranzacționă": "tranzacționa",
    "tranzacționai": "tranzacționa",
    "tranzacționam": "tranzacționa",
    "tranzacționăm": "tranzacționa",
    "tranzacționând": "tranzacționa",
    "tranzacționându": "tranzacționa",
    "tranzacționară": "tranzacționa",
    "tranzacționarăm": "tranzacționa",
    "tranzacționarăți": "tranzacționa",
    "tranzacționase": "tranzacționa",
    "tranzacționasem": "tranzacționa",
    "tranzacționaseră": "tranzacționa",
    "tranzacționaserăm": "tranzacționa",
    "tranzacționaserăți": "tranzacționa",
    "tranzacționaseși": "tranzacționa",
    "tranzacționași": "tranzacționa",
    "tranzacționat": "tranzacționa",
    "tranzacționați": "tranzacționa",
    "tranzacționatu": "tranzacționa",
    "tranzacționau": "tranzacționa",
    "tranzacționează": "tranzacționa",
    "tranzacționez": "tranzacționa",
    "tranzacționeze": "tranzacționa",
    "tranzacționezi": "tranzacționa",
    "tranzacționarea": "tranzacționare",
    "tranzacționări": "tranzacționare",
    "tranzacționării": "tranzacționare",
    "tranzacționările": "tranzacționare",
    "tranzacționata": "tranzacționat",
    "tranzacționată": "tranzacționat",
    "tranzacționate": "tranzacționat",
    "tranzacționatei": "tranzacționat",
    "tranzacționatele": "tranzacționat",
    "tranzacționatelor": "tranzacționat",
    "tranzacționați": "tranzacționat",
    "tranzacționații": "tranzacționat",
    "tranzacționaților": "tranzacționat",
    "tranzacționatul": "tranzacționat",
    "tranzacționatului": "tranzacționat",
    "tranzistoare": "tranzistor",
    "tranzistoarele": "tranzistor",
    "tranzistoarelor": "tranzistor",
    "tranzistorul": "tranzistor",
    "tranzistorului": "tranzistor",
    "tranzitul": "tranzit",
    "tranzitului": "tranzit",
    "tranzituri": "tranzit",
    "tranziturile": "tranzit",
    "tranziturilor": "tranzit",
    "tranziția": "tranziție",
    "tranziției": "tranziție",
    "tranziții": "tranziție",
    "tranzițiile": "tranziție",
    "tranzițiilor": "tranziție",
    "tranz.": "tranzitiv",
    "tranzitiva": "tranzitiv",
    "tranzitivă": "tranzitiv",
    "tranzitive": "tranzitiv",
    "tranzitivei": "tranzitiv",
    "tranzitivele": "tranzitiv",
    "tranzitivelor": "tranzitiv",
    "tranzitivi": "tranzitiv",
    "tranzitivii": "tranzitiv",
    "tranzitivilor": "tranzitiv",
    "tranzitivul": "tranzitiv",
    "tranzitivului": "tranzitiv",
    "tranzitoria": "tranzitoriu",
    "tranzitorie": "tranzitoriu",
    "tranzitoriei": "tranzitoriu",
    "tranzitorii": "tranzitoriu",
    "tranzitoriii": "tranzitoriu",
    "tranzitoriile": "tranzitoriu",
    "tranzitoriilor": "tranzitoriu",
    "tranzitoriul": "tranzitoriu",
    "tranzitoriului": "tranzitoriu",
    "trapa": "trapă",
    "trape": "trapă",
    "trapei": "trapă",
    "trapele": "trapă",
    "trapelor": "trapă",
    "trăpași": "trăpaș",
    "trăpașii": "trăpaș",
    "trăpașilor": "trăpaș",
    "trăpașul": "trăpaș",
    "trăpașului": "trăpaș",
    "trapeze": "trapez",
    "trapezele": "trapez",
    "trapezelor": "trapez",
    "trapezul": "trapez",
    "trapezului": "trapez",
    "trasa": "tras",
    "trasă": "tras",
    "trase": "tras",
    "trasei": "tras",
    "trasele": "tras",
    "traselor": "tras",
    "trași": "tras",
    "trașii": "tras",
    "trașilor": "tras",
    "traso": "tras",
    "trasul": "tras",
    "trasule": "tras",
    "trasului": "tras",
    "nemaitrasând": "trasa",
    "nemaitrasându": "trasa",
    "netrasând": "trasa",
    "netrasându": "trasa",
    "trasă": "trasa",
    "trasai": "trasa",
    "trasam": "trasa",
    "trasăm": "trasa",
    "trasând": "trasa",
    "trasându": "trasa",
    "trasară": "trasa",
    "trasarăm": "trasa",
    "trasarăți": "trasa",
    "trasase": "trasa",
    "trasasem": "trasa",
    "trasaseră": "trasa",
    "trasaserăm": "trasa",
    "trasaserăți": "trasa",
    "trasaseși": "trasa",
    "trasași": "trasa",
    "trasat": "trasa",
    "trasați": "trasa",
    "trasatu": "trasa",
    "trasau": "trasa",
    "trasează": "trasa",
    "trasez": "trasa",
    "traseze": "trasa",
    "trasezi": "trasa",
    "trasarea": "trasare",
    "trasări": "trasare",
    "trasării": "trasare",
    "trasările": "trasare",
    "trasata": "trasat",
    "trasată": "trasat",
    "trasate": "trasat",
    "trasatei": "trasat",
    "trasatele": "trasat",
    "trasatelor": "trasat",
    "trasați": "trasat",
    "trasații": "trasat",
    "trasaților": "trasat",
    "trasatul": "trasat",
    "trasatului": "trasat",
    "trăsătura": "trăsătură",
    "trăsături": "trăsătură",
    "trăsăturii": "trăsătură",
    "trăsăturile": "trăsătură",
    "trăsăturilor": "trăsătură",
    "trasee": "traseu",
    "traseele": "traseu",
    "traseelor": "traseu",
    "traseul": "traseu",
    "traseului": "traseu",
    "trăsnăi": "trăsnaie",
    "trăsnaia": "trăsnaie",
    "trăsnăii": "trăsnaie",
    "trăsnăile": "trăsnaie",
    "trăsnăilor": "trăsnaie",
    "trăsnete": "trăsnet",
    "trăsnetele": "trăsnet",
    "trăsnetelor": "trăsnet",
    "trăsnetul": "trăsnet",
    "trăsnetului": "trăsnet",
    "trăsnirea": "trăsnire",
    "trăsniri": "trăsnire",
    "trăsnirii": "trăsnire",
    "trăsnirile": "trăsnire",
    "trăsnirilor": "trăsnire",
    "trăsnita": "trăsnit",
    "trăsnită": "trăsnit",
    "trăsnite": "trăsnit",
    "trăsnitei": "trăsnit",
    "trăsnitele": "trăsnit",
    "trăsnitelor": "trăsnit",
    "trăsniți": "trăsnit",
    "trăsniții": "trăsnit",
    "trăsniților": "trăsnit",
    "trăsnitul": "trăsnit",
    "trăsnitule": "trăsnit",
    "trăsnitului": "trăsnit",
    "trăsnita": "trăsnită",
    "trăsnite": "trăsnită",
    "trăsnitei": "trăsnită",
    "trăsnitele": "trăsnită",
    "trăsnitelor": "trăsnită",
    "trăsnito": "trăsnită",
    "trasoare": "trasor",
    "trasoarele": "trasor",
    "trasoarelor": "trasor",
    "trasorul": "trasor",
    "trasorului": "trasor",
    "trăsura": "trăsură",
    "trăsuri": "trăsură",
    "trăsurii": "trăsură",
    "trăsurile": "trăsură",
    "trăsurilor": "trăsură",
    "trăsuro": "trăsură",
    "nemaitratând": "trata",
    "nemaitratându": "trata",
    "netratând": "trata",
    "netratându": "trata",
    "trată": "trata",
    "tratai": "trata",
    "tratam": "trata",
    "tratăm": "trata",
    "tratând": "trata",
    "tratându": "trata",
    "tratară": "trata",
    "tratarăm": "trata",
    "tratarăți": "trata",
    "tratase": "trata",
    "tratasem": "trata",
    "trataseră": "trata",
    "trataserăm": "trata",
    "trataserăți": "trata",
    "trataseși": "trata",
    "tratași": "trata",
    "tratat": "trata",
    "tratați": "trata",
    "tratatu": "trata",
    "tratau": "trata",
    "tratează": "trata",
    "tratez": "trata",
    "trateze": "trata",
    "tratezi": "trata",
    "tratamente": "tratament",
    "tratamentele": "tratament",
    "tratamentelor": "tratament",
    "tratamentul": "tratament",
    "tratamentului": "tratament",
    "tratarea": "tratare",
    "tratări": "tratare",
    "tratării": "tratare",
    "tratările": "tratare",
    "tratata": "tratat",
    "tratată": "tratat",
    "tratate": "tratat",
    "tratatei": "tratat",
    "tratatele": "tratat",
    "tratatelor": "tratat",
    "tratați": "tratat",
    "tratații": "tratat",
    "trataților": "tratat",
    "tratatul": "tratat",
    "tratatului": "tratat",
    "tratația": "tratație",
    "tratației": "tratație",
    "tratații": "tratație",
    "tratațiile": "tratație",
    "tratațiilor": "tratație",
    "tratativele": "tratative",
    "tratativelor": "tratative",
    "traule": "traul",
    "traulele": "traul",
    "traulelor": "traul",
    "traulul": "traul",
    "traulului": "traul",
    "traulere": "trauler",
    "traulerele": "trauler",
    "traulerelor": "trauler",
    "traulerul": "trauler",
    "traulerului": "trauler",
    "trauma": "traumă",
    "traume": "traumă",
    "traumei": "traumă",
    "traumele": "traumă",
    "traumelor": "traumă",
    "traumatisme": "traumatism",
    "traumatismele": "traumatism",
    "traumatismelor": "traumatism",
    "traumatismul": "traumatism",
    "traumatismului": "traumatism",
    "nemaitraumatizând": "traumatiza",
    "nemaitraumatizându": "traumatiza",
    "netraumatizând": "traumatiza",
    "netraumatizându": "traumatiza",
    "traumatiză": "traumatiza",
    "traumatizai": "traumatiza",
    "traumatizam": "traumatiza",
    "traumatizăm": "traumatiza",
    "traumatizând": "traumatiza",
    "traumatizându": "traumatiza",
    "traumatizară": "traumatiza",
    "traumatizarăm": "traumatiza",
    "traumatizarăți": "traumatiza",
    "traumatizase": "traumatiza",
    "traumatizasem": "traumatiza",
    "traumatizaseră": "traumatiza",
    "traumatizaserăm": "traumatiza",
    "traumatizaserăți": "traumatiza",
    "traumatizaseși": "traumatiza",
    "traumatizași": "traumatiza",
    "traumatizat": "traumatiza",
    "traumatizați": "traumatiza",
    "traumatizatu": "traumatiza",
    "traumatizau": "traumatiza",
    "traumatizează": "traumatiza",
    "traumatizez": "traumatiza",
    "traumatizeze": "traumatiza",
    "traumatizezi": "traumatiza",
    "traumatizanta": "traumatizant",
    "traumatizantă": "traumatizant",
    "traumatizante": "traumatizant",
    "traumatizantei": "traumatizant",
    "traumatizantele": "traumatizant",
    "traumatizantelor": "traumatizant",
    "traumatizanți": "traumatizant",
    "traumatizanții": "traumatizant",
    "traumatizanților": "traumatizant",
    "traumatizantul": "traumatizant",
    "traumatizantului": "traumatizant",
    "traumatizarea": "traumatizare",
    "traumatizări": "traumatizare",
    "traumatizării": "traumatizare",
    "traumatizările": "traumatizare",
    "traumatizata": "traumatizat",
    "traumatizată": "traumatizat",
    "traumatizate": "traumatizat",
    "traumatizatei": "traumatizat",
    "traumatizatele": "traumatizat",
    "traumatizatelor": "traumatizat",
    "traumatizați": "traumatizat",
    "traumatizații": "traumatizat",
    "traumatizaților": "traumatizat",
    "traumatizatul": "traumatizat",
    "traumatizatului": "traumatizat",
    "traumatizata": "traumatizată",
    "traumatizate": "traumatizată",
    "traumatizatei": "traumatizată",
    "traumatizatele": "traumatizată",
    "traumatizatelor": "traumatizată",
    "travalii": "travaliu",
    "travaliile": "travaliu",
    "travaliilor": "travaliu",
    "travaliul": "travaliu",
    "travaliului": "travaliu",
    "nemaitraversând": "traversa",
    "nemaitraversându": "traversa",
    "netraversând": "traversa",
    "netraversându": "traversa",
    "traversă": "traversa",
    "traversai": "traversa",
    "traversam": "traversa",
    "traversăm": "traversa",
    "traversând": "traversa",
    "traversându": "traversa",
    "traversară": "traversa",
    "traversarăm": "traversa",
    "traversarăți": "traversa",
    "traversase": "traversa",
    "traversasem": "traversa",
    "traversaseră": "traversa",
    "traversaserăm": "traversa",
    "traversaserăți": "traversa",
    "traversaseși": "traversa",
    "traversași": "traversa",
    "traversat": "traversa",
    "traversați": "traversa",
    "traversatu": "traversa",
    "traversau": "traversa",
    "traversează": "traversa",
    "traversez": "traversa",
    "traverseze": "traversa",
    "traversezi": "traversa",
    "traversa": "traversă",
    "traverse": "traversă",
    "traversei": "traversă",
    "traversele": "traversă",
    "traverselor": "traversă",
    "traversarea": "traversare",
    "traversări": "traversare",
    "traversării": "traversare",
    "traversările": "traversare",
    "traversata": "traversat",
    "traversată": "traversat",
    "traversate": "traversat",
    "traversatei": "traversat",
    "traversatele": "traversat",
    "traversatelor": "traversat",
    "traversați": "traversat",
    "traversații": "traversat",
    "traversaților": "traversat",
    "traversatul": "traversat",
    "traversatului": "traversat",
    "nemaitravestind": "travesti",
    "nemaitravestindu": "travesti",
    "netravestind": "travesti",
    "netravestindu": "travesti",
    "travestea": "travesti",
    "travesteai": "travesti",
    "travesteam": "travesti",
    "travestească": "travesti",
    "travesteați": "travesti",
    "travesteau": "travesti",
    "travestesc": "travesti",
    "travestește": "travesti",
    "travestești": "travesti",
    "travestii": "travesti",
    "travestim": "travesti",
    "travestind": "travesti",
    "travestindu": "travesti",
    "travestiră": "travesti",
    "travestirăm": "travesti",
    "travestirăți": "travesti",
    "travestise": "travesti",
    "travestisem": "travesti",
    "travestiseră": "travesti",
    "travestiserăm": "travesti",
    "travestiserăți": "travesti",
    "travestiseși": "travesti",
    "travestiși": "travesti",
    "travestit": "travesti",
    "travestiți": "travesti",
    "travestitu": "travesti",
    "travestiul": "travesti",
    "travestiului": "travesti",
    "travestiuri": "travesti",
    "travestiurile": "travesti",
    "travestiurilor": "travesti",
    "travestirea": "travestire",
    "travestiri": "travestire",
    "travestirii": "travestire",
    "travestirile": "travestire",
    "travestita": "travestit",
    "travestită": "travestit",
    "travestite": "travestit",
    "travestitei": "travestit",
    "travestitele": "travestit",
    "travestitelor": "travestit",
    "travestiți": "travestit",
    "travestiții": "travestit",
    "travestiților": "travestit",
    "travestitul": "travestit",
    "travestitului": "travestit",
    "treaba": "treabă",
    "treabo": "treabă",
    "trebii": "treabă",
    "treburi": "treabă",
    "treburile": "treabă",
    "treburilor": "treabă",
    "treapădul": "treapăd",
    "treapădului": "treapăd",
    "treapta": "treaptă",
    "treapto": "treaptă",
    "trepte": "treaptă",
    "treptei": "treaptă",
    "treptele": "treaptă",
    "treptelor": "treaptă",
    "treascul": "treasc",
    "treascului": "treasc",
    "treascuri": "treasc",
    "treascurile": "treasc",
    "treascurilor": "treasc",
    "treaza": "treaz",
    "trează": "treaz",
    "treazo": "treaz",
    "treazul": "treaz",
    "treazule": "treaz",
    "treazului": "treaz",
    "treji": "treaz",
    "trejii": "treaz",
    "trejilor": "treaz",
    "treze": "treaz",
    "trezei": "treaz",
    "trezele": "treaz",
    "trezelor": "treaz",
    "tre'": "trebui",
    "trebuia": "trebui",
    "trebuiască": "trebui",
    "trebuiau": "trebui",
    "trebuie": "trebui",
    "trebuind": "trebui",
    "trebuindu": "trebui",
    "trebuiră": "trebui",
    "trebuirăm": "trebui",
    "trebuirăți": "trebui",
    "trebuise": "trebui",
    "trebuisem": "trebui",
    "trebuiseră": "trebui",
    "trebuiserăm": "trebui",
    "trebuiserăți": "trebui",
    "trebuiseși": "trebui",
    "trebuit": "trebui",
    "trebuitu": "trebui",
    "trebuincioasa": "trebuincios",
    "trebuincioasă": "trebuincios",
    "trebuincioase": "trebuincios",
    "trebuincioasei": "trebuincios",
    "trebuincioasele": "trebuincios",
    "trebuincioaselor": "trebuincios",
    "trebuincioși": "trebuincios",
    "trebuincioșii": "trebuincios",
    "trebuincioșilor": "trebuincios",
    "trebuinciosul": "trebuincios",
    "trebuinciosului": "trebuincios",
    "trebuința": "trebuință",
    "trebuințe": "trebuință",
    "trebuinței": "trebuință",
    "trebuințele": "trebuință",
    "trebuințelor": "trebuință",
    "trebuită": "trebuit",
    "trebuite": "trebuit",
    "trecătoarea": "trecătoare",
    "trecătoarei": "trecătoare",
    "trecătoarele": "trecătoare",
    "trecătoarelor": "trecătoare",
    "trecătoare": "trecător",
    "trecătoarea": "trecător",
    "trecătoarei": "trecător",
    "trecătoarele": "trecător",
    "trecătoarelor": "trecător",
    "trecători": "trecător",
    "trecătorii": "trecător",
    "trecătorilor": "trecător",
    "trecătorul": "trecător",
    "trecătorului": "trecător",
    "nemaitrecând": "trece",
    "nemaitrecându": "trece",
    "netrecând": "trece",
    "netrecându": "trece",
    "treacă": "trece",
    "trec": "trece",
    "trecând": "trece",
    "trecându": "trece",
    "trecea": "trece",
    "treceai": "trece",
    "treceam": "trece",
    "treceați": "trece",
    "treceau": "trece",
    "trecem": "trece",
    "treceți": "trece",
    "treci": "trece",
    "trecu": "trece",
    "trecu'": "trece",
    "trecui": "trece",
    "trecură": "trece",
    "trecurăm": "trece",
    "trecurăți": "trece",
    "trecuse": "trece",
    "trecusem": "trece",
    "trecuseră": "trece",
    "trecuserăm": "trece",
    "trecuserăți": "trece",
    "trecuseși": "trece",
    "trecuși": "trece",
    "trecut": "trece",
    "trecutu": "trece",
    "trecerea": "trecere",
    "treceri": "trecere",
    "trecerii": "trecere",
    "trecerile": "trecere",
    "trecu'": "trecut",
    "trecuta": "trecut",
    "trecută": "trecut",
    "trecute": "trecut",
    "trecutei": "trecut",
    "trecutele": "trecut",
    "trecutelor": "trecut",
    "trecuți": "trecut",
    "trecuții": "trecut",
    "trecuților": "trecut",
    "trecutul": "trecut",
    "trecutului": "trecut",
    "trecuta": "trecută",
    "trecute": "trecută",
    "trecutei": "trecută",
    "trecutele": "trecută",
    "trecutelor": "trecută",
    "nemaitrefilând": "trefila",
    "nemaitrefilându": "trefila",
    "netrefilând": "trefila",
    "netrefilându": "trefila",
    "trefilă": "trefila",
    "trefilai": "trefila",
    "trefilam": "trefila",
    "trefilăm": "trefila",
    "trefilând": "trefila",
    "trefilându": "trefila",
    "trefilară": "trefila",
    "trefilarăm": "trefila",
    "trefilarăți": "trefila",
    "trefilase": "trefila",
    "trefilasem": "trefila",
    "trefilaseră": "trefila",
    "trefilaserăm": "trefila",
    "trefilaserăți": "trefila",
    "trefilaseși": "trefila",
    "trefilași": "trefila",
    "trefilat": "trefila",
    "trefilați": "trefila",
    "trefilatu": "trefila",
    "trefilau": "trefila",
    "trefilează": "trefila",
    "trefilez": "trefila",
    "trefileze": "trefila",
    "trefilezi": "trefila",
    "trefilarea": "trefilare",
    "trefilări": "trefilare",
    "trefilării": "trefilare",
    "trefilările": "trefilare",
    "trefilata": "trefilat",
    "trefilată": "trefilat",
    "trefilate": "trefilat",
    "trefilatei": "trefilat",
    "trefilatele": "trefilat",
    "trefilatelor": "trefilat",
    "trefilați": "trefilat",
    "trefilații": "trefilat",
    "trefilaților": "trefilat",
    "trefilatul": "trefilat",
    "trefilatului": "trefilat",
    "III": "trei",
    "treia": "trei",
    "treilea": "trei",
    "treiul": "trei",
    "treiului": "trei",
    "nemaitreierând": "treiera",
    "nemaitreierându": "treiera",
    "netreierând": "treiera",
    "netreierându": "treiera",
    "treier": "treiera",
    "treieră": "treiera",
    "treierai": "treiera",
    "treieram": "treiera",
    "treierăm": "treiera",
    "treierând": "treiera",
    "treierându": "treiera",
    "treierară": "treiera",
    "treierarăm": "treiera",
    "treierarăți": "treiera",
    "treierase": "treiera",
    "treierasem": "treiera",
    "treieraseră": "treiera",
    "treieraserăm": "treiera",
    "treieraserăți": "treiera",
    "treieraseși": "treiera",
    "treierași": "treiera",
    "treierat": "treiera",
    "treierați": "treiera",
    "treieratu": "treiera",
    "treierau": "treiera",
    "treiere": "treiera",
    "treieri": "treiera",
    "treierarea": "treierare",
    "treierări": "treierare",
    "treierării": "treierare",
    "treierările": "treierare",
    "treierata": "treierat",
    "treierată": "treierat",
    "treierate": "treierat",
    "treieratei": "treierat",
    "treieratele": "treierat",
    "treieratelor": "treierat",
    "treierați": "treierat",
    "treierații": "treierat",
    "treieraților": "treierat",
    "treieratul": "treierat",
    "treieratului": "treierat",
    "treierișul": "treieriș",
    "treierișului": "treieriș",
    "treierișuri": "treieriș",
    "treierișurile": "treieriș",
    "treierișurilor": "treieriș",
    "treimea": "treime",
    "treimi": "treime",
    "treimii": "treime",
    "treimile": "treime",
    "treimilor": "treime",
    "treișpe": "treisprezece",
    "treișpea": "treisprezece",
    "treișpelea": "treisprezece",
    "treisprezecea": "treisprezece",
    "treisprezecelea": "treisprezece",
    "XIII": "treisprezece",
    "treisprezecimea": "treisprezecime",
    "treisprezecimi": "treisprezecime",
    "treisprezecimii": "treisprezecime",
    "treisprezecimile": "treisprezecime",
    "treisprezecimilor": "treisprezecime",
    "treizecea": "treizeci",
    "treizecilea": "treizeci",
    "XXX": "treizeci",
    "trema": "tremă",
    "treme": "tremă",
    "tremei": "tremă",
    "tremele": "tremă",
    "tremelor": "tremă",
    "tremurul": "tremur",
    "tremurului": "tremur",
    "nemaitremurând": "tremura",
    "nemaitremurându": "tremura",
    "netremurând": "tremura",
    "netremurându": "tremura",
    "tremur": "tremura",
    "tremură": "tremura",
    "tremurai": "tremura",
    "tremuram": "tremura",
    "tremurăm": "tremura",
    "tremurând": "tremura",
    "tremurându": "tremura",
    "tremurară": "tremura",
    "tremurarăm": "tremura",
    "tremurarăți": "tremura",
    "tremurase": "tremura",
    "tremurasem": "tremura",
    "tremuraseră": "tremura",
    "tremuraserăm": "tremura",
    "tremuraserăți": "tremura",
    "tremuraseși": "tremura",
    "tremurași": "tremura",
    "tremurat": "tremura",
    "tremurați": "tremura",
    "tremuratu": "tremura",
    "tremurau": "tremura",
    "tremure": "tremura",
    "tremuri": "tremura",
    "tremurarea": "tremurare",
    "tremurareo": "tremurare",
    "tremurări": "tremurare",
    "tremurării": "tremurare",
    "tremurările": "tremurare",
    "tremurărilor": "tremurare",
    "tremurata": "tremurat",
    "tremurată": "tremurat",
    "tremurate": "tremurat",
    "tremuratei": "tremurat",
    "tremuratele": "tremurat",
    "tremuratelor": "tremurat",
    "tremurați": "tremurat",
    "tremurații": "tremurat",
    "tremuraților": "tremurat",
    "tremurato": "tremurat",
    "tremuratul": "tremurat",
    "tremuratule": "tremurat",
    "tremuratului": "tremurat",
    "tremurata": "tremurată",
    "tremurate": "tremurată",
    "tremuratei": "tremurată",
    "tremuratele": "tremurată",
    "tremuratelor": "tremurată",
    "tremurato": "tremurată",
    "tremurătoarea": "tremurătoare",
    "tremurători": "tremurătoare",
    "tremurătorii": "tremurătoare",
    "tremurătorile": "tremurătoare",
    "tremurătorilor": "tremurătoare",
    "tremurătoare": "tremurător",
    "tremurătoarea": "tremurător",
    "tremurătoarei": "tremurător",
    "tremurătoarele": "tremurător",
    "tremurătoarelor": "tremurător",
    "tremurătoareo": "tremurător",
    "tremurători": "tremurător",
    "tremurătorii": "tremurător",
    "tremurătorilor": "tremurător",
    "tremurătorul": "tremurător",
    "tremurătorule": "tremurător",
    "tremurătorului": "tremurător",
    "tremuricii": "tremurici",
    "tremuricilor": "tremurici",
    "tremuriciul": "tremurici",
    "tremuriciule": "tremurici",
    "tremuriciului": "tremurici",
    "trenul": "tren",
    "trenule": "tren",
    "trenului": "tren",
    "trenuri": "tren",
    "trenurile": "tren",
    "trenurilor": "tren",
    "nemaitrenând": "trena",
    "nemaitrenându": "trena",
    "netrenând": "trena",
    "netrenându": "trena",
    "trenă": "trena",
    "trenai": "trena",
    "trenam": "trena",
    "trenăm": "trena",
    "trenând": "trena",
    "trenându": "trena",
    "trenară": "trena",
    "trenarăm": "trena",
    "trenarăți": "trena",
    "trenase": "trena",
    "trenasem": "trena",
    "trenaseră": "trena",
    "trenaserăm": "trena",
    "trenaserăți": "trena",
    "trenaseși": "trena",
    "trenași": "trena",
    "trenat": "trena",
    "trenați": "trena",
    "trenatu": "trena",
    "trenau": "trena",
    "trenează": "trena",
    "trenez": "trena",
    "treneze": "trena",
    "trenezi": "trena",
    "trena": "trenă",
    "trene": "trenă",
    "trenei": "trenă",
    "trenele": "trenă",
    "trenelor": "trenă",
    "trenarea": "trenare",
    "trenări": "trenare",
    "trenării": "trenare",
    "trenările": "trenare",
    "trenata": "trenat",
    "trenată": "trenat",
    "trenate": "trenat",
    "trenatei": "trenat",
    "trenatele": "trenat",
    "trenatelor": "trenat",
    "trenați": "trenat",
    "trenații": "trenat",
    "trenaților": "trenat",
    "trenatul": "trenat",
    "trenatului": "trenat",
    "nemaitrepădând": "trepăda",
    "nemaitrepădându": "trepăda",
    "netrepădând": "trepăda",
    "netrepădându": "trepăda",
    "treapădă": "trepăda",
    "trepăd": "trepăda",
    "trepădă": "trepăda",
    "trepădai": "trepăda",
    "trepădam": "trepăda",
    "trepădăm": "trepăda",
    "trepădând": "trepăda",
    "trepădându": "trepăda",
    "trepădară": "trepăda",
    "trepădarăm": "trepăda",
    "trepădarăți": "trepăda",
    "trepădase": "trepăda",
    "trepădasem": "trepăda",
    "trepădaseră": "trepăda",
    "trepădaserăm": "trepăda",
    "trepădaserăți": "trepăda",
    "trepădaseși": "trepăda",
    "trepădași": "trepăda",
    "trepădat": "trepăda",
    "trepădați": "trepăda",
    "trepădatu": "trepăda",
    "trepădau": "trepăda",
    "trepede": "trepăda",
    "trepezi": "trepăda",
    "trepădarea": "trepădare",
    "trepădări": "trepădare",
    "trepădării": "trepădare",
    "trepădările": "trepădare",
    "trepădata": "trepădat",
    "trepădată": "trepădat",
    "trepădate": "trepădat",
    "trepădatei": "trepădat",
    "trepădatele": "trepădat",
    "trepădatelor": "trepădat",
    "trepădați": "trepădat",
    "trepădații": "trepădat",
    "trepădaților": "trepădat",
    "trepădatul": "trepădat",
    "trepădatului": "trepădat",
    "trepăduși": "trepăduș",
    "trepădușii": "trepăduș",
    "trepădușilor": "trepăduș",
    "trepădușul": "trepăduș",
    "trepădușului": "trepăduș",
    "trepiede": "trepied",
    "trepiedele": "trepied",
    "trepiedelor": "trepied",
    "trepiedul": "trepied",
    "trepiedule": "trepied",
    "trepiedului": "trepied",
    "treptata": "treptat",
    "treptată": "treptat",
    "treptate": "treptat",
    "treptatei": "treptat",
    "treptatele": "treptat",
    "treptatelor": "treptat",
    "treptați": "treptat",
    "treptații": "treptat",
    "treptaților": "treptat",
    "treptato": "treptat",
    "treptatul": "treptat",
    "treptatule": "treptat",
    "treptatului": "treptat",
    "tresa": "tresă",
    "trese": "tresă",
    "tresei": "tresă",
    "tresele": "tresă",
    "treselor": "tresă",
    "nemaitresăltând": "tresălta",
    "nemaitresăltându": "tresălta",
    "netresăltând": "tresălta",
    "netresăltându": "tresălta",
    "tresalt": "tresălta",
    "tresaltă": "tresălta",
    "tresăltă": "tresălta",
    "tresăltai": "tresălta",
    "tresăltam": "tresălta",
    "tresăltăm": "tresălta",
    "tresăltând": "tresălta",
    "tresăltându": "tresălta",
    "tresăltară": "tresălta",
    "tresăltarăm": "tresălta",
    "tresăltarăți": "tresălta",
    "tresăltase": "tresălta",
    "tresăltasem": "tresălta",
    "tresăltaseră": "tresălta",
    "tresăltaserăm": "tresălta",
    "tresăltaserăți": "tresălta",
    "tresăltaseși": "tresălta",
    "tresăltași": "tresălta",
    "tresăltat": "tresălta",
    "tresăltați": "tresălta",
    "tresăltatu": "tresălta",
    "tresăltau": "tresălta",
    "tresalte": "tresălta",
    "tresalți": "tresălta",
    "tresăltata": "tresăltat",
    "tresăltată": "tresăltat",
    "tresăltate": "tresăltat",
    "tresăltatei": "tresăltat",
    "tresăltatele": "tresăltat",
    "tresăltatelor": "tresăltat",
    "tresăltați": "tresăltat",
    "tresăltații": "tresăltat",
    "tresăltaților": "tresăltat",
    "tresăltatul": "tresăltat",
    "tresăltatului": "tresăltat",
    "nemaitresărind": "tresări",
    "nemaitresărindu": "tresări",
    "netresărind": "tresări",
    "netresărindu": "tresări",
    "tresar": "tresări",
    "tresară": "tresări",
    "tresare": "tresări",
    "tresărea": "tresări",
    "tresăreai": "tresări",
    "tresăream": "tresări",
    "tresăreați": "tresări",
    "tresăreau": "tresări",
    "tresari": "tresări",
    "tresării": "tresări",
    "tresărim": "tresări",
    "tresărind": "tresări",
    "tresărindu": "tresări",
    "tresăriră": "tresări",
    "tresărirăm": "tresări",
    "tresărirăți": "tresări",
    "tresărise": "tresări",
    "tresărisem": "tresări",
    "tresăriseră": "tresări",
    "tresăriserăm": "tresări",
    "tresăriserăți": "tresări",
    "tresăriseși": "tresări",
    "tresăriși": "tresări",
    "tresărit": "tresări",
    "tresăriți": "tresări",
    "tresăritu": "tresări",
    "tresărirea": "tresărire",
    "tresărireo": "tresărire",
    "tresăriri": "tresărire",
    "tresăririi": "tresărire",
    "tresăririle": "tresărire",
    "tresăririlor": "tresărire",
    "tresărita": "tresărit",
    "tresărită": "tresărit",
    "tresărite": "tresărit",
    "tresăritei": "tresărit",
    "tresăritele": "tresărit",
    "tresăritelor": "tresărit",
    "tresăriți": "tresărit",
    "tresăriții": "tresărit",
    "tresăriților": "tresărit",
    "tresărito": "tresărit",
    "tresăritul": "tresărit",
    "tresăritului": "tresărit",
    "nemaitrezind": "trezi",
    "nemaitrezindu": "trezi",
    "netrezind": "trezi",
    "netrezindu": "trezi",
    "trezea": "trezi",
    "trezeai": "trezi",
    "trezeam": "trezi",
    "trezească": "trezi",
    "trezeați": "trezi",
    "trezeau": "trezi",
    "trezesc": "trezi",
    "trezește": "trezi",
    "trezești": "trezi",
    "trezii": "trezi",
    "trezim": "trezi",
    "trezind": "trezi",
    "trezindu": "trezi",
    "treziră": "trezi",
    "trezirăm": "trezi",
    "trezirăți": "trezi",
    "trezise": "trezi",
    "trezisem": "trezi",
    "treziseră": "trezi",
    "treziserăm": "trezi",
    "treziserăți": "trezi",
    "treziseși": "trezi",
    "treziși": "trezi",
    "trezit": "trezi",
    "treziți": "trezi",
    "trezitu": "trezi",
    "trezia": "trezie",
    "treziei": "trezie",
    "trezii": "trezie",
    "treziile": "trezie",
    "treziilor": "trezie",
    "trezirea": "trezire",
    "trezireo": "trezire",
    "treziri": "trezire",
    "trezirii": "trezire",
    "trezirile": "trezire",
    "trezirilor": "trezire",
    "trezita": "trezit",
    "trezită": "trezit",
    "trezite": "trezit",
    "trezitei": "trezit",
    "trezitele": "trezit",
    "trezitelor": "trezit",
    "treziți": "trezit",
    "treziții": "trezit",
    "treziților": "trezit",
    "trezito": "trezit",
    "trezitul": "trezit",
    "trezitului": "trezit",
    "trezoreria": "trezorerie",
    "trezoreriei": "trezorerie",
    "trezorerii": "trezorerie",
    "trezoreriile": "trezorerie",
    "trezoreriilor": "trezorerie",
    "nemaitriind": "tria",
    "nemaitriindu": "tria",
    "netriind": "tria",
    "netriindu": "tria",
    "triai": "tria",
    "triam": "tria",
    "triară": "tria",
    "triarăm": "tria",
    "triarăți": "tria",
    "triase": "tria",
    "triasem": "tria",
    "triaseră": "tria",
    "triaserăm": "tria",
    "triaserăți": "tria",
    "triaseși": "tria",
    "triași": "tria",
    "triat": "tria",
    "triați": "tria",
    "triatu": "tria",
    "triau": "tria",
    "triază": "tria",
    "trie": "tria",
    "triem": "tria",
    "triez": "tria",
    "trieze": "tria",
    "triezi": "tria",
    "triind": "tria",
    "triindu": "tria",
    "triaje": "triaj",
    "triajele": "triaj",
    "triajelor": "triaj",
    "triajul": "triaj",
    "triajului": "triaj",
    "triata": "triat",
    "triată": "triat",
    "triate": "triat",
    "triatei": "triat",
    "triatele": "triat",
    "triatelor": "triat",
    "triați": "triat",
    "triații": "triat",
    "triaților": "triat",
    "triatul": "triat",
    "triatului": "triat",
    "tribul": "trib",
    "tribului": "trib",
    "triburi": "trib",
    "triburile": "trib",
    "triburilor": "trib",
    "tribala": "tribal",
    "tribală": "tribal",
    "tribale": "tribal",
    "tribalei": "tribal",
    "tribalele": "tribal",
    "tribalelor": "tribal",
    "tribali": "tribal",
    "tribalii": "tribal",
    "tribalilor": "tribal",
    "tribalul": "tribal",
    "tribalului": "tribal",
    "tribulația": "tribulație",
    "tribulației": "tribulație",
    "tribulații": "tribulație",
    "tribulațiile": "tribulație",
    "tribulațiilor": "tribulație",
    "tribuni": "tribun",
    "tribunii": "tribun",
    "tribunilor": "tribun",
    "tribunul": "tribun",
    "tribunului": "tribun",
    "tribuna": "tribună",
    "tribune": "tribună",
    "tribunei": "tribună",
    "tribunele": "tribună",
    "tribunelor": "tribună",
    "tribunale": "tribunal",
    "tribunalele": "tribunal",
    "tribunalelor": "tribunal",
    "tribunalul": "tribunal",
    "tribunalului": "tribunal",
    "TPI": "Tribunalul_Penal_Internațional",
    "tributul": "tribut",
    "tributului": "tribut",
    "tributuri": "tribut",
    "tributurile": "tribut",
    "tributurilor": "tribut",
    "tributara": "tributar",
    "tributară": "tributar",
    "tributare": "tributar",
    "tributarei": "tributar",
    "tributarele": "tributar",
    "tributarelor": "tributar",
    "tributari": "tributar",
    "tributarii": "tributar",
    "tributarilor": "tributar",
    "tributarul": "tributar",
    "tributarului": "tributar",
    "tricefala": "tricefal",
    "tricefală": "tricefal",
    "tricefale": "tricefal",
    "tricefalei": "tricefal",
    "tricefalele": "tricefal",
    "tricefalelor": "tricefal",
    "tricefali": "tricefal",
    "tricefalii": "tricefal",
    "tricefalilor": "tricefal",
    "tricefalul": "tricefal",
    "tricefalului": "tricefal",
    "tricofiția": "tricofiție",
    "tricofiției": "tricofiție",
    "tricofiții": "tricofiție",
    "tricofițiile": "tricofiție",
    "tricofițiilor": "tricofiție",
    "tricolora": "tricolor",
    "tricoloră": "tricolor",
    "tricolore": "tricolor",
    "tricolorei": "tricolor",
    "tricolorele": "tricolor",
    "tricolorelor": "tricolor",
    "tricolori": "tricolor",
    "tricolorii": "tricolor",
    "tricolorilor": "tricolor",
    "tricolorul": "tricolor",
    "tricolorului": "tricolor",
    "tricornul": "tricorn",
    "tricornului": "tricorn",
    "tricornuri": "tricorn",
    "tricornurile": "tricorn",
    "tricornurilor": "tricorn",
    "tricotul": "tricot",
    "tricotului": "tricot",
    "tricoturi": "tricot",
    "tricoturile": "tricot",
    "tricoturilor": "tricot",
    "nemaitricotând": "tricota",
    "nemaitricotându": "tricota",
    "netricotând": "tricota",
    "netricotându": "tricota",
    "tricotă": "tricota",
    "tricotai": "tricota",
    "tricotam": "tricota",
    "tricotăm": "tricota",
    "tricotând": "tricota",
    "tricotându": "tricota",
    "tricotară": "tricota",
    "tricotarăm": "tricota",
    "tricotarăți": "tricota",
    "tricotase": "tricota",
    "tricotasem": "tricota",
    "tricotaseră": "tricota",
    "tricotaserăm": "tricota",
    "tricotaserăți": "tricota",
    "tricotaseși": "tricota",
    "tricotași": "tricota",
    "tricotat": "tricota",
    "tricotați": "tricota",
    "tricotatu": "tricota",
    "tricotau": "tricota",
    "tricotează": "tricota",
    "tricotez": "tricota",
    "tricoteze": "tricota",
    "tricotezi": "tricota",
    "tricotarea": "tricotare",
    "tricotări": "tricotare",
    "tricotării": "tricotare",
    "tricotările": "tricotare",
    "tricotata": "tricotat",
    "tricotată": "tricotat",
    "tricotate": "tricotat",
    "tricotatei": "tricotat",
    "tricotatele": "tricotat",
    "tricotatelor": "tricotat",
    "tricotați": "tricotat",
    "tricotații": "tricotat",
    "tricotaților": "tricotat",
    "tricotatul": "tricotat",
    "tricotatului": "tricotat",
    "tricoul": "tricou",
    "tricoului": "tricou",
    "tricouri": "tricou",
    "tricourile": "tricou",
    "tricourilor": "tricou",
    "tridente": "trident",
    "tridentele": "trident",
    "tridentelor": "trident",
    "tridentul": "trident",
    "tridentului": "trident",
    "tridimensionala": "tridimensional",
    "tridimensională": "tridimensional",
    "tridimensionale": "tridimensional",
    "tridimensionalei": "tridimensional",
    "tridimensionalele": "tridimensional",
    "tridimensionalelor": "tridimensional",
    "tridimensionali": "tridimensional",
    "tridimensionalii": "tridimensional",
    "tridimensionalilor": "tridimensional",
    "tridimensionalul": "tridimensional",
    "tridimensionalului": "tridimensional",
    "trienala": "trienal",
    "trienală": "trienal",
    "trienale": "trienal",
    "trienalei": "trienal",
    "trienalele": "trienal",
    "trienalelor": "trienal",
    "trienali": "trienal",
    "trienalii": "trienal",
    "trienalilor": "trienal",
    "trienalo": "trienal",
    "trienalul": "trienal",
    "trienalule": "trienal",
    "trienalului": "trienal",
    "trierea": "triere",
    "trieri": "triere",
    "trierii": "triere",
    "trierile": "triere",
    "triftongi": "triftong",
    "triftongii": "triftong",
    "triftongilor": "triftong",
    "triftongul": "triftong",
    "triftongului": "triftong",
    "trifurcata": "trifurcat",
    "trifurcată": "trifurcat",
    "trifurcate": "trifurcat",
    "trifurcatei": "trifurcat",
    "trifurcatele": "trifurcat",
    "trifurcatelor": "trifurcat",
    "trifurcați": "trifurcat",
    "trifurcații": "trifurcat",
    "trifurcaților": "trifurcat",
    "trifurcatul": "trifurcat",
    "trifurcatului": "trifurcat",
    "trigonometria": "trigonometrie",
    "trigonometriei": "trigonometrie",
    "trigonometrii": "trigonometrie",
    "trigonometriile": "trigonometrie",
    "trigonometriilor": "trigonometrie",
    "trilul": "tril",
    "trilului": "tril",
    "triluri": "tril",
    "trilurile": "tril",
    "trilurilor": "tril",
    "trilaterală": "trilateral",
    "trilaterale": "trilateral",
    "trilaterali": "trilateral",
    "trilateralele": "trilaterale",
    "trilateralelor": "trilaterale",
    "trilogia": "trilogie",
    "trilogiei": "trilogie",
    "trilogii": "trilogie",
    "trilogiile": "trilogie",
    "trilogiilor": "trilogie",
    "trimestriala": "trimestrial",
    "trimestrială": "trimestrial",
    "trimestriale": "trimestrial",
    "trimestrialei": "trimestrial",
    "trimestrialele": "trimestrial",
    "trimestrialelor": "trimestrial",
    "trimestriali": "trimestrial",
    "trimestrialii": "trimestrial",
    "trimestrialilor": "trimestrial",
    "trimestrialul": "trimestrial",
    "trimestrialului": "trimestrial",
    "trim": "trimestru",
    "trimestre": "trimestru",
    "trimestrele": "trimestru",
    "trimestrelor": "trimestru",
    "trimestrul": "trimestru",
    "trimestrului": "trimestru",
    "trim.": "trimestrul",
    "trimisa": "trimis",
    "trimisă": "trimis",
    "trimise": "trimis",
    "trimisei": "trimis",
    "trimisele": "trimis",
    "trimiselor": "trimis",
    "trimiși": "trimis",
    "trimișii": "trimis",
    "trimișilor": "trimis",
    "trimiso": "trimis",
    "trimisul": "trimis",
    "trimisule": "trimis",
    "trimisului": "trimis",
    "trimisa": "trimisă",
    "trimise": "trimisă",
    "trimisei": "trimisă",
    "trimisele": "trimisă",
    "trimiselor": "trimisă",
    "trimiso": "trimisă",
    "nemaitrimițând": "trimite",
    "nemaitrimițându": "trimite",
    "netrimițând": "trimite",
    "netrimițându": "trimite",
    "trimis": "trimite",
    "trimise": "trimite",
    "trimisei": "trimite",
    "trimiseră": "trimite",
    "trimiserăm": "trimite",
    "trimiserăți": "trimite",
    "trimisese": "trimite",
    "trimisesem": "trimite",
    "trimiseseră": "trimite",
    "trimiseserăm": "trimite",
    "trimiseserăți": "trimite",
    "trimiseseși": "trimite",
    "trimiseși": "trimite",
    "trimisu": "trimite",
    "trimit": "trimite",
    "trimită": "trimite",
    "trimițând": "trimite",
    "trimițându": "trimite",
    "trimitea": "trimite",
    "trimiteai": "trimite",
    "trimiteam": "trimite",
    "trimiteați": "trimite",
    "trimiteau": "trimite",
    "trimitem": "trimite",
    "trimiteți": "trimite",
    "trimiți": "trimite",
    "trimiterea": "trimitere",
    "trimitereo": "trimitere",
    "trimiteri": "trimitere",
    "trimiterii": "trimitere",
    "trimiterile": "trimitere",
    "trimiterilor": "trimitere",
    "trinitatea": "trinitate",
    "trinități": "trinitate",
    "trinității": "trinitate",
    "trinitățile": "trinitate",
    "trinităților": "trinitate",
    "trinitroglicerina": "trinitroglicerină",
    "trinitroglicerine": "trinitroglicerină",
    "trinitroglicerinei": "trinitroglicerină",
    "trinitroglicerinele": "trinitroglicerină",
    "trinitroglicerinelor": "trinitroglicerină",
    "trinoame": "trinom",
    "trinoamele": "trinom",
    "trinoamelor": "trinom",
    "trinomul": "trinom",
    "trinomului": "trinom",
    "trioare": "trior",
    "trioarele": "trior",
    "trioarelor": "trior",
    "triorul": "trior",
    "triorului": "trior",
    "tripartita": "tripartit",
    "tripartită": "tripartit",
    "tripartite": "tripartit",
    "tripartitei": "tripartit",
    "tripartitele": "tripartit",
    "tripartitelor": "tripartit",
    "tripartiți": "tripartit",
    "tripartiții": "tripartit",
    "tripartiților": "tripartit",
    "tripartitul": "tripartit",
    "tripartitului": "tripartit",
    "nemaitriplând": "tripla",
    "nemaitriplându": "tripla",
    "netriplând": "tripla",
    "netriplându": "tripla",
    "triplă": "tripla",
    "triplai": "tripla",
    "triplam": "tripla",
    "triplăm": "tripla",
    "triplând": "tripla",
    "triplându": "tripla",
    "triplară": "tripla",
    "triplarăm": "tripla",
    "triplarăți": "tripla",
    "triplase": "tripla",
    "triplasem": "tripla",
    "triplaseră": "tripla",
    "triplaserăm": "tripla",
    "triplaserăți": "tripla",
    "triplaseși": "tripla",
    "triplași": "tripla",
    "triplat": "tripla",
    "triplați": "tripla",
    "triplatu": "tripla",
    "triplau": "tripla",
    "triplează": "tripla",
    "triplez": "tripla",
    "tripleze": "tripla",
    "triplezi": "tripla",
    "triplarea": "triplare",
    "triplări": "triplare",
    "triplării": "triplare",
    "triplările": "triplare",
    "triplata": "triplat",
    "triplată": "triplat",
    "triplate": "triplat",
    "triplatei": "triplat",
    "triplatele": "triplat",
    "triplatelor": "triplat",
    "triplați": "triplat",
    "triplații": "triplat",
    "triplaților": "triplat",
    "triplatul": "triplat",
    "triplatului": "triplat",
    "triplete": "triplet",
    "tripletele": "triplet",
    "tripletelor": "triplet",
    "tripletul": "triplet",
    "tripletului": "triplet",
    "triplicate": "triplicat",
    "triplicatele": "triplicat",
    "triplicatelor": "triplicat",
    "triplicatul": "triplicat",
    "triplicatului": "triplicat",
    "tripoul": "tripou",
    "tripoului": "tripou",
    "tripouri": "tripou",
    "tripourile": "tripou",
    "tripourilor": "tripou",
    "nemaitrișând": "trișa",
    "nemaitrișându": "trișa",
    "netrișând": "trișa",
    "netrișându": "trișa",
    "trișă": "trișa",
    "trișai": "trișa",
    "trișam": "trișa",
    "trișăm": "trișa",
    "trișând": "trișa",
    "trișându": "trișa",
    "trișară": "trișa",
    "trișarăm": "trișa",
    "trișarăți": "trișa",
    "trișase": "trișa",
    "trișasem": "trișa",
    "trișaseră": "trișa",
    "trișaserăm": "trișa",
    "trișaserăți": "trișa",
    "trișaseși": "trișa",
    "trișași": "trișa",
    "trișat": "trișa",
    "trișați": "trișa",
    "trișatu": "trișa",
    "trișau": "trișa",
    "trișează": "trișa",
    "trișez": "trișa",
    "trișeze": "trișa",
    "trișezi": "trișa",
    "trișarea": "trișare",
    "trișări": "trișare",
    "trișării": "trișare",
    "trișările": "trișare",
    "trișata": "trișat",
    "trișată": "trișat",
    "trișate": "trișat",
    "trișatei": "trișat",
    "trișatele": "trișat",
    "trișatelor": "trișat",
    "trișați": "trișat",
    "trișații": "trișat",
    "trișaților": "trișat",
    "trișatul": "trișat",
    "trișatului": "trișat",
    "trișata": "trișată",
    "trișate": "trișată",
    "trișatei": "trișată",
    "trișatele": "trișată",
    "trișatelor": "trișată",
    "trișca": "trișcă",
    "triște": "trișcă",
    "triștei": "trișcă",
    "triștile": "trișcă",
    "triștilor": "trișcă",
    "trișori": "trișor",
    "trișorii": "trișor",
    "trișorilor": "trișor",
    "trișorul": "trișor",
    "trișorului": "trișor",
    "trista": "trist",
    "tristă": "trist",
    "triste": "trist",
    "tristei": "trist",
    "tristele": "trist",
    "tristelor": "trist",
    "triști": "trist",
    "triștii": "trist",
    "triștilor": "trist",
    "tristo": "trist",
    "tristul": "trist",
    "tristule": "trist",
    "tristului": "trist",
    "tristețea": "tristețe",
    "tristețeo": "tristețe",
    "tristeți": "tristețe",
    "tristeții": "tristețe",
    "tristețile": "tristețe",
    "tristeților": "tristețe",
    "triumful": "triumf",
    "triumfului": "triumf",
    "triumfuri": "triumf",
    "triumfurile": "triumf",
    "triumfurilor": "triumf",
    "nemaitriumfând": "triumfa",
    "nemaitriumfându": "triumfa",
    "netriumfând": "triumfa",
    "netriumfându": "triumfa",
    "triumf": "triumfa",
    "triumfă": "triumfa",
    "triumfai": "triumfa",
    "triumfam": "triumfa",
    "triumfăm": "triumfa",
    "triumfând": "triumfa",
    "triumfându": "triumfa",
    "triumfară": "triumfa",
    "triumfarăm": "triumfa",
    "triumfarăți": "triumfa",
    "triumfase": "triumfa",
    "triumfasem": "triumfa",
    "triumfaseră": "triumfa",
    "triumfaserăm": "triumfa",
    "triumfaserăți": "triumfa",
    "triumfaseși": "triumfa",
    "triumfași": "triumfa",
    "triumfat": "triumfa",
    "triumfați": "triumfa",
    "triumfatu": "triumfa",
    "triumfau": "triumfa",
    "triumfe": "triumfa",
    "triumfi": "triumfa",
    "triumfala": "triumfal",
    "triumfală": "triumfal",
    "triumfale": "triumfal",
    "triumfalei": "triumfal",
    "triumfalele": "triumfal",
    "triumfalelor": "triumfal",
    "triumfali": "triumfal",
    "triumfalii": "triumfal",
    "triumfalilor": "triumfal",
    "triumfalul": "triumfal",
    "triumfalului": "triumfal",
    "triumfarea": "triumfare",
    "triumfareo": "triumfare",
    "triumfări": "triumfare",
    "triumfării": "triumfare",
    "triumfările": "triumfare",
    "triumfărilor": "triumfare",
    "triumfata": "triumfat",
    "triumfată": "triumfat",
    "triumfate": "triumfat",
    "triumfatei": "triumfat",
    "triumfatele": "triumfat",
    "triumfatelor": "triumfat",
    "triumfați": "triumfat",
    "triumfații": "triumfat",
    "triumfaților": "triumfat",
    "triumfatul": "triumfat",
    "triumfatului": "triumfat",
    "triumfătoarea": "triumfătoare",
    "triumfătoarei": "triumfătoare",
    "triumfătoarele": "triumfătoare",
    "triumfătoarelor": "triumfătoare",
    "triumfătoareo": "triumfătoare",
    "triumfătoare": "triumfător",
    "triumfătoarea": "triumfător",
    "triumfătoarei": "triumfător",
    "triumfătoarele": "triumfător",
    "triumfătoarelor": "triumfător",
    "triumfătoareo": "triumfător",
    "triumfători": "triumfător",
    "triumfătorii": "triumfător",
    "triumfătorilor": "triumfător",
    "triumfătorul": "triumfător",
    "triumfătorule": "triumfător",
    "triumfătorului": "triumfător",
    "triunghiul": "triunghi",
    "triunghiului": "triunghi",
    "triunghiuri": "triunghi",
    "triunghiurile": "triunghi",
    "triunghiurilor": "triunghi",
    "triunghiulara": "triunghiular",
    "triunghiulară": "triunghiular",
    "triunghiulare": "triunghiular",
    "triunghiularei": "triunghiular",
    "triunghiularele": "triunghiular",
    "triunghiularelor": "triunghiular",
    "triunghiulari": "triunghiular",
    "triunghiularii": "triunghiular",
    "triunghiularilor": "triunghiular",
    "triunghiularo": "triunghiular",
    "triunghiularul": "triunghiular",
    "triunghiularule": "triunghiular",
    "triunghiularului": "triunghiular",
    "triviala": "trivial",
    "trivială": "trivial",
    "triviale": "trivial",
    "trivialei": "trivial",
    "trivialele": "trivial",
    "trivialelor": "trivial",
    "triviali": "trivial",
    "trivialii": "trivial",
    "trivialilor": "trivial",
    "trivialul": "trivial",
    "trivialului": "trivial",
    "troaca": "troacă",
    "troace": "troacă",
    "troacei": "troacă",
    "troacele": "troacă",
    "troacelor": "troacă",
    "trocul": "troc",
    "trocului": "troc",
    "trocuri": "troc",
    "trocurile": "troc",
    "trocurilor": "troc",
    "trocare": "trocar",
    "trocarele": "trocar",
    "trocarelor": "trocar",
    "trocarul": "trocar",
    "trocarului": "trocar",
    "trofee": "trofeu",
    "trofeele": "trofeu",
    "trofeelor": "trofeu",
    "trofeul": "trofeu",
    "trofeului": "trofeu",
    "trofica": "trofic",
    "trofică": "trofic",
    "trofice": "trofic",
    "troficei": "trofic",
    "troficele": "trofic",
    "troficelor": "trofic",
    "trofici": "trofic",
    "troficii": "trofic",
    "troficilor": "trofic",
    "troficul": "trofic",
    "troficului": "trofic",
    "troglobia": "troglobie",
    "troglobiei": "troglobie",
    "troglobii": "troglobie",
    "troglobiile": "troglobie",
    "troglobiilor": "troglobie",
    "troglodiți": "troglodit",
    "troglodiții": "troglodit",
    "troglodiților": "troglodit",
    "trogloditul": "troglodit",
    "trogloditului": "troglodit",
    "troglodita": "troglodită",
    "troglodite": "troglodită",
    "trogloditei": "troglodită",
    "trogloditele": "troglodită",
    "trogloditelor": "troglodită",
    "trohaica": "trohaic",
    "trohaică": "trohaic",
    "trohaice": "trohaic",
    "trohaicei": "trohaic",
    "trohaicele": "trohaic",
    "trohaicelor": "trohaic",
    "trohaici": "trohaic",
    "trohaicii": "trohaic",
    "trohaicilor": "trohaic",
    "trohaicul": "trohaic",
    "trohaicului": "trohaic",
    "trohei": "troheu",
    "troheii": "troheu",
    "troheilor": "troheu",
    "troheul": "troheu",
    "troheului": "troheu",
    "Troiei": "Troia",
    "troiana": "troian",
    "troiană": "troian",
    "troianul": "troian",
    "troianului": "troian",
    "troiene": "troian",
    "troienele": "troian",
    "troienelor": "troian",
    "troieni": "troian",
    "troienii": "troian",
    "troienilor": "troian",
    "troica": "troică",
    "troici": "troică",
    "troicii": "troică",
    "troicile": "troică",
    "troicilor": "troică",
    "troița": "troiță",
    "troițe": "troiță",
    "troiței": "troiță",
    "troițele": "troiță",
    "troițelor": "troiță",
    "troleibuze": "troleibuz",
    "troleibuzele": "troleibuz",
    "troleibuzelor": "troleibuz",
    "troleibuzul": "troleibuz",
    "troleibuzului": "troleibuz",
    "trolee": "troleu",
    "troleele": "troleu",
    "troleelor": "troleu",
    "troleul": "troleu",
    "troleului": "troleu",
    "tromba": "trombă",
    "trombe": "trombă",
    "trombei": "trombă",
    "trombele": "trombă",
    "trombelor": "trombă",
    "tromboza": "tromboză",
    "tromboze": "tromboză",
    "trombozei": "tromboză",
    "trombozele": "tromboză",
    "trombozelor": "tromboză",
    "trompeți": "trompet",
    "trompeții": "trompet",
    "trompeților": "trompet",
    "trompetul": "trompet",
    "trompetule": "trompet",
    "trompetului": "trompet",
    "trompeta": "trompetă",
    "trompete": "trompetă",
    "trompetei": "trompetă",
    "trompetele": "trompetă",
    "trompetelor": "trompetă",
    "trompeto": "trompetă",
    "tronul": "tron",
    "tronului": "tron",
    "tronuri": "tron",
    "tronurile": "tron",
    "tronurilor": "tron",
    "nemaitronând": "trona",
    "nemaitronându": "trona",
    "netronând": "trona",
    "netronându": "trona",
    "tronă": "trona",
    "tronai": "trona",
    "tronam": "trona",
    "tronăm": "trona",
    "tronând": "trona",
    "tronându": "trona",
    "tronară": "trona",
    "tronarăm": "trona",
    "tronarăți": "trona",
    "tronase": "trona",
    "tronasem": "trona",
    "tronaseră": "trona",
    "tronaserăm": "trona",
    "tronaserăți": "trona",
    "tronaseși": "trona",
    "tronași": "trona",
    "tronat": "trona",
    "tronați": "trona",
    "tronatu": "trona",
    "tronau": "trona",
    "tronează": "trona",
    "tronez": "trona",
    "troneze": "trona",
    "tronezi": "trona",
    "tronata": "tronat",
    "tronată": "tronat",
    "tronate": "tronat",
    "tronatei": "tronat",
    "tronatele": "tronat",
    "tronatelor": "tronat",
    "tronați": "tronat",
    "tronații": "tronat",
    "tronaților": "tronat",
    "tronatul": "tronat",
    "tronatului": "tronat",
    "tronsoane": "tronson",
    "tronsoanele": "tronson",
    "tronsoanelor": "tronson",
    "tronsonul": "tronson",
    "tronsonului": "tronson",
    "nemaitropăind": "tropăi",
    "nemaitropăindu": "tropăi",
    "netropăind": "tropăi",
    "netropăindu": "tropăi",
    "tropăia": "tropăi",
    "tropăiai": "tropăi",
    "tropăiam": "tropăi",
    "tropăiați": "tropăi",
    "tropăiau": "tropăi",
    "tropăie": "tropăi",
    "tropăii": "tropăi",
    "tropăim": "tropăi",
    "tropăind": "tropăi",
    "tropăindu": "tropăi",
    "tropăiră": "tropăi",
    "tropăirăm": "tropăi",
    "tropăirăți": "tropăi",
    "tropăise": "tropăi",
    "tropăisem": "tropăi",
    "tropăiseră": "tropăi",
    "tropăiserăm": "tropăi",
    "tropăiserăți": "tropăi",
    "tropăiseși": "tropăi",
    "tropăiși": "tropăi",
    "tropăit": "tropăi",
    "tropăiți": "tropăi",
    "tropăitu": "tropăi",
    "tropăiala": "tropăială",
    "tropăieli": "tropăială",
    "tropăielii": "tropăială",
    "tropăielile": "tropăială",
    "tropăielilor": "tropăială",
    "tropăirea": "tropăire",
    "tropăiri": "tropăire",
    "tropăirii": "tropăire",
    "tropăirile": "tropăire",
    "tropăita": "tropăit",
    "tropăită": "tropăit",
    "tropăite": "tropăit",
    "tropăitei": "tropăit",
    "tropăitele": "tropăit",
    "tropăitelor": "tropăit",
    "tropăiți": "tropăit",
    "tropăiții": "tropăit",
    "tropăiților": "tropăit",
    "tropăitul": "tropăit",
    "tropăitului": "tropăit",
    "tropăituri": "tropăit",
    "tropăiturile": "tropăit",
    "tropăiturilor": "tropăit",
    "tropăitoare": "tropăitor",
    "tropăitoarea": "tropăitor",
    "tropăitoarei": "tropăitor",
    "tropăitoarele": "tropăitor",
    "tropăitoarelor": "tropăitor",
    "tropăitori": "tropăitor",
    "tropăitorii": "tropăitor",
    "tropăitorilor": "tropăitor",
    "tropăitorul": "tropăitor",
    "tropăitorului": "tropăitor",
    "tropăitura": "tropăitură",
    "tropăituri": "tropăitură",
    "tropăiturii": "tropăitură",
    "tropăiturile": "tropăitură",
    "tropăiturilor": "tropăitură",
    "tropice": "tropic",
    "tropicele": "tropic",
    "tropicelor": "tropic",
    "tropicul": "tropic",
    "tropicului": "tropic",
    "tropicala": "tropical",
    "tropicală": "tropical",
    "tropicale": "tropical",
    "tropicalei": "tropical",
    "tropicalele": "tropical",
    "tropicalelor": "tropical",
    "tropicali": "tropical",
    "tropicalii": "tropical",
    "tropicalilor": "tropical",
    "tropicalul": "tropical",
    "tropicalului": "tropical",
    "troposfera": "troposferă",
    "troposfere": "troposferă",
    "troposferei": "troposferă",
    "troposferele": "troposferă",
    "troposferelor": "troposferă",
    "trosneala": "trosneală",
    "trosnealo": "trosneală",
    "trosneli": "trosneală",
    "trosnelii": "trosneală",
    "trosnelile": "trosneală",
    "trosnelilor": "trosneală",
    "trosnete": "trosnet",
    "trosnetele": "trosnet",
    "trosnetelor": "trosnet",
    "trosnetul": "trosnet",
    "trosnetule": "trosnet",
    "trosnetului": "trosnet",
    "nemaitrosnind": "trosni",
    "nemaitrosnindu": "trosni",
    "netrosnind": "trosni",
    "netrosnindu": "trosni",
    "trosnea": "trosni",
    "trosneai": "trosni",
    "trosneam": "trosni",
    "trosnească": "trosni",
    "trosneați": "trosni",
    "trosneau": "trosni",
    "trosnesc": "trosni",
    "trosnește": "trosni",
    "trosnești": "trosni",
    "trosnii": "trosni",
    "trosnim": "trosni",
    "trosnind": "trosni",
    "trosnindu": "trosni",
    "trosniră": "trosni",
    "trosnirăm": "trosni",
    "trosnirăți": "trosni",
    "trosnise": "trosni",
    "trosnisem": "trosni",
    "trosniseră": "trosni",
    "trosniserăm": "trosni",
    "trosniserăți": "trosni",
    "trosniseși": "trosni",
    "trosniși": "trosni",
    "trosnit": "trosni",
    "trosniți": "trosni",
    "trosnitu": "trosni",
    "trosnirea": "trosnire",
    "trosnireo": "trosnire",
    "trosniri": "trosnire",
    "trosnirii": "trosnire",
    "trosnirile": "trosnire",
    "trosnirilor": "trosnire",
    "trosnita": "trosnit",
    "trosnită": "trosnit",
    "trosnite": "trosnit",
    "trosnitei": "trosnit",
    "trosnitele": "trosnit",
    "trosnitelor": "trosnit",
    "trosniți": "trosnit",
    "trosniții": "trosnit",
    "trosniților": "trosnit",
    "trosnito": "trosnit",
    "trosnitul": "trosnit",
    "trosnitule": "trosnit",
    "trosnitului": "trosnit",
    "trosnitoare": "trosnitor",
    "trosnitoarea": "trosnitor",
    "trosnitoarei": "trosnitor",
    "trosnitoarele": "trosnitor",
    "trosnitoarelor": "trosnitor",
    "trosnitori": "trosnitor",
    "trosnitorii": "trosnitor",
    "trosnitorilor": "trosnitor",
    "trosnitorul": "trosnitor",
    "trosnitorului": "trosnitor",
    "trotuare": "trotuar",
    "trotuarele": "trotuar",
    "trotuarelor": "trotuar",
    "trotuaru'": "trotuar",
    "trotuarul": "trotuar",
    "trotuarule": "trotuar",
    "trotuarului": "trotuar",
    "trubaduri": "trubadur",
    "trubadurii": "trubadur",
    "trubadurilor": "trubadur",
    "trubadurul": "trubadur",
    "trubadurului": "trubadur",
    "trucul": "truc",
    "trucului": "truc",
    "trucuri": "truc",
    "trucurile": "truc",
    "trucurilor": "truc",
    "nemaitrucând": "truca",
    "nemaitrucându": "truca",
    "netrucând": "truca",
    "netrucându": "truca",
    "trucă": "truca",
    "trucai": "truca",
    "trucam": "truca",
    "trucăm": "truca",
    "trucând": "truca",
    "trucându": "truca",
    "trucară": "truca",
    "trucarăm": "truca",
    "trucarăți": "truca",
    "trucase": "truca",
    "trucasem": "truca",
    "trucaseră": "truca",
    "trucaserăm": "truca",
    "trucaserăți": "truca",
    "trucaseși": "truca",
    "trucași": "truca",
    "trucat": "truca",
    "trucați": "truca",
    "trucatu": "truca",
    "trucau": "truca",
    "truchează": "truca",
    "truchez": "truca",
    "trucheze": "truca",
    "truchezi": "truca",
    "trucaje": "trucaj",
    "trucajele": "trucaj",
    "trucajelor": "trucaj",
    "trucajul": "trucaj",
    "trucajului": "trucaj",
    "trucarea": "trucare",
    "trucări": "trucare",
    "trucării": "trucare",
    "trucările": "trucare",
    "trucata": "trucat",
    "trucată": "trucat",
    "trucate": "trucat",
    "trucatei": "trucat",
    "trucatele": "trucat",
    "trucatelor": "trucat",
    "trucați": "trucat",
    "trucații": "trucat",
    "trucaților": "trucat",
    "trucatul": "trucat",
    "trucatului": "trucat",
    "truda": "trudă",
    "trude": "trudă",
    "trudei": "trudă",
    "trudele": "trudă",
    "trudelor": "trudă",
    "nemaitrudind": "trudi",
    "nemaitrudindu": "trudi",
    "netrudind": "trudi",
    "netrudindu": "trudi",
    "trudea": "trudi",
    "trudeai": "trudi",
    "trudeam": "trudi",
    "trudească": "trudi",
    "trudeați": "trudi",
    "trudeau": "trudi",
    "trudesc": "trudi",
    "trudește": "trudi",
    "trudești": "trudi",
    "trudii": "trudi",
    "trudim": "trudi",
    "trudind": "trudi",
    "trudindu": "trudi",
    "trudiră": "trudi",
    "trudirăm": "trudi",
    "trudirăți": "trudi",
    "trudise": "trudi",
    "trudisem": "trudi",
    "trudiseră": "trudi",
    "trudiserăm": "trudi",
    "trudiserăți": "trudi",
    "trudiseși": "trudi",
    "trudiși": "trudi",
    "trudit": "trudi",
    "trudiți": "trudi",
    "truditu": "trudi",
    "trudirea": "trudire",
    "trudiri": "trudire",
    "trudirii": "trudire",
    "trudirile": "trudire",
    "trudita": "trudit",
    "trudită": "trudit",
    "trudite": "trudit",
    "truditei": "trudit",
    "truditele": "trudit",
    "truditelor": "trudit",
    "trudiți": "trudit",
    "trudiții": "trudit",
    "trudiților": "trudit",
    "truditul": "trudit",
    "truditului": "trudit",
    "truditoarea": "truditoare",
    "truditoarei": "truditoare",
    "truditoarele": "truditoare",
    "truditoarelor": "truditoare",
    "truditoare": "truditor",
    "truditoarea": "truditor",
    "truditoarei": "truditor",
    "truditoarele": "truditor",
    "truditoarelor": "truditor",
    "truditori": "truditor",
    "truditorii": "truditor",
    "truditorilor": "truditor",
    "truditorul": "truditor",
    "truditorului": "truditor",
    "trudnica": "trudnic",
    "trudnică": "trudnic",
    "trudnice": "trudnic",
    "trudnicei": "trudnic",
    "trudnicele": "trudnic",
    "trudnicelor": "trudnic",
    "trudnici": "trudnic",
    "trudnicii": "trudnic",
    "trudnicilor": "trudnic",
    "trudnicul": "trudnic",
    "trudnicului": "trudnic",
    "trufandale": "trufanda",
    "trufandalei": "trufanda",
    "trufandalele": "trufanda",
    "trufandalelor": "trufanda",
    "trufandaua": "trufanda",
    "trufașa": "trufaș",
    "trufașă": "trufaș",
    "trufașe": "trufaș",
    "trufașei": "trufaș",
    "trufașele": "trufaș",
    "trufașelor": "trufaș",
    "trufași": "trufaș",
    "trufașii": "trufaș",
    "trufașilor": "trufaș",
    "trufașul": "trufaș",
    "trufașului": "trufaș",
    "trufia": "trufie",
    "trufiei": "trufie",
    "trufii": "trufie",
    "trufiile": "trufie",
    "trufiilor": "trufie",
    "truisme": "truism",
    "truismele": "truism",
    "truismelor": "truism",
    "truismul": "truism",
    "truismului": "truism",
    "trunchiul": "trunchi",
    "trunchiului": "trunchi",
    "trunchiuri": "trunchi",
    "trunchiurile": "trunchi",
    "trunchiurilor": "trunchi",
    "nemaitrunchiând": "trunchia",
    "nemaitrunchiându": "trunchia",
    "netrunchiând": "trunchia",
    "netrunchiându": "trunchia",
    "trunchiai": "trunchia",
    "trunchiam": "trunchia",
    "trunchiară": "trunchia",
    "trunchiarăm": "trunchia",
    "trunchiarăți": "trunchia",
    "trunchiase": "trunchia",
    "trunchiasem": "trunchia",
    "trunchiaseră": "trunchia",
    "trunchiaserăm": "trunchia",
    "trunchiaserăți": "trunchia",
    "trunchiaseși": "trunchia",
    "trunchiași": "trunchia",
    "trunchiat": "trunchia",
    "trunchiați": "trunchia",
    "trunchiau": "trunchia",
    "trunchiază": "trunchia",
    "trunchie": "trunchia",
    "trunchiem": "trunchia",
    "trunchiezi": "trunchia",
    "trunchiata": "trunchiat",
    "trunchiată": "trunchiat",
    "trunchiate": "trunchiat",
    "trunchiatei": "trunchiat",
    "trunchiatele": "trunchiat",
    "trunchiatelor": "trunchiat",
    "trunchiați": "trunchiat",
    "trunchiații": "trunchiat",
    "trunchiaților": "trunchiat",
    "trunchiato": "trunchiat",
    "trunchiatul": "trunchiat",
    "trunchiatule": "trunchiat",
    "trunchiatului": "trunchiat",
    "trunchierea": "trunchiere",
    "trunchieri": "trunchiere",
    "trunchierii": "trunchiere",
    "trunchierile": "trunchiere",
    "trupul": "trup",
    "trupului": "trup",
    "trupuri": "trup",
    "trupurile": "trup",
    "trupurilor": "trup",
    "trupa": "trupă",
    "trupe": "trupă",
    "trupei": "trupă",
    "trupele": "trupă",
    "trupelor": "trupă",
    "trupeșa": "trupeș",
    "trupeșă": "trupeș",
    "trupeșe": "trupeș",
    "trupeșei": "trupeș",
    "trupeșele": "trupeș",
    "trupeșelor": "trupeș",
    "trupeși": "trupeș",
    "trupeșii": "trupeș",
    "trupeșilor": "trupeș",
    "trupeșul": "trupeș",
    "trupeșului": "trupeș",
    "trupeasca": "trupesc",
    "trupească": "trupesc",
    "trupescul": "trupesc",
    "trupescului": "trupesc",
    "trupești": "trupesc",
    "trupeștii": "trupesc",
    "trupeștile": "trupesc",
    "trupeștilor": "trupesc",
    "trusa": "trusă",
    "truse": "trusă",
    "trusei": "trusă",
    "trusele": "trusă",
    "truselor": "trusă",
    "trusoul": "trusou",
    "trusoului": "trusou",
    "trusouri": "trusou",
    "trusourile": "trusou",
    "trusourilor": "trusou",
    "trustul": "trust",
    "trustului": "trust",
    "trusturi": "trust",
    "trusturile": "trust",
    "trusturilor": "trust",
    "îți": "tu",
    "te": "tu",
    "te-": "tu",
    "ți": "tu",
    "ți-": "tu",
    "ție": "tu",
    "tine": "tu",
    "tubul": "tub",
    "tubule": "tub",
    "tubului": "tub",
    "tuburi": "tub",
    "tuburile": "tub",
    "tuburilor": "tub",
    "tuberculoasa": "tuberculoasă",
    "tuberculoase": "tuberculoasă",
    "tuberculoasei": "tuberculoasă",
    "tuberculoasele": "tuberculoasă",
    "tuberculoaselor": "tuberculoasă",
    "tuberculoasa": "tuberculos",
    "tuberculoasă": "tuberculos",
    "tuberculoase": "tuberculos",
    "tuberculoasei": "tuberculos",
    "tuberculoasele": "tuberculos",
    "tuberculoaselor": "tuberculos",
    "tuberculoși": "tuberculos",
    "tuberculoșii": "tuberculos",
    "tuberculoșilor": "tuberculos",
    "tuberculosul": "tuberculos",
    "tuberculosului": "tuberculos",
    "tuberculoza": "tuberculoză",
    "tuberculoze": "tuberculoză",
    "tuberculozei": "tuberculoză",
    "tuberculozele": "tuberculoză",
    "tuberculozelor": "tuberculoză",
    "tubulara": "tubular",
    "tubulară": "tubular",
    "tubulare": "tubular",
    "tubularei": "tubular",
    "tubularele": "tubular",
    "tubularelor": "tubular",
    "tubulari": "tubular",
    "tubularii": "tubular",
    "tubularilor": "tubular",
    "tubularul": "tubular",
    "tubularului": "tubular",
    "tuciul": "tuci",
    "tuciului": "tuci",
    "tuciuri": "tuci",
    "tuciurile": "tuci",
    "tuciurilor": "tuci",
    "tuciuria": "tuciuriu",
    "tuciurie": "tuciuriu",
    "tuciuriei": "tuciuriu",
    "tuciurii": "tuciuriu",
    "tuciuriii": "tuciuriu",
    "tuciuriile": "tuciuriu",
    "tuciuriilor": "tuciuriu",
    "tuciurio": "tuciuriu",
    "tuciuriul": "tuciuriu",
    "tuciuriule": "tuciuriu",
    "tuciuriului": "tuciuriu",
    "tufa": "tufă",
    "tufe": "tufă",
    "tufei": "tufă",
    "tufele": "tufă",
    "tufelor": "tufă",
    "tufo": "tufă",
    "tufari": "tufar",
    "tufarul": "tufar",
    "tufarului": "tufar",
    "tufișul": "tufiș",
    "tufișule": "tufiș",
    "tufișului": "tufiș",
    "tufișuri": "tufiș",
    "tufișurile": "tufiș",
    "tufișurilor": "tufiș",
    "țuguie": "țugui",
    "țuguiele": "țugui",
    "țuguielor": "țugui",
    "țuguiul": "țugui",
    "țuguiului": "țugui",
    "nemaițuguind": "țuguia",
    "nemaițuguindu": "țuguia",
    "nețuguind": "țuguia",
    "nețuguindu": "țuguia",
    "țuguiai": "țuguia",
    "țuguiam": "țuguia",
    "țuguiară": "țuguia",
    "țuguiarăm": "țuguia",
    "țuguiarăți": "țuguia",
    "țuguiase": "țuguia",
    "țuguiasem": "țuguia",
    "țuguiaseră": "țuguia",
    "țuguiaserăm": "țuguia",
    "țuguiaserăți": "țuguia",
    "țuguiaseși": "țuguia",
    "țuguiași": "țuguia",
    "țuguiat": "țuguia",
    "țuguiați": "țuguia",
    "țuguiau": "țuguia",
    "țuguiază": "țuguia",
    "țuguiem": "țuguia",
    "țuguiez": "țuguia",
    "țuguieze": "țuguia",
    "țuguiezi": "țuguia",
    "țuguii": "țuguia",
    "țuguind": "țuguia",
    "țuguindu": "țuguia",
    "țuguiți": "țuguia",
    "țuguiata": "țuguiat",
    "țuguiată": "țuguiat",
    "țuguiate": "țuguiat",
    "țuguiatei": "țuguiat",
    "țuguiatele": "țuguiat",
    "țuguiatelor": "țuguiat",
    "țuguiați": "țuguiat",
    "țuguiații": "țuguiat",
    "țuguiaților": "țuguiat",
    "țuguiatul": "țuguiat",
    "țuguiatului": "țuguiat",
    "tuiul": "tui",
    "tuiului": "tui",
    "tuiuri": "tui",
    "tuiurile": "tui",
    "tuiurilor": "tui",
    "țuica": "țuică",
    "țuici": "țuică",
    "țuicii": "țuică",
    "țuicile": "țuică",
    "țuicilor": "țuică",
    "tulul": "tul",
    "tulului": "tul",
    "tuluri": "tul",
    "tulurile": "tul",
    "tulurilor": "tul",
    "nemaitulburând": "tulbura",
    "nemaitulburându": "tulbura",
    "netulburând": "tulbura",
    "netulburându": "tulbura",
    "tulbur": "tulbura",
    "tulbură": "tulbura",
    "tulburai": "tulbura",
    "tulburam": "tulbura",
    "tulburăm": "tulbura",
    "tulburând": "tulbura",
    "tulburându": "tulbura",
    "tulburară": "tulbura",
    "tulburarăm": "tulbura",
    "tulburarăți": "tulbura",
    "tulburase": "tulbura",
    "tulburasem": "tulbura",
    "tulburaseră": "tulbura",
    "tulburaserăm": "tulbura",
    "tulburaserăți": "tulbura",
    "tulburaseși": "tulbura",
    "tulburași": "tulbura",
    "tulburat": "tulbura",
    "tulburați": "tulbura",
    "tulburatu": "tulbura",
    "tulburau": "tulbura",
    "tulbure": "tulbura",
    "tulburi": "tulbura",
    "tulburarea": "tulburare",
    "tulburareo": "tulburare",
    "tulburări": "tulburare",
    "tulburării": "tulburare",
    "tulburările": "tulburare",
    "tulburărilor": "tulburare",
    "tulburata": "tulburat",
    "tulburată": "tulburat",
    "tulburate": "tulburat",
    "tulburatei": "tulburat",
    "tulburatele": "tulburat",
    "tulburatelor": "tulburat",
    "tulburați": "tulburat",
    "tulburații": "tulburat",
    "tulburaților": "tulburat",
    "tulburato": "tulburat",
    "tulburatul": "tulburat",
    "tulburatule": "tulburat",
    "tulburatului": "tulburat",
    "tulburătoare": "tulburător",
    "tulburătoarea": "tulburător",
    "tulburătoarei": "tulburător",
    "tulburătoarele": "tulburător",
    "tulburătoarelor": "tulburător",
    "tulburătoareo": "tulburător",
    "tulburători": "tulburător",
    "tulburătorii": "tulburător",
    "tulburătorilor": "tulburător",
    "tulburătorul": "tulburător",
    "tulburătorule": "tulburător",
    "tulburătorului": "tulburător",
    "tulburea": "tulbure",
    "tulburele": "tulbure",
    "tulburelui": "tulbure",
    "tulbureo": "tulbure",
    "tulburi": "tulbure",
    "tulburii": "tulbure",
    "tulburilor": "tulbure",
    "Tulce": "Tulcea",
    "Tulcei": "Tulcea",
    "Tulcii": "Tulcea",
    "nemaitulind": "tuli",
    "nemaitulindu": "tuli",
    "netulind": "tuli",
    "netulindu": "tuli",
    "tulea": "tuli",
    "tuleai": "tuli",
    "tuleam": "tuli",
    "tulească": "tuli",
    "tuleați": "tuli",
    "tuleau": "tuli",
    "tulesc": "tuli",
    "tulește": "tuli",
    "tulești": "tuli",
    "tulii": "tuli",
    "tulim": "tuli",
    "tulind": "tuli",
    "tulindu": "tuli",
    "tuliră": "tuli",
    "tulirăm": "tuli",
    "tulirăți": "tuli",
    "tulise": "tuli",
    "tulisem": "tuli",
    "tuliseră": "tuli",
    "tuliserăm": "tuli",
    "tuliserăți": "tuli",
    "tuliseși": "tuli",
    "tuliși": "tuli",
    "tulit": "tuli",
    "tuliți": "tuli",
    "tulitu": "tuli",
    "tulita": "tulit",
    "tulită": "tulit",
    "tulite": "tulit",
    "tulitei": "tulit",
    "tulitele": "tulit",
    "tulitelor": "tulit",
    "tuliți": "tulit",
    "tuliții": "tulit",
    "tuliților": "tulit",
    "tulito": "tulit",
    "tulitul": "tulit",
    "tulitului": "tulit",
    "tulnice": "tulnic",
    "tulnicele": "tulnic",
    "tulnicelor": "tulnic",
    "tulnicul": "tulnic",
    "tulnicului": "tulnic",
    "tumba": "tumbă",
    "tumbe": "tumbă",
    "tumbei": "tumbă",
    "tumbele": "tumbă",
    "tumbelor": "tumbă",
    "tumefacția": "tumefacție",
    "tumefacției": "tumefacție",
    "tumefacții": "tumefacție",
    "tumefacțiile": "tumefacție",
    "tumefacțiilor": "tumefacție",
    "nemaitumefiind": "tumefia",
    "nemaitumefiindu": "tumefia",
    "netumefiind": "tumefia",
    "netumefiindu": "tumefia",
    "tumefiai": "tumefia",
    "tumefiam": "tumefia",
    "tumefiară": "tumefia",
    "tumefiarăm": "tumefia",
    "tumefiarăți": "tumefia",
    "tumefiase": "tumefia",
    "tumefiasem": "tumefia",
    "tumefiaseră": "tumefia",
    "tumefiaserăm": "tumefia",
    "tumefiaserăți": "tumefia",
    "tumefiaseși": "tumefia",
    "tumefiași": "tumefia",
    "tumefiat": "tumefia",
    "tumefiați": "tumefia",
    "tumefiatu": "tumefia",
    "tumefiau": "tumefia",
    "tumefiază": "tumefia",
    "tumefie": "tumefia",
    "tumefiem": "tumefia",
    "tumefiez": "tumefia",
    "tumefieze": "tumefia",
    "tumefiezi": "tumefia",
    "tumefiind": "tumefia",
    "tumefiindu": "tumefia",
    "tumefiata": "tumefiat",
    "tumefiată": "tumefiat",
    "tumefiate": "tumefiat",
    "tumefiatei": "tumefiat",
    "tumefiatele": "tumefiat",
    "tumefiatelor": "tumefiat",
    "tumefiați": "tumefiat",
    "tumefiații": "tumefiat",
    "tumefiaților": "tumefiat",
    "tumefiato": "tumefiat",
    "tumefiatul": "tumefiat",
    "tumefiatule": "tumefiat",
    "tumefiatului": "tumefiat",
    "tumefierea": "tumefiere",
    "tumefiereo": "tumefiere",
    "tumefieri": "tumefiere",
    "tumefierii": "tumefiere",
    "tumefierile": "tumefiere",
    "tumefierilor": "tumefiere",
    "tumoarea": "tumoare",
    "tumori": "tumoare",
    "tumorii": "tumoare",
    "tumorile": "tumoare",
    "tumorilor": "tumoare",
    "tumora": "tumoră",
    "tumuli": "tumul",
    "tumulii": "tumul",
    "tumulilor": "tumul",
    "tumulul": "tumul",
    "tumulului": "tumul",
    "tumultul": "tumult",
    "tumultului": "tumult",
    "tumulturi": "tumult",
    "tumulturile": "tumult",
    "tumulturilor": "tumult",
    "tunul": "tun",
    "tunului": "tun",
    "tunuri": "tun",
    "tunurile": "tun",
    "tunurilor": "tun",
    "nemaitunând": "tuna",
    "nemaitunându": "tuna",
    "netunând": "tuna",
    "netunându": "tuna",
    "tun": "tuna",
    "tună": "tuna",
    "tunai": "tuna",
    "tunam": "tuna",
    "tunăm": "tuna",
    "tunând": "tuna",
    "tunându": "tuna",
    "tunară": "tuna",
    "tunarăm": "tuna",
    "tunarăți": "tuna",
    "tunase": "tuna",
    "tunasem": "tuna",
    "tunaseră": "tuna",
    "tunaserăm": "tuna",
    "tunaserăți": "tuna",
    "tunaseși": "tuna",
    "tunași": "tuna",
    "tunat": "tuna",
    "tunați": "tuna",
    "tunatu": "tuna",
    "tunau": "tuna",
    "tune": "tuna",
    "tuni": "tuna",
    "tunarea": "tunare",
    "tunareo": "tunare",
    "tunări": "tunare",
    "tunării": "tunare",
    "tunările": "tunare",
    "tunărilor": "tunare",
    "tunata": "tunat",
    "tunată": "tunat",
    "tunate": "tunat",
    "tunatei": "tunat",
    "tunatele": "tunat",
    "tunatelor": "tunat",
    "tunați": "tunat",
    "tunații": "tunat",
    "tunaților": "tunat",
    "tunato": "tunat",
    "tunatul": "tunat",
    "tunatule": "tunat",
    "tunatului": "tunat",
    "tunătoare": "tunător",
    "tunătoarea": "tunător",
    "tunătoarei": "tunător",
    "tunătoarele": "tunător",
    "tunătoarelor": "tunător",
    "tunătoareo": "tunător",
    "tunători": "tunător",
    "tunătorii": "tunător",
    "tunătorilor": "tunător",
    "tunătorul": "tunător",
    "tunătorule": "tunător",
    "tunătorului": "tunător",
    "nemaitunzând": "tunde",
    "nemaitunzându": "tunde",
    "netunzând": "tunde",
    "netunzându": "tunde",
    "tund": "tunde",
    "tundă": "tunde",
    "tundea": "tunde",
    "tundeai": "tunde",
    "tundeam": "tunde",
    "tundeați": "tunde",
    "tundeau": "tunde",
    "tundem": "tunde",
    "tundeți": "tunde",
    "tuns": "tunde",
    "tunse": "tunde",
    "tunsei": "tunde",
    "tunseră": "tunde",
    "tunserăm": "tunde",
    "tunserăți": "tunde",
    "tunsese": "tunde",
    "tunsesem": "tunde",
    "tunseseră": "tunde",
    "tunseserăm": "tunde",
    "tunseserăți": "tunde",
    "tunseseși": "tunde",
    "tunseși": "tunde",
    "tunsu": "tunde",
    "tunzând": "tunde",
    "tunzându": "tunde",
    "tunzi": "tunde",
    "tunderea": "tundere",
    "tundereo": "tundere",
    "tunderi": "tundere",
    "tunderii": "tundere",
    "tunderile": "tundere",
    "tunderilor": "tundere",
    "tundra": "tundră",
    "tundre": "tundră",
    "tundrei": "tundră",
    "tundrele": "tundră",
    "tundrelor": "tundră",
    "tunelul": "tunel",
    "tunelului": "tunel",
    "tuneluri": "tunel",
    "tunelurile": "tunel",
    "tunelurilor": "tunel",
    "tunete": "tunet",
    "tunetele": "tunet",
    "tunetelor": "tunet",
    "tunetul": "tunet",
    "tunetului": "tunet",
    "tungstenul": "tungsten",
    "tungstenului": "tungsten",
    "tungstenuri": "tungsten",
    "tungstenurile": "tungsten",
    "tungstenurilor": "tungsten",
    "tunica": "tunică",
    "tunici": "tunică",
    "tunicii": "tunică",
    "tunicile": "tunică",
    "tunicilor": "tunică",
    "tunico": "tunică",
    "Tunisie": "Tunisia",
    "Tunisiei": "Tunisia",
    "Tunisii": "Tunisia",
    "tunsa": "tuns",
    "tunsă": "tuns",
    "tunse": "tuns",
    "tunsei": "tuns",
    "tunsele": "tuns",
    "tunselor": "tuns",
    "tunși": "tuns",
    "tunșii": "tuns",
    "tunșilor": "tuns",
    "tunso": "tuns",
    "tunsul": "tuns",
    "tunsule": "tuns",
    "tunsului": "tuns",
    "tunsa": "tunsă",
    "tunse": "tunsă",
    "tunsei": "tunsă",
    "tunsele": "tunsă",
    "tunselor": "tunsă",
    "tunso": "tunsă",
    "tupeul": "tupeu",
    "tupeului": "tupeu",
    "tupeuri": "tupeu",
    "tupeurile": "tupeu",
    "tupeurilor": "tupeu",
    "nemaitupilând": "tupila",
    "nemaitupilându": "tupila",
    "netupilând": "tupila",
    "netupilându": "tupila",
    "tupilă": "tupila",
    "tupilai": "tupila",
    "tupilam": "tupila",
    "tupilăm": "tupila",
    "tupilând": "tupila",
    "tupilându": "tupila",
    "tupilară": "tupila",
    "tupilarăm": "tupila",
    "tupilarăți": "tupila",
    "tupilase": "tupila",
    "tupilasem": "tupila",
    "tupilaseră": "tupila",
    "tupilaserăm": "tupila",
    "tupilaserăți": "tupila",
    "tupilaseși": "tupila",
    "tupilași": "tupila",
    "tupilat": "tupila",
    "tupilați": "tupila",
    "tupilatu": "tupila",
    "tupilau": "tupila",
    "tupilează": "tupila",
    "tupilez": "tupila",
    "tupileze": "tupila",
    "tupilezi": "tupila",
    "tupilată": "tupilat",
    "tupilate": "tupilat",
    "tupilați": "tupilat",
    "turul": "tur",
    "turului": "tur",
    "tururi": "tur",
    "tururile": "tur",
    "tururilor": "tur",
    "tura": "tură",
    "ture": "tură",
    "turei": "tură",
    "turele": "tură",
    "turelor": "tură",
    "turația": "turație",
    "turației": "turație",
    "turații": "turație",
    "turațiile": "turație",
    "turațiilor": "turație",
    "nemaiturbând": "turba",
    "nemaiturbându": "turba",
    "neturbând": "turba",
    "neturbându": "turba",
    "turbă": "turba",
    "turbai": "turba",
    "turbam": "turba",
    "turbăm": "turba",
    "turbând": "turba",
    "turbându": "turba",
    "turbară": "turba",
    "turbarăm": "turba",
    "turbarăți": "turba",
    "turbase": "turba",
    "turbasem": "turba",
    "turbaseră": "turba",
    "turbaserăm": "turba",
    "turbaserăți": "turba",
    "turbaseși": "turba",
    "turbași": "turba",
    "turbat": "turba",
    "turbați": "turba",
    "turbatu": "turba",
    "turbau": "turba",
    "turbează": "turba",
    "turbez": "turba",
    "turbeze": "turba",
    "turbezi": "turba",
    "turba": "turbă",
    "turbe": "turbă",
    "turbei": "turbă",
    "turbele": "turbă",
    "turbelor": "turbă",
    "turbane": "turban",
    "turbanele": "turban",
    "turbanelor": "turban",
    "turbanul": "turban",
    "turbanului": "turban",
    "turbarea": "turbare",
    "turbareo": "turbare",
    "turbări": "turbare",
    "turbării": "turbare",
    "turbările": "turbare",
    "turbărilor": "turbare",
    "turbata": "turbat",
    "turbată": "turbat",
    "turbate": "turbat",
    "turbatei": "turbat",
    "turbatele": "turbat",
    "turbatelor": "turbat",
    "turbați": "turbat",
    "turbații": "turbat",
    "turbaților": "turbat",
    "turbato": "turbat",
    "turbatul": "turbat",
    "turbatule": "turbat",
    "turbatului": "turbat",
    "turbata": "turbată",
    "turbate": "turbată",
    "turbatei": "turbată",
    "turbatele": "turbată",
    "turbatelor": "turbată",
    "turbato": "turbată",
    "turbina": "turbină",
    "turbine": "turbină",
    "turbinei": "turbină",
    "turbinele": "turbină",
    "turbinelor": "turbină",
    "turbinca": "turbincă",
    "turbinci": "turbincă",
    "turbincii": "turbincă",
    "turbincile": "turbincă",
    "turbincilor": "turbincă",
    "turbulenta": "turbulent",
    "turbulentă": "turbulent",
    "turbulente": "turbulent",
    "turbulentei": "turbulent",
    "turbulentele": "turbulent",
    "turbulentelor": "turbulent",
    "turbulenți": "turbulent",
    "turbulenții": "turbulent",
    "turbulenților": "turbulent",
    "turbulentul": "turbulent",
    "turbulentului": "turbulent",
    "turbulența": "turbulență",
    "turbulențe": "turbulență",
    "turbulenței": "turbulență",
    "turbulențele": "turbulență",
    "turbulențelor": "turbulență",
    "turca": "turc",
    "turcă": "turc",
    "turce": "turc",
    "turcei": "turc",
    "turcele": "turc",
    "turcelor": "turc",
    "turci": "turc",
    "turcii": "turc",
    "turcilor": "turc",
    "turcul": "turc",
    "turcului": "turc",
    "turca": "turcă",
    "turcei": "turcă",
    "țurcana": "țurcan",
    "țurcană": "țurcan",
    "țurcane": "țurcan",
    "țurcanei": "țurcan",
    "țurcanele": "țurcan",
    "țurcanelor": "țurcan",
    "țurcani": "țurcan",
    "țurcanii": "țurcan",
    "țurcanilor": "țurcan",
    "țurcanul": "țurcan",
    "țurcanului": "țurcan",
    "turceasca": "turcesc",
    "turcească": "turcesc",
    "turcescul": "turcesc",
    "turcescului": "turcesc",
    "turcești": "turcesc",
    "turceștii": "turcesc",
    "turceștile": "turcesc",
    "turceștilor": "turcesc",
    "Turcie": "Turcia",
    "Turciei": "Turcia",
    "Turcii": "Turcia",
    "turco-americana": "turco-americană",
    "turco-americane": "turco-americană",
    "turco-americanei": "turco-americană",
    "turco-americanele": "turco-americană",
    "turco-americanelor": "turco-americană",
    "turela": "turelă",
    "turele": "turelă",
    "turelei": "turelă",
    "turelele": "turelă",
    "turelelor": "turelă",
    "turgescentul": "turgescent",
    "turgescentului": "turgescent",
    "turisme": "turism",
    "turismele": "turism",
    "turismelor": "turism",
    "turismul": "turism",
    "turismului": "turism",
    "turiști": "turist",
    "turiștii": "turist",
    "turiștilor": "turist",
    "turistul": "turist",
    "turistului": "turist",
    "turistice": "turistic",
    "turla": "turlă",
    "turle": "turlă",
    "turlei": "turlă",
    "turlele": "turlă",
    "turlelor": "turlă",
    "turma": "turmă",
    "turme": "turmă",
    "turmei": "turmă",
    "turmele": "turmă",
    "turmelor": "turmă",
    "nemaiturmentând": "turmenta",
    "nemaiturmentându": "turmenta",
    "neturmentând": "turmenta",
    "neturmentându": "turmenta",
    "turmentă": "turmenta",
    "turmentai": "turmenta",
    "turmentam": "turmenta",
    "turmentăm": "turmenta",
    "turmentând": "turmenta",
    "turmentându": "turmenta",
    "turmentară": "turmenta",
    "turmentarăm": "turmenta",
    "turmentarăți": "turmenta",
    "turmentase": "turmenta",
    "turmentasem": "turmenta",
    "turmentaseră": "turmenta",
    "turmentaserăm": "turmenta",
    "turmentaserăți": "turmenta",
    "turmentaseși": "turmenta",
    "turmentași": "turmenta",
    "turmentat": "turmenta",
    "turmentați": "turmenta",
    "turmentatu": "turmenta",
    "turmentau": "turmenta",
    "turmentează": "turmenta",
    "turmentez": "turmenta",
    "turmenteze": "turmenta",
    "turmentezi": "turmenta",
    "turmentarea": "turmentare",
    "turmentări": "turmentare",
    "turmentării": "turmentare",
    "turmentările": "turmentare",
    "turmentata": "turmentat",
    "turmentată": "turmentat",
    "turmentate": "turmentat",
    "turmentatei": "turmentat",
    "turmentatele": "turmentat",
    "turmentatelor": "turmentat",
    "turmentați": "turmentat",
    "turmentații": "turmentat",
    "turmentaților": "turmentat",
    "turmentatul": "turmentat",
    "turmentatului": "turmentat",
    "turmentata": "turmentată",
    "turmentate": "turmentată",
    "turmentatei": "turmentată",
    "turmentatele": "turmentată",
    "turmentatelor": "turmentată",
    "turnul": "turn",
    "turnului": "turn",
    "turnuri": "turn",
    "turnurile": "turn",
    "turnurilor": "turn",
    "nemaiturnând": "turna",
    "nemaiturnându": "turna",
    "neturnând": "turna",
    "neturnându": "turna",
    "toarnă": "turna",
    "toarne": "turna",
    "torn": "turna",
    "torni": "turna",
    "turnă": "turna",
    "turnai": "turna",
    "turnam": "turna",
    "turnăm": "turna",
    "turnând": "turna",
    "turnându": "turna",
    "turnară": "turna",
    "turnarăm": "turna",
    "turnarăți": "turna",
    "turnase": "turna",
    "turnasem": "turna",
    "turnaseră": "turna",
    "turnaserăm": "turna",
    "turnaserăți": "turna",
    "turnaseși": "turna",
    "turnași": "turna",
    "turnat": "turna",
    "turnați": "turna",
    "turnatu": "turna",
    "turnau": "turna",
    "turnanta": "turnant",
    "turnantă": "turnant",
    "turnante": "turnant",
    "turnantei": "turnant",
    "turnantele": "turnant",
    "turnantelor": "turnant",
    "turnanți": "turnant",
    "turnanții": "turnant",
    "turnanților": "turnant",
    "turnantul": "turnant",
    "turnantului": "turnant",
    "turnarea": "turnare",
    "turnareo": "turnare",
    "turnări": "turnare",
    "turnării": "turnare",
    "turnările": "turnare",
    "turnărilor": "turnare",
    "turnata": "turnat",
    "turnată": "turnat",
    "turnate": "turnat",
    "turnatei": "turnat",
    "turnatele": "turnat",
    "turnatelor": "turnat",
    "turnați": "turnat",
    "turnații": "turnat",
    "turnaților": "turnat",
    "turnato": "turnat",
    "turnatul": "turnat",
    "turnatule": "turnat",
    "turnatului": "turnat",
    "turnătoarea": "turnătoare",
    "turnătoarei": "turnătoare",
    "turnătoarele": "turnătoare",
    "turnătoarelor": "turnătoare",
    "turnătoare": "turnător",
    "turnătoarea": "turnător",
    "turnătoarei": "turnător",
    "turnătoarele": "turnător",
    "turnătoarelor": "turnător",
    "turnători": "turnător",
    "turnătorii": "turnător",
    "turnătorilor": "turnător",
    "turnătorul": "turnător",
    "turnătorului": "turnător",
    "turnătoria": "turnătorie",
    "turnătoriei": "turnătorie",
    "turnătorii": "turnătorie",
    "turnătoriile": "turnătorie",
    "turnătoriilor": "turnătorie",
    "turnesolul": "turnesol",
    "turnesolului": "turnesol",
    "turnesoluri": "turnesol",
    "turnesolurile": "turnesol",
    "turnesolurilor": "turnesol",
    "turnee": "turneu",
    "turneele": "turneu",
    "turneelor": "turneu",
    "turneul": "turneu",
    "turneului": "turneu",
    "turnire": "turnir",
    "turnirele": "turnir",
    "turnirelor": "turnir",
    "turnirul": "turnir",
    "turnirului": "turnir",
    "TR.": "Turnu",
    "turnulețe": "turnuleț",
    "turnulețele": "turnuleț",
    "turnulețelor": "turnuleț",
    "turnulețul": "turnuleț",
    "turnulețului": "turnuleț",
    "turnura": "turnură",
    "turnuri": "turnură",
    "turnurii": "turnură",
    "turnurile": "turnură",
    "turnurilor": "turnură",
    "turoperatorilor": "turoperator",
    "turta": "turtă",
    "turte": "turtă",
    "turtei": "turtă",
    "turtele": "turtă",
    "turtelor": "turtă",
    "turto": "turtă",
    "nemaiturtind": "turti",
    "nemaiturtindu": "turti",
    "neturtind": "turti",
    "neturtindu": "turti",
    "turtea": "turti",
    "turteai": "turti",
    "turteam": "turti",
    "turtească": "turti",
    "turteați": "turti",
    "turteau": "turti",
    "turtesc": "turti",
    "turtește": "turti",
    "turtești": "turti",
    "turtii": "turti",
    "turtim": "turti",
    "turtind": "turti",
    "turtindu": "turti",
    "turtiră": "turti",
    "turtirăm": "turti",
    "turtirăți": "turti",
    "turtise": "turti",
    "turtisem": "turti",
    "turtiseră": "turti",
    "turtiserăm": "turti",
    "turtiserăți": "turti",
    "turtiseși": "turti",
    "turtiși": "turti",
    "turtit": "turti",
    "turtiți": "turti",
    "turtitu": "turti",
    "turtirea": "turtire",
    "turtireo": "turtire",
    "turtiri": "turtire",
    "turtirii": "turtire",
    "turtirile": "turtire",
    "turtirilor": "turtire",
    "turtita": "turtit",
    "turtită": "turtit",
    "turtite": "turtit",
    "turtitei": "turtit",
    "turtitele": "turtit",
    "turtitelor": "turtit",
    "turtiți": "turtit",
    "turtiții": "turtit",
    "turtiților": "turtit",
    "turtito": "turtit",
    "turtitul": "turtit",
    "turtitule": "turtit",
    "turtitului": "turtit",
    "țurțuri": "țurțur",
    "țurțurii": "țurțur",
    "țurțurilor": "țurțur",
    "țurțurul": "țurțur",
    "țurțurului": "țurțur",
    "țurțurata": "țurțurat",
    "țurțurată": "țurțurat",
    "țurțurate": "țurțurat",
    "țurțuratei": "țurțurat",
    "țurțuratele": "țurțurat",
    "țurțuratelor": "țurțurat",
    "țurțurati": "țurțurat",
    "țurțurați": "țurțurat",
    "țurțuratii": "țurțurat",
    "țurțurații": "țurțurat",
    "țurțuratilor": "țurțurat",
    "țurțuraților": "țurțurat",
    "țurțuratul": "țurțurat",
    "țurțuratului": "țurțurat",
    "nemaituruind": "turui",
    "nemaituruindu": "turui",
    "neturuind": "turui",
    "neturuindu": "turui",
    "turuia": "turui",
    "turuiai": "turui",
    "turuiam": "turui",
    "turuiați": "turui",
    "turuiau": "turui",
    "turuie": "turui",
    "turuii": "turui",
    "turuim": "turui",
    "turuind": "turui",
    "turuindu": "turui",
    "turuiră": "turui",
    "turuirăm": "turui",
    "turuirăți": "turui",
    "turuise": "turui",
    "turuisem": "turui",
    "turuiseră": "turui",
    "turuiserăm": "turui",
    "turuiserăți": "turui",
    "turuiseși": "turui",
    "turuiși": "turui",
    "turuit": "turui",
    "turuiți": "turui",
    "turuitu": "turui",
    "turuiala": "turuială",
    "turuialo": "turuială",
    "turuieli": "turuială",
    "turuielii": "turuială",
    "turuielile": "turuială",
    "turuielilor": "turuială",
    "turuirea": "turuire",
    "turuireo": "turuire",
    "turuiri": "turuire",
    "turuirii": "turuire",
    "turuirile": "turuire",
    "turuirilor": "turuire",
    "turuita": "turuit",
    "turuită": "turuit",
    "turuite": "turuit",
    "turuitei": "turuit",
    "turuitele": "turuit",
    "turuitelor": "turuit",
    "turuiți": "turuit",
    "turuiții": "turuit",
    "turuiților": "turuit",
    "turuito": "turuit",
    "turuitul": "turuit",
    "turuitule": "turuit",
    "turuitului": "turuit",
    "tușul": "tuș",
    "tușului": "tuș",
    "tușuri": "tuș",
    "tușurile": "tuș",
    "tușurilor": "tuș",
    "tușa": "tușă",
    "tușe": "tușă",
    "tușei": "tușă",
    "tușele": "tușă",
    "tușelor": "tușă",
    "tusea": "tuse",
    "tusei": "tuse",
    "tusele": "tuse",
    "tuselor": "tuse",
    "tuseo": "tuse",
    "tușeul": "tușeu",
    "tușeului": "tușeu",
    "tușeuri": "tușeu",
    "tușeurile": "tușeu",
    "tușeurilor": "tușeu",
    "nemaitușind": "tuși",
    "nemaitușindu": "tuși",
    "netușind": "tuși",
    "netușindu": "tuși",
    "tușea": "tuși",
    "tușeai": "tuși",
    "tușeam": "tuși",
    "tușească": "tuși",
    "tușeați": "tuși",
    "tușeau": "tuși",
    "tușesc": "tuși",
    "tușește": "tuși",
    "tușești": "tuși",
    "tușii": "tuși",
    "tușim": "tuși",
    "tușind": "tuși",
    "tușindu": "tuși",
    "tușiră": "tuși",
    "tușirăm": "tuși",
    "tușirăți": "tuși",
    "tușise": "tuși",
    "tușisem": "tuși",
    "tușiseră": "tuși",
    "tușiserăm": "tuși",
    "tușiserăți": "tuși",
    "tușiseși": "tuși",
    "tușiși": "tuși",
    "tușit": "tuși",
    "tușiți": "tuși",
    "tușitu": "tuși",
    "tușirea": "tușire",
    "tușireo": "tușire",
    "tușiri": "tușire",
    "tușirii": "tușire",
    "tușirile": "tușire",
    "tușirilor": "tușire",
    "tușita": "tușit",
    "tușită": "tușit",
    "tușite": "tușit",
    "tușitei": "tușit",
    "tușitele": "tușit",
    "tușitelor": "tușit",
    "tușiți": "tușit",
    "tușiții": "tușit",
    "tușiților": "tușit",
    "tușito": "tușit",
    "tușitul": "tușit",
    "tușitule": "tușit",
    "tușitului": "tușit",
    "tutela": "tutelă",
    "tutele": "tutelă",
    "tutelei": "tutelă",
    "tutelele": "tutelă",
    "tutelelor": "tutelă",
    "tutorele": "tutore",
    "tutorelui": "tutore",
    "tutori": "tutore",
    "tutorii": "tutore",
    "tutorilor": "tutore",
    "tutuia": "tutui",
    "tutuiai": "tutui",
    "tutuiam": "tutui",
    "tutuiați": "tutui",
    "tutuiau": "tutui",
    "tutuie": "tutui",
    "tutuii": "tutui",
    "tutuim": "tutui",
    "tutuind": "tutui",
    "tutuindu": "tutui",
    "tutuiră": "tutui",
    "tutuirăm": "tutui",
    "tutuirăți": "tutui",
    "tutuise": "tutui",
    "tutuisem": "tutui",
    "tutuiseră": "tutui",
    "tutuiserăm": "tutui",
    "tutuiserăți": "tutui",
    "tutuiseși": "tutui",
    "tutuiși": "tutui",
    "tutuit": "tutui",
    "tutuiți": "tutui",
    "tutuitu": "tutui",
    "tutuiala": "tutuială",
    "tutuialo": "tutuială",
    "tutuieli": "tutuială",
    "tutuielii": "tutuială",
    "tutuielile": "tutuială",
    "tutuielilor": "tutuială",
    "tutuirea": "tutuire",
    "tutuireo": "tutuire",
    "tutuiri": "tutuire",
    "tutuirii": "tutuire",
    "tutuirile": "tutuire",
    "tutuirilor": "tutuire",
    "tutuita": "tutuit",
    "tutuită": "tutuit",
    "tutuite": "tutuit",
    "tutuitei": "tutuit",
    "tutuitele": "tutuit",
    "tutuitelor": "tutuit",
    "tutuiți": "tutuit",
    "tutuiții": "tutuit",
    "tutuiților": "tutuit",
    "tutuito": "tutuit",
    "tutuitul": "tutuit",
    "tutuitule": "tutuit",
    "tutuitului": "tutuit",
    "tutunul": "tutun",
    "tutunule": "tutun",
    "tutunului": "tutun",
    "tutunuri": "tutun",
    "tutunurile": "tutun",
    "tutunurilor": "tutun",
    "twistul": "twist",
    "twistului": "twist",
    "twisturi": "twist",
    "twisturile": "twist",
    "twisturilor": "twist",
    "ucenici": "ucenic",
    "ucenicii": "ucenic",
    "ucenicilor": "ucenic",
    "ucenicul": "ucenic",
    "ucenicului": "ucenic",
    "ucenica": "ucenică",
    "ucenice": "ucenică",
    "ucenicei": "ucenică",
    "ucenicele": "ucenică",
    "ucenicelor": "ucenică",
    "nemaiucenicind": "ucenici",
    "nemaiucenicindu": "ucenici",
    "neucenicind": "ucenici",
    "neucenicindu": "ucenici",
    "ucenicea": "ucenici",
    "uceniceai": "ucenici",
    "uceniceam": "ucenici",
    "ucenicească": "ucenici",
    "uceniceați": "ucenici",
    "uceniceau": "ucenici",
    "ucenicesc": "ucenici",
    "ucenicește": "ucenici",
    "ucenicești": "ucenici",
    "ucenicii": "ucenici",
    "ucenicim": "ucenici",
    "ucenicind": "ucenici",
    "ucenicindu": "ucenici",
    "uceniciră": "ucenici",
    "ucenicirăm": "ucenici",
    "ucenicirăți": "ucenici",
    "ucenicise": "ucenici",
    "ucenicisem": "ucenici",
    "uceniciseră": "ucenici",
    "uceniciserăm": "ucenici",
    "uceniciserăți": "ucenici",
    "uceniciseși": "ucenici",
    "uceniciși": "ucenici",
    "ucenicit": "ucenici",
    "uceniciți": "ucenici",
    "ucenicită": "ucenicit",
    "ucenicite": "ucenicit",
    "uceniciți": "ucenicit",
    "nemaiucigând": "ucide",
    "nemaiucigându": "ucide",
    "neucigând": "ucide",
    "neucigându": "ucide",
    "ucid": "ucide",
    "ucidă": "ucide",
    "ucidea": "ucide",
    "ucideai": "ucide",
    "ucideam": "ucide",
    "ucideați": "ucide",
    "ucideau": "ucide",
    "ucidem": "ucide",
    "ucideți": "ucide",
    "ucigând": "ucide",
    "ucigându": "ucide",
    "ucis": "ucide",
    "ucise": "ucide",
    "ucisei": "ucide",
    "uciseră": "ucide",
    "uciserăm": "ucide",
    "uciserăți": "ucide",
    "ucisese": "ucide",
    "ucisesem": "ucide",
    "uciseseră": "ucide",
    "uciseserăm": "ucide",
    "uciseserăți": "ucide",
    "uciseseși": "ucide",
    "uciseși": "ucide",
    "ucizi": "ucide",
    "uciderea": "ucidere",
    "ucidereo": "ucidere",
    "ucideri": "ucidere",
    "uciderii": "ucidere",
    "uciderile": "ucidere",
    "uciderilor": "ucidere",
    "ucigașa": "ucigaș",
    "ucigașă": "ucigaș",
    "ucigașe": "ucigaș",
    "ucigașei": "ucigaș",
    "ucigașele": "ucigaș",
    "ucigașelor": "ucigaș",
    "ucigași": "ucigaș",
    "ucigașii": "ucigaș",
    "ucigașilor": "ucigaș",
    "ucigașul": "ucigaș",
    "ucigașului": "ucigaș",
    "ucigașa": "ucigașă",
    "ucigașe": "ucigașă",
    "ucigașei": "ucigașă",
    "ucigașele": "ucigașă",
    "ucigașelor": "ucigașă",
    "ucigătoare": "ucigător",
    "ucigătoarea": "ucigător",
    "ucigătoarei": "ucigător",
    "ucigătoarele": "ucigător",
    "ucigătoarelor": "ucigător",
    "ucigători": "ucigător",
    "ucigătorii": "ucigător",
    "ucigătorilor": "ucigător",
    "ucigătorul": "ucigător",
    "ucigătorului": "ucigător",
    "ucisa": "ucis",
    "ucisă": "ucis",
    "ucise": "ucis",
    "ucisei": "ucis",
    "ucisele": "ucis",
    "uciselor": "ucis",
    "uciși": "ucis",
    "ucișii": "ucis",
    "ucișilor": "ucis",
    "ucisul": "ucis",
    "ucisului": "ucis",
    "Ucrainei": "Ucraina",
    "ucraineana": "ucrainean",
    "ucraineană": "ucrainean",
    "ucraineanul": "ucrainean",
    "ucraineanului": "ucrainean",
    "ucrainene": "ucrainean",
    "ucrainenei": "ucrainean",
    "ucrainenele": "ucrainean",
    "ucrainenelor": "ucrainean",
    "ucraineni": "ucrainean",
    "ucrainenii": "ucrainean",
    "ucrainenilor": "ucrainean",
    "uda": "ud",
    "udă": "ud",
    "ude": "ud",
    "udei": "ud",
    "udele": "ud",
    "udelor": "ud",
    "udul": "ud",
    "udului": "ud",
    "uzi": "ud",
    "uzii": "ud",
    "uzilor": "ud",
    "nemaiudând": "uda",
    "nemaiudându": "uda",
    "neudând": "uda",
    "neudându": "uda",
    "ud": "uda",
    "udă": "uda",
    "udai": "uda",
    "udam": "uda",
    "udăm": "uda",
    "udând": "uda",
    "udându": "uda",
    "udară": "uda",
    "udarăm": "uda",
    "udarăți": "uda",
    "udase": "uda",
    "udasem": "uda",
    "udaseră": "uda",
    "udaserăm": "uda",
    "udaserăți": "uda",
    "udaseși": "uda",
    "udași": "uda",
    "udat": "uda",
    "udați": "uda",
    "udau": "uda",
    "ude": "uda",
    "uzi": "uda",
    "udarea": "udare",
    "udareo": "udare",
    "udări": "udare",
    "udării": "udare",
    "udările": "udare",
    "udărilor": "udare",
    "udată": "udat",
    "udate": "udat",
    "udați": "udat",
    "udătura": "udătură",
    "udături": "udătură",
    "udăturii": "udătură",
    "udăturile": "udătură",
    "udăturilor": "udătură",
    "udăturo": "udătură",
    "udemeriști": "udemerist",
    "udemeriștii": "udemerist",
    "udemeriștilor": "udemerist",
    "udemeristul": "udemerist",
    "udemeristului": "udemerist",
    "ugere": "uger",
    "ugerele": "uger",
    "ugerelor": "uger",
    "ugerul": "uger",
    "ugerului": "uger",
    "nemaiuguind": "ugui",
    "nemaiuguindu": "ugui",
    "neuguind": "ugui",
    "neuguindu": "ugui",
    "uguia": "ugui",
    "uguiai": "ugui",
    "uguiam": "ugui",
    "uguiați": "ugui",
    "uguiau": "ugui",
    "uguie": "ugui",
    "uguii": "ugui",
    "uguim": "ugui",
    "uguind": "ugui",
    "uguindu": "ugui",
    "uguiră": "ugui",
    "uguirăm": "ugui",
    "uguirăți": "ugui",
    "uguise": "ugui",
    "uguisem": "ugui",
    "uguiseră": "ugui",
    "uguiserăm": "ugui",
    "uguiserăți": "ugui",
    "uguiseși": "ugui",
    "uguiși": "ugui",
    "uguit": "ugui",
    "uguiți": "ugui",
    "uguirea": "uguire",
    "uguireo": "uguire",
    "uguiri": "uguire",
    "uguirii": "uguire",
    "uguirile": "uguire",
    "uguirilor": "uguire",
    "uguită": "uguit",
    "uguite": "uguit",
    "uguiți": "uguit",
    "nemaiuimind": "uimi",
    "nemaiuimindu": "uimi",
    "neuimind": "uimi",
    "neuimindu": "uimi",
    "uimea": "uimi",
    "uimeai": "uimi",
    "uimeam": "uimi",
    "uimească": "uimi",
    "uimeați": "uimi",
    "uimeau": "uimi",
    "uimesc": "uimi",
    "uimește": "uimi",
    "uimești": "uimi",
    "uimii": "uimi",
    "uimim": "uimi",
    "uimind": "uimi",
    "uimindu": "uimi",
    "uimiră": "uimi",
    "uimirăm": "uimi",
    "uimirăți": "uimi",
    "uimise": "uimi",
    "uimisem": "uimi",
    "uimiseră": "uimi",
    "uimiserăm": "uimi",
    "uimiserăți": "uimi",
    "uimiseși": "uimi",
    "uimiși": "uimi",
    "uimit": "uimi",
    "uimiți": "uimi",
    "uimirea": "uimire",
    "uimireo": "uimire",
    "uimiri": "uimire",
    "uimirii": "uimire",
    "uimirile": "uimire",
    "uimirilor": "uimire",
    "uimita": "uimit",
    "uimită": "uimit",
    "uimite": "uimit",
    "uimitei": "uimit",
    "uimitele": "uimit",
    "uimitelor": "uimit",
    "uimiți": "uimit",
    "uimiții": "uimit",
    "uimiților": "uimit",
    "uimito": "uimit",
    "uimitul": "uimit",
    "uimitule": "uimit",
    "uimitului": "uimit",
    "uimitoare": "uimitor",
    "uimitoarea": "uimitor",
    "uimitoarei": "uimitor",
    "uimitoarele": "uimitor",
    "uimitoarelor": "uimitor",
    "uimitori": "uimitor",
    "uimitorii": "uimitor",
    "uimitorilor": "uimitor",
    "uimitorul": "uimitor",
    "uimitorului": "uimitor",
    "nemaiuitând": "uita",
    "nemaiuitându": "uita",
    "neuitând": "uita",
    "neuitându": "uita",
    "uit": "uita",
    "uită": "uita",
    "uitai": "uita",
    "uitam": "uita",
    "uităm": "uita",
    "uitând": "uita",
    "uitându": "uita",
    "uitară": "uita",
    "uitarăm": "uita",
    "uitarăți": "uita",
    "uitase": "uita",
    "uitasem": "uita",
    "uitaseră": "uita",
    "uitaserăm": "uita",
    "uitaserăți": "uita",
    "uitaseși": "uita",
    "uitași": "uita",
    "uitat": "uita",
    "uitați": "uita",
    "uitau": "uita",
    "uite": "uita",
    "uiți": "uita",
    "uitarea": "uitare",
    "uitareo": "uitare",
    "uitări": "uitare",
    "uitării": "uitare",
    "uitările": "uitare",
    "uitărilor": "uitare",
    "uitată": "uitat",
    "uitate": "uitat",
    "uitați": "uitat",
    "uitătura": "uitătură",
    "uitături": "uitătură",
    "uităturii": "uitătură",
    "uităturile": "uitătură",
    "uităturilor": "uitătură",
    "uităturo": "uitătură",
    "uituca": "uituc",
    "uitucă": "uituc",
    "uituce": "uituc",
    "uitucei": "uituc",
    "uitucele": "uituc",
    "uitucelor": "uituc",
    "uituci": "uituc",
    "uitucii": "uituc",
    "uitucilor": "uituc",
    "uitucul": "uituc",
    "uitucului": "uituc",
    "ulceaua": "ulcea",
    "ulcele": "ulcea",
    "ulcelei": "ulcea",
    "ulcelele": "ulcea",
    "ulcelelor": "ulcea",
    "ulcelușa": "ulcelușă",
    "ulcelușe": "ulcelușă",
    "ulcelușei": "ulcelușă",
    "ulcelușele": "ulcelușă",
    "ulcelușelor": "ulcelușă",
    "ulceluța": "ulceluță",
    "ulceluțe": "ulceluță",
    "ulceluței": "ulceluță",
    "ulceluțele": "ulceluță",
    "ulceluțelor": "ulceluță",
    "ulcere": "ulcer",
    "ulcerele": "ulcer",
    "ulcerelor": "ulcer",
    "ulcerul": "ulcer",
    "ulcerului": "ulcer",
    "nemaiulcerând": "ulcera",
    "nemaiulcerându": "ulcera",
    "neulcerând": "ulcera",
    "neulcerându": "ulcera",
    "ulceră": "ulcera",
    "ulcerai": "ulcera",
    "ulceram": "ulcera",
    "ulcerăm": "ulcera",
    "ulcerând": "ulcera",
    "ulcerându": "ulcera",
    "ulcerară": "ulcera",
    "ulcerarăm": "ulcera",
    "ulcerarăți": "ulcera",
    "ulcerase": "ulcera",
    "ulcerasem": "ulcera",
    "ulceraseră": "ulcera",
    "ulceraserăm": "ulcera",
    "ulceraserăți": "ulcera",
    "ulceraseși": "ulcera",
    "ulcerași": "ulcera",
    "ulcerat": "ulcera",
    "ulcerați": "ulcera",
    "ulcerau": "ulcera",
    "ulcerează": "ulcera",
    "ulcerez": "ulcera",
    "ulcereze": "ulcera",
    "ulcerezi": "ulcera",
    "ulcerarea": "ulcerare",
    "ulcerareo": "ulcerare",
    "ulcerări": "ulcerare",
    "ulcerării": "ulcerare",
    "ulcerările": "ulcerare",
    "ulcerărilor": "ulcerare",
    "ulcerata": "ulcerat",
    "ulcerată": "ulcerat",
    "ulcerate": "ulcerat",
    "ulceratei": "ulcerat",
    "ulceratele": "ulcerat",
    "ulceratelor": "ulcerat",
    "ulcerați": "ulcerat",
    "ulcerații": "ulcerat",
    "ulceraților": "ulcerat",
    "ulcerato": "ulcerat",
    "ulceratul": "ulcerat",
    "ulceratule": "ulcerat",
    "ulceratului": "ulcerat",
    "ulcerația": "ulcerație",
    "ulcerației": "ulcerație",
    "ulcerații": "ulcerație",
    "ulcerațiile": "ulcerație",
    "ulcerațiilor": "ulcerație",
    "ulcica": "ulcică",
    "ulcioare": "ulcior",
    "ulcioarele": "ulcior",
    "ulcioarelor": "ulcior",
    "ulciorul": "ulcior",
    "ulciorului": "ulcior",
    "urcioare": "ulcior",
    "urcioarele": "ulcior",
    "urcioarelor": "ulcior",
    "urcior": "ulcior",
    "urciorul": "ulcior",
    "urciorului": "ulcior",
    "ulciorușe": "ulcioruș",
    "ulciorușele": "ulcioruș",
    "ulciorușelor": "ulcioruș",
    "ulciorușul": "ulcioruș",
    "ulciorușului": "ulcioruș",
    "uleiul": "ulei",
    "uleiului": "ulei",
    "uleiuri": "ulei",
    "uleiurile": "ulei",
    "uleiurilor": "ulei",
    "nemaiuleiind": "uleia",
    "nemaiuleiindu": "uleia",
    "neuleiind": "uleia",
    "neuleiindu": "uleia",
    "uleiai": "uleia",
    "uleiam": "uleia",
    "uleiară": "uleia",
    "uleiarăm": "uleia",
    "uleiarăți": "uleia",
    "uleiase": "uleia",
    "uleiasem": "uleia",
    "uleiaseră": "uleia",
    "uleiaserăm": "uleia",
    "uleiaserăți": "uleia",
    "uleiaseși": "uleia",
    "uleiași": "uleia",
    "uleiat": "uleia",
    "uleiați": "uleia",
    "uleiau": "uleia",
    "uleiază": "uleia",
    "uleie": "uleia",
    "uleiem": "uleia",
    "uleiez": "uleia",
    "uleieze": "uleia",
    "uleiezi": "uleia",
    "uleind": "uleia",
    "uleindu": "uleia",
    "uleiata": "uleiat",
    "uleiată": "uleiat",
    "uleiate": "uleiat",
    "uleiatei": "uleiat",
    "uleiatele": "uleiat",
    "uleiatelor": "uleiat",
    "uleiați": "uleiat",
    "uleiații": "uleiat",
    "uleiaților": "uleiat",
    "uleiato": "uleiat",
    "uleiatul": "uleiat",
    "uleiatule": "uleiat",
    "uleiatului": "uleiat",
    "uleierea": "uleiere",
    "uleiereo": "uleiere",
    "uleieri": "uleiere",
    "uleierii": "uleiere",
    "uleierile": "uleiere",
    "uleierilor": "uleiere",
    "uleioasa": "uleios",
    "uleioasă": "uleios",
    "uleioase": "uleios",
    "uleioasei": "uleios",
    "uleioasele": "uleios",
    "uleioaselor": "uleios",
    "uleioși": "uleios",
    "uleioșii": "uleios",
    "uleioșilor": "uleios",
    "uleiosul": "uleios",
    "uleiosului": "uleios",
    "ulița": "uliță",
    "ulițe": "uliță",
    "uliței": "uliță",
    "ulițele": "uliță",
    "ulițelor": "uliță",
    "ulii": "uliu",
    "uliii": "uliu",
    "uliilor": "uliu",
    "uliul": "uliu",
    "uliului": "uliu",
    "ulmi": "ulm",
    "ulmii": "ulm",
    "ulmilor": "ulm",
    "ulmul": "ulm",
    "ulmului": "ulm",
    "ulterioara": "ulterior",
    "ulterioară": "ulterior",
    "ulterioare": "ulterior",
    "ulterioarei": "ulterior",
    "ulterioarele": "ulterior",
    "ulterioarelor": "ulterior",
    "ulteriori": "ulterior",
    "ulteriorii": "ulterior",
    "ulteriorilor": "ulterior",
    "ulteriorul": "ulterior",
    "ulteriorului": "ulterior",
    "ultima": "ultim",
    "ultimă": "ultim",
    "ultime": "ultim",
    "ultimei": "ultim",
    "ultimele": "ultim",
    "ultimelor": "ultim",
    "ultimi": "ultim",
    "ultimii": "ultim",
    "ultimilor": "ultim",
    "ultimul": "ultim",
    "ultimului": "ultim",
    "ultimativa": "ultimativ",
    "ultimativă": "ultimativ",
    "ultimative": "ultimativ",
    "ultimativei": "ultimativ",
    "ultimativele": "ultimativ",
    "ultimativelor": "ultimativ",
    "ultimativi": "ultimativ",
    "ultimativii": "ultimativ",
    "ultimativilor": "ultimativ",
    "ultimativul": "ultimativ",
    "ultimativului": "ultimativ",
    "ultimatumul": "ultimatum",
    "ultimatumului": "ultimatum",
    "ultimatumuri": "ultimatum",
    "ultimatumurile": "ultimatum",
    "ultimatumurilor": "ultimatum",
    "ultrafiltre": "ultrafiltru",
    "ultrafiltrele": "ultrafiltru",
    "ultrafiltrelor": "ultrafiltru",
    "ultrafiltrul": "ultrafiltru",
    "ultrafiltrului": "ultrafiltru",
    "nemaiultragiând": "ultragia",
    "nemaiultragiându": "ultragia",
    "neultragiând": "ultragia",
    "neultragiându": "ultragia",
    "ultragiă": "ultragia",
    "ultragiai": "ultragia",
    "ultragiam": "ultragia",
    "ultragiăm": "ultragia",
    "ultragiară": "ultragia",
    "ultragiarăm": "ultragia",
    "ultragiarăți": "ultragia",
    "ultragiase": "ultragia",
    "ultragiasem": "ultragia",
    "ultragiaseră": "ultragia",
    "ultragiaserăm": "ultragia",
    "ultragiaserăți": "ultragia",
    "ultragiaseși": "ultragia",
    "ultragiași": "ultragia",
    "ultragiat": "ultragia",
    "ultragiați": "ultragia",
    "ultragiau": "ultragia",
    "ultragiază": "ultragia",
    "ultragiez": "ultragia",
    "ultragieze": "ultragia",
    "ultragiezi": "ultragia",
    "ultragiind": "ultragia",
    "ultragiindu": "ultragia",
    "ultragiata": "ultragiat",
    "ultragiată": "ultragiat",
    "ultragiate": "ultragiat",
    "ultragiatei": "ultragiat",
    "ultragiatele": "ultragiat",
    "ultragiatelor": "ultragiat",
    "ultragiați": "ultragiat",
    "ultragiații": "ultragiat",
    "ultragiaților": "ultragiat",
    "ultragiatul": "ultragiat",
    "ultragiatului": "ultragiat",
    "ultragii": "ultragiu",
    "ultragiile": "ultragiu",
    "ultragiilor": "ultragiu",
    "ultragiul": "ultragiu",
    "ultragiului": "ultragiu",
    "ultraje": "ultraj",
    "ultrajele": "ultraj",
    "ultrajelor": "ultraj",
    "ultrajul": "ultraj",
    "ultrajului": "ultraj",
    "ultramarine": "ultramarin",
    "ultramarinele": "ultramarin",
    "ultramarinelor": "ultramarin",
    "ultramarinul": "ultramarin",
    "ultramarinului": "ultramarin",
    "ultramicrochimia": "ultramicrochimie",
    "ultramicrochimiei": "ultramicrochimie",
    "ultramicrochimii": "ultramicrochimie",
    "ultramicrochimiile": "ultramicrochimie",
    "ultramicrochimiilor": "ultramicrochimie",
    "ultramicroscoape": "ultramicroscop",
    "ultramicroscoapele": "ultramicroscop",
    "ultramicroscoapelor": "ultramicroscop",
    "ultramicroscopul": "ultramicroscop",
    "ultramicroscopului": "ultramicroscop",
    "ultramoderna": "ultramodern",
    "ultramodernă": "ultramodern",
    "ultramoderne": "ultramodern",
    "ultramodernei": "ultramodern",
    "ultramodernele": "ultramodern",
    "ultramodernelor": "ultramodern",
    "ultramoderni": "ultramodern",
    "ultramodernii": "ultramodern",
    "ultramodernilor": "ultramodern",
    "ultramodernul": "ultramodern",
    "ultramodernului": "ultramodern",
    "ultrasecreta": "ultrasecret",
    "ultrasecretă": "ultrasecret",
    "ultrasecrete": "ultrasecret",
    "ultrasecretei": "ultrasecret",
    "ultrasecretele": "ultrasecret",
    "ultrasecretelor": "ultrasecret",
    "ultrasecreți": "ultrasecret",
    "ultrasecreții": "ultrasecret",
    "ultrasecreților": "ultrasecret",
    "ultrasecretul": "ultrasecret",
    "ultrasecretului": "ultrasecret",
    "ultrasunete": "ultrasunet",
    "ultrasunetele": "ultrasunet",
    "ultrasunetelor": "ultrasunet",
    "ultrasunetul": "ultrasunet",
    "ultrasunetului": "ultrasunet",
    "ultravioleți": "ultraviolet",
    "ultravioleții": "ultraviolet",
    "ultravioleților": "ultraviolet",
    "ultravioletul": "ultraviolet",
    "ultravioletului": "ultraviolet",
    "uluce": "uluc",
    "ulucele": "uluc",
    "ulucelor": "uluc",
    "ulucul": "uluc",
    "ulucului": "uluc",
    "nemaiulucind": "uluci",
    "nemaiulucindu": "uluci",
    "neulucind": "uluci",
    "neulucindu": "uluci",
    "ulucea": "uluci",
    "uluceai": "uluci",
    "uluceam": "uluci",
    "ulucească": "uluci",
    "uluceați": "uluci",
    "uluceau": "uluci",
    "ulucesc": "uluci",
    "ulucește": "uluci",
    "ulucești": "uluci",
    "ulucii": "uluci",
    "ulucim": "uluci",
    "ulucind": "uluci",
    "ulucindu": "uluci",
    "uluciră": "uluci",
    "ulucirăm": "uluci",
    "ulucirăți": "uluci",
    "ulucise": "uluci",
    "ulucisem": "uluci",
    "uluciseră": "uluci",
    "uluciserăm": "uluci",
    "uluciserăți": "uluci",
    "uluciseși": "uluci",
    "uluciși": "uluci",
    "ulucit": "uluci",
    "uluciți": "uluci",
    "ulucită": "ulucit",
    "ulucite": "ulucit",
    "uluciți": "ulucit",
    "nemaiuluind": "ului",
    "nemaiuluindu": "ului",
    "neuluind": "ului",
    "neuluindu": "ului",
    "uluia": "ului",
    "uluiai": "ului",
    "uluiam": "ului",
    "uluiască": "ului",
    "uluiați": "ului",
    "uluiau": "ului",
    "uluiesc": "ului",
    "uluiește": "ului",
    "uluiești": "ului",
    "uluii": "ului",
    "uluim": "ului",
    "uluind": "ului",
    "uluindu": "ului",
    "uluiră": "ului",
    "uluirăm": "ului",
    "uluirăți": "ului",
    "uluise": "ului",
    "uluisem": "ului",
    "uluiseră": "ului",
    "uluiserăm": "ului",
    "uluiserăți": "ului",
    "uluiseși": "ului",
    "uluiși": "ului",
    "uluit": "ului",
    "uluiți": "ului",
    "uluirea": "uluire",
    "uluireo": "uluire",
    "uluiri": "uluire",
    "uluirii": "uluire",
    "uluirile": "uluire",
    "uluirilor": "uluire",
    "uluita": "uluit",
    "uluită": "uluit",
    "uluite": "uluit",
    "uluitei": "uluit",
    "uluitele": "uluit",
    "uluitelor": "uluit",
    "uluiți": "uluit",
    "uluiții": "uluit",
    "uluiților": "uluit",
    "uluito": "uluit",
    "uluitul": "uluit",
    "uluitule": "uluit",
    "uluitului": "uluit",
    "uluitoare": "uluitor",
    "uluitoarea": "uluitor",
    "uluitoarei": "uluitor",
    "uluitoarele": "uluitor",
    "uluitoarelor": "uluitor",
    "uluitoareo": "uluitor",
    "uluitori": "uluitor",
    "uluitorii": "uluitor",
    "uluitorilor": "uluitor",
    "uluitorul": "uluitor",
    "uluitorule": "uluitor",
    "uluitorului": "uluitor",
    "umana": "uman",
    "umană": "uman",
    "umane": "uman",
    "umanei": "uman",
    "umanele": "uman",
    "umanelor": "uman",
    "umani": "uman",
    "umanii": "uman",
    "umanilor": "uman",
    "umanul": "uman",
    "umanului": "uman",
    "umanisme": "umanism",
    "umanismele": "umanism",
    "umanismelor": "umanism",
    "umanismul": "umanism",
    "umanismului": "umanism",
    "umaniste": "umanist",
    "umanitara": "umanitar",
    "umanitară": "umanitar",
    "umanitare": "umanitar",
    "umanitarei": "umanitar",
    "umanitarele": "umanitar",
    "umanitarelor": "umanitar",
    "umanitari": "umanitar",
    "umanitarii": "umanitar",
    "umanitarilor": "umanitar",
    "umanitarul": "umanitar",
    "umanitarului": "umanitar",
    "umanitatea": "umanitate",
    "umanități": "umanitate",
    "umanității": "umanitate",
    "umanitățile": "umanitate",
    "umanităților": "umanitate",
    "nemaiumanizând": "umaniza",
    "nemaiumanizându": "umaniza",
    "neumanizând": "umaniza",
    "neumanizându": "umaniza",
    "umaniză": "umaniza",
    "umanizai": "umaniza",
    "umanizam": "umaniza",
    "umanizăm": "umaniza",
    "umanizând": "umaniza",
    "umanizându": "umaniza",
    "umanizară": "umaniza",
    "umanizarăm": "umaniza",
    "umanizarăți": "umaniza",
    "umanizase": "umaniza",
    "umanizasem": "umaniza",
    "umanizaseră": "umaniza",
    "umanizaserăm": "umaniza",
    "umanizaserăți": "umaniza",
    "umanizaseși": "umaniza",
    "umanizași": "umaniza",
    "umanizat": "umaniza",
    "umanizați": "umaniza",
    "umanizau": "umaniza",
    "umanizează": "umaniza",
    "umanizez": "umaniza",
    "umanizeze": "umaniza",
    "umanizezi": "umaniza",
    "umanizarea": "umanizare",
    "umanizări": "umanizare",
    "umanizării": "umanizare",
    "umanizările": "umanizare",
    "umanizărilor": "umanizare",
    "umanizată": "umanizat",
    "umanizate": "umanizat",
    "umanizați": "umanizat",
    "umărul": "umăr",
    "umărului": "umăr",
    "umeri": "umăr",
    "umerii": "umăr",
    "umerilor": "umăr",
    "nemaiumblând": "umbla",
    "nemaiumblându": "umbla",
    "neumblând": "umbla",
    "neumblându": "umbla",
    "umblă": "umbla",
    "umblai": "umbla",
    "umblam": "umbla",
    "umblăm": "umbla",
    "umblând": "umbla",
    "umblându": "umbla",
    "umblară": "umbla",
    "umblarăm": "umbla",
    "umblarăți": "umbla",
    "umblase": "umbla",
    "umblasem": "umbla",
    "umblaseră": "umbla",
    "umblaserăm": "umbla",
    "umblaserăți": "umbla",
    "umblaseși": "umbla",
    "umblași": "umbla",
    "umblat": "umbla",
    "umblați": "umbla",
    "umblau": "umbla",
    "umble": "umbla",
    "umbli": "umbla",
    "umblu": "umbla",
    "umblarea": "umblare",
    "umblareo": "umblare",
    "umblări": "umblare",
    "umblării": "umblare",
    "umblările": "umblare",
    "umblărilor": "umblare",
    "umblăreața": "umblăreț",
    "umblăreață": "umblăreț",
    "umblărețe": "umblăreț",
    "umblăreței": "umblăreț",
    "umblărețele": "umblăreț",
    "umblărețelor": "umblăreț",
    "umblăreți": "umblăreț",
    "umblăreții": "umblăreț",
    "umblăreților": "umblăreț",
    "umblărețul": "umblăreț",
    "umblărețului": "umblăreț",
    "umblata": "umblat",
    "umblată": "umblat",
    "umblate": "umblat",
    "umblatei": "umblat",
    "umblatele": "umblat",
    "umblatelor": "umblat",
    "umblați": "umblat",
    "umblații": "umblat",
    "umblaților": "umblat",
    "umblato": "umblat",
    "umblatul": "umblat",
    "umblatule": "umblat",
    "umblatului": "umblat",
    "umblătoare": "umblător",
    "umblătoarea": "umblător",
    "umblătoarei": "umblător",
    "umblătoarele": "umblător",
    "umblătoarelor": "umblător",
    "umblători": "umblător",
    "umblătorii": "umblător",
    "umblătorilor": "umblător",
    "umblătorul": "umblător",
    "umblătorului": "umblător",
    "umblătura": "umblătură",
    "umblături": "umblătură",
    "umblăturii": "umblătură",
    "umblăturile": "umblătură",
    "umblăturilor": "umblătură",
    "umbra": "umbră",
    "umbre": "umbră",
    "umbrei": "umbră",
    "umbrele": "umbră",
    "umbrelor": "umbră",
    "umbrela": "umbrelă",
    "umbrele": "umbrelă",
    "umbrelei": "umbrelă",
    "umbrelele": "umbrelă",
    "umbrelelor": "umbrelă",
    "umbreluța": "umbreluță",
    "umbreluțe": "umbreluță",
    "umbreluței": "umbreluță",
    "umbreluțele": "umbreluță",
    "umbreluțelor": "umbreluță",
    "nemaiumbrind": "umbri",
    "nemaiumbrindu": "umbri",
    "neumbrind": "umbri",
    "neumbrindu": "umbri",
    "umbrea": "umbri",
    "umbreai": "umbri",
    "umbream": "umbri",
    "umbrească": "umbri",
    "umbreați": "umbri",
    "umbreau": "umbri",
    "umbresc": "umbri",
    "umbrește": "umbri",
    "umbrești": "umbri",
    "umbrii": "umbri",
    "umbrim": "umbri",
    "umbrind": "umbri",
    "umbrindu": "umbri",
    "umbriră": "umbri",
    "umbrirăm": "umbri",
    "umbrirăți": "umbri",
    "umbrise": "umbri",
    "umbrisem": "umbri",
    "umbriseră": "umbri",
    "umbriserăm": "umbri",
    "umbriserăți": "umbri",
    "umbriseși": "umbri",
    "umbriși": "umbri",
    "umbrit": "umbri",
    "umbriți": "umbri",
    "umbrirea": "umbrire",
    "umbrireo": "umbrire",
    "umbriri": "umbrire",
    "umbririi": "umbrire",
    "umbririle": "umbrire",
    "umbririlor": "umbrire",
    "umbrișul": "umbriș",
    "umbrișului": "umbriș",
    "umbrișuri": "umbriș",
    "umbrișurile": "umbriș",
    "umbrișurilor": "umbriș",
    "umbrita": "umbrit",
    "umbrită": "umbrit",
    "umbrite": "umbrit",
    "umbritei": "umbrit",
    "umbritele": "umbrit",
    "umbritelor": "umbrit",
    "umbriți": "umbrit",
    "umbriții": "umbrit",
    "umbriților": "umbrit",
    "umbrito": "umbrit",
    "umbritul": "umbrit",
    "umbritule": "umbrit",
    "umbritului": "umbrit",
    "umbrița": "umbriță",
    "umbrițe": "umbriță",
    "umbriței": "umbriță",
    "umbrițele": "umbriță",
    "umbrițelor": "umbriță",
    "umbritoare": "umbritor",
    "umbritoarea": "umbritor",
    "umbritoarei": "umbritor",
    "umbritoarele": "umbritor",
    "umbritoarelor": "umbritor",
    "umbritoareo": "umbritor",
    "umbritori": "umbritor",
    "umbritorii": "umbritor",
    "umbritorilor": "umbritor",
    "umbritorul": "umbritor",
    "umbritorule": "umbritor",
    "umbritorului": "umbritor",
    "umbroasă": "umbros",
    "umbroase": "umbros",
    "umbroasei": "umbros",
    "umbroasele": "umbros",
    "umbroaselor": "umbros",
    "umbroși": "umbros",
    "umbroșii": "umbros",
    "umbroșilor": "umbros",
    "umbrosul": "umbros",
    "umbrosului": "umbros",
    "nemaiumectând": "umecta",
    "nemaiumectându": "umecta",
    "neumectând": "umecta",
    "neumectându": "umecta",
    "umectă": "umecta",
    "umectai": "umecta",
    "umectam": "umecta",
    "umectăm": "umecta",
    "umectând": "umecta",
    "umectându": "umecta",
    "umectară": "umecta",
    "umectarăm": "umecta",
    "umectarăți": "umecta",
    "umectase": "umecta",
    "umectasem": "umecta",
    "umectaseră": "umecta",
    "umectaserăm": "umecta",
    "umectaserăți": "umecta",
    "umectaseși": "umecta",
    "umectași": "umecta",
    "umectat": "umecta",
    "umectați": "umecta",
    "umectau": "umecta",
    "umectează": "umecta",
    "umectez": "umecta",
    "umecteze": "umecta",
    "umectezi": "umecta",
    "umectarea": "umectare",
    "umectareo": "umectare",
    "umectări": "umectare",
    "umectării": "umectare",
    "umectările": "umectare",
    "umectărilor": "umectare",
    "umectată": "umectat",
    "umectate": "umectat",
    "umectați": "umectat",
    "umedă": "umed",
    "umede": "umed",
    "umedei": "umed",
    "umedele": "umed",
    "umedelor": "umed",
    "umedul": "umed",
    "umedului": "umed",
    "umezi": "umed",
    "umezii": "umed",
    "umezilor": "umed",
    "umerala": "umeral",
    "umerală": "umeral",
    "umerale": "umeral",
    "umeralei": "umeral",
    "umeralele": "umeral",
    "umeralelor": "umeral",
    "umerali": "umeral",
    "umeralii": "umeral",
    "umeralilor": "umeral",
    "umeralul": "umeral",
    "umeralului": "umeral",
    "umezeala": "umezeală",
    "umezealo": "umezeală",
    "umezeli": "umezeală",
    "umezelii": "umezeală",
    "umezelile": "umezeală",
    "umezelilor": "umezeală",
    "nemaiumezind": "umezi",
    "nemaiumezindu": "umezi",
    "neumezind": "umezi",
    "neumezindu": "umezi",
    "umezea": "umezi",
    "umezeai": "umezi",
    "umezeam": "umezi",
    "umezească": "umezi",
    "umezeați": "umezi",
    "umezeau": "umezi",
    "umezesc": "umezi",
    "umezește": "umezi",
    "umezești": "umezi",
    "umezii": "umezi",
    "umezim": "umezi",
    "umezind": "umezi",
    "umezindu": "umezi",
    "umeziră": "umezi",
    "umezirăm": "umezi",
    "umezirăți": "umezi",
    "umezise": "umezi",
    "umezisem": "umezi",
    "umeziseră": "umezi",
    "umeziserăm": "umezi",
    "umeziserăți": "umezi",
    "umeziseși": "umezi",
    "umeziși": "umezi",
    "umezit": "umezi",
    "umeziți": "umezi",
    "umezirea": "umezire",
    "umezireo": "umezire",
    "umeziri": "umezire",
    "umezirii": "umezire",
    "umezirile": "umezire",
    "umezirilor": "umezire",
    "umezita": "umezit",
    "umezită": "umezit",
    "umezite": "umezit",
    "umezitei": "umezit",
    "umezitele": "umezit",
    "umezitelor": "umezit",
    "umeziți": "umezit",
    "umeziții": "umezit",
    "umeziților": "umezit",
    "umezito": "umezit",
    "umezitul": "umezit",
    "umezitule": "umezit",
    "umezitului": "umezit",
    "umezitoare": "umezitor",
    "umezitoarele": "umezitor",
    "umezitoarelor": "umezitor",
    "umezitorul": "umezitor",
    "umezitorului": "umezitor",
    "nemaiumflând": "umfla",
    "nemaiumflându": "umfla",
    "neumflând": "umfla",
    "neumflându": "umfla",
    "umflă": "umfla",
    "umflai": "umfla",
    "umflam": "umfla",
    "umflăm": "umfla",
    "umflând": "umfla",
    "umflându": "umfla",
    "umflară": "umfla",
    "umflarăm": "umfla",
    "umflarăți": "umfla",
    "umflase": "umfla",
    "umflasem": "umfla",
    "umflaseră": "umfla",
    "umflaserăm": "umfla",
    "umflaserăți": "umfla",
    "umflaseși": "umfla",
    "umflași": "umfla",
    "umflat": "umfla",
    "umflați": "umfla",
    "umflau": "umfla",
    "umfle": "umfla",
    "umfli": "umfla",
    "umflu": "umfla",
    "umflarea": "umflare",
    "umflareo": "umflare",
    "umflări": "umflare",
    "umflării": "umflare",
    "umflările": "umflare",
    "umflărilor": "umflare",
    "umflata": "umflat",
    "umflată": "umflat",
    "umflate": "umflat",
    "umflatei": "umflat",
    "umflatele": "umflat",
    "umflatelor": "umflat",
    "umflați": "umflat",
    "umflații": "umflat",
    "umflaților": "umflat",
    "umflato": "umflat",
    "umflatul": "umflat",
    "umflatule": "umflat",
    "umflatului": "umflat",
    "umflătura": "umflătură",
    "umflături": "umflătură",
    "umflăturii": "umflătură",
    "umflăturile": "umflătură",
    "umflăturilor": "umflătură",
    "umflăturo": "umflătură",
    "umidificarea": "umidificare",
    "umidificări": "umidificare",
    "umidificării": "umidificare",
    "umidifuga": "umidifug",
    "umidifugă": "umidifug",
    "umidifuge": "umidifug",
    "umidifugei": "umidifug",
    "umidifugele": "umidifug",
    "umidifugelor": "umidifug",
    "umidifugi": "umidifug",
    "umidifugii": "umidifug",
    "umidifugilor": "umidifug",
    "umidifugul": "umidifug",
    "umidifugului": "umidifug",
    "umiditatea": "umiditate",
    "umidități": "umiditate",
    "umidității": "umiditate",
    "umiditățile": "umiditate",
    "umidităților": "umiditate",
    "umila": "umil",
    "umilă": "umil",
    "umile": "umil",
    "umilei": "umil",
    "umilele": "umil",
    "umilelor": "umil",
    "umili": "umil",
    "umilii": "umil",
    "umililor": "umil",
    "umilul": "umil",
    "umilului": "umil",
    "nemaiumilind": "umili",
    "nemaiumilindu": "umili",
    "neumilind": "umili",
    "neumilindu": "umili",
    "umilea": "umili",
    "umileai": "umili",
    "umileam": "umili",
    "umilească": "umili",
    "umileați": "umili",
    "umileau": "umili",
    "umilesc": "umili",
    "umilește": "umili",
    "umilești": "umili",
    "umilii": "umili",
    "umilim": "umili",
    "umilind": "umili",
    "umilindu": "umili",
    "umiliră": "umili",
    "umilirăm": "umili",
    "umilirăți": "umili",
    "umilise": "umili",
    "umilisem": "umili",
    "umiliseră": "umili",
    "umiliserăm": "umili",
    "umiliserăți": "umili",
    "umiliseși": "umili",
    "umiliși": "umili",
    "umilit": "umili",
    "umiliți": "umili",
    "umilința": "umilință",
    "umilințe": "umilință",
    "umilinței": "umilință",
    "umilințele": "umilință",
    "umilințelor": "umilință",
    "umilințo": "umilință",
    "umilirea": "umilire",
    "umilireo": "umilire",
    "umiliri": "umilire",
    "umilirii": "umilire",
    "umilirile": "umilire",
    "umilirilor": "umilire",
    "umilita": "umilit",
    "umilită": "umilit",
    "umilite": "umilit",
    "umilitei": "umilit",
    "umilitele": "umilit",
    "umilitelor": "umilit",
    "umiliți": "umilit",
    "umiliții": "umilit",
    "umiliților": "umilit",
    "umilito": "umilit",
    "umilitul": "umilit",
    "umilitule": "umilit",
    "umilitului": "umilit",
    "umilitoare": "umilitor",
    "umilitoarea": "umilitor",
    "umilitoarei": "umilitor",
    "umilitoarele": "umilitor",
    "umilitoarelor": "umilitor",
    "umilitoareo": "umilitor",
    "umilitori": "umilitor",
    "umilitorii": "umilitor",
    "umilitorilor": "umilitor",
    "umilitorul": "umilitor",
    "umilitorule": "umilitor",
    "umilitorului": "umilitor",
    "umoarea": "umoare",
    "umori": "umoare",
    "umorii": "umoare",
    "umorile": "umoare",
    "umorilor": "umoare",
    "umorul": "umor",
    "umorului": "umor",
    "umoristica": "umoristic",
    "umoristică": "umoristic",
    "umoristice": "umoristic",
    "umoristicei": "umoristic",
    "umoristicele": "umoristic",
    "umoristicelor": "umoristic",
    "umoristici": "umoristic",
    "umoristicii": "umoristic",
    "umoristicilor": "umoristic",
    "umoristicul": "umoristic",
    "umoristicului": "umoristic",
    "nemaiumplând": "umple",
    "nemaiumplându": "umple",
    "neumplând": "umple",
    "neumplându": "umple",
    "umplând": "umple",
    "umplându": "umple",
    "umplea": "umple",
    "umpleai": "umple",
    "umpleam": "umple",
    "umpleați": "umple",
    "umpleau": "umple",
    "umplem": "umple",
    "umpleți": "umple",
    "umpli": "umple",
    "umplu": "umple",
    "umplui": "umple",
    "umplură": "umple",
    "umplurăm": "umple",
    "umplurăți": "umple",
    "umpluse": "umple",
    "umplusem": "umple",
    "umpluseră": "umple",
    "umpluserăm": "umple",
    "umpluserăți": "umple",
    "umpluseși": "umple",
    "umpluși": "umple",
    "umplut": "umple",
    "umplerea": "umplere",
    "umplereo": "umplere",
    "umpleri": "umplere",
    "umplerii": "umplere",
    "umplerile": "umplere",
    "umplerilor": "umplere",
    "umpluta": "umplut",
    "umplută": "umplut",
    "umplute": "umplut",
    "umplutei": "umplut",
    "umplutele": "umplut",
    "umplutelor": "umplut",
    "umpluți": "umplut",
    "umpluții": "umplut",
    "umpluților": "umplut",
    "umpluto": "umplut",
    "umplutul": "umplut",
    "umplutule": "umplut",
    "umplutului": "umplut",
    "umplutura": "umplutură",
    "umpluturi": "umplutură",
    "umpluturii": "umplutură",
    "umpluturile": "umplutură",
    "umpluturilor": "umplutură",
    "umpluturo": "umplutură",
    "o": "un",
    "unei": "un",
    "unele": "un",
    "unii": "un",
    "unor": "un",
    "unui": "un",
    "unanima": "unanim",
    "unanimă": "unanim",
    "unanime": "unanim",
    "unanimei": "unanim",
    "unanimele": "unanim",
    "unanimelor": "unanim",
    "unanimi": "unanim",
    "unanimii": "unanim",
    "unanimilor": "unanim",
    "unanimul": "unanim",
    "unanimului": "unanim",
    "unanimitatea": "unanimitate",
    "unanimități": "unanimitate",
    "unanimității": "unanimitate",
    "unanimitățile": "unanimitate",
    "unanimităților": "unanimitate",
    "unchii": "unchi",
    "unchilor": "unchi",
    "unchiul": "unchi",
    "unchiului": "unchi",
    "unciala": "uncial",
    "uncială": "uncial",
    "unciale": "uncial",
    "uncialei": "uncial",
    "uncialele": "uncial",
    "uncialelor": "uncial",
    "unciali": "uncial",
    "uncialii": "uncial",
    "uncialilor": "uncial",
    "uncialul": "uncial",
    "uncialului": "uncial",
    "oz": "uncie",
    "uncia": "uncie",
    "unciei": "uncie",
    "uncii": "uncie",
    "unciile": "uncie",
    "unciilor": "uncie",
    "unda": "undă",
    "unde": "undă",
    "undei": "undă",
    "undele": "undă",
    "undelor": "undă",
    "undița": "undiță",
    "undițe": "undiță",
    "undiței": "undiță",
    "undițele": "undiță",
    "undițelor": "undiță",
    "nemaiunduind": "undui",
    "nemaiunduindu": "undui",
    "neunduind": "undui",
    "neunduindu": "undui",
    "unduia": "undui",
    "unduiai": "undui",
    "unduiam": "undui",
    "unduiască": "undui",
    "unduiați": "undui",
    "unduiau": "undui",
    "unduiesc": "undui",
    "unduiește": "undui",
    "unduiești": "undui",
    "unduii": "undui",
    "unduim": "undui",
    "unduind": "undui",
    "unduindu": "undui",
    "unduiră": "undui",
    "unduirăm": "undui",
    "unduirăți": "undui",
    "unduise": "undui",
    "unduisem": "undui",
    "unduiseră": "undui",
    "unduiserăm": "undui",
    "unduiserăți": "undui",
    "unduiseși": "undui",
    "unduiși": "undui",
    "unduit": "undui",
    "unduiți": "undui",
    "unduioasa": "unduios",
    "unduioasă": "unduios",
    "unduioase": "unduios",
    "unduioasei": "unduios",
    "unduioasele": "unduios",
    "unduioaselor": "unduios",
    "unduioși": "unduios",
    "unduioșii": "unduios",
    "unduioșilor": "unduios",
    "unduiosul": "unduios",
    "unduiosului": "unduios",
    "unduirea": "unduire",
    "unduireo": "unduire",
    "unduiri": "unduire",
    "unduirii": "unduire",
    "unduirile": "unduire",
    "unduirilor": "unduire",
    "unduita": "unduit",
    "unduită": "unduit",
    "unduite": "unduit",
    "unduitei": "unduit",
    "unduitele": "unduit",
    "unduitelor": "unduit",
    "unduiți": "unduit",
    "unduiții": "unduit",
    "unduiților": "unduit",
    "unduito": "unduit",
    "unduitul": "unduit",
    "unduitule": "unduit",
    "unduitului": "unduit",
    "unealta": "unealtă",
    "unelte": "unealtă",
    "uneltei": "unealtă",
    "uneltele": "unealtă",
    "uneltelor": "unealtă",
    "nemaiuneltind": "unelti",
    "nemaiuneltindu": "unelti",
    "neuneltind": "unelti",
    "neuneltindu": "unelti",
    "uneltea": "unelti",
    "unelteai": "unelti",
    "unelteam": "unelti",
    "uneltească": "unelti",
    "unelteați": "unelti",
    "unelteau": "unelti",
    "uneltesc": "unelti",
    "uneltește": "unelti",
    "uneltești": "unelti",
    "uneltii": "unelti",
    "uneltim": "unelti",
    "uneltind": "unelti",
    "uneltindu": "unelti",
    "uneltiră": "unelti",
    "uneltirăm": "unelti",
    "uneltirăți": "unelti",
    "uneltise": "unelti",
    "uneltisem": "unelti",
    "uneltiseră": "unelti",
    "uneltiserăm": "unelti",
    "uneltiserăți": "unelti",
    "uneltiseși": "unelti",
    "uneltiși": "unelti",
    "uneltit": "unelti",
    "uneltiți": "unelti",
    "uneltirea": "uneltire",
    "uneltiri": "uneltire",
    "uneltirii": "uneltire",
    "uneltirile": "uneltire",
    "uneltirilor": "uneltire",
    "uneltită": "uneltit",
    "uneltite": "uneltit",
    "uneltiți": "uneltit",
    "ungară": "ungar",
    "ungare": "ungar",
    "ungari": "ungar",
    "Ungarie": "Ungaria",
    "Ungariei": "Ungaria",
    "ungătoarea": "ungătoare",
    "ungătoarei": "ungătoare",
    "ungătoarele": "ungătoare",
    "ungătoarelor": "ungătoare",
    "ungători": "ungător",
    "ungătorii": "ungător",
    "ungătorilor": "ungător",
    "ungătorul": "ungător",
    "ungătorule": "ungător",
    "ungătorului": "ungător",
    "nemaiungând": "unge",
    "nemaiungându": "unge",
    "neungând": "unge",
    "neungându": "unge",
    "neuns": "unge",
    "ung": "unge",
    "ungă": "unge",
    "ungând": "unge",
    "ungându": "unge",
    "ungea": "unge",
    "ungeai": "unge",
    "ungeam": "unge",
    "ungeați": "unge",
    "ungeau": "unge",
    "ungem": "unge",
    "ungeți": "unge",
    "ungi": "unge",
    "uns": "unge",
    "unse": "unge",
    "unsei": "unge",
    "unseră": "unge",
    "unserăm": "unge",
    "unserăți": "unge",
    "unsese": "unge",
    "unsesem": "unge",
    "unseseră": "unge",
    "unseserăm": "unge",
    "unseserăți": "unge",
    "unseseși": "unge",
    "unseși": "unge",
    "ungerea": "ungere",
    "ungereo": "ungere",
    "ungeri": "ungere",
    "ungerii": "ungere",
    "ungerile": "ungere",
    "ungerilor": "ungere",
    "unghere": "ungher",
    "ungherele": "ungher",
    "ungherelor": "ungher",
    "ungherul": "ungher",
    "ungherului": "ungher",
    "unghiul": "unghi",
    "unghiului": "unghi",
    "unghiuri": "unghi",
    "unghiurile": "unghi",
    "unghiurilor": "unghi",
    "unghia": "unghie",
    "unghiei": "unghie",
    "unghii": "unghie",
    "unghiile": "unghie",
    "unghiilor": "unghie",
    "unghiulara": "unghiular",
    "unghiulară": "unghiular",
    "unghiulare": "unghiular",
    "unghiularei": "unghiular",
    "unghiularele": "unghiular",
    "unghiularelor": "unghiular",
    "unghiulari": "unghiular",
    "unghiularii": "unghiular",
    "unghiularilor": "unghiular",
    "unghiularul": "unghiular",
    "unghiularului": "unghiular",
    "unghiuța": "unghiuță",
    "unghiuțe": "unghiuță",
    "unghiuței": "unghiuță",
    "unghiuțele": "unghiuță",
    "unghiuțelor": "unghiuță",
    "unguente": "unguent",
    "unguentele": "unguent",
    "unguentelor": "unguent",
    "unguentul": "unguent",
    "unguentului": "unguent",
    "unguri": "ungur",
    "ungurii": "ungur",
    "ungurilor": "ungur",
    "ungurul": "ungur",
    "ungurului": "ungur",
    "ungurași": "unguraș",
    "ungurașii": "unguraș",
    "ungurașilor": "unguraș",
    "ungurașul": "unguraș",
    "ungurașului": "unguraș",
    "ungureanul": "ungurean",
    "ungureanului": "ungurean",
    "ungureni": "ungurean",
    "ungurenii": "ungurean",
    "ungurenilor": "ungurean",
    "ungureanca": "ungureancă",
    "ungurence": "ungureancă",
    "ungurencei": "ungureancă",
    "ungurencele": "ungureancă",
    "ungurencelor": "ungureancă",
    "ungurească": "unguresc",
    "ungurești": "unguresc",
    "ungurimea": "ungurime",
    "ungurimi": "ungurime",
    "ungurimii": "ungurime",
    "ungurimile": "ungurime",
    "ungurimilor": "ungurime",
    "ungurisme": "ungurism",
    "ungurismele": "ungurism",
    "ungurismelor": "ungurism",
    "ungurismul": "ungurism",
    "ungurismului": "ungurism",
    "unguroaica": "unguroaică",
    "unguroaice": "unguroaică",
    "unguroaicei": "unguroaică",
    "unguroaicele": "unguroaică",
    "unguroaicelor": "unguroaică",
    "nemaiunind": "uni",
    "nemaiunindu": "uni",
    "neunind": "uni",
    "neunindu": "uni",
    "unea": "uni",
    "uneai": "uni",
    "uneam": "uni",
    "unească": "uni",
    "uneați": "uni",
    "uneau": "uni",
    "unesc": "uni",
    "unește": "uni",
    "unești": "uni",
    "unii": "uni",
    "unim": "uni",
    "unind": "uni",
    "unindu": "uni",
    "uniră": "uni",
    "unirăm": "uni",
    "unirăți": "uni",
    "unise": "uni",
    "unisem": "uni",
    "uniseră": "uni",
    "uniserăm": "uni",
    "uniserăți": "uni",
    "uniseși": "uni",
    "uniși": "uni",
    "unit": "uni",
    "uniți": "uni",
    "unica": "unic",
    "unică": "unic",
    "unice": "unic",
    "unicei": "unic",
    "unicele": "unic",
    "unicelor": "unic",
    "unici": "unic",
    "unicii": "unic",
    "unicilor": "unic",
    "unicul": "unic",
    "unicului": "unic",
    "unicapsulara": "unicapsular",
    "unicapsulară": "unicapsular",
    "unicapsulare": "unicapsular",
    "unicapsularei": "unicapsular",
    "unicapsularele": "unicapsular",
    "unicapsularelor": "unicapsular",
    "unicapsulari": "unicapsular",
    "unicapsularii": "unicapsular",
    "unicapsularilor": "unicapsular",
    "unicapsularul": "unicapsular",
    "unicapsularului": "unicapsular",
    "unicate": "unicat",
    "unicatele": "unicat",
    "unicatelor": "unicat",
    "unicatul": "unicat",
    "unicatului": "unicat",
    "unicelulara": "unicelular",
    "unicelulară": "unicelular",
    "unicelulare": "unicelular",
    "unicelularei": "unicelular",
    "unicelularele": "unicelular",
    "unicelularelor": "unicelular",
    "unicelulari": "unicelular",
    "unicelularii": "unicelular",
    "unicelularilor": "unicelular",
    "unicelularul": "unicelular",
    "unicelularului": "unicelular",
    "unicitatea": "unicitate",
    "unicități": "unicitate",
    "unicității": "unicitate",
    "unicitățile": "unicitate",
    "unicităților": "unicitate",
    "unicolora": "unicolor",
    "unicoloră": "unicolor",
    "unicolore": "unicolor",
    "unicolorei": "unicolor",
    "unicolorele": "unicolor",
    "unicolorelor": "unicolor",
    "unicolori": "unicolor",
    "unicolorii": "unicolor",
    "unicolorilor": "unicolor",
    "unicolorul": "unicolor",
    "unicolorului": "unicolor",
    "unicorde": "unicord",
    "unicordei": "unicord",
    "unicordele": "unicord",
    "unicordelor": "unicord",
    "unicordul": "unicord",
    "unicordului": "unicord",
    "unicorzi": "unicord",
    "unicorzii": "unicord",
    "unicorzilor": "unicord",
    "unicorna": "unicorn",
    "unicornă": "unicorn",
    "unicorne": "unicorn",
    "unicornei": "unicorn",
    "unicornele": "unicorn",
    "unicornelor": "unicorn",
    "unicorni": "unicorn",
    "unicornii": "unicorn",
    "unicornilor": "unicorn",
    "unicornul": "unicorn",
    "unicornului": "unicorn",
    "nemaiunificând": "unifica",
    "nemaiunificându": "unifica",
    "neunificând": "unifica",
    "neunificându": "unifica",
    "unific": "unifica",
    "unifică": "unifica",
    "unificai": "unifica",
    "unificam": "unifica",
    "unificăm": "unifica",
    "unificând": "unifica",
    "unificându": "unifica",
    "unificară": "unifica",
    "unificarăm": "unifica",
    "unificarăți": "unifica",
    "unificase": "unifica",
    "unificasem": "unifica",
    "unificaseră": "unifica",
    "unificaserăm": "unifica",
    "unificaserăți": "unifica",
    "unificaseși": "unifica",
    "unificași": "unifica",
    "unificat": "unifica",
    "unificați": "unifica",
    "unificau": "unifica",
    "unifice": "unifica",
    "unifici": "unifica",
    "unificarea": "unificare",
    "unificareo": "unificare",
    "unificări": "unificare",
    "unificării": "unificare",
    "unificările": "unificare",
    "unificărilor": "unificare",
    "unificata": "unificat",
    "unificată": "unificat",
    "unificate": "unificat",
    "unificatei": "unificat",
    "unificatele": "unificat",
    "unificatelor": "unificat",
    "unificați": "unificat",
    "unificații": "unificat",
    "unificaților": "unificat",
    "unificato": "unificat",
    "unificatul": "unificat",
    "unificatule": "unificat",
    "unificatului": "unificat",
    "unificatoare": "unificator",
    "unificatoarea": "unificator",
    "unificatoarei": "unificator",
    "unificatoarele": "unificator",
    "unificatoarelor": "unificator",
    "unificatoareo": "unificator",
    "unificatori": "unificator",
    "unificatorii": "unificator",
    "unificatorilor": "unificator",
    "unificatorul": "unificator",
    "unificatorule": "unificator",
    "unificatorului": "unificator",
    "unifoliata": "unifoliat",
    "unifoliată": "unifoliat",
    "unifoliate": "unifoliat",
    "unifoliatei": "unifoliat",
    "unifoliatele": "unifoliat",
    "unifoliatelor": "unifoliat",
    "unifoliați": "unifoliat",
    "unifoliații": "unifoliat",
    "unifoliaților": "unifoliat",
    "unifoliatul": "unifoliat",
    "unifoliatului": "unifoliat",
    "uniforma": "uniform",
    "uniformă": "uniform",
    "uniforme": "uniform",
    "uniformei": "uniform",
    "uniformele": "uniform",
    "uniformelor": "uniform",
    "uniformi": "uniform",
    "uniformii": "uniform",
    "uniformilor": "uniform",
    "uniformul": "uniform",
    "uniformului": "uniform",
    "uniforma": "uniformă",
    "uniforme": "uniformă",
    "uniformei": "uniformă",
    "uniformele": "uniformă",
    "uniformelor": "uniformă",
    "uniformitatea": "uniformitate",
    "uniformități": "uniformitate",
    "uniformității": "uniformitate",
    "uniformitățile": "uniformitate",
    "uniformităților": "uniformitate",
    "nemaiuniformizând": "uniformiza",
    "nemaiuniformizându": "uniformiza",
    "neuniformizând": "uniformiza",
    "neuniformizându": "uniformiza",
    "uniformiză": "uniformiza",
    "uniformizai": "uniformiza",
    "uniformizam": "uniformiza",
    "uniformizăm": "uniformiza",
    "uniformizând": "uniformiza",
    "uniformizându": "uniformiza",
    "uniformizară": "uniformiza",
    "uniformizarăm": "uniformiza",
    "uniformizarăți": "uniformiza",
    "uniformizase": "uniformiza",
    "uniformizasem": "uniformiza",
    "uniformizaseră": "uniformiza",
    "uniformizaserăm": "uniformiza",
    "uniformizaserăți": "uniformiza",
    "uniformizaseși": "uniformiza",
    "uniformizași": "uniformiza",
    "uniformizat": "uniformiza",
    "uniformizați": "uniformiza",
    "uniformizau": "uniformiza",
    "uniformizează": "uniformiza",
    "uniformizez": "uniformiza",
    "uniformizeze": "uniformiza",
    "uniformizezi": "uniformiza",
    "uniformizarea": "uniformizare",
    "uniformizareo": "uniformizare",
    "uniformizări": "uniformizare",
    "uniformizării": "uniformizare",
    "uniformizările": "uniformizare",
    "uniformizărilor": "uniformizare",
    "uniformizata": "uniformizat",
    "uniformizată": "uniformizat",
    "uniformizate": "uniformizat",
    "uniformizatei": "uniformizat",
    "uniformizatele": "uniformizat",
    "uniformizatelor": "uniformizat",
    "uniformizați": "uniformizat",
    "uniformizații": "uniformizat",
    "uniformizaților": "uniformizat",
    "uniformizato": "uniformizat",
    "uniformizatul": "uniformizat",
    "uniformizatule": "uniformizat",
    "uniformizatului": "uniformizat",
    "unilaterala": "unilateral",
    "unilaterală": "unilateral",
    "unilaterale": "unilateral",
    "unilateralei": "unilateral",
    "unilateralele": "unilateral",
    "unilateralelor": "unilateral",
    "unilaterali": "unilateral",
    "unilateralii": "unilateral",
    "unilateralilor": "unilateral",
    "unilateralul": "unilateral",
    "unilateralului": "unilateral",
    "uninaționala": "uninațional",
    "uninațională": "uninațional",
    "uninaționale": "uninațional",
    "uninaționalei": "uninațional",
    "uninaționalele": "uninațional",
    "uninaționalelor": "uninațional",
    "uninaționali": "uninațional",
    "uninaționalii": "uninațional",
    "uninaționalilor": "uninațional",
    "uninaționalul": "uninațional",
    "uninaționalului": "uninațional",
    "uninominala": "uninominal",
    "uninominală": "uninominal",
    "uninominale": "uninominal",
    "uninominalei": "uninominal",
    "uninominalele": "uninominal",
    "uninominalelor": "uninominal",
    "uninominali": "uninominal",
    "uninominalii": "uninominal",
    "uninominalilor": "uninominal",
    "uninominalul": "uninominal",
    "uninominalului": "uninominal",
    "unionala": "unional",
    "unională": "unional",
    "unionale": "unional",
    "unionalei": "unional",
    "unionalele": "unional",
    "unionalelor": "unional",
    "unionali": "unional",
    "unionalii": "unional",
    "unionalilor": "unional",
    "unionalul": "unional",
    "unionalului": "unional",
    "unionista": "unionist",
    "unionistă": "unionist",
    "unioniste": "unionist",
    "unionistei": "unionist",
    "unionistele": "unionist",
    "unionistelor": "unionist",
    "unionistul": "unionist",
    "unionistului": "unionist",
    "unipersonala": "unipersonal",
    "unipersonală": "unipersonal",
    "unipersonale": "unipersonal",
    "unipersonalei": "unipersonal",
    "unipersonalele": "unipersonal",
    "unipersonalelor": "unipersonal",
    "unipersonali": "unipersonal",
    "unipersonalii": "unipersonal",
    "unipersonalilor": "unipersonal",
    "unipersonalul": "unipersonal",
    "unipersonalului": "unipersonal",
    "unipetala": "unipetal",
    "unipetală": "unipetal",
    "unipetale": "unipetal",
    "unipetalei": "unipetal",
    "unipetalele": "unipetal",
    "unipetalelor": "unipetal",
    "unipetali": "unipetal",
    "unipetalii": "unipetal",
    "unipetalilor": "unipetal",
    "unipetalul": "unipetal",
    "unipetalului": "unipetal",
    "unipolara": "unipolar",
    "unipolară": "unipolar",
    "unipolare": "unipolar",
    "unipolarei": "unipolar",
    "unipolarele": "unipolar",
    "unipolarelor": "unipolar",
    "unipolari": "unipolar",
    "unipolarii": "unipolar",
    "unipolarilor": "unipolar",
    "unipolarul": "unipolar",
    "unipolarului": "unipolar",
    "unirea": "unire",
    "unireo": "unire",
    "uniri": "unire",
    "unirii": "unire",
    "unirile": "unire",
    "unirilor": "unire",
    "unisexuata": "unisexuat",
    "unisexuată": "unisexuat",
    "unisexuate": "unisexuat",
    "unisexuatei": "unisexuat",
    "unisexuatele": "unisexuat",
    "unisexuatelor": "unisexuat",
    "unisexuați": "unisexuat",
    "unisexuații": "unisexuat",
    "unisexuaților": "unisexuat",
    "unisexuatul": "unisexuat",
    "unisexuatului": "unisexuat",
    "unisonul": "unison",
    "unisonului": "unison",
    "unisonuri": "unison",
    "unisonurile": "unison",
    "unisonurilor": "unison",
    "unisonanța": "unisonanță",
    "unisonanțe": "unisonanță",
    "unisonanței": "unisonanță",
    "unisonanțele": "unisonanță",
    "unisonanțelor": "unisonanță",
    "unita": "unit",
    "unită": "unit",
    "unite": "unit",
    "unitei": "unit",
    "unitele": "unit",
    "unitelor": "unit",
    "uniți": "unit",
    "uniții": "unit",
    "uniților": "unit",
    "unito": "unit",
    "unitul": "unit",
    "unitule": "unit",
    "unitului": "unit",
    "unitara": "unitar",
    "unitară": "unitar",
    "unitare": "unitar",
    "unitarei": "unitar",
    "unitarele": "unitar",
    "unitarelor": "unitar",
    "unitari": "unitar",
    "unitarii": "unitar",
    "unitarilor": "unitar",
    "unitarul": "unitar",
    "unitarului": "unitar",
    "unitatea": "unitate",
    "unități": "unitate",
    "unității": "unitate",
    "unitățile": "unitate",
    "unităților": "unitate",
    "u.m.": "unitate_de_măsură",
    "USD": "United_State_Dollar",
    "uniunea": "uniune",
    "uniuni": "uniune",
    "uniunii": "uniune",
    "uniunile": "uniune",
    "uniunilor": "uniune",
    "UDMR": "Uniunea_Democrată_a_Maghiarilor_din_România",
    "U.E.": "Uniunea_Europeană",
    "UE": "Uniunea_Europeană",
    "univalva": "univalv",
    "univalvă": "univalv",
    "univalve": "univalv",
    "univalvei": "univalv",
    "univalvele": "univalv",
    "univalvelor": "univalv",
    "univalvi": "univalv",
    "univalvii": "univalv",
    "univalvilor": "univalv",
    "univalvul": "univalv",
    "univalvului": "univalv",
    "universul": "univers",
    "universului": "univers",
    "universuri": "univers",
    "universurile": "univers",
    "universurilor": "univers",
    "universala": "universal",
    "universală": "universal",
    "universale": "universal",
    "universalei": "universal",
    "universalele": "universal",
    "universalelor": "universal",
    "universali": "universal",
    "universalii": "universal",
    "universalilor": "universal",
    "universalul": "universal",
    "universalului": "universal",
    "universalitatea": "universalitate",
    "universitara": "universitar",
    "universitară": "universitar",
    "universitare": "universitar",
    "universitarei": "universitar",
    "universitarele": "universitar",
    "universitarelor": "universitar",
    "universitari": "universitar",
    "universitarii": "universitar",
    "universitarilor": "universitar",
    "universitarul": "universitar",
    "universitarului": "universitar",
    "univ.": "universitate",
    "universitatea": "universitate",
    "universități": "universitate",
    "universității": "universitate",
    "universitățile": "universitate",
    "universităților": "universitate",
    "univocă": "univoc",
    "univoce": "univoc",
    "univoci": "univoc",
    "unsa": "uns",
    "unsă": "uns",
    "unse": "uns",
    "unsei": "uns",
    "unsele": "uns",
    "unselor": "uns",
    "unși": "uns",
    "unșii": "uns",
    "unșilor": "uns",
    "unso": "uns",
    "unsul": "uns",
    "unsule": "uns",
    "unsului": "uns",
    "unsoarea": "unsoare",
    "unsori": "unsoare",
    "unsorii": "unsoare",
    "unsorile": "unsoare",
    "unsorilor": "unsoare",
    "unșpe": "unsprezece",
    "unșpea": "unsprezece",
    "unșpelea": "unsprezece",
    "unsprezecea": "unsprezece",
    "unsprezecelea": "unsprezece",
    "XI": "unsprezece",
    "unsprezecimea": "unsprezecime",
    "unsprezecimi": "unsprezecime",
    "unsprezecimii": "unsprezecime",
    "unsprezecimile": "unsprezecime",
    "unsprezecimilor": "unsprezecime",
    "unsuroasă": "unsuros",
    "unsuroase": "unsuros",
    "unsuroasei": "unsuros",
    "unsuroasele": "unsuros",
    "unsuroaselor": "unsuros",
    "unsuroși": "unsuros",
    "unsuroșii": "unsuros",
    "unsuroșilor": "unsuros",
    "unsurosul": "unsuros",
    "unsurosului": "unsuros",
    "untul": "unt",
    "untului": "unt",
    "untdelemnul": "untdelemn",
    "untdelemnului": "untdelemn",
    "untișoare": "untișor",
    "untișoarele": "untișor",
    "untișoarelor": "untișor",
    "untișorul": "untișor",
    "untișorului": "untișor",
    "untura": "untură",
    "unturei": "untură",
    "unturi": "untură",
    "unturii": "untură",
    "unturile": "untură",
    "unturilor": "untură",
    "unul": "unu",
    "unulea": "unu",
    "unului": "unu",
    "una": "unul",
    "uneia": "unul",
    "unele": "unul",
    "unii": "unul",
    "unora": "unul",
    "unu": "unul",
    "unu'": "unul",
    "unu-": "unul",
    "unuia": "unul",
    "nemaiurând": "ura",
    "nemaiurându": "ura",
    "neurând": "ura",
    "neurându": "ura",
    "ură": "ura",
    "urai": "ura",
    "uram": "ura",
    "urăm": "ura",
    "urând": "ura",
    "urându": "ura",
    "urară": "ura",
    "urarăm": "ura",
    "urarăți": "ura",
    "urase": "ura",
    "urasem": "ura",
    "uraseră": "ura",
    "uraserăm": "ura",
    "uraserăți": "ura",
    "uraseși": "ura",
    "urași": "ura",
    "urat": "ura",
    "urați": "ura",
    "urau": "ura",
    "urează": "ura",
    "urez": "ura",
    "ureze": "ura",
    "urezi": "ura",
    "ura": "ură",
    "uri": "ură",
    "urii": "ură",
    "urile": "ură",
    "urilor": "ură",
    "urâcioasa": "urâcios",
    "urâcioasă": "urâcios",
    "urâcioasei": "urâcios",
    "urâcioasele": "urâcios",
    "urâcioaselor": "urâcios",
    "urâciose": "urâcios",
    "urâcioși": "urâcios",
    "urâcioșii": "urâcios",
    "urâcioșilor": "urâcios",
    "urâciosul": "urâcios",
    "urâciosului": "urâcios",
    "urâciunea": "urâciune",
    "urâciuni": "urâciune",
    "urâciunii": "urâciune",
    "urâciunile": "urâciune",
    "urâciunilor": "urâciune",
    "uragane": "uragan",
    "uraganele": "uragan",
    "uraganelor": "uragan",
    "uraganul": "uragan",
    "uraganului": "uragan",
    "uralele": "urale",
    "uralelor": "urale",
    "urangutani": "urangutan",
    "urangutanii": "urangutan",
    "urangutanilor": "urangutan",
    "urangutanul": "urangutan",
    "urangutanului": "urangutan",
    "uraniul": "uraniu",
    "uraniului": "uraniu",
    "urarea": "urare",
    "urareo": "urare",
    "urări": "urare",
    "urării": "urare",
    "urările": "urare",
    "urărilor": "urare",
    "urata": "urat",
    "urată": "urat",
    "urate": "urat",
    "uratei": "urat",
    "uratele": "urat",
    "uratelor": "urat",
    "urați": "urat",
    "urații": "urat",
    "uraților": "urat",
    "urato": "urat",
    "uratul": "urat",
    "uratule": "urat",
    "uratului": "urat",
    "urâta": "urât",
    "urâtă": "urât",
    "urâte": "urât",
    "urâtei": "urât",
    "urâtele": "urât",
    "urâtelor": "urât",
    "urâți": "urât",
    "urâții": "urât",
    "urâților": "urât",
    "urâtul": "urât",
    "urâtului": "urât",
    "urâței": "urâțel",
    "urâțeii": "urâțel",
    "urâțeilor": "urâțel",
    "urâțele": "urâțel",
    "urâțelei": "urâțel",
    "urâțelele": "urâțel",
    "urâțelelor": "urâțel",
    "urâțica": "urâțel",
    "urâțică": "urâțel",
    "urâțenia": "urâțenie",
    "urâțeniei": "urâțenie",
    "urâțenii": "urâțenie",
    "urâțeniile": "urâțenie",
    "urâțeniilor": "urâțenie",
    "nemaiurâțind": "urâți",
    "nemaiurâțindu": "urâți",
    "neurâțind": "urâți",
    "neurâțindu": "urâți",
    "urâțea": "urâți",
    "urâțeai": "urâți",
    "urâțeam": "urâți",
    "urâțească": "urâți",
    "urâțeați": "urâți",
    "urâțeau": "urâți",
    "urâțesc": "urâți",
    "urâțește": "urâți",
    "urâțești": "urâți",
    "urâții": "urâți",
    "urâțim": "urâți",
    "urâțind": "urâți",
    "urâțindu": "urâți",
    "urâțiră": "urâți",
    "urâțirăm": "urâți",
    "urâțirăți": "urâți",
    "urâțise": "urâți",
    "urâțisem": "urâți",
    "urâțiseră": "urâți",
    "urâțiserăm": "urâți",
    "urâțiserăți": "urâți",
    "urâțiseși": "urâți",
    "urâțiși": "urâți",
    "urâțit": "urâți",
    "urâțiți": "urâți",
    "urâțirea": "urâțire",
    "urâțireo": "urâțire",
    "urâțiri": "urâțire",
    "urâțirii": "urâțire",
    "urâțirile": "urâțire",
    "urâțirilor": "urâțire",
    "urâțita": "urâțit",
    "urâțită": "urâțit",
    "urâțite": "urâțit",
    "urâțitei": "urâțit",
    "urâțitele": "urâțit",
    "urâțitelor": "urâțit",
    "urâțiți": "urâțit",
    "urâțiții": "urâțit",
    "urâțiților": "urâțit",
    "urâțito": "urâțit",
    "urâțitul": "urâțit",
    "urâțitule": "urâțit",
    "urâțitului": "urâțit",
    "urătoarea": "urătoare",
    "urătoarei": "urătoare",
    "urătoarele": "urătoare",
    "urătoarelor": "urătoare",
    "urătoareo": "urătoare",
    "urători": "urător",
    "urătorii": "urător",
    "urătorilor": "urător",
    "urătorul": "urător",
    "urătorule": "urător",
    "urătorului": "urător",
    "urătura": "urătură",
    "urături": "urătură",
    "urăturii": "urătură",
    "urăturile": "urătură",
    "urăturilor": "urătură",
    "urăturo": "urătură",
    "urbana": "urban",
    "urbană": "urban",
    "urbane": "urban",
    "urbanei": "urban",
    "urbanele": "urban",
    "urbanelor": "urban",
    "urbani": "urban",
    "urbanii": "urban",
    "urbanilor": "urban",
    "urbanul": "urban",
    "urbanului": "urban",
    "urbanismul": "urbanism",
    "urbanismului": "urbanism",
    "urbanistică": "urbanistic",
    "urbanistice": "urbanistic",
    "urbanistici": "urbanistic",
    "urb.": "urbanistică",
    "urbanistica": "urbanistică",
    "urbanistici": "urbanistică",
    "urbanisticii": "urbanistică",
    "urbea": "urbe",
    "urbei": "urbe",
    "urbele": "urbe",
    "urbelor": "urbe",
    "nemaiurcând": "urca",
    "nemaiurcându": "urca",
    "neurcând": "urca",
    "neurcându": "urca",
    "urc": "urca",
    "urcă": "urca",
    "urcai": "urca",
    "urcam": "urca",
    "urcăm": "urca",
    "urcând": "urca",
    "urcându": "urca",
    "urcară": "urca",
    "urcarăm": "urca",
    "urcarăți": "urca",
    "urcase": "urca",
    "urcasem": "urca",
    "urcaseră": "urca",
    "urcaserăm": "urca",
    "urcaserăți": "urca",
    "urcaseși": "urca",
    "urcași": "urca",
    "urcat": "urca",
    "urcați": "urca",
    "urcau": "urca",
    "urce": "urca",
    "urci": "urca",
    "urcarea": "urcare",
    "urcareo": "urcare",
    "urcări": "urcare",
    "urcării": "urcare",
    "urcările": "urcare",
    "urcărilor": "urcare",
    "urcata": "urcat",
    "urcată": "urcat",
    "urcate": "urcat",
    "urcatei": "urcat",
    "urcatele": "urcat",
    "urcatelor": "urcat",
    "urcați": "urcat",
    "urcații": "urcat",
    "urcaților": "urcat",
    "urcato": "urcat",
    "urcatul": "urcat",
    "urcatule": "urcat",
    "urcatului": "urcat",
    "urcătoare": "urcător",
    "urcătoarea": "urcător",
    "urcătoarei": "urcător",
    "urcătoarele": "urcător",
    "urcătoarelor": "urcător",
    "urcătoareo": "urcător",
    "urcători": "urcător",
    "urcătorii": "urcător",
    "urcătorilor": "urcător",
    "urcătorul": "urcător",
    "urcătorule": "urcător",
    "urcătorului": "urcător",
    "urcușul": "urcuș",
    "urcușului": "urcuș",
    "urcușuri": "urcuș",
    "urcușurile": "urcuș",
    "urcușurilor": "urcuș",
    "urda": "urdă",
    "urde": "urdă",
    "urdei": "urdă",
    "urdele": "urdă",
    "urdelor": "urdă",
    "urechea": "ureche",
    "urechi": "ureche",
    "urechii": "ureche",
    "urechile": "ureche",
    "urechilor": "ureche",
    "nemaiurecheând": "urechea",
    "nemaiurecheându": "urechea",
    "neurecheând": "urechea",
    "neurecheându": "urechea",
    "urecheai": "urechea",
    "urecheam": "urechea",
    "urecheăm": "urechea",
    "urecheând": "urechea",
    "urecheându": "urechea",
    "urecheară": "urechea",
    "urechearăm": "urechea",
    "urechearăți": "urechea",
    "urechease": "urechea",
    "urecheasem": "urechea",
    "urecheaseră": "urechea",
    "urecheaserăm": "urechea",
    "urecheaserăți": "urechea",
    "urecheaseși": "urechea",
    "urecheași": "urechea",
    "urecheat": "urechea",
    "urecheați": "urechea",
    "urecheau": "urechea",
    "urechează": "urechea",
    "urechez": "urechea",
    "urecheze": "urechea",
    "urechezi": "urechea",
    "urecheala": "urecheală",
    "urechealo": "urecheală",
    "urecheli": "urecheală",
    "urechelii": "urecheală",
    "urechelile": "urecheală",
    "urechelilor": "urecheală",
    "urecheata": "urecheat",
    "urecheată": "urecheat",
    "urecheate": "urecheat",
    "urecheatei": "urecheat",
    "urecheatele": "urecheat",
    "urecheatelor": "urecheat",
    "urecheați": "urecheat",
    "urecheații": "urecheat",
    "urecheaților": "urecheat",
    "urecheato": "urecheat",
    "urecheatul": "urecheat",
    "urecheatule": "urecheat",
    "urecheatului": "urecheat",
    "urechiatul": "urecheat",
    "urechiușa": "urechiușă",
    "urechiușe": "urechiușă",
    "urechiușei": "urechiușă",
    "urechiușele": "urechiușă",
    "urechiușelor": "urechiușă",
    "ureea": "uree",
    "ureei": "uree",
    "uremica": "uremic",
    "uremică": "uremic",
    "uremice": "uremic",
    "uremicei": "uremic",
    "uremicele": "uremic",
    "uremicelor": "uremic",
    "uremici": "uremic",
    "uremicii": "uremic",
    "uremicilor": "uremic",
    "uremicul": "uremic",
    "uremicului": "uremic",
    "uretere": "ureter",
    "ureterele": "ureter",
    "ureterelor": "ureter",
    "ureterul": "ureter",
    "ureterului": "ureter",
    "uretra": "uretră",
    "uretre": "uretră",
    "uretrei": "uretră",
    "uretrele": "uretră",
    "uretrelor": "uretră",
    "uretrala": "uretral",
    "uretrală": "uretral",
    "uretrale": "uretral",
    "uretralei": "uretral",
    "uretralele": "uretral",
    "uretralelor": "uretral",
    "uretrali": "uretral",
    "uretralii": "uretral",
    "uretralilor": "uretral",
    "uretralul": "uretral",
    "uretralului": "uretral",
    "uretrita": "uretrită",
    "uretrite": "uretrită",
    "uretritei": "uretrită",
    "uretritele": "uretrită",
    "uretritelor": "uretrită",
    "uretroscoape": "uretroscop",
    "uretroscoapele": "uretroscop",
    "uretroscoapelor": "uretroscop",
    "uretroscopul": "uretroscop",
    "uretroscopului": "uretroscop",
    "urgenta": "urgent",
    "urgentă": "urgent",
    "urgente": "urgent",
    "urgentei": "urgent",
    "urgentele": "urgent",
    "urgentelor": "urgent",
    "urgenți": "urgent",
    "urgenții": "urgent",
    "urgenților": "urgent",
    "urgentul": "urgent",
    "urgentului": "urgent",
    "nemaiurgentând": "urgenta",
    "nemaiurgentându": "urgenta",
    "neurgentând": "urgenta",
    "neurgentându": "urgenta",
    "urgentă": "urgenta",
    "urgentai": "urgenta",
    "urgentam": "urgenta",
    "urgentăm": "urgenta",
    "urgentând": "urgenta",
    "urgentându": "urgenta",
    "urgentară": "urgenta",
    "urgentarăm": "urgenta",
    "urgentarăți": "urgenta",
    "urgentase": "urgenta",
    "urgentasem": "urgenta",
    "urgentaseră": "urgenta",
    "urgentaserăm": "urgenta",
    "urgentaserăți": "urgenta",
    "urgentaseși": "urgenta",
    "urgentași": "urgenta",
    "urgentat": "urgenta",
    "urgentați": "urgenta",
    "urgentau": "urgenta",
    "urgentează": "urgenta",
    "urgentez": "urgenta",
    "urgenteze": "urgenta",
    "urgentezi": "urgenta",
    "urgența": "urgență",
    "urgențe": "urgență",
    "urgenței": "urgență",
    "urgențele": "urgență",
    "urgențelor": "urgență",
    "urgentată": "urgentat",
    "urgentate": "urgentat",
    "urgentați": "urgentat",
    "urgia": "urgie",
    "urgiei": "urgie",
    "urgii": "urgie",
    "urgiile": "urgie",
    "urgiilor": "urgie",
    "nemaiurgisind": "urgisi",
    "nemaiurgisindu": "urgisi",
    "neurgisind": "urgisi",
    "neurgisindu": "urgisi",
    "urgisea": "urgisi",
    "urgiseai": "urgisi",
    "urgiseam": "urgisi",
    "urgisească": "urgisi",
    "urgiseați": "urgisi",
    "urgiseau": "urgisi",
    "urgisesc": "urgisi",
    "urgisește": "urgisi",
    "urgisești": "urgisi",
    "urgisii": "urgisi",
    "urgisim": "urgisi",
    "urgisind": "urgisi",
    "urgisindu": "urgisi",
    "urgisiră": "urgisi",
    "urgisirăm": "urgisi",
    "urgisirăți": "urgisi",
    "urgisise": "urgisi",
    "urgisisem": "urgisi",
    "urgisiseră": "urgisi",
    "urgisiserăm": "urgisi",
    "urgisiserăți": "urgisi",
    "urgisiseși": "urgisi",
    "urgisiși": "urgisi",
    "urgisit": "urgisi",
    "urgisiți": "urgisi",
    "urgisirea": "urgisire",
    "urgisireo": "urgisire",
    "urgisiri": "urgisire",
    "urgisirii": "urgisire",
    "urgisirile": "urgisire",
    "urgisirilor": "urgisire",
    "urgisita": "urgisit",
    "urgisită": "urgisit",
    "urgisite": "urgisit",
    "urgisitei": "urgisit",
    "urgisitele": "urgisit",
    "urgisitelor": "urgisit",
    "urgisiți": "urgisit",
    "urgisiții": "urgisit",
    "urgisiților": "urgisit",
    "urgisito": "urgisit",
    "urgisitul": "urgisit",
    "urgisitule": "urgisit",
    "urgisitului": "urgisit",
    "nemaiurând": "urî",
    "nemaiurându": "urî",
    "neurând": "urî",
    "neurându": "urî",
    "ura": "urî",
    "urai": "urî",
    "urâi": "urî",
    "uram": "urî",
    "urâm": "urî",
    "urând": "urî",
    "urându": "urî",
    "urâră": "urî",
    "urârăm": "urî",
    "urârăți": "urî",
    "urăsc": "urî",
    "urască": "urî",
    "urâse": "urî",
    "urâsem": "urî",
    "urâseră": "urî",
    "urâserăm": "urî",
    "urâserăți": "urî",
    "urâseși": "urî",
    "urâși": "urî",
    "urăște": "urî",
    "urăști": "urî",
    "urât": "urî",
    "urați": "urî",
    "urâți": "urî",
    "urau": "urî",
    "uriașa": "uriaș",
    "uriașă": "uriaș",
    "uriașe": "uriaș",
    "uriașei": "uriaș",
    "uriașele": "uriaș",
    "uriașelor": "uriaș",
    "uriași": "uriaș",
    "uriașii": "uriaș",
    "uriașilor": "uriaș",
    "uriașo": "uriaș",
    "uriașul": "uriaș",
    "uriașule": "uriaș",
    "uriașului": "uriaș",
    "uriașa": "uriașă",
    "uriașe": "uriașă",
    "uriașei": "uriașă",
    "uriașele": "uriașă",
    "uriașelor": "uriașă",
    "urină": "urina",
    "urinai": "urina",
    "urinam": "urina",
    "urinăm": "urina",
    "urinând": "urina",
    "urinându": "urina",
    "urinară": "urina",
    "urinarăm": "urina",
    "urinarăți": "urina",
    "urinase": "urina",
    "urinasem": "urina",
    "urinaseră": "urina",
    "urinaserăm": "urina",
    "urinaserăți": "urina",
    "urinaseși": "urina",
    "urinași": "urina",
    "urinat": "urina",
    "urinați": "urina",
    "urinatu": "urina",
    "urinau": "urina",
    "urinează": "urina",
    "urinez": "urina",
    "urineze": "urina",
    "urinezi": "urina",
    "urina": "urină",
    "urine": "urină",
    "urinei": "urină",
    "urinele": "urină",
    "urinelor": "urină",
    "urinara": "urinar",
    "urinară": "urinar",
    "urinare": "urinar",
    "urinarei": "urinar",
    "urinarele": "urinar",
    "urinarelor": "urinar",
    "urinari": "urinar",
    "urinarii": "urinar",
    "urinarilor": "urinar",
    "urinarul": "urinar",
    "urinarului": "urinar",
    "urinată": "urinat",
    "urinate": "urinat",
    "urinați": "urinat",
    "nemaiurlând": "urla",
    "nemaiurlându": "urla",
    "neurlând": "urla",
    "neurlându": "urla",
    "urlă": "urla",
    "urlai": "urla",
    "urlam": "urla",
    "urlăm": "urla",
    "urlând": "urla",
    "urlându": "urla",
    "urlară": "urla",
    "urlarăm": "urla",
    "urlarăți": "urla",
    "urlase": "urla",
    "urlasem": "urla",
    "urlaseră": "urla",
    "urlaserăm": "urla",
    "urlaserăți": "urla",
    "urlaseși": "urla",
    "urlași": "urla",
    "urlat": "urla",
    "urlați": "urla",
    "urlau": "urla",
    "urle": "urla",
    "urli": "urla",
    "urlu": "urla",
    "urlata": "urlat",
    "urlată": "urlat",
    "urlate": "urlat",
    "urlatei": "urlat",
    "urlatele": "urlat",
    "urlatelor": "urlat",
    "urlați": "urlat",
    "urlații": "urlat",
    "urlaților": "urlat",
    "urlato": "urlat",
    "urlatul": "urlat",
    "urlatule": "urlat",
    "urlatului": "urlat",
    "urlătoare": "urlător",
    "urlătoarea": "urlător",
    "urlătoarei": "urlător",
    "urlătoarele": "urlător",
    "urlătoarelor": "urlător",
    "urlătoareo": "urlător",
    "urlători": "urlător",
    "urlătorii": "urlător",
    "urlătorilor": "urlător",
    "urlătorul": "urlător",
    "urlătorule": "urlător",
    "urlătorului": "urlător",
    "urlete": "urlet",
    "urletele": "urlet",
    "urletelor": "urlet",
    "urletul": "urlet",
    "urletului": "urlet",
    "nemaiurluind": "urlui",
    "nemaiurluindu": "urlui",
    "neurluind": "urlui",
    "neurluindu": "urlui",
    "urluia": "urlui",
    "urluiai": "urlui",
    "urluiam": "urlui",
    "urluiască": "urlui",
    "urluiați": "urlui",
    "urluiau": "urlui",
    "urluiesc": "urlui",
    "urluiește": "urlui",
    "urluiești": "urlui",
    "urluii": "urlui",
    "urluim": "urlui",
    "urluind": "urlui",
    "urluindu": "urlui",
    "urluiră": "urlui",
    "urluirăm": "urlui",
    "urluirăți": "urlui",
    "urluise": "urlui",
    "urluisem": "urlui",
    "urluiseră": "urlui",
    "urluiserăm": "urlui",
    "urluiserăți": "urlui",
    "urluiseși": "urlui",
    "urluiși": "urlui",
    "urluit": "urlui",
    "urluiți": "urlui",
    "urluiala": "urluială",
    "urluialo": "urluială",
    "urluieli": "urluială",
    "urluielii": "urluială",
    "urluielile": "urluială",
    "urluielilor": "urluială",
    "urluita": "urluit",
    "urluită": "urluit",
    "urluite": "urluit",
    "urluitei": "urluit",
    "urluitele": "urluit",
    "urluitelor": "urluit",
    "urluiți": "urluit",
    "urluiții": "urluit",
    "urluiților": "urluit",
    "urluito": "urluit",
    "urluitul": "urluit",
    "urluitule": "urluit",
    "urluitului": "urluit",
    "nemaiurmând": "urma",
    "nemaiurmându": "urma",
    "neurmând": "urma",
    "neurmându": "urma",
    "urmă": "urma",
    "urmai": "urma",
    "urmam": "urma",
    "urmăm": "urma",
    "urmând": "urma",
    "urmându": "urma",
    "urmară": "urma",
    "urmarăm": "urma",
    "urmarăți": "urma",
    "urmase": "urma",
    "urmasem": "urma",
    "urmaseră": "urma",
    "urmaserăm": "urma",
    "urmaserăți": "urma",
    "urmaseși": "urma",
    "urmași": "urma",
    "urmat": "urma",
    "urmați": "urma",
    "urmau": "urma",
    "urmează": "urma",
    "urmez": "urma",
    "urmeze": "urma",
    "urmezi": "urma",
    "ormă": "urmă",
    "urma": "urmă",
    "urme": "urmă",
    "urmei": "urmă",
    "urmele": "urmă",
    "urmelor": "urmă",
    "urmarea": "urmare",
    "urmări": "urmare",
    "urmării": "urmare",
    "urmările": "urmare",
    "urmărilor": "urmare",
    "nemaiurmărind": "urmări",
    "nemaiurmărindu": "urmări",
    "neurmărind": "urmări",
    "neurmărindu": "urmări",
    "urmărea": "urmări",
    "urmăreai": "urmări",
    "urmăream": "urmări",
    "urmărească": "urmări",
    "urmăreați": "urmări",
    "urmăreau": "urmări",
    "urmăresc": "urmări",
    "urmărește": "urmări",
    "urmărești": "urmări",
    "urmării": "urmări",
    "urmărim": "urmări",
    "urmărind": "urmări",
    "urmărindu": "urmări",
    "urmăriră": "urmări",
    "urmărirăm": "urmări",
    "urmărirăți": "urmări",
    "urmărise": "urmări",
    "urmărisem": "urmări",
    "urmăriseră": "urmări",
    "urmăriserăm": "urmări",
    "urmăriserăți": "urmări",
    "urmăriseși": "urmări",
    "urmăriși": "urmări",
    "urmărit": "urmări",
    "urmăriți": "urmări",
    "urmărirea": "urmărire",
    "urmărireo": "urmărire",
    "urmăriri": "urmărire",
    "urmăririi": "urmărire",
    "urmăririle": "urmărire",
    "urmăririlor": "urmărire",
    "urmărita": "urmărit",
    "urmărită": "urmărit",
    "urmărite": "urmărit",
    "urmăritei": "urmărit",
    "urmăritele": "urmărit",
    "urmăritelor": "urmărit",
    "urmăriți": "urmărit",
    "urmăriții": "urmărit",
    "urmăriților": "urmărit",
    "urmărito": "urmărit",
    "urmăritul": "urmărit",
    "urmăritule": "urmărit",
    "urmăritului": "urmărit",
    "urmăritori": "urmăritor",
    "urmăritorii": "urmăritor",
    "urmăritorilor": "urmăritor",
    "urmăritorul": "urmăritor",
    "urmăritorului": "urmăritor",
    "urmașa": "urmaș",
    "urmașă": "urmaș",
    "urmașe": "urmaș",
    "urmașei": "urmaș",
    "urmașele": "urmaș",
    "urmașelor": "urmaș",
    "urmași": "urmaș",
    "urmașii": "urmaș",
    "urmașilor": "urmaș",
    "urmașul": "urmaș",
    "urmașului": "urmaș",
    "urmată": "urmat",
    "urmate": "urmat",
    "urmați": "urmat",
    "următoarei": "următoarea",
    "următoarele": "următoarea",
    "următoarelor": "următoarea",
    "urm.": "următoarele",
    "următoare": "următor",
    "următoarea": "următor",
    "următoarei": "următor",
    "următoarele": "următor",
    "următoarelor": "următor",
    "următori": "următor",
    "următorii": "următor",
    "următorilor": "următor",
    "următorul": "următor",
    "următorului": "următor",
    "următorii": "următorul",
    "următorilor": "următorul",
    "următoru'": "următorul",
    "următorului": "următorul",
    "urna": "urnă",
    "urne": "urnă",
    "urnei": "urnă",
    "urnele": "urnă",
    "urnelor": "urnă",
    "nemaiurnind": "urni",
    "nemaiurnindu": "urni",
    "neurnind": "urni",
    "neurnindu": "urni",
    "urnea": "urni",
    "urneai": "urni",
    "urneam": "urni",
    "urnească": "urni",
    "urneați": "urni",
    "urneau": "urni",
    "urnesc": "urni",
    "urnește": "urni",
    "urnești": "urni",
    "urnii": "urni",
    "urnim": "urni",
    "urnind": "urni",
    "urnindu": "urni",
    "urniră": "urni",
    "urnirăm": "urni",
    "urnirăți": "urni",
    "urnise": "urni",
    "urnisem": "urni",
    "urniseră": "urni",
    "urniserăm": "urni",
    "urniserăți": "urni",
    "urniseși": "urni",
    "urniși": "urni",
    "urnit": "urni",
    "urniți": "urni",
    "urnirea": "urnire",
    "urnireo": "urnire",
    "urniri": "urnire",
    "urnirii": "urnire",
    "urnirile": "urnire",
    "urnirilor": "urnire",
    "urnita": "urnit",
    "urnită": "urnit",
    "urnite": "urnit",
    "urnitei": "urnit",
    "urnitele": "urnit",
    "urnitelor": "urnit",
    "urniți": "urnit",
    "urniții": "urnit",
    "urniților": "urnit",
    "urnito": "urnit",
    "urnitul": "urnit",
    "urnitule": "urnit",
    "urnitului": "urnit",
    "urologia": "urologie",
    "urologiei": "urologie",
    "urologii": "urologie",
    "urologiile": "urologie",
    "urologiilor": "urologie",
    "uroscopia": "uroscopie",
    "uroscopiei": "uroscopie",
    "uroscopii": "uroscopie",
    "uroscopiile": "uroscopie",
    "uroscopiilor": "uroscopie",
    "urotropina": "urotropină",
    "urotropine": "urotropină",
    "urotropinei": "urotropină",
    "urotropinele": "urotropină",
    "urotropinelor": "urotropină",
    "urși": "urs",
    "urșii": "urs",
    "urșilor": "urs",
    "ursul": "urs",
    "ursului": "urs",
    "nemaiursind": "ursi",
    "nemaiursindu": "ursi",
    "neursind": "ursi",
    "neursindu": "ursi",
    "ursea": "ursi",
    "urseai": "ursi",
    "urseam": "ursi",
    "ursească": "ursi",
    "urseați": "ursi",
    "urseau": "ursi",
    "ursesc": "ursi",
    "ursește": "ursi",
    "ursești": "ursi",
    "ursii": "ursi",
    "ursim": "ursi",
    "ursind": "ursi",
    "ursindu": "ursi",
    "ursiră": "ursi",
    "ursirăm": "ursi",
    "ursirăți": "ursi",
    "ursise": "ursi",
    "ursisem": "ursi",
    "ursiseră": "ursi",
    "ursiserăm": "ursi",
    "ursiserăți": "ursi",
    "ursiseși": "ursi",
    "ursiși": "ursi",
    "ursit": "ursi",
    "ursiți": "ursi",
    "ursirea": "ursire",
    "ursireo": "ursire",
    "ursiri": "ursire",
    "ursirii": "ursire",
    "ursirile": "ursire",
    "ursirilor": "ursire",
    "ursita": "ursit",
    "ursită": "ursit",
    "ursite": "ursit",
    "ursitei": "ursit",
    "ursitele": "ursit",
    "ursitelor": "ursit",
    "ursiți": "ursit",
    "ursiții": "ursit",
    "ursiților": "ursit",
    "ursito": "ursit",
    "ursitul": "ursit",
    "ursitule": "ursit",
    "ursitului": "ursit",
    "ursita": "ursită",
    "ursite": "ursită",
    "ursitei": "ursită",
    "ursitele": "ursită",
    "ursitelor": "ursită",
    "ursuza": "ursuz",
    "ursuză": "ursuz",
    "ursuze": "ursuz",
    "ursuzei": "ursuz",
    "ursuzele": "ursuz",
    "ursuzelor": "ursuz",
    "ursuzi": "ursuz",
    "ursuzii": "ursuz",
    "ursuzilor": "ursuz",
    "ursuzul": "ursuz",
    "ursuzului": "ursuz",
    "urticaria": "urticarie",
    "urticariei": "urticarie",
    "urticarii": "urticarie",
    "urticariile": "urticarie",
    "urticariilor": "urticarie",
    "urzeala": "urzeală",
    "urzealo": "urzeală",
    "urzeli": "urzeală",
    "urzelii": "urzeală",
    "urzelile": "urzeală",
    "urzelilor": "urzeală",
    "nemaiurzind": "urzi",
    "nemaiurzindu": "urzi",
    "neurzind": "urzi",
    "neurzindu": "urzi",
    "urzea": "urzi",
    "urzeai": "urzi",
    "urzeam": "urzi",
    "urzească": "urzi",
    "urzeați": "urzi",
    "urzeau": "urzi",
    "urzesc": "urzi",
    "urzește": "urzi",
    "urzești": "urzi",
    "urzii": "urzi",
    "urzim": "urzi",
    "urzind": "urzi",
    "urzindu": "urzi",
    "urziră": "urzi",
    "urzirăm": "urzi",
    "urzirăți": "urzi",
    "urzise": "urzi",
    "urzisem": "urzi",
    "urziseră": "urzi",
    "urziserăm": "urzi",
    "urziserăți": "urzi",
    "urziseși": "urzi",
    "urziși": "urzi",
    "urzit": "urzi",
    "urziți": "urzi",
    "urzica": "urzică",
    "urzici": "urzică",
    "urzicii": "urzică",
    "urzicile": "urzică",
    "urzicilor": "urzică",
    "urzirea": "urzire",
    "urzireo": "urzire",
    "urziri": "urzire",
    "urzirii": "urzire",
    "urzirile": "urzire",
    "urzirilor": "urzire",
    "urzita": "urzit",
    "urzită": "urzit",
    "urzite": "urzit",
    "urzitei": "urzit",
    "urzitele": "urzit",
    "urzitelor": "urzit",
    "urziți": "urzit",
    "urziții": "urzit",
    "urziților": "urzit",
    "urzito": "urzit",
    "urzitul": "urzit",
    "urzitule": "urzit",
    "urzitului": "urzit",
    "ușa": "ușă",
    "uși": "ușă",
    "ușii": "ușă",
    "ușile": "ușă",
    "ușilor": "ușă",
    "nemaiuscând": "usca",
    "nemaiuscându": "usca",
    "neuscând": "usca",
    "neuscându": "usca",
    "uscă": "usca",
    "uscai": "usca",
    "uscam": "usca",
    "uscăm": "usca",
    "uscând": "usca",
    "uscându": "usca",
    "uscară": "usca",
    "uscarăm": "usca",
    "uscarăți": "usca",
    "uscase": "usca",
    "uscasem": "usca",
    "uscaseră": "usca",
    "uscaserăm": "usca",
    "uscaserăți": "usca",
    "uscaseși": "usca",
    "uscași": "usca",
    "uscat": "usca",
    "uscați": "usca",
    "uscau": "usca",
    "usuc": "usca",
    "usucă": "usca",
    "usuce": "usca",
    "usuci": "usca",
    "uscăcioasa": "uscăcios",
    "uscăcioasă": "uscăcios",
    "uscăcioase": "uscăcios",
    "uscăcioasei": "uscăcios",
    "uscăcioasele": "uscăcios",
    "uscăcioaselor": "uscăcios",
    "uscăcioși": "uscăcios",
    "uscăcioșii": "uscăcios",
    "uscăcioșilor": "uscăcios",
    "uscăciosul": "uscăcios",
    "uscăciosului": "uscăcios",
    "uscăciunea": "uscăciune",
    "uscăciuni": "uscăciune",
    "uscăciunii": "uscăciune",
    "uscăciunile": "uscăciune",
    "uscăciunilor": "uscăciune",
    "uscarea": "uscare",
    "uscareo": "uscare",
    "uscări": "uscare",
    "uscării": "uscare",
    "uscările": "uscare",
    "uscărilor": "uscare",
    "uscata": "uscat",
    "uscată": "uscat",
    "uscate": "uscat",
    "uscatei": "uscat",
    "uscatele": "uscat",
    "uscatelor": "uscat",
    "uscați": "uscat",
    "uscații": "uscat",
    "uscaților": "uscat",
    "uscato": "uscat",
    "uscatul": "uscat",
    "uscatule": "uscat",
    "uscatului": "uscat",
    "uscățiva": "uscățiv",
    "uscățivă": "uscățiv",
    "uscățive": "uscățiv",
    "uscățivei": "uscățiv",
    "uscățivele": "uscățiv",
    "uscățivelor": "uscățiv",
    "uscățivi": "uscățiv",
    "uscățivii": "uscățiv",
    "uscățivilor": "uscățiv",
    "uscățivul": "uscățiv",
    "uscățivului": "uscățiv",
    "uscătoare": "uscător",
    "uscătoarele": "uscător",
    "uscătoarelor": "uscător",
    "uscătorul": "uscător",
    "uscătorului": "uscător",
    "uscătoria": "uscătorie",
    "uscătoriei": "uscătorie",
    "uscătorii": "uscătorie",
    "uscătoriile": "uscătorie",
    "uscătoriilor": "uscătorie",
    "uscătura": "uscătură",
    "uscături": "uscătură",
    "uscăturii": "uscătură",
    "uscăturile": "uscătură",
    "uscăturilor": "uscătură",
    "uscăturo": "uscătură",
    "ușița": "ușiță",
    "ușițe": "ușiță",
    "ușiței": "ușiță",
    "ușițele": "ușiță",
    "ușițelor": "ușiță",
    "uslași": "uslaș",
    "uslașii": "uslaș",
    "uslașilor": "uslaș",
    "uslașul": "uslaș",
    "uslașului": "uslaș",
    "ușoara": "ușor",
    "ușoară": "ușor",
    "ușoare": "ușor",
    "ușoarei": "ușor",
    "ușoarele": "ușor",
    "ușoarelor": "ușor",
    "ușori": "ușor",
    "ușorii": "ușor",
    "ușorilor": "ușor",
    "ușorul": "ușor",
    "ușorului": "ușor",
    "nemaiusturând": "ustura",
    "nemaiusturându": "ustura",
    "neusturând": "ustura",
    "neusturându": "ustura",
    "ustur": "ustura",
    "ustură": "ustura",
    "usturai": "ustura",
    "usturam": "ustura",
    "usturăm": "ustura",
    "usturând": "ustura",
    "usturându": "ustura",
    "usturară": "ustura",
    "usturarăm": "ustura",
    "usturarăți": "ustura",
    "usturase": "ustura",
    "usturasem": "ustura",
    "usturaseră": "ustura",
    "usturaserăm": "ustura",
    "usturaserăți": "ustura",
    "usturaseși": "ustura",
    "usturași": "ustura",
    "usturat": "ustura",
    "usturați": "ustura",
    "usturau": "ustura",
    "usture": "ustura",
    "usturi": "ustura",
    "usturată": "usturat",
    "usturate": "usturat",
    "usturați": "usturat",
    "usturătoare": "usturător",
    "usturătoarea": "usturător",
    "usturătoarei": "usturător",
    "usturătoarele": "usturător",
    "usturătoarelor": "usturător",
    "usturători": "usturător",
    "usturătorii": "usturător",
    "usturătorilor": "usturător",
    "usturătorul": "usturător",
    "usturătorului": "usturător",
    "usturătura": "usturătură",
    "usturături": "usturătură",
    "usturăturii": "usturătură",
    "usturăturile": "usturătură",
    "usturăturilor": "usturătură",
    "usturăturo": "usturătură",
    "usturimea": "usturime",
    "usturimi": "usturime",
    "usturimii": "usturime",
    "usturimile": "usturime",
    "usturimilor": "usturime",
    "usturoiul": "usturoi",
    "usturoiului": "usturoi",
    "nemaiusturoiând": "usturoia",
    "nemaiusturoiându": "usturoia",
    "neusturoiând": "usturoia",
    "neusturoiându": "usturoia",
    "usturoiă": "usturoia",
    "usturoiai": "usturoia",
    "usturoiam": "usturoia",
    "usturoiară": "usturoia",
    "usturoiarăm": "usturoia",
    "usturoiarăți": "usturoia",
    "usturoiase": "usturoia",
    "usturoiasem": "usturoia",
    "usturoiaseră": "usturoia",
    "usturoiaserăm": "usturoia",
    "usturoiaserăți": "usturoia",
    "usturoiaseși": "usturoia",
    "usturoiași": "usturoia",
    "usturoiat": "usturoia",
    "usturoiați": "usturoia",
    "usturoiau": "usturoia",
    "usturoiează": "usturoia",
    "usturoiez": "usturoia",
    "usturoieze": "usturoia",
    "usturoiezi": "usturoia",
    "usturoim": "usturoia",
    "usturoind": "usturoia",
    "usturoindu": "usturoia",
    "usturoiata": "usturoiat",
    "usturoiată": "usturoiat",
    "usturoiate": "usturoiat",
    "usturoiatei": "usturoiat",
    "usturoiatele": "usturoiat",
    "usturoiatelor": "usturoiat",
    "usturoiați": "usturoiat",
    "usturoiații": "usturoiat",
    "usturoiaților": "usturoiat",
    "usturoiato": "usturoiat",
    "usturoiatul": "usturoiat",
    "usturoiatule": "usturoiat",
    "usturoiatului": "usturoiat",
    "nemaiușurând": "ușura",
    "nemaiușurându": "ușura",
    "neușurând": "ușura",
    "neușurându": "ușura",
    "ușură": "ușura",
    "ușurai": "ușura",
    "ușuram": "ușura",
    "ușurăm": "ușura",
    "ușurând": "ușura",
    "ușurându": "ușura",
    "ușurară": "ușura",
    "ușurarăm": "ușura",
    "ușurarăți": "ușura",
    "ușurase": "ușura",
    "ușurasem": "ușura",
    "ușuraseră": "ușura",
    "ușuraserăm": "ușura",
    "ușuraserăți": "ușura",
    "ușuraseși": "ușura",
    "ușurași": "ușura",
    "ușurat": "ușura",
    "ușurați": "ușura",
    "ușurau": "ușura",
    "ușurează": "ușura",
    "ușurez": "ușura",
    "ușureze": "ușura",
    "ușurezi": "ușura",
    "ușurarea": "ușurare",
    "ușurareo": "ușurare",
    "ușurări": "ușurare",
    "ușurării": "ușurare",
    "ușurările": "ușurare",
    "ușurărilor": "ușurare",
    "ușurata": "ușurat",
    "ușurată": "ușurat",
    "ușurate": "ușurat",
    "ușuratei": "ușurat",
    "ușuratele": "ușurat",
    "ușuratelor": "ușurat",
    "ușurați": "ușurat",
    "ușurații": "ușurat",
    "ușuraților": "ușurat",
    "ușurato": "ușurat",
    "ușuratul": "ușurat",
    "ușuratule": "ușurat",
    "ușuratului": "ușurat",
    "ușurătatea": "ușurătate",
    "ușurătăți": "ușurătate",
    "ușurătății": "ușurătate",
    "ușurătățile": "ușurătate",
    "ușurătăților": "ușurătate",
    "ușuratica": "ușuratic",
    "ușuratică": "ușuratic",
    "ușuratice": "ușuratic",
    "ușuraticei": "ușuratic",
    "ușuraticele": "ușuratic",
    "ușuraticelor": "ușuratic",
    "ușuratici": "ușuratic",
    "ușuraticii": "ușuratic",
    "ușuraticilor": "ușuratic",
    "ușuraticul": "ușuratic",
    "ușuraticului": "ușuratic",
    "ușurei": "ușurel",
    "ușureii": "ușurel",
    "ușureilor": "ușurel",
    "ușurelul": "ușurel",
    "ușurelului": "ușurel",
    "ușurința": "ușurință",
    "ușurințe": "ușurință",
    "ușurinței": "ușurință",
    "ușurințele": "ușurință",
    "ușurințelor": "ușurință",
    "u.s.": "ut_supra",
    "utere": "uter",
    "uterele": "uter",
    "uterelor": "uter",
    "uterul": "uter",
    "uterului": "uter",
    "uterina": "uterin",
    "uterină": "uterin",
    "uterine": "uterin",
    "uterinei": "uterin",
    "uterinele": "uterin",
    "uterinelor": "uterin",
    "uterini": "uterin",
    "uterinii": "uterin",
    "uterinilor": "uterin",
    "uterinul": "uterin",
    "uterinului": "uterin",
    "utila": "util",
    "utilă": "util",
    "utile": "util",
    "utilei": "util",
    "utilele": "util",
    "utilelor": "util",
    "utili": "util",
    "utilii": "util",
    "utililor": "util",
    "utilul": "util",
    "utilului": "util",
    "nemaiutilând": "utila",
    "nemaiutilându": "utila",
    "neutilând": "utila",
    "neutilându": "utila",
    "utilă": "utila",
    "utilai": "utila",
    "utilam": "utila",
    "utilăm": "utila",
    "utilând": "utila",
    "utilându": "utila",
    "utilară": "utila",
    "utilarăm": "utila",
    "utilarăți": "utila",
    "utilase": "utila",
    "utilasem": "utila",
    "utilaseră": "utila",
    "utilaserăm": "utila",
    "utilaserăți": "utila",
    "utilaseși": "utila",
    "utilași": "utila",
    "utilat": "utila",
    "utilați": "utila",
    "utilau": "utila",
    "utilează": "utila",
    "utilez": "utila",
    "utileze": "utila",
    "utilezi": "utila",
    "utilaje": "utilaj",
    "utilajele": "utilaj",
    "utilajelor": "utilaj",
    "utilajul": "utilaj",
    "utilajului": "utilaj",
    "utilarea": "utilare",
    "utilareo": "utilare",
    "utilări": "utilare",
    "utilării": "utilare",
    "utilările": "utilare",
    "utilărilor": "utilare",
    "utilata": "utilat",
    "utilată": "utilat",
    "utilate": "utilat",
    "utilatei": "utilat",
    "utilatele": "utilat",
    "utilatelor": "utilat",
    "utilați": "utilat",
    "utilații": "utilat",
    "utilaților": "utilat",
    "utilato": "utilat",
    "utilatul": "utilat",
    "utilatule": "utilat",
    "utilatului": "utilat",
    "utilitara": "utilitar",
    "utilitară": "utilitar",
    "utilitare": "utilitar",
    "utilitarei": "utilitar",
    "utilitarele": "utilitar",
    "utilitarelor": "utilitar",
    "utilitari": "utilitar",
    "utilitarii": "utilitar",
    "utilitarilor": "utilitar",
    "utilitarul": "utilitar",
    "utilitarului": "utilitar",
    "utilitarisme": "utilitarism",
    "utilitarismele": "utilitarism",
    "utilitarismelor": "utilitarism",
    "utilitarismul": "utilitarism",
    "utilitarismului": "utilitarism",
    "utilitatea": "utilitate",
    "utilități": "utilitate",
    "utilității": "utilitate",
    "utilitățile": "utilitate",
    "utilităților": "utilitate",
    "nemaiutilizând": "utiliza",
    "nemaiutilizându": "utiliza",
    "neutilizând": "utiliza",
    "neutilizându": "utiliza",
    "utiliză": "utiliza",
    "utilizai": "utiliza",
    "utilizam": "utiliza",
    "utilizăm": "utiliza",
    "utilizând": "utiliza",
    "utilizându": "utiliza",
    "utilizară": "utiliza",
    "utilizarăm": "utiliza",
    "utilizarăți": "utiliza",
    "utilizase": "utiliza",
    "utilizasem": "utiliza",
    "utilizaseră": "utiliza",
    "utilizaserăm": "utiliza",
    "utilizaserăți": "utiliza",
    "utilizaseși": "utiliza",
    "utilizași": "utiliza",
    "utilizat": "utiliza",
    "utilizați": "utiliza",
    "utilizau": "utiliza",
    "utilizează": "utiliza",
    "utilizez": "utiliza",
    "utilizeze": "utiliza",
    "utilizezi": "utiliza",
    "utilizabila": "utilizabil",
    "utilizabilă": "utilizabil",
    "utilizabile": "utilizabil",
    "utilizabilei": "utilizabil",
    "utilizabilele": "utilizabil",
    "utilizabilelor": "utilizabil",
    "utilizabili": "utilizabil",
    "utilizabilii": "utilizabil",
    "utilizabililor": "utilizabil",
    "utilizabilo": "utilizabil",
    "utilizabilul": "utilizabil",
    "utilizabilule": "utilizabil",
    "utilizabilului": "utilizabil",
    "utilizarea": "utilizare",
    "utilizareo": "utilizare",
    "utilizări": "utilizare",
    "utilizării": "utilizare",
    "utilizările": "utilizare",
    "utilizărilor": "utilizare",
    "utilizata": "utilizat",
    "utilizată": "utilizat",
    "utilizate": "utilizat",
    "utilizatei": "utilizat",
    "utilizatele": "utilizat",
    "utilizatelor": "utilizat",
    "utilizați": "utilizat",
    "utilizații": "utilizat",
    "utilizaților": "utilizat",
    "utilizato": "utilizat",
    "utilizatul": "utilizat",
    "utilizatule": "utilizat",
    "utilizatului": "utilizat",
    "utilizatoarea": "utilizatoare",
    "utilizatoarei": "utilizatoare",
    "utilizatoarele": "utilizatoare",
    "utilizatoarelor": "utilizatoare",
    "utilizatoare": "utilizator",
    "utilizatori": "utilizator",
    "utilizatorii": "utilizator",
    "utilizatorilor": "utilizator",
    "utilizatorul": "utilizator",
    "utilizatorului": "utilizator",
    "utopica": "utopic",
    "utopică": "utopic",
    "utopice": "utopic",
    "utopicei": "utopic",
    "utopicele": "utopic",
    "utopicelor": "utopic",
    "utopici": "utopic",
    "utopicii": "utopic",
    "utopicilor": "utopic",
    "utopicul": "utopic",
    "utopicului": "utopic",
    "utopia": "utopie",
    "utopiei": "utopie",
    "utopii": "utopie",
    "utopiile": "utopie",
    "utopiilor": "utopie",
    "utopismul": "utopism",
    "utopismului": "utopism",
    "utopista": "utopist",
    "utopistă": "utopist",
    "utopiste": "utopist",
    "utopistei": "utopist",
    "utopistele": "utopist",
    "utopistelor": "utopist",
    "utopiști": "utopist",
    "utopiștii": "utopist",
    "utopiștilor": "utopist",
    "utopistul": "utopist",
    "utopistului": "utopist",
    "utrenia": "utrenie",
    "utreniei": "utrenie",
    "utrenii": "utrenie",
    "utreniile": "utrenie",
    "utreniilor": "utrenie",
    "uvertura": "uvertură",
    "uverturei": "uvertură",
    "uverturi": "uvertură",
    "uverturile": "uvertură",
    "uverturilor": "uvertură",
    "uzul": "uz",
    "uzului": "uz",
    "uzuri": "uz",
    "uzurile": "uz",
    "uzurilor": "uz",
    "nemaiuzând": "uza",
    "nemaiuzându": "uza",
    "neuzând": "uza",
    "neuzându": "uza",
    "uză": "uza",
    "uzai": "uza",
    "uzam": "uza",
    "uzăm": "uza",
    "uzând": "uza",
    "uzându": "uza",
    "uzară": "uza",
    "uzarăm": "uza",
    "uzarăți": "uza",
    "uzase": "uza",
    "uzasem": "uza",
    "uzaseră": "uza",
    "uzaserăm": "uza",
    "uzaserăți": "uza",
    "uzaseși": "uza",
    "uzași": "uza",
    "uzat": "uza",
    "uzați": "uza",
    "uzau": "uza",
    "uzează": "uza",
    "uzez": "uza",
    "uzeze": "uza",
    "uzezi": "uza",
    "uzajul": "uzaj",
    "uzajule": "uzaj",
    "uzajului": "uzaj",
    "uzajuri": "uzaj",
    "uzajurile": "uzaj",
    "uzajurilor": "uzaj",
    "uzanța": "uzanță",
    "uzanțe": "uzanță",
    "uzanței": "uzanță",
    "uzanțele": "uzanță",
    "uzanțelor": "uzanță",
    "uzarea": "uzare",
    "uzareo": "uzare",
    "uzări": "uzare",
    "uzării": "uzare",
    "uzările": "uzare",
    "uzărilor": "uzare",
    "uzata": "uzat",
    "uzată": "uzat",
    "uzate": "uzat",
    "uzatei": "uzat",
    "uzatele": "uzat",
    "uzatelor": "uzat",
    "uzați": "uzat",
    "uzații": "uzat",
    "uzaților": "uzat",
    "uzato": "uzat",
    "uzatul": "uzat",
    "uzatule": "uzat",
    "uzatului": "uzat",
    "uzina": "uzină",
    "uzine": "uzină",
    "uzinei": "uzină",
    "uzinele": "uzină",
    "uzinelor": "uzină",
    "nemaiuzitând": "uzita",
    "nemaiuzitându": "uzita",
    "neuzitând": "uzita",
    "neuzitându": "uzita",
    "uzită": "uzita",
    "uzitai": "uzita",
    "uzitam": "uzita",
    "uzităm": "uzita",
    "uzitând": "uzita",
    "uzitându": "uzita",
    "uzitară": "uzita",
    "uzitarăm": "uzita",
    "uzitarăți": "uzita",
    "uzitase": "uzita",
    "uzitasem": "uzita",
    "uzitaseră": "uzita",
    "uzitaserăm": "uzita",
    "uzitaserăți": "uzita",
    "uzitaseși": "uzita",
    "uzitași": "uzita",
    "uzitat": "uzita",
    "uzitați": "uzita",
    "uzitau": "uzita",
    "uzitează": "uzita",
    "uzitez": "uzita",
    "uziteze": "uzita",
    "uzitezi": "uzita",
    "uzitată": "uzitat",
    "uzitate": "uzitat",
    "uzitați": "uzitat",
    "uzuala": "uzual",
    "uzuală": "uzual",
    "uzuale": "uzual",
    "uzualei": "uzual",
    "uzualele": "uzual",
    "uzualelor": "uzual",
    "uzuali": "uzual",
    "uzualii": "uzual",
    "uzualilor": "uzual",
    "uzualul": "uzual",
    "uzualului": "uzual",
    "uzura": "uzură",
    "uzurei": "uzură",
    "uzuri": "uzură",
    "uzurile": "uzură",
    "uzurilor": "uzură",
    "nemaiuzurpând": "uzurpa",
    "nemaiuzurpându": "uzurpa",
    "neuzurpând": "uzurpa",
    "neuzurpându": "uzurpa",
    "uzurpă": "uzurpa",
    "uzurpai": "uzurpa",
    "uzurpam": "uzurpa",
    "uzurpăm": "uzurpa",
    "uzurpând": "uzurpa",
    "uzurpându": "uzurpa",
    "uzurpară": "uzurpa",
    "uzurparăm": "uzurpa",
    "uzurparăți": "uzurpa",
    "uzurpase": "uzurpa",
    "uzurpasem": "uzurpa",
    "uzurpaseră": "uzurpa",
    "uzurpaserăm": "uzurpa",
    "uzurpaserăți": "uzurpa",
    "uzurpaseși": "uzurpa",
    "uzurpași": "uzurpa",
    "uzurpat": "uzurpa",
    "uzurpați": "uzurpa",
    "uzurpau": "uzurpa",
    "uzurpează": "uzurpa",
    "uzurpez": "uzurpa",
    "uzurpeze": "uzurpa",
    "uzurpezi": "uzurpa",
    "uzurparea": "uzurpare",
    "uzurpareo": "uzurpare",
    "uzurpări": "uzurpare",
    "uzurpării": "uzurpare",
    "uzurpările": "uzurpare",
    "uzurpărilor": "uzurpare",
    "uzurpata": "uzurpat",
    "uzurpată": "uzurpat",
    "uzurpate": "uzurpat",
    "uzurpatei": "uzurpat",
    "uzurpatele": "uzurpat",
    "uzurpatelor": "uzurpat",
    "uzurpați": "uzurpat",
    "uzurpații": "uzurpat",
    "uzurpaților": "uzurpat",
    "uzurpato": "uzurpat",
    "uzurpatul": "uzurpat",
    "uzurpatule": "uzurpat",
    "uzurpatului": "uzurpat",
    "uzurpatori": "uzurpator",
    "uzurpatorii": "uzurpator",
    "uzurpatorilor": "uzurpator",
    "uzurpatorul": "uzurpator",
    "uzurpatorului": "uzurpator",
    "vaca": "vacă",
    "vaci": "vacă",
    "vacii": "vacă",
    "vacile": "vacă",
    "vacilor": "vacă",
    "vacanta": "vacant",
    "vacantă": "vacant",
    "vacante": "vacant",
    "vacantei": "vacant",
    "vacantele": "vacant",
    "vacantelor": "vacant",
    "vacanți": "vacant",
    "vacanții": "vacant",
    "vacanților": "vacant",
    "vacantul": "vacant",
    "vacantului": "vacant",
    "vacanța": "vacanță",
    "vacanțe": "vacanță",
    "vacanței": "vacanță",
    "vacanțele": "vacanță",
    "vacanțelor": "vacanță",
    "văcari": "văcar",
    "văcarii": "văcar",
    "văcarilor": "văcar",
    "văcarul": "văcar",
    "văcarului": "văcar",
    "vacarmul": "vacarm",
    "vacarmului": "vacarm",
    "vacarmuri": "vacarm",
    "vacarmurile": "vacarm",
    "vacarmurilor": "vacarm",
    "văcăroizează": "văcăroiza",
    "vaccinul": "vaccin",
    "vaccinului": "vaccin",
    "vaccinuri": "vaccin",
    "vaccinurile": "vaccin",
    "vaccinurilor": "vaccin",
    "vaccinoterapia": "vaccinoterapie",
    "vaccinoterapiei": "vaccinoterapie",
    "vaccinoterapii": "vaccinoterapie",
    "vaccinoterapiile": "vaccinoterapie",
    "vaccinoterapiilor": "vaccinoterapie",
    "vacuola": "vacuolă",
    "vacuole": "vacuolă",
    "vacuolei": "vacuolă",
    "vacuolele": "vacuolă",
    "vacuolelor": "vacuolă",
    "vac.": "vacuum",
    "vacuumul": "vacuum",
    "vacuumului": "vacuum",
    "vacuumuri": "vacuum",
    "vacuumurile": "vacuum",
    "vacuumurilor": "vacuum",
    "vacuummetrele": "vacuummetru",
    "vacuummetrelor": "vacuummetru",
    "vacuummetrue": "vacuummetru",
    "vacuummetrul": "vacuummetru",
    "vacuummetrului": "vacuummetru",
    "vadul": "vad",
    "vadului": "vad",
    "vaduri": "vad",
    "vadurile": "vad",
    "vadurilor": "vad",
    "nemaivădind": "vădi",
    "nemaivădindu": "vădi",
    "nevădind": "vădi",
    "nevădindu": "vădi",
    "vădea": "vădi",
    "vădeai": "vădi",
    "vădeam": "vădi",
    "vădească": "vădi",
    "vădeați": "vădi",
    "vădeau": "vădi",
    "vădesc": "vădi",
    "vădește": "vădi",
    "vădești": "vădi",
    "vădii": "vădi",
    "vădim": "vădi",
    "vădind": "vădi",
    "vădindu": "vădi",
    "vădiră": "vădi",
    "vădirăm": "vădi",
    "vădirăți": "vădi",
    "vădise": "vădi",
    "vădisem": "vădi",
    "vădiseră": "vădi",
    "vădiserăm": "vădi",
    "vădiserăți": "vădi",
    "vădiseși": "vădi",
    "vădiși": "vădi",
    "vădit": "vădi",
    "vădiți": "vădi",
    "vădită": "vădit",
    "vădite": "vădit",
    "vădiți": "vădit",
    "văduva": "văduv",
    "văduvă": "văduv",
    "văduve": "văduv",
    "văduvei": "văduv",
    "văduvele": "văduv",
    "văduvelor": "văduv",
    "văduvi": "văduv",
    "văduvii": "văduv",
    "văduvilor": "văduv",
    "văduvul": "văduv",
    "văduvului": "văduv",
    "nemaivăduvind": "văduvi",
    "nemaivăduvindu": "văduvi",
    "nevăduvind": "văduvi",
    "nevăduvindu": "văduvi",
    "văduvea": "văduvi",
    "văduveai": "văduvi",
    "văduveam": "văduvi",
    "văduvească": "văduvi",
    "văduveați": "văduvi",
    "văduveau": "văduvi",
    "văduvesc": "văduvi",
    "văduvește": "văduvi",
    "văduvești": "văduvi",
    "văduvii": "văduvi",
    "văduvim": "văduvi",
    "văduvind": "văduvi",
    "văduvindu": "văduvi",
    "văduviră": "văduvi",
    "văduvirăm": "văduvi",
    "văduvirăți": "văduvi",
    "văduvise": "văduvi",
    "văduvisem": "văduvi",
    "văduviseră": "văduvi",
    "văduviserăm": "văduvi",
    "văduviserăți": "văduvi",
    "văduviseși": "văduvi",
    "văduviși": "văduvi",
    "văduvit": "văduvi",
    "văduviți": "văduvi",
    "văduvita": "văduvit",
    "văduvită": "văduvit",
    "văduvite": "văduvit",
    "văduvitei": "văduvit",
    "văduvitele": "văduvit",
    "văduvitelor": "văduvit",
    "văduviți": "văduvit",
    "văduviții": "văduvit",
    "văduviților": "văduvit",
    "văduvito": "văduvit",
    "văduvitul": "văduvit",
    "văduvitule": "văduvit",
    "văduvitului": "văduvit",
    "vaga": "vag",
    "vagă": "vag",
    "vage": "vag",
    "vagei": "vag",
    "vagele": "vag",
    "vagelor": "vag",
    "vagi": "vag",
    "vagii": "vag",
    "vagilor": "vag",
    "vagul": "vag",
    "vagului": "vag",
    "vagabondul": "vagabond",
    "vagabondului": "vagabond",
    "vagabonzi": "vagabond",
    "vagabonzii": "vagabond",
    "vagabonzilor": "vagabond",
    "văgăuna": "văgăună",
    "văgăunei": "văgăună",
    "văgăuni": "văgăună",
    "văgăunile": "văgăună",
    "văgăunilor": "văgăună",
    "vaginul": "vagin",
    "vaginului": "vagin",
    "vaginuri": "vagin",
    "vaginurile": "vagin",
    "vaginurilor": "vagin",
    "vagoane": "vagon",
    "vagoanele": "vagon",
    "vagoanelor": "vagon",
    "vagonul": "vagon",
    "vagonului": "vagon",
    "vagoane-atelier": "vagon-atelier",
    "vagoanele-atelier": "vagon-atelier",
    "vagoanelor-atelier": "vagon-atelier",
    "vagonul-atelier": "vagon-atelier",
    "vagonului-atelier": "vagon-atelier",
    "vagoane-cisternă": "vagon-cisternă",
    "vagoanele-cisternă": "vagon-cisternă",
    "vagoanelor-cisternă": "vagon-cisternă",
    "vagonul-cisternă": "vagon-cisternă",
    "vagonului-cisternă": "vagon-cisternă",
    "vagonete": "vagonet",
    "vagonetele": "vagonet",
    "vagonetelor": "vagonet",
    "vagonetul": "vagonet",
    "vagonetului": "vagonet",
    "vagonetari": "vagonetar",
    "vagonetarii": "vagonetar",
    "vagonetarilor": "vagonetar",
    "vagonetarul": "vagonetar",
    "vagonetarului": "vagonetar",
    "vagoanele-restaurant": "vagon-restaurant",
    "vagoanelor-restaurant": "vagon-restaurant",
    "vagoane-restaurant": "vagon-restaurant",
    "vagonul-restaurant": "vagon-restaurant",
    "vagonului-restaurant": "vagon-restaurant",
    "văicăreala": "văicăreală",
    "văicărealo": "văicăreală",
    "văicăreli": "văicăreală",
    "văicărelii": "văicăreală",
    "văicărelile": "văicăreală",
    "văicărelilor": "văicăreală",
    "nemaivăicărind": "văicări",
    "nemaivăicărindu": "văicări",
    "nevăicărind": "văicări",
    "nevăicărindu": "văicări",
    "văicărea": "văicări",
    "văicăreai": "văicări",
    "văicăream": "văicări",
    "văicărească": "văicări",
    "văicăreați": "văicări",
    "văicăreau": "văicări",
    "văicăresc": "văicări",
    "văicărește": "văicări",
    "văicărești": "văicări",
    "văicării": "văicări",
    "văicărim": "văicări",
    "văicărind": "văicări",
    "văicărindu": "văicări",
    "văicăriră": "văicări",
    "văicărirăm": "văicări",
    "văicărirăți": "văicări",
    "văicărise": "văicări",
    "văicărisem": "văicări",
    "văicăriseră": "văicări",
    "văicăriserăm": "văicări",
    "văicăriserăți": "văicări",
    "văicăriseși": "văicări",
    "văicăriși": "văicări",
    "văicărit": "văicări",
    "văicăriți": "văicări",
    "văicărită": "văicărit",
    "văicărite": "văicărit",
    "văicăriți": "văicărit",
    "vaiete": "vaiet",
    "vaietele": "vaiet",
    "vaietelor": "vaiet",
    "vaietul": "vaiet",
    "vaietului": "vaiet",
    "nemaivăitând": "văita",
    "nemaivăitându": "văita",
    "nevăitând": "văita",
    "nevăitându": "văita",
    "vait": "văita",
    "vaită": "văita",
    "văită": "văita",
    "văitai": "văita",
    "văitam": "văita",
    "văităm": "văita",
    "văitând": "văita",
    "văitându": "văita",
    "văitară": "văita",
    "văitarăm": "văita",
    "văitarăți": "văita",
    "văitase": "văita",
    "văitasem": "văita",
    "văitaseră": "văita",
    "văitaserăm": "văita",
    "văitaserăți": "văita",
    "văitaseși": "văita",
    "văitași": "văita",
    "văitat": "văita",
    "văitați": "văita",
    "văitau": "văita",
    "văitarea": "văitare",
    "văitareo": "văitare",
    "văitări": "văitare",
    "văitării": "văitare",
    "văitările": "văitare",
    "văitărilor": "văitare",
    "văităreața": "văităreț",
    "văităreață": "văităreț",
    "văitărețe": "văităreț",
    "văităreței": "văităreț",
    "văitărețele": "văităreț",
    "văitărețelor": "văităreț",
    "văităreți": "văităreț",
    "văităreții": "văităreț",
    "văităreților": "văităreț",
    "văitărețul": "văităreț",
    "văitărețului": "văităreț",
    "văitată": "văitat",
    "văitate": "văitat",
    "văitați": "văitat",
    "văitătoare": "văitător",
    "văitătoarea": "văitător",
    "văitătoarei": "văitător",
    "văitătoarele": "văitător",
    "văitătoarelor": "văitător",
    "văitătoareo": "văitător",
    "văitători": "văitător",
    "văitătorii": "văitător",
    "văitătorilor": "văitător",
    "văitătorul": "văitător",
    "văitătorule": "văitător",
    "văitătorului": "văitător",
    "nemaivâjâind": "vâjâi",
    "nemaivâjâindu": "vâjâi",
    "nevâjâind": "vâjâi",
    "nevâjâindu": "vâjâi",
    "vâjâia": "vâjâi",
    "vâjâiai": "vâjâi",
    "vâjâiam": "vâjâi",
    "vâjâiați": "vâjâi",
    "vâjâiau": "vâjâi",
    "vâjâie": "vâjâi",
    "vâjâii": "vâjâi",
    "vâjâim": "vâjâi",
    "vâjâind": "vâjâi",
    "vâjâindu": "vâjâi",
    "vâjâiră": "vâjâi",
    "vâjâirăm": "vâjâi",
    "vâjâirăți": "vâjâi",
    "vâjâise": "vâjâi",
    "vâjâisem": "vâjâi",
    "vâjâiseră": "vâjâi",
    "vâjâiserăm": "vâjâi",
    "vâjâiserăți": "vâjâi",
    "vâjâiseși": "vâjâi",
    "vâjâiși": "vâjâi",
    "vâjâit": "vâjâi",
    "vâjâiți": "vâjâi",
    "vâjâirea": "vâjâire",
    "vâjâiri": "vâjâire",
    "vâjâirii": "vâjâire",
    "vâjâirile": "vâjâire",
    "vâjâirilor": "vâjâire",
    "vâjâită": "vâjâit",
    "vâjâite": "vâjâit",
    "vâjâiți": "vâjâit",
    "vâjâitul": "vâjâit",
    "vâjâitului": "vâjâit",
    "vâjâituri": "vâjâit",
    "vâjâiturile": "vâjâit",
    "vâjâiturilor": "vâjâit",
    "vâjâitura": "vâjâitură",
    "vâjâituri": "vâjâitură",
    "vâjâiturii": "vâjâitură",
    "vâjâiturile": "vâjâitură",
    "vâjâiturilor": "vâjâitură",
    "vâjâituro": "vâjâitură",
    "vajnica": "vajnic",
    "vajnică": "vajnic",
    "vajnice": "vajnic",
    "vajnicei": "vajnic",
    "vajnicele": "vajnic",
    "vajnicelor": "vajnic",
    "vajnici": "vajnic",
    "vajnicii": "vajnic",
    "vajnicilor": "vajnic",
    "vajnicul": "vajnic",
    "vajnicului": "vajnic",
    "valul": "val",
    "valului": "val",
    "valuri": "val",
    "valurile": "val",
    "valurilor": "val",
    "vălul": "văl",
    "vălului": "văl",
    "văluri": "văl",
    "vălurile": "văl",
    "vălurilor": "văl",
    "valabila": "valabil",
    "valabilă": "valabil",
    "valabile": "valabil",
    "valabilei": "valabil",
    "valabilele": "valabil",
    "valabilelor": "valabil",
    "valabili": "valabil",
    "valabilii": "valabil",
    "valabililor": "valabil",
    "valabilul": "valabil",
    "valabilului": "valabil",
    "valabilitatea": "valabilitate",
    "valabilități": "valabilitate",
    "valabilității": "valabilitate",
    "valabilitățile": "valabilitate",
    "valabilităților": "valabilitate",
    "valaha": "valah",
    "valahă": "valah",
    "valahe": "valah",
    "valahei": "valah",
    "valahele": "valah",
    "valahelor": "valah",
    "valahi": "valah",
    "valahii": "valah",
    "valahilor": "valah",
    "valahul": "valah",
    "valahului": "valah",
    "valaha": "valahă",
    "valahe": "valahă",
    "valahei": "valahă",
    "valahele": "valahă",
    "valahelor": "valahă",
    "vălătuci": "vălătuc",
    "vălătucii": "vălătuc",
    "vălătucilor": "vălătuc",
    "vălătucul": "vălătuc",
    "vălătucului": "vălătuc",
    "vâlceaua": "vâlcea",
    "vâlcele": "vâlcea",
    "vâlcelei": "vâlcea",
    "vâlcelele": "vâlcea",
    "vâlcelelor": "vâlcea",
    "văi": "vale",
    "văii": "vale",
    "văile": "vale",
    "văilor": "vale",
    "valea": "vale",
    "valența": "valență",
    "valențe": "valență",
    "valenței": "valență",
    "valențele": "valență",
    "valențelor": "valență",
    "valeți": "valet",
    "valeții": "valet",
    "valeților": "valet",
    "valetul": "valet",
    "valetului": "valet",
    "validul": "valid",
    "validului": "valid",
    "valize": "valid",
    "valizei": "valid",
    "valizele": "valid",
    "valizelor": "valid",
    "valizi": "valid",
    "valizii": "valid",
    "valizilor": "valid",
    "nemaivalidând": "valida",
    "nemaivalidându": "valida",
    "nevalidând": "valida",
    "nevalidându": "valida",
    "validă": "valida",
    "validai": "valida",
    "validam": "valida",
    "validăm": "valida",
    "validând": "valida",
    "validându": "valida",
    "validară": "valida",
    "validarăm": "valida",
    "validarăți": "valida",
    "validase": "valida",
    "validasem": "valida",
    "validaseră": "valida",
    "validaserăm": "valida",
    "validaserăți": "valida",
    "validaseși": "valida",
    "validași": "valida",
    "validat": "valida",
    "validați": "valida",
    "validau": "valida",
    "validează": "valida",
    "validez": "valida",
    "valideze": "valida",
    "validezi": "valida",
    "validarea": "validare",
    "validareo": "validare",
    "validări": "validare",
    "validării": "validare",
    "validările": "validare",
    "validărilor": "validare",
    "validata": "validat",
    "validată": "validat",
    "validate": "validat",
    "validatei": "validat",
    "validatele": "validat",
    "validatelor": "validat",
    "validați": "validat",
    "validații": "validat",
    "validaților": "validat",
    "validato": "validat",
    "validatul": "validat",
    "validatule": "validat",
    "validatului": "validat",
    "valiza": "valiză",
    "valize": "valiză",
    "valizei": "valiză",
    "valizele": "valiză",
    "valizelor": "valiză",
    "valma": "valmă",
    "valmei": "valmă",
    "vălmi": "valmă",
    "vălmile": "valmă",
    "vălmilor": "valmă",
    "valoarea": "valoare",
    "valori": "valoare",
    "valorii": "valoare",
    "valorile": "valoare",
    "valorilor": "valoare",
    "nemaivalorând": "valora",
    "nemaivalorându": "valora",
    "nevalorând": "valora",
    "nevalorându": "valora",
    "valoră": "valora",
    "valorai": "valora",
    "valoram": "valora",
    "valorăm": "valora",
    "valorând": "valora",
    "valorându": "valora",
    "valorară": "valora",
    "valorarăm": "valora",
    "valorarăți": "valora",
    "valorase": "valora",
    "valorasem": "valora",
    "valoraseră": "valora",
    "valoraserăm": "valora",
    "valoraserăți": "valora",
    "valoraseși": "valora",
    "valorași": "valora",
    "valorat": "valora",
    "valorați": "valora",
    "valorau": "valora",
    "valorează": "valora",
    "valorez": "valora",
    "valoreze": "valora",
    "valorezi": "valora",
    "valorată": "valorat",
    "valorate": "valorat",
    "valorați": "valorat",
    "valorica": "valoric",
    "valorică": "valoric",
    "valorice": "valoric",
    "valoricei": "valoric",
    "valoricele": "valoric",
    "valoricelor": "valoric",
    "valorici": "valoric",
    "valoricii": "valoric",
    "valoricilor": "valoric",
    "valoricul": "valoric",
    "valoricului": "valoric",
    "valorific": "valorifica",
    "valorifică": "valorifica",
    "valorificai": "valorifica",
    "valorificam": "valorifica",
    "valorificăm": "valorifica",
    "valorificând": "valorifica",
    "valorificându": "valorifica",
    "valorificară": "valorifica",
    "valorificarăm": "valorifica",
    "valorificarăți": "valorifica",
    "valorificase": "valorifica",
    "valorificasem": "valorifica",
    "valorificaseră": "valorifica",
    "valorificaserăm": "valorifica",
    "valorificaserăți": "valorifica",
    "valorificaseși": "valorifica",
    "valorificași": "valorifica",
    "valorificat": "valorifica",
    "valorificați": "valorifica",
    "valorificatu": "valorifica",
    "valorificau": "valorifica",
    "valorifice": "valorifica",
    "valorifici": "valorifica",
    "valorificarea": "valorificare",
    "valorificări": "valorificare",
    "valorificării": "valorificare",
    "valorificările": "valorificare",
    "valorificărilor": "valorificare",
    "valorificata": "valorificat",
    "valorificată": "valorificat",
    "valorificate": "valorificat",
    "valorificatei": "valorificat",
    "valorificatele": "valorificat",
    "valorificatelor": "valorificat",
    "valorificați": "valorificat",
    "valorificații": "valorificat",
    "valorificaților": "valorificat",
    "valorificatul": "valorificat",
    "valorificatului": "valorificat",
    "valoroasa": "valoros",
    "valoroasă": "valoros",
    "valoroase": "valoros",
    "valoroasei": "valoros",
    "valoroasele": "valoros",
    "valoroaselor": "valoros",
    "valoroși": "valoros",
    "valoroșii": "valoros",
    "valoroșilor": "valoros",
    "valorosul": "valoros",
    "valorosului": "valoros",
    "valsul": "vals",
    "valsului": "vals",
    "valsuri": "vals",
    "valsurile": "vals",
    "valsurilor": "vals",
    "nemaivalsând": "valsa",
    "nemaivalsându": "valsa",
    "nevalsând": "valsa",
    "nevalsându": "valsa",
    "valsă": "valsa",
    "valsai": "valsa",
    "valsam": "valsa",
    "valsăm": "valsa",
    "valsând": "valsa",
    "valsându": "valsa",
    "valsară": "valsa",
    "valsarăm": "valsa",
    "valsarăți": "valsa",
    "valsase": "valsa",
    "valsasem": "valsa",
    "valsaseră": "valsa",
    "valsaserăm": "valsa",
    "valsaserăți": "valsa",
    "valsaseși": "valsa",
    "valsași": "valsa",
    "valsat": "valsa",
    "valsați": "valsa",
    "valsau": "valsa",
    "valsează": "valsa",
    "valsez": "valsa",
    "valseze": "valsa",
    "valsezi": "valsa",
    "valsată": "valsat",
    "valsate": "valsat",
    "valsați": "valsat",
    "valsatoare": "valsator",
    "valsatoarea": "valsator",
    "valsatoarei": "valsator",
    "valsatoarele": "valsator",
    "valsatoarelor": "valsator",
    "valsatoareo": "valsator",
    "valsatori": "valsator",
    "valsatorii": "valsator",
    "valsatorilor": "valsator",
    "valsatorul": "valsator",
    "valsatorule": "valsator",
    "valsatorului": "valsator",
    "valțul": "valț",
    "valțului": "valț",
    "valțuri": "valț",
    "valțurile": "valț",
    "valțurilor": "valț",
    "vâltoarea": "vâltoare",
    "vâltori": "vâltoare",
    "vâltorii": "vâltoare",
    "vâltorile": "vâltoare",
    "vâltorilor": "vâltoare",
    "văluroasa": "văluros",
    "văluroasă": "văluros",
    "văluroase": "văluros",
    "văluroasei": "văluros",
    "văluroasele": "văluros",
    "văluroaselor": "văluros",
    "văluroși": "văluros",
    "văluroșii": "văluros",
    "văluroșilor": "văluros",
    "vălurosul": "văluros",
    "vălurosului": "văluros",
    "valuta": "valută",
    "valute": "valută",
    "valutei": "valută",
    "valutele": "valută",
    "valutelor": "valută",
    "valutara": "valutar",
    "valutară": "valutar",
    "valutare": "valutar",
    "valutarei": "valutar",
    "valutarele": "valutar",
    "valutarelor": "valutar",
    "valutari": "valutar",
    "valutarii": "valutar",
    "valutarilor": "valutar",
    "valutarul": "valutar",
    "valutarului": "valutar",
    "valva": "valvă",
    "valve": "valvă",
    "valvei": "valvă",
    "valvele": "valvă",
    "valvelor": "valvă",
    "vâlva": "vâlvă",
    "vâlve": "vâlvă",
    "vâlvei": "vâlvă",
    "vâlvele": "vâlvă",
    "vâlvelor": "vâlvă",
    "vâlvătaei": "vâlvătaie",
    "vâlvătăi": "vâlvătaie",
    "vâlvătaia": "vâlvătaie",
    "vâlvătăile": "vâlvătaie",
    "vâlvătăilor": "vâlvătaie",
    "valvolina": "valvolină",
    "valvoline": "valvolină",
    "valvolinei": "valvolină",
    "valvolinele": "valvolină",
    "valvolinelor": "valvolină",
    "valvula": "valvulă",
    "valvule": "valvulă",
    "valvulei": "valvulă",
    "valvulele": "valvulă",
    "valvulelor": "valvulă",
    "vama": "vamă",
    "vămi": "vamă",
    "vămii": "vamă",
    "vămile": "vamă",
    "vămilor": "vamă",
    "vamala": "vamal",
    "vamală": "vamal",
    "vamale": "vamal",
    "vamalei": "vamal",
    "vamalele": "vamal",
    "vamalelor": "vamal",
    "vamali": "vamal",
    "vamalii": "vamal",
    "vamalilor": "vamal",
    "vamalul": "vamal",
    "vamalului": "vamal",
    "vameși": "vameș",
    "vameșii": "vameș",
    "vameșilor": "vameș",
    "vameșul": "vameș",
    "vameșului": "vameș",
    "vămeșeasca": "vămeșesc",
    "vămeșească": "vămeșesc",
    "vămeșescul": "vămeșesc",
    "vămeșescului": "vămeșesc",
    "vămeșești": "vămeșesc",
    "vămeșeștii": "vămeșesc",
    "vămeșeștile": "vămeșesc",
    "vămeșeștilor": "vămeșesc",
    "vămeșia": "vămeșie",
    "vămeșiei": "vămeșie",
    "vămeșii": "vămeșie",
    "vămeșiile": "vămeșie",
    "vămeșiilor": "vămeșie",
    "vampiri": "vampir",
    "vampirii": "vampir",
    "vampirilor": "vampir",
    "vampirul": "vampir",
    "vampirului": "vampir",
    "nemaivămuind": "vămui",
    "nemaivămuindu": "vămui",
    "nevămuind": "vămui",
    "nevămuindu": "vămui",
    "vămuia": "vămui",
    "vămuiai": "vămui",
    "vămuiam": "vămui",
    "vămuiască": "vămui",
    "vămuiați": "vămui",
    "vămuiau": "vămui",
    "vămuiesc": "vămui",
    "vămuiește": "vămui",
    "vămuiești": "vămui",
    "vămuii": "vămui",
    "vămuim": "vămui",
    "vămuind": "vămui",
    "vămuindu": "vămui",
    "vămuiră": "vămui",
    "vămuirăm": "vămui",
    "vămuirăți": "vămui",
    "vămuise": "vămui",
    "vămuisem": "vămui",
    "vămuiseră": "vămui",
    "vămuiserăm": "vămui",
    "vămuiserăți": "vămui",
    "vămuiseși": "vămui",
    "vămuiși": "vămui",
    "vămuit": "vămui",
    "vămuiți": "vămui",
    "vămuirea": "vămuire",
    "vămuireo": "vămuire",
    "vămuiri": "vămuire",
    "vămuirii": "vămuire",
    "vămuirile": "vămuire",
    "vămuirilor": "vămuire",
    "vămuită": "vămuit",
    "vămuite": "vămuit",
    "vămuiți": "vămuit",
    "vana": "van",
    "vană": "van",
    "vane": "van",
    "vanei": "van",
    "vanele": "van",
    "vanelor": "van",
    "vani": "van",
    "vanii": "van",
    "vanilor": "van",
    "vanul": "van",
    "vanului": "van",
    "vana": "vană",
    "vane": "vană",
    "vanei": "vană",
    "vanele": "vană",
    "vanelor": "vană",
    "nemaivânând": "vâna",
    "nemaivânându": "vâna",
    "nevânând": "vâna",
    "nevânându": "vâna",
    "vână": "vâna",
    "vânai": "vâna",
    "vânam": "vâna",
    "vânăm": "vâna",
    "vânând": "vâna",
    "vânându": "vâna",
    "vânară": "vâna",
    "vânarăm": "vâna",
    "vânarăți": "vâna",
    "vânase": "vâna",
    "vânasem": "vâna",
    "vânaseră": "vâna",
    "vânaserăm": "vâna",
    "vânaserăți": "vâna",
    "vânaseși": "vâna",
    "vânași": "vâna",
    "vânat": "vâna",
    "vânați": "vâna",
    "vânau": "vâna",
    "vânează": "vâna",
    "vânez": "vâna",
    "vâneze": "vâna",
    "vânezi": "vâna",
    "vâna": "vână",
    "vine": "vână",
    "vinei": "vână",
    "vinele": "vână",
    "vinelor": "vână",
    "vanadiul": "vanadiu",
    "vanadiului": "vanadiu",
    "vânarea": "vânare",
    "vânareo": "vânare",
    "vânări": "vânare",
    "vânării": "vânare",
    "vânările": "vânare",
    "vânărilor": "vânare",
    "vânată": "vânat",
    "vânate": "vânat",
    "vânați": "vânat",
    "vânatul": "vânat",
    "vânatului": "vânat",
    "vânaturi": "vânat",
    "vânaturile": "vânat",
    "vânaturilor": "vânat",
    "vânăta": "vânăt",
    "vânătă": "vânăt",
    "vânătul": "vânăt",
    "vânătului": "vânăt",
    "vinete": "vânăt",
    "vinetei": "vânăt",
    "vinetele": "vânăt",
    "vinetelor": "vânăt",
    "vineți": "vânăt",
    "vineților": "vânăt",
    "vânăta": "vânătă",
    "vinete": "vânătă",
    "vinetei": "vânătă",
    "vinetele": "vânătă",
    "vinetelor": "vânătă",
    "vânătăi": "vânătaie",
    "vânătaia": "vânătaie",
    "vânătăii": "vânătaie",
    "vânătăile": "vânătaie",
    "vânătăilor": "vânătaie",
    "vân.": "vânătoare",
    "vânătoarea": "vânătoare",
    "vânători": "vânătoare",
    "vânătorii": "vânătoare",
    "vânătorile": "vânătoare",
    "vânătorilor": "vânătoare",
    "vânători": "vânător",
    "vânătorii": "vânător",
    "vânătorilor": "vânător",
    "vânătorul": "vânător",
    "vânătorului": "vânător",
    "vânătoreasca": "vânătoresc",
    "vânătorească": "vânătoresc",
    "vânătorescul": "vânătoresc",
    "vânătorescului": "vânătoresc",
    "vânătorești": "vânătoresc",
    "vânătoreștii": "vânătoresc",
    "vânătoreștile": "vânătoresc",
    "vânătoreștilor": "vânătoresc",
    "vandabila": "vandabil",
    "vandabilă": "vandabil",
    "vandabile": "vandabil",
    "vandabilei": "vandabil",
    "vandabilele": "vandabil",
    "vandabilelor": "vandabil",
    "vandabili": "vandabil",
    "vandabilii": "vandabil",
    "vandabililor": "vandabil",
    "vandabilul": "vandabil",
    "vandabilului": "vandabil",
    "vandali": "vandal",
    "vandalii": "vandal",
    "vandalilor": "vandal",
    "vandalul": "vandal",
    "vandalului": "vandal",
    "vandalisme": "vandalism",
    "vandalismele": "vandalism",
    "vandalismelor": "vandalism",
    "vandalismul": "vandalism",
    "vandalismului": "vandalism",
    "vandrugi": "vandrug",
    "vandrugii": "vandrug",
    "vandrugilor": "vandrug",
    "vandrugul": "vandrug",
    "vandrugului": "vandrug",
    "vândută": "vândut",
    "vândute": "vândut",
    "vânduți": "vândut",
    "vanilia": "vanilie",
    "vaniliei": "vanilie",
    "vanilii": "vanilie",
    "vaniliile": "vanilie",
    "vaniliilor": "vanilie",
    "vanilina": "vanilină",
    "vaniline": "vanilină",
    "vanilinei": "vanilină",
    "vanilinele": "vanilină",
    "vanilinelor": "vanilină",
    "vanitatea": "vanitate",
    "vanități": "vanitate",
    "vanității": "vanitate",
    "vanitățile": "vanitate",
    "vanităților": "vanitate",
    "vanitoasa": "vanitos",
    "vanitoasă": "vanitos",
    "vanitoase": "vanitos",
    "vanitoasei": "vanitos",
    "vanitoasele": "vanitos",
    "vanitoaselor": "vanitos",
    "vanitoși": "vanitos",
    "vanitoșii": "vanitos",
    "vanitoșilor": "vanitos",
    "vanitosul": "vanitos",
    "vanitosului": "vanitos",
    "vânjoasa": "vânjos",
    "vânjoasă": "vânjos",
    "vânjoase": "vânjos",
    "vânjoasei": "vânjos",
    "vânjoasele": "vânjos",
    "vânjoaselor": "vânjos",
    "vânjoși": "vânjos",
    "vânjoșii": "vânjos",
    "vânjoșilor": "vânjos",
    "vânjosul": "vânjos",
    "vânjosului": "vânjos",
    "vânoasa": "vânos",
    "vânoasă": "vânos",
    "vânoase": "vânos",
    "vânoasei": "vânos",
    "vânoasele": "vânos",
    "vânoaselor": "vânos",
    "vânoși": "vânos",
    "vânoșii": "vânos",
    "vânoșilor": "vânos",
    "vânosul": "vânos",
    "vânosului": "vânos",
    "vântul": "vânt",
    "vântului": "vânt",
    "vânturi": "vânt",
    "vânturile": "vânt",
    "vânturilor": "vânt",
    "nemaivânturând": "vântura",
    "nemaivânturându": "vântura",
    "nevânturând": "vântura",
    "nevânturându": "vântura",
    "vântur": "vântura",
    "vântură": "vântura",
    "vânturai": "vântura",
    "vânturam": "vântura",
    "vânturăm": "vântura",
    "vânturând": "vântura",
    "vânturându": "vântura",
    "vânturară": "vântura",
    "vânturarăm": "vântura",
    "vânturarăți": "vântura",
    "vânturase": "vântura",
    "vânturasem": "vântura",
    "vânturaseră": "vântura",
    "vânturaserăm": "vântura",
    "vânturaserăți": "vântura",
    "vânturaseși": "vântura",
    "vânturași": "vântura",
    "vânturat": "vântura",
    "vânturați": "vântura",
    "vânturau": "vântura",
    "vânture": "vântura",
    "vânturi": "vântura",
    "vânturarea": "vânturare",
    "vânturareo": "vânturare",
    "vânturări": "vânturare",
    "vânturării": "vânturare",
    "vânturările": "vânturare",
    "vânturărilor": "vânturare",
    "vânturată": "vânturat",
    "vânturate": "vânturat",
    "vânturați": "vânturat",
    "vânturătoarea": "vânturătoare",
    "vânturători": "vânturătoare",
    "vânturătorii": "vânturătoare",
    "vânturătorile": "vânturătoare",
    "vânturătorilor": "vânturătoare",
    "vânzarea": "vânzare",
    "vânzări": "vânzare",
    "vânzării": "vânzare",
    "vânzările": "vânzare",
    "vânzărilor": "vânzare",
    "vânzători": "vânzător",
    "vânzătorii": "vânzător",
    "vânzătorilor": "vânzător",
    "vânzătorul": "vânzător",
    "vânzătorului": "vânzător",
    "vânzoleala": "vânzoleală",
    "vânzolealo": "vânzoleală",
    "vânzoleli": "vânzoleală",
    "vânzolelii": "vânzoleală",
    "vânzolelile": "vânzoleală",
    "vânzolelilor": "vânzoleală",
    "nemaivânzolind": "vânzoli",
    "nemaivânzolindu": "vânzoli",
    "nevânzolind": "vânzoli",
    "nevânzolindu": "vânzoli",
    "vânzolea": "vânzoli",
    "vânzoleai": "vânzoli",
    "vânzoleam": "vânzoli",
    "vânzolească": "vânzoli",
    "vânzoleați": "vânzoli",
    "vânzoleau": "vânzoli",
    "vânzolesc": "vânzoli",
    "vânzolește": "vânzoli",
    "vânzolești": "vânzoli",
    "vânzolii": "vânzoli",
    "vânzolim": "vânzoli",
    "vânzolind": "vânzoli",
    "vânzolindu": "vânzoli",
    "vânzoliră": "vânzoli",
    "vânzolirăm": "vânzoli",
    "vânzolirăți": "vânzoli",
    "vânzolise": "vânzoli",
    "vânzolisem": "vânzoli",
    "vânzoliseră": "vânzoli",
    "vânzoliserăm": "vânzoli",
    "vânzoliserăți": "vânzoli",
    "vânzoliseși": "vânzoli",
    "vânzoliși": "vânzoli",
    "vânzolit": "vânzoli",
    "vânzoliți": "vânzoli",
    "vânzolirea": "vânzolire",
    "vânzoliri": "vânzolire",
    "vânzolirii": "vânzolire",
    "vânzolirile": "vânzolire",
    "vânzolirilor": "vânzolire",
    "vânzolită": "vânzolit",
    "vânzolite": "vânzolit",
    "vânzoliți": "vânzolit",
    "văpaei": "văpaie",
    "văpăi": "văpaie",
    "văpaia": "văpaie",
    "văpăile": "văpaie",
    "văpăilor": "văpaie",
    "vapoare": "vapor",
    "vapoarele": "vapor",
    "vapoarelor": "vapor",
    "vaporu'": "vapor",
    "vaporul": "vapor",
    "vaporului": "vapor",
    "vaporii": "vapori",
    "vaporilor": "vapori",
    "nemaivaporizând": "vaporiza",
    "nemaivaporizându": "vaporiza",
    "nevaporizând": "vaporiza",
    "nevaporizându": "vaporiza",
    "vaporiză": "vaporiza",
    "vaporizai": "vaporiza",
    "vaporizam": "vaporiza",
    "vaporizăm": "vaporiza",
    "vaporizând": "vaporiza",
    "vaporizându": "vaporiza",
    "vaporizară": "vaporiza",
    "vaporizarăm": "vaporiza",
    "vaporizarăți": "vaporiza",
    "vaporizase": "vaporiza",
    "vaporizasem": "vaporiza",
    "vaporizaseră": "vaporiza",
    "vaporizaserăm": "vaporiza",
    "vaporizaserăți": "vaporiza",
    "vaporizaseși": "vaporiza",
    "vaporizași": "vaporiza",
    "vaporizat": "vaporiza",
    "vaporizați": "vaporiza",
    "vaporizau": "vaporiza",
    "vaporizează": "vaporiza",
    "vaporizez": "vaporiza",
    "vaporizeze": "vaporiza",
    "vaporizezi": "vaporiza",
    "vaporizarea": "vaporizare",
    "vaporizareo": "vaporizare",
    "vaporizări": "vaporizare",
    "vaporizării": "vaporizare",
    "vaporizările": "vaporizare",
    "vaporizărilor": "vaporizare",
    "vaporizată": "vaporizat",
    "vaporizate": "vaporizat",
    "vaporizați": "vaporizat",
    "vaporizatoare": "vaporizator",
    "vaporizatoarele": "vaporizator",
    "vaporizatoarelor": "vaporizator",
    "vaporizatorul": "vaporizator",
    "vaporizatorule": "vaporizator",
    "vaporizatorului": "vaporizator",
    "vaporoasa": "vaporos",
    "vaporoasă": "vaporos",
    "vaporoase": "vaporos",
    "vaporoasei": "vaporos",
    "vaporoasele": "vaporos",
    "vaporoaselor": "vaporos",
    "vaporoși": "vaporos",
    "vaporoșii": "vaporos",
    "vaporoșilor": "vaporos",
    "vaporosul": "vaporos",
    "vaporosului": "vaporos",
    "varul": "var",
    "varului": "var",
    "vărul": "văr",
    "vărului": "văr",
    "veri": "văr",
    "verii": "văr",
    "verilor": "văr",
    "vara": "vară",
    "veri": "vară",
    "verii": "vară",
    "verile": "vară",
    "verilor": "vară",
    "vârâtă": "vârât",
    "vârâte": "vârât",
    "vârâți": "vârât",
    "văratica": "văratic",
    "văratică": "văratic",
    "văratice": "văratic",
    "văraticei": "văratic",
    "văraticele": "văratic",
    "văraticelor": "văratic",
    "văratici": "văratic",
    "văraticii": "văratic",
    "văraticilor": "văratic",
    "văraticul": "văratic",
    "văraticului": "văratic",
    "vârcolaci": "vârcolac",
    "vârcolacii": "vârcolac",
    "vârcolacilor": "vârcolac",
    "vârcolacul": "vârcolac",
    "vârcolacului": "vârcolac",
    "vârful": "vârf",
    "vârfului": "vârf",
    "vârfuri": "vârf",
    "vârfurile": "vârf",
    "vârfurilor": "vârf",
    "vf.": "vârf",
    "vârfșoare": "vârfșor",
    "vârfșoarele": "vârfșor",
    "vârfșoarelor": "vârfșor",
    "vârfșorul": "vârfșor",
    "vârfșorului": "vârfșor",
    "vârfulețe": "vârfuleț",
    "vârfulețele": "vârfuleț",
    "vârfulețelor": "vârfuleț",
    "vârfulețul": "vârfuleț",
    "vârfulețului": "vârfuleț",
    "vârfușoare": "vârfușor",
    "vârfușoarele": "vârfușor",
    "vârfușoarelor": "vârfușor",
    "vârfușorul": "vârfușor",
    "vârfușorului": "vârfușor",
    "vârfuțe": "vârfuț",
    "vârfuțele": "vârfuț",
    "vârfuțelor": "vârfuț",
    "vârfuțul": "vârfuț",
    "vârfuțului": "vârfuț",
    "varga": "vargă",
    "vergi": "vargă",
    "vergii": "vargă",
    "vergile": "vargă",
    "vergilor": "vargă",
    "vărgulița": "vărguliță",
    "vărgulițe": "vărguliță",
    "vărguliței": "vărguliță",
    "vărgulițele": "vărguliță",
    "vărgulițelor": "vărguliță",
    "vărguța": "vărguță",
    "vărguțe": "vărguță",
    "vărguței": "vărguță",
    "vărguțele": "vărguță",
    "vărguțelor": "vărguță",
    "nemaivârând": "vârî",
    "nemaivârându": "vârî",
    "nevârând": "vârî",
    "nevârându": "vârî",
    "vâr": "vârî",
    "vâra": "vârî",
    "vâră": "vârî",
    "vârai": "vârî",
    "vârâi": "vârî",
    "vâram": "vârî",
    "vârâm": "vârî",
    "vârând": "vârî",
    "vârându": "vârî",
    "vârâră": "vârî",
    "vârârăm": "vârî",
    "vârârăți": "vârî",
    "vârâse": "vârî",
    "vârâsem": "vârî",
    "vârâseră": "vârî",
    "vârâserăm": "vârî",
    "vârâserăți": "vârî",
    "vârâseși": "vârî",
    "vârâși": "vârî",
    "vârât": "vârî",
    "vârați": "vârî",
    "vârâți": "vârî",
    "vârau": "vârî",
    "vâre": "vârî",
    "vâri": "vârî",
    "nemaivariând": "varia",
    "nemaivariându": "varia",
    "nevariând": "varia",
    "nevariându": "varia",
    "variă": "varia",
    "variai": "varia",
    "variam": "varia",
    "variăm": "varia",
    "variând": "varia",
    "variându": "varia",
    "variară": "varia",
    "variarăm": "varia",
    "variarăți": "varia",
    "variase": "varia",
    "variasem": "varia",
    "variaseră": "varia",
    "variaserăm": "varia",
    "variaserăți": "varia",
    "variaseși": "varia",
    "variași": "varia",
    "variat": "varia",
    "variați": "varia",
    "variau": "varia",
    "variază": "varia",
    "variez": "varia",
    "varieze": "varia",
    "variezi": "varia",
    "variabila": "variabil",
    "variabilă": "variabil",
    "variabile": "variabil",
    "variabilei": "variabil",
    "variabilele": "variabil",
    "variabilelor": "variabil",
    "variabili": "variabil",
    "variabilii": "variabil",
    "variabililor": "variabil",
    "variabilo": "variabil",
    "variabilul": "variabil",
    "variabilule": "variabil",
    "variabilului": "variabil",
    "variabila": "variabilă",
    "variabile": "variabilă",
    "variabilei": "variabilă",
    "variabilele": "variabilă",
    "variabilelor": "variabilă",
    "v.l.": "variae_lectiones",
    "var.lect.": "variae_lectiones",
    "var.": "variantă",
    "varianta": "variantă",
    "variante": "variantă",
    "variantei": "variantă",
    "variantele": "variantă",
    "variantelor": "variantă",
    "variata": "variat",
    "variată": "variat",
    "variate": "variat",
    "variatei": "variat",
    "variatele": "variat",
    "variatelor": "variat",
    "variați": "variat",
    "variații": "variat",
    "variaților": "variat",
    "variato": "variat",
    "variatul": "variat",
    "variatule": "variat",
    "variatului": "variat",
    "variația": "variație",
    "variației": "variație",
    "variații": "variație",
    "variațiile": "variație",
    "variațiilor": "variație",
    "variațio": "variație",
    "varicele": "varice",
    "varicelor": "varice",
    "varicela": "varicelă",
    "varicoasa": "varicos",
    "varicoasă": "varicos",
    "varicoase": "varicos",
    "varicoasei": "varicos",
    "varicoasele": "varicos",
    "varicoaselor": "varicos",
    "varicoși": "varicos",
    "varicoșii": "varicos",
    "varicoșilor": "varicos",
    "varicosul": "varicos",
    "varicosului": "varicos",
    "varietatea": "varietate",
    "varietăți": "varietate",
    "varietății": "varietate",
    "varietățile": "varietate",
    "varietăților": "varietate",
    "variola": "variolă",
    "variometre": "variometru",
    "variometrele": "variometru",
    "variometrelor": "variometru",
    "variometrul": "variometru",
    "variometrului": "variometru",
    "nemaivărsând": "vărsa",
    "nemaivărsându": "vărsa",
    "nevărsând": "vărsa",
    "nevărsându": "vărsa",
    "vărs": "vărsa",
    "varsă": "vărsa",
    "vărsă": "vărsa",
    "vărsai": "vărsa",
    "vărsam": "vărsa",
    "vărsăm": "vărsa",
    "vărsând": "vărsa",
    "vărsându": "vărsa",
    "vărsară": "vărsa",
    "vărsarăm": "vărsa",
    "vărsarăți": "vărsa",
    "vărsase": "vărsa",
    "vărsasem": "vărsa",
    "vărsaseră": "vărsa",
    "vărsaserăm": "vărsa",
    "vărsaserăți": "vărsa",
    "vărsaseși": "vărsa",
    "vărsași": "vărsa",
    "vărsat": "vărsa",
    "vărsați": "vărsa",
    "vărsau": "vărsa",
    "verse": "vărsa",
    "verși": "vărsa",
    "vărsământul": "vărsământ",
    "vărsământului": "vărsământ",
    "vărsăminte": "vărsământ",
    "vărsămintele": "vărsământ",
    "vărsămintelor": "vărsământ",
    "vărsarea": "vărsare",
    "vărsareo": "vărsare",
    "vărsări": "vărsare",
    "vărsării": "vărsare",
    "vărsările": "vărsare",
    "vărsărilor": "vărsare",
    "vărsata": "vărsat",
    "vărsată": "vărsat",
    "vărsate": "vărsat",
    "vărsatei": "vărsat",
    "vărsatele": "vărsat",
    "vărsatelor": "vărsat",
    "vărsați": "vărsat",
    "vărsații": "vărsat",
    "vărsaților": "vărsat",
    "vărsato": "vărsat",
    "vărsatul": "vărsat",
    "vărsatule": "vărsat",
    "vărsatului": "vărsat",
    "vărsătoare": "vărsător",
    "vărsătoarea": "vărsător",
    "vărsătoarei": "vărsător",
    "vărsătoarele": "vărsător",
    "vărsătoarelor": "vărsător",
    "vărsători": "vărsător",
    "vărsătorii": "vărsător",
    "vărsătorilor": "vărsător",
    "vărsătorul": "vărsător",
    "vărsătorului": "vărsător",
    "Varșovie": "Varșovia",
    "Varșoviei": "Varșovia",
    "vârsta": "vârstă",
    "vârste": "vârstă",
    "vârstei": "vârstă",
    "vârstele": "vârstă",
    "vârstelor": "vârstă",
    "vârstnica": "vârstnic",
    "vârstnică": "vârstnic",
    "vârstnice": "vârstnic",
    "vârstnicei": "vârstnic",
    "vârstnicele": "vârstnic",
    "vârstnicelor": "vârstnic",
    "vârstnici": "vârstnic",
    "vârstnicii": "vârstnic",
    "vârstnicilor": "vârstnic",
    "vârstnicul": "vârstnic",
    "vârstnicului": "vârstnic",
    "vârtejul": "vârtej",
    "vârtejului": "vârtej",
    "vârtejuri": "vârtej",
    "vârtejurile": "vârtej",
    "vârtejurilor": "vârtej",
    "vârtelnița": "vârtelniță",
    "vârtelnițe": "vârtelniță",
    "vârtelniței": "vârtelniță",
    "vârtelnițele": "vârtelniță",
    "vârtelnițelor": "vârtelniță",
    "vârtoasa": "vârtos",
    "vârtoasă": "vârtos",
    "vârtoase": "vârtos",
    "vârtoasei": "vârtos",
    "vârtoasele": "vârtos",
    "vârtoaselor": "vârtos",
    "vârtoși": "vârtos",
    "vârtoșii": "vârtos",
    "vârtoșilor": "vârtos",
    "vârtosul": "vârtos",
    "vârtosului": "vârtos",
    "nemaivăruind": "vărui",
    "nemaivăruindu": "vărui",
    "nevăruind": "vărui",
    "nevăruindu": "vărui",
    "văruia": "vărui",
    "văruiai": "vărui",
    "văruiam": "vărui",
    "văruiască": "vărui",
    "văruiați": "vărui",
    "văruiau": "vărui",
    "văruiesc": "vărui",
    "văruiește": "vărui",
    "văruiești": "vărui",
    "văruii": "vărui",
    "văruim": "vărui",
    "văruind": "vărui",
    "văruindu": "vărui",
    "văruiră": "vărui",
    "văruirăm": "vărui",
    "văruirăți": "vărui",
    "văruise": "vărui",
    "văruisem": "vărui",
    "văruiseră": "vărui",
    "văruiserăm": "vărui",
    "văruiserăți": "vărui",
    "văruiseși": "vărui",
    "văruiși": "vărui",
    "văruit": "vărui",
    "văruiți": "vărui",
    "văruirea": "văruire",
    "văruireo": "văruire",
    "văruiri": "văruire",
    "văruirii": "văruire",
    "văruirile": "văruire",
    "văruirilor": "văruire",
    "văruita": "văruit",
    "văruită": "văruit",
    "văruite": "văruit",
    "văruitei": "văruit",
    "văruitele": "văruit",
    "văruitelor": "văruit",
    "văruiți": "văruit",
    "văruiții": "văruit",
    "văruiților": "văruit",
    "văruito": "văruit",
    "văruitul": "văruit",
    "văruitule": "văruit",
    "văruitului": "văruit",
    "varza": "varză",
    "verze": "varză",
    "verzei": "varză",
    "verzele": "varză",
    "verzelor": "varză",
    "vase": "vas",
    "vasele": "vas",
    "vaselor": "vas",
    "vasul": "vas",
    "vasului": "vas",
    "vasali": "vasal",
    "vasalii": "vasal",
    "vasalilor": "vasal",
    "vasalul": "vasal",
    "vasalului": "vasal",
    "vasalitatea": "vasalitate",
    "vasalități": "vasalitate",
    "vasalității": "vasalitate",
    "vasalitățile": "vasalitate",
    "vasalităților": "vasalitate",
    "vâscul": "vâsc",
    "vâscului": "vâsc",
    "vâscuri": "vâsc",
    "vâscurile": "vâsc",
    "vâscurilor": "vâsc",
    "vâscoasa": "vâscos",
    "vâscoasă": "vâscos",
    "vâscoase": "vâscos",
    "vâscoasei": "vâscos",
    "vâscoasele": "vâscos",
    "vâscoaselor": "vâscos",
    "vâscoși": "vâscos",
    "vâscoșii": "vâscos",
    "vâscoșilor": "vâscos",
    "vâscosul": "vâscos",
    "vâscosului": "vâscos",
    "vâscoza": "vâscoză",
    "vâscoze": "vâscoză",
    "vâscozei": "vâscoză",
    "vâscozele": "vâscoză",
    "vâscozelor": "vâscoză",
    "vâscozitatea": "vâscozitate",
    "vâscozități": "vâscozitate",
    "vâscozității": "vâscozitate",
    "vâscozitățile": "vâscozitate",
    "vâscozităților": "vâscozitate",
    "vasculara": "vascular",
    "vasculară": "vascular",
    "vasculare": "vascular",
    "vascularei": "vascular",
    "vascularele": "vascular",
    "vascularelor": "vascular",
    "vasculari": "vascular",
    "vascularii": "vascular",
    "vascularilor": "vascular",
    "vascularul": "vascular",
    "vascularului": "vascular",
    "nemaivascularizând": "vasculariza",
    "nemaivascularizându": "vasculariza",
    "nevascularizând": "vasculariza",
    "nevascularizându": "vasculariza",
    "vasculariză": "vasculariza",
    "vascularizând": "vasculariza",
    "vascularizându": "vasculariza",
    "vascularizară": "vasculariza",
    "vascularizase": "vasculariza",
    "vascularizaseră": "vasculariza",
    "vascularizat": "vasculariza",
    "vascularizau": "vasculariza",
    "vascularizează": "vasculariza",
    "vascularizata": "vascularizat",
    "vascularizată": "vascularizat",
    "vascularizate": "vascularizat",
    "vascularizatei": "vascularizat",
    "vascularizatele": "vascularizat",
    "vascularizatelor": "vascularizat",
    "vascularizați": "vascularizat",
    "vascularizații": "vascularizat",
    "vascularizaților": "vascularizat",
    "vascularizato": "vascularizat",
    "vascularizatul": "vascularizat",
    "vascularizatule": "vascularizat",
    "vascularizatului": "vascularizat",
    "vascularizația": "vascularizație",
    "vascularizației": "vascularizație",
    "vascularizații": "vascularizație",
    "vascularizațiile": "vascularizație",
    "vascularizațiilor": "vascularizație",
    "vascularizațio": "vascularizație",
    "vaselina": "vaselină",
    "vaseline": "vaselină",
    "vaselinei": "vaselină",
    "vaselinele": "vaselină",
    "vaselinelor": "vaselină",
    "V.": "Vasile",
    "Vasilicăi": "Vasilica",
    "nemaivâslind": "vâsli",
    "nemaivâslindu": "vâsli",
    "nevâslind": "vâsli",
    "nevâslindu": "vâsli",
    "vâslea": "vâsli",
    "vâsleai": "vâsli",
    "vâsleam": "vâsli",
    "vâslească": "vâsli",
    "vâsleați": "vâsli",
    "vâsleau": "vâsli",
    "vâslesc": "vâsli",
    "vâslește": "vâsli",
    "vâslești": "vâsli",
    "vâslii": "vâsli",
    "vâslim": "vâsli",
    "vâslind": "vâsli",
    "vâslindu": "vâsli",
    "vâsliră": "vâsli",
    "vâslirăm": "vâsli",
    "vâslirăți": "vâsli",
    "vâslise": "vâsli",
    "vâslisem": "vâsli",
    "vâsliseră": "vâsli",
    "vâsliserăm": "vâsli",
    "vâsliserăți": "vâsli",
    "vâsliseși": "vâsli",
    "vâsliși": "vâsli",
    "vâslit": "vâsli",
    "vâsliți": "vâsli",
    "vâslirea": "vâslire",
    "vâslireo": "vâslire",
    "vâsliri": "vâslire",
    "vâslirii": "vâslire",
    "vâslirile": "vâslire",
    "vâslirilor": "vâslire",
    "vâslită": "vâslit",
    "vâslite": "vâslit",
    "vâsliți": "vâslit",
    "vasoconstricția": "vasoconstricție",
    "vasoconstricției": "vasoconstricție",
    "vasoconstricții": "vasoconstricție",
    "vasoconstricțiile": "vasoconstricție",
    "vasoconstricțiilor": "vasoconstricție",
    "vasodilatarea": "vasodilatare",
    "vasodilatări": "vasodilatare",
    "vasodilatării": "vasodilatare",
    "vasodilatările": "vasodilatare",
    "vasodilatărilor": "vasodilatare",
    "vasta": "vast",
    "vastă": "vast",
    "vaste": "vast",
    "vastei": "vast",
    "vastele": "vast",
    "vastelor": "vast",
    "vaști": "vast",
    "vaștii": "vast",
    "vaștilor": "vast",
    "vastul": "vast",
    "vastului": "vast",
    "vata": "vată",
    "vatei": "vată",
    "vătafi": "vătaf",
    "vătafii": "vătaf",
    "vătafilor": "vătaf",
    "vătaful": "vătaf",
    "vătafului": "vătaf",
    "vatăm": "vătăma",
    "vatămă": "vătăma",
    "vătămă": "vătăma",
    "vătămai": "vătăma",
    "vătămăm": "vătăma",
    "vătămând": "vătăma",
    "vătămându": "vătăma",
    "vătămară": "vătăma",
    "vătămarăm": "vătăma",
    "vătămarăți": "vătăma",
    "vătămași": "vătăma",
    "vătămat": "vătăma",
    "vătămați": "vătăma",
    "vatăme": "vătăma",
    "vatămi": "vătăma",
    "vătămi": "vătăma",
    "vateme": "vătăma",
    "vatemi": "vătăma",
    "veteme": "vătăma",
    "vătămarea": "vătămare",
    "vătămări": "vătămare",
    "vătămării": "vătămare",
    "vătămările": "vătămare",
    "vătămărilor": "vătămare",
    "vătămata": "vătămat",
    "vătămată": "vătămat",
    "vătămate": "vătămat",
    "vătămatei": "vătămat",
    "vătămatele": "vătămat",
    "vătămatelor": "vătămat",
    "vătămați": "vătămat",
    "vătămații": "vătămat",
    "vătămaților": "vătămat",
    "vătămatul": "vătămat",
    "vătămatule": "vătămat",
    "vătămatului": "vătămat",
    "vătămătoare": "vătămător",
    "vătămătoarea": "vătămător",
    "vătămătoarei": "vătămător",
    "vătămătoarele": "vătămător",
    "vătămătoarelor": "vătămător",
    "vătămători": "vătămător",
    "vătămătorii": "vătămător",
    "vătămătorilor": "vătămător",
    "vătămătorul": "vătămător",
    "vătămătorului": "vătămător",
    "vatelina": "vatelină",
    "vateline": "vatelină",
    "vatelinei": "vatelină",
    "vatelinele": "vatelină",
    "vatelinelor": "vatelină",
    "vatmani": "vatman",
    "vatmanii": "vatman",
    "vatmanilor": "vatman",
    "vatmanul": "vatman",
    "vatmanului": "vatman",
    "vatra": "vatră",
    "vetre": "vatră",
    "vetrei": "vatră",
    "vetrele": "vatră",
    "vetrelor": "vatră",
    "vătraie": "vătrai",
    "vătraiele": "vătrai",
    "vătraielor": "vătrai",
    "vătraiul": "vătrai",
    "vătraiului": "vătrai",
    "nemaivătuind": "vătui",
    "nemaivătuindu": "vătui",
    "nevătuind": "vătui",
    "nevătuindu": "vătui",
    "vătuia": "vătui",
    "vătuiai": "vătui",
    "vătuiam": "vătui",
    "vătuiască": "vătui",
    "vătuiați": "vătui",
    "vătuiau": "vătui",
    "vătuiesc": "vătui",
    "vătuiește": "vătui",
    "vătuiești": "vătui",
    "vătuii": "vătui",
    "vătuim": "vătui",
    "vătuind": "vătui",
    "vătuindu": "vătui",
    "vătuiră": "vătui",
    "vătuirăm": "vătui",
    "vătuirăți": "vătui",
    "vătuise": "vătui",
    "vătuisem": "vătui",
    "vătuiseră": "vătui",
    "vătuiserăm": "vătui",
    "vătuiserăți": "vătui",
    "vătuiseși": "vătui",
    "vătuiși": "vătui",
    "vătuit": "vătui",
    "vătuiți": "vătui",
    "vătuirea": "vătuire",
    "vătuireo": "vătuire",
    "vătuiri": "vătuire",
    "vătuirii": "vătuire",
    "vătuirile": "vătuire",
    "vătuirilor": "vătuire",
    "vătuita": "vătuit",
    "vătuită": "vătuit",
    "vătuite": "vătuit",
    "vătuitei": "vătuit",
    "vătuitele": "vătuit",
    "vătuitelor": "vătuit",
    "vătuiți": "vătuit",
    "vătuiții": "vătuit",
    "vătuiților": "vătuit",
    "vătuito": "vătuit",
    "vătuitul": "vătuit",
    "vătuitule": "vătuit",
    "vătuitului": "vătuit",
    "văzul": "văz",
    "văzului": "văz",
    "văzuri": "văz",
    "văzurile": "văz",
    "văzurilor": "văz",
    "vaza": "vază",
    "vaze": "vază",
    "vazei": "vază",
    "vazele": "vază",
    "vazelor": "vază",
    "văzduhul": "văzduh",
    "văzduhului": "văzduh",
    "văzduhuri": "văzduh",
    "văzduhurile": "văzduh",
    "văzduhurilor": "văzduh",
    "văzută": "văzut",
    "văzute": "văzut",
    "văzuți": "văzut",
    "veacul": "veac",
    "veacului": "veac",
    "veacuri": "veac",
    "veacurile": "veac",
    "veacurilor": "veac",
    "veci": "veac",
    "vecii": "veac",
    "vecilor": "veac",
    "vecernia": "vecernie",
    "vecerniei": "vecernie",
    "vecernii": "vecernie",
    "vecerniile": "vecernie",
    "vecerniilor": "vecernie",
    "v.": "vechi",
    "veche": "vechi",
    "vechea": "vechi",
    "vechii": "vechi",
    "vechile": "vechi",
    "vechilor": "vechi",
    "vechiu'": "vechi",
    "vechiul": "vechi",
    "vechiului": "vechi",
    "vechigânditorii": "vechigânditor",
    "vechimea": "vechime",
    "vechimei": "vechime",
    "vechimi": "vechime",
    "vechimile": "vechime",
    "vechimilor": "vechime",
    "vechitura": "vechitură",
    "vechituri": "vechitură",
    "vechiturii": "vechitură",
    "vechiturile": "vechitură",
    "vechiturilor": "vechitură",
    "vechivorba": "vechivorbă",
    "vechivorbei": "vechivorbă",
    "vecia": "vecie",
    "veciei": "vecie",
    "vecii": "vecie",
    "veciile": "vecie",
    "veciilor": "vecie",
    "vecina": "vecin",
    "vecină": "vecin",
    "vecine": "vecin",
    "vecinei": "vecin",
    "vecinele": "vecin",
    "vecinelor": "vecin",
    "vecini": "vecin",
    "vecinii": "vecin",
    "vecinilor": "vecin",
    "vecinul": "vecin",
    "vecinului": "vecin",
    "vecina": "vecină",
    "vecine": "vecină",
    "vecinei": "vecină",
    "vecinele": "vecină",
    "vecinelor": "vecină",
    "vecinătatea": "vecinătate",
    "vecinătăți": "vecinătate",
    "vecinătății": "vecinătate",
    "vecinătățile": "vecinătate",
    "vecinătăților": "vecinătate",
    "vectori": "vector",
    "vectorii": "vector",
    "vectorilor": "vector",
    "vectorul": "vector",
    "vectorului": "vector",
    "vecuia": "vecui",
    "vecuiai": "vecui",
    "vecuiam": "vecui",
    "vecuiască": "vecui",
    "vecuiați": "vecui",
    "vecuiau": "vecui",
    "vecuiesc": "vecui",
    "vecuiește": "vecui",
    "vecuiești": "vecui",
    "vecuii": "vecui",
    "vecuim": "vecui",
    "vecuind": "vecui",
    "vecuindu": "vecui",
    "vecuiră": "vecui",
    "vecuirăm": "vecui",
    "vecuirăți": "vecui",
    "vecuise": "vecui",
    "vecuisem": "vecui",
    "vecuiseră": "vecui",
    "vecuiserăm": "vecui",
    "vecuiserăți": "vecui",
    "vecuiseși": "vecui",
    "vecuiși": "vecui",
    "vecuit": "vecui",
    "vecuiți": "vecui",
    "vecuitu": "vecui",
    "vecuită": "vecuit",
    "vecuite": "vecuit",
    "vecuiți": "vecuit",
    "nemaivăzând": "vedea",
    "nemaivăzându": "vedea",
    "nevăzând": "vedea",
    "nevăzându": "vedea",
    "văd": "vedea",
    "vadă": "vedea",
    "văzând": "vedea",
    "văzându": "vedea",
    "văzu": "vedea",
    "văzui": "vedea",
    "văzură": "vedea",
    "văzurăm": "vedea",
    "văzurăți": "vedea",
    "văzuse": "vedea",
    "văzusem": "vedea",
    "văzuseră": "vedea",
    "văzuserăm": "vedea",
    "văzuserăți": "vedea",
    "văzuseși": "vedea",
    "văzuși": "vedea",
    "văzut": "vedea",
    "vede": "vedea",
    "vedeai": "vedea",
    "vedeam": "vedea",
    "vedeați": "vedea",
    "vedeau": "vedea",
    "vedem": "vedea",
    "vedeți": "vedea",
    "vezi": "vedea",
    "vedenia": "vedenie",
    "vedeniei": "vedenie",
    "vedenii": "vedenie",
    "vedeniile": "vedenie",
    "vedeniilor": "vedenie",
    "vederea": "vedere",
    "vederi": "vedere",
    "vederii": "vedere",
    "vederile": "vedere",
    "vederilor": "vedere",
    "vedeta": "vedetă",
    "vedete": "vedetă",
    "vedetei": "vedetă",
    "vedetele": "vedetă",
    "vedetelor": "vedetă",
    "vedetisme": "vedetism",
    "vedetismele": "vedetism",
    "vedetismelor": "vedetism",
    "vedetismul": "vedetism",
    "vedetismului": "vedetism",
    "nemaivegetând": "vegeta",
    "nemaivegetându": "vegeta",
    "nevegetând": "vegeta",
    "nevegetându": "vegeta",
    "vegetă": "vegeta",
    "vegetai": "vegeta",
    "vegetam": "vegeta",
    "vegetăm": "vegeta",
    "vegetând": "vegeta",
    "vegetându": "vegeta",
    "vegetară": "vegeta",
    "vegetarăm": "vegeta",
    "vegetarăți": "vegeta",
    "vegetase": "vegeta",
    "vegetasem": "vegeta",
    "vegetaseră": "vegeta",
    "vegetaserăm": "vegeta",
    "vegetaserăți": "vegeta",
    "vegetaseși": "vegeta",
    "vegetași": "vegeta",
    "vegetat": "vegeta",
    "vegetați": "vegeta",
    "vegetau": "vegeta",
    "vegetează": "vegeta",
    "vegetez": "vegeta",
    "vegeteze": "vegeta",
    "vegetezi": "vegeta",
    "vegetala": "vegetal",
    "vegetală": "vegetal",
    "vegetale": "vegetal",
    "vegetalei": "vegetal",
    "vegetalele": "vegetal",
    "vegetalelor": "vegetal",
    "vegetali": "vegetal",
    "vegetalii": "vegetal",
    "vegetalilor": "vegetal",
    "vegetalul": "vegetal",
    "vegetalului": "vegetal",
    "vegetarea": "vegetare",
    "vegetareo": "vegetare",
    "vegetări": "vegetare",
    "vegetării": "vegetare",
    "vegetările": "vegetare",
    "vegetărilor": "vegetare",
    "vegetată": "vegetat",
    "vegetate": "vegetat",
    "vegetați": "vegetat",
    "vegetația": "vegetație",
    "vegetației": "vegetație",
    "vegetații": "vegetație",
    "vegetațiile": "vegetație",
    "vegetațiilor": "vegetație",
    "veghea": "veghe",
    "veghi": "veghe",
    "veghii": "veghe",
    "veghile": "veghe",
    "veghilor": "veghe",
    "nemaivegheând": "veghea",
    "nemaivegheându": "veghea",
    "nevegheând": "veghea",
    "nevegheându": "veghea",
    "veghe": "veghea",
    "vegheai": "veghea",
    "vegheam": "veghea",
    "vegheară": "veghea",
    "veghearăm": "veghea",
    "veghearăți": "veghea",
    "veghease": "veghea",
    "vegheasem": "veghea",
    "vegheaseră": "veghea",
    "vegheaserăm": "veghea",
    "vegheaserăți": "veghea",
    "vegheaseși": "veghea",
    "vegheași": "veghea",
    "vegheat": "veghea",
    "vegheați": "veghea",
    "vegheau": "veghea",
    "veghează": "veghea",
    "veghem": "veghea",
    "veghez": "veghea",
    "vegheze": "veghea",
    "veghezi": "veghea",
    "veghind": "veghea",
    "veghindu": "veghea",
    "vegheata": "vegheat",
    "vegheată": "vegheat",
    "vegheate": "vegheat",
    "vegheatei": "vegheat",
    "vegheatele": "vegheat",
    "vegheatelor": "vegheat",
    "vegheați": "vegheat",
    "vegheații": "vegheat",
    "vegheaților": "vegheat",
    "vegheato": "vegheat",
    "vegheatul": "vegheat",
    "vegheatule": "vegheat",
    "vegheatului": "vegheat",
    "vegherea": "veghere",
    "vegheri": "veghere",
    "vegherii": "veghere",
    "vegherile": "veghere",
    "vegherilor": "veghere",
    "vehementa": "vehement",
    "vehementă": "vehement",
    "vehemențe": "vehement",
    "vehemenței": "vehement",
    "vehemențele": "vehement",
    "vehemențelor": "vehement",
    "vehemenți": "vehement",
    "vehemenții": "vehement",
    "vehemenților": "vehement",
    "vehementul": "vehement",
    "vehementului": "vehement",
    "vehemența": "vehemență",
    "vehemențe": "vehemență",
    "vehemenței": "vehemență",
    "vehemențele": "vehemență",
    "vehemențelor": "vehemență",
    "vehicule": "vehicul",
    "vehiculele": "vehicul",
    "vehiculelor": "vehicul",
    "vehiculul": "vehicul",
    "vehiculului": "vehicul",
    "vehiculă": "vehicula",
    "vehiculai": "vehicula",
    "vehiculam": "vehicula",
    "vehiculăm": "vehicula",
    "vehiculând": "vehicula",
    "vehiculându": "vehicula",
    "vehiculară": "vehicula",
    "vehicularăm": "vehicula",
    "vehicularăți": "vehicula",
    "vehiculase": "vehicula",
    "vehiculasem": "vehicula",
    "vehiculaseră": "vehicula",
    "vehiculaserăm": "vehicula",
    "vehiculaserăți": "vehicula",
    "vehiculaseși": "vehicula",
    "vehiculași": "vehicula",
    "vehiculat": "vehicula",
    "vehiculați": "vehicula",
    "vehiculatu": "vehicula",
    "vehiculau": "vehicula",
    "vehiculează": "vehicula",
    "vehiculez": "vehicula",
    "vehiculeze": "vehicula",
    "vehiculezi": "vehicula",
    "vehiculată": "vehiculat",
    "vehiculate": "vehiculat",
    "vehiculați": "vehiculat",
    "vela": "velă",
    "vele": "velă",
    "velei": "velă",
    "velele": "velă",
    "velelor": "velă",
    "veleitara": "veleitar",
    "veleitară": "veleitar",
    "veleitare": "veleitar",
    "veleitarei": "veleitar",
    "veleitarele": "veleitar",
    "veleitarelor": "veleitar",
    "veleitari": "veleitar",
    "veleitarii": "veleitar",
    "veleitarilor": "veleitar",
    "veleitarul": "veleitar",
    "veleitarului": "veleitar",
    "veleitatea": "veleitate",
    "veleități": "veleitate",
    "veleității": "veleitate",
    "veleitățile": "veleitate",
    "veleităților": "veleitate",
    "velința": "velință",
    "velințe": "velință",
    "velinței": "velință",
    "velințele": "velință",
    "velințelor": "velință",
    "velodromul": "velodrom",
    "velodromului": "velodrom",
    "velodromuri": "velodrom",
    "velodromurile": "velodrom",
    "velodromurilor": "velodrom",
    "velure": "velur",
    "velurele": "velur",
    "velurelor": "velur",
    "velurul": "velur",
    "velurului": "velur",
    "vena": "venă",
    "vene": "venă",
    "venei": "venă",
    "venele": "venă",
    "venelor": "venă",
    "venala": "venal",
    "venală": "venal",
    "venale": "venal",
    "venalei": "venal",
    "venalele": "venal",
    "venalelor": "venal",
    "venali": "venal",
    "venalii": "venal",
    "venalilor": "venal",
    "venalul": "venal",
    "venalului": "venal",
    "vendeta": "vendetă",
    "vendete": "vendetă",
    "vendetei": "vendetă",
    "vendetele": "vendetă",
    "vendetelor": "vendetă",
    "nemaivenerând": "venera",
    "nemaivenerându": "venera",
    "nevenerând": "venera",
    "nevenerându": "venera",
    "veneră": "venera",
    "venerai": "venera",
    "veneram": "venera",
    "venerăm": "venera",
    "venerând": "venera",
    "venerându": "venera",
    "venerară": "venera",
    "venerarăm": "venera",
    "venerarăți": "venera",
    "venerase": "venera",
    "venerasem": "venera",
    "veneraseră": "venera",
    "veneraserăm": "venera",
    "veneraserăți": "venera",
    "veneraseși": "venera",
    "venerași": "venera",
    "venerat": "venera",
    "venerați": "venera",
    "venerau": "venera",
    "venerează": "venera",
    "venerez": "venera",
    "venereze": "venera",
    "venerezi": "venera",
    "venerabila": "venerabil",
    "venerabilă": "venerabil",
    "venerabile": "venerabil",
    "venerabilei": "venerabil",
    "venerabilele": "venerabil",
    "venerabilelor": "venerabil",
    "venerabili": "venerabil",
    "venerabilii": "venerabil",
    "venerabililor": "venerabil",
    "venerabilo": "venerabil",
    "venerabilul": "venerabil",
    "venerabilule": "venerabil",
    "venerabilului": "venerabil",
    "venerarea": "venerare",
    "venerareo": "venerare",
    "venerări": "venerare",
    "venerării": "venerare",
    "venerările": "venerare",
    "venerărilor": "venerare",
    "venerata": "venerat",
    "venerată": "venerat",
    "venerate": "venerat",
    "veneratei": "venerat",
    "veneratele": "venerat",
    "veneratelor": "venerat",
    "venerați": "venerat",
    "venerații": "venerat",
    "veneraților": "venerat",
    "venerato": "venerat",
    "veneratul": "venerat",
    "veneratule": "venerat",
    "veneratului": "venerat",
    "venerația": "venerație",
    "venerației": "venerație",
    "venerații": "venerație",
    "venerațiile": "venerație",
    "venerațiilor": "venerație",
    "venerațio": "venerație",
    "venerica": "veneric",
    "venerică": "veneric",
    "venerice": "veneric",
    "venericei": "veneric",
    "venericele": "veneric",
    "venericelor": "veneric",
    "venerici": "veneric",
    "venericii": "veneric",
    "venericilor": "veneric",
    "venericul": "veneric",
    "venericului": "veneric",
    "venerologi": "venerolog",
    "venerologii": "venerolog",
    "venerologilor": "venerolog",
    "venerologul": "venerolog",
    "venerologului": "venerolog",
    "venerologia": "venerologie",
    "venerologiei": "venerologie",
    "venerologii": "venerologie",
    "venerologiile": "venerologie",
    "venerologiilor": "venerologie",
    "venesecția": "venesecție",
    "venesecției": "venesecție",
    "venesecții": "venesecție",
    "venesecțiile": "venesecție",
    "venesecțiilor": "venesecție",
    "Veneție": "Veneția",
    "Veneției": "Veneția",
    "venețiana": "venețian",
    "venețiană": "venețian",
    "venețianul": "venețian",
    "venețianului": "venețian",
    "venețiene": "venețian",
    "venețienei": "venețian",
    "venețienele": "venețian",
    "venețienelor": "venețian",
    "venețieni": "venețian",
    "venețienii": "venețian",
    "venețienilor": "venețian",
    "venetica": "venetic",
    "venetică": "venetic",
    "venetice": "venetic",
    "veneticei": "venetic",
    "veneticele": "venetic",
    "veneticelor": "venetic",
    "venetici": "venetic",
    "veneticii": "venetic",
    "veneticilor": "venetic",
    "veneticul": "venetic",
    "veneticului": "venetic",
    "nemaivenind": "veni",
    "nemaivenindu": "veni",
    "nevenind": "veni",
    "nevenindu": "veni",
    "venea": "veni",
    "veneai": "veni",
    "veneam": "veni",
    "veneați": "veni",
    "veneau": "veni",
    "venii": "veni",
    "venim": "veni",
    "venind": "veni",
    "venindu": "veni",
    "veniră": "veni",
    "venirăm": "veni",
    "venirăți": "veni",
    "venise": "veni",
    "venisem": "veni",
    "veniseră": "veni",
    "veniserăm": "veni",
    "veniserăți": "veni",
    "veniseși": "veni",
    "veniși": "veni",
    "venit": "veni",
    "veniți": "veni",
    "vii": "veni",
    "vin": "veni",
    "vin'": "veni",
    "vină": "veni",
    "vine": "veni",
    "vino": "veni",
    "veninul": "venin",
    "veninului": "venin",
    "veninuri": "venin",
    "veninurile": "venin",
    "veninurilor": "venin",
    "veninoasa": "veninos",
    "veninoasă": "veninos",
    "veninoase": "veninos",
    "veninoasei": "veninos",
    "veninoasele": "veninos",
    "veninoaselor": "veninos",
    "veninoși": "veninos",
    "veninoșii": "veninos",
    "veninoșilor": "veninos",
    "veninosul": "veninos",
    "veninosului": "veninos",
    "venirea": "venire",
    "venireo": "venire",
    "veniri": "venire",
    "venirii": "venire",
    "venirile": "venire",
    "venirilor": "venire",
    "venită": "venit",
    "venite": "venit",
    "veniți": "venit",
    "venitul": "venit",
    "venitului": "venit",
    "venituri": "venit",
    "veniturile": "venit",
    "veniturilor": "venit",
    "venoasa": "venos",
    "venoasă": "venos",
    "venoase": "venos",
    "venoasei": "venos",
    "venoasele": "venos",
    "venoaselor": "venos",
    "venoși": "venos",
    "venoșii": "venos",
    "venoșilor": "venos",
    "venosul": "venos",
    "venosului": "venos",
    "venozitatea": "venozitate",
    "venozități": "venozitate",
    "venozității": "venozitate",
    "venozitățile": "venozitate",
    "venozităților": "venozitate",
    "ventile": "ventil",
    "ventilele": "ventil",
    "ventilelor": "ventil",
    "ventilul": "ventil",
    "ventilului": "ventil",
    "nemaiventilând": "ventila",
    "nemaiventilându": "ventila",
    "neventilând": "ventila",
    "neventilându": "ventila",
    "ventilă": "ventila",
    "ventilai": "ventila",
    "ventilam": "ventila",
    "ventilăm": "ventila",
    "ventilând": "ventila",
    "ventilându": "ventila",
    "ventilară": "ventila",
    "ventilarăm": "ventila",
    "ventilarăți": "ventila",
    "ventilase": "ventila",
    "ventilasem": "ventila",
    "ventilaseră": "ventila",
    "ventilaserăm": "ventila",
    "ventilaserăți": "ventila",
    "ventilaseși": "ventila",
    "ventilași": "ventila",
    "ventilat": "ventila",
    "ventilați": "ventila",
    "ventilau": "ventila",
    "ventilează": "ventila",
    "ventilez": "ventila",
    "ventileze": "ventila",
    "ventilezi": "ventila",
    "ventilată": "ventilat",
    "ventilate": "ventilat",
    "ventilați": "ventilat",
    "ventilatoare": "ventilator",
    "ventilatoarele": "ventilator",
    "ventilatoarelor": "ventilator",
    "ventilatorul": "ventilator",
    "ventilatorului": "ventilator",
    "ventrala": "ventral",
    "ventrală": "ventral",
    "ventrale": "ventral",
    "ventralei": "ventral",
    "ventralele": "ventral",
    "ventralelor": "ventral",
    "ventrali": "ventral",
    "ventralii": "ventral",
    "ventralilor": "ventral",
    "ventralul": "ventral",
    "ventralului": "ventral",
    "ventricule": "ventricul",
    "ventriculele": "ventricul",
    "ventriculelor": "ventricul",
    "ventriculul": "ventricul",
    "ventriculului": "ventricul",
    "ventriculara": "ventricular",
    "ventriculară": "ventricular",
    "ventriculare": "ventricular",
    "ventricularei": "ventricular",
    "ventricularele": "ventricular",
    "ventricularelor": "ventricular",
    "ventriculari": "ventricular",
    "ventricularii": "ventricular",
    "ventricularilor": "ventricular",
    "ventricularul": "ventricular",
    "ventricularului": "ventricular",
    "ventriloci": "ventriloc",
    "ventrilocii": "ventriloc",
    "ventrilocilor": "ventriloc",
    "ventrilocul": "ventriloc",
    "ventrilocului": "ventriloc",
    "ventuza": "ventuză",
    "ventuze": "ventuză",
    "ventuzei": "ventuză",
    "ventuzele": "ventuză",
    "ventuzelor": "ventuză",
    "veracitatea": "veracitate",
    "veracități": "veracitate",
    "veracității": "veracitate",
    "veracitățile": "veracitate",
    "veracităților": "veracitate",
    "veranda": "verandă",
    "verande": "verandă",
    "verandei": "verandă",
    "verandele": "verandă",
    "verandelor": "verandă",
    "vb.": "verb",
    "verbe": "verb",
    "verbele": "verb",
    "verbelor": "verb",
    "verbul": "verb",
    "verbului": "verb",
    "verbala": "verbal",
    "verbală": "verbal",
    "verbale": "verbal",
    "verbalei": "verbal",
    "verbalele": "verbal",
    "verbalelor": "verbal",
    "verbali": "verbal",
    "verbalii": "verbal",
    "verbalilor": "verbal",
    "verbalul": "verbal",
    "verbalului": "verbal",
    "verbina": "verbină",
    "verbine": "verbină",
    "verbinei": "verbină",
    "verbinele": "verbină",
    "verbinelor": "verbină",
    "verb-substantivul": "verb-substantiv",
    "verdele": "verde",
    "verdelui": "verde",
    "verzi": "verde",
    "verdeața": "verdeață",
    "verdeți": "verdeață",
    "verdeții": "verdeață",
    "verdețuri": "verdeață",
    "verdețurile": "verdeață",
    "verdețurilor": "verdeață",
    "verdicte": "verdict",
    "verdictele": "verdict",
    "verdictelor": "verdict",
    "verdictul": "verdict",
    "verdictului": "verdict",
    "vergea": "vergă",
    "vergi": "vergă",
    "vergii": "vergă",
    "vergile": "vergă",
    "vergilor": "vergă",
    "vergeaua": "vergea",
    "vergele": "vergea",
    "vergelei": "vergea",
    "vergelele": "vergea",
    "vergelelor": "vergea",
    "veridica": "veridic",
    "veridică": "veridic",
    "veridice": "veridic",
    "veridicei": "veridic",
    "veridicele": "veridic",
    "veridicelor": "veridic",
    "veridici": "veridic",
    "veridicii": "veridic",
    "veridicilor": "veridic",
    "veridicul": "veridic",
    "veridicului": "veridic",
    "veridicitatea": "veridicitate",
    "veridicități": "veridicitate",
    "veridicității": "veridicitate",
    "veridicitățile": "veridicitate",
    "veridicităților": "veridicitate",
    "nemaiverificând": "verifica",
    "nemaiverificându": "verifica",
    "neverificând": "verifica",
    "neverificându": "verifica",
    "verific": "verifica",
    "verifică": "verifica",
    "verificai": "verifica",
    "verificam": "verifica",
    "verificăm": "verifica",
    "verificând": "verifica",
    "verificându": "verifica",
    "verificară": "verifica",
    "verificarăm": "verifica",
    "verificarăți": "verifica",
    "verificase": "verifica",
    "verificasem": "verifica",
    "verificaseră": "verifica",
    "verificaserăm": "verifica",
    "verificaserăți": "verifica",
    "verificaseși": "verifica",
    "verificași": "verifica",
    "verificat": "verifica",
    "verificați": "verifica",
    "verificau": "verifica",
    "verifice": "verifica",
    "verifici": "verifica",
    "verificarea": "verificare",
    "verificareo": "verificare",
    "verificări": "verificare",
    "verificării": "verificare",
    "verificările": "verificare",
    "verificărilor": "verificare",
    "verificata": "verificat",
    "verificată": "verificat",
    "verificate": "verificat",
    "verificatei": "verificat",
    "verificatele": "verificat",
    "verificatelor": "verificat",
    "verificați": "verificat",
    "verificații": "verificat",
    "verificaților": "verificat",
    "verificato": "verificat",
    "verificatul": "verificat",
    "verificatule": "verificat",
    "verificatului": "verificat",
    "veriga": "verigă",
    "verigi": "verigă",
    "verigii": "verigă",
    "verigile": "verigă",
    "verigilor": "verigă",
    "verigari": "verigar",
    "verigarii": "verigar",
    "verigarilor": "verigar",
    "verigarul": "verigar",
    "verigarului": "verigar",
    "verigei": "verigel",
    "verigeii": "verigel",
    "verigeilor": "verigel",
    "verigelul": "verigel",
    "verigelului": "verigel",
    "verigheta": "verighetă",
    "verighete": "verighetă",
    "verighetei": "verighetă",
    "verighetele": "verighetă",
    "verighetelor": "verighetă",
    "veriguța": "veriguță",
    "veriguțe": "veriguță",
    "veriguței": "veriguță",
    "veriguțele": "veriguță",
    "veriguțelor": "veriguță",
    "verismul": "verism",
    "verismului": "verism",
    "verișoara": "verișoară",
    "verișoare": "verișoară",
    "verișoarei": "verișoară",
    "verișoarele": "verișoară",
    "verișoarelor": "verișoară",
    "verișori": "verișor",
    "verișorii": "verișor",
    "verișorilor": "verișor",
    "verișorul": "verișor",
    "verișorului": "verișor",
    "veriste": "verist",
    "veristei": "verist",
    "veristele": "verist",
    "veristelor": "verist",
    "veriști": "verist",
    "veriștii": "verist",
    "veriștilor": "verist",
    "veristul": "verist",
    "veristului": "verist",
    "veritabila": "veritabil",
    "veritabilă": "veritabil",
    "veritabile": "veritabil",
    "veritabilei": "veritabil",
    "veritabilele": "veritabil",
    "veritabilelor": "veritabil",
    "veritabili": "veritabil",
    "veritabilii": "veritabil",
    "veritabililor": "veritabil",
    "veritabilul": "veritabil",
    "veritabilului": "veritabil",
    "vermiala": "vermial",
    "vermială": "vermial",
    "vermiale": "vermial",
    "vermialei": "vermial",
    "vermialele": "vermial",
    "vermialelor": "vermial",
    "vermiali": "vermial",
    "vermialii": "vermial",
    "vermialilor": "vermial",
    "vermialul": "vermial",
    "vermialului": "vermial",
    "vermiforma": "vermiform",
    "vermiformă": "vermiform",
    "vermiforme": "vermiform",
    "vermiformei": "vermiform",
    "vermiformele": "vermiform",
    "vermiformelor": "vermiform",
    "vermiformi": "vermiform",
    "vermiformii": "vermiform",
    "vermiformilor": "vermiform",
    "vermiformul": "vermiform",
    "vermiformului": "vermiform",
    "vermifuga": "vermifug",
    "vermifugă": "vermifug",
    "vermifuge": "vermifug",
    "vermifugei": "vermifug",
    "vermifugele": "vermifug",
    "vermifugelor": "vermifug",
    "vermifugi": "vermifug",
    "vermifugii": "vermifug",
    "vermifugilor": "vermifug",
    "vermifugul": "vermifug",
    "vermifugului": "vermifug",
    "vermina": "vermină",
    "vermine": "vermină",
    "verminei": "vermină",
    "verminele": "vermină",
    "verminelor": "vermină",
    "vermorele": "vermorel",
    "vermorelele": "vermorel",
    "vermorelelor": "vermorel",
    "vermorelul": "vermorel",
    "vermorelului": "vermorel",
    "vermutul": "vermut",
    "vermutului": "vermut",
    "vermuturi": "vermut",
    "vermuturile": "vermut",
    "vermuturilor": "vermut",
    "verniere": "vernier",
    "vernierele": "vernier",
    "vernierelor": "vernier",
    "vernierul": "vernier",
    "vernierului": "vernier",
    "vernisul": "vernis",
    "vernisului": "vernis",
    "vernisuri": "vernis",
    "vernisurile": "vernis",
    "vernisurilor": "vernis",
    "vernisaje": "vernisaj",
    "vernisajele": "vernisaj",
    "vernisajelor": "vernisaj",
    "vernisajul": "vernisaj",
    "vernisajului": "vernisaj",
    "veroasa": "veros",
    "veroasă": "veros",
    "veroase": "veros",
    "veroasei": "veros",
    "veroasele": "veros",
    "veroaselor": "veros",
    "veroși": "veros",
    "veroșii": "veros",
    "veroșilor": "veros",
    "verosul": "veros",
    "verosului": "veros",
    "verosimila": "verosimil",
    "verosimilă": "verosimil",
    "verosimile": "verosimil",
    "verosimilei": "verosimil",
    "verosimilele": "verosimil",
    "verosimilelor": "verosimil",
    "verosimili": "verosimil",
    "verosimilii": "verosimil",
    "verosimililor": "verosimil",
    "verosimilul": "verosimil",
    "verosimilului": "verosimil",
    "versul": "vers",
    "versului": "vers",
    "versuri": "vers",
    "versurile": "vers",
    "versurilor": "vers",
    "versante": "versant",
    "versantele": "versant",
    "versantelor": "versant",
    "versantul": "versant",
    "versantului": "versant",
    "versate": "versat",
    "versatei": "versat",
    "versatele": "versat",
    "versatelor": "versat",
    "versați": "versat",
    "versații": "versat",
    "versaților": "versat",
    "versatul": "versat",
    "versatului": "versat",
    "versatila": "versatil",
    "versatilă": "versatil",
    "versatile": "versatil",
    "versatilei": "versatil",
    "versatilele": "versatil",
    "versatilelor": "versatil",
    "versatili": "versatil",
    "versatilii": "versatil",
    "versatililor": "versatil",
    "versatilul": "versatil",
    "versatilului": "versatil",
    "versatilitatea": "versatilitate",
    "versatilități": "versatilitate",
    "versatilității": "versatilitate",
    "versatilitățile": "versatilitate",
    "versatilităților": "versatilitate",
    "versete": "verset",
    "versetele": "verset",
    "versetelor": "verset",
    "versetul": "verset",
    "versetului": "verset",
    "nemaiversificând": "versifica",
    "nemaiversificându": "versifica",
    "neversificând": "versifica",
    "neversificându": "versifica",
    "versific": "versifica",
    "versifică": "versifica",
    "versificai": "versifica",
    "versificam": "versifica",
    "versificăm": "versifica",
    "versificând": "versifica",
    "versificându": "versifica",
    "versificară": "versifica",
    "versificarăm": "versifica",
    "versificarăți": "versifica",
    "versificase": "versifica",
    "versificasem": "versifica",
    "versificaseră": "versifica",
    "versificaserăm": "versifica",
    "versificaserăți": "versifica",
    "versificaseși": "versifica",
    "versificași": "versifica",
    "versificat": "versifica",
    "versificați": "versifica",
    "versificau": "versifica",
    "versifice": "versifica",
    "versifici": "versifica",
    "versificarea": "versificare",
    "versificareo": "versificare",
    "versificări": "versificare",
    "versificării": "versificare",
    "versificările": "versificare",
    "versificărilor": "versificare",
    "versificata": "versificat",
    "versificată": "versificat",
    "versificate": "versificat",
    "versificatei": "versificat",
    "versificatele": "versificat",
    "versificatelor": "versificat",
    "versificați": "versificat",
    "versificații": "versificat",
    "versificaților": "versificat",
    "versificato": "versificat",
    "versificatul": "versificat",
    "versificatule": "versificat",
    "versificatului": "versificat",
    "versificația": "versificație",
    "versificației": "versificație",
    "versificații": "versificație",
    "versificațiile": "versificație",
    "versificațiilor": "versificație",
    "versificatoarea": "versificatoare",
    "versificatoarei": "versificatoare",
    "versificatoarele": "versificatoare",
    "versificatoarelor": "versificatoare",
    "versificatoareo": "versificatoare",
    "versificatori": "versificator",
    "versificatorii": "versificator",
    "versificatorilor": "versificator",
    "versificatorul": "versificator",
    "versificatorule": "versificator",
    "versificatorului": "versificator",
    "versiunea": "versiune",
    "versiuni": "versiune",
    "versiunii": "versiune",
    "versiunile": "versiune",
    "versiunilor": "versiune",
    "v.": "verso",
    "versoul": "verso",
    "versoului": "verso",
    "vo.": "verso",
    "vs.": "versus",
    "vertebra": "vertebră",
    "vertebre": "vertebră",
    "vertebrei": "vertebră",
    "vertebrele": "vertebră",
    "vertebrelor": "vertebră",
    "vertebrala": "vertebral",
    "vertebrală": "vertebral",
    "vertebrale": "vertebral",
    "vertebralei": "vertebral",
    "vertebralele": "vertebral",
    "vertebralelor": "vertebral",
    "vertebrali": "vertebral",
    "vertebralii": "vertebral",
    "vertebralilor": "vertebral",
    "vertebralul": "vertebral",
    "vertebralului": "vertebral",
    "vertebrata": "vertebrat",
    "vertebrată": "vertebrat",
    "vertebrate": "vertebrat",
    "vertebratei": "vertebrat",
    "vertebratele": "vertebrat",
    "vertebratelor": "vertebrat",
    "vertebrați": "vertebrat",
    "vertebrații": "vertebrat",
    "vertebraților": "vertebrat",
    "vertebratul": "vertebrat",
    "vertebratului": "vertebrat",
    "verticala": "vertical",
    "verticală": "vertical",
    "verticale": "vertical",
    "verticalei": "vertical",
    "verticalele": "vertical",
    "verticalelor": "vertical",
    "verticali": "vertical",
    "verticalii": "vertical",
    "verticalilor": "vertical",
    "verticalul": "vertical",
    "verticalului": "vertical",
    "vertiginoasa": "vertiginos",
    "vertiginoasă": "vertiginos",
    "vertiginoase": "vertiginos",
    "vertiginoasei": "vertiginos",
    "vertiginoasele": "vertiginos",
    "vertiginoaselor": "vertiginos",
    "vertiginoși": "vertiginos",
    "vertiginoșii": "vertiginos",
    "vertiginoșilor": "vertiginos",
    "vertiginosul": "vertiginos",
    "vertiginosului": "vertiginos",
    "verva": "vervă",
    "verve": "vervă",
    "vervei": "vervă",
    "vervele": "vervă",
    "vervelor": "vervă",
    "verzișoara": "verzișoară",
    "verzișoare": "verzișoară",
    "verzișoarei": "verzișoară",
    "verzișoarele": "verzișoară",
    "verzișoarelor": "verzișoară",
    "verzișori": "verzișor",
    "verzișorii": "verzișor",
    "verzișorilor": "verzișor",
    "verzișorul": "verzișor",
    "verzișorului": "verzișor",
    "verzia": "verziu",
    "verzie": "verziu",
    "verziei": "verziu",
    "verzii": "verziu",
    "verziii": "verziu",
    "verziile": "verziu",
    "verziilor": "verziu",
    "verziul": "verziu",
    "verziului": "verziu",
    "verzuia": "verzui",
    "verzuie": "verzui",
    "verzuiei": "verzui",
    "verzuii": "verzui",
    "verzuile": "verzui",
    "verzuilor": "verzui",
    "verzuiul": "verzui",
    "verzuiului": "verzui",
    "vesela": "vesel",
    "veselă": "vesel",
    "vesele": "vesel",
    "veselei": "vesel",
    "veselele": "vesel",
    "veselelor": "vesel",
    "veseli": "vesel",
    "veselii": "vesel",
    "veselilor": "vesel",
    "veselul": "vesel",
    "veselului": "vesel",
    "vesela": "veselă",
    "vesele": "veselă",
    "veselei": "veselă",
    "veselele": "veselă",
    "veselelor": "veselă",
    "veselia": "veselie",
    "veseliei": "veselie",
    "veselii": "veselie",
    "veseliile": "veselie",
    "veseliilor": "veselie",
    "veșmântul": "veșmânt",
    "veșmântului": "veșmânt",
    "veșminte": "veșmânt",
    "veșmintele": "veșmânt",
    "veșmintelor": "veșmânt",
    "veșnica": "veșnic",
    "veșnică": "veșnic",
    "veșnice": "veșnic",
    "veșnicei": "veșnic",
    "veșnicele": "veșnic",
    "veșnicelor": "veșnic",
    "veșnici": "veșnic",
    "veșnicii": "veșnic",
    "veșnicilor": "veșnic",
    "veșnicul": "veșnic",
    "veșnicului": "veșnic",
    "veșnicia": "veșnicie",
    "veșniciei": "veșnicie",
    "veșnicii": "veșnicie",
    "veșniciile": "veșnicie",
    "veșniciilor": "veșnicie",
    "V": "vest",
    "vestul": "vest",
    "vestului": "vest",
    "vesta": "vestă",
    "veste": "vestă",
    "vestei": "vestă",
    "vestele": "vestă",
    "vestelor": "vestă",
    "vesta": "veste",
    "vestea": "veste",
    "vestei": "veste",
    "vesti": "veste",
    "vești": "veste",
    "vestii": "veste",
    "veștile": "veste",
    "veștilor": "veste",
    "veștedă": "veșted",
    "veștede": "veșted",
    "veștedei": "veșted",
    "veștedele": "veșted",
    "veștedelor": "veșted",
    "veștedul": "veșted",
    "veștedului": "veșted",
    "veștezi": "veșted",
    "veștezii": "veșted",
    "veștezilor": "veșted",
    "nemaiveștejind": "veșteji",
    "nemaiveștejindu": "veșteji",
    "neveștejind": "veșteji",
    "neveștejindu": "veșteji",
    "veștejea": "veșteji",
    "veștejeai": "veșteji",
    "veștejeam": "veșteji",
    "veștejească": "veșteji",
    "veștejeați": "veșteji",
    "veștejeau": "veșteji",
    "veștejesc": "veșteji",
    "veștejește": "veșteji",
    "veștejești": "veșteji",
    "veștejii": "veșteji",
    "veștejim": "veșteji",
    "veștejind": "veșteji",
    "veștejindu": "veșteji",
    "veștejiră": "veșteji",
    "veștejirăm": "veșteji",
    "veștejirăți": "veșteji",
    "veștejise": "veșteji",
    "veștejisem": "veșteji",
    "veștejiseră": "veșteji",
    "veștejiserăm": "veșteji",
    "veștejiserăți": "veșteji",
    "veștejiseși": "veșteji",
    "veștejiși": "veșteji",
    "veștejit": "veșteji",
    "veștejiți": "veșteji",
    "veștejirea": "veștejire",
    "veștejireo": "veștejire",
    "veștejiri": "veștejire",
    "veștejirii": "veștejire",
    "veștejirile": "veștejire",
    "veștejirilor": "veștejire",
    "veștejita": "veștejit",
    "veștejită": "veștejit",
    "veștejite": "veștejit",
    "veștejitei": "veștejit",
    "veștejitele": "veștejit",
    "veștejitelor": "veștejit",
    "veștejiți": "veștejit",
    "veștejiții": "veștejit",
    "veștejiților": "veștejit",
    "veștejito": "veștejit",
    "veștejitul": "veștejit",
    "veștejitule": "veștejit",
    "veștejitului": "veștejit",
    "nemaivestind": "vesti",
    "nemaivestindu": "vesti",
    "nevestind": "vesti",
    "nevestindu": "vesti",
    "vestea": "vesti",
    "vesteai": "vesti",
    "vesteam": "vesti",
    "vestească": "vesti",
    "vesteați": "vesti",
    "vesteau": "vesti",
    "vestesc": "vesti",
    "vestește": "vesti",
    "vestești": "vesti",
    "vestii": "vesti",
    "vestim": "vesti",
    "vestind": "vesti",
    "vestindu": "vesti",
    "vestiră": "vesti",
    "vestirăm": "vesti",
    "vestirăți": "vesti",
    "vestise": "vesti",
    "vestisem": "vesti",
    "vestiseră": "vesti",
    "vestiserăm": "vesti",
    "vestiserăți": "vesti",
    "vestiseși": "vesti",
    "vestiși": "vesti",
    "vestit": "vesti",
    "vestiți": "vesti",
    "vestiare": "vestiar",
    "vestiarele": "vestiar",
    "vestiarelor": "vestiar",
    "vestiarul": "vestiar",
    "vestiarului": "vestiar",
    "vestibulul": "vestibul",
    "vestibulului": "vestibul",
    "vestibuluri": "vestibul",
    "vestibulurile": "vestibul",
    "vestibulurilor": "vestibul",
    "vestică": "vestic",
    "vestice": "vestic",
    "vestici": "vestic",
    "vestigii": "vestigiu",
    "vestigiile": "vestigiu",
    "vestigiilor": "vestigiu",
    "vestigiul": "vestigiu",
    "vestigiului": "vestigiu",
    "vestimentara": "vestimentar",
    "vestimentară": "vestimentar",
    "vestimentare": "vestimentar",
    "vestimentarei": "vestimentar",
    "vestimentarele": "vestimentar",
    "vestimentarelor": "vestimentar",
    "vestimentari": "vestimentar",
    "vestimentarii": "vestimentar",
    "vestimentarilor": "vestimentar",
    "vestimentarul": "vestimentar",
    "vestimentarului": "vestimentar",
    "vestimentația": "vestimentație",
    "vestimentației": "vestimentație",
    "vestimentații": "vestimentație",
    "vestimentațiile": "vestimentație",
    "vestimentațiilor": "vestimentație",
    "vestirea": "vestire",
    "vestireo": "vestire",
    "vestiri": "vestire",
    "vestirii": "vestire",
    "vestirile": "vestire",
    "vestirilor": "vestire",
    "vestita": "vestit",
    "vestită": "vestit",
    "vestite": "vestit",
    "vestitei": "vestit",
    "vestitele": "vestit",
    "vestitelor": "vestit",
    "vestiți": "vestit",
    "vestiții": "vestit",
    "vestiților": "vestit",
    "vestito": "vestit",
    "vestitul": "vestit",
    "vestitule": "vestit",
    "vestitului": "vestit",
    "vestitoare": "vestitor",
    "vestitoarea": "vestitor",
    "vestitoarei": "vestitor",
    "vestitoarele": "vestitor",
    "vestitoarelor": "vestitor",
    "vestitori": "vestitor",
    "vestitorii": "vestitor",
    "vestitorilor": "vestitor",
    "vestitorul": "vestitor",
    "vestitorului": "vestitor",
    "veștmântul": "veștmânt",
    "veștmântului": "veștmânt",
    "veștminte": "veștmânt",
    "veștmintele": "veștmânt",
    "veștmintelor": "veștmânt",
    "vestoane": "veston",
    "vestoanele": "veston",
    "vestoanelor": "veston",
    "vestonul": "veston",
    "vestonului": "veston",
    "veterani": "veteran",
    "veteranii": "veteran",
    "veteranilor": "veteran",
    "veteranul": "veteran",
    "veteranului": "veteran",
    "veterinara": "veterinar",
    "veterinară": "veterinar",
    "veterinare": "veterinar",
    "veterinarei": "veterinar",
    "veterinarele": "veterinar",
    "veterinarelor": "veterinar",
    "veterinari": "veterinar",
    "veterinarii": "veterinar",
    "veterinarilor": "veterinar",
    "veterinarul": "veterinar",
    "veterinarului": "veterinar",
    "vetoul": "veto",
    "vetoului": "veto",
    "veverița": "veveriță",
    "veverițe": "veveriță",
    "veveriței": "veveriță",
    "veverițele": "veveriță",
    "veverițelor": "veveriță",
    "nemaivexând": "vexa",
    "nemaivexându": "vexa",
    "nevexând": "vexa",
    "nevexându": "vexa",
    "vexă": "vexa",
    "vexai": "vexa",
    "vexam": "vexa",
    "vexăm": "vexa",
    "vexând": "vexa",
    "vexându": "vexa",
    "vexară": "vexa",
    "vexarăm": "vexa",
    "vexarăți": "vexa",
    "vexase": "vexa",
    "vexasem": "vexa",
    "vexaseră": "vexa",
    "vexaserăm": "vexa",
    "vexaserăți": "vexa",
    "vexaseși": "vexa",
    "vexași": "vexa",
    "vexat": "vexa",
    "vexați": "vexa",
    "vexau": "vexa",
    "vexează": "vexa",
    "vexez": "vexa",
    "vexeze": "vexa",
    "vexezi": "vexa",
    "vexată": "vexat",
    "vexate": "vexat",
    "vexați": "vexat",
    "vezica": "vezică",
    "vezici": "vezică",
    "vezicii": "vezică",
    "vezicile": "vezică",
    "vezicilor": "vezică",
    "vezicala": "vezical",
    "vezicală": "vezical",
    "vezicale": "vezical",
    "vezicalei": "vezical",
    "vezicalele": "vezical",
    "vezicalelor": "vezical",
    "vezicali": "vezical",
    "vezicalii": "vezical",
    "vezicalilor": "vezical",
    "vezicalul": "vezical",
    "vezicalului": "vezical",
    "vezicula": "veziculă",
    "vezicule": "veziculă",
    "veziculei": "veziculă",
    "veziculele": "veziculă",
    "veziculelor": "veziculă",
    "v.": "via",
    "viabila": "viabil",
    "viabilă": "viabil",
    "viabile": "viabil",
    "viabilei": "viabil",
    "viabilele": "viabil",
    "viabilelor": "viabil",
    "viabili": "viabil",
    "viabilii": "viabil",
    "viabililor": "viabil",
    "viabilul": "viabil",
    "viabilului": "viabil",
    "viabilitatea": "viabilitate",
    "viabilități": "viabilitate",
    "viabilității": "viabilitate",
    "viabilitățile": "viabilitate",
    "viabilităților": "viabilitate",
    "viaducte": "viaduct",
    "viaductele": "viaduct",
    "viaductelor": "viaduct",
    "viaductul": "viaduct",
    "viaductului": "viaduct",
    "viața": "viață",
    "vieți": "viață",
    "vieții": "viață",
    "viețile": "viață",
    "vieților": "viață",
    "nemaivibrând": "vibra",
    "nemaivibrându": "vibra",
    "nevibrând": "vibra",
    "nevibrându": "vibra",
    "vibră": "vibra",
    "vibrai": "vibra",
    "vibram": "vibra",
    "vibrăm": "vibra",
    "vibrând": "vibra",
    "vibrându": "vibra",
    "vibrară": "vibra",
    "vibrarăm": "vibra",
    "vibrarăți": "vibra",
    "vibrase": "vibra",
    "vibrasem": "vibra",
    "vibraseră": "vibra",
    "vibraserăm": "vibra",
    "vibraserăți": "vibra",
    "vibraseși": "vibra",
    "vibrași": "vibra",
    "vibrat": "vibra",
    "vibrați": "vibra",
    "vibrau": "vibra",
    "vibrează": "vibra",
    "vibrez": "vibra",
    "vibreze": "vibra",
    "vibrezi": "vibra",
    "vibrarea": "vibrare",
    "vibrareo": "vibrare",
    "vibrări": "vibrare",
    "vibrării": "vibrare",
    "vibrările": "vibrare",
    "vibrărilor": "vibrare",
    "vibrată": "vibrat",
    "vibrate": "vibrat",
    "vibrați": "vibrat",
    "vibrația": "vibrație",
    "vibrației": "vibrație",
    "vibrații": "vibrație",
    "vibrațiile": "vibrație",
    "vibrațiilor": "vibrație",
    "vibratila": "vibratil",
    "vibratilă": "vibratil",
    "vibratile": "vibratil",
    "vibratilei": "vibratil",
    "vibratilele": "vibratil",
    "vibratilelor": "vibratil",
    "vibratili": "vibratil",
    "vibratilii": "vibratil",
    "vibratililor": "vibratil",
    "vibratilul": "vibratil",
    "vibratilului": "vibratil",
    "vibratoare": "vibrator",
    "vibratoarea": "vibrator",
    "vibratoarei": "vibrator",
    "vibratoarele": "vibrator",
    "vibratoarelor": "vibrator",
    "vibratoareo": "vibrator",
    "vibratori": "vibrator",
    "vibratorii": "vibrator",
    "vibratorilor": "vibrator",
    "vibratorul": "vibrator",
    "vibratorule": "vibrator",
    "vibratorului": "vibrator",
    "vibrioni": "vibrion",
    "vibrionii": "vibrion",
    "vibrionilor": "vibrion",
    "vibrionul": "vibrion",
    "vibrionului": "vibrion",
    "vicari": "vicar",
    "vicarii": "vicar",
    "vicarilor": "vicar",
    "vicarul": "vicar",
    "vicarului": "vicar",
    "v.v.": "vice_versa",
    "vicepreședintele": "vicepreședinte",
    "vicepreședintelui": "vicepreședinte",
    "vicepreședinți": "vicepreședinte",
    "vicepreședinții": "vicepreședinte",
    "vicepreședinților": "vicepreședinte",
    "viceprimarul": "viceprimar",
    "viceprimarului": "viceprimar",
    "viceprimărița": "viceprimăriță",
    "nemaiviciând": "vicia",
    "nemaiviciându": "vicia",
    "neviciând": "vicia",
    "neviciându": "vicia",
    "viciai": "vicia",
    "viciam": "vicia",
    "viciară": "vicia",
    "viciarăm": "vicia",
    "viciarăți": "vicia",
    "viciase": "vicia",
    "viciasem": "vicia",
    "viciaseră": "vicia",
    "viciaserăm": "vicia",
    "viciaserăți": "vicia",
    "viciaseși": "vicia",
    "viciași": "vicia",
    "viciat": "vicia",
    "viciați": "vicia",
    "viciau": "vicia",
    "viciază": "vicia",
    "vicie": "vicia",
    "viciem": "vicia",
    "viciez": "vicia",
    "vicieze": "vicia",
    "viciezi": "vicia",
    "viciind": "vicia",
    "viciindu": "vicia",
    "viciata": "viciat",
    "viciată": "viciat",
    "viciate": "viciat",
    "viciatei": "viciat",
    "viciatele": "viciat",
    "viciatelor": "viciat",
    "viciați": "viciat",
    "viciații": "viciat",
    "viciaților": "viciat",
    "viciato": "viciat",
    "viciatul": "viciat",
    "viciatule": "viciat",
    "viciatului": "viciat",
    "vicioasa": "vicios",
    "vicioasă": "vicios",
    "vicioase": "vicios",
    "vicioasei": "vicios",
    "vicioasele": "vicios",
    "vicioaselor": "vicios",
    "vicioși": "vicios",
    "vicioșii": "vicios",
    "vicioșilor": "vicios",
    "viciosul": "vicios",
    "viciosului": "vicios",
    "vicisitudinea": "vicisitudine",
    "vicisitudini": "vicisitudine",
    "vicisitudinii": "vicisitudine",
    "vicisitudinile": "vicisitudine",
    "vicisitudinilor": "vicisitudine",
    "vicii": "viciu",
    "viciile": "viciu",
    "viciilor": "viciu",
    "viciul": "viciu",
    "viciului": "viciu",
    "vicleana": "viclean",
    "vicleană": "viclean",
    "vicleanul": "viclean",
    "vicleanului": "viclean",
    "viclene": "viclean",
    "viclenei": "viclean",
    "viclenele": "viclean",
    "viclenelor": "viclean",
    "vicleni": "viclean",
    "viclenii": "viclean",
    "viclenilor": "viclean",
    "vicontele": "viconte",
    "vicontelui": "viconte",
    "viconți": "viconte",
    "viconții": "viconte",
    "viconților": "viconte",
    "victima": "victimă",
    "victime": "victimă",
    "victimei": "victimă",
    "victimele": "victimă",
    "victimelor": "victimă",
    "Victoriei": "Victoria",
    "victoria": "victorie",
    "victoriei": "victorie",
    "victorii": "victorie",
    "victoriile": "victorie",
    "victoriilor": "victorie",
    "victorioasa": "victorios",
    "victorioasă": "victorios",
    "victorioase": "victorios",
    "victorioasei": "victorios",
    "victorioasele": "victorios",
    "victorioaselor": "victorios",
    "victorioși": "victorios",
    "victorioșii": "victorios",
    "victorioșilor": "victorios",
    "victoriosul": "victorios",
    "victoriosului": "victorios",
    "vidul": "vid",
    "vidului": "vid",
    "viduri": "vid",
    "vidurile": "vid",
    "vidurilor": "vid",
    "v.": "vide",
    "vid.": "vide",
    "video-clipul": "video-clip",
    "video-clipului": "video-clip",
    "video-clipuri": "video-clip",
    "video-clipurile": "video-clip",
    "video-clipurilor": "video-clip",
    "vidra": "vidră",
    "vidre": "vidră",
    "vidrei": "vidră",
    "vidrele": "vidră",
    "vidrelor": "vidră",
    "via": "vie",
    "viei": "vie",
    "vii": "vie",
    "viile": "vie",
    "viilor": "vie",
    "Vienei": "Viena",
    "vieri": "vier",
    "vierii": "vier",
    "vierilor": "vier",
    "vierul": "vier",
    "vierului": "vier",
    "viermănoasa": "viermănos",
    "viermănoasă": "viermănos",
    "viermănoase": "viermănos",
    "viermănoasei": "viermănos",
    "viermănoasele": "viermănos",
    "viermănoaselor": "viermănos",
    "viermănoși": "viermănos",
    "viermănoșii": "viermănos",
    "viermănoșilor": "viermănos",
    "viermănosul": "viermănos",
    "viermănosului": "viermănos",
    "viermăria": "viermărie",
    "viermăriei": "viermărie",
    "viermării": "viermărie",
    "viermăriile": "viermărie",
    "viermăriilor": "viermărie",
    "viermele": "vierme",
    "viermelui": "vierme",
    "viermi": "vierme",
    "viermii": "vierme",
    "viermilor": "vierme",
    "viermișori": "viermișor",
    "viermișorii": "viermișor",
    "viermișorilor": "viermișor",
    "viermișorul": "viermișor",
    "viermișorului": "viermișor",
    "nemaiviermuind": "viermui",
    "nemaiviermuindu": "viermui",
    "neviermuind": "viermui",
    "neviermuindu": "viermui",
    "viermuia": "viermui",
    "viermuiai": "viermui",
    "viermuiam": "viermui",
    "viermuiască": "viermui",
    "viermuiați": "viermui",
    "viermuiau": "viermui",
    "viermuiesc": "viermui",
    "viermuiește": "viermui",
    "viermuiești": "viermui",
    "viermuii": "viermui",
    "viermuim": "viermui",
    "viermuind": "viermui",
    "viermuindu": "viermui",
    "viermuiră": "viermui",
    "viermuirăm": "viermui",
    "viermuirăți": "viermui",
    "viermuise": "viermui",
    "viermuisem": "viermui",
    "viermuiseră": "viermui",
    "viermuiserăm": "viermui",
    "viermuiserăți": "viermui",
    "viermuiseși": "viermui",
    "viermuiși": "viermui",
    "viermuit": "viermui",
    "viermuiți": "viermui",
    "viermuiala": "viermuială",
    "viermuialo": "viermuială",
    "viermuieli": "viermuială",
    "viermuielii": "viermuială",
    "viermuielile": "viermuială",
    "viermuielilor": "viermuială",
    "viermuirea": "viermuire",
    "viermuireo": "viermuire",
    "viermuiri": "viermuire",
    "viermuirii": "viermuire",
    "viermuirile": "viermuire",
    "viermuirilor": "viermuire",
    "viermuită": "viermuit",
    "viermuite": "viermuit",
    "viermuiți": "viermuit",
    "viermuitoare": "viermuitor",
    "viermuitoarea": "viermuitor",
    "viermuitoarei": "viermuitor",
    "viermuitoarele": "viermuitor",
    "viermuitoarelor": "viermuitor",
    "viermuitori": "viermuitor",
    "viermuitorii": "viermuitor",
    "viermuitorilor": "viermuitor",
    "viermuitorul": "viermuitor",
    "viermuitorului": "viermuitor",
    "viespare": "viespar",
    "viesparele": "viespar",
    "viesparelor": "viespar",
    "viesparul": "viespar",
    "viesparului": "viespar",
    "viespea": "viespe",
    "viespi": "viespe",
    "viespii": "viespe",
    "viespile": "viespe",
    "viespilor": "viespe",
    "viespoii": "viespoi",
    "viespoilor": "viespoi",
    "viespoiul": "viespoi",
    "viespoiului": "viespoi",
    "vietatea": "vietate",
    "vietăți": "vietate",
    "vietății": "vietate",
    "vietățile": "vietate",
    "vietăților": "vietate",
    "nemaiviețuind": "viețui",
    "nemaiviețuindu": "viețui",
    "neviețuind": "viețui",
    "neviețuindu": "viețui",
    "viețuia": "viețui",
    "viețuiai": "viețui",
    "viețuiam": "viețui",
    "viețuiască": "viețui",
    "viețuiați": "viețui",
    "viețuiau": "viețui",
    "viețuiesc": "viețui",
    "viețuiește": "viețui",
    "viețuiești": "viețui",
    "viețuii": "viețui",
    "viețuim": "viețui",
    "viețuind": "viețui",
    "viețuindu": "viețui",
    "viețuiră": "viețui",
    "viețuirăm": "viețui",
    "viețuirăți": "viețui",
    "viețuise": "viețui",
    "viețuisem": "viețui",
    "viețuiseră": "viețui",
    "viețuiserăm": "viețui",
    "viețuiserăți": "viețui",
    "viețuiseși": "viețui",
    "viețuiși": "viețui",
    "viețuit": "viețui",
    "viețuiți": "viețui",
    "viețuirea": "viețuire",
    "viețuireo": "viețuire",
    "viețuiri": "viețuire",
    "viețuirii": "viețuire",
    "viețuirile": "viețuire",
    "viețuirilor": "viețuire",
    "viețuită": "viețuit",
    "viețuite": "viețuit",
    "viețuiți": "viețuit",
    "viețuitoarea": "viețuitoare",
    "viețuitoarei": "viețuitoare",
    "viețuitoarele": "viețuitoare",
    "viețuitoarelor": "viețuitoare",
    "viețuitoareo": "viețuitoare",
    "viețuitoare": "viețuitor",
    "viețuitoarea": "viețuitor",
    "viețuitoarei": "viețuitor",
    "viețuitoarele": "viețuitor",
    "viețuitoarelor": "viețuitor",
    "viețuitoareo": "viețuitor",
    "viețuitori": "viețuitor",
    "viețuitorii": "viețuitor",
    "viețuitorilor": "viețuitor",
    "viețuitorul": "viețuitor",
    "viețuitorule": "viețuitor",
    "viețuitorului": "viețuitor",
    "viezurele": "viezure",
    "viezurelui": "viezure",
    "viezuri": "viezure",
    "viezurii": "viezure",
    "viezurilor": "viezure",
    "vifore": "vifor",
    "viforele": "vifor",
    "viforelor": "vifor",
    "viforul": "vifor",
    "viforului": "vifor",
    "viforeala": "viforeală",
    "viforeli": "viforeală",
    "viforelii": "viforeală",
    "viforelilor": "viforeală",
    "viforoasa": "viforos",
    "viforoasă": "viforos",
    "viforoase": "viforos",
    "viforoasei": "viforos",
    "viforoasele": "viforos",
    "viforoaselor": "viforos",
    "viforoși": "viforos",
    "viforoșii": "viforos",
    "viforoșilor": "viforos",
    "viforosul": "viforos",
    "viforosului": "viforos",
    "vigilenta": "vigilent",
    "vigilentă": "vigilent",
    "vigilente": "vigilent",
    "vigilentei": "vigilent",
    "vigilentele": "vigilent",
    "vigilentelor": "vigilent",
    "vigilenți": "vigilent",
    "vigilenții": "vigilent",
    "vigilenților": "vigilent",
    "vigilentul": "vigilent",
    "vigilentului": "vigilent",
    "vigilența": "vigilență",
    "vigilențe": "vigilență",
    "vigilenței": "vigilență",
    "vigilențele": "vigilență",
    "vigilențelor": "vigilență",
    "vigoarea": "vigoare",
    "vigori": "vigoare",
    "vigorii": "vigoare",
    "vigorile": "vigoare",
    "vigorilor": "vigoare",
    "viguroasa": "viguros",
    "viguroasă": "viguros",
    "viguroase": "viguros",
    "viguroasei": "viguros",
    "viguroasele": "viguros",
    "viguroaselor": "viguros",
    "viguroși": "viguros",
    "viguroșii": "viguros",
    "viguroșilor": "viguros",
    "vigurosul": "viguros",
    "vigurosului": "viguros",
    "viit.": "viitor",
    "viitoare": "viitor",
    "viitoarea": "viitor",
    "viitoarei": "viitor",
    "viitoarele": "viitor",
    "viitoarelor": "viitor",
    "viitori": "viitor",
    "viitorii": "viitor",
    "viitorilor": "viitor",
    "viitorul": "viitor",
    "viitorului": "viitor",
    "viitorimea": "viitorime",
    "viitorimi": "viitorime",
    "viitorimii": "viitorime",
    "viitorimile": "viitorime",
    "viitorimilor": "viitorime",
    "viitura": "viitură",
    "viituri": "viitură",
    "viiturii": "viitură",
    "viiturile": "viitură",
    "viiturilor": "viitură",
    "vijelia": "vijelie",
    "vijeliei": "vijelie",
    "vijelii": "vijelie",
    "vijeliile": "vijelie",
    "vijeliilor": "vijelie",
    "vijelioasa": "vijelios",
    "vijelioasă": "vijelios",
    "vijelioase": "vijelios",
    "vijelioasei": "vijelios",
    "vijelioasele": "vijelios",
    "vijelioaselor": "vijelios",
    "vijelioși": "vijelios",
    "vijelioșii": "vijelios",
    "vijelioșilor": "vijelios",
    "vijeliosul": "vijelios",
    "vijeliosului": "vijelios",
    "vila": "vilă",
    "vile": "vilă",
    "vilei": "vilă",
    "vilele": "vilă",
    "vilelor": "vilă",
    "vileagul": "vileag",
    "vileagului": "vileag",
    "vilegiatura": "vilegiatură",
    "vilegiaturi": "vilegiatură",
    "vilegiaturii": "vilegiatură",
    "vilegiaturile": "vilegiatură",
    "vilegiaturilor": "vilegiatură",
    "vilegiaturiști": "vilegiaturist",
    "vilegiaturiștii": "vilegiaturist",
    "vilegiaturiștilor": "vilegiaturist",
    "vilegiaturistul": "vilegiaturist",
    "vilegiaturistului": "vilegiaturist",
    "vilegiaturista": "vilegiaturistă",
    "vilegiaturiste": "vilegiaturistă",
    "vilegiaturistei": "vilegiaturistă",
    "vilegiaturistele": "vilegiaturistă",
    "vilegiaturistelor": "vilegiaturistă",
    "vilozitatea": "vilozitate",
    "vilozități": "vilozitate",
    "vilozității": "vilozitate",
    "vilozitățile": "vilozitate",
    "vilozităților": "vilozitate",
    "vinul": "vin",
    "vinului": "vin",
    "vinuri": "vin",
    "vinurile": "vin",
    "vinurilor": "vin",
    "vina": "vină",
    "vini": "vină",
    "vinii": "vină",
    "vinile": "vină",
    "vinilor": "vină",
    "vinăria": "vinărie",
    "vinăriei": "vinărie",
    "vinării": "vinărie",
    "vinăriile": "vinărie",
    "vinăriilor": "vinărie",
    "vinclul": "vinclu",
    "vinclului": "vinclu",
    "vincluri": "vinclu",
    "vinclurile": "vinclu",
    "vinclurilor": "vinclu",
    "nemaivânzând": "vinde",
    "nemaivânzându": "vinde",
    "nevânzând": "vinde",
    "nevânzându": "vinde",
    "vând": "vinde",
    "vândă": "vinde",
    "vându": "vinde",
    "vândui": "vinde",
    "vândură": "vinde",
    "vândurăm": "vinde",
    "vândurăți": "vinde",
    "vânduse": "vinde",
    "vândusem": "vinde",
    "vânduseră": "vinde",
    "vânduserăm": "vinde",
    "vânduserăți": "vinde",
    "vânduseși": "vinde",
    "vânduși": "vinde",
    "vândut": "vinde",
    "vânzând": "vinde",
    "vânzându": "vinde",
    "vindea": "vinde",
    "vindeai": "vinde",
    "vindeam": "vinde",
    "vindeați": "vinde",
    "vindeau": "vinde",
    "vindem": "vinde",
    "vindeți": "vinde",
    "vinzi": "vinde",
    "nemaivindecând": "vindeca",
    "nemaivindecându": "vindeca",
    "nevindecând": "vindeca",
    "nevindecându": "vindeca",
    "vindec": "vindeca",
    "vindecă": "vindeca",
    "vindecai": "vindeca",
    "vindecam": "vindeca",
    "vindecăm": "vindeca",
    "vindecând": "vindeca",
    "vindecându": "vindeca",
    "vindecară": "vindeca",
    "vindecarăm": "vindeca",
    "vindecarăți": "vindeca",
    "vindecase": "vindeca",
    "vindecasem": "vindeca",
    "vindecaseră": "vindeca",
    "vindecaserăm": "vindeca",
    "vindecaserăți": "vindeca",
    "vindecaseși": "vindeca",
    "vindecași": "vindeca",
    "vindecat": "vindeca",
    "vindecați": "vindeca",
    "vindecau": "vindeca",
    "vindece": "vindeca",
    "vindeci": "vindeca",
    "vindecabila": "vindecabil",
    "vindecabilă": "vindecabil",
    "vindecabile": "vindecabil",
    "vindecabilei": "vindecabil",
    "vindecabilele": "vindecabil",
    "vindecabilelor": "vindecabil",
    "vindecabili": "vindecabil",
    "vindecabilii": "vindecabil",
    "vindecabililor": "vindecabil",
    "vindecabilo": "vindecabil",
    "vindecabilul": "vindecabil",
    "vindecabilule": "vindecabil",
    "vindecabilului": "vindecabil",
    "vindecarea": "vindecare",
    "vindecareo": "vindecare",
    "vindecări": "vindecare",
    "vindecării": "vindecare",
    "vindecările": "vindecare",
    "vindecărilor": "vindecare",
    "vindecata": "vindecat",
    "vindecată": "vindecat",
    "vindecate": "vindecat",
    "vindecatei": "vindecat",
    "vindecatele": "vindecat",
    "vindecatelor": "vindecat",
    "vindecați": "vindecat",
    "vindecații": "vindecat",
    "vindecaților": "vindecat",
    "vindecato": "vindecat",
    "vindecatul": "vindecat",
    "vindecatule": "vindecat",
    "vindecatului": "vindecat",
    "vindecătoare": "vindecător",
    "vindecătoarea": "vindecător",
    "vindecătoarei": "vindecător",
    "vindecătoarele": "vindecător",
    "vindecătoarelor": "vindecător",
    "vindecători": "vindecător",
    "vindecătorii": "vindecător",
    "vindecătorilor": "vindecător",
    "vindecătorul": "vindecător",
    "vindecătorului": "vindecător",
    "vinderea": "vindere",
    "vinderi": "vindere",
    "vinderii": "vindere",
    "vinderile": "vindere",
    "vinderilor": "vindere",
    "V.": "vineri",
    "vinerea": "vineri",
    "vinerile": "vineri",
    "vinerilor": "vineri",
    "vineția": "vinețiu",
    "vineție": "vinețiu",
    "vineției": "vinețiu",
    "vineții": "vinețiu",
    "vinețiii": "vinețiu",
    "vinețiile": "vinețiu",
    "vinețiilor": "vinețiu",
    "vinețiul": "vinețiu",
    "vinețiului": "vinețiu",
    "vinifera": "vinifer",
    "viniferă": "vinifer",
    "vinifere": "vinifer",
    "viniferei": "vinifer",
    "viniferele": "vinifer",
    "viniferelor": "vinifer",
    "viniferi": "vinifer",
    "viniferii": "vinifer",
    "viniferilor": "vinifer",
    "viniferul": "vinifer",
    "viniferului": "vinifer",
    "vinișoara": "vinișoară",
    "vinișoare": "vinișoară",
    "vinișoarei": "vinișoară",
    "vinișoarele": "vinișoară",
    "vinișoarelor": "vinișoară",
    "vinovată": "vinovat",
    "vinovate": "vinovat",
    "vinovatei": "vinovat",
    "vinovatele": "vinovat",
    "vinovatelor": "vinovat",
    "vinovați": "vinovat",
    "vinovații": "vinovat",
    "vinovaților": "vinovat",
    "vinovatul": "vinovat",
    "vinovatului": "vinovat",
    "vinovate": "vinovată",
    "vinovatei": "vinovată",
    "vinovatele": "vinovată",
    "vinovatelor": "vinovată",
    "vinovatul": "vinovată",
    "vinovatului": "vinovată",
    "vinovăția": "vinovăție",
    "vinovăției": "vinovăție",
    "vinovății": "vinovăție",
    "vinovățiile": "vinovăție",
    "vinovățiilor": "vinovăție",
    "vintrea": "vintre",
    "vintrei": "vintre",
    "vintrele": "vintre",
    "vintrelor": "vintre",
    "vioara": "vioară",
    "viori": "vioară",
    "viorii": "vioară",
    "viorile": "vioară",
    "viorilor": "vioară",
    "vioaia": "vioi",
    "vioaie": "vioi",
    "vioaiei": "vioi",
    "vioaiele": "vioi",
    "vioaielor": "vioi",
    "vioiii": "vioi",
    "vioiilor": "vioi",
    "vioiul": "vioi",
    "vioiului": "vioi",
    "vioiciunea": "vioiciune",
    "vioiciuni": "vioiciune",
    "vioiciunii": "vioiciune",
    "vioiciunile": "vioiciune",
    "vioiciunilor": "vioiciune",
    "violul": "viol",
    "violului": "viol",
    "violuri": "viol",
    "violurile": "viol",
    "violurilor": "viol",
    "nemaiviolând": "viola",
    "nemaiviolându": "viola",
    "neviolând": "viola",
    "neviolându": "viola",
    "violă": "viola",
    "violai": "viola",
    "violam": "viola",
    "violăm": "viola",
    "violând": "viola",
    "violându": "viola",
    "violară": "viola",
    "violarăm": "viola",
    "violarăți": "viola",
    "violase": "viola",
    "violasem": "viola",
    "violaseră": "viola",
    "violaserăm": "viola",
    "violaserăți": "viola",
    "violaseși": "viola",
    "violași": "viola",
    "violat": "viola",
    "violați": "viola",
    "violau": "viola",
    "violează": "viola",
    "violez": "viola",
    "violeze": "viola",
    "violezi": "viola",
    "viola": "violă",
    "viole": "violă",
    "violei": "violă",
    "violele": "violă",
    "violelor": "violă",
    "violarea": "violare",
    "violareo": "violare",
    "violări": "violare",
    "violării": "violare",
    "violările": "violare",
    "violărilor": "violare",
    "violata": "violat",
    "violată": "violat",
    "violate": "violat",
    "violatei": "violat",
    "violatele": "violat",
    "violatelor": "violat",
    "violați": "violat",
    "violații": "violat",
    "violaților": "violat",
    "violato": "violat",
    "violatul": "violat",
    "violatule": "violat",
    "violatului": "violat",
    "violatori": "violator",
    "violatorii": "violator",
    "violatorilor": "violator",
    "violatorul": "violator",
    "violatorului": "violator",
    "violentă": "violent",
    "violente": "violent",
    "violentei": "violent",
    "violentele": "violent",
    "violentelor": "violent",
    "violenți": "violent",
    "violenții": "violent",
    "violenților": "violent",
    "violentul": "violent",
    "violentului": "violent",
    "nemaiviolentând": "violenta",
    "nemaiviolentându": "violenta",
    "neviolentând": "violenta",
    "neviolentându": "violenta",
    "violentă": "violenta",
    "violentai": "violenta",
    "violentam": "violenta",
    "violentăm": "violenta",
    "violentând": "violenta",
    "violentându": "violenta",
    "violentară": "violenta",
    "violentarăm": "violenta",
    "violentarăți": "violenta",
    "violentase": "violenta",
    "violentasem": "violenta",
    "violentaseră": "violenta",
    "violentaserăm": "violenta",
    "violentaserăți": "violenta",
    "violentaseși": "violenta",
    "violentași": "violenta",
    "violentat": "violenta",
    "violentați": "violenta",
    "violentau": "violenta",
    "violentează": "violenta",
    "violentez": "violenta",
    "violenteze": "violenta",
    "violentezi": "violenta",
    "violența": "violență",
    "violențe": "violență",
    "violenței": "violență",
    "violențele": "violență",
    "violențelor": "violență",
    "violentarea": "violentare",
    "violentareo": "violentare",
    "violentări": "violentare",
    "violentării": "violentare",
    "violentările": "violentare",
    "violentărilor": "violentare",
    "violentată": "violentat",
    "violentate": "violentat",
    "violentați": "violentat",
    "violeta": "violet",
    "violetă": "violet",
    "violete": "violet",
    "violetei": "violet",
    "violetele": "violet",
    "violetelor": "violet",
    "violeți": "violet",
    "violeții": "violet",
    "violeților": "violet",
    "violetul": "violet",
    "violetului": "violet",
    "violeta": "violetă",
    "violete": "violetă",
    "violetei": "violetă",
    "violetele": "violetă",
    "violetelor": "violetă",
    "violina": "violină",
    "violine": "violină",
    "violinei": "violină",
    "violinele": "violină",
    "violinelor": "violină",
    "violoncele": "violoncel",
    "violoncelele": "violoncel",
    "violoncelelor": "violoncel",
    "violoncelul": "violoncel",
    "violoncelului": "violoncel",
    "violoniști": "violonist",
    "violoniștii": "violonist",
    "violoniștilor": "violonist",
    "violonistul": "violonist",
    "violonistului": "violonist",
    "vioreaua": "viorea",
    "viorele": "viorea",
    "viorelei": "viorea",
    "viorelele": "viorea",
    "viorelelor": "viorea",
    "vioriști": "viorist",
    "vioriștii": "viorist",
    "vioriștilor": "viorist",
    "vioristul": "viorist",
    "vioristului": "viorist",
    "viorista": "vioristă",
    "vioriste": "vioristă",
    "vioristei": "vioristă",
    "vioristele": "vioristă",
    "vioristelor": "vioristă",
    "vioria": "vioriu",
    "viorie": "vioriu",
    "vioriei": "vioriu",
    "viorii": "vioriu",
    "vioriii": "vioriu",
    "vioriile": "vioriu",
    "vioriilor": "vioriu",
    "vioriul": "vioriu",
    "vioriului": "vioriu",
    "vipera": "viperă",
    "vipere": "viperă",
    "viperei": "viperă",
    "viperele": "viperă",
    "viperelor": "viperă",
    "vipla": "viplă",
    "viple": "viplă",
    "viplei": "viplă",
    "viplele": "viplă",
    "viplelor": "viplă",
    "vipușca": "vipușcă",
    "vipuști": "vipușcă",
    "vipuștile": "vipușcă",
    "vipuștilor": "vipușcă",
    "nemaivirând": "vira",
    "nemaivirându": "vira",
    "nevirând": "vira",
    "nevirându": "vira",
    "viră": "vira",
    "virai": "vira",
    "viram": "vira",
    "virăm": "vira",
    "virând": "vira",
    "virându": "vira",
    "virară": "vira",
    "virarăm": "vira",
    "virarăți": "vira",
    "virase": "vira",
    "virasem": "vira",
    "viraseră": "vira",
    "viraserăm": "vira",
    "viraserăți": "vira",
    "viraseși": "vira",
    "virași": "vira",
    "virat": "vira",
    "virați": "vira",
    "virau": "vira",
    "virează": "vira",
    "virez": "vira",
    "vireze": "vira",
    "virezi": "vira",
    "virată": "virat",
    "virate": "virat",
    "virați": "virat",
    "V.": "Virgil",
    "virgina": "virgin",
    "virgină": "virgin",
    "virgine": "virgin",
    "virginei": "virgin",
    "virginele": "virgin",
    "virginelor": "virgin",
    "virgini": "virgin",
    "virginii": "virgin",
    "virginilor": "virgin",
    "virginul": "virgin",
    "virginului": "virgin",
    "virgula": "virgulă",
    "virgule": "virgulă",
    "virgulei": "virgulă",
    "virgulele": "virgulă",
    "virgulelor": "virgulă",
    "virila": "viril",
    "virilă": "viril",
    "virile": "viril",
    "virilei": "viril",
    "virilele": "viril",
    "virilelor": "viril",
    "virili": "viril",
    "virilii": "viril",
    "virililor": "viril",
    "virilul": "viril",
    "virilului": "viril",
    "virilitatea": "virilitate",
    "virilități": "virilitate",
    "virilității": "virilitate",
    "virilitățile": "virilitate",
    "virilităților": "virilitate",
    "virtuala": "virtual",
    "virtuală": "virtual",
    "virtuale": "virtual",
    "virtualei": "virtual",
    "virtualele": "virtual",
    "virtualelor": "virtual",
    "virtuali": "virtual",
    "virtualii": "virtual",
    "virtualilor": "virtual",
    "virtualul": "virtual",
    "virtualului": "virtual",
    "virtualitatea": "virtualitate",
    "virtualități": "virtualitate",
    "virtualității": "virtualitate",
    "virtualitățile": "virtualitate",
    "virtualităților": "virtualitate",
    "virtuoasa": "virtuos",
    "virtuoasă": "virtuos",
    "virtuoase": "virtuos",
    "virtuoasei": "virtuos",
    "virtuoasele": "virtuos",
    "virtuoaselor": "virtuos",
    "virtuoși": "virtuos",
    "virtuoșii": "virtuos",
    "virtuoșilor": "virtuos",
    "virtuosul": "virtuos",
    "virtuosului": "virtuos",
    "virtuozitatea": "virtuozitate",
    "virtuozități": "virtuozitate",
    "virtuozității": "virtuozitate",
    "virtuozitățile": "virtuozitate",
    "virtuozităților": "virtuozitate",
    "virtutea": "virtute",
    "virtuți": "virtute",
    "virtuții": "virtute",
    "virtuțile": "virtute",
    "virtuților": "virtute",
    "virulențe": "virulent",
    "virulenței": "virulent",
    "virulențele": "virulent",
    "virulențelor": "virulent",
    "virulenți": "virulent",
    "virulenții": "virulent",
    "virulenților": "virulent",
    "virulentul": "virulent",
    "virulentului": "virulent",
    "virulenta": "virulentă",
    "virulente": "virulentă",
    "virulentei": "virulentă",
    "virulentele": "virulentă",
    "virulentelor": "virulentă",
    "viruși": "virus",
    "virusul": "virus",
    "virusului": "virus",
    "virusuri": "virus",
    "virusurile": "virus",
    "virusurilor": "virus",
    "vise": "vis",
    "visele": "vis",
    "viselor": "vis",
    "visu'": "vis",
    "visul": "vis",
    "visului": "vis",
    "visuri": "vis",
    "visurile": "vis",
    "visurilor": "vis",
    "nemaivisând": "visa",
    "nemaivisându": "visa",
    "nevisând": "visa",
    "nevisându": "visa",
    "visă": "visa",
    "visai": "visa",
    "visam": "visa",
    "visăm": "visa",
    "visând": "visa",
    "visându": "visa",
    "visară": "visa",
    "visarăm": "visa",
    "visarăți": "visa",
    "visase": "visa",
    "visasem": "visa",
    "visaseră": "visa",
    "visaserăm": "visa",
    "visaserăți": "visa",
    "visaseși": "visa",
    "visași": "visa",
    "visat": "visa",
    "visați": "visa",
    "visau": "visa",
    "visează": "visa",
    "visez": "visa",
    "viseze": "visa",
    "visezi": "visa",
    "visarea": "visare",
    "visareo": "visare",
    "visări": "visare",
    "visării": "visare",
    "visările": "visare",
    "visărilor": "visare",
    "visata": "visat",
    "visată": "visat",
    "visate": "visat",
    "visatei": "visat",
    "visatele": "visat",
    "visatelor": "visat",
    "visați": "visat",
    "visații": "visat",
    "visaților": "visat",
    "visato": "visat",
    "visatul": "visat",
    "visatule": "visat",
    "visatului": "visat",
    "visătoare": "visător",
    "visătoarea": "visător",
    "visătoarei": "visător",
    "visătoarele": "visător",
    "visătoarelor": "visător",
    "visătoareo": "visător",
    "visători": "visător",
    "visătorii": "visător",
    "visătorilor": "visător",
    "visătorul": "visător",
    "visătorule": "visător",
    "visătorului": "visător",
    "viscerala": "visceral",
    "viscerală": "visceral",
    "viscerale": "visceral",
    "visceralei": "visceral",
    "visceralele": "visceral",
    "visceralelor": "visceral",
    "viscerali": "visceral",
    "visceralii": "visceral",
    "visceralilor": "visceral",
    "visceralul": "visceral",
    "visceralului": "visceral",
    "viscerele": "viscere",
    "viscerelor": "viscere",
    "viscole": "viscol",
    "viscolele": "viscol",
    "viscolelor": "viscol",
    "viscolul": "viscol",
    "viscolului": "viscol",
    "nemaiviscolind": "viscoli",
    "nemaiviscolindu": "viscoli",
    "neviscolind": "viscoli",
    "neviscolindu": "viscoli",
    "viscolea": "viscoli",
    "viscoleai": "viscoli",
    "viscoleam": "viscoli",
    "viscolească": "viscoli",
    "viscoleați": "viscoli",
    "viscoleau": "viscoli",
    "viscolesc": "viscoli",
    "viscolește": "viscoli",
    "viscolești": "viscoli",
    "viscolii": "viscoli",
    "viscolim": "viscoli",
    "viscolind": "viscoli",
    "viscolindu": "viscoli",
    "viscoliră": "viscoli",
    "viscolirăm": "viscoli",
    "viscolirăți": "viscoli",
    "viscolise": "viscoli",
    "viscolisem": "viscoli",
    "viscoliseră": "viscoli",
    "viscoliserăm": "viscoli",
    "viscoliserăți": "viscoli",
    "viscoliseși": "viscoli",
    "viscoliși": "viscoli",
    "viscolit": "viscoli",
    "viscoliți": "viscoli",
    "viscolirea": "viscolire",
    "viscolireo": "viscolire",
    "viscoliri": "viscolire",
    "viscolirii": "viscolire",
    "viscolirile": "viscolire",
    "viscolirilor": "viscolire",
    "viscolita": "viscolit",
    "viscolită": "viscolit",
    "viscolite": "viscolit",
    "viscolitei": "viscolit",
    "viscolitele": "viscolit",
    "viscolitelor": "viscolit",
    "viscoliți": "viscolit",
    "viscoliții": "viscolit",
    "viscoliților": "viscolit",
    "viscolito": "viscolit",
    "viscolitul": "viscolit",
    "viscolitule": "viscolit",
    "viscolitului": "viscolit",
    "viscolită": "viscolitor",
    "viscolitoare": "viscolitor",
    "viscolitoarea": "viscolitor",
    "viscolitoarei": "viscolitor",
    "viscolitoarele": "viscolitor",
    "viscolitoarelor": "viscolitor",
    "viscolitoareo": "viscolitor",
    "viscolitori": "viscolitor",
    "viscolitorii": "viscolitor",
    "viscolitorilor": "viscolitor",
    "viscolitorul": "viscolitor",
    "viscolitorule": "viscolitor",
    "viscolitorului": "viscolitor",
    "viscoloasa": "viscolos",
    "viscoloasă": "viscolos",
    "viscoloase": "viscolos",
    "viscoloasei": "viscolos",
    "viscoloasele": "viscolos",
    "viscoloaselor": "viscolos",
    "viscoloși": "viscolos",
    "viscoloșii": "viscolos",
    "viscoloșilor": "viscolos",
    "viscolosul": "viscolos",
    "viscolosului": "viscolos",
    "vișini": "vișin",
    "vișinii": "vișin",
    "vișinilor": "vișin",
    "vișinul": "vișin",
    "vișinului": "vișin",
    "vișina": "vișină",
    "vișine": "vișină",
    "vișinei": "vișină",
    "vișinata": "vișinată",
    "vișinate": "vișinată",
    "vișinatei": "vișinată",
    "vișinatele": "vișinată",
    "vișinatelor": "vișinată",
    "vișinia": "vișiniu",
    "vișiniei": "vișiniu",
    "vișinii": "vișiniu",
    "vișiniii": "vișiniu",
    "vișiniile": "vișiniu",
    "vișiniilor": "vișiniu",
    "vișiniul": "vișiniu",
    "vișiniului": "vișiniu",
    "visteria": "visterie",
    "visteriei": "visterie",
    "visterii": "visterie",
    "visteriile": "visterie",
    "visteriilor": "visterie",
    "visternicia": "visternicie",
    "visterniciei": "visternicie",
    "visternicii": "visternicie",
    "visterniciile": "visternicie",
    "visterniciilor": "visternicie",
    "vistieri": "vistier",
    "vistierii": "vistier",
    "vistierilor": "vistier",
    "vistierul": "vistier",
    "vistierului": "vistier",
    "vistieria": "vistierie",
    "vistieriei": "vistierie",
    "vistierii": "vistierie",
    "vistieriile": "vistierie",
    "vistieriilor": "vistierie",
    "vistiernici": "vistiernic",
    "vistiernicii": "vistiernic",
    "vistiernicilor": "vistiernic",
    "vistiernicul": "vistiernic",
    "vistiernicului": "vistiernic",
    "vita": "vită",
    "vite": "vită",
    "vitei": "vită",
    "vitele": "vită",
    "vitelor": "vită",
    "vița": "viță",
    "vițe": "viță",
    "viței": "viță",
    "vițele": "viță",
    "vițelor": "viță",
    "vitala": "vital",
    "vitală": "vital",
    "vitale": "vital",
    "vitalei": "vital",
    "vitalele": "vital",
    "vitalelor": "vital",
    "vitali": "vital",
    "vitalii": "vital",
    "vitalilor": "vital",
    "vitalul": "vital",
    "vitalului": "vital",
    "vitalitatea": "vitalitate",
    "vitalități": "vitalitate",
    "vitalității": "vitalitate",
    "vitalitățile": "vitalitate",
    "vitalităților": "vitalitate",
    "vitamina": "vitamină",
    "vitamine": "vitamină",
    "vitaminei": "vitamină",
    "vitaminele": "vitamină",
    "vitaminelor": "vitamină",
    "viteaza": "viteaz",
    "vitează": "viteaz",
    "viteazul": "viteaz",
    "viteazului": "viteaz",
    "viteji": "viteaz",
    "vitejii": "viteaz",
    "vitejilor": "viteaz",
    "viteze": "viteaz",
    "vitezei": "viteaz",
    "vitezele": "viteaz",
    "vitezelor": "viteaz",
    "vitejia": "vitejie",
    "vitejiei": "vitejie",
    "vitejii": "vitejie",
    "vitejiile": "vitejie",
    "vitejiilor": "vitejie",
    "viței": "vițel",
    "vițeii": "vițel",
    "vițeilor": "vițel",
    "vițelul": "vițel",
    "vițelului": "vițel",
    "vițelari": "vițelar",
    "vițelarii": "vițelar",
    "vițelarilor": "vițelar",
    "vițelarul": "vițelar",
    "vițelarului": "vițelar",
    "vitelina": "vitelină",
    "viteline": "vitelină",
    "vitelinei": "vitelină",
    "vitelinele": "vitelină",
    "vitelinelor": "vitelină",
    "vițeluși": "vițeluș",
    "vițelușii": "vițeluș",
    "vițelușilor": "vițeluș",
    "vițelușul": "vițeluș",
    "vițelușului": "vițeluș",
    "vițelușa": "vițelușă",
    "vițelușe": "vițelușă",
    "vițelușei": "vițelușă",
    "vițelușele": "vițelușă",
    "vițelușelor": "vițelușă",
    "viteza": "viteză",
    "viteze": "viteză",
    "vitezei": "viteză",
    "vitezele": "viteză",
    "vitezelor": "viteză",
    "vitezometre": "vitezometru",
    "vitezometrele": "vitezometru",
    "vitezometrelor": "vitezometru",
    "vitezometrul": "vitezometru",
    "vitezometrului": "vitezometru",
    "viticola": "viticol",
    "viticolă": "viticol",
    "viticole": "viticol",
    "viticolei": "viticol",
    "viticolele": "viticol",
    "viticolelor": "viticol",
    "viticoli": "viticol",
    "viticolii": "viticol",
    "viticolilor": "viticol",
    "viticolul": "viticol",
    "viticolului": "viticol",
    "viticultori": "viticultor",
    "viticultorii": "viticultor",
    "viticultorilor": "viticultor",
    "viticultorul": "viticultor",
    "viticultorului": "viticultor",
    "viticultura": "viticultură",
    "viticulturi": "viticultură",
    "viticulturii": "viticultură",
    "viticulturile": "viticultură",
    "viticulturilor": "viticultură",
    "vitralii": "vitraliu",
    "vitraliile": "vitraliu",
    "vitraliilor": "vitraliu",
    "vitraliul": "vitraliu",
    "vitraliului": "vitraliu",
    "vitrega": "vitreg",
    "vitregă": "vitreg",
    "vitrege": "vitreg",
    "vitregei": "vitreg",
    "vitregele": "vitreg",
    "vitregelor": "vitreg",
    "vitregi": "vitreg",
    "vitregii": "vitreg",
    "vitregilor": "vitreg",
    "vitregul": "vitreg",
    "vitregului": "vitreg",
    "vitregita": "vitregit",
    "vitregită": "vitregit",
    "vitregite": "vitregit",
    "vitregitei": "vitregit",
    "vitregitele": "vitregit",
    "vitregitelor": "vitregit",
    "vitregiți": "vitregit",
    "vitregiții": "vitregit",
    "vitregiților": "vitregit",
    "vitregitul": "vitregit",
    "vitregitului": "vitregit",
    "nemaivitrificând": "vitrifica",
    "nemaivitrificându": "vitrifica",
    "nevitrificând": "vitrifica",
    "nevitrificându": "vitrifica",
    "vitrific": "vitrifica",
    "vitrifică": "vitrifica",
    "vitrificai": "vitrifica",
    "vitrificam": "vitrifica",
    "vitrificăm": "vitrifica",
    "vitrificând": "vitrifica",
    "vitrificându": "vitrifica",
    "vitrificară": "vitrifica",
    "vitrificarăm": "vitrifica",
    "vitrificarăți": "vitrifica",
    "vitrificase": "vitrifica",
    "vitrificasem": "vitrifica",
    "vitrificaseră": "vitrifica",
    "vitrificaserăm": "vitrifica",
    "vitrificaserăți": "vitrifica",
    "vitrificaseși": "vitrifica",
    "vitrificași": "vitrifica",
    "vitrificat": "vitrifica",
    "vitrificați": "vitrifica",
    "vitrificau": "vitrifica",
    "vitrifice": "vitrifica",
    "vitrifici": "vitrifica",
    "vitrificarea": "vitrificare",
    "vitrificareo": "vitrificare",
    "vitrificări": "vitrificare",
    "vitrificării": "vitrificare",
    "vitrificările": "vitrificare",
    "vitrificărilor": "vitrificare",
    "vitrificată": "vitrificat",
    "vitrificate": "vitrificat",
    "vitrificați": "vitrificat",
    "vitrina": "vitrină",
    "vitrine": "vitrină",
    "vitrinei": "vitrină",
    "vitrinele": "vitrină",
    "vitrinelor": "vitrină",
    "vitriolul": "vitriol",
    "vitriolului": "vitriol",
    "vitrioluri": "vitriol",
    "vitriolurile": "vitriol",
    "vitriolurilor": "vitriol",
    "via": "viu",
    "vie": "viu",
    "viei": "viu",
    "viele": "viu",
    "vii": "viu",
    "viii": "viu",
    "viilor": "viu",
    "viul": "viu",
    "viului": "viu",
    "vivacitatea": "vivacitate",
    "vivacități": "vivacitate",
    "vivacității": "vivacitate",
    "vivacitățile": "vivacitate",
    "vivacităților": "vivacitate",
    "vivisecția": "vivisecție",
    "vivisecției": "vivisecție",
    "vivisecții": "vivisecție",
    "vivisecțiile": "vivisecție",
    "vivisecțiilor": "vivisecție",
    "nemaivizând": "viza",
    "nemaivizându": "viza",
    "nevizând": "viza",
    "nevizându": "viza",
    "viză": "viza",
    "vizai": "viza",
    "vizam": "viza",
    "vizăm": "viza",
    "vizând": "viza",
    "vizându": "viza",
    "vizară": "viza",
    "vizarăm": "viza",
    "vizarăți": "viza",
    "vizase": "viza",
    "vizasem": "viza",
    "vizaseră": "viza",
    "vizaserăm": "viza",
    "vizaserăți": "viza",
    "vizaseși": "viza",
    "vizași": "viza",
    "vizat": "viza",
    "vizați": "viza",
    "vizau": "viza",
    "vizează": "viza",
    "vizez": "viza",
    "vizeze": "viza",
    "vizezi": "viza",
    "viza": "viză",
    "vize": "viză",
    "vizei": "viză",
    "vizele": "viză",
    "vizelor": "viză",
    "vizată": "vizat",
    "vizate": "vizat",
    "vizați": "vizat",
    "vizeta": "vizetă",
    "vizete": "vizetă",
    "vizetei": "vizetă",
    "vizetele": "vizetă",
    "vizetelor": "vizetă",
    "vizibila": "vizibil",
    "vizibilă": "vizibil",
    "vizibile": "vizibil",
    "vizibilei": "vizibil",
    "vizibilele": "vizibil",
    "vizibilelor": "vizibil",
    "vizibili": "vizibil",
    "vizibilii": "vizibil",
    "vizibililor": "vizibil",
    "vizibilul": "vizibil",
    "vizibilului": "vizibil",
    "vizibilitatea": "vizibilitate",
    "vizibilități": "vizibilitate",
    "vizibilității": "vizibilitate",
    "vizibilitățile": "vizibilitate",
    "vizibilităților": "vizibilitate",
    "viziera": "vizieră",
    "viziere": "vizieră",
    "vizierei": "vizieră",
    "vizierele": "vizieră",
    "vizierelor": "vizieră",
    "nemaivizionând": "viziona",
    "nemaivizionându": "viziona",
    "nevizionând": "viziona",
    "nevizionându": "viziona",
    "vizionă": "viziona",
    "vizionai": "viziona",
    "vizionam": "viziona",
    "vizionăm": "viziona",
    "vizionând": "viziona",
    "vizionându": "viziona",
    "vizionară": "viziona",
    "vizionarăm": "viziona",
    "vizionarăți": "viziona",
    "vizionase": "viziona",
    "vizionasem": "viziona",
    "vizionaseră": "viziona",
    "vizionaserăm": "viziona",
    "vizionaserăți": "viziona",
    "vizionaseși": "viziona",
    "vizionași": "viziona",
    "vizionat": "viziona",
    "vizionați": "viziona",
    "vizionau": "viziona",
    "vizionează": "viziona",
    "vizionez": "viziona",
    "vizioneze": "viziona",
    "vizionezi": "viziona",
    "vizionarea": "vizionare",
    "vizionareo": "vizionare",
    "vizionări": "vizionare",
    "vizionării": "vizionare",
    "vizionările": "vizionare",
    "vizionărilor": "vizionare",
    "vizionată": "vizionat",
    "vizionate": "vizionat",
    "vizionați": "vizionat",
    "nemaivizitând": "vizita",
    "nemaivizitându": "vizita",
    "nevizitând": "vizita",
    "nevizitându": "vizita",
    "vizită": "vizita",
    "vizitai": "vizita",
    "vizitam": "vizita",
    "vizităm": "vizita",
    "vizitând": "vizita",
    "vizitându": "vizita",
    "vizitară": "vizita",
    "vizitarăm": "vizita",
    "vizitarăți": "vizita",
    "vizitase": "vizita",
    "vizitasem": "vizita",
    "vizitaseră": "vizita",
    "vizitaserăm": "vizita",
    "vizitaserăți": "vizita",
    "vizitaseși": "vizita",
    "vizitași": "vizita",
    "vizitat": "vizita",
    "vizitați": "vizita",
    "vizitau": "vizita",
    "vizitează": "vizita",
    "vizitez": "vizita",
    "viziteze": "vizita",
    "vizitezi": "vizita",
    "vizita": "vizită",
    "vizite": "vizită",
    "vizitei": "vizită",
    "vizitele": "vizită",
    "vizitelor": "vizită",
    "vizitarea": "vizitare",
    "vizitareo": "vizitare",
    "vizitări": "vizitare",
    "vizitării": "vizitare",
    "vizitările": "vizitare",
    "vizitărilor": "vizitare",
    "vizitata": "vizitat",
    "vizitată": "vizitat",
    "vizitate": "vizitat",
    "vizitatei": "vizitat",
    "vizitatele": "vizitat",
    "vizitatelor": "vizitat",
    "vizitați": "vizitat",
    "vizitații": "vizitat",
    "vizitaților": "vizitat",
    "vizitato": "vizitat",
    "vizitatul": "vizitat",
    "vizitatule": "vizitat",
    "vizitatului": "vizitat",
    "vizitatori": "vizitator",
    "vizitatorii": "vizitator",
    "vizitatorilor": "vizitator",
    "vizitatorul": "vizitator",
    "vizitatorului": "vizitator",
    "vizitii": "vizitiu",
    "vizitiii": "vizitiu",
    "vizitiilor": "vizitiu",
    "vizitiul": "vizitiu",
    "vizitiului": "vizitiu",
    "viziunea": "viziune",
    "viziuni": "viziune",
    "viziunii": "viziune",
    "viziunile": "viziune",
    "viziunilor": "viziune",
    "vizoni": "vizon",
    "vizonii": "vizon",
    "vizonilor": "vizon",
    "vizonul": "vizon",
    "vizonului": "vizon",
    "vizoare": "vizor",
    "vizoarele": "vizor",
    "vizoarelor": "vizor",
    "vizorul": "vizor",
    "vizorului": "vizor",
    "vizuala": "vizual",
    "vizuală": "vizual",
    "vizuale": "vizual",
    "vizualei": "vizual",
    "vizualele": "vizual",
    "vizualelor": "vizual",
    "vizuali": "vizual",
    "vizualii": "vizual",
    "vizualilor": "vizual",
    "vizualul": "vizual",
    "vizualului": "vizual",
    "vizualitatea": "vizualitate",
    "vizualități": "vizualitate",
    "vizualității": "vizualitate",
    "vizualitățile": "vizualitate",
    "vizualităților": "vizualitate",
    "nemaivizualizând": "vizualiza",
    "nemaivizualizându": "vizualiza",
    "nevizualizând": "vizualiza",
    "nevizualizându": "vizualiza",
    "vizualiză": "vizualiza",
    "vizualizai": "vizualiza",
    "vizualizam": "vizualiza",
    "vizualizăm": "vizualiza",
    "vizualizând": "vizualiza",
    "vizualizându": "vizualiza",
    "vizualizară": "vizualiza",
    "vizualizarăm": "vizualiza",
    "vizualizarăți": "vizualiza",
    "vizualizase": "vizualiza",
    "vizualizasem": "vizualiza",
    "vizualizaseră": "vizualiza",
    "vizualizaserăm": "vizualiza",
    "vizualizaserăți": "vizualiza",
    "vizualizaseși": "vizualiza",
    "vizualizași": "vizualiza",
    "vizualizat": "vizualiza",
    "vizualizați": "vizualiza",
    "vizualizau": "vizualiza",
    "vizualizează": "vizualiza",
    "vizualizez": "vizualiza",
    "vizualizeze": "vizualiza",
    "vizualizezi": "vizualiza",
    "vizualizată": "vizualizat",
    "vizualizate": "vizualizat",
    "vizualizați": "vizualizat",
    "vizuina": "vizuină",
    "vizuine": "vizuină",
    "vizuinei": "vizuină",
    "vizuinele": "vizuină",
    "vizuinelor": "vizuină",
    "vlădica": "vlădică",
    "vlădicăi": "vlădică",
    "vlădici": "vlădică",
    "vlădicii": "vlădică",
    "vlădicilor": "vlădică",
    "nemaivlăguind": "vlăgui",
    "nemaivlăguindu": "vlăgui",
    "nevlăguind": "vlăgui",
    "nevlăguindu": "vlăgui",
    "vlăguia": "vlăgui",
    "vlăguiai": "vlăgui",
    "vlăguiam": "vlăgui",
    "vlăguiască": "vlăgui",
    "vlăguiați": "vlăgui",
    "vlăguiau": "vlăgui",
    "vlăguiesc": "vlăgui",
    "vlăguiește": "vlăgui",
    "vlăguiești": "vlăgui",
    "vlăguii": "vlăgui",
    "vlăguim": "vlăgui",
    "vlăguind": "vlăgui",
    "vlăguindu": "vlăgui",
    "vlăguiră": "vlăgui",
    "vlăguirăm": "vlăgui",
    "vlăguirăți": "vlăgui",
    "vlăguise": "vlăgui",
    "vlăguisem": "vlăgui",
    "vlăguiseră": "vlăgui",
    "vlăguiserăm": "vlăgui",
    "vlăguiserăți": "vlăgui",
    "vlăguiseși": "vlăgui",
    "vlăguiși": "vlăgui",
    "vlăguit": "vlăgui",
    "vlăguiți": "vlăgui",
    "vlăguirea": "vlăguire",
    "vlăguiri": "vlăguire",
    "vlăguirii": "vlăguire",
    "vlăguirile": "vlăguire",
    "vlăguirilor": "vlăguire",
    "vlăguita": "vlăguit",
    "vlăguită": "vlăguit",
    "vlăguite": "vlăguit",
    "vlăguitei": "vlăguit",
    "vlăguitele": "vlăguit",
    "vlăguitelor": "vlăguit",
    "vlăguiți": "vlăguit",
    "vlăguiții": "vlăguit",
    "vlăguiților": "vlăguit",
    "vlăguito": "vlăguit",
    "vlăguitul": "vlăguit",
    "vlăguitule": "vlăguit",
    "vlăguitului": "vlăguit",
    "vlăguitoare": "vlăguitor",
    "vlăguitoarea": "vlăguitor",
    "vlăguitoarei": "vlăguitor",
    "vlăguitoarele": "vlăguitor",
    "vlăguitoarelor": "vlăguitor",
    "vlăguitoareo": "vlăguitor",
    "vlăguitori": "vlăguitor",
    "vlăguitorii": "vlăguitor",
    "vlăguitorilor": "vlăguitor",
    "vlăguitorul": "vlăguitor",
    "vlăguitorule": "vlăguitor",
    "vlăguitorului": "vlăguitor",
    "vlăstare": "vlăstar",
    "vlăstarele": "vlăstar",
    "vlăstarelor": "vlăstar",
    "vlăstarul": "vlăstar",
    "vlăstarului": "vlăstar",
    "voalul": "voal",
    "voalului": "voal",
    "voaluri": "voal",
    "voalurile": "voal",
    "voalurilor": "voal",
    "nemaivoalând": "voala",
    "nemaivoalându": "voala",
    "nevoalând": "voala",
    "nevoalându": "voala",
    "voală": "voala",
    "voalai": "voala",
    "voalam": "voala",
    "voalăm": "voala",
    "voalând": "voala",
    "voalându": "voala",
    "voalară": "voala",
    "voalarăm": "voala",
    "voalarăți": "voala",
    "voalase": "voala",
    "voalasem": "voala",
    "voalaseră": "voala",
    "voalaserăm": "voala",
    "voalaserăți": "voala",
    "voalaseși": "voala",
    "voalași": "voala",
    "voalat": "voala",
    "voalați": "voala",
    "voalau": "voala",
    "voalează": "voala",
    "voalez": "voala",
    "voaleze": "voala",
    "voalezi": "voala",
    "voalarea": "voalare",
    "voalareo": "voalare",
    "voalări": "voalare",
    "voalării": "voalare",
    "voalările": "voalare",
    "voalărilor": "voalare",
    "voalata": "voalat",
    "voalată": "voalat",
    "voalate": "voalat",
    "voalatei": "voalat",
    "voalatele": "voalat",
    "voalatelor": "voalat",
    "voalați": "voalat",
    "voalații": "voalat",
    "voalaților": "voalat",
    "voalato": "voalat",
    "voalatul": "voalat",
    "voalatule": "voalat",
    "voalatului": "voalat",
    "voaleta": "voaletă",
    "voalete": "voaletă",
    "voaletei": "voaletă",
    "voaletele": "voaletă",
    "voaletelor": "voaletă",
    "vocabula": "vocabulă",
    "vocabule": "vocabulă",
    "vocabulei": "vocabulă",
    "vocabulele": "vocabulă",
    "vocabulelor": "vocabulă",
    "vocabulare": "vocabular",
    "vocabularele": "vocabular",
    "vocabularelor": "vocabular",
    "vocabularul": "vocabular",
    "vocabularului": "vocabular",
    "vocala": "vocală",
    "vocale": "vocală",
    "vocalei": "vocală",
    "vocalele": "vocală",
    "vocalelor": "vocală",
    "vocalica": "vocalic",
    "vocalică": "vocalic",
    "vocalice": "vocalic",
    "vocalicei": "vocalic",
    "vocalicele": "vocalic",
    "vocalicelor": "vocalic",
    "vocalici": "vocalic",
    "vocalicii": "vocalic",
    "vocalicilor": "vocalic",
    "vocalicul": "vocalic",
    "vocalicului": "vocalic",
    "vocalisme": "vocalism",
    "vocalismele": "vocalism",
    "vocalismelor": "vocalism",
    "vocalismul": "vocalism",
    "vocalismului": "vocalism",
    "nemaivocalizând": "vocaliza",
    "nemaivocalizându": "vocaliza",
    "nevocalizând": "vocaliza",
    "nevocalizându": "vocaliza",
    "vocaliză": "vocaliza",
    "vocalizai": "vocaliza",
    "vocalizam": "vocaliza",
    "vocalizăm": "vocaliza",
    "vocalizând": "vocaliza",
    "vocalizându": "vocaliza",
    "vocalizară": "vocaliza",
    "vocalizarăm": "vocaliza",
    "vocalizarăți": "vocaliza",
    "vocalizase": "vocaliza",
    "vocalizasem": "vocaliza",
    "vocalizaseră": "vocaliza",
    "vocalizaserăm": "vocaliza",
    "vocalizaserăți": "vocaliza",
    "vocalizaseși": "vocaliza",
    "vocalizași": "vocaliza",
    "vocalizat": "vocaliza",
    "vocalizați": "vocaliza",
    "vocalizau": "vocaliza",
    "vocalizează": "vocaliza",
    "vocalizez": "vocaliza",
    "vocalizeze": "vocaliza",
    "vocalizezi": "vocaliza",
    "vocaliza": "vocaliză",
    "vocalize": "vocaliză",
    "vocalizei": "vocaliză",
    "vocalizele": "vocaliză",
    "vocalizelor": "vocaliză",
    "vocalizarea": "vocalizare",
    "vocalizareo": "vocalizare",
    "vocalizări": "vocalizare",
    "vocalizării": "vocalizare",
    "vocalizările": "vocalizare",
    "vocalizărilor": "vocalizare",
    "vocalizată": "vocalizat",
    "vocalizate": "vocalizat",
    "vocalizați": "vocalizat",
    "vocația": "vocație",
    "vocației": "vocație",
    "vocații": "vocație",
    "vocațiile": "vocație",
    "vocațiilor": "vocație",
    "voc.": "vocativ",
    "vocative": "vocativ",
    "vocativele": "vocativ",
    "vocativelor": "vocativ",
    "vocativul": "vocativ",
    "vocativului": "vocativ",
    "vocea": "voce",
    "voci": "voce",
    "vocii": "voce",
    "vocile": "voce",
    "vocilor": "voce",
    "nemaivociferând": "vocifera",
    "nemaivociferându": "vocifera",
    "nevociferând": "vocifera",
    "nevociferându": "vocifera",
    "vociferă": "vocifera",
    "vociferai": "vocifera",
    "vociferam": "vocifera",
    "vociferăm": "vocifera",
    "vociferând": "vocifera",
    "vociferându": "vocifera",
    "vociferară": "vocifera",
    "vociferarăm": "vocifera",
    "vociferarăți": "vocifera",
    "vociferase": "vocifera",
    "vociferasem": "vocifera",
    "vociferaseră": "vocifera",
    "vociferaserăm": "vocifera",
    "vociferaserăți": "vocifera",
    "vociferaseși": "vocifera",
    "vociferași": "vocifera",
    "vociferat": "vocifera",
    "vociferați": "vocifera",
    "vociferau": "vocifera",
    "vociferează": "vocifera",
    "vociferez": "vocifera",
    "vocifereze": "vocifera",
    "vociferezi": "vocifera",
    "vociferarea": "vociferare",
    "vociferareo": "vociferare",
    "vociferări": "vociferare",
    "vociferării": "vociferare",
    "vociferările": "vociferare",
    "vociferărilor": "vociferare",
    "vociferată": "vociferat",
    "vociferate": "vociferat",
    "vociferați": "vociferat",
    "vodca": "vodcă",
    "vodci": "vodcă",
    "vodcii": "vodcă",
    "vodcile": "vodcă",
    "vodcilor": "vodcă",
    "vodevilul": "vodevil",
    "vodevilului": "vodevil",
    "vodeviluri": "vodevil",
    "vodevilurile": "vodevil",
    "vodevilurilor": "vodevil",
    "nemaivoind": "voi",
    "nemaivoindu": "voi",
    "nevoind": "voi",
    "nevoindu": "voi",
    "v-": "voi",
    "vă": "voi",
    "vă-": "voi",
    "vi": "voi",
    "vi-": "voi",
    "voia": "voi",
    "voiai": "voi",
    "voiam": "voi",
    "voiască": "voi",
    "voiați": "voi",
    "voiau": "voi",
    "voiesc": "voi",
    "voiește": "voi",
    "voiești": "voi",
    "voii": "voi",
    "voim": "voi",
    "voind": "voi",
    "voindu": "voi",
    "voiră": "voi",
    "voirăm": "voi",
    "voirăți": "voi",
    "voise": "voi",
    "voisem": "voi",
    "voiseră": "voi",
    "voiserăm": "voi",
    "voiserăți": "voi",
    "voiseși": "voi",
    "voiși": "voi",
    "voit": "voi",
    "voiți": "voi",
    "vouă": "voi",
    "voiaje": "voiaj",
    "voiajele": "voiaj",
    "voiajelor": "voiaj",
    "voiajul": "voiaj",
    "voiajului": "voiaj",
    "voiajuri": "voiaj",
    "voiajurile": "voiaj",
    "voiajurilor": "voiaj",
    "voi": "voie",
    "voia": "voie",
    "voii": "voie",
    "voile": "voie",
    "voilor": "voie",
    "voievodul": "voievod",
    "voievodului": "voievod",
    "voievozi": "voievod",
    "voievozii": "voievod",
    "voievozilor": "voievod",
    "voievodala": "voievodal",
    "voievodală": "voievodal",
    "voievodale": "voievodal",
    "voievodalei": "voievodal",
    "voievodalele": "voievodal",
    "voievodalelor": "voievodal",
    "voievodali": "voievodal",
    "voievodalii": "voievodal",
    "voievodalilor": "voievodal",
    "voievodalul": "voievodal",
    "voievodalului": "voievodal",
    "voinica": "voinic",
    "voinică": "voinic",
    "voinice": "voinic",
    "voinicei": "voinic",
    "voinicele": "voinic",
    "voinicelor": "voinic",
    "voinici": "voinic",
    "voinicii": "voinic",
    "voinicilor": "voinic",
    "voinicul": "voinic",
    "voinicului": "voinic",
    "voinicei": "voinicel",
    "voiniceii": "voinicel",
    "voiniceilor": "voinicel",
    "voinicelul": "voinicel",
    "voinicelului": "voinicel",
    "voiniceasca": "voinicesc",
    "voinicească": "voinicesc",
    "voinicescul": "voinicesc",
    "voinicescului": "voinicesc",
    "voinicești": "voinicesc",
    "voiniceștii": "voinicesc",
    "voiniceștile": "voinicesc",
    "voiniceștilor": "voinicesc",
    "nemaivoinicind": "voinici",
    "nemaivoinicindu": "voinici",
    "nevoinicind": "voinici",
    "nevoinicindu": "voinici",
    "voinicea": "voinici",
    "voiniceai": "voinici",
    "voiniceam": "voinici",
    "voinicească": "voinici",
    "voiniceați": "voinici",
    "voiniceau": "voinici",
    "voinicesc": "voinici",
    "voinicește": "voinici",
    "voinicești": "voinici",
    "voinicii": "voinici",
    "voinicim": "voinici",
    "voinicind": "voinici",
    "voinicindu": "voinici",
    "voiniciră": "voinici",
    "voinicirăm": "voinici",
    "voinicirăți": "voinici",
    "voinicise": "voinici",
    "voinicisem": "voinici",
    "voiniciseră": "voinici",
    "voiniciserăm": "voinici",
    "voiniciserăți": "voinici",
    "voiniciseși": "voinici",
    "voiniciși": "voinici",
    "voinicit": "voinici",
    "voiniciți": "voinici",
    "voinicele": "voinicică",
    "voinicelei": "voinicică",
    "voinicelele": "voinicică",
    "voinicelelor": "voinicică",
    "voinicica": "voinicică",
    "voinicia": "voinicie",
    "voiniciei": "voinicie",
    "voinicii": "voinicie",
    "voiniciile": "voinicie",
    "voiniciilor": "voinicie",
    "voinicimea": "voinicime",
    "voinicimi": "voinicime",
    "voinicimii": "voinicime",
    "voinicimile": "voinicime",
    "voinicimilor": "voinicime",
    "voinicită": "voinicit",
    "voinicite": "voinicit",
    "voiniciți": "voinicit",
    "voinicoasa": "voinicos",
    "voinicoasă": "voinicos",
    "voinicoase": "voinicos",
    "voinicoasei": "voinicos",
    "voinicoasele": "voinicos",
    "voinicoaselor": "voinicos",
    "voinicoși": "voinicos",
    "voinicoșii": "voinicos",
    "voinicoșilor": "voinicos",
    "voinicosul": "voinicos",
    "voinicosului": "voinicos",
    "voinicuți": "voinicuț",
    "voinicuții": "voinicuț",
    "voinicuților": "voinicuț",
    "voinicuțul": "voinicuț",
    "voinicuțului": "voinicuț",
    "voința": "voință",
    "voințe": "voință",
    "voinței": "voință",
    "voințele": "voință",
    "voințelor": "voință",
    "voioșia": "voioșie",
    "voioșiei": "voioșie",
    "voioșii": "voioșie",
    "voioșiile": "voioșie",
    "voioșiilor": "voioșie",
    "voirea": "voire",
    "voireo": "voire",
    "voiri": "voire",
    "voirii": "voire",
    "voirile": "voire",
    "voirilor": "voire",
    "voita": "voit",
    "voită": "voit",
    "voite": "voit",
    "voitei": "voit",
    "voitele": "voit",
    "voitelor": "voit",
    "voiți": "voit",
    "voiții": "voit",
    "voiților": "voit",
    "voito": "voit",
    "voitul": "voit",
    "voitule": "voit",
    "voitului": "voit",
    "volane": "volan",
    "volanele": "volan",
    "volanelor": "volan",
    "volanul": "volan",
    "volanului": "volan",
    "volanta": "volant",
    "volantă": "volant",
    "volante": "volant",
    "volantei": "volant",
    "volantele": "volant",
    "volantelor": "volant",
    "volanți": "volant",
    "volanții": "volant",
    "volanților": "volant",
    "volantul": "volant",
    "volantului": "volant",
    "volatila": "volatil",
    "volatilă": "volatil",
    "volatile": "volatil",
    "volatilei": "volatil",
    "volatilele": "volatil",
    "volatilelor": "volatil",
    "volatili": "volatil",
    "volatilii": "volatil",
    "volatililor": "volatil",
    "volatilul": "volatil",
    "volatilului": "volatil",
    "volatilitatea": "volatilitate",
    "volatilități": "volatilitate",
    "volatilității": "volatilitate",
    "volatilitățile": "volatilitate",
    "volatilităților": "volatilitate",
    "nemaivolatilizând": "volatiliza",
    "nemaivolatilizându": "volatiliza",
    "nevolatilizând": "volatiliza",
    "nevolatilizându": "volatiliza",
    "volatiliză": "volatiliza",
    "volatilizai": "volatiliza",
    "volatilizam": "volatiliza",
    "volatilizăm": "volatiliza",
    "volatilizând": "volatiliza",
    "volatilizându": "volatiliza",
    "volatilizară": "volatiliza",
    "volatilizarăm": "volatiliza",
    "volatilizarăți": "volatiliza",
    "volatilizase": "volatiliza",
    "volatilizasem": "volatiliza",
    "volatilizaseră": "volatiliza",
    "volatilizaserăm": "volatiliza",
    "volatilizaserăți": "volatiliza",
    "volatilizaseși": "volatiliza",
    "volatilizași": "volatiliza",
    "volatilizat": "volatiliza",
    "volatilizați": "volatiliza",
    "volatilizau": "volatiliza",
    "volatilizează": "volatiliza",
    "volatilizez": "volatiliza",
    "volatilizeze": "volatiliza",
    "volatilizezi": "volatiliza",
    "volatilizarea": "volatilizare",
    "volatilizareo": "volatilizare",
    "volatilizări": "volatilizare",
    "volatilizării": "volatilizare",
    "volatilizările": "volatilizare",
    "volatilizărilor": "volatilizare",
    "volatilizată": "volatilizat",
    "volatilizate": "volatilizat",
    "volatilizați": "volatilizat",
    "volbura": "volbură",
    "volburi": "volbură",
    "volburii": "volbură",
    "volburile": "volbură",
    "volburilor": "volbură",
    "voloace": "voloc",
    "voloacelor": "voloc",
    "volocele": "voloc",
    "volocul": "voloc",
    "volocului": "voloc",
    "volocele": "volocel",
    "volocelele": "volocel",
    "volocelelor": "volocel",
    "volocelul": "volocel",
    "volocelului": "volocel",
    "V": "volt",
    "volți": "volt",
    "volții": "volt",
    "volților": "volt",
    "voltul": "volt",
    "voltului": "volt",
    "volta": "voltă",
    "volte": "voltă",
    "voltei": "voltă",
    "voltele": "voltă",
    "voltelor": "voltă",
    "voltaica": "voltaic",
    "voltaică": "voltaic",
    "voltaice": "voltaic",
    "voltaicei": "voltaic",
    "voltaicele": "voltaic",
    "voltaicelor": "voltaic",
    "voltaici": "voltaic",
    "voltaicii": "voltaic",
    "voltaicilor": "voltaic",
    "voltaicul": "voltaic",
    "voltaicului": "voltaic",
    "voltampermetre": "voltampermetru",
    "voltampermetrele": "voltampermetru",
    "voltampermetrelor": "voltampermetru",
    "voltampermetrul": "voltampermetru",
    "voltampermetrului": "voltampermetru",
    "voltmetre": "voltmetru",
    "voltmetrele": "voltmetru",
    "voltmetrelor": "voltmetru",
    "voltmetrul": "voltmetru",
    "voltmetrului": "voltmetru",
    "volubila": "volubil",
    "volubilă": "volubil",
    "volubile": "volubil",
    "volubilei": "volubil",
    "volubilele": "volubil",
    "volubilelor": "volubil",
    "volubili": "volubil",
    "volubilii": "volubil",
    "volubililor": "volubil",
    "volubilul": "volubil",
    "volubilului": "volubil",
    "volubilitatea": "volubilitate",
    "volubilități": "volubilitate",
    "volubilității": "volubilitate",
    "volubilitățile": "volubilitate",
    "volubilităților": "volubilitate",
    "v.": "volum",
    "vol.": "volum",
    "volume": "volum",
    "volumele": "volum",
    "volumelor": "volum",
    "volumul": "volum",
    "volumului": "volum",
    "volumașe": "volumaș",
    "volumașele": "volumaș",
    "volumașelor": "volumaș",
    "volumașul": "volumaș",
    "volumașului": "volumaș",
    "volumetrica": "volumetric",
    "volumetrică": "volumetric",
    "volumetrice": "volumetric",
    "volumetricei": "volumetric",
    "volumetricele": "volumetric",
    "volumetricelor": "volumetric",
    "volumetrici": "volumetric",
    "volumetricii": "volumetric",
    "volumetricilor": "volumetric",
    "volumetricul": "volumetric",
    "volumetricului": "volumetric",
    "voluminoasa": "voluminos",
    "voluminoasă": "voluminos",
    "voluminoase": "voluminos",
    "voluminoasei": "voluminos",
    "voluminoasele": "voluminos",
    "voluminoaselor": "voluminos",
    "voluminoși": "voluminos",
    "voluminoșii": "voluminos",
    "voluminoșilor": "voluminos",
    "voluminosul": "voluminos",
    "voluminosului": "voluminos",
    "voluntara": "voluntar",
    "voluntară": "voluntar",
    "voluntare": "voluntar",
    "voluntarei": "voluntar",
    "voluntarele": "voluntar",
    "voluntarelor": "voluntar",
    "voluntari": "voluntar",
    "voluntarii": "voluntar",
    "voluntarilor": "voluntar",
    "voluntarul": "voluntar",
    "voluntarului": "voluntar",
    "voluntarisme": "voluntarism",
    "voluntarismele": "voluntarism",
    "voluntarismelor": "voluntarism",
    "voluntarismul": "voluntarism",
    "voluntarismului": "voluntarism",
    "voluptatea": "voluptate",
    "voluptăți": "voluptate",
    "voluptății": "voluptate",
    "voluptățile": "voluptate",
    "voluptăților": "voluptate",
    "voluptoasa": "voluptos",
    "voluptoasă": "voluptos",
    "voluptoase": "voluptos",
    "voluptoasei": "voluptos",
    "voluptoasele": "voluptos",
    "voluptoaselor": "voluptos",
    "voluptoși": "voluptos",
    "voluptoșii": "voluptos",
    "voluptoșilor": "voluptos",
    "voluptosul": "voluptos",
    "voluptosului": "voluptos",
    "voluta": "volută",
    "volute": "volută",
    "volutei": "volută",
    "volutele": "volută",
    "volutelor": "volută",
    "voma": "vomă",
    "vome": "vomă",
    "vomei": "vomă",
    "vomele": "vomă",
    "vomelor": "vomă",
    "vomere": "vomer",
    "vomerele": "vomer",
    "vomerelor": "vomer",
    "vomerul": "vomer",
    "vomerului": "vomer",
    "nemaivomitând": "vomita",
    "nemaivomitându": "vomita",
    "nevomitând": "vomita",
    "nevomitându": "vomita",
    "vomit": "vomita",
    "vomită": "vomita",
    "vomitai": "vomita",
    "vomitam": "vomita",
    "vomităm": "vomita",
    "vomitând": "vomita",
    "vomitându": "vomita",
    "vomitară": "vomita",
    "vomitarăm": "vomita",
    "vomitarăți": "vomita",
    "vomitase": "vomita",
    "vomitasem": "vomita",
    "vomitaseră": "vomita",
    "vomitaserăm": "vomita",
    "vomitaserăți": "vomita",
    "vomitaseși": "vomita",
    "vomitași": "vomita",
    "vomitat": "vomita",
    "vomitați": "vomita",
    "vomitau": "vomita",
    "vomite": "vomita",
    "vomiți": "vomita",
    "vomitată": "vomitat",
    "vomitate": "vomitat",
    "vomitați": "vomitat",
    "voniceri": "vonicer",
    "vonicerii": "vonicer",
    "vonicerilor": "vonicer",
    "vonicerul": "vonicer",
    "vonicerului": "vonicer",
    "vopseaua": "vopsea",
    "vopsele": "vopsea",
    "vopselei": "vopsea",
    "vopselele": "vopsea",
    "vopselelor": "vopsea",
    "nemaivopsind": "vopsi",
    "nemaivopsindu": "vopsi",
    "nevopsind": "vopsi",
    "nevopsindu": "vopsi",
    "vopsea": "vopsi",
    "vopseai": "vopsi",
    "vopseam": "vopsi",
    "vopsească": "vopsi",
    "vopseați": "vopsi",
    "vopseau": "vopsi",
    "vopsesc": "vopsi",
    "vopsește": "vopsi",
    "vopsești": "vopsi",
    "vopsii": "vopsi",
    "vopsim": "vopsi",
    "vopsind": "vopsi",
    "vopsindu": "vopsi",
    "vopsiră": "vopsi",
    "vopsirăm": "vopsi",
    "vopsirăți": "vopsi",
    "vopsise": "vopsi",
    "vopsisem": "vopsi",
    "vopsiseră": "vopsi",
    "vopsiserăm": "vopsi",
    "vopsiserăți": "vopsi",
    "vopsiseși": "vopsi",
    "vopsiși": "vopsi",
    "vopsit": "vopsi",
    "vopsiți": "vopsi",
    "vopsirea": "vopsire",
    "vopsireo": "vopsire",
    "vopsiri": "vopsire",
    "vopsirii": "vopsire",
    "vopsirile": "vopsire",
    "vopsirilor": "vopsire",
    "vopsita": "vopsit",
    "vopsită": "vopsit",
    "vopsite": "vopsit",
    "vopsitei": "vopsit",
    "vopsitele": "vopsit",
    "vopsitelor": "vopsit",
    "vopsiți": "vopsit",
    "vopsiții": "vopsit",
    "vopsiților": "vopsit",
    "vopsito": "vopsit",
    "vopsitul": "vopsit",
    "vopsitule": "vopsit",
    "vopsitului": "vopsit",
    "vopsitori": "vopsitor",
    "vopsitorii": "vopsitor",
    "vopsitorilor": "vopsitor",
    "vopsitorul": "vopsitor",
    "vopsitorului": "vopsitor",
    "voracitatea": "voracitate",
    "voracități": "voracitate",
    "voracității": "voracitate",
    "voracitățile": "voracitate",
    "voracităților": "voracitate",
    "vorba": "vorbă",
    "vorbe": "vorbă",
    "vorbei": "vorbă",
    "vorbele": "vorbă",
    "vorbelor": "vorbă",
    "vorbăreața": "vorbăreț",
    "vorbăreață": "vorbăreț",
    "vorbărețe": "vorbăreț",
    "vorbăreței": "vorbăreț",
    "vorbărețele": "vorbăreț",
    "vorbărețelor": "vorbăreț",
    "vorbăreți": "vorbăreț",
    "vorbăreții": "vorbăreț",
    "vorbăreților": "vorbăreț",
    "vorbărețul": "vorbăreț",
    "vorbărețului": "vorbăreț",
    "vorbăria": "vorbărie",
    "vorbăriei": "vorbărie",
    "vorbării": "vorbărie",
    "vorbăriile": "vorbărie",
    "vorbăriilor": "vorbărie",
    "nemaivorbind": "vorbi",
    "nemaivorbindu": "vorbi",
    "nevorbind": "vorbi",
    "nevorbindu": "vorbi",
    "vorbea": "vorbi",
    "vorbeai": "vorbi",
    "vorbeam": "vorbi",
    "vorbească": "vorbi",
    "vorbeați": "vorbi",
    "vorbeau": "vorbi",
    "vorbesc": "vorbi",
    "vorbește": "vorbi",
    "vorbești": "vorbi",
    "vorbii": "vorbi",
    "vorbim": "vorbi",
    "vorbind": "vorbi",
    "vorbindu": "vorbi",
    "vorbiră": "vorbi",
    "vorbirăm": "vorbi",
    "vorbirăți": "vorbi",
    "vorbise": "vorbi",
    "vorbisem": "vorbi",
    "vorbiseră": "vorbi",
    "vorbiserăm": "vorbi",
    "vorbiserăți": "vorbi",
    "vorbiseși": "vorbi",
    "vorbiși": "vorbi",
    "vorbit": "vorbi",
    "vorbiți": "vorbi",
    "vorbirea": "vorbire",
    "vorbireo": "vorbire",
    "vorbiri": "vorbire",
    "vorbirii": "vorbire",
    "vorbirile": "vorbire",
    "vorbirilor": "vorbire",
    "vorbită": "vorbit",
    "vorbite": "vorbit",
    "vorbiți": "vorbit",
    "vorbitul": "vorbit",
    "vorbitului": "vorbit",
    "vorbitoare": "vorbitor",
    "vorbitoarele": "vorbitor",
    "vorbitoarelor": "vorbitor",
    "vorbitori": "vorbitor",
    "vorbitorii": "vorbitor",
    "vorbitorilor": "vorbitor",
    "vorbitorul": "vorbitor",
    "vorbitorului": "vorbitor",
    "voastră": "vostru",
    "voastre": "vostru",
    "voștri": "vostru",
    "votul": "vot",
    "votului": "vot",
    "voturi": "vot",
    "voturile": "vot",
    "voturilor": "vot",
    "nemaivotând": "vota",
    "nemaivotându": "vota",
    "nevotând": "vota",
    "nevotându": "vota",
    "votă": "vota",
    "votai": "vota",
    "votam": "vota",
    "votăm": "vota",
    "votând": "vota",
    "votându": "vota",
    "votară": "vota",
    "votarăm": "vota",
    "votarăți": "vota",
    "votase": "vota",
    "votasem": "vota",
    "votaseră": "vota",
    "votaserăm": "vota",
    "votaserăți": "vota",
    "votaseși": "vota",
    "votași": "vota",
    "votat": "vota",
    "votați": "vota",
    "votau": "vota",
    "votează": "vota",
    "votez": "vota",
    "voteze": "vota",
    "votezi": "vota",
    "votantă": "votant",
    "votante": "votant",
    "votanți": "votant",
    "votarea": "votare",
    "votareo": "votare",
    "votări": "votare",
    "votării": "votare",
    "votările": "votare",
    "votărilor": "votare",
    "votată": "votat",
    "votate": "votat",
    "votați": "votat",
    "votca": "votcă",
    "votci": "votcă",
    "votcii": "votcă",
    "votcile": "votcă",
    "votcilor": "votcă",
    "vrabia": "vrabie",
    "vrăbiei": "vrabie",
    "vrăbii": "vrabie",
    "vrăbiile": "vrabie",
    "vrăbiilor": "vrabie",
    "vrăbieri": "vrăbier",
    "vrăbierii": "vrăbier",
    "vrăbierilor": "vrăbier",
    "vrăbierul": "vrăbier",
    "vrăbierului": "vrăbier",
    "vrăbioara": "vrăbioară",
    "vrăbioare": "vrăbioară",
    "vrăbioarei": "vrăbioară",
    "vrăbioarele": "vrăbioară",
    "vrăbioarelor": "vrăbioară",
    "vrăbioii": "vrăbioi",
    "vrăbioilor": "vrăbioi",
    "vrăbioiul": "vrăbioi",
    "vrăbioiului": "vrăbioi",
    "vrăbiuța": "vrăbiuță",
    "vrăbiuțe": "vrăbiuță",
    "vrăbiuței": "vrăbiuță",
    "vrăbiuțele": "vrăbiuță",
    "vrăbiuțelor": "vrăbiuță",
    "vracul": "vrac",
    "vracului": "vrac",
    "vracuri": "vrac",
    "vracurile": "vrac",
    "vracurilor": "vrac",
    "vracii": "vraci",
    "vracilor": "vraci",
    "vraciul": "vraci",
    "vraciului": "vraci",
    "vraful": "vraf",
    "vrafului": "vraf",
    "vrafuri": "vraf",
    "vrafurile": "vraf",
    "vrafurilor": "vraf",
    "nemaivrăfuind": "vrăfui",
    "nemaivrăfuindu": "vrăfui",
    "nevrăfuind": "vrăfui",
    "nevrăfuindu": "vrăfui",
    "vrăfuia": "vrăfui",
    "vrăfuiai": "vrăfui",
    "vrăfuiam": "vrăfui",
    "vrăfuiască": "vrăfui",
    "vrăfuiați": "vrăfui",
    "vrăfuiau": "vrăfui",
    "vrăfuiesc": "vrăfui",
    "vrăfuiește": "vrăfui",
    "vrăfuiești": "vrăfui",
    "vrăfuii": "vrăfui",
    "vrăfuim": "vrăfui",
    "vrăfuind": "vrăfui",
    "vrăfuindu": "vrăfui",
    "vrăfuiră": "vrăfui",
    "vrăfuirăm": "vrăfui",
    "vrăfuirăți": "vrăfui",
    "vrăfuise": "vrăfui",
    "vrăfuisem": "vrăfui",
    "vrăfuiseră": "vrăfui",
    "vrăfuiserăm": "vrăfui",
    "vrăfuiserăți": "vrăfui",
    "vrăfuiseși": "vrăfui",
    "vrăfuiși": "vrăfui",
    "vrăfuit": "vrăfui",
    "vrăfuiți": "vrăfui",
    "vrăfuită": "vrăfuit",
    "vrăfuite": "vrăfuit",
    "vrăfuiți": "vrăfuit",
    "vraja": "vrajă",
    "vrăji": "vrajă",
    "vrăjii": "vrajă",
    "vrăjile": "vrajă",
    "vrăjilor": "vrajă",
    "vrajba": "vrajbă",
    "vrajbe": "vrajbă",
    "vrajbei": "vrajbă",
    "vrajbele": "vrajbă",
    "vrajbelor": "vrajbă",
    "nemaivrăjind": "vrăji",
    "nemaivrăjindu": "vrăji",
    "nevrăjind": "vrăji",
    "nevrăjindu": "vrăji",
    "vrăjea": "vrăji",
    "vrăjeai": "vrăji",
    "vrăjeam": "vrăji",
    "vrăjească": "vrăji",
    "vrăjeați": "vrăji",
    "vrăjeau": "vrăji",
    "vrăjesc": "vrăji",
    "vrăjește": "vrăji",
    "vrăjești": "vrăji",
    "vrăjii": "vrăji",
    "vrăjim": "vrăji",
    "vrăjind": "vrăji",
    "vrăjindu": "vrăji",
    "vrăjiră": "vrăji",
    "vrăjirăm": "vrăji",
    "vrăjirăți": "vrăji",
    "vrăjise": "vrăji",
    "vrăjisem": "vrăji",
    "vrăjiseră": "vrăji",
    "vrăjiserăm": "vrăji",
    "vrăjiserăți": "vrăji",
    "vrăjiseși": "vrăji",
    "vrăjiși": "vrăji",
    "vrăjit": "vrăji",
    "vrăjiți": "vrăji",
    "vrăjirea": "vrăjire",
    "vrăjireo": "vrăjire",
    "vrăjiri": "vrăjire",
    "vrăjirii": "vrăjire",
    "vrăjirile": "vrăjire",
    "vrăjirilor": "vrăjire",
    "vrăjita": "vrăjit",
    "vrăjită": "vrăjit",
    "vrăjite": "vrăjit",
    "vrăjitei": "vrăjit",
    "vrăjitele": "vrăjit",
    "vrăjitelor": "vrăjit",
    "vrăjiți": "vrăjit",
    "vrăjiții": "vrăjit",
    "vrăjiților": "vrăjit",
    "vrăjito": "vrăjit",
    "vrăjitul": "vrăjit",
    "vrăjitule": "vrăjit",
    "vrăjitului": "vrăjit",
    "vrăjitori": "vrăjitor",
    "vrăjitorii": "vrăjitor",
    "vrăjitorilor": "vrăjitor",
    "vrăjitorul": "vrăjitor",
    "vrăjitorului": "vrăjitor",
    "vrăjmașa": "vrăjmaș",
    "vrăjmașă": "vrăjmaș",
    "vrăjmașe": "vrăjmaș",
    "vrăjmașei": "vrăjmaș",
    "vrăjmașele": "vrăjmaș",
    "vrăjmașelor": "vrăjmaș",
    "vrăjmași": "vrăjmaș",
    "vrăjmașii": "vrăjmaș",
    "vrăjmașilor": "vrăjmaș",
    "vrăjmașul": "vrăjmaș",
    "vrăjmașului": "vrăjmaș",
    "vrăjmașa": "vrăjmașă",
    "vrăjmașe": "vrăjmașă",
    "vrăjmașei": "vrăjmașă",
    "vrăjmașele": "vrăjmașă",
    "vrăjmașelor": "vrăjmașă",
    "vrăjmășeasca": "vrăjmășesc",
    "vrăjmășească": "vrăjmășesc",
    "vrăjmășescul": "vrăjmășesc",
    "vrăjmășescului": "vrăjmășesc",
    "vrăjmășești": "vrăjmășesc",
    "vrăjmășeștii": "vrăjmășesc",
    "vrăjmășeștile": "vrăjmășesc",
    "vrăjmășeștilor": "vrăjmășesc",
    "vrana": "vrană",
    "vrane": "vrană",
    "vranei": "vrană",
    "vranele": "vrană",
    "vranelor": "vrană",
    "vrășmașa": "vrășmaș",
    "vrășmașă": "vrășmaș",
    "vrășmașe": "vrășmaș",
    "vrășmașei": "vrășmaș",
    "vrășmașele": "vrășmaș",
    "vrășmașelor": "vrășmaș",
    "vrășmași": "vrășmaș",
    "vrășmașii": "vrășmaș",
    "vrășmașilor": "vrășmaș",
    "vrășmașul": "vrășmaș",
    "vrășmașului": "vrășmaș",
    "ăi": "vrea",
    "ăți": "vrea",
    "eți": "vrea",
    "îi": "vrea",
    "îți": "vrea",
    "nemaivrând": "vrea",
    "nemaivrându": "vrea",
    "nevrând": "vrea",
    "nevrându": "vrea",
    "o": "vrea",
    "oi": "vrea",
    "or": "vrea",
    "va": "vrea",
    "vei": "vrea",
    "veți": "vrea",
    "voi": "vrea",
    "vom": "vrea",
    "vor": "vrea",
    "vrând": "vrea",
    "vrându": "vrea",
    "vreau": "vrea",
    "vrei": "vrea",
    "vrem": "vrea",
    "vreți": "vrea",
    "vroia": "vrea",
    "vroiai": "vrea",
    "vroiam": "vrea",
    "vroiați": "vrea",
    "vroiau": "vrea",
    "vru": "vrea",
    "vrui": "vrea",
    "vrură": "vrea",
    "vrurăm": "vrea",
    "vrurăți": "vrea",
    "vruse": "vrea",
    "vrusem": "vrea",
    "vruseră": "vrea",
    "vruserăm": "vrea",
    "vruserăți": "vrea",
    "vruseși": "vrea",
    "vruși": "vrea",
    "vrut": "vrea",
    "vreascul": "vreasc",
    "vreascului": "vreasc",
    "vreascuri": "vreasc",
    "vreascurile": "vreasc",
    "vreascurilor": "vreasc",
    "vrednica": "vrednic",
    "vrednică": "vrednic",
    "vrednice": "vrednic",
    "vrednicei": "vrednic",
    "vrednicele": "vrednic",
    "vrednicelor": "vrednic",
    "vrednici": "vrednic",
    "vrednicii": "vrednic",
    "vrednicilor": "vrednic",
    "vrednicul": "vrednic",
    "vrednicului": "vrednic",
    "vrednicea": "vrednici",
    "vredniceai": "vrednici",
    "vredniceam": "vrednici",
    "vrednicească": "vrednici",
    "vredniceați": "vrednici",
    "vredniceau": "vrednici",
    "vrednicesc": "vrednici",
    "vrednicește": "vrednici",
    "vrednicești": "vrednici",
    "vrednicii": "vrednici",
    "vrednicim": "vrednici",
    "vrednicind": "vrednici",
    "vrednicindu": "vrednici",
    "vredniciră": "vrednici",
    "vrednicirăm": "vrednici",
    "vrednicirăți": "vrednici",
    "vrednicise": "vrednici",
    "vrednicisem": "vrednici",
    "vredniciseră": "vrednici",
    "vredniciserăm": "vrednici",
    "vredniciserăți": "vrednici",
    "vredniciseși": "vrednici",
    "vredniciși": "vrednici",
    "vrednicit": "vrednici",
    "vredniciți": "vrednici",
    "vrednicitu": "vrednici",
    "vrednicia": "vrednicie",
    "vredniciei": "vrednicie",
    "vrednicii": "vrednicie",
    "vredniciile": "vrednicie",
    "vredniciilor": "vrednicie",
    "vrednicită": "vrednicit",
    "vrednicite": "vrednicit",
    "vredniciți": "vrednicit",
    "vrejul": "vrej",
    "vrejului": "vrej",
    "vrejuri": "vrej",
    "vrejurile": "vrej",
    "vrejurilor": "vrej",
    "vremea": "vreme",
    "vremi": "vreme",
    "vremii": "vreme",
    "vremuri": "vreme",
    "vremurile": "vreme",
    "vremurilor": "vreme",
    "vremelnica": "vremelnic",
    "vremelnică": "vremelnic",
    "vremelnice": "vremelnic",
    "vremelnicei": "vremelnic",
    "vremelnicele": "vremelnic",
    "vremelnicelor": "vremelnic",
    "vremelnici": "vremelnic",
    "vremelnicii": "vremelnic",
    "vremelnicilor": "vremelnic",
    "vremelnicul": "vremelnic",
    "vremelnicului": "vremelnic",
    "nemaivremuind": "vremui",
    "nemaivremuindu": "vremui",
    "nevremuind": "vremui",
    "nevremuindu": "vremui",
    "vremuia": "vremui",
    "vremuiai": "vremui",
    "vremuiam": "vremui",
    "vremuiască": "vremui",
    "vremuiați": "vremui",
    "vremuiau": "vremui",
    "vremuiesc": "vremui",
    "vremuiește": "vremui",
    "vremuiești": "vremui",
    "vremuii": "vremui",
    "vremuim": "vremui",
    "vremuind": "vremui",
    "vremuindu": "vremui",
    "vremuiră": "vremui",
    "vremuirăm": "vremui",
    "vremuirăți": "vremui",
    "vremuise": "vremui",
    "vremuisem": "vremui",
    "vremuiseră": "vremui",
    "vremuiserăm": "vremui",
    "vremuiserăți": "vremui",
    "vremuiseși": "vremui",
    "vremuiși": "vremui",
    "vremuit": "vremui",
    "vremuiți": "vremui",
    "vremuiala": "vremuială",
    "vremuieli": "vremuială",
    "vremuielii": "vremuială",
    "vremuielile": "vremuială",
    "vremuielilor": "vremuială",
    "vremuirea": "vremuire",
    "vremuireo": "vremuire",
    "vremuiri": "vremuire",
    "vremuirii": "vremuire",
    "vremuirile": "vremuire",
    "vremuirilor": "vremuire",
    "vremuită": "vremuit",
    "vremuite": "vremuit",
    "vremuiți": "vremuit",
    "vo": "vreo",
    "vrerea": "vrere",
    "vreri": "vrere",
    "vrerii": "vrere",
    "vrerile": "vrere",
    "vrerilor": "vrere",
    "vreo": "vreun",
    "vreunei": "vreun",
    "vreunele": "vreun",
    "vreunii": "vreun",
    "vreunor": "vreun",
    "vreunui": "vreun",
    "vreuna": "vreunul",
    "vreuneia": "vreunul",
    "vreunele": "vreunul",
    "vreunii": "vreunul",
    "vreunora": "vreunul",
    "vreunuia": "vreunul",
    "vrută": "vrut",
    "vrute": "vrut",
    "vruți": "vrut",
    "nemaivuind": "vui",
    "nemaivuindu": "vui",
    "nevuind": "vui",
    "nevuindu": "vui",
    "vuia": "vui",
    "vuiai": "vui",
    "vuiam": "vui",
    "vuiască": "vui",
    "vuiați": "vui",
    "vuiau": "vui",
    "vuiesc": "vui",
    "vuiește": "vui",
    "vuiești": "vui",
    "vuii": "vui",
    "vuim": "vui",
    "vuind": "vui",
    "vuindu": "vui",
    "vuiră": "vui",
    "vuirăm": "vui",
    "vuirăți": "vui",
    "vuise": "vui",
    "vuisem": "vui",
    "vuiseră": "vui",
    "vuiserăm": "vui",
    "vuiserăți": "vui",
    "vuiseși": "vui",
    "vuiși": "vui",
    "vuit": "vui",
    "vuiți": "vui",
    "vuiete": "vuiet",
    "vuietele": "vuiet",
    "vuietelor": "vuiet",
    "vuietul": "vuiet",
    "vuietului": "vuiet",
    "vuirea": "vuire",
    "vuireo": "vuire",
    "vuiri": "vuire",
    "vuirii": "vuire",
    "vuirile": "vuire",
    "vuirilor": "vuire",
    "vuita": "vuit",
    "vuită": "vuit",
    "vuite": "vuit",
    "vuitei": "vuit",
    "vuitele": "vuit",
    "vuitelor": "vuit",
    "vuiți": "vuit",
    "vuiții": "vuit",
    "vuiților": "vuit",
    "vuito": "vuit",
    "vuitul": "vuit",
    "vuitule": "vuit",
    "vuitului": "vuit",
    "vulcani": "vulcan",
    "vulcanii": "vulcan",
    "vulcanilor": "vulcan",
    "vulcanul": "vulcan",
    "vulcanului": "vulcan",
    "vulcanisme": "vulcanism",
    "vulcanismele": "vulcanism",
    "vulcanismelor": "vulcanism",
    "vulcanismul": "vulcanism",
    "vulcanismului": "vulcanism",
    "nemaivulcanizând": "vulcaniza",
    "nemaivulcanizându": "vulcaniza",
    "nevulcanizând": "vulcaniza",
    "nevulcanizându": "vulcaniza",
    "vulcaniză": "vulcaniza",
    "vulcanizai": "vulcaniza",
    "vulcanizam": "vulcaniza",
    "vulcanizăm": "vulcaniza",
    "vulcanizând": "vulcaniza",
    "vulcanizându": "vulcaniza",
    "vulcanizară": "vulcaniza",
    "vulcanizarăm": "vulcaniza",
    "vulcanizarăți": "vulcaniza",
    "vulcanizase": "vulcaniza",
    "vulcanizasem": "vulcaniza",
    "vulcanizaseră": "vulcaniza",
    "vulcanizaserăm": "vulcaniza",
    "vulcanizaserăți": "vulcaniza",
    "vulcanizaseși": "vulcaniza",
    "vulcanizași": "vulcaniza",
    "vulcanizat": "vulcaniza",
    "vulcanizați": "vulcaniza",
    "vulcanizau": "vulcaniza",
    "vulcanizează": "vulcaniza",
    "vulcanizez": "vulcaniza",
    "vulcanizeze": "vulcaniza",
    "vulcanizezi": "vulcaniza",
    "vulcanizarea": "vulcanizare",
    "vulcanizareo": "vulcanizare",
    "vulcanizări": "vulcanizare",
    "vulcanizării": "vulcanizare",
    "vulcanizările": "vulcanizare",
    "vulcanizărilor": "vulcanizare",
    "vulcanizată": "vulcanizat",
    "vulcanizate": "vulcanizat",
    "vulcanizați": "vulcanizat",
    "vulcanologia": "vulcanologie",
    "vulcanologiei": "vulcanologie",
    "vulcanologii": "vulcanologie",
    "vulcanologiile": "vulcanologie",
    "vulcanologiilor": "vulcanologie",
    "vulgara": "vulgar",
    "vulgară": "vulgar",
    "vulgare": "vulgar",
    "vulgarei": "vulgar",
    "vulgarele": "vulgar",
    "vulgarelor": "vulgar",
    "vulgari": "vulgar",
    "vulgarii": "vulgar",
    "vulgarilor": "vulgar",
    "vulgarul": "vulgar",
    "vulgarului": "vulgar",
    "vulgaritatea": "vulgaritate",
    "vulgarități": "vulgaritate",
    "vulgarității": "vulgaritate",
    "vulgaritățile": "vulgaritate",
    "vulgarităților": "vulgaritate",
    "vulgarizata": "vulgarizat",
    "vulgarizată": "vulgarizat",
    "vulgarizate": "vulgarizat",
    "vulgarizatei": "vulgarizat",
    "vulgarizatele": "vulgarizat",
    "vulgarizatelor": "vulgarizat",
    "vulgarizați": "vulgarizat",
    "vulgarizații": "vulgarizat",
    "vulgarizaților": "vulgarizat",
    "vulgarizatul": "vulgarizat",
    "vulgarizatului": "vulgarizat",
    "vulnerabila": "vulnerabil",
    "vulnerabilă": "vulnerabil",
    "vulnerabile": "vulnerabil",
    "vulnerabilei": "vulnerabil",
    "vulnerabilele": "vulnerabil",
    "vulnerabilelor": "vulnerabil",
    "vulnerabili": "vulnerabil",
    "vulnerabilii": "vulnerabil",
    "vulnerabililor": "vulnerabil",
    "vulnerabilul": "vulnerabil",
    "vulnerabilului": "vulnerabil",
    "vulpăria": "vulpărie",
    "vulpăriei": "vulpărie",
    "vulpării": "vulpărie",
    "vulpăriile": "vulpărie",
    "vulpăriilor": "vulpărie",
    "vulpea": "vulpe",
    "vulpi": "vulpe",
    "vulpii": "vulpe",
    "vulpile": "vulpe",
    "vulpilor": "vulpe",
    "vulpenia": "vulpenie",
    "vulpeniei": "vulpenie",
    "vulpenii": "vulpenie",
    "vulpeniile": "vulpenie",
    "vulpeniilor": "vulpenie",
    "vulpeasca": "vulpesc",
    "vulpească": "vulpesc",
    "vulpescul": "vulpesc",
    "vulpescului": "vulpesc",
    "vulpești": "vulpesc",
    "vulpeștii": "vulpesc",
    "vulpeștile": "vulpesc",
    "vulpeștilor": "vulpesc",
    "vulpișoara": "vulpișoară",
    "vulpișoare": "vulpișoară",
    "vulpișoarei": "vulpișoară",
    "vulpișoarele": "vulpișoară",
    "vulpișoarelor": "vulpișoară",
    "vulpița": "vulpiță",
    "vulpițe": "vulpiță",
    "vulpiței": "vulpiță",
    "vulpițele": "vulpiță",
    "vulpițelor": "vulpiță",
    "vulpoii": "vulpoi",
    "vulpoilor": "vulpoi",
    "vulpoiul": "vulpoi",
    "vulpoiului": "vulpoi",
    "vulturi": "vultur",
    "vulturii": "vultur",
    "vulturilor": "vultur",
    "vulturul": "vultur",
    "vulturului": "vultur",
    "vulturași": "vulturaș",
    "vulturașii": "vulturaș",
    "vulturașilor": "vulturaș",
    "vulturașul": "vulturaș",
    "vulturașului": "vulturaș",
    "vulturei": "vulturel",
    "vultureii": "vulturel",
    "vultureilor": "vulturel",
    "vulturelul": "vulturel",
    "vulturelului": "vulturel",
    "vultureasca": "vulturesc",
    "vulturească": "vulturesc",
    "vulturescul": "vulturesc",
    "vulturescului": "vulturesc",
    "vulturești": "vulturesc",
    "vultureștii": "vulturesc",
    "vultureștile": "vulturesc",
    "vultureștilor": "vulturesc",
    "vulturica": "vulturică",
    "vulturici": "vulturică",
    "vulturicii": "vulturică",
    "vulturicile": "vulturică",
    "vulturicilor": "vulturică",
    "vulturița": "vulturiță",
    "vulturițe": "vulturiță",
    "vulturiței": "vulturiță",
    "vulturițele": "vulturiță",
    "vulturițelor": "vulturiță",
    "vulturoaia": "vulturoaie",
    "vulturoaiei": "vulturoaie",
    "vulturoaiele": "vulturoaie",
    "vulturoaielor": "vulturoaie",
    "vulva": "vulvă",
    "vulve": "vulvă",
    "vulvei": "vulvă",
    "vulvele": "vulvă",
    "vulvelor": "vulvă",
    "nemaivuvuind": "vuvui",
    "nemaivuvuindu": "vuvui",
    "nevuvuind": "vuvui",
    "nevuvuindu": "vuvui",
    "vuvuia": "vuvui",
    "vuvuiai": "vuvui",
    "vuvuiam": "vuvui",
    "vuvuiască": "vuvui",
    "vuvuiați": "vuvui",
    "vuvuiau": "vuvui",
    "vuvuiesc": "vuvui",
    "vuvuiește": "vuvui",
    "vuvuiești": "vuvui",
    "vuvuii": "vuvui",
    "vuvuim": "vuvui",
    "vuvuind": "vuvui",
    "vuvuindu": "vuvui",
    "vuvuiră": "vuvui",
    "vuvuirăm": "vuvui",
    "vuvuirăți": "vuvui",
    "vuvuise": "vuvui",
    "vuvuisem": "vuvui",
    "vuvuiseră": "vuvui",
    "vuvuiserăm": "vuvui",
    "vuvuiserăți": "vuvui",
    "vuvuiseși": "vuvui",
    "vuvuiși": "vuvui",
    "vuvuit": "vuvui",
    "vuvuiți": "vuvui",
    "vuvuită": "vuvuit",
    "vuvuite": "vuvuit",
    "vuvuiți": "vuvuit",
    "Washingtonul": "Washington",
    "Washingtonului": "Washington",
    "W.C.": "water_closet",
    "W": "watt",
    "wați": "watt",
    "wații": "watt",
    "waților": "watt",
    "wattul": "watt",
    "wattului": "watt",
    "wattmetre": "wattmetru",
    "wattmetrele": "wattmetru",
    "wattmetrelor": "wattmetru",
    "wattmetrul": "wattmetru",
    "wattmetrului": "wattmetru",
    "Wb": "weber",
    "weberi": "weber",
    "weberii": "weber",
    "weberilor": "weber",
    "weberul": "weber",
    "weberului": "weber",
    "week-end-ul": "week-end",
    "week-end-ului": "week-end",
    "week-end-uri": "week-end",
    "week-end-urile": "week-end",
    "week-end-urilor": "week-end",
    "westernul": "western",
    "westernului": "western",
    "westernuri": "western",
    "westernurile": "western",
    "westernurilor": "western",
    "whiskyul": "whisky",
    "whiskyului": "whisky",
    "whiskyuri": "whisky",
    "whiskyurile": "whisky",
    "whiskyurilor": "whisky",
    "W": "wolfram",
    "wolframul": "wolfram",
    "wolframului": "wolfram",
    "wolframite": "wolframit",
    "wolframitele": "wolframit",
    "wolframitelor": "wolframit",
    "wolframitul": "wolframit",
    "wolframitului": "wolframit",
    "work-shopuri": "work-shop",
    "xenofoba": "xenofob",
    "xenofobă": "xenofob",
    "xenofobe": "xenofob",
    "xenofobei": "xenofob",
    "xenofobele": "xenofob",
    "xenofobelor": "xenofob",
    "xenofobi": "xenofob",
    "xenofobii": "xenofob",
    "xenofobilor": "xenofob",
    "xenofobul": "xenofob",
    "xenofobului": "xenofob",
    "xenofobia": "xenofobie",
    "xenofobiei": "xenofobie",
    "xenofobii": "xenofobie",
    "xenofobiile": "xenofobie",
    "xenofobiilor": "xenofobie",
    "xenomani": "xenoman",
    "xenomanii": "xenoman",
    "xenomanilor": "xenoman",
    "xenomanul": "xenoman",
    "xenomanului": "xenoman",
    "xenomana": "xenomană",
    "xenomane": "xenomană",
    "xenomanei": "xenomană",
    "xenomanele": "xenomană",
    "xenomanelor": "xenomană",
    "xenomania": "xenomanie",
    "xenomaniei": "xenomanie",
    "xenomanii": "xenomanie",
    "xenomaniile": "xenomanie",
    "xenomaniilor": "xenomanie",
    "Xe": "xenon",
    "xenonul": "xenon",
    "xenonului": "xenon",
    "xerofita": "xerofită",
    "xerofite": "xerofită",
    "xerofitei": "xerofită",
    "xerofitele": "xerofită",
    "xerofitelor": "xerofită",
    "xeroxul": "xerox",
    "xeroxului": "xerox",
    "xeroxuri": "xerox",
    "xeroxurile": "xerox",
    "xeroxurilor": "xerox",
    "xilografi": "xilograf",
    "xilografii": "xilograf",
    "xilografilor": "xilograf",
    "xilograful": "xilograf",
    "xilografului": "xilograf",
    "xilografia": "xilografie",
    "xilografiei": "xilografie",
    "xilografii": "xilografie",
    "xilografiile": "xilografie",
    "xilografiilor": "xilografie",
    "xilogravura": "xilogravură",
    "xilogravuri": "xilogravură",
    "xilogravurii": "xilogravură",
    "xilogravurile": "xilogravură",
    "xilogravurilor": "xilogravură",
    "yala": "yală",
    "yale": "yală",
    "yalei": "yală",
    "yalele": "yală",
    "yalelor": "yală",
    "yankei": "yankeu",
    "yankeii": "yankeu",
    "yankeilor": "yankeu",
    "yankeul": "yankeu",
    "yankeului": "yankeu",
    "yeni": "yen",
    "yenii": "yen",
    "yenilor": "yen",
    "yenul": "yen",
    "yenului": "yen",
    "yorkul": "york",
    "yorkului": "york",
    "yorkuri": "york",
    "yorkurile": "york",
    "yorkurilor": "york",
    "yterbiul": "yterbiu",
    "yterbiului": "yterbiu",
    "yuani": "yuan",
    "yuanii": "yuan",
    "yuanilor": "yuan",
    "yuanul": "yuan",
    "yuanului": "yuan",
    "zale": "za",
    "zalei": "za",
    "zalele": "za",
    "zalelor": "za",
    "zaua": "za",
    "zăbala": "zăbală",
    "zăbale": "zăbală",
    "zăbalei": "zăbală",
    "zăbalele": "zăbală",
    "zăbalelor": "zăbală",
    "zăbava": "zăbavă",
    "zăbave": "zăbavă",
    "zăbavei": "zăbavă",
    "zăbavele": "zăbavă",
    "zăbavelor": "zăbavă",
    "nemaizăbovind": "zăbovi",
    "nemaizăbovindu": "zăbovi",
    "nezăbovind": "zăbovi",
    "nezăbovindu": "zăbovi",
    "zăbovea": "zăbovi",
    "zăboveai": "zăbovi",
    "zăboveam": "zăbovi",
    "zăbovească": "zăbovi",
    "zăboveați": "zăbovi",
    "zăboveau": "zăbovi",
    "zăbovesc": "zăbovi",
    "zăbovește": "zăbovi",
    "zăbovești": "zăbovi",
    "zăbovii": "zăbovi",
    "zăbovim": "zăbovi",
    "zăbovind": "zăbovi",
    "zăbovindu": "zăbovi",
    "zăboviră": "zăbovi",
    "zăbovirăm": "zăbovi",
    "zăbovirăți": "zăbovi",
    "zăbovise": "zăbovi",
    "zăbovisem": "zăbovi",
    "zăboviseră": "zăbovi",
    "zăboviserăm": "zăbovi",
    "zăboviserăți": "zăbovi",
    "zăboviseși": "zăbovi",
    "zăboviși": "zăbovi",
    "zăbovit": "zăbovi",
    "zăboviți": "zăbovi",
    "zăbovitu": "zăbovi",
    "zăbovirea": "zăbovire",
    "zăbovireo": "zăbovire",
    "zăboviri": "zăbovire",
    "zăbovirii": "zăbovire",
    "zăbovirile": "zăbovire",
    "zăbovirilor": "zăbovire",
    "zăbovita": "zăbovit",
    "zăbovită": "zăbovit",
    "zăbovite": "zăbovit",
    "zăbovitei": "zăbovit",
    "zăbovitele": "zăbovit",
    "zăbovitelor": "zăbovit",
    "zăboviți": "zăbovit",
    "zăboviții": "zăbovit",
    "zăboviților": "zăbovit",
    "zăbovitul": "zăbovit",
    "zăbovitule": "zăbovit",
    "zăbovitului": "zăbovit",
    "zăbranice": "zăbranic",
    "zăbranicele": "zăbranic",
    "zăbranicelor": "zăbranic",
    "zăbranicul": "zăbranic",
    "zăbranicului": "zăbranic",
    "zăbreaua": "zăbrea",
    "zăbrele": "zăbrea",
    "zăbrelei": "zăbrea",
    "zăbrelele": "zăbrea",
    "zăbrelelor": "zăbrea",
    "zăbrelirea": "zăbrelire",
    "zăbreliri": "zăbrelire",
    "zăbrelirii": "zăbrelire",
    "zăbrelirile": "zăbrelire",
    "zăbrelirilor": "zăbrelire",
    "zăbrelita": "zăbrelit",
    "zăbrelită": "zăbrelit",
    "zăbrelite": "zăbrelit",
    "zăbrelitei": "zăbrelit",
    "zăbrelitele": "zăbrelit",
    "zăbrelitelor": "zăbrelit",
    "zăbreliți": "zăbrelit",
    "zăbreliții": "zăbrelit",
    "zăbreliților": "zăbrelit",
    "zăbrelitul": "zăbrelit",
    "zăbrelitului": "zăbrelit",
    "zăbune": "zăbun",
    "zăbunele": "zăbun",
    "zăbunelor": "zăbun",
    "zăbunul": "zăbun",
    "zăbunului": "zăbun",
    "zăcământul": "zăcământ",
    "zăcământului": "zăcământ",
    "zăcăminte": "zăcământ",
    "zăcămintele": "zăcământ",
    "zăcămintelor": "zăcământ",
    "zăcarea": "zăcare",
    "zăcări": "zăcare",
    "zăcării": "zăcare",
    "zăcările": "zăcare",
    "zăcărilor": "zăcare",
    "nemaizăcând": "zăcea",
    "nemaizăcându": "zăcea",
    "nezăcând": "zăcea",
    "nezăcându": "zăcea",
    "zac": "zăcea",
    "zacă": "zăcea",
    "zăcând": "zăcea",
    "zăcându": "zăcea",
    "zace": "zăcea",
    "zăceai": "zăcea",
    "zăceam": "zăcea",
    "zăceați": "zăcea",
    "zăceau": "zăcea",
    "zăcem": "zăcea",
    "zăceți": "zăcea",
    "zaci": "zăcea",
    "zăcu": "zăcea",
    "zăcui": "zăcea",
    "zăcură": "zăcea",
    "zăcurăm": "zăcea",
    "zăcurăți": "zăcea",
    "zăcuse": "zăcea",
    "zăcusem": "zăcea",
    "zăcuseră": "zăcea",
    "zăcuserăm": "zăcea",
    "zăcuserăți": "zăcea",
    "zăcuseși": "zăcea",
    "zăcuși": "zăcea",
    "zăcut": "zăcea",
    "zăcutu": "zăcea",
    "zăcuta": "zăcut",
    "zăcută": "zăcut",
    "zăcute": "zăcut",
    "zăcutei": "zăcut",
    "zăcutele": "zăcut",
    "zăcutelor": "zăcut",
    "zăcuți": "zăcut",
    "zăcuții": "zăcut",
    "zăcuților": "zăcut",
    "zăcutul": "zăcut",
    "zăcutului": "zăcut",
    "zadarul": "zadar",
    "zadarului": "zadar",
    "zădărârea": "zădărâre",
    "zădărâri": "zădărâre",
    "zădărârii": "zădărâre",
    "zădărârile": "zădărâre",
    "zădărâta": "zădărât",
    "zădărâtă": "zădărât",
    "zădărâte": "zădărât",
    "zădărâtei": "zădărât",
    "zădărâtele": "zădărât",
    "zădărâtelor": "zădărât",
    "zădărâți": "zădărât",
    "zădărâții": "zădărât",
    "zădărâților": "zădărât",
    "zădărâtul": "zădărât",
    "zădărâtului": "zădărât",
    "zădărâta": "zădărâtă",
    "zădărâte": "zădărâtă",
    "zădărâtei": "zădărâtă",
    "zădărâtele": "zădărâtă",
    "zădărâtelor": "zădărâtă",
    "nemaizădărând": "zădărî",
    "nemaizădărându": "zădărî",
    "nezădărând": "zădărî",
    "nezădărându": "zădărî",
    "zădăra": "zădărî",
    "zădărai": "zădărî",
    "zădărâi": "zădărî",
    "zădăram": "zădărî",
    "zădărâm": "zădărî",
    "zădărând": "zădărî",
    "zădărându": "zădărî",
    "zădărâră": "zădărî",
    "zădărârăm": "zădărî",
    "zădărârăți": "zădărî",
    "zădărăsc": "zădărî",
    "zădărască": "zădărî",
    "zădărâse": "zădărî",
    "zădărâsem": "zădărî",
    "zădărâseră": "zădărî",
    "zădărâserăm": "zădărî",
    "zădărâserăți": "zădărî",
    "zădărâseși": "zădărî",
    "zădărâși": "zădărî",
    "zădărăște": "zădărî",
    "zădărăști": "zădărî",
    "zădărât": "zădărî",
    "zădărați": "zădărî",
    "zădărâți": "zădărî",
    "zădărâtu": "zădărî",
    "zădărau": "zădărî",
    "zadarnica": "zadarnic",
    "zadarnică": "zadarnic",
    "zadarnice": "zadarnic",
    "zadarnicei": "zadarnic",
    "zadarnicele": "zadarnic",
    "zadarnicelor": "zadarnic",
    "zadarnici": "zadarnic",
    "zadarnicii": "zadarnic",
    "zadarnicilor": "zadarnic",
    "zadarnicul": "zadarnic",
    "zadarnicului": "zadarnic",
    "nemaizădărnicind": "zădărnici",
    "nemaizădărnicindu": "zădărnici",
    "nezădărnicind": "zădărnici",
    "nezădărnicindu": "zădărnici",
    "zădărnicea": "zădărnici",
    "zădărniceai": "zădărnici",
    "zădărniceam": "zădărnici",
    "zădărnicească": "zădărnici",
    "zădărniceați": "zădărnici",
    "zădărniceau": "zădărnici",
    "zădărnicesc": "zădărnici",
    "zădărnicește": "zădărnici",
    "zădărnicești": "zădărnici",
    "zădărnicii": "zădărnici",
    "zădărnicim": "zădărnici",
    "zădărnicind": "zădărnici",
    "zădărnicindu": "zădărnici",
    "zădărniciră": "zădărnici",
    "zădărnicirăm": "zădărnici",
    "zădărnicirăți": "zădărnici",
    "zădărnicise": "zădărnici",
    "zădărnicisem": "zădărnici",
    "zădărniciseră": "zădărnici",
    "zădărniciserăm": "zădărnici",
    "zădărniciserăți": "zădărnici",
    "zădărniciseși": "zădărnici",
    "zădărniciși": "zădărnici",
    "zădărnicit": "zădărnici",
    "zădărniciți": "zădărnici",
    "zădărnicitu": "zădărnici",
    "zădărnicia": "zădărnicie",
    "zădărniciei": "zădărnicie",
    "zădărnicii": "zădărnicie",
    "zădărniciile": "zădărnicie",
    "zădărniciilor": "zădărnicie",
    "zădărnicirea": "zădărnicire",
    "zădărniciri": "zădărnicire",
    "zădărnicirii": "zădărnicire",
    "zădărnicirile": "zădărnicire",
    "zădărnicita": "zădărnicit",
    "zădărnicită": "zădărnicit",
    "zădărnicite": "zădărnicit",
    "zădărnicitei": "zădărnicit",
    "zădărnicitele": "zădărnicit",
    "zădărnicitelor": "zădărnicit",
    "zădărniciți": "zădărnicit",
    "zădărniciții": "zădărnicit",
    "zădărniciților": "zădărnicit",
    "zădărnicitul": "zădărnicit",
    "zădărnicitului": "zădărnicit",
    "zăduful": "zăduf",
    "zădufului": "zăduf",
    "zădufuri": "zăduf",
    "zădufurile": "zăduf",
    "zădufurilor": "zăduf",
    "zăgazul": "zăgaz",
    "zăgazului": "zăgaz",
    "zăgazuri": "zăgaz",
    "zăgazurile": "zăgaz",
    "zăgazurilor": "zăgaz",
    "nemaizăgăzuind": "zăgăzui",
    "nemaizăgăzuindu": "zăgăzui",
    "nezăgăzuind": "zăgăzui",
    "nezăgăzuindu": "zăgăzui",
    "zăgăzuia": "zăgăzui",
    "zăgăzuiai": "zăgăzui",
    "zăgăzuiam": "zăgăzui",
    "zăgăzuiască": "zăgăzui",
    "zăgăzuiați": "zăgăzui",
    "zăgăzuiau": "zăgăzui",
    "zăgăzuiesc": "zăgăzui",
    "zăgăzuiește": "zăgăzui",
    "zăgăzuiești": "zăgăzui",
    "zăgăzuii": "zăgăzui",
    "zăgăzuim": "zăgăzui",
    "zăgăzuind": "zăgăzui",
    "zăgăzuindu": "zăgăzui",
    "zăgăzuiră": "zăgăzui",
    "zăgăzuirăm": "zăgăzui",
    "zăgăzuirăți": "zăgăzui",
    "zăgăzuise": "zăgăzui",
    "zăgăzuisem": "zăgăzui",
    "zăgăzuiseră": "zăgăzui",
    "zăgăzuiserăm": "zăgăzui",
    "zăgăzuiserăți": "zăgăzui",
    "zăgăzuiseși": "zăgăzui",
    "zăgăzuiși": "zăgăzui",
    "zăgăzuit": "zăgăzui",
    "zăgăzuiți": "zăgăzui",
    "zăgăzuitu": "zăgăzui",
    "zăgăzuirea": "zăgăzuire",
    "zăgăzuiri": "zăgăzuire",
    "zăgăzuirii": "zăgăzuire",
    "zăgăzuirile": "zăgăzuire",
    "zăgăzuita": "zăgăzuit",
    "zăgăzuită": "zăgăzuit",
    "zăgăzuite": "zăgăzuit",
    "zăgăzuitei": "zăgăzuit",
    "zăgăzuitele": "zăgăzuit",
    "zăgăzuitelor": "zăgăzuit",
    "zăgăzuiți": "zăgăzuit",
    "zăgăzuiții": "zăgăzuit",
    "zăgăzuiților": "zăgăzuit",
    "zăgăzuitul": "zăgăzuit",
    "zăgăzuitului": "zăgăzuit",
    "zahărul": "zahăr",
    "zahărule": "zahăr",
    "zahărului": "zahăr",
    "zahăr-zahăr": "zahăr",
    "zaharina": "zaharină",
    "zaharine": "zaharină",
    "zaharinei": "zaharină",
    "zaharinele": "zaharină",
    "zaharinelor": "zaharină",
    "zaiafetul": "zaiafet",
    "zaiafetului": "zaiafet",
    "zaiafeturi": "zaiafet",
    "zaiafeturile": "zaiafet",
    "zaiafeturilor": "zaiafet",
    "zala": "zală",
    "zale": "zală",
    "zalei": "zală",
    "zalele": "zală",
    "zalelor": "zală",
    "zălogul": "zălog",
    "zălogului": "zălog",
    "zăloguri": "zălog",
    "zălogurile": "zălog",
    "zălogurilor": "zălog",
    "nemaizălogind": "zălogi",
    "nemaizălogindu": "zălogi",
    "nezălogind": "zălogi",
    "nezălogindu": "zălogi",
    "zălogea": "zălogi",
    "zălogeai": "zălogi",
    "zălogeam": "zălogi",
    "zălogească": "zălogi",
    "zălogeați": "zălogi",
    "zălogeau": "zălogi",
    "zălogesc": "zălogi",
    "zălogește": "zălogi",
    "zălogești": "zălogi",
    "zălogii": "zălogi",
    "zălogim": "zălogi",
    "zălogind": "zălogi",
    "zălogindu": "zălogi",
    "zălogiră": "zălogi",
    "zălogirăm": "zălogi",
    "zălogirăți": "zălogi",
    "zălogise": "zălogi",
    "zălogisem": "zălogi",
    "zălogiseră": "zălogi",
    "zălogiserăm": "zălogi",
    "zălogiserăți": "zălogi",
    "zălogiseși": "zălogi",
    "zălogiși": "zălogi",
    "zălogit": "zălogi",
    "zălogiți": "zălogi",
    "zălogitu": "zălogi",
    "zălogirea": "zălogire",
    "zălogiri": "zălogire",
    "zălogirii": "zălogire",
    "zălogirile": "zălogire",
    "zălogita": "zălogit",
    "zălogită": "zălogit",
    "zălogite": "zălogit",
    "zălogitei": "zălogit",
    "zălogitele": "zălogit",
    "zălogitelor": "zălogit",
    "zălogiți": "zălogit",
    "zălogiții": "zălogit",
    "zălogiților": "zălogit",
    "zălogitul": "zălogit",
    "zălogitului": "zălogit",
    "zăluda": "zălud",
    "zăludă": "zălud",
    "zălude": "zălud",
    "zăludei": "zălud",
    "zăludele": "zălud",
    "zăludelor": "zălud",
    "zăludul": "zălud",
    "zăludului": "zălud",
    "zăluzi": "zălud",
    "zăluzii": "zălud",
    "zăluzilor": "zălud",
    "zâmbete": "zâmbet",
    "zâmbetele": "zâmbet",
    "zâmbetelor": "zâmbet",
    "zâmbetul": "zâmbet",
    "zâmbetule": "zâmbet",
    "zâmbetului": "zâmbet",
    "nemaizâmbind": "zâmbi",
    "nemaizâmbindu": "zâmbi",
    "nezâmbind": "zâmbi",
    "nezâmbindu": "zâmbi",
    "zâmbea": "zâmbi",
    "zâmbeai": "zâmbi",
    "zâmbeam": "zâmbi",
    "zâmbească": "zâmbi",
    "zâmbeați": "zâmbi",
    "zâmbeau": "zâmbi",
    "zâmbesc": "zâmbi",
    "zâmbește": "zâmbi",
    "zâmbești": "zâmbi",
    "zâmbii": "zâmbi",
    "zâmbim": "zâmbi",
    "zâmbind": "zâmbi",
    "zâmbindu": "zâmbi",
    "zâmbiră": "zâmbi",
    "zâmbirăm": "zâmbi",
    "zâmbirăți": "zâmbi",
    "zâmbise": "zâmbi",
    "zâmbisem": "zâmbi",
    "zâmbiseră": "zâmbi",
    "zâmbiserăm": "zâmbi",
    "zâmbiserăți": "zâmbi",
    "zâmbiseși": "zâmbi",
    "zâmbiși": "zâmbi",
    "zâmbit": "zâmbi",
    "zâmbiți": "zâmbi",
    "zâmbitu": "zâmbi",
    "zâmbirea": "zâmbire",
    "zâmbireo": "zâmbire",
    "zâmbiri": "zâmbire",
    "zâmbirii": "zâmbire",
    "zâmbirile": "zâmbire",
    "zâmbirilor": "zâmbire",
    "zâmbita": "zâmbit",
    "zâmbită": "zâmbit",
    "zâmbite": "zâmbit",
    "zâmbitei": "zâmbit",
    "zâmbitele": "zâmbit",
    "zâmbitelor": "zâmbit",
    "zâmbiți": "zâmbit",
    "zâmbiții": "zâmbit",
    "zâmbiților": "zâmbit",
    "zâmbito": "zâmbit",
    "zâmbitul": "zâmbit",
    "zâmbitule": "zâmbit",
    "zâmbitului": "zâmbit",
    "zâmbitoarea": "zâmbitoare",
    "zâmbitoarei": "zâmbitoare",
    "zâmbitoarele": "zâmbitoare",
    "zâmbitoarelor": "zâmbitoare",
    "zâmbitoare": "zâmbitor",
    "zâmbitoarea": "zâmbitor",
    "zâmbitoarei": "zâmbitor",
    "zâmbitoarele": "zâmbitor",
    "zâmbitoarelor": "zâmbitor",
    "zâmbitori": "zâmbitor",
    "zâmbitorii": "zâmbitor",
    "zâmbitorilor": "zâmbitor",
    "zâmbitorul": "zâmbitor",
    "zâmbitorului": "zâmbitor",
    "nemaizămislind": "zămisli",
    "nemaizămislindu": "zămisli",
    "nezămislind": "zămisli",
    "nezămislindu": "zămisli",
    "zămislea": "zămisli",
    "zămisleai": "zămisli",
    "zămisleam": "zămisli",
    "zămislească": "zămisli",
    "zămisleați": "zămisli",
    "zămisleau": "zămisli",
    "zămislesc": "zămisli",
    "zămislește": "zămisli",
    "zămislești": "zămisli",
    "zămislii": "zămisli",
    "zămislim": "zămisli",
    "zămislind": "zămisli",
    "zămislindu": "zămisli",
    "zămisliră": "zămisli",
    "zămislirăm": "zămisli",
    "zămislirăți": "zămisli",
    "zămislise": "zămisli",
    "zămislisem": "zămisli",
    "zămisliseră": "zămisli",
    "zămisliserăm": "zămisli",
    "zămisliserăți": "zămisli",
    "zămisliseși": "zămisli",
    "zămisliși": "zămisli",
    "zămislit": "zămisli",
    "zămisliți": "zămisli",
    "zămislitu": "zămisli",
    "zămislirea": "zămislire",
    "zămisliri": "zămislire",
    "zămislirii": "zămislire",
    "zămislirile": "zămislire",
    "zămislita": "zămislit",
    "zămislită": "zămislit",
    "zămislite": "zămislit",
    "zămislitei": "zămislit",
    "zămislitele": "zămislit",
    "zămislitelor": "zămislit",
    "zămisliți": "zămislit",
    "zămisliții": "zămislit",
    "zămisliților": "zămislit",
    "zămislitul": "zămislit",
    "zămislitului": "zămislit",
    "zămislitoarea": "zămislitoare",
    "zămislitoarei": "zămislitoare",
    "zămislitoarele": "zămislitoare",
    "zămislitoarelor": "zămislitoare",
    "zămislitoare": "zămislitor",
    "zămislitoarea": "zămislitor",
    "zămislitoarei": "zămislitor",
    "zămislitoarele": "zămislitor",
    "zămislitoarelor": "zămislitor",
    "zămislitori": "zămislitor",
    "zămislitorii": "zămislitor",
    "zămislitorilor": "zămislitor",
    "zămislitorul": "zămislitor",
    "zămislitorului": "zămislitor",
    "zâna": "zână",
    "zâne": "zână",
    "zânei": "zână",
    "zânele": "zână",
    "zânelor": "zână",
    "zănatica": "zănatic",
    "zănatică": "zănatic",
    "zănatice": "zănatic",
    "zănaticei": "zănatic",
    "zănaticele": "zănatic",
    "zănaticelor": "zănatic",
    "zănatici": "zănatic",
    "zănaticii": "zănatic",
    "zănaticilor": "zănatic",
    "zănaticul": "zănatic",
    "zănaticului": "zănatic",
    "nemaizăngănind": "zăngăni",
    "nemaizăngănindu": "zăngăni",
    "nezăngănind": "zăngăni",
    "nezăngănindu": "zăngăni",
    "zăngănea": "zăngăni",
    "zăngăneai": "zăngăni",
    "zăngăneam": "zăngăni",
    "zăngănească": "zăngăni",
    "zăngăneați": "zăngăni",
    "zăngăneau": "zăngăni",
    "zăngănesc": "zăngăni",
    "zăngănește": "zăngăni",
    "zăngănești": "zăngăni",
    "zăngănii": "zăngăni",
    "zăngănim": "zăngăni",
    "zăngănind": "zăngăni",
    "zăngănindu": "zăngăni",
    "zăngăniră": "zăngăni",
    "zăngănirăm": "zăngăni",
    "zăngănirăți": "zăngăni",
    "zăngănise": "zăngăni",
    "zăngănisem": "zăngăni",
    "zăngăniseră": "zăngăni",
    "zăngăniserăm": "zăngăni",
    "zăngăniserăți": "zăngăni",
    "zăngăniseși": "zăngăni",
    "zăngăniși": "zăngăni",
    "zăngănit": "zăngăni",
    "zăngăniți": "zăngăni",
    "zăngănitu": "zăngăni",
    "zăngănirea": "zăngănire",
    "zăngănireo": "zăngănire",
    "zăngăniri": "zăngănire",
    "zăngănirii": "zăngănire",
    "zăngănirile": "zăngănire",
    "zăngănirilor": "zăngănire",
    "zăngănita": "zăngănit",
    "zăngănită": "zăngănit",
    "zăngănite": "zăngănit",
    "zăngănitei": "zăngănit",
    "zăngănitele": "zăngănit",
    "zăngănitelor": "zăngănit",
    "zăngăniți": "zăngănit",
    "zăngăniții": "zăngănit",
    "zăngăniților": "zăngănit",
    "zăngănito": "zăngănit",
    "zăngănitul": "zăngănit",
    "zăngănitule": "zăngănit",
    "zăngănitului": "zăngănit",
    "zănoaga": "zănoagă",
    "zănoage": "zănoagă",
    "zănoagei": "zănoagă",
    "zănoagele": "zănoagă",
    "zănoagelor": "zănoagă",
    "zăpăceala": "zăpăceală",
    "zăpăceli": "zăpăceală",
    "zăpăcelii": "zăpăceală",
    "zăpăcelile": "zăpăceală",
    "nemaizăpăcind": "zăpăci",
    "nemaizăpăcindu": "zăpăci",
    "nezăpăcind": "zăpăci",
    "nezăpăcindu": "zăpăci",
    "zăpăcea": "zăpăci",
    "zăpăceai": "zăpăci",
    "zăpăceam": "zăpăci",
    "zăpăcească": "zăpăci",
    "zăpăceați": "zăpăci",
    "zăpăceau": "zăpăci",
    "zăpăcesc": "zăpăci",
    "zăpăcește": "zăpăci",
    "zăpăcești": "zăpăci",
    "zăpăcii": "zăpăci",
    "zăpăcim": "zăpăci",
    "zăpăcind": "zăpăci",
    "zăpăcindu": "zăpăci",
    "zăpăciră": "zăpăci",
    "zăpăcirăm": "zăpăci",
    "zăpăcirăți": "zăpăci",
    "zăpăcise": "zăpăci",
    "zăpăcisem": "zăpăci",
    "zăpăciseră": "zăpăci",
    "zăpăciserăm": "zăpăci",
    "zăpăciserăți": "zăpăci",
    "zăpăciseși": "zăpăci",
    "zăpăciși": "zăpăci",
    "zăpăcit": "zăpăci",
    "zăpăciți": "zăpăci",
    "zăpăcitu": "zăpăci",
    "zăpăcirea": "zăpăcire",
    "zăpăciri": "zăpăcire",
    "zăpăcirii": "zăpăcire",
    "zăpăcirile": "zăpăcire",
    "zăpăcita": "zăpăcit",
    "zăpăcită": "zăpăcit",
    "zăpăcite": "zăpăcit",
    "zăpăcitei": "zăpăcit",
    "zăpăcitele": "zăpăcit",
    "zăpăcitelor": "zăpăcit",
    "zăpăciți": "zăpăcit",
    "zăpăciții": "zăpăcit",
    "zăpăciților": "zăpăcit",
    "zăpăcitul": "zăpăcit",
    "zăpăcitului": "zăpăcit",
    "zăpăcita": "zăpăcită",
    "zăpăcite": "zăpăcită",
    "zăpăcitei": "zăpăcită",
    "zăpăcitele": "zăpăcită",
    "zăpăcitelor": "zăpăcită",
    "zăpăcitoare": "zăpăcitor",
    "zăpăcitoarea": "zăpăcitor",
    "zăpăcitoarei": "zăpăcitor",
    "zăpăcitoarele": "zăpăcitor",
    "zăpăcitoarelor": "zăpăcitor",
    "zăpăcitori": "zăpăcitor",
    "zăpăcitorii": "zăpăcitor",
    "zăpăcitorilor": "zăpăcitor",
    "zăpăcitorul": "zăpăcitor",
    "zăpăcitorului": "zăpăcitor",
    "zăpada": "zăpadă",
    "zăpado": "zăpadă",
    "zăpezi": "zăpadă",
    "zăpezii": "zăpadă",
    "zăpezile": "zăpadă",
    "zăpezilor": "zăpadă",
    "zapise": "zapis",
    "zapisele": "zapis",
    "zapiselor": "zapis",
    "zapisul": "zapis",
    "zapisului": "zapis",
    "zăplani": "zăplan",
    "zăplanii": "zăplan",
    "zăplanilor": "zăplan",
    "zăplanul": "zăplan",
    "zăplanului": "zăplan",
    "zăplazul": "zăplaz",
    "zăplazului": "zăplaz",
    "zăplazuri": "zăplaz",
    "zăplazurile": "zăplaz",
    "zăplazurilor": "zăplaz",
    "zăpoare": "zăpor",
    "zăpoarele": "zăpor",
    "zăpoarelor": "zăpor",
    "zăporul": "zăpor",
    "zăporului": "zăpor",
    "zăpușeala": "zăpușeală",
    "zăpușeli": "zăpușeală",
    "zăpușelii": "zăpușeală",
    "zăpușelile": "zăpușeală",
    "zăpușelilor": "zăpușeală",
    "nemaizăpușind": "zăpuși",
    "nemaizăpușindu": "zăpuși",
    "nezăpușind": "zăpuși",
    "nezăpușindu": "zăpuși",
    "zăpușea": "zăpuși",
    "zăpușeai": "zăpuși",
    "zăpușeam": "zăpuși",
    "zăpușească": "zăpuși",
    "zăpușeați": "zăpuși",
    "zăpușeau": "zăpuși",
    "zăpușesc": "zăpuși",
    "zăpușește": "zăpuși",
    "zăpușești": "zăpuși",
    "zăpușii": "zăpuși",
    "zăpușim": "zăpuși",
    "zăpușind": "zăpuși",
    "zăpușindu": "zăpuși",
    "zăpușiră": "zăpuși",
    "zăpușirăm": "zăpuși",
    "zăpușirăți": "zăpuși",
    "zăpușise": "zăpuși",
    "zăpușisem": "zăpuși",
    "zăpușiseră": "zăpuși",
    "zăpușiserăm": "zăpuși",
    "zăpușiserăți": "zăpuși",
    "zăpușiseși": "zăpuși",
    "zăpușiși": "zăpuși",
    "zăpușit": "zăpuși",
    "zăpușiți": "zăpuși",
    "zăpușitu": "zăpuși",
    "zăpușirea": "zăpușire",
    "zăpușiri": "zăpușire",
    "zăpușirii": "zăpușire",
    "zăpușirile": "zăpușire",
    "zăpușita": "zăpușit",
    "zăpușită": "zăpușit",
    "zăpușite": "zăpușit",
    "zăpușitei": "zăpușit",
    "zăpușitele": "zăpușit",
    "zăpușitelor": "zăpușit",
    "zăpușiți": "zăpușit",
    "zăpușiții": "zăpușit",
    "zăpușiților": "zăpușit",
    "zăpușitul": "zăpușit",
    "zăpușitului": "zăpușit",
    "zarul": "zar",
    "zarule": "zar",
    "zarului": "zar",
    "zaruri": "zar",
    "zarurile": "zar",
    "zarurilor": "zar",
    "zarafi": "zaraf",
    "zarafii": "zaraf",
    "zarafilor": "zaraf",
    "zaraful": "zaraf",
    "zarafului": "zaraf",
    "zarea": "zare",
    "zări": "zare",
    "zării": "zare",
    "zările": "zare",
    "zărilor": "zare",
    "nemaizărind": "zări",
    "nemaizărindu": "zări",
    "nezărind": "zări",
    "nezărindu": "zări",
    "zărea": "zări",
    "zăreai": "zări",
    "zăream": "zări",
    "zărească": "zări",
    "zăreați": "zări",
    "zăreau": "zări",
    "zăresc": "zări",
    "zărește": "zări",
    "zărești": "zări",
    "zării": "zări",
    "zărim": "zări",
    "zărind": "zări",
    "zărindu": "zări",
    "zăriră": "zări",
    "zărirăm": "zări",
    "zărirăți": "zări",
    "zărise": "zări",
    "zărisem": "zări",
    "zăriseră": "zări",
    "zăriserăm": "zări",
    "zăriserăți": "zări",
    "zăriseși": "zări",
    "zăriși": "zări",
    "zărit": "zări",
    "zăriți": "zări",
    "zăritu": "zări",
    "zărirea": "zărire",
    "zărireo": "zărire",
    "zăriri": "zărire",
    "zăririi": "zărire",
    "zăririle": "zărire",
    "zăririlor": "zărire",
    "zărita": "zărit",
    "zărită": "zărit",
    "zărite": "zărit",
    "zăritei": "zărit",
    "zăritele": "zărit",
    "zăritelor": "zărit",
    "zăriți": "zărit",
    "zăriții": "zărit",
    "zăriților": "zărit",
    "zărito": "zărit",
    "zăritul": "zărit",
    "zăritule": "zărit",
    "zăritului": "zărit",
    "Zărneștiul": "Zărnești",
    "Zărneștiului": "Zărnești",
    "zarva": "zarvă",
    "zarve": "zarvă",
    "zarvei": "zarvă",
    "zarvele": "zarvă",
    "zarvelor": "zarvă",
    "zarzavatul": "zarzavat",
    "zarzavatului": "zarzavat",
    "zarzavaturi": "zarzavat",
    "zarzavaturile": "zarzavat",
    "zarzavaturilor": "zarzavat",
    "zațul": "zaț",
    "zațului": "zaț",
    "zațuri": "zaț",
    "zațurile": "zaț",
    "zațurilor": "zaț",
    "zavera": "zaveră",
    "zavere": "zaveră",
    "zaverei": "zaveră",
    "zaverele": "zaveră",
    "zaverelor": "zaveră",
    "zăvodul": "zăvod",
    "zăvodului": "zăvod",
    "zăvoduri": "zăvod",
    "zăvodurile": "zăvod",
    "zăvodurilor": "zăvod",
    "zăvoaie": "zăvoi",
    "zăvoaiele": "zăvoi",
    "zăvoaielor": "zăvoi",
    "zăvoiul": "zăvoi",
    "zăvoiului": "zăvoi",
    "zăvoare": "zăvor",
    "zăvoarele": "zăvor",
    "zăvoarelor": "zăvor",
    "zăvorul": "zăvor",
    "zăvorule": "zăvor",
    "zăvorului": "zăvor",
    "zăvorârea": "zăvorâre",
    "zăvorâreo": "zăvorâre",
    "zăvorâri": "zăvorâre",
    "zăvorârii": "zăvorâre",
    "zăvorârile": "zăvorâre",
    "zăvorârilor": "zăvorâre",
    "zăvorâtă": "zăvorât",
    "zăvorâte": "zăvorât",
    "zăvorâți": "zăvorât",
    "zăvorâtul": "zăvorât",
    "zăvorâtule": "zăvorât",
    "zăvorâtului": "zăvorât",
    "nemaizăvorând": "zăvorî",
    "nemaizăvorându": "zăvorî",
    "nezăvorând": "zăvorî",
    "nezăvorându": "zăvorî",
    "zăvora": "zăvorî",
    "zăvorai": "zăvorî",
    "zăvorâi": "zăvorî",
    "zăvoram": "zăvorî",
    "zăvorâm": "zăvorî",
    "zăvorând": "zăvorî",
    "zăvorându": "zăvorî",
    "zăvorâră": "zăvorî",
    "zăvorârăm": "zăvorî",
    "zăvorârăți": "zăvorî",
    "zăvorăsc": "zăvorî",
    "zăvorască": "zăvorî",
    "zăvorâse": "zăvorî",
    "zăvorâsem": "zăvorî",
    "zăvorâseră": "zăvorî",
    "zăvorâserăm": "zăvorî",
    "zăvorâserăți": "zăvorî",
    "zăvorâseși": "zăvorî",
    "zăvorâși": "zăvorî",
    "zăvorăște": "zăvorî",
    "zăvorăști": "zăvorî",
    "zăvorât": "zăvorî",
    "zăvorați": "zăvorî",
    "zăvorâți": "zăvorî",
    "zăvorâtu": "zăvorî",
    "zăvorau": "zăvorî",
    "zâzania": "zâzanie",
    "zâzaniei": "zâzanie",
    "zâzanii": "zâzanie",
    "zâzaniile": "zâzanie",
    "zâzaniilor": "zâzanie",
    "zbanghia": "zbanghiu",
    "zbanghie": "zbanghiu",
    "zbanghiei": "zbanghiu",
    "zbanghii": "zbanghiu",
    "zbanghiii": "zbanghiu",
    "zbanghiile": "zbanghiu",
    "zbanghiilor": "zbanghiu",
    "zbanghiul": "zbanghiu",
    "zbanghiului": "zbanghiu",
    "zbânțuia": "zbânțui",
    "zbânțuiai": "zbânțui",
    "zbânțuiam": "zbânțui",
    "zbânțuiați": "zbânțui",
    "zbânțuiau": "zbânțui",
    "zbânțuie": "zbânțui",
    "zbânțuii": "zbânțui",
    "zbânțuim": "zbânțui",
    "zbânțuind": "zbânțui",
    "zbânțuindu": "zbânțui",
    "zbânțuiră": "zbânțui",
    "zbânțuirăm": "zbânțui",
    "zbânțuirăți": "zbânțui",
    "zbânțuise": "zbânțui",
    "zbânțuisem": "zbânțui",
    "zbânțuiseră": "zbânțui",
    "zbânțuiserăm": "zbânțui",
    "zbânțuiserăți": "zbânțui",
    "zbânțuiseși": "zbânțui",
    "zbânțuiși": "zbânțui",
    "zbânțuit": "zbânțui",
    "zbânțuiți": "zbânțui",
    "zbânțuirea": "zbânțuire",
    "zbânțuireo": "zbânțuire",
    "zbânțuiri": "zbânțuire",
    "zbânțuirii": "zbânțuire",
    "zbânțuirile": "zbânțuire",
    "zbânțuirilor": "zbânțuire",
    "zbânțuită": "zbânțuit",
    "zbânțuite": "zbânțuit",
    "zbânțuiți": "zbânțuit",
    "nemaizbârcind": "zbârci",
    "nemaizbârcindu": "zbârci",
    "nezbârcind": "zbârci",
    "nezbârcindu": "zbârci",
    "zbârcea": "zbârci",
    "zbârceai": "zbârci",
    "zbârceam": "zbârci",
    "zbârcească": "zbârci",
    "zbârceați": "zbârci",
    "zbârceau": "zbârci",
    "zbârcesc": "zbârci",
    "zbârcește": "zbârci",
    "zbârcești": "zbârci",
    "zbârcii": "zbârci",
    "zbârcim": "zbârci",
    "zbârcind": "zbârci",
    "zbârcindu": "zbârci",
    "zbârciră": "zbârci",
    "zbârcirăm": "zbârci",
    "zbârcirăți": "zbârci",
    "zbârcise": "zbârci",
    "zbârcisem": "zbârci",
    "zbârciseră": "zbârci",
    "zbârciserăm": "zbârci",
    "zbârciserăți": "zbârci",
    "zbârciseși": "zbârci",
    "zbârciși": "zbârci",
    "zbârcit": "zbârci",
    "zbârciți": "zbârci",
    "zbârcitu": "zbârci",
    "zbârcirea": "zbârcire",
    "zbârcireo": "zbârcire",
    "zbârciri": "zbârcire",
    "zbârcirii": "zbârcire",
    "zbârcirile": "zbârcire",
    "zbârcirilor": "zbârcire",
    "zbârcita": "zbârcit",
    "zbârcită": "zbârcit",
    "zbârcite": "zbârcit",
    "zbârcitei": "zbârcit",
    "zbârcitele": "zbârcit",
    "zbârcitelor": "zbârcit",
    "zbârciți": "zbârcit",
    "zbârciții": "zbârcit",
    "zbârciților": "zbârcit",
    "zbârcito": "zbârcit",
    "zbârcitul": "zbârcit",
    "zbârcitule": "zbârcit",
    "zbârcitului": "zbârcit",
    "zbârcita": "zbârcită",
    "zbârcite": "zbârcită",
    "zbârcitei": "zbârcită",
    "zbârcitele": "zbârcită",
    "zbârcitelor": "zbârcită",
    "zbârcito": "zbârcită",
    "zbârlita": "zbârlit",
    "zbârlită": "zbârlit",
    "zbârlite": "zbârlit",
    "zbârlitei": "zbârlit",
    "zbârlitele": "zbârlit",
    "zbârlitelor": "zbârlit",
    "zbârliți": "zbârlit",
    "zbârliții": "zbârlit",
    "zbârliților": "zbârlit",
    "zbârlitul": "zbârlit",
    "zbârlitului": "zbârlit",
    "zbârlita": "zbârlită",
    "zbârlite": "zbârlită",
    "zbârlitei": "zbârlită",
    "zbârlitele": "zbârlită",
    "zbârlitelor": "zbârlită",
    "zbârnâia": "zbârnâi",
    "zbârnâiai": "zbârnâi",
    "zbârnâiam": "zbârnâi",
    "zbârnâiați": "zbârnâi",
    "zbârnâiau": "zbârnâi",
    "zbârnâie": "zbârnâi",
    "zbârnâiește": "zbârnâi",
    "zbârnâii": "zbârnâi",
    "zbârnâim": "zbârnâi",
    "zbârnâind": "zbârnâi",
    "zbârnâindu": "zbârnâi",
    "zbârnâiră": "zbârnâi",
    "zbârnâirăm": "zbârnâi",
    "zbârnâirăți": "zbârnâi",
    "zbârnâise": "zbârnâi",
    "zbârnâisem": "zbârnâi",
    "zbârnâiseră": "zbârnâi",
    "zbârnâiserăm": "zbârnâi",
    "zbârnâiserăți": "zbârnâi",
    "zbârnâiseși": "zbârnâi",
    "zbârnâiși": "zbârnâi",
    "zbârnâit": "zbârnâi",
    "zbârnâiți": "zbârnâi",
    "zbârnâitu": "zbârnâi",
    "zbârnâită": "zbârnâit",
    "zbârnâite": "zbârnâit",
    "zbârnâiți": "zbârnâit",
    "nemaizbătând": "zbate",
    "nemaizbătându": "zbate",
    "nezbătând": "zbate",
    "nezbătându": "zbate",
    "zbat": "zbate",
    "zbată": "zbate",
    "zbătând": "zbate",
    "zbătându": "zbate",
    "zbătea": "zbate",
    "zbăteai": "zbate",
    "zbăteam": "zbate",
    "zbăteați": "zbate",
    "zbăteau": "zbate",
    "zbatem": "zbate",
    "zbateți": "zbate",
    "zbați": "zbate",
    "zbătu": "zbate",
    "zbătui": "zbate",
    "zbătură": "zbate",
    "zbăturăm": "zbate",
    "zbăturăți": "zbate",
    "zbătuse": "zbate",
    "zbătusem": "zbate",
    "zbătuseră": "zbate",
    "zbătuserăm": "zbate",
    "zbătuserăți": "zbate",
    "zbătuseși": "zbate",
    "zbătuși": "zbate",
    "zbătut": "zbate",
    "zbătutu": "zbate",
    "zbaterea": "zbatere",
    "zbatereo": "zbatere",
    "zbateri": "zbatere",
    "zbaterii": "zbatere",
    "zbaterile": "zbatere",
    "zbaterilor": "zbatere",
    "zbătuta": "zbătut",
    "zbătută": "zbătut",
    "zbătute": "zbătut",
    "zbătutei": "zbătut",
    "zbătutele": "zbătut",
    "zbătutelor": "zbătut",
    "zbătuți": "zbătut",
    "zbătuții": "zbătut",
    "zbătuților": "zbătut",
    "zbătuto": "zbătut",
    "zbătutul": "zbătut",
    "zbătutule": "zbătut",
    "zbătutului": "zbătut",
    "nemaizbicind": "zbici",
    "nemaizbicindu": "zbici",
    "nezbicind": "zbici",
    "nezbicindu": "zbici",
    "zbicea": "zbici",
    "zbiceai": "zbici",
    "zbiceam": "zbici",
    "zbicească": "zbici",
    "zbiceați": "zbici",
    "zbiceau": "zbici",
    "zbicesc": "zbici",
    "zbicește": "zbici",
    "zbicești": "zbici",
    "zbicii": "zbici",
    "zbicim": "zbici",
    "zbicind": "zbici",
    "zbicindu": "zbici",
    "zbiciră": "zbici",
    "zbicirăm": "zbici",
    "zbicirăți": "zbici",
    "zbicise": "zbici",
    "zbicisem": "zbici",
    "zbiciseră": "zbici",
    "zbiciserăm": "zbici",
    "zbiciserăți": "zbici",
    "zbiciseși": "zbici",
    "zbiciși": "zbici",
    "zbicit": "zbici",
    "zbiciți": "zbici",
    "zbicitu": "zbici",
    "zbicirea": "zbicire",
    "zbiciri": "zbicire",
    "zbicirii": "zbicire",
    "zbicirile": "zbicire",
    "zbicita": "zbicit",
    "zbicită": "zbicit",
    "zbicite": "zbicit",
    "zbicitei": "zbicit",
    "zbicitele": "zbicit",
    "zbicitelor": "zbicit",
    "zbiciți": "zbicit",
    "zbiciții": "zbicit",
    "zbiciților": "zbicit",
    "zbicitul": "zbicit",
    "zbicitului": "zbicit",
    "nemaizbierând": "zbiera",
    "nemaizbierându": "zbiera",
    "nezbierând": "zbiera",
    "nezbierându": "zbiera",
    "zbiară": "zbiera",
    "zbier": "zbiera",
    "zbieră": "zbiera",
    "zbierai": "zbiera",
    "zbieram": "zbiera",
    "zbierăm": "zbiera",
    "zbierând": "zbiera",
    "zbierându": "zbiera",
    "zbierară": "zbiera",
    "zbierarăm": "zbiera",
    "zbierarăți": "zbiera",
    "zbierase": "zbiera",
    "zbierasem": "zbiera",
    "zbieraseră": "zbiera",
    "zbieraserăm": "zbiera",
    "zbieraserăți": "zbiera",
    "zbieraseși": "zbiera",
    "zbierași": "zbiera",
    "zbierat": "zbiera",
    "zbierați": "zbiera",
    "zbieratu": "zbiera",
    "zbierau": "zbiera",
    "zbiere": "zbiera",
    "zbieri": "zbiera",
    "zbierarea": "zbierare",
    "zbierareo": "zbierare",
    "zbierări": "zbierare",
    "zbierării": "zbierare",
    "zbierările": "zbierare",
    "zbierărilor": "zbierare",
    "zbierata": "zbierat",
    "zbierată": "zbierat",
    "zbierate": "zbierat",
    "zbieratei": "zbierat",
    "zbieratele": "zbierat",
    "zbieratelor": "zbierat",
    "zbierați": "zbierat",
    "zbierații": "zbierat",
    "zbieraților": "zbierat",
    "zbierato": "zbierat",
    "zbieratul": "zbierat",
    "zbieratule": "zbierat",
    "zbieratului": "zbierat",
    "zbierăte": "zbierăt",
    "zbierătele": "zbierăt",
    "zbierătelor": "zbierăt",
    "zbierătul": "zbierăt",
    "zbierătule": "zbierăt",
    "zbierătului": "zbierăt",
    "zbierete": "zbieret",
    "zbieretele": "zbieret",
    "zbieretelor": "zbieret",
    "zbieretul": "zbieret",
    "zbieretului": "zbieret",
    "zbilțul": "zbilț",
    "zbilțului": "zbilț",
    "zbilțuri": "zbilț",
    "zbilțurile": "zbilț",
    "zbilțurilor": "zbilț",
    "zbiri": "zbir",
    "zbirii": "zbir",
    "zbirilor": "zbir",
    "zbirul": "zbir",
    "zbirului": "zbir",
    "zborul": "zbor",
    "zborului": "zbor",
    "zboruri": "zbor",
    "zborurile": "zbor",
    "zborurilor": "zbor",
    "zbuciume": "zbucium",
    "zbuciumele": "zbucium",
    "zbuciumelor": "zbucium",
    "zbuciumul": "zbucium",
    "zbuciumului": "zbucium",
    "nemaizbuciumând": "zbuciuma",
    "nemaizbuciumându": "zbuciuma",
    "nezbuciumând": "zbuciuma",
    "nezbuciumându": "zbuciuma",
    "zbucium": "zbuciuma",
    "zbuciumă": "zbuciuma",
    "zbuciumai": "zbuciuma",
    "zbuciumam": "zbuciuma",
    "zbuciumăm": "zbuciuma",
    "zbuciumând": "zbuciuma",
    "zbuciumându": "zbuciuma",
    "zbuciumară": "zbuciuma",
    "zbuciumarăm": "zbuciuma",
    "zbuciumarăți": "zbuciuma",
    "zbuciumase": "zbuciuma",
    "zbuciumasem": "zbuciuma",
    "zbuciumaseră": "zbuciuma",
    "zbuciumaserăm": "zbuciuma",
    "zbuciumaserăți": "zbuciuma",
    "zbuciumaseși": "zbuciuma",
    "zbuciumași": "zbuciuma",
    "zbuciumat": "zbuciuma",
    "zbuciumați": "zbuciuma",
    "zbuciumatu": "zbuciuma",
    "zbuciumau": "zbuciuma",
    "zbuciume": "zbuciuma",
    "zbuciumi": "zbuciuma",
    "zbuciumarea": "zbuciumare",
    "zbuciumări": "zbuciumare",
    "zbuciumării": "zbuciumare",
    "zbuciumările": "zbuciumare",
    "zbuciumata": "zbuciumat",
    "zbuciumată": "zbuciumat",
    "zbuciumate": "zbuciumat",
    "zbuciumatei": "zbuciumat",
    "zbuciumatele": "zbuciumat",
    "zbuciumatelor": "zbuciumat",
    "zbuciumați": "zbuciumat",
    "zbuciumații": "zbuciumat",
    "zbuciumaților": "zbuciumat",
    "zbuciumatul": "zbuciumat",
    "zbuciumatului": "zbuciumat",
    "zbuciumata": "zbuciumată",
    "zbuciumate": "zbuciumată",
    "zbuciumatei": "zbuciumată",
    "zbuciumatele": "zbuciumată",
    "zbuciumatelor": "zbuciumată",
    "nemaizbughind": "zbughi",
    "nemaizbughindu": "zbughi",
    "nezbughind": "zbughi",
    "nezbughindu": "zbughi",
    "zbughea": "zbughi",
    "zbugheai": "zbughi",
    "zbugheam": "zbughi",
    "zbughească": "zbughi",
    "zbugheați": "zbughi",
    "zbugheau": "zbughi",
    "zbughesc": "zbughi",
    "zbughește": "zbughi",
    "zbughești": "zbughi",
    "zbughii": "zbughi",
    "zbughim": "zbughi",
    "zbughind": "zbughi",
    "zbughindu": "zbughi",
    "zbughiră": "zbughi",
    "zbughirăm": "zbughi",
    "zbughirăți": "zbughi",
    "zbughise": "zbughi",
    "zbughisem": "zbughi",
    "zbughiseră": "zbughi",
    "zbughiserăm": "zbughi",
    "zbughiserăți": "zbughi",
    "zbughiseși": "zbughi",
    "zbughiși": "zbughi",
    "zbughit": "zbughi",
    "zbughiți": "zbughi",
    "zbughitu": "zbughi",
    "zbughirea": "zbughire",
    "zbughiri": "zbughire",
    "zbughirii": "zbughire",
    "zbughirile": "zbughire",
    "zbughita": "zbughit",
    "zbughită": "zbughit",
    "zbughite": "zbughit",
    "zbughitei": "zbughit",
    "zbughitele": "zbughit",
    "zbughitelor": "zbughit",
    "zbughiți": "zbughit",
    "zbughiții": "zbughit",
    "zbughiților": "zbughit",
    "zbughitul": "zbughit",
    "zbughitului": "zbughit",
    "nemaizburând": "zbura",
    "nemaizburându": "zbura",
    "nezburând": "zbura",
    "nezburându": "zbura",
    "zboară": "zbura",
    "zboare": "zbura",
    "zbor": "zbura",
    "zbori": "zbura",
    "zbura'": "zbura",
    "zbură": "zbura",
    "zburai": "zbura",
    "zburam": "zbura",
    "zburăm": "zbura",
    "zburând": "zbura",
    "zburându": "zbura",
    "zburară": "zbura",
    "zburarăm": "zbura",
    "zburarăți": "zbura",
    "zburase": "zbura",
    "zburasem": "zbura",
    "zburaseră": "zbura",
    "zburaserăm": "zbura",
    "zburaserăți": "zbura",
    "zburaseși": "zbura",
    "zburași": "zbura",
    "zburat": "zbura",
    "zburați": "zbura",
    "zburatu": "zbura",
    "zburau": "zbura",
    "zburarea": "zburare",
    "zburareo": "zburare",
    "zburări": "zburare",
    "zburării": "zburare",
    "zburările": "zburare",
    "zburărilor": "zburare",
    "zbura'": "zburat",
    "zburata": "zburat",
    "zburată": "zburat",
    "zburate": "zburat",
    "zburatei": "zburat",
    "zburatele": "zburat",
    "zburatelor": "zburat",
    "zburați": "zburat",
    "zburații": "zburat",
    "zburaților": "zburat",
    "zburato": "zburat",
    "zburatul": "zburat",
    "zburatule": "zburat",
    "zburatului": "zburat",
    "nemaizburătăcind": "zburătăci",
    "nemaizburătăcindu": "zburătăci",
    "nezburătăcind": "zburătăci",
    "nezburătăcindu": "zburătăci",
    "zburătăcea": "zburătăci",
    "zburătăceai": "zburătăci",
    "zburătăceam": "zburătăci",
    "zburătăcească": "zburătăci",
    "zburătăceați": "zburătăci",
    "zburătăceau": "zburătăci",
    "zburătăcesc": "zburătăci",
    "zburătăcește": "zburătăci",
    "zburătăcești": "zburătăci",
    "zburătăcii": "zburătăci",
    "zburătăcim": "zburătăci",
    "zburătăcind": "zburătăci",
    "zburătăcindu": "zburătăci",
    "zburătăciră": "zburătăci",
    "zburătăcirăm": "zburătăci",
    "zburătăcirăți": "zburătăci",
    "zburătăcise": "zburătăci",
    "zburătăcisem": "zburătăci",
    "zburătăciseră": "zburătăci",
    "zburătăciserăm": "zburătăci",
    "zburătăciserăți": "zburătăci",
    "zburătăciseși": "zburătăci",
    "zburătăciși": "zburătăci",
    "zburătăcit": "zburătăci",
    "zburătăciți": "zburătăci",
    "zburătăcitu": "zburătăci",
    "zburătăcirea": "zburătăcire",
    "zburătăciri": "zburătăcire",
    "zburătăcirii": "zburătăcire",
    "zburătăcirile": "zburătăcire",
    "zburătăcita": "zburătăcit",
    "zburătăcită": "zburătăcit",
    "zburătăcite": "zburătăcit",
    "zburătăcitei": "zburătăcit",
    "zburătăcitele": "zburătăcit",
    "zburătăcitelor": "zburătăcit",
    "zburătăciți": "zburătăcit",
    "zburătăciții": "zburătăcit",
    "zburătăciților": "zburătăcit",
    "zburătăcitul": "zburătăcit",
    "zburătăcitului": "zburătăcit",
    "zburătoarea": "zburătoare",
    "zburătoarei": "zburătoare",
    "zburătoarele": "zburătoare",
    "zburătoarelor": "zburătoare",
    "zburătoare": "zburător",
    "zburătoarea": "zburător",
    "zburătoarei": "zburător",
    "zburătoarele": "zburător",
    "zburătoarelor": "zburător",
    "zburători": "zburător",
    "zburătorii": "zburător",
    "zburătorilor": "zburător",
    "zburătorul": "zburător",
    "zburătorului": "zburător",
    "nemaizburdând": "zburda",
    "nemaizburdându": "zburda",
    "nezburdând": "zburda",
    "nezburdându": "zburda",
    "zburd": "zburda",
    "zburdă": "zburda",
    "zburdai": "zburda",
    "zburdam": "zburda",
    "zburdăm": "zburda",
    "zburdând": "zburda",
    "zburdându": "zburda",
    "zburdară": "zburda",
    "zburdarăm": "zburda",
    "zburdarăți": "zburda",
    "zburdase": "zburda",
    "zburdasem": "zburda",
    "zburdaseră": "zburda",
    "zburdaserăm": "zburda",
    "zburdaserăți": "zburda",
    "zburdaseși": "zburda",
    "zburdași": "zburda",
    "zburdat": "zburda",
    "zburdați": "zburda",
    "zburdatu": "zburda",
    "zburdau": "zburda",
    "zburde": "zburda",
    "zburzi": "zburda",
    "zburdată": "zburdat",
    "zburdate": "zburdat",
    "zburdați": "zburdat",
    "zburleala": "zburleală",
    "zburleli": "zburleală",
    "zburlelii": "zburleală",
    "zburlelile": "zburleală",
    "zburlelilor": "zburleală",
    "zburlea": "zburli",
    "zburleai": "zburli",
    "zburleam": "zburli",
    "zburlească": "zburli",
    "zburleați": "zburli",
    "zburleau": "zburli",
    "zburlesc": "zburli",
    "zburlește": "zburli",
    "zburlești": "zburli",
    "zburlii": "zburli",
    "zburlim": "zburli",
    "zburlind": "zburli",
    "zburlindu": "zburli",
    "zburliră": "zburli",
    "zburlirăm": "zburli",
    "zburlirăți": "zburli",
    "zburlise": "zburli",
    "zburlisem": "zburli",
    "zburliseră": "zburli",
    "zburliserăm": "zburli",
    "zburliserăți": "zburli",
    "zburliseși": "zburli",
    "zburliși": "zburli",
    "zburlit": "zburli",
    "zburliți": "zburli",
    "zburlitu": "zburli",
    "zburlirea": "zburlire",
    "zburlireo": "zburlire",
    "zburliri": "zburlire",
    "zburlirii": "zburlire",
    "zburlirile": "zburlire",
    "zburlirilor": "zburlire",
    "zburlita": "zburlit",
    "zburlită": "zburlit",
    "zburlite": "zburlit",
    "zburlitei": "zburlit",
    "zburlitele": "zburlit",
    "zburlitelor": "zburlit",
    "zburliți": "zburlit",
    "zburliții": "zburlit",
    "zburliților": "zburlit",
    "zburlito": "zburlit",
    "zburlitul": "zburlit",
    "zburlitule": "zburlit",
    "zburlitului": "zburlit",
    "zdragoni": "zdragon",
    "zdragonii": "zdragon",
    "zdragonilor": "zdragon",
    "zdragonul": "zdragon",
    "zdragonului": "zdragon",
    "zdrahoni": "zdrahon",
    "zdrahonii": "zdrahon",
    "zdrahonilor": "zdrahon",
    "zdrahonul": "zdrahon",
    "zdrahonule": "zdrahon",
    "zdrahonului": "zdrahon",
    "zdravăna": "zdravăn",
    "zdravănă": "zdravăn",
    "zdravănul": "zdravăn",
    "zdravănului": "zdravăn",
    "zdravene": "zdravăn",
    "zdravenei": "zdravăn",
    "zdravenele": "zdravăn",
    "zdravenelor": "zdravăn",
    "zdraveni": "zdravăn",
    "zdravenii": "zdravăn",
    "zdravenilor": "zdravăn",
    "zdreanța": "zdreanță",
    "zdreanțo": "zdreanță",
    "zdrențe": "zdreanță",
    "zdrenței": "zdreanță",
    "zdrențele": "zdreanță",
    "zdrențelor": "zdreanță",
    "nemaizdrelind": "zdreli",
    "nemaizdrelindu": "zdreli",
    "nezdrelind": "zdreli",
    "nezdrelindu": "zdreli",
    "zdrelea": "zdreli",
    "zdreleai": "zdreli",
    "zdreleam": "zdreli",
    "zdrelească": "zdreli",
    "zdreleați": "zdreli",
    "zdreleau": "zdreli",
    "zdrelesc": "zdreli",
    "zdrelește": "zdreli",
    "zdrelești": "zdreli",
    "zdrelii": "zdreli",
    "zdrelim": "zdreli",
    "zdrelind": "zdreli",
    "zdrelindu": "zdreli",
    "zdreliră": "zdreli",
    "zdrelirăm": "zdreli",
    "zdrelirăți": "zdreli",
    "zdrelise": "zdreli",
    "zdrelisem": "zdreli",
    "zdreliseră": "zdreli",
    "zdreliserăm": "zdreli",
    "zdreliserăți": "zdreli",
    "zdreliseși": "zdreli",
    "zdreliși": "zdreli",
    "zdrelit": "zdreli",
    "zdreliți": "zdreli",
    "zdrelitu": "zdreli",
    "zdrelirea": "zdrelire",
    "zdreliri": "zdrelire",
    "zdrelirii": "zdrelire",
    "zdrelirile": "zdrelire",
    "zdrelita": "zdrelit",
    "zdrelită": "zdrelit",
    "zdrelite": "zdrelit",
    "zdrelitei": "zdrelit",
    "zdrelitele": "zdrelit",
    "zdrelitelor": "zdrelit",
    "zdreliți": "zdrelit",
    "zdreliții": "zdrelit",
    "zdreliților": "zdrelit",
    "zdrelitul": "zdrelit",
    "zdrelitului": "zdrelit",
    "zdrelita": "zdrelită",
    "zdrelite": "zdrelită",
    "zdrelitei": "zdrelită",
    "zdrelitele": "zdrelită",
    "zdrelitelor": "zdrelită",
    "nemaizdrențuind": "zdrențui",
    "nemaizdrențuindu": "zdrențui",
    "nezdrențuind": "zdrențui",
    "nezdrențuindu": "zdrențui",
    "zdrențuia": "zdrențui",
    "zdrențuiai": "zdrențui",
    "zdrențuiam": "zdrențui",
    "zdrențuiască": "zdrențui",
    "zdrențuiați": "zdrențui",
    "zdrențuiau": "zdrențui",
    "zdrențuiesc": "zdrențui",
    "zdrențuiește": "zdrențui",
    "zdrențuiești": "zdrențui",
    "zdrențuii": "zdrențui",
    "zdrențuim": "zdrențui",
    "zdrențuind": "zdrențui",
    "zdrențuindu": "zdrențui",
    "zdrențuiră": "zdrențui",
    "zdrențuirăm": "zdrențui",
    "zdrențuirăți": "zdrențui",
    "zdrențuise": "zdrențui",
    "zdrențuisem": "zdrențui",
    "zdrențuiseră": "zdrențui",
    "zdrențuiserăm": "zdrențui",
    "zdrențuiserăți": "zdrențui",
    "zdrențuiseși": "zdrențui",
    "zdrențuiși": "zdrențui",
    "zdrențuit": "zdrențui",
    "zdrențuiți": "zdrențui",
    "zdrențuitu": "zdrențui",
    "zdrențuirea": "zdrențuire",
    "zdrențuireo": "zdrențuire",
    "zdrențuiri": "zdrențuire",
    "zdrențuirii": "zdrențuire",
    "zdrențuirile": "zdrențuire",
    "zdrențuirilor": "zdrențuire",
    "zdrențuita": "zdrențuit",
    "zdrențuită": "zdrențuit",
    "zdrențuite": "zdrențuit",
    "zdrențuitei": "zdrențuit",
    "zdrențuitele": "zdrențuit",
    "zdrențuitelor": "zdrențuit",
    "zdrențuiți": "zdrențuit",
    "zdrențuiții": "zdrențuit",
    "zdrențuiților": "zdrențuit",
    "zdrențuito": "zdrențuit",
    "zdrențuitul": "zdrențuit",
    "zdrențuitule": "zdrențuit",
    "zdrențuitului": "zdrențuit",
    "zdrențuita": "zdrențuită",
    "zdrențuite": "zdrențuită",
    "zdrențuitei": "zdrențuită",
    "zdrențuitele": "zdrențuită",
    "zdrențuitelor": "zdrențuită",
    "zdrențuito": "zdrențuită",
    "nemaizdrobind": "zdrobi",
    "nemaizdrobindu": "zdrobi",
    "nezdrobind": "zdrobi",
    "nezdrobindu": "zdrobi",
    "zdrobea": "zdrobi",
    "zdrobeai": "zdrobi",
    "zdrobeam": "zdrobi",
    "zdrobească": "zdrobi",
    "zdrobeați": "zdrobi",
    "zdrobeau": "zdrobi",
    "zdrobesc": "zdrobi",
    "zdrobește": "zdrobi",
    "zdrobești": "zdrobi",
    "zdrobii": "zdrobi",
    "zdrobim": "zdrobi",
    "zdrobind": "zdrobi",
    "zdrobindu": "zdrobi",
    "zdrobiră": "zdrobi",
    "zdrobirăm": "zdrobi",
    "zdrobirăți": "zdrobi",
    "zdrobise": "zdrobi",
    "zdrobisem": "zdrobi",
    "zdrobiseră": "zdrobi",
    "zdrobiserăm": "zdrobi",
    "zdrobiserăți": "zdrobi",
    "zdrobiseși": "zdrobi",
    "zdrobiși": "zdrobi",
    "zdrobit": "zdrobi",
    "zdrobiți": "zdrobi",
    "zdrobitu": "zdrobi",
    "zdrobirea": "zdrobire",
    "zdrobireo": "zdrobire",
    "zdrobiri": "zdrobire",
    "zdrobirii": "zdrobire",
    "zdrobirile": "zdrobire",
    "zdrobirilor": "zdrobire",
    "zdrobita": "zdrobit",
    "zdrobită": "zdrobit",
    "zdrobite": "zdrobit",
    "zdrobitei": "zdrobit",
    "zdrobitele": "zdrobit",
    "zdrobitelor": "zdrobit",
    "zdrobiți": "zdrobit",
    "zdrobiții": "zdrobit",
    "zdrobiților": "zdrobit",
    "zdrobito": "zdrobit",
    "zdrobitul": "zdrobit",
    "zdrobitule": "zdrobit",
    "zdrobitului": "zdrobit",
    "zdrobita": "zdrobită",
    "zdrobite": "zdrobită",
    "zdrobitei": "zdrobită",
    "zdrobitele": "zdrobită",
    "zdrobitelor": "zdrobită",
    "zdrobito": "zdrobită",
    "zdrobitoarea": "zdrobitoare",
    "zdrobitoarei": "zdrobitoare",
    "zdrobitoarele": "zdrobitoare",
    "zdrobitoarelor": "zdrobitoare",
    "zdrobitoareo": "zdrobitoare",
    "zdrobitoare": "zdrobitor",
    "zdrobitoarea": "zdrobitor",
    "zdrobitoarei": "zdrobitor",
    "zdrobitoarele": "zdrobitor",
    "zdrobitoarelor": "zdrobitor",
    "zdrobitoareo": "zdrobitor",
    "zdrobitori": "zdrobitor",
    "zdrobitorii": "zdrobitor",
    "zdrobitorilor": "zdrobitor",
    "zdrobitorul": "zdrobitor",
    "zdrobitorule": "zdrobitor",
    "zdrobitorului": "zdrobitor",
    "nemaizdrumicând": "zdrumica",
    "nemaizdrumicându": "zdrumica",
    "nezdrumicând": "zdrumica",
    "nezdrumicându": "zdrumica",
    "zdrumic": "zdrumica",
    "zdrumică": "zdrumica",
    "zdrumicai": "zdrumica",
    "zdrumicam": "zdrumica",
    "zdrumicăm": "zdrumica",
    "zdrumicând": "zdrumica",
    "zdrumicându": "zdrumica",
    "zdrumicară": "zdrumica",
    "zdrumicarăm": "zdrumica",
    "zdrumicarăți": "zdrumica",
    "zdrumicase": "zdrumica",
    "zdrumicasem": "zdrumica",
    "zdrumicaseră": "zdrumica",
    "zdrumicaserăm": "zdrumica",
    "zdrumicaserăți": "zdrumica",
    "zdrumicaseși": "zdrumica",
    "zdrumicași": "zdrumica",
    "zdrumicat": "zdrumica",
    "zdrumicați": "zdrumica",
    "zdrumicatu": "zdrumica",
    "zdrumicau": "zdrumica",
    "zdrumice": "zdrumica",
    "zdrumici": "zdrumica",
    "zdrumicarea": "zdrumicare",
    "zdrumicări": "zdrumicare",
    "zdrumicării": "zdrumicare",
    "zdrumicările": "zdrumicare",
    "zdrumicata": "zdrumicat",
    "zdrumicată": "zdrumicat",
    "zdrumicate": "zdrumicat",
    "zdrumicatei": "zdrumicat",
    "zdrumicatele": "zdrumicat",
    "zdrumicatelor": "zdrumicat",
    "zdrumicați": "zdrumicat",
    "zdrumicații": "zdrumicat",
    "zdrumicaților": "zdrumicat",
    "zdrumicatul": "zdrumicat",
    "zdrumicatului": "zdrumicat",
    "zdrumicata": "zdrumicată",
    "zdrumicate": "zdrumicată",
    "zdrumicatei": "zdrumicată",
    "zdrumicatele": "zdrumicată",
    "zdrumicatelor": "zdrumicată",
    "nemaizdruncinând": "zdruncina",
    "nemaizdruncinându": "zdruncina",
    "nezdruncinând": "zdruncina",
    "nezdruncinându": "zdruncina",
    "zdruncin": "zdruncina",
    "zdruncină": "zdruncina",
    "zdruncinai": "zdruncina",
    "zdruncinam": "zdruncina",
    "zdruncinăm": "zdruncina",
    "zdruncinând": "zdruncina",
    "zdruncinându": "zdruncina",
    "zdruncinară": "zdruncina",
    "zdruncinarăm": "zdruncina",
    "zdruncinarăți": "zdruncina",
    "zdruncinase": "zdruncina",
    "zdruncinasem": "zdruncina",
    "zdruncinaseră": "zdruncina",
    "zdruncinaserăm": "zdruncina",
    "zdruncinaserăți": "zdruncina",
    "zdruncinaseși": "zdruncina",
    "zdruncinași": "zdruncina",
    "zdruncinat": "zdruncina",
    "zdruncinați": "zdruncina",
    "zdruncinatu": "zdruncina",
    "zdruncinau": "zdruncina",
    "zdruncine": "zdruncina",
    "zdruncini": "zdruncina",
    "zdruncinarea": "zdruncinare",
    "zdruncinări": "zdruncinare",
    "zdruncinării": "zdruncinare",
    "zdruncinările": "zdruncinare",
    "zdruncinata": "zdruncinat",
    "zdruncinată": "zdruncinat",
    "zdruncinate": "zdruncinat",
    "zdruncinatei": "zdruncinat",
    "zdruncinatele": "zdruncinat",
    "zdruncinatelor": "zdruncinat",
    "zdruncinați": "zdruncinat",
    "zdruncinații": "zdruncinat",
    "zdruncinaților": "zdruncinat",
    "zdruncinatul": "zdruncinat",
    "zdruncinatului": "zdruncinat",
    "zdruncinata": "zdruncinată",
    "zdruncinate": "zdruncinată",
    "zdruncinatei": "zdruncinată",
    "zdruncinatele": "zdruncinată",
    "zdruncinatelor": "zdruncinată",
    "zeama": "zeamă",
    "zeamo": "zeamă",
    "zemii": "zeamă",
    "zemuri": "zeamă",
    "zemurile": "zeamă",
    "zemurilor": "zeamă",
    "zebrata": "zebrat",
    "zebrată": "zebrat",
    "zebrate": "zebrat",
    "zebratei": "zebrat",
    "zebratele": "zebrat",
    "zebratelor": "zebrat",
    "zebrați": "zebrat",
    "zebrații": "zebrat",
    "zebraților": "zebrat",
    "zebratul": "zebrat",
    "zebratului": "zebrat",
    "X": "zece",
    "zecea": "zece",
    "zecelea": "zece",
    "zeci": "zece",
    "zecii": "zece",
    "zecile": "zece",
    "zecilor": "zece",
    "zecimala": "zecimală",
    "zecimale": "zecimală",
    "zecimalei": "zecimală",
    "zecimalele": "zecimală",
    "zecimalelor": "zecimală",
    "zecimea": "zecime",
    "zecimi": "zecime",
    "zecimii": "zecime",
    "zecimile": "zecime",
    "zecimilor": "zecime",
    "nemaizeciuind": "zeciui",
    "nemaizeciuindu": "zeciui",
    "nezeciuind": "zeciui",
    "nezeciuindu": "zeciui",
    "zeciuia": "zeciui",
    "zeciuiai": "zeciui",
    "zeciuiam": "zeciui",
    "zeciuiască": "zeciui",
    "zeciuiați": "zeciui",
    "zeciuiau": "zeciui",
    "zeciuiesc": "zeciui",
    "zeciuiește": "zeciui",
    "zeciuiești": "zeciui",
    "zeciuii": "zeciui",
    "zeciuim": "zeciui",
    "zeciuind": "zeciui",
    "zeciuindu": "zeciui",
    "zeciuiră": "zeciui",
    "zeciuirăm": "zeciui",
    "zeciuirăți": "zeciui",
    "zeciuise": "zeciui",
    "zeciuisem": "zeciui",
    "zeciuiseră": "zeciui",
    "zeciuiserăm": "zeciui",
    "zeciuiserăți": "zeciui",
    "zeciuiseși": "zeciui",
    "zeciuiși": "zeciui",
    "zeciuit": "zeciui",
    "zeciuiți": "zeciui",
    "zeciuitu": "zeciui",
    "zeciuirea": "zeciuire",
    "zeciuiri": "zeciuire",
    "zeciuirii": "zeciuire",
    "zeciuirile": "zeciuire",
    "zeciuita": "zeciuit",
    "zeciuită": "zeciuit",
    "zeciuite": "zeciuit",
    "zeciuitei": "zeciuit",
    "zeciuitele": "zeciuit",
    "zeciuitelor": "zeciuit",
    "zeciuiți": "zeciuit",
    "zeciuiții": "zeciuit",
    "zeciuiților": "zeciuit",
    "zeciuitul": "zeciuit",
    "zeciuitului": "zeciuit",
    "zeciuituri": "zeciuit",
    "zeciuiturile": "zeciuit",
    "zeciuiturilor": "zeciuit",
    "zefiri": "zefir",
    "zefirii": "zefir",
    "zefirilor": "zefir",
    "zefirul": "zefir",
    "zefirului": "zefir",
    "zefiruri": "zefir",
    "zefirurile": "zefir",
    "zefirurilor": "zefir",
    "zeflemeaua": "zeflemea",
    "zeflemele": "zeflemea",
    "zeflemelei": "zeflemea",
    "zeflemelele": "zeflemea",
    "zeflemelelor": "zeflemea",
    "nemaizeflemisind": "zeflemisi",
    "nemaizeflemisindu": "zeflemisi",
    "nezeflemisind": "zeflemisi",
    "nezeflemisindu": "zeflemisi",
    "zeflemisea": "zeflemisi",
    "zeflemiseai": "zeflemisi",
    "zeflemiseam": "zeflemisi",
    "zeflemisească": "zeflemisi",
    "zeflemiseați": "zeflemisi",
    "zeflemiseau": "zeflemisi",
    "zeflemisesc": "zeflemisi",
    "zeflemisește": "zeflemisi",
    "zeflemisești": "zeflemisi",
    "zeflemisii": "zeflemisi",
    "zeflemisim": "zeflemisi",
    "zeflemisind": "zeflemisi",
    "zeflemisindu": "zeflemisi",
    "zeflemisiră": "zeflemisi",
    "zeflemisirăm": "zeflemisi",
    "zeflemisirăți": "zeflemisi",
    "zeflemisise": "zeflemisi",
    "zeflemisisem": "zeflemisi",
    "zeflemisiseră": "zeflemisi",
    "zeflemisiserăm": "zeflemisi",
    "zeflemisiserăți": "zeflemisi",
    "zeflemisiseși": "zeflemisi",
    "zeflemisiși": "zeflemisi",
    "zeflemisit": "zeflemisi",
    "zeflemisiți": "zeflemisi",
    "zeflemisitu": "zeflemisi",
    "zeflemisirea": "zeflemisire",
    "zeflemisiri": "zeflemisire",
    "zeflemisirii": "zeflemisire",
    "zeflemisirile": "zeflemisire",
    "zeflemisita": "zeflemisit",
    "zeflemisită": "zeflemisit",
    "zeflemisite": "zeflemisit",
    "zeflemisitei": "zeflemisit",
    "zeflemisitele": "zeflemisit",
    "zeflemisitelor": "zeflemisit",
    "zeflemisiți": "zeflemisit",
    "zeflemisiții": "zeflemisit",
    "zeflemisiților": "zeflemisit",
    "zeflemisitul": "zeflemisit",
    "zeflemisitului": "zeflemisit",
    "zeflemisita": "zeflemisită",
    "zeflemisite": "zeflemisită",
    "zeflemisitei": "zeflemisită",
    "zeflemisitele": "zeflemisită",
    "zeflemisitelor": "zeflemisită",
    "zeflemitoarea": "zeflemitoare",
    "zeflemitoarei": "zeflemitoare",
    "zeflemitoarele": "zeflemitoare",
    "zeflemitoarelor": "zeflemitoare",
    "zeflemitoareo": "zeflemitoare",
    "zeflemitoare": "zeflemitor",
    "zeflemitoarea": "zeflemitor",
    "zeflemitoarei": "zeflemitor",
    "zeflemitoarele": "zeflemitor",
    "zeflemitoarelor": "zeflemitor",
    "zeflemitoareo": "zeflemitor",
    "zeflemitori": "zeflemitor",
    "zeflemitorii": "zeflemitor",
    "zeflemitorilor": "zeflemitor",
    "zeflemitorul": "zeflemitor",
    "zeflemitorule": "zeflemitor",
    "zeflemitorului": "zeflemitor",
    "zeghea": "zeghe",
    "zeghi": "zeghe",
    "zeghii": "zeghe",
    "zeghile": "zeghe",
    "zeghilor": "zeghe",
    "zeia": "zeie",
    "zeiei": "zeie",
    "zeiele": "zeie",
    "zeielor": "zeie",
    "zeiasca": "zeiesc",
    "zeiască": "zeiesc",
    "zeiescul": "zeiesc",
    "zeiescului": "zeiesc",
    "zeiești": "zeiesc",
    "zeieștii": "zeiesc",
    "zeieștile": "zeiesc",
    "zeieștilor": "zeiesc",
    "zeița": "zeiță",
    "zeițe": "zeiță",
    "zeiței": "zeiță",
    "zeițele": "zeiță",
    "zeițelor": "zeiță",
    "zeitatea": "zeitate",
    "zeități": "zeitate",
    "zeității": "zeitate",
    "zeitățile": "zeitate",
    "zeităților": "zeitate",
    "zelul": "zel",
    "zelului": "zel",
    "zeluri": "zel",
    "zelurile": "zel",
    "zelurilor": "zel",
    "zeloasa": "zelos",
    "zeloasă": "zelos",
    "zeloase": "zelos",
    "zeloasei": "zelos",
    "zeloasele": "zelos",
    "zeloaselor": "zelos",
    "zeloaso": "zelos",
    "zeloși": "zelos",
    "zeloșii": "zelos",
    "zeloșilor": "zelos",
    "zelosul": "zelos",
    "zelosule": "zelos",
    "zelosului": "zelos",
    "zenitul": "zenit",
    "zenitului": "zenit",
    "zeonifere": "zeonifer",
    "zeoniferele": "zeonifer",
    "zeoniferelor": "zeonifer",
    "zeoniferul": "zeonifer",
    "zeoniferului": "zeonifer",
    "zeppeline": "zeppelin",
    "zeppelinele": "zeppelin",
    "zeppelinelor": "zeppelin",
    "zeppelinul": "zeppelin",
    "zeppelinului": "zeppelin",
    "zerul": "zer",
    "zerului": "zer",
    "zeruri": "zer",
    "zerurile": "zer",
    "zerurilor": "zer",
    "Z.": "zero",
    "zeroul": "zero",
    "zeroule": "zero",
    "zeroului": "zero",
    "zerouri": "zero",
    "zerourile": "zero",
    "zerourilor": "zero",
    "zestrea": "zestre",
    "zețari": "zețar",
    "zețarii": "zețar",
    "zețarilor": "zețar",
    "zețarul": "zețar",
    "zețarului": "zețar",
    "zei": "zeu",
    "zeii": "zeu",
    "zeilor": "zeu",
    "zeul": "zeu",
    "zeului": "zeu",
    "nemaizgâind": "zgâi",
    "nemaizgâindu": "zgâi",
    "nezgâind": "zgâi",
    "nezgâindu": "zgâi",
    "zgâia": "zgâi",
    "zgâiai": "zgâi",
    "zgâiam": "zgâi",
    "zgâiască": "zgâi",
    "zgâiați": "zgâi",
    "zgâiau": "zgâi",
    "zgâiesc": "zgâi",
    "zgâiește": "zgâi",
    "zgâiești": "zgâi",
    "zgâii": "zgâi",
    "zgâim": "zgâi",
    "zgâind": "zgâi",
    "zgâindu": "zgâi",
    "zgâiră": "zgâi",
    "zgâirăm": "zgâi",
    "zgâirăți": "zgâi",
    "zgâise": "zgâi",
    "zgâisem": "zgâi",
    "zgâiseră": "zgâi",
    "zgâiserăm": "zgâi",
    "zgâiserăți": "zgâi",
    "zgâiseși": "zgâi",
    "zgâiși": "zgâi",
    "zgâit": "zgâi",
    "zgâiți": "zgâi",
    "zgâitu": "zgâi",
    "zgâirea": "zgâire",
    "zgâiri": "zgâire",
    "zgâirii": "zgâire",
    "zgâirile": "zgâire",
    "zgâita": "zgâit",
    "zgâită": "zgâit",
    "zgâite": "zgâit",
    "zgâitei": "zgâit",
    "zgâitele": "zgâit",
    "zgâitelor": "zgâit",
    "zgâiți": "zgâit",
    "zgâiții": "zgâit",
    "zgâiților": "zgâit",
    "zgâitul": "zgâit",
    "zgâitului": "zgâit",
    "zgâita": "zgâită",
    "zgâite": "zgâită",
    "zgâitei": "zgâită",
    "zgâitele": "zgâită",
    "zgâitelor": "zgâită",
    "zgâlțâia": "zgâlțâi",
    "zgâlțâiai": "zgâlțâi",
    "zgâlțâiam": "zgâlțâi",
    "zgâlțâiați": "zgâlțâi",
    "zgâlțâiau": "zgâlțâi",
    "zgâlțâie": "zgâlțâi",
    "zgâlțâii": "zgâlțâi",
    "zgâlțâim": "zgâlțâi",
    "zgâlțâind": "zgâlțâi",
    "zgâlțâindu": "zgâlțâi",
    "zgâlțâiră": "zgâlțâi",
    "zgâlțâirăm": "zgâlțâi",
    "zgâlțâirăți": "zgâlțâi",
    "zgâlțâise": "zgâlțâi",
    "zgâlțâisem": "zgâlțâi",
    "zgâlțâiseră": "zgâlțâi",
    "zgâlțâiserăm": "zgâlțâi",
    "zgâlțâiserăți": "zgâlțâi",
    "zgâlțâiseși": "zgâlțâi",
    "zgâlțâiși": "zgâlțâi",
    "zgâlțâit": "zgâlțâi",
    "zgâlțâiți": "zgâlțâi",
    "zgâlțâitu": "zgâlțâi",
    "zgâlțâită": "zgâlțâit",
    "zgâlțâite": "zgâlțâit",
    "zgâlțâiți": "zgâlțâit",
    "zgârcenia": "zgârcenie",
    "zgârceniei": "zgârcenie",
    "zgârcenii": "zgârcenie",
    "zgârceniile": "zgârcenie",
    "zgârceniilor": "zgârcenie",
    "nemaizgârcind": "zgârci",
    "nemaizgârcindu": "zgârci",
    "nezgârcind": "zgârci",
    "nezgârcindu": "zgârci",
    "zgârcea": "zgârci",
    "zgârceai": "zgârci",
    "zgârceam": "zgârci",
    "zgârcească": "zgârci",
    "zgârceați": "zgârci",
    "zgârceau": "zgârci",
    "zgârcesc": "zgârci",
    "zgârcește": "zgârci",
    "zgârcești": "zgârci",
    "zgârcii": "zgârci",
    "zgârcim": "zgârci",
    "zgârcind": "zgârci",
    "zgârcindu": "zgârci",
    "zgârciră": "zgârci",
    "zgârcirăm": "zgârci",
    "zgârcirăți": "zgârci",
    "zgârcise": "zgârci",
    "zgârcisem": "zgârci",
    "zgârciseră": "zgârci",
    "zgârciserăm": "zgârci",
    "zgârciserăți": "zgârci",
    "zgârciseși": "zgârci",
    "zgârciși": "zgârci",
    "zgârcit": "zgârci",
    "zgârciți": "zgârci",
    "zgârcitu": "zgârci",
    "zgârciul": "zgârci",
    "zgârciului": "zgârci",
    "zgârciuri": "zgârci",
    "zgârciurile": "zgârci",
    "zgârciurilor": "zgârci",
    "zgârcirea": "zgârcire",
    "zgârcireo": "zgârcire",
    "zgârciri": "zgârcire",
    "zgârcirii": "zgârcire",
    "zgârcirile": "zgârcire",
    "zgârcirilor": "zgârcire",
    "zgârcita": "zgârcit",
    "zgârcită": "zgârcit",
    "zgârcite": "zgârcit",
    "zgârcitei": "zgârcit",
    "zgârcitele": "zgârcit",
    "zgârcitelor": "zgârcit",
    "zgârciți": "zgârcit",
    "zgârciții": "zgârcit",
    "zgârciților": "zgârcit",
    "zgârcito": "zgârcit",
    "zgârcitul": "zgârcit",
    "zgârcitule": "zgârcit",
    "zgârcitului": "zgârcit",
    "zgârcita": "zgârcită",
    "zgârcite": "zgârcită",
    "zgârcitei": "zgârcită",
    "zgârcitele": "zgârcită",
    "zgârcitelor": "zgârcită",
    "zgârcito": "zgârcită",
    "zgarda": "zgardă",
    "zgărzi": "zgardă",
    "zgărzii": "zgardă",
    "zgărzile": "zgardă",
    "zgărzilor": "zgardă",
    "zgâriai": "zgâria",
    "zgâriam": "zgâria",
    "zgâriară": "zgâria",
    "zgâriarăm": "zgâria",
    "zgâriarăți": "zgâria",
    "zgâriase": "zgâria",
    "zgâriasem": "zgâria",
    "zgâriaseră": "zgâria",
    "zgâriaserăm": "zgâria",
    "zgâriaserăți": "zgâria",
    "zgâriaseși": "zgâria",
    "zgâriași": "zgâria",
    "zgâriat": "zgâria",
    "zgâriați": "zgâria",
    "zgâriatu": "zgâria",
    "zgâriau": "zgâria",
    "zgâriază": "zgâria",
    "zgârie": "zgâria",
    "zgâriem": "zgâria",
    "zgârii": "zgâria",
    "zgâriind": "zgâria",
    "zgâriindu": "zgâria",
    "zgâriata": "zgâriat",
    "zgâriată": "zgâriat",
    "zgâriate": "zgâriat",
    "zgâriatei": "zgâriat",
    "zgâriatele": "zgâriat",
    "zgâriatelor": "zgâriat",
    "zgâriați": "zgâriat",
    "zgâriații": "zgâriat",
    "zgâriaților": "zgâriat",
    "zgâriatul": "zgâriat",
    "zgâriatului": "zgâriat",
    "zgârie-norii": "zgârie-nori",
    "zgârie-norilor": "zgârie-nori",
    "zgârierea": "zgâriere",
    "zgâriereo": "zgâriere",
    "zgârieri": "zgâriere",
    "zgârierii": "zgâriere",
    "zgârierile": "zgâriere",
    "zgârierilor": "zgâriere",
    "zgârietura": "zgârietură",
    "zgârieturi": "zgârietură",
    "zgârieturii": "zgârietură",
    "zgârieturile": "zgârietură",
    "zgârieturilor": "zgârietură",
    "zgâtia": "zgâtie",
    "zgâtiei": "zgâtie",
    "zgâtii": "zgâtie",
    "zgâtiile": "zgâtie",
    "zgâtiilor": "zgâtie",
    "zglobia": "zglobiu",
    "zglobie": "zglobiu",
    "zglobiei": "zglobiu",
    "zglobii": "zglobiu",
    "zglobiii": "zglobiu",
    "zglobiile": "zglobiu",
    "zglobiilor": "zglobiu",
    "zglobiul": "zglobiu",
    "zglobiului": "zglobiu",
    "zgomote": "zgomot",
    "zgomotele": "zgomot",
    "zgomotelor": "zgomot",
    "zgomotul": "zgomot",
    "zgomotule": "zgomot",
    "zgomotului": "zgomot",
    "zgomotoasa": "zgomotos",
    "zgomotoasă": "zgomotos",
    "zgomotoase": "zgomotos",
    "zgomotoasei": "zgomotos",
    "zgomotoasele": "zgomotos",
    "zgomotoaselor": "zgomotos",
    "zgomotoaso": "zgomotos",
    "zgomotoși": "zgomotos",
    "zgomotoșii": "zgomotos",
    "zgomotoșilor": "zgomotos",
    "zgomotosul": "zgomotos",
    "zgomotosule": "zgomotos",
    "zgomotosului": "zgomotos",
    "zgribulea": "zgribuli",
    "zgribuleai": "zgribuli",
    "zgribuleam": "zgribuli",
    "zgribulească": "zgribuli",
    "zgribuleați": "zgribuli",
    "zgribuleau": "zgribuli",
    "zgribulesc": "zgribuli",
    "zgribulește": "zgribuli",
    "zgribulești": "zgribuli",
    "zgribulii": "zgribuli",
    "zgribulim": "zgribuli",
    "zgribulind": "zgribuli",
    "zgribulindu": "zgribuli",
    "zgribuliră": "zgribuli",
    "zgribulirăm": "zgribuli",
    "zgribulirăți": "zgribuli",
    "zgribulise": "zgribuli",
    "zgribulisem": "zgribuli",
    "zgribuliseră": "zgribuli",
    "zgribuliserăm": "zgribuli",
    "zgribuliserăți": "zgribuli",
    "zgribuliseși": "zgribuli",
    "zgribuliși": "zgribuli",
    "zgribulit": "zgribuli",
    "zgribuliți": "zgribuli",
    "zgribulitu": "zgribuli",
    "zgribulirea": "zgribulire",
    "zgribuliri": "zgribulire",
    "zgribulirii": "zgribulire",
    "zgribulirile": "zgribulire",
    "zgribulirilor": "zgribulire",
    "zgribulită": "zgribulit",
    "zgribulite": "zgribulit",
    "zgribuliți": "zgribulit",
    "zgribuliții": "zgribulit",
    "zgribuliților": "zgribulit",
    "zgribulitul": "zgribulit",
    "zgribulitului": "zgribulit",
    "zgripțori": "zgripțor",
    "zgripțorii": "zgripțor",
    "zgripțorilor": "zgripțor",
    "zgripțorul": "zgripțor",
    "zgripțorului": "zgripțor",
    "zgripțoroii": "zgripțoroi",
    "zgripțoroilor": "zgripțoroi",
    "zgripțoroiul": "zgripțoroi",
    "zgripțoroiului": "zgripțoroi",
    "zgrunțuroasa": "zgrunțuros",
    "zgrunțuroasă": "zgrunțuros",
    "zgrunțuroase": "zgrunțuros",
    "zgrunțuroasei": "zgrunțuros",
    "zgrunțuroasele": "zgrunțuros",
    "zgrunțuroaselor": "zgrunțuros",
    "zgrunțuroaso": "zgrunțuros",
    "zgrunțuroși": "zgrunțuros",
    "zgrunțuroșii": "zgrunțuros",
    "zgrunțuroșilor": "zgrunțuros",
    "zgrunțurosul": "zgrunțuros",
    "zgrunțurosule": "zgrunțuros",
    "zgrunțurosului": "zgrunțuros",
    "nemaizguduind": "zgudui",
    "nemaizguduindu": "zgudui",
    "nezguduind": "zgudui",
    "nezguduindu": "zgudui",
    "zguduia": "zgudui",
    "zguduiai": "zgudui",
    "zguduiam": "zgudui",
    "zguduiați": "zgudui",
    "zguduiau": "zgudui",
    "zguduie": "zgudui",
    "zguduii": "zgudui",
    "zguduim": "zgudui",
    "zguduind": "zgudui",
    "zguduindu": "zgudui",
    "zguduiră": "zgudui",
    "zguduirăm": "zgudui",
    "zguduirăți": "zgudui",
    "zguduise": "zgudui",
    "zguduisem": "zgudui",
    "zguduiseră": "zgudui",
    "zguduiserăm": "zgudui",
    "zguduiserăți": "zgudui",
    "zguduiseși": "zgudui",
    "zguduiși": "zgudui",
    "zguduit": "zgudui",
    "zguduiți": "zgudui",
    "zguduitu": "zgudui",
    "zguduirea": "zguduire",
    "zguduireo": "zguduire",
    "zguduiri": "zguduire",
    "zguduirii": "zguduire",
    "zguduirile": "zguduire",
    "zguduirilor": "zguduire",
    "zguduita": "zguduit",
    "zguduită": "zguduit",
    "zguduite": "zguduit",
    "zguduitei": "zguduit",
    "zguduitele": "zguduit",
    "zguduitelor": "zguduit",
    "zguduiți": "zguduit",
    "zguduiții": "zguduit",
    "zguduiților": "zguduit",
    "zguduito": "zguduit",
    "zguduitul": "zguduit",
    "zguduitule": "zguduit",
    "zguduitului": "zguduit",
    "zguduitoare": "zguduitor",
    "zguduitoarea": "zguduitor",
    "zguduitoarei": "zguduitor",
    "zguduitoarele": "zguduitor",
    "zguduitoarelor": "zguduitor",
    "zguduitori": "zguduitor",
    "zguduitorii": "zguduitor",
    "zguduitorilor": "zguduitor",
    "zguduitorul": "zguduitor",
    "zguduitorule": "zguduitor",
    "zguduitorului": "zguduitor",
    "zguduitura": "zguduitură",
    "zguduituri": "zguduitură",
    "zguduiturii": "zguduitură",
    "zguduiturile": "zguduitură",
    "zguduiturilor": "zguduitură",
    "zgura": "zgură",
    "zguri": "zgură",
    "zgurii": "zgură",
    "zgurile": "zgură",
    "zgurilor": "zgură",
    "zî": "zi",
    "zile": "zi",
    "zilei": "zi",
    "zilele": "zi",
    "zilelor": "zi",
    "zio": "zi",
    "ziare": "ziar",
    "ziarele": "ziar",
    "ziarelor": "ziar",
    "ziarul": "ziar",
    "ziarului": "ziar",
    "ziariști": "ziarist",
    "ziariștii": "ziarist",
    "ziariștilor": "ziarist",
    "ziaristul": "ziarist",
    "ziaristului": "ziarist",
    "ziarista": "ziaristă",
    "ziariste": "ziaristă",
    "ziaristei": "ziaristă",
    "ziaristele": "ziaristă",
    "ziaristelor": "ziaristă",
    "ziaristica": "ziaristică",
    "ziaristicele": "ziaristică",
    "ziaristici": "ziaristică",
    "ziaristicii": "ziaristică",
    "ziaristicilor": "ziaristică",
    "zicala": "zicală",
    "zicale": "zicală",
    "zicalei": "zicală",
    "zicalele": "zicală",
    "zicalelor": "zicală",
    "zicătoarea": "zicătoare",
    "zicători": "zicătoare",
    "zicătorile": "zicătoare",
    "zicătorilor": "zicătoare",
    "nemaizicând": "zice",
    "nemaizicându": "zice",
    "nezicând": "zice",
    "nezicându": "zice",
    "zâs": "zice",
    "zi": "zice",
    "zi'": "zice",
    "zic": "zice",
    "zică": "zice",
    "zicând": "zice",
    "zicându": "zice",
    "zicea": "zice",
    "ziceai": "zice",
    "ziceam": "zice",
    "ziceați": "zice",
    "ziceau": "zice",
    "zicem": "zice",
    "ziceți": "zice",
    "zici": "zice",
    "zis": "zice",
    "ziș'": "zice",
    "zise": "zice",
    "zisei": "zice",
    "ziseră": "zice",
    "ziserăm": "zice",
    "ziserăți": "zice",
    "zisese": "zice",
    "zisesem": "zice",
    "ziseseră": "zice",
    "ziseserăm": "zice",
    "ziseserăți": "zice",
    "ziseseși": "zice",
    "ziseși": "zice",
    "zisu": "zice",
    "zicerea": "zicere",
    "ziceri": "zicere",
    "zicerii": "zicere",
    "zicerile": "zicere",
    "zicerilor": "zicere",
    "zidul": "zid",
    "zidule": "zid",
    "zidului": "zid",
    "ziduri": "zid",
    "zidurile": "zid",
    "zidurilor": "zid",
    "zidari": "zidar",
    "zidarii": "zidar",
    "zidarilor": "zidar",
    "zidarul": "zidar",
    "zidarului": "zidar",
    "zidăria": "zidărie",
    "zidăriei": "zidărie",
    "zidării": "zidărie",
    "zidăriile": "zidărie",
    "zidăriilor": "zidărie",
    "zidea": "zidi",
    "zideai": "zidi",
    "zideam": "zidi",
    "zidească": "zidi",
    "zideați": "zidi",
    "zideau": "zidi",
    "zidesc": "zidi",
    "zidește": "zidi",
    "zidești": "zidi",
    "zidii": "zidi",
    "zidim": "zidi",
    "zidind": "zidi",
    "zidindu": "zidi",
    "zidiră": "zidi",
    "zidirăm": "zidi",
    "zidirăți": "zidi",
    "zidise": "zidi",
    "zidisem": "zidi",
    "zidiseră": "zidi",
    "zidiserăm": "zidi",
    "zidiserăți": "zidi",
    "zidiseși": "zidi",
    "zidiși": "zidi",
    "zidit": "zidi",
    "zidiți": "zidi",
    "ziditu": "zidi",
    "zidirea": "zidire",
    "zidiri": "zidire",
    "zidirii": "zidire",
    "zidirile": "zidire",
    "zidirilor": "zidire",
    "zidita": "zidit",
    "zidită": "zidit",
    "zidite": "zidit",
    "ziditei": "zidit",
    "ziditele": "zidit",
    "ziditelor": "zidit",
    "zidiți": "zidit",
    "zidiții": "zidit",
    "zidiților": "zidit",
    "ziditul": "zidit",
    "ziditului": "zidit",
    "ziditoarea": "ziditoare",
    "ziditoarei": "ziditoare",
    "ziditoarele": "ziditoare",
    "ziditoarelor": "ziditoare",
    "ziditoare": "ziditor",
    "ziditoarea": "ziditor",
    "ziditoarei": "ziditor",
    "ziditoarele": "ziditor",
    "ziditoarelor": "ziditor",
    "ziditori": "ziditor",
    "ziditorii": "ziditor",
    "ziditorilor": "ziditor",
    "ziditorul": "ziditor",
    "ziditorului": "ziditor",
    "zigzagul": "zigzag",
    "zigzagule": "zigzag",
    "zigzagului": "zigzag",
    "zigzaguri": "zigzag",
    "zigzagurile": "zigzag",
    "zigzagurilor": "zigzag",
    "zig-zagul": "zig-zag",
    "zig-zagului": "zig-zag",
    "zig-zaguri": "zig-zag",
    "zig-zagurile": "zig-zag",
    "zig-zagurilor": "zig-zag",
    "zilieri": "zilier",
    "zilierii": "zilier",
    "zilierilor": "zilier",
    "zilierul": "zilier",
    "zilierului": "zilier",
    "zilnica": "zilnic",
    "zilnică": "zilnic",
    "zilnice": "zilnic",
    "zilnicei": "zilnic",
    "zilnicele": "zilnic",
    "zilnicelor": "zilnic",
    "zilnici": "zilnic",
    "zilnicii": "zilnic",
    "zilnicilor": "zilnic",
    "zilnico": "zilnic",
    "zilnicul": "zilnic",
    "zilnicule": "zilnic",
    "zilnicului": "zilnic",
    "zilei-muncă": "zi-muncă",
    "zilele-muncă": "zi-muncă",
    "zilelor-muncă": "zi-muncă",
    "zile-muncă": "zi-muncă",
    "ziua-muncă": "zi-muncă",
    "zincul": "zinc",
    "zincului": "zinc",
    "Zn": "zinc",
    "zirconiul": "zirconiu",
    "zirconiului": "zirconiu",
    "zisa": "zis",
    "zisă": "zis",
    "zise": "zis",
    "zisei": "zis",
    "zisele": "zis",
    "ziselor": "zis",
    "ziși": "zis",
    "zișii": "zis",
    "zișilor": "zis",
    "zisul": "zis",
    "zisului": "zis",
    "zisa": "zisă",
    "zise": "zisă",
    "zisei": "zisă",
    "zisele": "zisă",
    "ziselor": "zisă",
    "ziua": "ziuă",
    "ziuo": "ziuă",
    "zlătari": "zlătar",
    "zlătarii": "zlătar",
    "zlătarilor": "zlătar",
    "zlătarul": "zlătar",
    "zlătarului": "zlătar",
    "zloata": "zloată",
    "zloate": "zloată",
    "zloatei": "zloată",
    "zloatele": "zloată",
    "zloatelor": "zloată",
    "zodiacala": "zodiacal",
    "zodiacală": "zodiacal",
    "zodiacale": "zodiacal",
    "zodiacalei": "zodiacal",
    "zodiacalele": "zodiacal",
    "zodiacalelor": "zodiacal",
    "zodiacali": "zodiacal",
    "zodiacalii": "zodiacal",
    "zodiacalilor": "zodiacal",
    "zodiacalul": "zodiacal",
    "zodiacalului": "zodiacal",
    "zodia": "zodie",
    "zodiei": "zodie",
    "zodii": "zodie",
    "zodiile": "zodie",
    "zodiilor": "zodie",
    "zona": "zonă",
    "zone": "zonă",
    "zonei": "zonă",
    "zonele": "zonă",
    "zonelor": "zonă",
    "zonala": "zonal",
    "zonală": "zonal",
    "zonale": "zonal",
    "zonalei": "zonal",
    "zonalele": "zonal",
    "zonalelor": "zonal",
    "zonali": "zonal",
    "zonalii": "zonal",
    "zonalilor": "zonal",
    "zonalul": "zonal",
    "zonalului": "zonal",
    "zoofite": "zoofit",
    "zoofitele": "zoofit",
    "zoofitelor": "zoofit",
    "zoofitul": "zoofit",
    "zoofitului": "zoofit",
    "zoogenia": "zoogenie",
    "zoogeniei": "zoogenie",
    "zoogenii": "zoogenie",
    "zoogeniile": "zoogenie",
    "zoogeniilor": "zoogenie",
    "zoolatria": "zoolatrie",
    "zoolatriei": "zoolatrie",
    "zoolatrii": "zoolatrie",
    "zoolatriile": "zoolatrie",
    "zoolatriilor": "zoolatrie",
    "zoolatri": "zoolatru",
    "zoolatrii": "zoolatru",
    "zoolatrilor": "zoolatru",
    "zoolatrul": "zoolatru",
    "zoolatrului": "zoolatru",
    "zooliți": "zoolit",
    "zooliții": "zoolit",
    "zooliților": "zoolit",
    "zoolitul": "zoolit",
    "zoolitului": "zoolit",
    "zoologi": "zoolog",
    "zoologii": "zoolog",
    "zoologilor": "zoolog",
    "zoologul": "zoolog",
    "zoologului": "zoolog",
    "zool.": "zoologie",
    "zoologia": "zoologie",
    "zoologiei": "zoologie",
    "zoologii": "zoologie",
    "zoologiile": "zoologie",
    "zoologiilor": "zoologie",
    "zoomorfa": "zoomorf",
    "zoomorfă": "zoomorf",
    "zoomorfe": "zoomorf",
    "zoomorfei": "zoomorf",
    "zoomorfele": "zoomorf",
    "zoomorfelor": "zoomorf",
    "zoomorfi": "zoomorf",
    "zoomorfii": "zoomorf",
    "zoomorfilor": "zoomorf",
    "zoomorful": "zoomorf",
    "zoomorfului": "zoomorf",
    "zoonoza": "zoonoză",
    "zoonoze": "zoonoză",
    "zoonozei": "zoonoză",
    "zoonozele": "zoonoză",
    "zoonozelor": "zoonoză",
    "zootehnica": "zootehnic",
    "zootehnică": "zootehnic",
    "zootehnice": "zootehnic",
    "zootehnicei": "zootehnic",
    "zootehnicele": "zootehnic",
    "zootehnicelor": "zootehnic",
    "zootehnici": "zootehnic",
    "zootehnicii": "zootehnic",
    "zootehnicilor": "zootehnic",
    "zootehnico": "zootehnic",
    "zootehnicul": "zootehnic",
    "zootehnicule": "zootehnic",
    "zootehnicului": "zootehnic",
    "zootehnicianul": "zootehnician",
    "zootehnicianului": "zootehnician",
    "zootehnicieni": "zootehnician",
    "zootehnicienii": "zootehnician",
    "zootehnicienilor": "zootehnician",
    "zootehnia": "zootehnie",
    "zootehniei": "zootehnie",
    "zootehnii": "zootehnie",
    "zootehniile": "zootehnie",
    "zootehniilor": "zootehnie",
    "zooterapia": "zooterapie",
    "zooterapiei": "zooterapie",
    "zooterapii": "zooterapie",
    "zooterapiile": "zooterapie",
    "zooterapiilor": "zooterapie",
    "zootoxina": "zootoxină",
    "zootoxine": "zootoxină",
    "zootoxinei": "zootoxină",
    "zootoxinele": "zootoxină",
    "zootoxinelor": "zootoxină",
    "zorul": "zor",
    "zorule": "zor",
    "zorului": "zor",
    "nemaizorind": "zori",
    "nemaizorindu": "zori",
    "nezorind": "zori",
    "nezorindu": "zori",
    "zorea": "zori",
    "zoreai": "zori",
    "zoream": "zori",
    "zorească": "zori",
    "zoreați": "zori",
    "zoreau": "zori",
    "zoresc": "zori",
    "zorește": "zori",
    "zorești": "zori",
    "zorii": "zori",
    "zorile": "zori",
    "zorilor": "zori",
    "zorim": "zori",
    "zorind": "zori",
    "zorindu": "zori",
    "zoriră": "zori",
    "zorirăm": "zori",
    "zorirăți": "zori",
    "zorise": "zori",
    "zorisem": "zori",
    "zoriseră": "zori",
    "zoriserăm": "zori",
    "zoriserăți": "zori",
    "zoriseși": "zori",
    "zoriși": "zori",
    "zorit": "zori",
    "zoriți": "zori",
    "zoritu": "zori",
    "zorirea": "zorire",
    "zoriri": "zorire",
    "zoririi": "zorire",
    "zoririle": "zorire",
    "zorita": "zorit",
    "zorită": "zorit",
    "zorite": "zorit",
    "zoritei": "zorit",
    "zoritele": "zorit",
    "zoritelor": "zorit",
    "zoriți": "zorit",
    "zoriții": "zorit",
    "zoriților": "zorit",
    "zoritul": "zorit",
    "zoritului": "zorit",
    "zorituri": "zorit",
    "zoriturile": "zorit",
    "zoriturilor": "zorit",
    "zornăii": "zornăi",
    "zornăim": "zornăi",
    "zornăind": "zornăi",
    "zornăindu": "zornăi",
    "zornăiră": "zornăi",
    "zornăirăm": "zornăi",
    "zornăirăți": "zornăi",
    "zornăise": "zornăi",
    "zornăisem": "zornăi",
    "zornăiseră": "zornăi",
    "zornăiserăm": "zornăi",
    "zornăiserăți": "zornăi",
    "zornăiseși": "zornăi",
    "zornăiși": "zornăi",
    "zornăit": "zornăi",
    "zornăiți": "zornăi",
    "zornăitu": "zornăi",
    "zornăiu": "zornăi",
    "zornăiză": "zornăi",
    "zornăirea": "zornăire",
    "zornăireo": "zornăire",
    "zornăiri": "zornăire",
    "zornăirii": "zornăire",
    "zornăirile": "zornăire",
    "zornăirilor": "zornăire",
    "zornăită": "zornăit",
    "zornăite": "zornăit",
    "zornăiți": "zornăit",
    "zugravi": "zugrav",
    "zugravii": "zugrav",
    "zugravilor": "zugrav",
    "zugravul": "zugrav",
    "zugravului": "zugrav",
    "zugrăveala": "zugrăveală",
    "zugrăveli": "zugrăveală",
    "zugrăvelii": "zugrăveală",
    "zugrăvelile": "zugrăveală",
    "zugrăvelilor": "zugrăveală",
    "zugrăvea": "zugrăvi",
    "zugrăveai": "zugrăvi",
    "zugrăveam": "zugrăvi",
    "zugrăvească": "zugrăvi",
    "zugrăveați": "zugrăvi",
    "zugrăveau": "zugrăvi",
    "zugrăvesc": "zugrăvi",
    "zugrăvește": "zugrăvi",
    "zugrăvești": "zugrăvi",
    "zugrăvii": "zugrăvi",
    "zugrăvim": "zugrăvi",
    "zugrăvind": "zugrăvi",
    "zugrăvindu": "zugrăvi",
    "zugrăviră": "zugrăvi",
    "zugrăvirăm": "zugrăvi",
    "zugrăvirăți": "zugrăvi",
    "zugrăvise": "zugrăvi",
    "zugrăvisem": "zugrăvi",
    "zugrăviseră": "zugrăvi",
    "zugrăviserăm": "zugrăvi",
    "zugrăviserăți": "zugrăvi",
    "zugrăviseși": "zugrăvi",
    "zugrăviși": "zugrăvi",
    "zugrăvit": "zugrăvi",
    "zugrăviți": "zugrăvi",
    "zugrăvitu": "zugrăvi",
    "zugrăvirea": "zugrăvire",
    "zugrăviri": "zugrăvire",
    "zugrăvirii": "zugrăvire",
    "zugrăvirile": "zugrăvire",
    "zugrăvirilor": "zugrăvire",
    "zugrăvita": "zugrăvit",
    "zugrăvită": "zugrăvit",
    "zugrăvite": "zugrăvit",
    "zugrăvitei": "zugrăvit",
    "zugrăvitele": "zugrăvit",
    "zugrăvitelor": "zugrăvit",
    "zugrăviți": "zugrăvit",
    "zugrăviții": "zugrăvit",
    "zugrăviților": "zugrăvit",
    "zugrăvitul": "zugrăvit",
    "zugrăvitului": "zugrăvit",
    "zulufi": "zuluf",
    "zulufii": "zuluf",
    "zulufilor": "zuluf",
    "zuluful": "zuluf",
    "zulufule": "zuluf",
    "zulufului": "zuluf",
    "zumzăia": "zumzăi",
    "zumzăiai": "zumzăi",
    "zumzăiam": "zumzăi",
    "zumzăiați": "zumzăi",
    "zumzăiau": "zumzăi",
    "zumzăie": "zumzăi",
    "zumzăii": "zumzăi",
    "zumzăim": "zumzăi",
    "zumzăind": "zumzăi",
    "zumzăindu": "zumzăi",
    "zumzăiră": "zumzăi",
    "zumzăirăm": "zumzăi",
    "zumzăirăți": "zumzăi",
    "zumzăise": "zumzăi",
    "zumzăisem": "zumzăi",
    "zumzăiseră": "zumzăi",
    "zumzăiserăm": "zumzăi",
    "zumzăiserăți": "zumzăi",
    "zumzăiseși": "zumzăi",
    "zumzăiși": "zumzăi",
    "zumzăit": "zumzăi",
    "zumzăiți": "zumzăi",
    "zumzăitu": "zumzăi",
    "zumzăirea": "zumzăire",
    "zumzăiri": "zumzăire",
    "zumzăirii": "zumzăire",
    "zumzăirile": "zumzăire",
    "zumzăirilor": "zumzăire",
    "zumzăită": "zumzăit",
    "zumzăite": "zumzăit",
    "zumzăiți": "zumzăit",
    "zumzăitoare": "zumzăitor",
    "zumzăitoarea": "zumzăitor",
    "zumzăitoarei": "zumzăitor",
    "zumzăitoarele": "zumzăitor",
    "zumzăitoarelor": "zumzăitor",
    "zumzăitori": "zumzăitor",
    "zumzăitorii": "zumzăitor",
    "zumzăitorilor": "zumzăitor",
    "zumzăitorul": "zumzăitor",
    "zumzăitorului": "zumzăitor",
    "zumzete": "zumzet",
    "zumzetele": "zumzet",
    "zumzetelor": "zumzet",
    "zumzetul": "zumzet",
    "zumzetule": "zumzet",
    "zumzetului": "zumzet",
    "nemaizuruind": "zurui",
    "nemaizuruindu": "zurui",
    "nezuruind": "zurui",
    "nezuruindu": "zurui",
    "zuruia": "zurui",
    "zuruiai": "zurui",
    "zuruiam": "zurui",
    "zuruiască": "zurui",
    "zuruiați": "zurui",
    "zuruiau": "zurui",
    "zuruiesc": "zurui",
    "zuruiește": "zurui",
    "zuruiești": "zurui",
    "zuruii": "zurui",
    "zuruim": "zurui",
    "zuruind": "zurui",
    "zuruindu": "zurui",
    "zuruiră": "zurui",
    "zuruirăm": "zurui",
    "zuruirăți": "zurui",
    "zuruise": "zurui",
    "zuruisem": "zurui",
    "zuruiseră": "zurui",
    "zuruiserăm": "zurui",
    "zuruiserăți": "zurui",
    "zuruiseși": "zurui",
    "zuruiși": "zurui",
    "zuruit": "zurui",
    "zuruiți": "zurui",
    "zuruitu": "zurui",
    "zuruirea": "zuruire",
    "zuruireo": "zuruire",
    "zuruiri": "zuruire",
    "zuruirii": "zuruire",
    "zuruirile": "zuruire",
    "zuruirilor": "zuruire",
    "zuruita": "zuruit",
    "zuruită": "zuruit",
    "zuruite": "zuruit",
    "zuruitei": "zuruit",
    "zuruitele": "zuruit",
    "zuruitelor": "zuruit",
    "zuruiți": "zuruit",
    "zuruiții": "zuruit",
    "zuruiților": "zuruit",
    "zuruito": "zuruit",
    "zuruitul": "zuruit",
    "zuruitului": "zuruit",
    "zuruituri": "zuruit",
    "zuruiturile": "zuruit",
    "zuruiturilor": "zuruit",
    "zvâcnete": "zvâcnet",
    "zvâcnetele": "zvâcnet",
    "zvâcnetelor": "zvâcnet",
    "zvâcnetul": "zvâcnet",
    "zvâcnetului": "zvâcnet",
    "nemaizvâcnind": "zvâcni",
    "nemaizvâcnindu": "zvâcni",
    "nezvâcnind": "zvâcni",
    "nezvâcnindu": "zvâcni",
    "zvâcnea": "zvâcni",
    "zvâcneai": "zvâcni",
    "zvâcneam": "zvâcni",
    "zvâcnească": "zvâcni",
    "zvâcneați": "zvâcni",
    "zvâcneau": "zvâcni",
    "zvâcnesc": "zvâcni",
    "zvâcnește": "zvâcni",
    "zvâcnești": "zvâcni",
    "zvâcnii": "zvâcni",
    "zvâcnim": "zvâcni",
    "zvâcnind": "zvâcni",
    "zvâcnindu": "zvâcni",
    "zvâcniră": "zvâcni",
    "zvâcnirăm": "zvâcni",
    "zvâcnirăți": "zvâcni",
    "zvâcnise": "zvâcni",
    "zvâcnisem": "zvâcni",
    "zvâcniseră": "zvâcni",
    "zvâcniserăm": "zvâcni",
    "zvâcniserăți": "zvâcni",
    "zvâcniseși": "zvâcni",
    "zvâcniși": "zvâcni",
    "zvâcnit": "zvâcni",
    "zvâcniți": "zvâcni",
    "zvâcnitu": "zvâcni",
    "zvâcnirea": "zvâcnire",
    "zvâcnireo": "zvâcnire",
    "zvâcniri": "zvâcnire",
    "zvâcnirii": "zvâcnire",
    "zvâcnirile": "zvâcnire",
    "zvâcnirilor": "zvâcnire",
    "zvâcnita": "zvâcnit",
    "zvâcnită": "zvâcnit",
    "zvâcnite": "zvâcnit",
    "zvâcnitei": "zvâcnit",
    "zvâcnitele": "zvâcnit",
    "zvâcnitelor": "zvâcnit",
    "zvâcniți": "zvâcnit",
    "zvâcniții": "zvâcnit",
    "zvâcniților": "zvâcnit",
    "zvâcnito": "zvâcnit",
    "zvâcnitul": "zvâcnit",
    "zvâcnitule": "zvâcnit",
    "zvâcnitului": "zvâcnit",
    "zvâcnitoare": "zvâcnitor",
    "zvâcnitoarea": "zvâcnitor",
    "zvâcnitoarei": "zvâcnitor",
    "zvâcnitoarele": "zvâcnitor",
    "zvâcnitoarelor": "zvâcnitor",
    "zvâcnitori": "zvâcnitor",
    "zvâcnitorii": "zvâcnitor",
    "zvâcnitorilor": "zvâcnitor",
    "zvâcnitorul": "zvâcnitor",
    "zvâcnitorului": "zvâcnitor",
    "nemaizvântând": "zvânta",
    "nemaizvântându": "zvânta",
    "nezvântând": "zvânta",
    "nezvântându": "zvânta",
    "zvânt": "zvânta",
    "zvântă": "zvânta",
    "zvântai": "zvânta",
    "zvântam": "zvânta",
    "zvântăm": "zvânta",
    "zvântând": "zvânta",
    "zvântându": "zvânta",
    "zvântară": "zvânta",
    "zvântarăm": "zvânta",
    "zvântarăți": "zvânta",
    "zvântase": "zvânta",
    "zvântasem": "zvânta",
    "zvântaseră": "zvânta",
    "zvântaserăm": "zvânta",
    "zvântaserăți": "zvânta",
    "zvântaseși": "zvânta",
    "zvântași": "zvânta",
    "zvântat": "zvânta",
    "zvântați": "zvânta",
    "zvântatu": "zvânta",
    "zvântau": "zvânta",
    "zvânte": "zvânta",
    "zvânți": "zvânta",
    "zvântarea": "zvântare",
    "zvântări": "zvântare",
    "zvântării": "zvântare",
    "zvântările": "zvântare",
    "zvântata": "zvântat",
    "zvântată": "zvântat",
    "zvântate": "zvântat",
    "zvântatei": "zvântat",
    "zvântatele": "zvântat",
    "zvântatelor": "zvântat",
    "zvântați": "zvântat",
    "zvântații": "zvântat",
    "zvântaților": "zvântat",
    "zvântatul": "zvântat",
    "zvântatului": "zvântat",
    "zvârcoleala": "zvârcoleală",
    "zvârcoleli": "zvârcoleală",
    "zvârcolelii": "zvârcoleală",
    "zvârcolelile": "zvârcoleală",
    "zvârcolelilor": "zvârcoleală",
    "nemaizvârcolind": "zvârcoli",
    "nemaizvârcolindu": "zvârcoli",
    "nezvârcolind": "zvârcoli",
    "nezvârcolindu": "zvârcoli",
    "zvârcolea": "zvârcoli",
    "zvârcoleai": "zvârcoli",
    "zvârcoleam": "zvârcoli",
    "zvârcolească": "zvârcoli",
    "zvârcoleați": "zvârcoli",
    "zvârcoleau": "zvârcoli",
    "zvârcolesc": "zvârcoli",
    "zvârcolește": "zvârcoli",
    "zvârcolești": "zvârcoli",
    "zvârcolii": "zvârcoli",
    "zvârcolim": "zvârcoli",
    "zvârcolind": "zvârcoli",
    "zvârcolindu": "zvârcoli",
    "zvârcoliră": "zvârcoli",
    "zvârcolirăm": "zvârcoli",
    "zvârcolirăți": "zvârcoli",
    "zvârcolise": "zvârcoli",
    "zvârcolisem": "zvârcoli",
    "zvârcoliseră": "zvârcoli",
    "zvârcoliserăm": "zvârcoli",
    "zvârcoliserăți": "zvârcoli",
    "zvârcoliseși": "zvârcoli",
    "zvârcoliși": "zvârcoli",
    "zvârcolit": "zvârcoli",
    "zvârcoliți": "zvârcoli",
    "zvârcolitu": "zvârcoli",
    "zvârcolirea": "zvârcolire",
    "zvârcolireo": "zvârcolire",
    "zvârcoliri": "zvârcolire",
    "zvârcolirii": "zvârcolire",
    "zvârcolirile": "zvârcolire",
    "zvârcolirilor": "zvârcolire",
    "zvârcolita": "zvârcolit",
    "zvârcolită": "zvârcolit",
    "zvârcolite": "zvârcolit",
    "zvârcolitei": "zvârcolit",
    "zvârcolitele": "zvârcolit",
    "zvârcolitelor": "zvârcolit",
    "zvârcoliți": "zvârcolit",
    "zvârcoliții": "zvârcolit",
    "zvârcoliților": "zvârcolit",
    "zvârcolito": "zvârcolit",
    "zvârcolitul": "zvârcolit",
    "zvârcolitule": "zvârcolit",
    "zvârcolitului": "zvârcolit",
    "nemaizvârlind": "zvârli",
    "nemaizvârlindu": "zvârli",
    "nezvârlind": "zvârli",
    "nezvârlindu": "zvârli",
    "zvârl": "zvârli",
    "zvârlă": "zvârli",
    "zvârle": "zvârli",
    "zvârlea": "zvârli",
    "zvârleai": "zvârli",
    "zvârleam": "zvârli",
    "zvârleați": "zvârli",
    "zvârleau": "zvârli",
    "zvârlii": "zvârli",
    "zvârlim": "zvârli",
    "zvârlind": "zvârli",
    "zvârlindu": "zvârli",
    "zvârliră": "zvârli",
    "zvârlirăm": "zvârli",
    "zvârlirăți": "zvârli",
    "zvârlise": "zvârli",
    "zvârlisem": "zvârli",
    "zvârliseră": "zvârli",
    "zvârliserăm": "zvârli",
    "zvârliserăți": "zvârli",
    "zvârliseși": "zvârli",
    "zvârliși": "zvârli",
    "zvârlit": "zvârli",
    "zvârliți": "zvârli",
    "zvârlitu": "zvârli",
    "zvârlirea": "zvârlire",
    "zvârliri": "zvârlire",
    "zvârlirii": "zvârlire",
    "zvârlirile": "zvârlire",
    "zvârlita": "zvârlit",
    "zvârlită": "zvârlit",
    "zvârlite": "zvârlit",
    "zvârlitei": "zvârlit",
    "zvârlitele": "zvârlit",
    "zvârlitelor": "zvârlit",
    "zvârliți": "zvârlit",
    "zvârliții": "zvârlit",
    "zvârliților": "zvârlit",
    "zvârlitul": "zvârlit",
    "zvârlitului": "zvârlit",
    "zvârlitura": "zvârlitură",
    "zvârlituri": "zvârlitură",
    "zvârliturii": "zvârlitură",
    "zvârliturile": "zvârlitură",
    "zvârliturilor": "zvârlitură",
    "zvelta": "zvelt",
    "zveltă": "zvelt",
    "zvelte": "zvelt",
    "zveltei": "zvelt",
    "zveltele": "zvelt",
    "zveltelor": "zvelt",
    "zvelți": "zvelt",
    "zvelții": "zvelt",
    "zvelților": "zvelt",
    "zvelto": "zvelt",
    "zveltul": "zvelt",
    "zveltule": "zvelt",
    "zveltului": "zvelt",
    "zvonul": "zvon",
    "zvonule": "zvon",
    "zvonului": "zvon",
    "zvonuri": "zvon",
    "zvonurile": "zvon",
    "zvonurilor": "zvon",
    "nemaizvonind": "zvoni",
    "nemaizvonindu": "zvoni",
    "nezvonind": "zvoni",
    "nezvonindu": "zvoni",
    "zvonea": "zvoni",
    "zvoneai": "zvoni",
    "zvoneam": "zvoni",
    "zvonească": "zvoni",
    "zvoneați": "zvoni",
    "zvoneau": "zvoni",
    "zvonesc": "zvoni",
    "zvonește": "zvoni",
    "zvonești": "zvoni",
    "zvonii": "zvoni",
    "zvonim": "zvoni",
    "zvonind": "zvoni",
    "zvonindu": "zvoni",
    "zvoniră": "zvoni",
    "zvonirăm": "zvoni",
    "zvonirăți": "zvoni",
    "zvonise": "zvoni",
    "zvonisem": "zvoni",
    "zvoniseră": "zvoni",
    "zvoniserăm": "zvoni",
    "zvoniserăți": "zvoni",
    "zvoniseși": "zvoni",
    "zvoniși": "zvoni",
    "zvonit": "zvoni",
    "zvoniți": "zvoni",
    "zvonitu": "zvoni",
    "zvonirea": "zvonire",
    "zvonireo": "zvonire",
    "zvoniri": "zvonire",
    "zvonirii": "zvonire",
    "zvonirile": "zvonire",
    "zvonirilor": "zvonire",
    "zvonistica": "zvonistică",
    "zvonistici": "zvonistică",
    "zvonisticii": "zvonistică",
    "zvonita": "zvonit",
    "zvonită": "zvonit",
    "zvonite": "zvonit",
    "zvonitei": "zvonit",
    "zvonitele": "zvonit",
    "zvonitelor": "zvonit",
    "zvoniți": "zvonit",
    "zvoniții": "zvonit",
    "zvoniților": "zvonit",
    "zvonito": "zvonit",
    "zvonitul": "zvonit",
    "zvonitule": "zvonit",
    "zvonitului": "zvonit"
}
